

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET transaction_timeout = 0;
SET client_encoding = 'LATIN1';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET xmloption = content;
SET client_min_messages = warning;
SET row_security = off;


CREATE DATABASE harmbase2 WITH TEMPLATE = template0 ENCODING = 'LATIN1' LOCALE_PROVIDER = libc LC_COLLATE = 'C' LC_CTYPE = 'en_US';


\connect harmbase2

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET transaction_timeout = 0;
SET client_encoding = 'LATIN1';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET xmloption = content;
SET client_min_messages = warning;
SET row_security = off;

SET default_tablespace = '';

SET default_table_access_method = heap;


CREATE TABLE public.aliases (
    format text NOT NULL,
    alias text NOT NULL,
    name text NOT NULL
);



CREATE TABLE public.constants (
    index integer NOT NULL,
    name text NOT NULL,
    phase double precision NOT NULL,
    amp double precision NOT NULL,
    CONSTRAINT constants_amp_check CHECK ((amp >= (0.00005)::double precision)),
    CONSTRAINT constants_phase_check CHECK (((phase >= (0)::double precision) AND (phase < (360)::double precision)))
);



CREATE TABLE public.constituents (
    name text NOT NULL,
    definition text NOT NULL,
    speed double precision NOT NULL,
    CONSTRAINT constituents_speed_check CHECK ((speed > (0)::double precision))
);



CREATE TABLE public.currents_geogroups (
    sid text NOT NULL,
    state text NOT NULL,
    region text,
    subregion text
);



CREATE TABLE public.data_sets (
    index integer NOT NULL,
    name text NOT NULL,
    station_id_context text,
    station_id text,
    lat double precision,
    lng double precision,
    timezone text NOT NULL,
    country text,
    units text NOT NULL,
    min_dir double precision,
    max_dir double precision,
    legalese text,
    notes text,
    comments text,
    source text,
    restriction text NOT NULL,
    date_imported date DEFAULT ('now'::text)::date,
    xfields text,
    meridian interval hour to minute,
    datumkind text,
    datum double precision,
    months_on_station smallint,
    last_date_on_station date,
    ref_index integer,
    min_time_add interval hour to minute,
    min_level_add double precision,
    min_level_multiply double precision,
    max_time_add interval hour to minute,
    max_level_add double precision,
    max_level_multiply double precision,
    flood_begins interval hour to minute,
    ebb_begins interval hour to minute,
    original_name text,
    state text,
    CONSTRAINT data_sets_check CHECK ((((lat IS NULL) AND (lng IS NULL)) OR ((lat IS NOT NULL) AND (lng IS NOT NULL)))),
    CONSTRAINT data_sets_check2 CHECK ((((datum IS NULL) AND (meridian IS NULL)) OR ((datum IS NOT NULL) AND (meridian IS NOT NULL)))),
    CONSTRAINT data_sets_check3 CHECK (((datum IS NOT NULL) OR (ref_index IS NOT NULL))),
    CONSTRAINT data_sets_lat_check CHECK (((lat >= ('-90'::integer)::double precision) AND (lat <= (90)::double precision))),
    CONSTRAINT data_sets_lng_check CHECK (((lng >= ('-180'::integer)::double precision) AND (lng <= (180)::double precision))),
    CONSTRAINT data_sets_max_dir_check CHECK (((max_dir >= (0)::double precision) AND (max_dir < (360)::double precision))),
    CONSTRAINT data_sets_max_level_multiply_check CHECK ((max_level_multiply > (0)::double precision)),
    CONSTRAINT data_sets_min_dir_check CHECK (((min_dir >= (0)::double precision) AND (min_dir < (360)::double precision))),
    CONSTRAINT data_sets_min_level_multiply_check CHECK ((min_level_multiply > (0)::double precision)),
    CONSTRAINT data_sets_units_check CHECK (((units = 'feet'::text) OR (units = 'meters'::text) OR (units = 'knots'::text) OR (units = 'knots^2'::text)))
);



CREATE SEQUENCE public.data_sets_index_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;



ALTER SEQUENCE public.data_sets_index_seq OWNED BY public.data_sets.index;



CREATE TABLE public.data_sets_old (
    index integer,
    name text,
    station_id_context text,
    station_id text,
    lat double precision,
    lng double precision,
    timezone text,
    country text,
    units text,
    min_dir double precision,
    max_dir double precision,
    legalese text,
    notes text,
    comments text,
    source text,
    restriction text,
    date_imported date,
    xfields text,
    meridian interval hour to minute,
    datumkind text,
    datum double precision,
    months_on_station smallint,
    last_date_on_station date,
    ref_index integer,
    min_time_add interval hour to minute,
    min_level_add double precision,
    min_level_multiply double precision,
    max_time_add interval hour to minute,
    max_level_add double precision,
    max_level_multiply double precision,
    flood_begins interval hour to minute,
    ebb_begins interval hour to minute,
    original_name text,
    state text
);



CREATE VIEW public.reference_stations AS
 SELECT index,
    name,
    original_name,
    station_id_context,
    station_id,
    lat,
    lng,
    timezone,
    country,
    state,
    units,
    min_dir,
    max_dir,
    legalese,
    notes,
    comments,
    source,
    restriction,
    date_imported,
    xfields,
    meridian,
    datumkind,
    datum,
    months_on_station,
    last_date_on_station
   FROM public.data_sets
  WHERE (datum IS NOT NULL);



CREATE VIEW public.subordinate_stations AS
 SELECT index,
    name,
    original_name,
    station_id_context,
    station_id,
    lat,
    lng,
    timezone,
    country,
    state,
    units,
    min_dir,
    max_dir,
    legalese,
    notes,
    comments,
    source,
    restriction,
    date_imported,
    xfields,
    ref_index,
    min_time_add,
    min_level_add,
    min_level_multiply,
    max_time_add,
    max_level_add,
    max_level_multiply,
    flood_begins,
    ebb_begins
   FROM public.data_sets
  WHERE (datum IS NULL);



ALTER TABLE ONLY public.data_sets ALTER COLUMN index SET DEFAULT nextval('public.data_sets_index_seq'::regclass);



COPY public.aliases (format, alias, name) FROM stdin;
N	SM	MSF
N	OQ2	OQ2-HORN
N	LABDA2	LDA2
N	3MSN10	3MNS10
N	4MSN12	4MNS12
G	OQ2	OQ2-HORN
G	LAM2	LDA2
G	4MSN12	4MNS12
G	MQ3	NO3
G	3M(SK2	3MKS2
G	3M2S2	3MS2
G	2MV6	2MNU6
G	MVS2	MNUS2
GI	SA	SA-IOS
GI	MF	MF-IOS
GI	S1	S1-IOS
GI	OO1	OO1-IOS
GI	R2	R2-IOS
NOS	LAM2	LDA2
NOS	RHO	RHO1
NOS	SIGMA1	SIG1
NOS	2MLNS6	2MNLS6
NOS	2MS8	2(MS)8
NOS	2MN8	2(MN)8
NOS	M2KS2	M2(KS)2
NOS	2SNMK2	2SN(MK)2
NOS	2KMSN2	2KM(SN)2
NOS	THETA1	THE1
NOS	OO2	OQ2-HORN
NOS	RP1	PSI1
NOS	KJ2	KJ2-IHO
\.



COPY public.constants (index, name, phase, amp) FROM stdin;
102693	M2	44.1	0.52
102693	S2	38.3	0.22
102693	N2	38.3	0.1
102693	K1	226.5	0.54
102693	O1	221.5	0.28
102693	NU2	25.2	0.02
102693	MU2	356	0.01
102693	2N2	45	0.01
102693	OO1	263.1	0.02
102693	M1	247.2	0.02
102693	J1	237.6	0.04
102693	SA	192.1	0.16
102693	RHO1	219.4	0.01
102693	Q1	215.7	0.05
102693	T2	38.2	0.02
102693	2Q1	216.4	0.01
102693	P1	223.3	0.17
102693	L2	35.1	0.01
102693	K2	34	0.06
102694	M2	48.1	0.49
102694	S2	45.3	0.19
102694	N2	35	0.1
102694	K1	230.3	0.48
102694	M4	187.3	0.01
102694	O1	221.3	0.28
102694	NU2	33.6	0.02
102694	MU2	357.4	0.01
102694	2N2	20.9	0.01
102694	OO1	255	0.02
102694	LDA2	54.8	0.01
102694	M1	241.5	0.02
102694	J1	246.3	0.03
102694	MM	19.4	0.03
102694	SA	181.1	0.17
102694	MF	49.6	0.02
102694	RHO1	217.3	0.01
102694	Q1	212.4	0.05
102694	T2	45.3	0.01
102694	P1	228	0.15
102694	L2	30.2	0.01
102694	K2	34.8	0.05
102694	MS4	206.8	0.01
102695	M2	59.4	0.56
102695	S2	54.7	0.18
102695	N2	48.8	0.11
102695	K1	226.8	0.49
102695	O1	215.9	0.27
102695	NU2	56	0.02
102695	MU2	7.8	0.01
102695	2N2	39.9	0.01
102695	OO1	251.7	0.02
102695	S1	210	0.01
102695	M1	232.5	0.02
102695	J1	238.3	0.03
102695	MM	43.4	0.02
102695	SA	177.7	0.16
102695	MF	44.3	0.02
102695	RHO1	195.4	0.01
102695	Q1	209.6	0.05
102695	T2	43.6	0.01
102695	P1	224.9	0.15
102695	L2	49.3	0.01
102695	K2	45.7	0.05
102696	M2	64.1	0.52
102696	S2	57.5	0.18
102696	N2	50.1	0.1
102696	K1	223.6	0.51
102696	M4	268.1	0.01
102696	O1	215.9	0.27
102696	NU2	52	0.02
102696	MU2	114.7	0.01
102696	2N2	35.6	0.01
102696	OO1	231.3	0.01
102696	M1	219.8	0.02
102696	J1	227.4	0.02
102696	SA	191.5	0.13
102696	MF	48.2	0.02
102696	RHO1	212.6	0.01
102696	Q1	212.1	0.05
102696	T2	57.8	0.01
102696	2Q1	208.3	0.01
102696	P1	223	0.17
102696	L2	77.8	0.01
102696	K2	57	0.05
102697	M2	63	0.58
102697	S2	63.6	0.2
102697	N2	47.4	0.12
102697	K1	226.2	0.5
102697	M4	223.6	0.02
102697	O1	216.2	0.27
102697	MK3	146.4	0.01
102697	MN4	157.8	0.01
102697	NU2	38.7	0.02
102697	MU2	15.1	0.01
102697	2N2	59.7	0.01
102697	OO1	255.6	0.02
102697	LDA2	43.9	0.01
102697	S1	345.8	0.01
102697	M1	242.1	0.02
102697	J1	240.8	0.03
102697	MM	43.3	0.02
102697	SA	177.7	0.16
102697	MF	44.3	0.02
102697	RHO1	217.7	0.01
102697	Q1	204.2	0.04
102697	T2	352.1	0.01
102697	P1	225.1	0.15
102697	2SM2	254.8	0.01
102697	L2	41.8	0.02
102697	K2	47.7	0.06
102697	MS4	278.7	0.01
102698	M2	64.9	0.53
102698	S2	58.4	0.18
102698	N2	50.1	0.1
102698	K1	223.7	0.51
102698	M4	286.6	0.01
102698	O1	215.5	0.27
102698	NU2	52.1	0.02
102698	MU2	115.5	0.01
102698	2N2	34.8	0.01
102698	OO1	232	0.01
102698	M1	219.7	0.02
102698	J1	227.9	0.02
102698	SA	191.5	0.13
102698	RHO1	212	0.01
102698	Q1	211.4	0.05
102698	T2	58.7	0.01
102698	2Q1	207.2	0.01
102698	P1	223.1	0.17
102698	L2	79.6	0.02
102698	K2	57.9	0.05
102699	M2	13.2	0.52
102699	S2	14	0.26
102699	N2	7.8	0.11
102699	K1	236.2	0.58
102699	M4	178.8	0.01
102699	O1	227.3	0.32
102699	NU2	10.6	0.02
102699	MU2	337.1	0.02
102699	2N2	0.2	0.02
102699	OO1	260.7	0.03
102699	LDA2	324.2	0.01
102699	M1	249.5	0.02
102699	J1	248.7	0.04
102699	MM	43.1	0.02
102699	SA	184.6	0.16
102699	MF	43.6	0.02
102699	RHO1	224	0.01
102699	Q1	220	0.06
102699	T2	7.4	0.02
102699	R2	315.5	0.01
102699	P1	234.7	0.18
102699	2SM2	238.4	0.01
102699	M3	153.1	0.01
102699	L2	3.5	0.01
102699	K2	11.1	0.08
102700	M2	55.9	0.6
102700	S2	59.6	0.22
102700	N2	44	0.11
102700	K1	227.7	0.52
102700	M4	227.3	0.01
102700	O1	216.5	0.29
102700	NU2	43.8	0.02
102700	MU2	15.1	0.02
102700	2N2	49.1	0.02
102700	OO1	243.1	0.02
102700	LDA2	61.4	0.01
102700	S1	149.9	0.01
102700	M1	227.5	0.02
102700	J1	236.8	0.03
102700	SA	181.5	0.13
102700	MF	48.2	0.02
102700	RHO1	171.7	0.01
102700	Q1	218.7	0.04
102700	T2	38.8	0.02
102700	R2	59	0.03
102700	2Q1	245.7	0.01
102700	P1	222.8	0.17
102700	L2	88.4	0.01
102700	K2	56.3	0.06
102701	M2	8	0.6
102701	S2	15.3	0.31
102701	N2	1.4	0.11
102701	K1	233.3	0.55
102701	O1	219.7	0.31
102701	NU2	4.6	0.02
102701	MU2	343.2	0.03
102701	2N2	354	0.02
102701	OO1	258.1	0.02
102701	LDA2	351.5	0.01
102701	S1	188.5	0.01
102701	M1	244.9	0.02
102701	J1	246.1	0.04
102701	MM	37.2	0.02
102701	SA	179.2	0.16
102701	MF	28.7	0.02
102701	RHO1	210	0.01
102701	Q1	210.9	0.05
102701	T2	14.6	0.02
102701	R2	63.8	0.01
102701	P1	230.1	0.17
102701	M3	134.5	0.01
102701	L2	359.5	0.02
102701	K2	9.4	0.09
102702	M2	57.6	0.65
102702	S2	64.6	0.22
102702	N2	45.8	0.13
102702	K1	226.2	0.52
102702	O1	213.4	0.29
102702	NU2	53.7	0.03
102702	MU2	16.6	0.02
102702	2N2	36.7	0.02
102702	OO1	255	0.02
102702	S1	218.7	0.01
102702	M1	230.3	0.02
102702	J1	242.4	0.03
102702	SA	174.4	0.16
102702	MF	38.8	0.02
102702	RHO1	199.4	0.01
102702	Q1	204.9	0.05
102702	T2	83.2	0.01
102702	P1	223.2	0.16
102702	L2	42.2	0.01
102702	K2	53.3	0.06
102703	M2	29	0.72
102703	S2	34.6	0.3
102703	N2	19.3	0.14
102703	K1	233.4	0.53
102703	O1	222.6	0.3
102703	NU2	27.3	0.03
102703	MU2	0.9	0.03
102703	2N2	13.3	0.02
102703	OO1	264	0.02
102703	S1	238.4	0.01
102703	M1	242.4	0.02
102703	J1	246.4	0.04
102703	MM	19.8	0.03
102703	SA	188.2	0.15
102703	MF	41.3	0.02
102703	RHO1	208.8	0.01
102703	Q1	215.2	0.05
102703	T2	33	0.01
102703	P1	231.2	0.16
102703	2SM2	221.3	0.01
102703	M3	114.7	0.01
102703	L2	12.8	0.02
102703	K2	26.6	0.09
102704	M2	100.4	0.89
102704	S2	122.1	0.34
102704	N2	99.8	0.16
102704	K1	214.8	0.27
102704	O1	223.9	0.11
102704	NU2	96.5	0.03
102704	MU2	106	0.02
102704	2N2	95.1	0.02
102704	OO1	239.1	0.01
102704	LDA2	110.4	0.01
102704	S1	250.9	0.01
102704	M1	219.3	0.01
102704	J1	223.8	0.02
102704	SA	204.3	0.18
102704	MF	30.4	0.03
102704	Q1	229.1	0.02
102704	T2	129.3	0.03
102704	P1	212.2	0.08
102704	L2	93.9	0.02
102704	K2	117.9	0.09
102704	MS4	13.8	0.01
102705	M2	91.8	0.39
102705	S2	165.5	0.07
102705	N2	54.9	0.08
102705	K1	274.7	0.25
102705	O1	279.2	0.18
102705	NU2	58.9	0.02
102705	MU2	279.7	0.01
102705	2N2	17.8	0.01
102705	OO1	282.5	0.01
102705	LDA2	134.6	0.01
102705	S1	184	0.01
102705	M1	307	0.01
102705	J1	263.5	0.01
102705	SA	232.6	0.17
102705	RHO1	265.6	0.01
102705	Q1	278.7	0.04
102705	T2	143.9	0.01
102705	R2	344.5	0.01
102705	2Q1	317.4	0.01
102705	P1	274	0.08
102705	M3	240.7	0.01
102705	L2	126.3	0.01
102705	K2	173.3	0.02
102706	M2	291.4	0.72
102706	S2	306.7	0.18
102706	N2	276.5	0.16
102706	K1	64.7	0.53
102706	M4	155	0.01
102706	O1	43.6	0.38
102706	NU2	278.3	0.03
102706	MU2	266.4	0.01
102706	2N2	245.2	0.02
102706	OO1	101.6	0.02
102706	LDA2	328.7	0.01
102706	S1	236.1	0.02
102706	M1	83.6	0.03
102706	J1	85.9	0.03
102706	MM	355.5	0.03
102706	SA	103.6	0.23
102706	MF	18	0.03
102706	RHO1	36.1	0.02
102706	Q1	36.8	0.08
102706	T2	308.4	0.02
102706	R2	68.5	0.01
102706	2Q1	27.1	0.01
102706	P1	66.4	0.18
102706	L2	319.5	0.02
102706	K2	304.4	0.05
102706	MS4	212.4	0.01
102707	M2	276.4	0.47
102707	S2	281.6	0.08
102707	N2	253.3	0.11
102707	K1	62.1	0.48
102707	M4	131.7	0.01
102707	O1	44.1	0.33
102707	MK3	294.4	0.01
102707	NU2	254.8	0.02
102707	2N2	225	0.02
102707	OO1	91.3	0.02
102707	LDA2	314.9	0.01
102707	S1	301.6	0.02
102707	M1	82.1	0.02
102707	J1	88.7	0.03
102707	SSA	273	0.03
102707	SA	22.8	0.09
102707	MSF	33.2	0.03
102707	RHO1	28.4	0.01
102707	Q1	33.9	0.06
102707	2Q1	35.3	0.01
102707	P1	61.4	0.15
102707	L2	302.7	0.01
102707	2MK3	295.5	0.01
102707	K2	281.7	0.03
102707	MS4	178.5	0.01
102708	M2	296.2	0.62
102708	S2	305.3	0.14
102708	N2	278.9	0.15
102708	K1	64.9	0.55
102708	O1	45.6	0.37
102708	S4	189.7	0.01
102708	NU2	287.4	0.03
102708	MU2	283.2	0.01
102708	2N2	228.6	0.02
102708	OO1	110.6	0.02
102708	LDA2	334	0.01
102708	S1	80.4	0.02
102708	M1	59.5	0.02
102708	J1	70.9	0.04
102708	RHO1	21.4	0.02
102708	Q1	33.3	0.08
102708	T2	280.1	0.02
102708	R2	108.7	0.02
102708	2Q1	38	0.01
102708	P1	66.7	0.2
102708	M3	350.3	0.01
102708	L2	316.4	0.02
102708	K2	300.7	0.05
102708	MS4	261.6	0.01
102709	M2	179.8	1.24
102709	S2	164.9	0.2
102709	N2	160.4	0.35
102709	K1	81.9	0.14
102709	M4	80.6	0.01
102709	O1	67.2	0.1
102709	NU2	161.3	0.07
102709	MU2	139.8	0.06
102709	2N2	139.9	0.05
102709	S1	240.2	0.01
102709	J1	64.2	0.01
102709	MM	17.3	0.02
102709	SSA	104.1	0.01
102709	SA	205	0.04
102709	MF	23.8	0.03
102709	Q1	53.4	0.02
102709	T2	157.5	0.01
102709	P1	73.2	0.04
102709	M3	19.5	0.01
102709	L2	182.1	0.02
102709	K2	154.1	0.05
102710	M2	128	1.53
102710	S2	148.6	0.86
102710	N2	126.9	0.29
102710	K1	65.9	0.33
102710	O1	39.6	0.21
102710	NU2	126.1	0.05
102710	MU2	129.5	0.05
102710	2N2	119	0.04
102710	OO1	126.6	0.01
102710	LDA2	122.3	0.01
102710	S1	249.8	0.02
102710	M1	84.2	0.01
102710	J1	87.5	0.02
102710	MM	15.7	0.03
102710	SA	48.8	0.15
102710	MF	16.5	0.04
102710	RHO1	29.2	0.01
102710	Q1	26	0.04
102710	T2	138.3	0.06
102710	R2	114.6	0.01
102710	2Q1	352.7	0.01
102710	P1	67	0.1
102710	M3	320.4	0.01
102710	L2	125	0.05
102710	K2	144.9	0.24
102711	M2	129.2	0.24
102711	S2	147.5	0.34
102711	N2	185	0.05
102711	K1	64.8	0.62
102711	O1	44	0.39
102711	NU2	177.4	0.01
102711	MU2	133.4	0.02
102711	2N2	240.7	0.01
102711	OO1	85.6	0.02
102711	S1	253	0.01
102711	M1	54.4	0.03
102711	J1	81.2	0.04
102711	SSA	25.7	0.1
102711	SA	62.6	0.11
102711	MF	16.7	0.04
102711	RHO1	35.1	0.01
102711	Q1	34.2	0.08
102711	T2	147.5	0.02
102711	2Q1	23.2	0.01
102711	P1	64.2	0.2
102711	M3	30.6	0.01
102711	L2	73.6	0.01
102711	K2	143.2	0.1
102712	M2	309.1	1.79
102712	S2	342.3	0.7
102712	N2	292.6	0.34
102712	K1	91.1	0.65
102712	M4	181.7	0.08
102712	O1	70.7	0.5
102712	NU2	291.9	0.05
102712	MU2	5.8	0.04
102712	2N2	276.1	0.05
102712	OO1	111.6	0.02
102712	LDA2	324.6	0.01
102712	S1	67.5	0.05
102712	M1	91.5	0.03
102712	J1	101.3	0.04
102712	SSA	64.8	0.16
102712	SA	194.4	0.37
102712	MSF	131.3	0.1
102712	MF	348.2	0.03
102712	RHO1	62	0.02
102712	Q1	63.5	0.1
102712	T2	342.3	0.04
102712	2Q1	50.3	0.01
102712	P1	94.1	0.22
102712	2SM2	339.5	0.03
102712	L2	312.6	0.09
102712	K2	339.3	0.2
102713	M2	115.5	0.91
102713	S2	149.5	0.46
102713	N2	105.8	0.15
102713	K1	44.5	0.2
102713	O1	14.8	0.16
102713	NU2	106.2	0.03
102713	MU2	128.6	0.02
102713	2N2	100.4	0.02
102713	OO1	134	0.01
102713	LDA2	103.5	0.01
102713	S1	279.5	0.01
102713	M1	63.3	0.01
102713	J1	80.5	0.01
102713	SA	167.2	0.11
102713	MF	38	0.02
102713	RHO1	5.6	0.01
102713	Q1	5.8	0.04
102713	T2	144.8	0.03
102713	2Q1	340.1	0.01
102713	P1	40.7	0.07
102713	M3	308.5	0.01
102713	L2	127.6	0.03
102713	K2	146.6	0.12
102714	M2	98.4	8.69
102714	S2	138.8	1.36
102714	N2	67	1.78
102714	K1	195.5	0.51
102714	M4	84.8	0.19
102714	O1	176.3	0.39
102714	M6	274	0.16
102714	MK3	74.1	0.01
102714	MN4	51.7	0.07
102714	NU2	73.6	0.41
102714	MU2	166.5	0.05
102714	2N2	44.7	0.22
102714	OO1	234.3	0.02
102714	LDA2	122.4	0.17
102714	S1	124.9	0.02
102714	M1	212.9	0.02
102714	J1	207.5	0.02
102714	SSA	126.4	0.04
102714	SA	171.5	0.03
102714	RHO1	157.8	0.01
102714	Q1	157.9	0.07
102714	T2	115.8	0.12
102714	R2	348.5	0.03
102714	2Q1	225.8	0.01
102714	P1	196.4	0.17
102714	2SM2	70	0.02
102714	M3	216.5	0.01
102714	L2	141	0.52
102714	2MK3	327.1	0.02
102714	K2	138.3	0.38
102714	M8	250	0.02
102714	MS4	129.2	0.06
102715	M2	117.3	7.93
102715	S2	161.4	1.18
102715	N2	94.6	1.57
102715	K1	216.1	0.48
102715	M4	136.2	0.26
102715	O1	192.3	0.37
102715	M6	339.7	0.33
102715	S4	314.6	0.01
102715	NU2	97.6	0.31
102715	S6	251.2	0.01
102715	MU2	299	0.19
102715	2N2	71.8	0.21
102715	OO1	240.1	0.02
102715	LDA2	137.8	0.06
102715	M1	204.3	0.03
102715	J1	228	0.03
102715	SSA	127.6	0.05
102715	RHO1	182	0.01
102715	Q1	180.4	0.07
102715	T2	159.7	0.07
102715	R2	163.2	0.01
102715	2Q1	168.5	0.01
102715	P1	214.3	0.16
102715	L2	140	0.22
102715	K2	165	0.32
102715	M8	329.7	0.04
102716	M2	106.7	8.97
102716	S2	147	1.46
102716	N2	83.8	1.85
102716	K1	202	0.53
102716	M4	97.3	0.25
102716	O1	180.3	0.4
102716	M6	311.4	0.27
102716	S4	271.8	0.01
102716	NU2	86.9	0.36
102716	S6	205.5	0.01
102716	MU2	292	0.22
102716	2N2	61	0.25
102716	OO1	223.6	0.02
102716	LDA2	125.4	0.06
102716	M1	191.2	0.03
102716	J1	212.7	0.03
102716	SSA	127.6	0.05
102716	RHO1	171	0.02
102716	Q1	169.5	0.08
102716	T2	145.4	0.09
102716	R2	148.6	0.01
102716	2Q1	158.7	0.01
102716	P1	200.3	0.17
102716	L2	129.5	0.25
102716	K2	150.3	0.4
102716	M8	306.9	0.04
102717	M2	105.1	9.13
102717	S2	147.6	1.4
102717	N2	75.9	1.95
102717	K1	199.7	0.51
102717	M4	111.4	0.27
102717	O1	178.9	0.39
102717	M6	282	0.33
102717	MN4	81	0.11
102717	NU2	85.8	0.44
102717	MU2	172.8	0.12
102717	2N2	78.3	0.21
102717	OO1	238.9	0.03
102717	LDA2	125.8	0.17
102717	S1	160	0.03
102717	M1	191.6	0.03
102717	J1	221.1	0.03
102717	SSA	127.6	0.05
102717	Q1	170.4	0.06
102717	T2	126.5	0.13
102717	2Q1	165	0.01
102717	P1	199.4	0.15
102717	2SM2	48.5	0.02
102717	L2	145.2	0.74
102717	K2	148.5	0.41
102717	M8	294	0.06
102717	MS4	162	0.08
102718	M2	135.5	7.88
102718	S2	185.6	1.13
102718	N2	110.5	1.57
102718	K1	226.1	0.45
102718	M4	182.1	0.44
102718	O1	204.8	0.35
102718	M6	24.4	0.46
102718	MK3	244.7	0.04
102718	S4	284.2	0.01
102718	MN4	156.2	0.19
102718	NU2	111.6	0.39
102718	MU2	216.9	0.28
102718	2N2	133.9	0.19
102718	OO1	267.3	0.02
102718	LDA2	143.1	0.17
102718	S1	150	0.03
102718	M1	223.3	0.03
102718	J1	262.5	0.03
102718	SSA	127.6	0.05
102718	RHO1	154.8	0.01
102718	Q1	199.3	0.05
102718	T2	162	0.11
102718	R2	0.8	0.03
102718	2Q1	204.4	0.02
102718	P1	227.4	0.14
102718	2SM2	65.9	0.02
102718	M3	156.2	0.01
102718	L2	160.5	0.86
102718	2MK3	222.3	0.04
102718	K2	185.4	0.32
102718	M8	62.7	0.1
102718	MS4	232	0.12
102719	M2	94	6.67
102719	S2	131.9	1.02
102719	N2	64.1	1.42
102719	K1	192.8	0.47
102719	M4	155.4	0.06
102719	O1	175	0.37
102719	M6	234.7	0.04
102719	MK3	328.4	0.01
102719	MN4	140.2	0.02
102719	NU2	71.2	0.31
102719	MU2	133.6	0.01
102719	2N2	47.5	0.18
102719	OO1	212.2	0.02
102719	LDA2	123.7	0.13
102719	S1	146.5	0.02
102719	M1	212.1	0.02
102719	J1	208	0.02
102719	SSA	128.3	0.06
102719	SA	188.8	0.07
102719	RHO1	141.7	0.01
102719	Q1	154.7	0.05
102719	T2	112.4	0.09
102719	R2	332.8	0.01
102719	P1	194.9	0.16
102719	2SM2	73.3	0.02
102719	L2	132.5	0.34
102719	2MK3	299.6	0.02
102719	K2	131.8	0.29
102719	MS4	214.9	0.02
102720	M2	92.9	6.11
102720	S2	129.8	0.94
102720	N2	62.8	1.29
102720	K1	193.7	0.46
102720	M4	108.5	0.04
102720	O1	173.5	0.36
102720	M6	255.3	0.03
102720	MN4	81.5	0.01
102720	NU2	69.4	0.28
102720	2N2	40.9	0.16
102720	OO1	228.5	0.02
102720	LDA2	124.2	0.11
102720	S1	158.8	0.02
102720	M1	205.9	0.02
102720	J1	204.8	0.03
102720	RHO1	142.2	0.01
102720	Q1	159.2	0.06
102720	T2	103.7	0.09
102720	R2	329.9	0.03
102720	2Q1	153.4	0.01
102720	P1	193.1	0.16
102720	2SM2	77.7	0.02
102720	L2	136	0.28
102720	2MK3	295.9	0.02
102720	K2	128.7	0.26
102720	MS4	186.4	0.01
102721	M2	98.2	5.35
102721	S2	138.4	0.73
102721	N2	64.8	1.08
102721	K1	192.8	0.48
102721	M4	106.5	0.28
102721	O1	180.1	0.4
102721	M6	356.5	0.05
102721	NU2	69.3	0.21
102721	S6	59.7	0.01
102721	MU2	282.2	0.13
102721	2N2	31.5	0.14
102721	OO1	205.5	0.02
102721	LDA2	116.9	0.04
102721	M1	186.5	0.03
102721	J1	199.1	0.03
102721	RHO1	174.7	0.02
102721	Q1	173.8	0.08
102721	T2	136.8	0.04
102721	R2	140	0.01
102721	2Q1	167.5	0.01
102721	P1	191.9	0.16
102721	L2	131.6	0.15
102721	K2	141.7	0.2
102721	M8	162.2	0.03
102722	M2	91.9	5.16
102722	S2	128.1	0.78
102722	N2	61.4	1.14
102722	K1	193.8	0.46
102722	M4	92.8	0.03
102722	O1	174.4	0.36
102722	M6	48.3	0.04
102722	MN4	42.9	0.01
102722	NU2	67.6	0.25
102722	MU2	42.8	0.03
102722	2N2	37.1	0.14
102722	OO1	231.5	0.02
102722	LDA2	125.3	0.09
102722	S1	160.4	0.03
102722	M1	210	0.02
102722	J1	196.8	0.03
102722	SSA	133.7	0.04
102722	SA	135.8	0.1
102722	MSF	86.4	0.04
102722	RHO1	143	0.01
102722	Q1	155.2	0.07
102722	T2	107.7	0.07
102722	R2	335.2	0.02
102722	2Q1	174.5	0.01
102722	P1	190.6	0.16
102722	2SM2	68.4	0.01
102722	L2	135.4	0.26
102722	2MK3	259.9	0.01
102722	K2	128.7	0.21
102722	MS4	167	0.01
102723	M2	99.1	5.25
102723	S2	140.2	0.75
102723	N2	67.2	1.15
102723	K1	197.8	0.52
102723	M4	80.9	0.11
102723	O1	178.3	0.39
102723	M6	100.6	0.11
102723	NU2	71.4	0.22
102723	S6	98.6	0.01
102723	MU2	281.2	0.12
102723	2N2	35.2	0.15
102723	OO1	216.8	0.02
102723	LDA2	118.1	0.04
102723	M1	188	0.03
102723	J1	207	0.03
102723	RHO1	170	0.02
102723	Q1	168.7	0.08
102723	T2	138.5	0.04
102723	R2	141.8	0.01
102723	2Q1	159.1	0.01
102723	P1	196.3	0.17
102723	L2	131	0.15
102723	K2	143.5	0.2
102723	M8	105.1	0.05
102724	M2	95.6	5.05
102724	S2	132.1	0.73
102724	N2	71.2	1.13
102724	K1	199.3	0.52
102724	M4	74.3	0.04
102724	O1	174.9	0.35
102724	M6	81	0.08
102724	NU2	74.4	0.22
102724	MU2	59.1	0.12
102724	2N2	46.7	0.15
102724	OO1	223.7	0.02
102724	LDA2	112.5	0.04
102724	M1	187.2	0.03
102724	J1	211.4	0.03
102724	SSA	133.7	0.04
102724	SA	135.8	0.1
102724	RHO1	164.4	0.01
102724	Q1	162.8	0.07
102724	T2	130.6	0.04
102724	R2	133.6	0.01
102724	2Q1	150.7	0.01
102724	P1	197.4	0.17
102724	L2	120	0.14
102724	K2	135.1	0.2
102724	M8	70.1	0.02
102725	M2	94.6	4.98
102725	S2	145.8	0.76
102725	N2	62.5	1.12
102725	K1	191.9	0.43
102725	M4	53.6	0.02
102725	O1	176.6	0.37
102725	M6	82.4	0.08
102725	MK3	237.1	0.01
102725	MN4	339.8	0.01
102725	NU2	69.9	0.23
102725	MU2	7.8	0.01
102725	2N2	57.1	0.11
102725	OO1	223.2	0.02
102725	LDA2	113.8	0.08
102725	S1	227.1	0.06
102725	M1	188.6	0.02
102725	J1	203.8	0.03
102725	Q1	166.5	0.06
102725	T2	192.7	0.07
102725	R2	25.7	0.22
102725	2Q1	165.1	0.01
102725	P1	181.2	0.13
102725	2SM2	69.3	0.02
102725	M3	155.3	0.01
102725	L2	151	0.34
102725	2MK3	232.6	0.01
102725	K2	109.6	0.24
102725	M8	122.3	0.01
102725	MS4	180.5	0.01
102726	M2	112.6	6
102726	S2	150.7	0.86
102726	N2	74.9	1.24
102726	K1	206.6	0.48
102726	M4	114.9	0.44
102726	O1	190.4	0.37
102726	M6	246.3	0.65
102726	S4	100.7	0.03
102726	NU2	79.9	0.24
102726	S6	250.8	0.04
102726	MU2	296.9	0.14
102726	2N2	37.2	0.16
102726	OO1	222.9	0.02
102726	LDA2	130.3	0.04
102726	M1	198.6	0.03
102726	J1	214.7	0.03
102726	RHO1	183.4	0.01
102726	Q1	182.3	0.07
102726	T2	149.2	0.05
102726	R2	152.3	0.01
102726	2Q1	174.3	0.01
102726	P1	205.4	0.16
102726	L2	150.2	0.17
102726	K2	153.8	0.24
102726	M8	303.5	0.09
102727	M2	98.2	5.21
102727	S2	134.5	0.74
102727	N2	63.5	1.16
102727	K1	195.9	0.49
102727	M4	58.2	0.04
102727	O1	177.9	0.37
102727	M6	118.1	0.17
102727	NU2	68.1	0.23
102727	S6	76.1	0.02
102727	MU2	284.1	0.12
102727	2N2	28.8	0.15
102727	OO1	214	0.02
102727	LDA2	115.1	0.04
102727	M1	187	0.03
102727	J1	204.9	0.03
102727	SSA	105.8	0.07
102727	SA	128.3	0.1
102727	RHO1	170.2	0.01
102727	Q1	168.9	0.07
102727	T2	133	0.04
102727	R2	135.9	0.01
102727	2Q1	160	0.01
102727	P1	194.6	0.16
102727	L2	132.8	0.15
102727	K2	137.4	0.2
102727	M8	163.6	0.02
102728	M2	105.7	5.64
102728	S2	146.4	0.83
102728	N2	74.5	1.28
102728	K1	203	0.52
102728	M4	106.4	0.11
102728	O1	183.4	0.39
102728	M6	202	0.32
102728	S4	124.4	0.01
102728	NU2	78.7	0.25
102728	S6	42.8	0.01
102728	MU2	64.9	0.13
102728	2N2	43.3	0.17
102728	OO1	222.6	0.02
102728	LDA2	124.5	0.04
102728	M1	193.3	0.03
102728	J1	212.8	0.03
102728	RHO1	175	0.02
102728	Q1	173.7	0.08
102728	T2	144.7	0.05
102728	R2	148	0.01
102728	2Q1	164	0.01
102728	P1	201.5	0.17
102728	L2	136.7	0.16
102728	K2	149.6	0.23
102728	M8	309.8	0.04
102729	M2	98.2	4.9
102729	S2	134.1	0.72
102729	N2	65.9	1.12
102729	K1	197.7	0.46
102729	M4	50.7	0.03
102729	O1	178.6	0.36
102729	M6	99.8	0.12
102729	S4	237.9	0.01
102729	NU2	70.3	0.22
102729	MU2	62.3	0.12
102729	2N2	33.7	0.15
102729	OO1	216.7	0.02
102729	LDA2	114.8	0.03
102729	M1	188.2	0.03
102729	J1	207.1	0.03
102729	RHO1	170.4	0.01
102729	Q1	169.2	0.07
102729	T2	132.6	0.04
102729	R2	135.5	0.01
102729	2Q1	159.7	0.01
102729	P1	196.2	0.15
102729	L2	130.4	0.14
102729	K2	137	0.19
102729	M8	164.8	0.01
102730	M2	97.9	4.92
102730	S2	133.2	0.64
102730	N2	65.3	1.08
102730	K1	201.2	0.5
102730	O1	170.3	0.39
102730	M6	98.2	0.11
102730	NU2	69.6	0.21
102730	2N2	32.7	0.14
102730	OO1	231.9	0.02
102730	LDA2	114.1	0.03
102730	M1	185.6	0.03
102730	J1	216.6	0.03
102730	RHO1	157	0.02
102730	Q1	154.8	0.08
102730	T2	133.1	0.04
102730	2Q1	139.4	0.01
102730	P1	201.1	0.17
102730	L2	130.4	0.14
102730	K2	133.2	0.17
102730	M8	186.9	0.03
102731	M2	101.3	4.55
102731	S2	139.2	0.64
102731	N2	72.3	1.02
102731	K1	186.3	0.46
102731	M4	347	0.02
102731	O1	184.6	0.36
102731	M6	119.2	0.11
102731	S4	0.9	0.01
102731	NU2	76.2	0.2
102731	S6	9.5	0.01
102731	MU2	285	0.11
102731	2N2	43.4	0.13
102731	OO1	184.5	0.01
102731	LDA2	118.9	0.03
102731	M1	184.7	0.03
102731	J1	184.8	0.03
102731	RHO1	184.5	0.01
102731	Q1	184.5	0.07
102731	T2	137.7	0.04
102731	R2	140.8	0.01
102731	2Q1	184.5	0.01
102731	P1	186.1	0.15
102731	L2	130.3	0.13
102731	K2	142.3	0.17
102731	M8	99.5	0.02
102732	M2	106.4	4.45
102732	S2	143.6	0.68
102732	N2	78.2	0.96
102732	K1	205.7	0.47
102732	M4	97.9	0.06
102732	O1	184.7	0.36
102732	M6	270.8	0.06
102732	MK3	215.2	0.02
102732	MN4	71.2	0.03
102732	NU2	87	0.21
102732	S6	196.1	0.01
102732	MU2	112.9	0.01
102732	2N2	71.7	0.13
102732	OO1	233	0.01
102732	LDA2	133.6	0.07
102732	S1	116.5	0.02
102732	J1	199.7	0.03
102732	MM	19.7	0.06
102732	SSA	239	0.01
102732	SA	125.7	0.05
102732	RHO1	186.7	0.02
102732	Q1	157.6	0.07
102732	T2	114.9	0.06
102732	2Q1	263.1	0.01
102732	P1	204.5	0.16
102732	2SM2	106.5	0.01
102732	L2	146.3	0.15
102732	2MK3	196.1	0.02
102732	K2	142.3	0.19
102732	M8	262.1	0.01
102732	MS4	136.1	0.02
102733	M2	105.8	4.7
102733	S2	146	0.69
102733	N2	71.6	1.01
102733	K1	201.4	0.48
102733	M4	309.9	0.07
102733	O1	186.2	0.36
102733	M6	218.6	0.01
102733	NU2	76.1	0.19
102733	MU2	65.5	0.11
102733	2N2	37.3	0.13
102733	OO1	216.4	0.01
102733	LDA2	124.5	0.03
102733	M1	193.9	0.02
102733	J1	208.8	0.03
102733	SSA	105.8	0.07
102733	SA	128.3	0.1
102733	RHO1	179.8	0.01
102733	Q1	178.8	0.07
102733	T2	144.3	0.04
102733	R2	147.7	0.01
102733	2Q1	171.4	0.01
102733	P1	200.2	0.16
102733	L2	140.1	0.13
102733	K2	149.3	0.18
102733	M8	118	0.02
102734	M2	209.8	2.61
102734	S2	259.8	0.29
102734	N2	179.7	0.53
102734	K1	283.9	0.34
102734	M4	317.9	0.22
102734	O1	262.5	0.26
102734	M6	290.2	0.16
102734	S4	14	0.02
102734	NU2	183.8	0.1
102734	S6	64.4	0.01
102734	MU2	20.2	0.06
102734	2N2	149.7	0.07
102734	OO1	305.2	0.01
102734	LDA2	233	0.02
102734	M1	273.3	0.02
102734	J1	294.5	0.02
102734	RHO1	253.3	0.01
102734	Q1	251.9	0.05
102734	T2	257.8	0.02
102734	2Q1	241.3	0.01
102734	P1	282.3	0.11
102734	L2	239.8	0.07
102734	K2	263.9	0.08
102734	M8	52.8	0.04
102735	M2	221	0.92
102735	S2	306.2	0.12
102735	N2	181.2	0.19
102735	K1	268.4	0.14
102735	M4	55.7	0.27
102735	O1	277.5	0.21
102735	M6	243.6	0.06
102735	S4	108.7	0.01
102735	NU2	186.6	0.04
102735	MU2	133.3	0.02
102735	2N2	141.9	0.02
102735	OO1	253.5	0.01
102735	LDA2	262.7	0.01
102735	M1	271.6	0.02
102735	J1	259.4	0.02
102735	RHO1	281.4	0.01
102735	Q1	283.4	0.04
102735	T2	301.9	0.01
102735	P1	269.4	0.05
102735	L2	260.2	0.03
102735	K2	314	0.03
102735	M8	120	0.01
102736	M2	104.8	4.14
102736	S2	137.4	0.62
102736	N2	74.7	0.92
102736	K1	202.8	0.46
102736	M4	307.8	0.04
102736	O1	185.7	0.35
102736	M6	346.8	0.02
102736	NU2	78.7	0.18
102736	MU2	292.6	0.1
102736	2N2	44.6	0.12
102736	OO1	220	0.02
102736	LDA2	120	0.03
102736	M1	194.3	0.03
102736	J1	211.3	0.03
102736	SSA	108	0.05
102736	SA	136.2	0.1
102736	RHO1	178.3	0.01
102736	Q1	177.2	0.07
102736	T2	136.1	0.04
102736	R2	138.8	0.01
102736	2Q1	168.7	0.01
102736	P1	201.5	0.15
102736	L2	135	0.11
102736	K2	140.1	0.17
102736	M8	120.7	0.01
102737	M2	189.9	2.38
102737	S2	233.8	0.29
102737	N2	161.3	0.42
102737	K1	266.4	0.3
102737	M4	251.3	0.12
102737	O1	250.7	0.24
102737	M6	202.8	0.1
102737	S4	312	0.01
102737	NU2	165.1	0.08
102737	MU2	6.5	0.06
102737	2N2	132.7	0.06
102737	OO1	282	0.01
102737	LDA2	210.3	0.02
102737	M1	258.6	0.02
102737	J1	274.1	0.02
102737	SSA	108	0.05
102737	SA	136.2	0.1
102737	RHO1	244	0.01
102737	Q1	242.9	0.05
102737	T2	232	0.02
102737	2Q1	235.2	0.01
102737	P1	265.2	0.1
102737	L2	218.8	0.07
102737	K2	237.3	0.08
102737	M8	282.6	0.02
102738	M2	130.1	3.52
102738	S2	166.3	0.5
102738	N2	96	0.72
102738	K1	219.5	0.41
102738	M4	120	0.1
102738	O1	204.6	0.31
102738	M6	324.4	0.02
102738	S4	227.2	0.01
102738	NU2	100.6	0.14
102738	MU2	314.2	0.09
102738	2N2	61.9	0.1
102738	OO1	234.3	0.01
102738	LDA2	146.9	0.02
102738	M1	212	0.02
102738	J1	226.8	0.02
102738	SSA	108	0.05
102738	SA	136.2	0.1
102738	RHO1	198.2	0.01
102738	Q1	197.2	0.06
102738	T2	164.9	0.03
102738	2Q1	189.8	0.01
102738	P1	218.3	0.13
102738	L2	164.1	0.1
102738	K2	169.2	0.13
102738	M8	121.6	0.02
102739	M2	102.2	4.51
102739	S2	139.1	0.68
102739	N2	70.5	0.98
102739	K1	201.4	0.47
102739	M4	5.8	0.04
102739	O1	182	0.37
102739	M6	123.2	0.05
102739	MK3	232.3	0.01
102739	MN4	350.1	0.02
102739	NU2	77.1	0.22
102739	S6	160.9	0.01
102739	MU2	37.9	0.04
102739	2N2	47.4	0.13
102739	OO1	223.4	0.02
102739	LDA2	137.4	0.07
102739	S1	206.4	0.03
102739	M1	224.4	0.01
102739	J1	214	0.03
102739	SSA	108	0.05
102739	SA	136.2	0.1
102739	RHO1	175.3	0.01
102739	Q1	164	0.06
102739	T2	111.5	0.07
102739	R2	348.3	0.01
102739	P1	200.1	0.16
102739	2SM2	88.9	0.01
102739	L2	155.3	0.2
102739	2MK3	217.7	0.02
102739	K2	137.6	0.19
102739	M8	129.4	0.01
102739	MS4	52.6	0.01
102740	M2	109.1	4.21
102740	S2	147.5	0.57
102740	N2	81.5	0.93
102740	K1	208.8	0.46
102740	M4	128.7	0.07
102740	O1	188.8	0.35
102740	M6	306.4	0.03
102740	S4	215.1	0.01
102740	NU2	85.2	0.18
102740	MU2	290.1	0.1
102740	2N2	53.9	0.12
102740	OO1	228.6	0.02
102740	LDA2	126.9	0.03
102740	M1	198.8	0.03
102740	J1	218.6	0.03
102740	RHO1	180.2	0.01
102740	Q1	178.9	0.07
102740	T2	146	0.03
102740	2Q1	169.1	0.01
102740	P1	207.3	0.15
102740	L2	136.7	0.12
102740	K2	150.6	0.16
102740	M8	255.2	0.02
102741	M2	105.3	4.28
102741	S2	143.1	0.63
102741	N2	73.5	0.98
102741	K1	204.1	0.48
102741	M4	116.2	0.05
102741	O1	183.6	0.37
102741	M6	96.2	0.02
102741	S4	200.3	0.01
102741	NU2	77.8	0.19
102741	MU2	286.8	0.1
102741	2N2	41.7	0.13
102741	OO1	224.4	0.02
102741	LDA2	122.8	0.03
102741	M1	193.9	0.03
102741	J1	214.1	0.03
102741	RHO1	174.9	0.01
102741	Q1	173.5	0.07
102741	T2	141.6	0.04
102741	R2	144.6	0.01
102741	2Q1	163.4	0.01
102741	P1	202.6	0.16
102741	L2	137.1	0.12
102741	K2	146.2	0.17
102741	M8	249.4	0.01
102742	M2	112.1	4.31
102742	S2	161	1.26
102742	N2	79.6	1.01
102742	K1	209.1	0.46
102742	M4	99.9	0.1
102742	O1	188.7	0.37
102742	M6	135.8	0.03
102742	MK3	247.1	0.03
102742	S4	200.5	0.01
102742	MN4	54.2	0.06
102742	NU2	87.8	0.21
102742	MU2	357.6	0.02
102742	2N2	62.4	0.19
102742	OO1	256.7	0.01
102742	LDA2	157.7	0.08
102742	S1	100.1	0.03
102742	M1	186.2	0.03
102742	J1	215.5	0.04
102742	SSA	105.8	0.07
102742	SA	128.3	1.05
102742	RHO1	179.5	0.03
102742	Q1	173.8	0.07
102742	T2	116.4	0.3
102742	R2	46.1	0.67
102742	2Q1	226.5	0.01
102742	P1	195.4	0.15
102742	2SM2	57.9	0.01
102742	M3	136.5	0.02
102742	L2	168.4	0.21
102742	2MK3	218.1	0.04
102742	K2	144.7	0.44
102742	M8	295.7	0.02
102742	MS4	153	0.05
102743	M2	106.5	4.24
102743	S2	130.1	0.79
102743	N2	72.9	0.98
102743	K1	206.8	0.5
102743	M4	352.6	0.05
102743	O1	184.1	0.36
102743	M6	225.4	0.02
102743	MK3	248.1	0.02
102743	MN4	329.5	0.03
102743	NU2	78.9	0.19
102743	MU2	30.3	0.03
102743	2N2	57.1	0.18
102743	OO1	245.4	0.02
102743	LDA2	155.4	0.06
102743	S1	354.1	0.08
102743	M1	178.5	0.03
102743	J1	210.1	0.04
102743	SSA	105.8	0.07
102743	SA	128.3	0.1
102743	RHO1	177.8	0.01
102743	Q1	172	0.07
102743	T2	71.4	0.1
102743	R2	318.1	0.2
102743	2Q1	204.2	0.02
102743	P1	181.1	0.15
102743	2SM2	142.2	0.01
102743	M3	124.1	0.02
102743	L2	162.3	0.2
102743	2MK3	208.9	0.02
102743	K2	122.1	0.19
102743	M8	108.9	0.01
102743	MS4	43.9	0.02
102744	M2	104.6	4.32
102744	S2	141	0.65
102744	N2	72.4	0.97
102744	K1	202.1	0.46
102744	M4	328.5	0.07
102744	O1	185.3	0.37
102744	M6	183	0.02
102744	MN4	305.6	0.04
102744	NU2	80.9	0.2
102744	MU2	48.8	0.03
102744	2N2	47.6	0.13
102744	OO1	210.1	0.01
102744	LDA2	136.5	0.07
102744	S1	136.9	0.02
102744	M1	230.7	0.01
102744	J1	219.8	0.03
102744	SSA	98.4	0.04
102744	SA	126.5	0.16
102744	RHO1	198.5	0.01
102744	Q1	169	0.06
102744	T2	118.3	0.06
102744	R2	19.3	0.01
102744	P1	201.9	0.15
102744	2SM2	89.4	0.01
102744	M3	115.1	0.01
102744	L2	148	0.22
102744	2MK3	198.8	0.01
102744	K2	141.1	0.18
102744	MS4	7.5	0.03
102745	M2	110.9	3.98
102745	S2	147.2	0.58
102745	N2	81.3	0.91
102745	K1	207	0.43
102745	M4	1.4	0.06
102745	O1	189.1	0.35
102745	M6	166.3	0.01
102745	MK3	222.1	0.01
102745	MN4	351.8	0.03
102745	NU2	88.8	0.18
102745	MU2	61.3	0.01
102745	2N2	45.6	0.12
102745	OO1	217.7	0.01
102745	LDA2	151.4	0.08
102745	S1	174.4	0.02
102745	M1	218.4	0.02
102745	J1	213.4	0.02
102745	SSA	108	0.05
102745	SA	136.2	0.1
102745	RHO1	179.8	0.02
102745	Q1	180.5	0.05
102745	T2	124.5	0.05
102745	R2	9.7	0.01
102745	P1	204.2	0.15
102745	2SM2	98.8	0.02
102745	L2	132	0.23
102745	2MK3	209.6	0.02
102745	K2	146.1	0.15
102745	MS4	54.6	0.02
102746	M2	150.1	3.3
102746	S2	189.1	0.43
102746	N2	117.4	0.63
102746	K1	230.8	0.38
102746	M4	108.7	0.09
102746	O1	220.2	0.31
102746	M6	102.8	0.07
102746	NU2	121.7	0.12
102746	MU2	329.4	0.08
102746	2N2	84.6	0.08
102746	OO1	241.4	0.01
102746	LDA2	168.1	0.02
102746	M1	225.5	0.02
102746	J1	236	0.02
102746	RHO1	215.6	0.01
102746	Q1	214.9	0.06
102746	T2	187.6	0.03
102746	2Q1	209.6	0.01
102746	P1	230	0.13
102746	L2	182.8	0.09
102746	K2	192.3	0.11
102746	M8	32.3	0.03
102747	M2	141.2	3.15
102747	S2	177.4	0.4
102747	N2	108	0.65
102747	K1	230.9	0.38
102747	M4	49.1	0.09
102747	O1	209.4	0.32
102747	M6	112.3	0.04
102747	NU2	112.5	0.12
102747	MU2	105.1	0.08
102747	2N2	74.8	0.09
102747	OO1	252.7	0.01
102747	LDA2	158	0.02
102747	M1	220.3	0.02
102747	J1	241.8	0.03
102747	SSA	89.8	0.06
102747	SA	126.3	0.1
102747	RHO1	200.3	0.01
102747	Q1	198.7	0.06
102747	T2	175.9	0.02
102747	2Q1	188.3	0.01
102747	P1	229.3	0.12
102747	L2	174.4	0.09
102747	K2	180.3	0.11
102747	M8	343.5	0.01
102748	M2	105.9	4.31
102748	S2	136.2	0.59
102748	N2	76.1	0.96
102748	K1	203.3	0.44
102748	M4	324.5	0.06
102748	O1	187.1	0.37
102748	M6	134.7	0.03
102748	MK3	244.9	0.01
102748	MN4	317.9	0.02
102748	NU2	85.2	0.21
102748	MU2	24	0.03
102748	2N2	49.3	0.16
102748	OO1	247.6	0.01
102748	LDA2	144.8	0.06
102748	S1	168.7	0.03
102748	M1	250.2	0.02
102748	J1	214.2	0.03
102748	SSA	105.8	0.07
102748	SA	128.3	0.1
102748	RHO1	159.4	0.01
102748	Q1	156.6	0.07
102748	T2	94.5	0.08
102748	R2	130.7	0.09
102748	2Q1	38	0.01
102748	P1	204.1	0.13
102748	2SM2	156.6	0.02
102748	L2	140.3	0.15
102748	2MK3	225.4	0.02
102748	K2	131.8	0.21
102748	M8	293.2	0.01
102748	MS4	23.9	0.02
102749	M2	132.3	3.6
102749	S2	157.9	0.48
102749	N2	105.8	0.72
102749	K1	225.5	0.41
102749	M4	178.2	0.15
102749	O1	210.3	0.33
102749	M6	62.9	0.1
102749	MK3	255.7	0.05
102749	S4	245.9	0.01
102749	MN4	161.3	0.07
102749	NU2	121.5	0.16
102749	MU2	233	0.07
102749	2N2	41.5	0.05
102749	OO1	278.4	0.02
102749	LDA2	135.8	0.06
102749	S1	308.2	0.06
102749	M1	246.8	0.03
102749	J1	277.4	0.01
102749	SSA	89.8	0.06
102749	SA	126.3	0.1
102749	Q1	201.9	0.05
102749	T2	70.9	0.05
102749	2Q1	274.7	0.03
102749	P1	207.1	0.08
102749	2SM2	37.1	0.01
102749	M3	309.6	0.01
102749	L2	143.3	0.27
102749	2MK3	224.9	0.06
102749	K2	159.6	0.1
102749	M8	68.2	0.03
102749	MS4	217.1	0.06
102750	M2	149.6	3.19
102750	S2	192.2	0.39
102750	N2	130.3	0.6
102750	K1	246.4	0.39
102750	M4	209.9	0.21
102750	O1	219.6	0.32
102750	M6	114	0.13
102750	NU2	132.9	0.12
102750	S6	270.7	0.01
102750	MU2	324.9	0.08
102750	2N2	111	0.08
102750	OO1	273.2	0.01
102750	LDA2	169.4	0.02
102750	M1	233.1	0.02
102750	J1	259.7	0.03
102750	SSA	89.8	0.06
102750	SA	126.3	0.1
102750	RHO1	208.2	0.01
102750	Q1	206.4	0.06
102750	T2	190.5	0.02
102750	2Q1	193.1	0.01
102750	P1	244.4	0.13
102750	L2	168.8	0.09
102750	K2	195.7	0.11
102750	M8	145.4	0.05
102751	M2	115.7	3.84
102751	S2	153	0.54
102751	N2	85.6	0.78
102751	K1	211.2	0.43
102751	M4	133	0.03
102751	O1	194.2	0.34
102751	M6	335.3	0.08
102751	NU2	89.6	0.15
102751	MU2	297	0.09
102751	2N2	55.5	0.1
102751	OO1	227.9	0.01
102751	LDA2	133	0.03
102751	M1	202.7	0.02
102751	J1	219.4	0.03
102751	SSA	89.8	0.06
102751	SA	126.3	0.1
102751	RHO1	187	0.01
102751	Q1	185.8	0.07
102751	T2	151.6	0.03
102751	2Q1	177.5	0.01
102751	P1	209.9	0.14
102751	L2	145.9	0.11
102751	K2	156.1	0.15
102751	M8	177.9	0.01
102752	M2	122	3.86
102752	S2	166.2	0.51
102752	N2	91.7	0.76
102752	K1	216.8	0.42
102752	M4	164.2	0.17
102752	O1	203.3	0.36
102752	M6	16.9	0.08
102752	S4	246.4	0.01
102752	NU2	95.8	0.15
102752	MU2	296	0.09
102752	2N2	61.4	0.1
102752	OO1	230.3	0.02
102752	LDA2	142.6	0.03
102752	M1	210.1	0.03
102752	J1	223.5	0.03
102752	SSA	89.8	0.06
102752	SA	126.3	0.1
102752	RHO1	197.5	0.01
102752	Q1	196.6	0.07
102752	T2	164.5	0.03
102752	2Q1	189.9	0.01
102752	P1	215.8	0.14
102752	L2	152.4	0.11
102752	K2	169.8	0.14
102752	M8	356.6	0.02
102753	M2	176	2.49
102753	S2	227.5	0.3
102753	N2	151.6	0.44
102753	K1	267.4	0.32
102753	M4	284.6	0.46
102753	O1	240.8	0.29
102753	M6	109.9	0.04
102753	S4	41.6	0.01
102753	NU2	154.9	0.09
102753	MU2	342.4	0.06
102753	2N2	127.1	0.06
102753	OO1	294	0.01
102753	LDA2	199.9	0.02
102753	M1	254.2	0.02
102753	J1	280.6	0.02
102753	SSA	89.8	0.06
102753	SA	126.3	0.1
102753	RHO1	229.4	0.01
102753	Q1	227.6	0.06
102753	T2	225.5	0.02
102753	2Q1	214.3	0.01
102753	P1	265.4	0.1
102753	L2	200.4	0.07
102753	K2	231.7	0.08
102753	M8	270.9	0.05
102754	M2	116.9	4.19
102754	S2	159.1	0.52
102754	N2	88.2	0.88
102754	K1	212.8	0.43
102754	M4	176.6	0.06
102754	O1	199.9	0.37
102754	M6	345.1	0.09
102754	NU2	92.1	0.17
102754	MU2	293	0.1
102754	2N2	59.5	0.11
102754	OO1	225.6	0.02
102754	LDA2	136.5	0.03
102754	M1	206.4	0.03
102754	J1	219.1	0.03
102754	SSA	89.8	0.06
102754	SA	126.3	0.1
102754	RHO1	194.4	0.01
102754	Q1	193.6	0.07
102754	T2	157.4	0.03
102754	2Q1	187.2	0.01
102754	P1	211.8	0.14
102754	L2	145.6	0.12
102754	K2	162.5	0.14
102754	M8	329.5	0.02
102755	M2	106.6	4.23
102755	S2	144.2	0.61
102755	N2	75.5	1
102755	K1	204.9	0.47
102755	M4	357.6	0.04
102755	O1	186	0.38
102755	M6	228.6	0.02
102755	NU2	79.6	0.19
102755	MU2	287.7	0.1
102755	2N2	44.4	0.13
102755	OO1	223.5	0.02
102755	LDA2	124.1	0.03
102755	M1	195.5	0.03
102755	J1	214	0.03
102755	SSA	89.8	0.06
102755	SA	126.3	0.1
102755	RHO1	178	0.01
102755	Q1	176.7	0.08
102755	T2	142.7	0.04
102755	2Q1	167.4	0.01
102755	P1	203.4	0.16
102755	L2	137.8	0.12
102755	K2	147.2	0.17
102755	M8	234.1	0.01
102756	M2	108.4	4.3
102756	S2	152.6	0.68
102756	N2	78.5	0.96
102756	K1	210	0.46
102756	M4	359.3	0.03
102756	O1	185.3	0.37
102756	M6	266.8	0.04
102756	MK3	245.5	0.02
102756	MN4	351.3	0.02
102756	NU2	81.5	0.2
102756	MU2	60.6	0.02
102756	2N2	48.1	0.14
102756	OO1	302.3	0.01
102756	LDA2	133.3	0.07
102756	S1	80.8	0.07
102756	M1	203.3	0.03
102756	J1	205.4	0.03
102756	SSA	97.5	0.07
102756	SA	138.3	0.16
102756	RHO1	219.4	0.01
102756	Q1	166.1	0.05
102756	T2	163.6	0.07
102756	R2	45.9	0.09
102756	2Q1	142.9	0.01
102756	P1	202.6	0.19
102756	2SM2	117	0.01
102756	M3	138	0.01
102756	L2	134.1	0.16
102756	2MK3	211.6	0.02
102756	K2	136.8	0.19
102756	M8	202.9	0.01
102756	MS4	44.6	0.01
102757	M2	118.4	4.28
102757	S2	169.8	0.69
102757	N2	92.9	0.94
102757	K1	219.3	0.47
102757	M4	140.6	0.2
102757	O1	196.6	0.38
102757	M6	318	0.09
102757	MK3	232.6	0.05
102757	S4	247.2	0.01
102757	MN4	109.8	0.08
102757	NU2	93.3	0.19
102757	MU2	165	0.05
102757	2N2	61.5	0.13
102757	OO1	315.5	0.01
102757	LDA2	115.3	0.08
102757	S1	88.8	0.07
102757	M1	224.2	0.04
102757	J1	248.8	0.02
102757	SSA	89.8	0.06
102757	SA	126.3	0.1
102757	RHO1	273.9	0.01
102757	Q1	187.9	0.06
102757	T2	181.5	0.09
102757	2Q1	142.4	0.02
102757	P1	214.3	0.18
102757	L2	118.5	0.19
102757	2MK3	195.2	0.04
102757	K2	145.9	0.19
102757	M8	260.2	0.08
102757	MS4	186.3	0.05
102758	M2	108.4	4.24
102758	S2	147	0.63
102758	N2	75.4	0.99
102758	K1	205.8	0.47
102758	M4	1.8	0.06
102758	O1	186.5	0.39
102758	M6	277.2	0.04
102758	NU2	79.8	0.19
102758	MU2	288.5	0.1
102758	2N2	42.4	0.13
102758	OO1	224.9	0.02
102758	LDA2	126.3	0.03
102758	M1	196.2	0.03
102758	J1	215.2	0.03
102758	SSA	97.5	0.07
102758	SA	136.3	0.16
102758	RHO1	178.3	0.01
102758	Q1	177	0.08
102758	T2	145.4	0.04
102758	2Q1	167.5	0.01
102758	P1	204.4	0.15
102758	L2	141.3	0.12
102758	K2	150.1	0.17
102759	M2	110.2	4.31
102759	S2	148.3	0.63
102759	N2	77.5	1.03
102759	K1	206	0.47
102759	M4	5.1	0.06
102759	O1	186.7	0.39
102759	M6	280	0.07
102759	NU2	81.9	0.2
102759	MU2	290.4	0.1
102759	2N2	44.9	0.13
102759	OO1	225.1	0.02
102759	LDA2	127.8	0.03
102759	M1	196.4	0.03
102759	J1	215.4	0.03
102759	SSA	97.5	0.07
102759	SA	136.3	0.16
102759	RHO1	178.5	0.01
102759	Q1	177.2	0.08
102759	T2	146.7	0.04
102759	R2	149.8	0.01
102759	2Q1	167.7	0.01
102759	P1	204.5	0.15
102759	L2	142.8	0.12
102759	K2	151.3	0.17
102759	M8	194.6	0.01
102760	M2	108.3	4.27
102760	S2	145.6	0.62
102760	N2	77.6	1.06
102760	K1	206.2	0.49
102760	M4	359.7	0.06
102760	O1	187.5	0.38
102760	M6	275	0.05
102760	NU2	81.7	0.21
102760	MU2	289.1	0.1
102760	2N2	46.9	0.14
102760	OO1	224.5	0.02
102760	LDA2	125.6	0.03
102760	M1	196.8	0.03
102760	J1	215.2	0.03
102760	RHO1	179.5	0.01
102760	Q1	178.3	0.08
102760	T2	144.1	0.04
102760	R2	147.1	0.01
102760	2Q1	169.1	0.01
102760	P1	204.8	0.16
102760	L2	139	0.12
102760	K2	148.6	0.17
102760	M8	178.8	0.01
102761	M2	109.7	4.39
102761	S2	151.5	0.78
102761	N2	78.1	1.08
102761	K1	208	0.44
102761	M4	28.9	0.06
102761	O1	185.3	0.39
102761	M6	285.9	0.08
102761	MK3	244.1	0.02
102761	MN4	8.3	0.04
102761	NU2	83.2	0.17
102761	MU2	72.4	0.06
102761	2N2	61.6	0.12
102761	OO1	201.6	0.02
102761	LDA2	152.1	0.07
102761	S1	139.9	0.06
102761	M1	199.6	0.03
102761	J1	204.3	0.04
102761	SSA	89.8	0.06
102761	SA	126.3	0.1
102761	RHO1	91.9	0.02
102761	Q1	186.4	0.08
102761	T2	146.3	0.1
102761	R2	10.3	0.15
102761	2Q1	162	0.01
102761	P1	217	0.15
102761	2SM2	113.5	0.02
102761	M3	137.4	0.02
102761	L2	168.3	0.24
102761	2MK3	202.8	0.03
102761	K2	127	0.2
102761	M8	220.5	0.01
102761	MS4	70.8	0.02
102762	M2	110.7	4.53
102762	S2	148.9	0.69
102762	N2	82.6	1.03
102762	K1	203.2	0.49
102762	M4	34.8	0.09
102762	O1	189.2	0.39
102762	M6	292.7	0.11
102762	S4	185.4	0.01
102762	NU2	86.3	0.2
102762	MU2	290.4	0.11
102762	2N2	54.4	0.14
102762	OO1	217	0.02
102762	LDA2	128.4	0.03
102762	M1	196.2	0.03
102762	J1	210	0.03
102762	SSA	89.8	0.06
102762	SA	126.3	0.1
102762	RHO1	183.2	0.01
102762	Q1	182.2	0.08
102762	T2	147.4	0.04
102762	R2	150.5	0.01
102762	2Q1	175.3	0.01
102762	P1	202.2	0.16
102762	L2	138.8	0.13
102762	K2	152	0.19
102762	M8	249.4	0.02
102763	M2	111.1	4.5
102763	S2	146.2	0.67
102763	N2	81.1	1.05
102763	K1	203.8	0.47
102763	M4	19.4	0.07
102763	O1	187.2	0.37
102763	M6	290.2	0.11
102763	S4	96.1	0.01
102763	NU2	85.1	0.2
102763	S6	72.4	0.01
102763	MU2	293.8	0.11
102763	2N2	51.1	0.14
102763	OO1	220.3	0.02
102763	LDA2	127.4	0.03
102763	M1	195.6	0.03
102763	J1	212	0.03
102763	SSA	89.8	0.06
102763	SA	126.3	0.1
102763	RHO1	180.1	0.01
102763	Q1	179	0.07
102763	T2	144.8	0.04
102763	R2	147.6	0.01
102763	2Q1	170.8	0.01
102763	P1	202.5	0.15
102763	L2	141	0.12
102763	K2	149.1	0.18
102763	M8	236.5	0.02
102764	M2	109.2	4.5
102764	S2	146.2	0.68
102764	N2	76.7	1
102764	K1	205.6	0.47
102764	M4	29	0.08
102764	O1	187.1	0.38
102764	M6	281.3	0.1
102764	MK3	231.8	0.02
102764	S4	119.3	0.01
102764	MN4	13.7	0.04
102764	NU2	84	0.22
102764	S6	246.8	0.01
102764	MU2	53.3	0.03
102764	2N2	53.7	0.13
102764	OO1	218.7	0.01
102764	LDA2	140.1	0.07
102764	S1	131.6	0.02
102764	M1	223.2	0.02
102764	J1	210	0.03
102764	SSA	97.5	0.07
102764	SA	136.3	0.16
102764	RHO1	179.3	0.02
102764	Q1	172.1	0.06
102764	T2	120.1	0.06
102764	R2	13.1	0.01
102764	2Q1	211.3	0.01
102764	P1	204.8	0.15
102764	2SM2	110.3	0.01
102764	M3	149.2	0.01
102764	L2	160.4	0.22
102764	2MK3	204.7	0.02
102764	K2	146.1	0.19
102764	M8	241.3	0.02
102764	MS4	74	0.03
102765	M2	108.6	4.34
102765	S2	144.4	0.67
102765	N2	77	1
102765	K1	204.6	0.46
102765	M4	4.4	0.04
102765	O1	187.1	0.37
102765	M6	270	0.07
102765	MK3	247.5	0.02
102765	MN4	2	0.02
102765	NU2	85.4	0.22
102765	S6	236.9	0.01
102765	MU2	42.2	0.04
102765	2N2	59.3	0.13
102765	OO1	243.9	0.02
102765	LDA2	151.1	0.07
102765	S1	109.3	0.03
102765	M1	202.9	0.02
102765	J1	217.7	0.03
102765	SSA	89.8	0.06
102765	SA	126.3	0.1
102765	RHO1	132.7	0.01
102765	Q1	171.2	0.06
102765	T2	120.8	0.05
102765	R2	12.5	0.02
102765	2Q1	201.3	0.01
102765	P1	199.1	0.16
102765	2SM2	119.8	0.01
102765	M3	142.1	0.01
102765	L2	156.2	0.22
102765	2MK3	212	0.02
102765	K2	145.7	0.19
102765	MS4	50.8	0.01
102766	M2	110.6	4.46
102766	S2	147.1	0.68
102766	N2	77.2	1.03
102766	K1	205.8	0.46
102766	M4	35.6	0.05
102766	O1	187.6	0.38
102766	M6	285.9	0.11
102766	MK3	234.3	0.02
102766	MN4	26	0.03
102766	NU2	89.9	0.22
102766	S6	263.5	0.01
102766	MU2	65.3	0.03
102766	2N2	66.8	0.15
102766	OO1	251	0.02
102766	LDA2	137.2	0.07
102766	S1	173.4	0.01
102766	M1	188.6	0.02
102766	J1	210.5	0.03
102766	SSA	89.8	0.06
102766	SA	126.3	0.1
102766	RHO1	140.7	0.01
102766	Q1	174.8	0.06
102766	T2	128.1	0.06
102766	R2	12.7	0.02
102766	2Q1	210.6	0.03
102766	P1	203.7	0.15
102766	2SM2	126.9	0.01
102766	M3	155.1	0.01
102766	L2	161.7	0.21
102766	2MK3	207.2	0.03
102766	K2	148.6	0.2
102766	M8	239.5	0.02
102766	MS4	85.5	0.02
102767	M2	113.2	4.54
102767	S2	153.9	0.66
102767	N2	87	1.03
102767	K1	207.6	0.48
102767	M4	49	0.08
102767	O1	188	0.39
102767	M6	296.3	0.14
102767	NU2	90.5	0.2
102767	MU2	290.4	0.11
102767	2N2	60.9	0.14
102767	OO1	227	0.02
102767	LDA2	132.1	0.03
102767	M1	197.9	0.03
102767	J1	217.2	0.03
102767	SSA	89.8	0.06
102767	SA	126.3	0.1
102767	RHO1	179.7	0.02
102767	Q1	178.4	0.08
102767	T2	152.3	0.04
102767	R2	155.6	0.01
102767	2Q1	168.7	0.01
102767	P1	206.1	0.16
102767	L2	139.3	0.13
102767	K2	157.2	0.18
102767	M8	238.3	0.03
102768	M2	110.3	4.25
102768	S2	147.8	0.62
102768	N2	76.2	0.96
102768	K1	205.7	0.46
102768	M4	359.9	0.06
102768	O1	188.4	0.38
102768	M6	288.7	0.07
102768	NU2	80.8	0.19
102768	MU2	291.3	0.1
102768	2N2	42.1	0.13
102768	OO1	223	0.02
102768	LDA2	127.8	0.03
102768	M1	197.1	0.03
102768	J1	214.2	0.03
102768	RHO1	180.9	0.01
102768	Q1	179.8	0.08
102768	T2	146.3	0.04
102768	R2	149.3	0.01
102768	2Q1	171.2	0.01
102768	P1	204.4	0.15
102768	L2	144.6	0.12
102768	K2	150.8	0.17
102768	M8	275.1	0.01
102769	M2	112.8	4.27
102769	S2	150.1	0.63
102769	N2	77.1	1.01
102769	K1	207.6	0.45
102769	M4	8.1	0.06
102769	O1	189.4	0.39
102769	M6	299.9	0.1
102769	NU2	81.9	0.2
102769	MU2	293.7	0.1
102769	2N2	41.5	0.13
102769	OO1	225.9	0.02
102769	LDA2	130.3	0.03
102769	M1	198.6	0.03
102769	J1	216.7	0.03
102769	SSA	89.8	0.06
102769	SA	126.3	0.1
102769	RHO1	181.5	0.02
102769	Q1	180.3	0.08
102769	T2	148.6	0.04
102769	R2	151.6	0.01
102769	2Q1	171.3	0.01
102769	P1	206.3	0.15
102769	L2	148.4	0.12
102769	K2	153.1	0.17
102770	M2	112	4.48
102770	S2	151.3	0.57
102770	N2	78.8	1.06
102770	K1	206.1	0.45
102770	M4	9.7	0.07
102770	O1	187.9	0.39
102770	M6	294.6	0.13
102770	MK3	245.8	0.02
102770	MN4	351.1	0.03
102770	NU2	91.9	0.24
102770	MU2	56.5	0.01
102770	2N2	74.7	0.1
102770	OO1	235.5	0.02
102770	LDA2	141.9	0.07
102770	S1	221.2	0.02
102770	M1	201.7	0.02
102770	J1	211.9	0.03
102770	SSA	89.8	0.06
102770	SA	126.3	0.1
102770	RHO1	194.4	0.01
102770	Q1	172	0.06
102770	T2	96.9	0.04
102770	2Q1	198.3	0.01
102770	P1	201.7	0.14
102770	2SM2	102.2	0.01
102770	M3	152.2	0.01
102770	L2	170.3	0.27
102770	2MK3	216.6	0.02
102770	K2	138.8	0.23
102770	MS4	55.6	0.02
102771	M2	120.4	4.47
102771	S2	161.4	0.63
102771	N2	89.5	1
102771	K1	213.2	0.47
102771	M4	127.9	0.24
102771	O1	193.6	0.4
102771	M6	340	0.19
102771	NU2	93.6	0.19
102771	S6	109.7	0.01
102771	MU2	298.2	0.11
102771	2N2	58.4	0.13
102771	OO1	232.8	0.02
102771	LDA2	139.4	0.03
102771	M1	203.5	0.03
102771	J1	222.9	0.03
102771	SSA	89.8	0.06
102771	SA	126.3	0.1
102771	RHO1	185.2	0.02
102771	Q1	183.9	0.08
102771	T2	159.7	0.04
102771	R2	163	0.01
102771	2Q1	174.2	0.01
102771	P1	211.7	0.15
102771	L2	151.6	0.12
102771	K2	164.7	0.17
102771	M8	340.4	0.06
102772	M2	117.4	4.45
102772	S2	156.3	0.68
102772	N2	83.5	1
102772	K1	210.9	0.46
102772	M4	112.7	0.15
102772	O1	193.4	0.38
102772	M6	325.2	0.19
102772	NU2	88.1	0.19
102772	S6	90.8	0.01
102772	MU2	297.2	0.11
102772	2N2	49.7	0.13
102772	OO1	228.4	0.02
102772	LDA2	135.4	0.03
102772	M1	202.2	0.03
102772	J1	219.5	0.03
102772	SSA	89.8	0.06
102772	SA	126.3	0.1
102772	RHO1	185.9	0.01
102772	Q1	184.8	0.08
102772	T2	154.7	0.04
102772	R2	157.8	0.01
102772	2Q1	176.1	0.01
102772	P1	209.6	0.15
102772	L2	151.3	0.12
102772	K2	159.4	0.18
102772	M8	300.5	0.04
102773	M2	107.3	3.66
102773	S2	142	0.54
102773	N2	75.4	0.88
102773	K1	202.2	0.43
102773	M4	64.1	0.14
102773	O1	188	0.34
102773	M6	297.3	0.13
102773	S4	35.9	0.01
102773	NU2	79.7	0.17
102773	MU2	291.6	0.09
102773	2N2	43.5	0.12
102773	OO1	216.3	0.02
102773	LDA2	123.5	0.03
102773	M1	195.2	0.02
102773	J1	209.2	0.03
102773	RHO1	182	0.01
102773	Q1	181	0.07
102773	T2	140.6	0.03
102773	2Q1	174	0.01
102773	P1	201.1	0.14
102773	L2	139.3	0.1
102773	K2	144.8	0.15
102773	M8	223.7	0.02
102774	M2	109.2	4.1
102774	S2	146.6	0.6
102774	N2	77.6	0.96
102774	K1	203.3	0.45
102774	M4	35.2	0.1
102774	O1	187.9	0.36
102774	M6	294.6	0.13
102774	NU2	81.9	0.19
102774	MU2	71.8	0.1
102774	2N2	46	0.13
102774	OO1	218.7	0.02
102774	LDA2	126.6	0.03
102774	M1	195.7	0.03
102774	J1	211	0.03
102774	RHO1	181.3	0.01
102774	Q1	180.3	0.07
102774	T2	145.2	0.04
102774	2Q1	172.6	0.01
102774	P1	202.1	0.15
102774	L2	140.9	0.11
102774	K2	149.7	0.16
102775	M2	99.1	2.82
102775	S2	130.5	0.41
102775	N2	66.6	0.71
102775	K1	198.5	0.34
102775	M4	58.3	0.14
102775	O1	194.8	0.3
102775	M6	295.4	0.11
102775	S4	52.4	0.01
102775	NU2	70.9	0.14
102775	S6	93.2	0.01
102775	MU2	286.5	0.07
102775	2N2	34	0.1
102775	OO1	202.8	0.01
102775	LDA2	113.8	0.02
102775	M1	196.7	0.02
102775	J1	200.7	0.02
102775	RHO1	192.3	0.01
102775	Q1	192.8	0.06
102775	T2	129.4	0.02
102775	2Q1	190.6	0.01
102775	P1	198.2	0.11
102775	L2	131.8	0.08
102775	K2	133.1	0.11
102775	M8	221.3	0.02
102776	M2	111.8	4.69
102776	S2	148.5	0.7
102776	N2	79	1.08
102776	K1	205	0.46
102776	M4	21.7	0.1
102776	O1	189	0.37
102776	M6	298.8	0.22
102776	NU2	83.4	0.21
102776	MU2	294.8	0.11
102776	2N2	46.2	0.14
102776	OO1	220.8	0.02
102776	LDA2	128.9	0.03
102776	M1	197	0.03
102776	J1	212.7	0.03
102776	SSA	89.8	0.06
102776	SA	126.3	0.1
102776	RHO1	182.2	0.01
102776	Q1	181.1	0.07
102776	T2	147.1	0.04
102776	R2	150	0.01
102776	2Q1	173.2	0.01
102776	P1	203.8	0.15
102776	L2	144.6	0.13
102776	K2	151.6	0.19
102776	M8	21.3	0.01
102777	M2	79.1	1.95
102777	S2	104.8	0.3
102777	N2	49.1	0.55
102777	K1	187.9	0.3
102777	M4	64.8	0.22
102777	O1	196.7	0.28
102777	M6	300	0.11
102777	S4	50.8	0.02
102777	NU2	53.1	0.11
102777	S6	88.8	0.01
102777	MU2	272.3	0.05
102777	2N2	19	0.07
102777	OO1	179.1	0.01
102777	LDA2	91.1	0.01
102777	M1	192.2	0.02
102777	J1	183.5	0.02
102777	RHO1	200.4	0.01
102777	Q1	201	0.05
102777	T2	103.8	0.02
102777	2Q1	205.4	0.01
102777	P1	188.5	0.1
102777	L2	109.2	0.06
102777	K2	106.9	0.08
102777	M8	231.1	0.02
102778	M2	50	1.7
102778	S2	65.2	0.31
102778	N2	28.2	0.48
102778	K1	184.9	0.27
102778	M4	65.4	0.3
102778	O1	194.9	0.23
102778	M6	292.4	0.07
102778	MK3	12.7	0.03
102778	S4	20.5	0.03
102778	MN4	14.8	0.12
102778	NU2	35.6	0.09
102778	S6	320.1	0.02
102778	MU2	4	0.08
102778	2N2	15.7	0.08
102778	OO1	194.8	0.02
102778	LDA2	126	0.01
102778	S1	117.4	0.03
102778	M1	191.5	0.02
102778	J1	179.9	0.02
102778	RHO1	185.1	0.01
102778	Q1	185.1	0.05
102778	T2	61.8	0.04
102778	2Q1	204.7	0.01
102778	P1	185.4	0.1
102778	M3	43	0.02
102778	L2	90.3	0.01
102778	2MK3	354.8	0.04
102778	K2	63.8	0.08
102778	M8	229.1	0.02
102778	MS4	143.4	0.08
102779	M2	28.7	1.74
102779	S2	47.6	0.32
102779	N2	10.2	0.47
102779	K1	173.4	0.28
102779	M4	54.6	0.29
102779	O1	199.9	0.17
102779	M6	292.7	0.08
102779	S4	0.2	0.03
102779	NU2	12.6	0.09
102779	S6	273.4	0.02
102779	MU2	228.5	0.04
102779	2N2	351.6	0.06
102779	OO1	148.3	0.01
102779	LDA2	37.5	0.01
102779	M1	186.6	0.01
102779	J1	160.8	0.01
102779	RHO1	211.4	0.01
102779	Q1	213.1	0.03
102779	T2	46.9	0.02
102779	P1	175.4	0.09
102779	L2	47.2	0.05
102779	K2	49.1	0.09
102779	M8	193.5	0.01
102780	M2	10.7	1.83
102780	S2	33.8	0.41
102780	N2	350.3	0.51
102780	K1	165.5	0.23
102780	M4	45.1	0.33
102780	O1	198.4	0.19
102780	M6	315.8	0.04
102780	S4	67.2	0.04
102780	NU2	353	0.1
102780	S6	284.4	0.01
102780	MU2	206.1	0.04
102780	2N2	329.8	0.07
102780	OO1	132.7	0.01
102780	LDA2	21.4	0.01
102780	M1	181.8	0.01
102780	J1	149.2	0.02
102780	RHO1	212.5	0.01
102780	Q1	214.7	0.04
102780	T2	32.9	0.02
102780	2Q1	231	0.01
102780	P1	168	0.08
102780	L2	31.1	0.05
102780	K2	35.7	0.11
102780	M8	236.5	0.01
102781	M2	9	1.95
102781	S2	32.1	0.41
102781	N2	353.3	0.47
102781	K1	172	0.22
102781	M4	63	0.31
102781	O1	200.2	0.16
102781	M6	331	0.07
102781	MK3	32.5	0.04
102781	S4	34.2	0.04
102781	MN4	14.9	0.13
102781	NU2	352.3	0.08
102781	S6	337.4	0.01
102781	MU2	0.3	0.1
102781	2N2	336.3	0.07
102781	OO1	215	0.02
102781	LDA2	348.2	0.02
102781	S1	127.4	0.05
102781	M1	212.6	0.01
102781	J1	204	0.02
102781	SA	144.8	0.24
102781	RHO1	201.7	0.01
102781	Q1	183.9	0.04
102781	T2	24.3	0.04
102781	R2	238.2	0.01
102781	P1	184.1	0.09
102781	2SM2	60.5	0.01
102781	M3	59.4	0.04
102781	L2	354.5	0.04
102781	2MK3	18.1	0.04
102781	K2	31.1	0.11
102781	M8	146.5	0.01
102781	MS4	146.5	0.08
102782	M2	9.5	1.84
102782	S2	31.7	0.38
102782	N2	353.5	0.47
102782	K1	166.3	0.24
102782	M4	41.3	0.3
102782	O1	201	0.16
102782	M6	286.7	0.04
102782	S4	347.6	0.04
102782	NU2	355.7	0.09
102782	S6	262.3	0.02
102782	MU2	205.8	0.04
102782	2N2	337.6	0.06
102782	OO1	131.9	0.01
102782	LDA2	19.8	0.01
102782	M1	183.6	0.01
102782	J1	149.3	0.01
102782	SSA	61.8	0.07
102782	SA	140.5	0.2
102782	RHO1	215.9	0.01
102782	Q1	218.2	0.03
102782	T2	30.8	0.02
102782	P1	168.9	0.08
102782	L2	25.5	0.05
102782	K2	33.5	0.1
102782	M8	154.7	0.01
102783	M2	135.7	2.51
102783	S2	175.6	0.32
102783	N2	104.6	0.52
102783	K1	232.7	0.35
102783	M4	178.1	0.13
102783	O1	216.9	0.3
102783	M6	134.2	0.05
102783	MK3	257.4	0.05
102783	S4	282.1	0.01
102783	MN4	156.8	0.07
102783	NU2	112.5	0.11
102783	MU2	272.4	0.03
102783	2N2	80.6	0.06
102783	OO1	261.6	0.01
102783	LDA2	154.7	0.06
102783	S1	252.7	0.01
102783	M1	288.7	0.02
102783	J1	276.7	0.01
102783	MM	35.6	0.14
102783	SSA	72.4	0.05
102783	SA	173.3	0.07
102783	MSF	48.5	0.12
102783	RHO1	199.6	0.01
102783	Q1	214.4	0.05
102783	T2	158.5	0.03
102783	2Q1	245.7	0.01
102783	P1	227.7	0.1
102783	M3	99.8	0.01
102783	L2	167.5	0.16
102783	2MK3	236.5	0.05
102783	K2	171.1	0.1
102783	M8	105.1	0.01
102783	MS4	228	0.05
102783	SIG1	212.5	0.02
102783	MP1	296.2	0.02
102783	2PO1	114.7	0.01
102783	SO1	19.2	0.01
102783	MSN2	22.6	0.02
102783	MNS2	189.7	0.02
102783	OP2	302.7	0.01
102783	2NS2	252.6	0.01
102783	MLN2S2	202.1	0.01
102783	2MS2K2	344.7	0.01
102783	M2(KS)2	164.3	0.02
102783	2SN(MK)2	313.9	0.01
102783	SO3	248.2	0.02
102783	SK3	306.1	0.01
102783	NO3	201.1	0.02
102783	MK4	215.4	0.01
102783	SN4	221.3	0.02
102783	2MLS4	303.1	0.01
102783	3MS4	163.5	0.02
102783	ML4	94.5	0.02
102783	N4	130.3	0.01
102783	SL4	140.6	0.01
102783	MNO5	158.6	0.02
102783	2MO5	172.1	0.03
102783	2MK5	194.9	0.03
102783	MSK5	255.5	0.01
102783	2MP5	221.6	0.01
102783	MNK5	182.7	0.01
102783	2MN6	90.6	0.04
102783	MSN6	172.6	0.01
102783	2MS6	163.1	0.02
102783	2NM6	78.4	0.01
102783	2ML6	105.4	0.01
102783	3MLS6	273.8	0.01
102783	2MK6	152.8	0.01
102783	2MNO7	127.3	0.01
102783	2NMK7	156.7	0.01
102783	2MSO7	191.4	0.01
102783	MSKO7	33.7	0.01
102783	2MSN8	125.9	0.01
102783	3MS8	125.9	0.01
102783	2(MN)8	28.9	0.01
102783	3MN8	53.5	0.02
102783	3ML8	53.5	0.01
102783	2M2NK9	155.6	0.01
102783	3MNK9	140.8	0.01
102783	4MK9	166.1	0.01
102783	4MN10	69	0.01
102783	M10	104.3	0.01
102783	3MNS10	114.8	0.01
102783	4MS10	149.2	0.01
102783	5MS12	119.2	0.01
102783	PSI1	102.6	0.01
102783	KP1	289.5	0.01
102783	THE1	13.2	0.01
102783	KJ2-IHO	103.6	0.01
102783	OQ2-HORN	54	0.02
102784	M2	130.3	1.8
102784	S2	163.5	0.22
102784	N2	93.8	0.47
102784	K1	219	0.34
102784	M4	8	0.13
102784	O1	203.3	0.3
102784	M6	298.4	0.07
102784	S4	353.9	0.01
102784	NU2	98.7	0.09
102784	MU2	317.1	0.04
102784	2N2	57.2	0.06
102784	OO1	234.9	0.01
102784	LDA2	145.7	0.01
102784	M1	211.3	0.02
102784	J1	227	0.02
102784	SA	165.7	0.12
102784	RHO1	196.5	0.01
102784	Q1	195.4	0.06
102784	T2	162.2	0.01
102784	2Q1	187.5	0.01
102784	P1	217.8	0.11
102784	L2	166.9	0.05
102784	K2	166.2	0.06
102785	M2	132.6	1.83
102785	S2	175.6	0.21
102785	N2	101.4	0.47
102785	K1	220.8	0.32
102785	M4	13.7	0.11
102785	O1	211	0.31
102785	M6	312.8	0.07
102785	S4	40.6	0.01
102785	NU2	105.6	0.09
102785	MU2	309.8	0.04
102785	2N2	70.2	0.06
102785	OO1	230	0.01
102785	LDA2	152.5	0.01
102785	M1	215.8	0.02
102785	J1	225.2	0.02
102785	SA	165.7	0.12
102785	RHO1	206.9	0.01
102785	Q1	206.2	0.06
102785	T2	173.9	0.01
102785	2Q1	201.6	0.01
102785	P1	220	0.11
102785	L2	163.9	0.05
102785	K2	179.1	0.06
102785	M8	309.7	0.02
102786	M2	134.3	1.49
102786	S2	167	0.15
102786	N2	98.7	0.4
102786	K1	219.5	0.32
102786	M4	10.1	0.15
102786	O1	209.2	0.29
102786	M6	333.7	0.07
102786	S4	358.4	0.01
102786	NU2	103.5	0.08
102786	MU2	101.8	0.04
102786	2N2	63.2	0.05
102786	OO1	229.8	0.01
102786	LDA2	149.4	0.01
102786	M1	214.3	0.02
102786	J1	224.5	0.02
102786	SA	145.9	0.17
102786	RHO1	204.8	0.01
102786	Q1	204.1	0.06
102786	T2	165.6	0.01
102786	2Q1	199.1	0.01
102786	P1	218.7	0.11
102786	L2	169.9	0.04
102786	K2	169.7	0.04
102786	M8	149.9	0.01
102787	M2	8.5	1.67
102787	S2	31.4	0.36
102787	N2	355.8	0.39
102787	K1	171.5	0.21
102787	M4	39	0.24
102787	O1	201.5	0.17
102787	M6	338.8	0.01
102787	MK3	26.6	0.04
102787	S4	20.6	0.02
102787	MN4	355.7	0.1
102787	NU2	358.8	0.08
102787	S6	305.1	0.01
102787	MU2	354.7	0.09
102787	2N2	342.8	0.06
102787	OO1	200.4	0.02
102787	LDA2	344.5	0.01
102787	S1	125.4	0.03
102787	M1	256.8	0.01
102787	J1	182.8	0.02
102787	SSA	75.1	0.05
102787	SA	145.3	0.2
102787	RHO1	222	0.01
102787	Q1	177.5	0.05
102787	T2	19.9	0.03
102787	2Q1	130.6	0.01
102787	P1	182.7	0.08
102787	2SM2	72.4	0.01
102787	M3	70.5	0.03
102787	L2	307.6	0.05
102787	2MK3	348.8	0.04
102787	K2	30	0.1
102787	MS4	125.3	0.07
102788	M2	7.2	1.8
102788	S2	28.8	0.37
102788	N2	351.6	0.46
102788	K1	167.4	0.23
102788	M4	37.5	0.28
102788	O1	201.4	0.16
102788	M6	299.1	0.02
102788	S4	344	0.03
102788	NU2	353.7	0.09
102788	S6	245.4	0.01
102788	MU2	345.8	0.04
102788	2N2	336	0.06
102788	OO1	133.3	0.01
102788	LDA2	17.3	0.01
102788	M1	184.3	0.01
102788	J1	150.5	0.01
102788	SA	145.9	0.17
102788	RHO1	216.1	0.01
102788	Q1	218.1	0.03
102788	T2	27.9	0.02
102788	P1	170	0.08
102788	L2	23	0.05
102788	K2	30.4	0.1
102789	M2	7.8	1.69
102789	S2	29.4	0.38
102789	N2	354.6	0.42
102789	K1	168.3	0.19
102789	M4	43.3	0.24
102789	O1	199.9	0.17
102789	M6	24.8	0.01
102789	S4	315.5	0.01
102789	NU2	356.4	0.08
102789	S6	83.6	0.01
102789	MU2	204.1	0.04
102789	2N2	341.3	0.06
102789	OO1	137.2	0.01
102789	LDA2	18	0.01
102789	M1	184.1	0.01
102789	J1	153	0.01
102789	SSA	61.8	0.07
102789	SA	140.5	0.2
102789	RHO1	213.3	0.01
102789	Q1	215.4	0.03
102789	T2	28.5	0.02
102789	P1	170.6	0.06
102789	L2	21.2	0.05
102789	K2	31.2	0.1
102789	M8	142.2	0.01
102790	M2	7.9	1.65
102790	S2	359.9	0.58
102790	N2	353.7	0.43
102790	K1	163.3	0.17
102790	M4	41.4	0.21
102790	O1	208.9	0.19
102790	M6	101.8	0.01
102790	MK3	23.2	0.05
102790	MN4	350.4	0.09
102790	NU2	355.4	0.1
102790	MU2	350.8	0.08
102790	2N2	338.4	0.07
102790	OO1	154.5	0.01
102790	LDA2	4.3	0.03
102790	S1	191.1	0.05
102790	M1	190.4	0.02
102790	J1	160.2	0.02
102790	SSA	61.8	0.07
102790	SA	140.5	0.2
102790	RHO1	100.6	0.04
102790	Q1	152.4	0.08
102790	T2	332.7	0.16
102790	R2	146.9	0.32
102790	2Q1	64.4	0.01
102790	P1	156	0.05
102790	2SM2	105.4	0.01
102790	M3	44.7	0.02
102790	L2	328	0.04
102790	2MK3	339.5	0.04
102790	K2	164.3	0.1
102790	MS4	117.6	0.04
102791	M2	35.3	0.75
102791	S2	36.9	0.18
102791	N2	20.9	0.25
102791	K1	191.2	0.22
102791	M4	354.9	0.17
102791	O1	201.5	0.2
102791	M6	43.9	0.06
102791	MK3	12.7	0.03
102791	S4	353.2	0.01
102791	MN4	317.8	0.08
102791	NU2	29	0.03
102791	S6	210.6	0.01
102791	MU2	350	0.07
102791	2N2	7.3	0.04
102791	OO1	189.6	0.02
102791	LDA2	189	0.01
102791	S1	116.5	0.02
102791	M1	243.9	0.01
102791	J1	204.6	0.02
102791	SSA	88.2	0.04
102791	SA	154.1	0.22
102791	RHO1	194.3	0.01
102791	Q1	191.4	0.05
102791	T2	31.4	0.01
102791	2Q1	272.5	0.01
102791	P1	201.1	0.09
102791	M3	28.1	0.02
102791	L2	258.4	0.03
102791	2MK3	339.6	0.03
102791	K2	31.1	0.05
102791	M8	160.7	0.01
102791	MS4	53	0.03
102792	M2	86.9	0.68
102792	S2	59.1	0.1
102792	N2	56.6	0.24
102792	K1	202	0.24
102792	M4	339.9	0.17
102792	O1	206.1	0.22
102792	M6	12.9	0.07
102792	S4	341.7	0.01
102792	NU2	60.7	0.05
102792	S6	45.8	0.01
102792	MU2	114.8	0.02
102792	2N2	26.2	0.03
102792	OO1	198	0.01
102792	M1	204	0.01
102792	J1	199.9	0.02
102792	SA	145.9	0.17
102792	RHO1	208.3	0.01
102792	Q1	208.2	0.04
102792	T2	60.2	0.01
102792	2Q1	209.9	0.01
102792	P1	202.3	0.08
102792	L2	117.3	0.02
102792	K2	56.8	0.03
102792	M8	185.5	0.02
102793	M2	2.5	1.61
102793	S2	23	0.36
102793	N2	348	0.4
102793	K1	166	0.18
102793	M4	29.7	0.19
102793	O1	199.7	0.16
102793	M6	85.3	0.01
102793	MK3	8.4	0.04
102793	S4	350.3	0.01
102793	MN4	343.8	0.09
102793	NU2	346	0.07
102793	MU2	346.9	0.08
102793	2N2	333.9	0.06
102793	OO1	214.3	0.01
102793	LDA2	346.1	0.01
102793	S1	141	0.05
102793	M1	175	0.01
102793	J1	196	0.03
102793	SSA	61.8	0.07
102793	SA	140.5	0.2
102793	RHO1	235.4	0.01
102793	Q1	169.1	0.04
102793	T2	2.9	0.04
102793	R2	205.1	0.01
102793	2Q1	214.5	0.01
102793	P1	185.7	0.06
102793	M3	30.5	0.02
102793	L2	314.9	0.04
102793	2MK3	345.6	0.04
102793	K2	20.5	0.09
102793	MS4	102.2	0.05
102794	M2	111.8	0.87
102794	S2	108.7	0.08
102794	N2	75.4	0.29
102794	K1	210.6	0.26
102794	M4	22.9	0.22
102794	O1	212.6	0.24
102794	M6	23.3	0.1
102794	S4	98.3	0.02
102794	NU2	80.3	0.06
102794	S6	163.3	0.01
102794	MU2	333.9	0.02
102794	2N2	39	0.04
102794	OO1	208.6	0.01
102794	LDA2	110.4	0.01
102794	M1	211.6	0.02
102794	J1	209.6	0.02
102794	RHO1	213.4	0.01
102794	Q1	213.6	0.05
102794	2Q1	214.6	0.01
102794	P1	210.8	0.09
102794	L2	148.2	0.02
102794	K2	108.5	0.02
102794	M8	197.3	0.02
102795	M2	13.3	1.27
102795	S2	33.1	0.27
102795	N2	358.6	0.33
102795	K1	173.8	0.2
102795	M4	24.2	0.14
102795	O1	200.5	0.16
102795	M6	76.3	0.05
102795	MK3	342.7	0.03
102795	S4	345.8	0.01
102795	MN4	346.3	0.05
102795	NU2	351.1	0.05
102795	MU2	350.7	0.06
102795	2N2	339.9	0.05
102795	OO1	179.4	0.01
102795	LDA2	11.8	0.01
102795	S1	147.8	0.02
102795	M1	240.6	0.02
102795	J1	173.3	0.01
102795	SA	166.3	0.24
102795	RHO1	179.4	0.01
102795	Q1	191.9	0.03
102795	T2	18.3	0.02
102795	R2	276.7	0.01
102795	P1	187.3	0.06
102795	2SM2	22.1	0.01
102795	M3	4.5	0.01
102795	L2	14.6	0.03
102795	2MK3	335.4	0.03
102795	K2	33.3	0.07
102795	M8	130.8	0.01
102795	MS4	92.6	0.05
102796	M2	354.9	1.32
102796	S2	17.7	0.26
102796	N2	338.5	0.33
102796	K1	167.8	0.18
102796	M4	318.8	0.1
102796	O1	203.9	0.14
102796	M6	332.9	0.04
102796	S4	142.1	0.03
102796	NU2	340.7	0.07
102796	S6	100.9	0.01
102796	MU2	332.1	0.03
102796	2N2	322.1	0.04
102796	OO1	131.7	0.01
102796	LDA2	5.5	0.01
102796	M1	185.7	0.01
102796	J1	149.9	0.01
102796	SA	165.7	0.12
102796	RHO1	219.4	0.01
102796	Q1	221.8	0.03
102796	T2	16.8	0.02
102796	P1	170.5	0.06
102796	L2	11.3	0.04
102796	K2	19.6	0.07
102796	M8	69.1	0.01
102797	M2	134.1	1.45
102797	S2	166.9	0.16
102797	N2	103.1	0.38
102797	K1	220.9	0.31
102797	M4	23.9	0.09
102797	O1	214.7	0.27
102797	M6	8.1	0.03
102797	MK3	62	0.01
102797	S4	67.7	0.01
102797	MN4	354.8	0.04
102797	NU2	115.3	0.08
102797	MU2	14.3	0.02
102797	2N2	84.1	0.06
102797	OO1	224.9	0.01
102797	LDA2	168.7	0.02
102797	S1	102.6	0.01
102797	M1	264.8	0.02
102797	J1	235.9	0.02
102797	SA	167	0.16
102797	RHO1	206.5	0.01
102797	Q1	202.7	0.05
102797	T2	149.5	0.02
102797	P1	225.9	0.1
102797	M3	101	0.01
102797	L2	177.5	0.06
102797	K2	170.7	0.04
102797	M8	264.9	0.01
102797	MS4	69.8	0.02
102798	M2	359.5	1.55
102798	S2	13.4	0.34
102798	N2	343	0.39
102798	K1	169.3	0.17
102798	M4	16.8	0.13
102798	O1	198.9	0.16
102798	M6	171.3	0.03
102798	MK3	17.6	0.02
102798	S4	305.5	0.01
102798	MN4	324.5	0.06
102798	NU2	344.1	0.06
102798	MU2	346.1	0.07
102798	2N2	332.4	0.06
102798	OO1	215.3	0.02
102798	LDA2	20.3	0.01
102798	S1	73.9	0.05
102798	M1	184.6	0.01
102798	J1	215.2	0.01
102798	MM	73.9	0.06
102798	SSA	75.1	0.05
102798	SA	145.3	0.2
102798	RHO1	190.7	0.01
102798	Q1	191.6	0.04
102798	T2	313.7	0.03
102798	R2	176.1	0.05
102798	2Q1	111.2	0.01
102798	P1	163.6	0.09
102798	2SM2	26	0.01
102798	M3	345.5	0.01
102798	L2	345.3	0.05
102798	2MK3	338.6	0.03
102798	K2	5.3	0.09
102798	M8	298.2	0.01
102798	MS4	71.6	0.03
102799	M2	8.6	1.9
102799	S2	30	0.43
102799	N2	359.6	0.44
102799	K1	184.1	0.28
102799	M4	63.5	0.28
102799	O1	172.2	0.15
102799	M6	308.9	0.04
102799	S4	1.5	0.07
102799	NU2	0.8	0.09
102799	S6	294.8	0.01
102799	MU2	204.7	0.05
102799	2N2	350.6	0.06
102799	OO1	196	0.01
102799	LDA2	18.5	0.01
102799	M1	178.2	0.01
102799	J1	190	0.01
102799	SSA	61.8	0.07
102799	SA	140.5	0.2
102799	RHO1	167.2	0.01
102799	Q1	166.4	0.03
102799	T2	29.1	0.03
102799	P1	183.2	0.1
102799	L2	17.6	0.05
102799	K2	31.7	0.12
102800	M2	6.6	1.9
102800	S2	32.5	0.42
102800	N2	352.3	0.44
102800	K1	157.8	0.2
102800	M4	56.4	0.28
102800	O1	203.6	0.16
102800	M6	296.1	0.06
102800	MK3	33.8	0.05
102800	S4	42.2	0.02
102800	MN4	10.1	0.11
102800	NU2	351	0.08
102800	MU2	355	0.08
102800	2N2	330.6	0.06
102800	OO1	215.6	0.01
102800	LDA2	337.4	0.01
102800	S1	182.9	0.06
102800	M1	163.7	0.01
102800	J1	197.4	0.03
102800	SA	131.8	0.2
102800	RHO1	226.7	0.02
102800	Q1	172.4	0.07
102800	T2	38.5	0.05
102800	R2	246.9	0.03
102800	2Q1	268.3	0.03
102800	P1	158.8	0.06
102800	2SM2	52.2	0.01
102800	M3	73.3	0.04
102800	L2	318.8	0.03
102800	2MK3	16.3	0.04
102800	K2	19.5	0.1
102800	M8	100.2	0.01
102800	MS4	137.8	0.06
102801	M2	2.3	1.66
102801	S2	25	0.35
102801	N2	345.8	0.41
102801	K1	166.1	0.2
102801	M4	35.8	0.19
102801	O1	202	0.15
102801	M6	220.1	0.02
102801	MK3	19.5	0.03
102801	S4	5.1	0.02
102801	MN4	347.9	0.09
102801	NU2	341	0.07
102801	MU2	344.5	0.08
102801	2N2	333	0.06
102801	OO1	195.7	0.01
102801	LDA2	345.5	0.01
102801	S1	121.9	0.02
102801	M1	204	0.01
102801	J1	181.1	0.02
102801	MM	73.9	0.06
102801	SSA	75.1	0.05
102801	SA	145.3	0.2
102801	RHO1	230.9	0.01
102801	Q1	185.3	0.04
102801	T2	9	0.03
102801	2Q1	172.9	0.01
102801	P1	176.6	0.07
102801	2SM2	48.8	0.01
102801	M3	34.1	0.02
102801	L2	349.9	0.04
102801	2MK3	357.1	0.03
102801	K2	21.7	0.1
102801	MS4	106.4	0.05
102802	M2	7.6	1.89
102802	S2	31	0.4
102802	N2	351.7	0.46
102802	K1	170.7	0.21
102802	M4	56.2	0.29
102802	O1	201.1	0.16
102802	M6	301.9	0.06
102802	MK3	29.7	0.04
102802	S4	29	0.04
102802	MN4	7.8	0.13
102802	NU2	350	0.08
102802	S6	299.1	0.01
102802	MU2	355.8	0.09
102802	2N2	336.7	0.07
102802	OO1	198.7	0.02
102802	LDA2	351.5	0.01
102802	S1	119.8	0.04
102802	M1	225.9	0.01
102802	J1	201.3	0.02
102802	SA	140.4	0.24
102802	RHO1	188.9	0.01
102802	Q1	192.3	0.04
102802	T2	17.9	0.04
102802	R2	212.7	0.01
102802	P1	180.2	0.08
102802	2SM2	35.9	0.01
102802	M3	44.7	0.03
102802	L2	355.8	0.05
102802	2MK3	11.5	0.04
102802	K2	29.4	0.11
102802	M8	102	0.01
102802	MS4	137.9	0.07
102803	M2	10.8	1.9
102803	S2	33.8	0.4
102803	N2	0.3	0.46
102803	K1	170.3	0.25
102803	M4	58.5	0.29
102803	O1	202.4	0.14
102803	M6	305.3	0.08
102803	S4	350.2	0.07
102803	NU2	1.7	0.09
102803	S6	259.5	0.01
102803	MU2	205.3	0.05
102803	2N2	349.8	0.06
102803	OO1	139.3	0.01
102803	LDA2	21.5	0.01
102803	M1	186.5	0.01
102803	J1	155.2	0.01
102803	SSA	80.8	0.06
102803	SA	130.9	0.27
102803	RHO1	215.8	0.01
102803	Q1	218	0.03
102803	T2	32.9	0.02
102803	P1	172.7	0.08
102803	L2	21.5	0.05
102803	K2	35.7	0.11
102803	M8	106.1	0.01
102804	M2	13.8	2
102804	S2	36.9	0.41
102804	N2	1.1	0.48
102804	K1	169.3	0.25
102804	M4	75	0.32
102804	O1	202.4	0.16
102804	M6	329.6	0.13
102804	S4	8.5	0.05
102804	NU2	2.8	0.09
102804	MU2	207.9	0.05
102804	2N2	348.5	0.06
102804	OO1	135.9	0.01
102804	LDA2	24.5	0.01
102804	M1	185.6	0.01
102804	J1	152.7	0.01
102804	SSA	80.8	0.06
102804	SA	130.9	0.27
102804	RHO1	216.6	0.01
102804	Q1	218.8	0.03
102804	T2	36	0.02
102804	P1	171.7	0.09
102804	L2	26.4	0.06
102804	K2	38.8	0.11
102804	M8	144.6	0.03
102805	M2	2.8	1.686
102805	S2	24.8	0.348
102805	N2	349.3	0.407
102805	K1	172.9	0.285
102805	M4	45.5	0.18
102805	O1	200.6	0.171
102805	M6	232.7	0.016
102805	S4	12.2	0.03
102805	NU2	351.1	0.079
102805	S6	345.1	0.007
102805	MU2	198.1	0.039
102805	2N2	335.8	0.052
102805	OO1	145.1	0.007
102805	LDA2	13	0.013
102805	M1	186.6	0.013
102805	J1	159.1	0.013
102805	RHO1	212.5	0.007
102805	Q1	214.4	0.033
102805	T2	23.9	0.02
102805	R2	25.7	0.003
102805	2Q1	228.1	0.003
102805	P1	174.9	0.095
102805	L2	16.3	0.046
102805	K2	26.6	0.095
102805	M8	19.2	0.007
102806	M2	8.7	1.95
102806	S2	31.2	0.4
102806	N2	356	0.46
102806	K1	166.9	0.25
102806	M4	64.2	0.32
102806	O1	201.9	0.16
102806	M6	307.8	0.08
102806	S4	356.3	0.04
102806	NU2	357.7	0.09
102806	MU2	203.5	0.05
102806	2N2	343.2	0.06
102806	OO1	131.5	0.01
102806	LDA2	19.2	0.01
102806	M1	184.1	0.01
102806	J1	149.2	0.01
102806	SSA	80.8	0.06
102806	SA	130.9	0.27
102806	RHO1	217	0.01
102806	Q1	219.3	0.03
102806	T2	30.3	0.02
102806	P1	169.4	0.08
102806	L2	21.5	0.06
102806	K2	33	0.11
102806	M8	116.2	0.01
102807	M2	8.6	1.95
102807	S2	32.6	0.42
102807	N2	352.6	0.47
102807	K1	169.9	0.22
102807	M4	59.1	0.32
102807	O1	199.8	0.16
102807	M6	305	0.09
102807	MK3	32.6	0.04
102807	S4	29.7	0.04
102807	MN4	10.6	0.14
102807	NU2	351.7	0.08
102807	S6	308.9	0.01
102807	MU2	358.1	0.09
102807	2N2	333.8	0.07
102807	OO1	208.7	0.02
102807	LDA2	352.5	0.02
102807	S1	121	0.05
102807	M1	207.3	0.02
102807	J1	204.4	0.02
102807	SSA	80.8	0.06
102807	SA	130.9	0.27
102807	RHO1	215.3	0.01
102807	Q1	185.6	0.04
102807	T2	22.8	0.04
102807	R2	211.1	0.01
102807	P1	180.1	0.08
102807	2SM2	53.6	0.01
102807	M3	56.6	0.04
102807	L2	355	0.04
102807	2MK3	18.2	0.05
102807	K2	31.4	0.11
102807	M8	121.1	0.02
102807	MS4	144.6	0.08
102808	M2	5.3	1.75
102808	S2	28.5	0.37
102808	N2	349.6	0.43
102808	K1	168.8	0.21
102808	M4	48.2	0.22
102808	O1	200.4	0.16
102808	M6	267.2	0.03
102808	MK3	23.5	0.03
102808	S4	17.1	0.03
102808	MN4	0.7	0.1
102808	NU2	346	0.07
102808	MU2	351.9	0.09
102808	2N2	335.5	0.07
102808	OO1	195.8	0.01
102808	LDA2	357.7	0.01
102808	S1	118	0.03
102808	M1	221.9	0.02
102808	J1	194.7	0.02
102808	SA	145.7	0.24
102808	RHO1	207.4	0.01
102808	Q1	189.9	0.04
102808	T2	13.8	0.03
102808	R2	194.1	0.01
102808	P1	181.5	0.08
102808	2SM2	36.5	0.01
102808	M3	37.6	0.03
102808	L2	347.4	0.05
102808	2MK3	1.5	0.04
102808	K2	27.2	0.1
102808	M8	351.5	0.01
102808	MS4	126.4	0.05
102809	M2	6.8	1.75
102809	S2	29.6	0.36
102809	N2	353.7	0.42
102809	K1	165.4	0.23
102809	M4	56	0.21
102809	O1	201.8	0.16
102809	M6	268.2	0.03
102809	S4	348.4	0.02
102809	NU2	355.5	0.08
102809	MU2	201.1	0.04
102809	2N2	340.6	0.06
102809	OO1	128.7	0.01
102809	LDA2	17.4	0.01
102809	M1	183.3	0.01
102809	J1	147.1	0.01
102809	SSA	61.8	0.07
102809	SA	140.5	0.2
102809	RHO1	217.4	0.01
102809	Q1	219.9	0.03
102809	T2	28.7	0.02
102809	P1	168.1	0.08
102809	L2	19.9	0.05
102809	K2	31.5	0.1
102810	M2	6.6	1.87
102810	S2	32.5	0.41
102810	N2	352.2	0.43
102810	K1	157	0.2
102810	M4	55.2	0.27
102810	O1	204	0.15
102810	M6	287.2	0.06
102810	MK3	35.7	0.04
102810	S4	40.3	0.02
102810	MN4	8	0.11
102810	NU2	349	0.08
102810	MU2	354	0.09
102810	2N2	331.1	0.06
102810	OO1	216.5	0.01
102810	LDA2	330.2	0.01
102810	S1	188.3	0.06
102810	M1	155.6	0.01
102810	J1	197	0.03
102810	SA	131.8	0.2
102810	RHO1	219.9	0.02
102810	Q1	171.5	0.07
102810	T2	36.6	0.04
102810	R2	246.5	0.03
102810	2Q1	266.9	0.03
102810	P1	155	0.06
102810	2SM2	52.6	0.01
102810	M3	74	0.04
102810	L2	317.9	0.03
102810	2MK3	15.3	0.03
102810	K2	18.1	0.1
102810	MS4	136.2	0.06
102811	M2	2.1	1.56
102811	S2	24.5	0.32
102811	N2	349.3	0.37
102811	K1	164.7	0.22
102811	M4	29	0.13
102811	O1	200.4	0.15
102811	M6	179.1	0.03
102811	S4	334.8	0.01
102811	NU2	350.9	0.07
102811	MU2	339.7	0.04
102811	2N2	336.5	0.05
102811	OO1	129.1	0.01
102811	LDA2	12.5	0.01
102811	M1	182.6	0.01
102811	J1	147.4	0.01
102811	MM	73.9	0.06
102811	SSA	75.1	0.05
102811	SA	145.3	0.2
102811	RHO1	215.4	0.01
102811	Q1	218.3	0.03
102811	T2	23.6	0.02
102811	P1	167.3	0.08
102811	L2	14.9	0.04
102811	K2	26.3	0.09
102811	M8	321.5	0.01
102812	M2	8.2	1.5
102812	S2	28.2	0.32
102812	N2	349.2	0.36
102812	K1	162.9	0.21
102812	M4	23.9	0.08
102812	O1	198.1	0.16
102812	M6	196.9	0.04
102812	MK3	36.9	0.02
102812	S4	27.6	0.01
102812	MN4	331.4	0.04
102812	NU2	320.5	0.08
102812	MU2	347.1	0.08
102812	2N2	331.6	0.07
102812	OO1	304.1	0.01
102812	LDA2	145.3	0.02
102812	S1	150.1	0.05
102812	M1	215.7	0.02
102812	J1	217.9	0.02
102812	SSA	61.8	0.07
102812	SA	140.5	0.2
102812	RHO1	82	0.02
102812	Q1	208.2	0.05
102812	T2	1.6	0.03
102812	R2	192.9	0.03
102812	2Q1	223.6	0.01
102812	P1	193.6	0.05
102812	2SM2	61.6	0.02
102812	M3	353.8	0.02
102812	L2	21.1	0.04
102812	2MK3	18.1	0.03
102812	K2	32.1	0.07
102812	M8	341.3	0.01
102812	MS4	115.4	0.02
102813	M2	13.6	1.92
102813	S2	41	0.38
102813	N2	359.3	0.45
102813	K1	167.4	0.25
102813	M4	70	0.29
102813	O1	200.7	0.17
102813	M6	342.3	0.1
102813	S4	66.8	0.02
102813	NU2	1.2	0.09
102813	MU2	346.2	0.05
102813	2N2	345	0.06
102813	OO1	133.4	0.01
102813	LDA2	26.3	0.01
102813	M1	184	0.01
102813	J1	150.8	0.01
102813	SA	131.8	0.2
102813	RHO1	214.3	0.01
102813	Q1	217.4	0.03
102813	T2	40	0.02
102813	P1	169.9	0.08
102813	L2	27.8	0.05
102813	K2	43.2	0.1
102813	M8	101	0.01
102814	M2	44.2	1.2
102814	S2	65	0.22
102814	N2	25	0.28
102814	K1	172.5	0.25
102814	M4	8.8	0.13
102814	O1	207.5	0.16
102814	M6	217.3	0.09
102814	NU2	27.7	0.06
102814	MU2	23.5	0.03
102814	2N2	5.9	0.04
102814	OO1	137.8	0.01
102814	LDA2	53.9	0.01
102814	M1	190	0.01
102814	J1	155.3	0.01
102814	SSA	69.4	0.06
102814	SA	135.3	0.18
102814	RHO1	222.2	0.01
102814	Q1	224.9	0.03
102814	T2	64.2	0.01
102814	P1	175.2	0.09
102814	L2	63.4	0.03
102814	K2	66.7	0.06
102814	M8	198.7	0.01
102815	M2	19.3	1.24
102815	S2	31.2	0.24
102815	N2	3.6	0.32
102815	K1	184.2	0.24
102815	M4	30.2	0.04
102815	O1	206.7	0.14
102815	M6	174.1	0.05
102815	NU2	5.7	0.06
102815	S6	17.1	0.01
102815	MU2	223.9	0.03
102815	2N2	347.9	0.04
102815	OO1	161.7	0.01
102815	LDA2	24.8	0.01
102815	M1	195.4	0.01
102815	J1	173	0.01
102815	RHO1	216.4	0.01
102815	Q1	217.9	0.03
102815	T2	30.7	0.01
102815	P1	185.9	0.08
102815	L2	34.9	0.04
102815	K2	32.1	0.07
102815	M8	299.8	0.01
102816	M2	359.8	1.42
102816	S2	22.1	0.32
102816	N2	343.1	0.33
102816	K1	168.5	0.2
102816	M4	11.5	0.08
102816	O1	198.7	0.15
102816	M6	178	0.04
102816	MK3	16.6	0.02
102816	S4	312.7	0.01
102816	MN4	329.8	0.04
102816	NU2	343.6	0.05
102816	MU2	340.9	0.07
102816	2N2	326.9	0.05
102816	OO1	189.2	0.01
102816	S1	143.1	0.01
102816	M1	197.8	0.01
102816	J1	170.6	0.02
102816	SSA	75.1	0.05
102816	SA	145.3	0.2
102816	RHO1	144.8	0.02
102816	Q1	189.9	0.04
102816	T2	1.2	0.03
102816	2Q1	117.9	0.01
102816	P1	175.4	0.06
102816	2SM2	17.5	0.01
102816	M3	49.2	0.02
102816	L2	243.2	0.02
102816	2MK3	352.4	0.02
102816	K2	19.1	0.09
102816	M8	288.7	0.01
102816	MS4	81	0.02
102817	M2	0.4	1.45
102817	S2	24	0.29
102817	N2	339.1	0.33
102817	K1	161.9	0.23
102817	M4	16	0.07
102817	O1	190.4	0.14
102817	M6	182.1	0.05
102817	NU2	341.9	0.07
102817	MU2	333.5	0.04
102817	2N2	317.7	0.05
102817	OO1	133.8	0.01
102817	LDA2	11.4	0.01
102817	M1	176.1	0.01
102817	J1	148	0.01
102817	SSA	75.1	0.05
102817	SA	145.3	0.2
102817	RHO1	202.5	0.01
102817	Q1	204.4	0.03
102817	T2	23.1	0.02
102817	P1	164	0.08
102817	L2	21.9	0.04
102817	K2	25.9	0.08
102818	M2	8.1	1.3
102818	S2	28.9	0.28
102818	N2	350.3	0.31
102818	K1	165.2	0.23
102818	M4	16.1	0.08
102818	O1	200.8	0.15
102818	M6	182.9	0.05
102818	MK3	22.6	0.02
102818	MN4	327	0.04
102818	NU2	350.4	0.06
102818	MU2	343.1	0.07
102818	2N2	329	0.05
102818	OO1	180.1	0.01
102818	LDA2	84.5	0.01
102818	S1	227.3	0.02
102818	M1	196.1	0.01
102818	J1	171.6	0.02
102818	SSA	61.8	0.07
102818	SA	140.5	0.2
102818	RHO1	125	0.01
102818	Q1	183.8	0.04
102818	T2	21.2	0.02
102818	P1	162.4	0.06
102818	2SM2	37.8	0.01
102818	M3	59.1	0.02
102818	L2	251.3	0.02
102818	2MK3	0.3	0.01
102818	K2	29	0.08
102818	M8	276.5	0.01
102818	MS4	90.7	0.02
102819	M2	5.8	1.31
102819	S2	25	0.28
102819	N2	346.9	0.31
102819	K1	169.4	0.21
102819	M4	12.7	0.06
102819	O1	203.8	0.15
102819	M6	175.9	0.05
102819	MK3	8.2	0.01
102819	MN4	322.1	0.03
102819	NU2	347.9	0.06
102819	MU2	344.6	0.06
102819	2N2	329.8	0.05
102819	OO1	134.9	0.01
102819	LDA2	14.6	0.01
102819	S1	103.6	0.02
102819	M1	181.2	0.01
102819	J1	174.6	0.01
102819	SSA	75.1	0.05
102819	SA	145.3	0.2
102819	RHO1	254.4	0.02
102819	Q1	185.7	0.04
102819	T2	8.5	0.03
102819	2Q1	201.1	0.02
102819	P1	185.1	0.07
102819	M3	43.5	0.02
102819	L2	81.2	0.02
102819	2MK3	3.6	0.02
102819	K2	25.5	0.08
102819	MS4	85.2	0.02
102820	M2	47.6	1.14
102820	S2	56.9	0.23
102820	N2	26.4	0.27
102820	K1	168.6	0.21
102820	M4	347.6	0.08
102820	O1	211.6	0.15
102820	M6	192	0.07
102820	MK3	39.9	0.02
102820	S4	340.1	0.01
102820	MN4	319.7	0.04
102820	NU2	26.3	0.06
102820	MU2	348.8	0.04
102820	2N2	355.2	0.03
102820	OO1	218.4	0.01
102820	S1	197.7	0.06
102820	M1	182	0.01
102820	J1	211.8	0.03
102820	SSA	69.4	0.06
102820	SA	135.3	0.18
102820	RHO1	236.8	0.02
102820	Q1	186	0.06
102820	T2	34.2	0.03
102820	R2	190.4	0.03
102820	2Q1	269.3	0.02
102820	P1	172.5	0.05
102820	2SM2	35.1	0.01
102820	M3	71.3	0.02
102820	L2	115.5	0.02
102820	2MK3	30.9	0.02
102820	K2	74.1	0.04
102820	MS4	28.6	0.01
102821	M2	58.7	1.18
102821	S2	70.4	0.21
102821	N2	34	0.28
102821	K1	180.1	0.24
102821	M4	343.1	0.08
102821	O1	209.1	0.16
102821	M6	206.5	0.04
102821	MK3	25.3	0.02
102821	S4	348.7	0.01
102821	MN4	310	0.05
102821	NU2	41.3	0.06
102821	MU2	347.5	0.04
102821	2N2	9.1	0.04
102821	OO1	216.9	0.02
102821	LDA2	114.8	0.02
102821	S1	112	0.03
102821	M1	242.4	0.02
102821	J1	222.6	0.02
102821	SSA	72.6	0.09
102821	SA	138	0.24
102821	RHO1	197.2	0.02
102821	Q1	196.7	0.04
102821	T2	52.2	0.02
102821	2Q1	216	0.01
102821	P1	193.7	0.08
102821	2SM2	44.9	0.01
102821	M3	48.4	0.01
102821	L2	121.6	0.05
102821	2MK3	20	0.02
102821	K2	72.1	0.05
102821	MS4	8.1	0.01
102822	M2	104.6	2.23
102822	S2	128.1	0.33
102822	N2	85.8	0.49
102822	K1	183.2	0.29
102822	M4	187.4	0.05
102822	O1	215.1	0.2
102822	M6	352.1	0.06
102822	NU2	88.3	0.1
102822	MU2	296.1	0.05
102822	2N2	67.1	0.07
102822	OO1	151.1	0.01
102822	LDA2	115.5	0.02
102822	M1	199	0.01
102822	J1	167.3	0.02
102822	SSA	69.4	0.06
102822	SA	135.3	0.18
102822	RHO1	228.8	0.01
102822	Q1	230.9	0.04
102822	T2	127.1	0.02
102822	2Q1	246.8	0.01
102822	P1	185.5	0.1
102822	L2	123.5	0.06
102822	K2	130	0.09
102822	M8	157.2	0.02
102823	M2	106.4	2.91
102823	S2	132.4	0.46
102823	N2	84.3	0.62
102823	K1	189.9	0.29
102823	M4	109.8	0.01
102823	O1	219.2	0.2
102823	M6	348.1	0.09
102823	MK3	186.6	0.01
102823	MN4	67.7	0.01
102823	NU2	85.2	0.13
102823	2N2	63.2	0.08
102823	OO1	225.2	0.02
102823	LDA2	131.9	0.06
102823	S1	127.4	0.04
102823	M1	253.9	0.03
102823	J1	236.6	0.02
102823	SSA	70	0.09
102823	SA	142	0.28
102823	RHO1	215	0.02
102823	Q1	220.9	0.05
102823	T2	107.5	0.04
102823	R2	253.5	0.01
102823	2Q1	244.7	0.01
102823	P1	201.1	0.1
102823	2SM2	61.6	0.01
102823	M3	165.8	0.01
102823	L2	130.2	0.18
102823	2MK3	185	0.01
102823	K2	133.5	0.13
102824	M2	109.4	3.21
102824	S2	135.3	0.5
102824	N2	86	0.66
102824	K1	192.4	0.29
102824	M4	129.7	0.04
102824	O1	220.1	0.2
102824	M6	352.7	0.05
102824	MK3	194.7	0.02
102824	S4	142.5	0.01
102824	MN4	96.2	0.02
102824	NU2	87.2	0.15
102824	2N2	66.4	0.08
102824	OO1	231	0.02
102824	LDA2	133.8	0.07
102824	S1	128.2	0.04
102824	M1	242.3	0.02
102824	J1	253.7	0.02
102824	SSA	61.2	0.1
102824	SA	138.2	0.28
102824	RHO1	217.6	0.01
102824	Q1	218.7	0.05
102824	T2	114.4	0.04
102824	R2	231.1	0.01
102824	2Q1	228	0.01
102824	P1	202	0.11
102824	2SM2	56.1	0.01
102824	M3	185.4	0.01
102824	L2	141.8	0.19
102824	2MK3	199.8	0.02
102824	K2	136.9	0.14
102824	M8	331.2	0.01
102825	M2	110.2	3.31
102825	S2	138.4	0.49
102825	N2	92.6	0.72
102825	K1	182.8	0.33
102825	M4	134.9	0.04
102825	O1	214.5	0.2
102825	M6	354.3	0.05
102825	S4	135	0.01
102825	NU2	94.9	0.14
102825	MU2	295.4	0.08
102825	2N2	75	0.1
102825	OO1	151.4	0.01
102825	LDA2	123.4	0.02
102825	M1	198.6	0.01
102825	J1	167.3	0.02
102825	SSA	61.2	0.07
102825	SA	132	0.21
102825	RHO1	228.1	0.01
102825	Q1	230.1	0.04
102825	T2	137.3	0.03
102825	2Q1	245.9	0.01
102825	P1	185.2	0.11
102825	L2	127.8	0.09
102825	K2	140.7	0.13
102825	M8	310.4	0.01
102826	M2	110.7	3.41
102826	S2	145.7	0.47
102826	N2	91.2	0.67
102826	K1	181.2	0.31
102826	M4	130.1	0.04
102826	O1	220	0.19
102826	M6	4.9	0.03
102826	NU2	93.8	0.13
102826	S6	213.2	0.01
102826	MU2	75.7	0.08
102826	2N2	71.7	0.09
102826	OO1	142.5	0.01
102826	LDA2	127	0.02
102826	M1	200.5	0.01
102826	J1	162	0.02
102826	SSA	61.2	0.07
102826	SA	132	0.21
102826	RHO1	236.6	0.01
102826	Q1	239.2	0.04
102826	T2	144.3	0.03
102826	2Q1	258.4	0.01
102826	P1	184.2	0.1
102826	L2	130.2	0.1
102826	K2	148.6	0.13
102826	M8	342.4	0.01
102827	M2	111.9	3.41
102827	S2	146	0.55
102827	N2	90.3	0.67
102827	K1	185.3	0.3
102827	M4	136.7	0.08
102827	O1	224.5	0.2
102827	M6	31.2	0.02
102827	MK3	203.6	0.03
102827	S4	155.5	0.01
102827	MN4	112.7	0.04
102827	NU2	89.1	0.15
102827	MU2	199.9	0.01
102827	2N2	72.7	0.05
102827	OO1	275.3	0.01
102827	LDA2	138.4	0.06
102827	S1	201.6	0.03
102827	M1	209.5	0.01
102827	J1	237.4	0.03
102827	SSA	61.2	0.07
102827	SA	132	0.21
102827	RHO1	242	0.02
102827	Q1	196.4	0.07
102827	T2	174.7	0.05
102827	R2	34.1	0.08
102827	2Q1	284.3	0.03
102827	P1	196.7	0.07
102827	2SM2	54.2	0.01
102827	M3	219	0.02
102827	L2	142.2	0.19
102827	2MK3	214.7	0.02
102827	K2	124.1	0.17
102827	M8	320.7	0.01
102827	MS4	149.4	0.02
102828	M2	113.9	3.51
102828	S2	137	0.55
102828	N2	92.7	0.79
102828	K1	185.2	0.33
102828	M4	131.9	0.07
102828	O1	219.4	0.22
102828	M6	143	0.02
102828	S4	123.7	0.01
102828	NU2	95.5	0.15
102828	MU2	303.9	0.09
102828	2N2	71.5	0.1
102828	OO1	150.9	0.01
102828	LDA2	124.6	0.02
102828	M1	202.1	0.02
102828	J1	168.2	0.02
102828	SSA	61.2	0.07
102828	SA	132	0.21
102828	RHO1	234.1	0.01
102828	Q1	236.4	0.04
102828	T2	136	0.03
102828	2Q1	253.4	0.01
102828	P1	187.7	0.11
102828	L2	134.9	0.1
102828	K2	138.8	0.15
102828	M8	311.2	0.01
102829	M2	111.7	3.48
102829	S2	141	0.53
102829	N2	88	0.74
102829	K1	185.8	0.36
102829	M4	137	0.08
102829	O1	229	0.16
102829	M6	154.3	0.06
102829	S4	169.1	0.02
102829	NU2	91.2	0.14
102829	MU2	82.4	0.08
102829	2N2	64.4	0.1
102829	OO1	142.6	0.01
102829	LDA2	125.3	0.02
102829	M1	207.2	0.01
102829	J1	164.4	0.01
102829	SSA	61.2	0.07
102829	SA	132	0.21
102829	RHO1	247.5	0.01
102829	Q1	250.4	0.03
102829	T2	139.8	0.03
102829	P1	189	0.12
102829	L2	135.4	0.1
102829	K2	143.4	0.14
102830	M2	113.5	3.68
102830	S2	139.3	0.59
102830	N2	91.8	0.72
102830	K1	192.4	0.31
102830	M4	133.1	0.1
102830	O1	217.9	0.21
102830	M6	158.4	0.12
102830	MK3	198.1	0.03
102830	S4	168.5	0.01
102830	MN4	110.9	0.06
102830	NU2	93.5	0.18
102830	MU2	174.2	0.01
102830	2N2	74.7	0.05
102830	OO1	245.4	0.01
102830	LDA2	119	0.07
102830	S1	163.2	0.04
102830	M1	179.1	0.01
102830	J1	256.9	0.02
102830	SSA	61.2	0.07
102830	SA	132	0.21
102830	RHO1	288.6	0.01
102830	Q1	204	0.06
102830	T2	121	0.06
102830	R2	339.8	0.02
102830	2Q1	283.4	0.01
102830	P1	206.7	0.09
102830	2SM2	40.5	0.01
102830	M3	220.2	0.02
102830	L2	141.1	0.2
102830	2MK3	218.1	0.03
102830	K2	132.4	0.17
102830	M8	216.7	0.01
102830	MS4	154.2	0.02
102831	M2	113.6	3.66
102831	S2	143.2	0.55
102831	N2	91.6	0.73
102831	K1	187	0.32
102831	M4	137.1	0.08
102831	O1	224.7	0.21
102831	M6	160.4	0.09
102831	S4	190.9	0.01
102831	NU2	94.6	0.14
102831	MU2	83.9	0.09
102831	2N2	69.6	0.1
102831	OO1	149.1	0.01
102831	LDA2	127.3	0.03
102831	M1	205.7	0.01
102831	J1	168.3	0.02
102831	SSA	61.2	0.07
102831	SA	132	0.21
102831	RHO1	240.6	0.01
102831	Q1	243.4	0.04
102831	T2	142	0.03
102831	2Q1	262.5	0.01
102831	P1	189.9	0.1
102831	L2	135.6	0.1
102831	K2	145.6	0.15
102831	M8	280.8	0.01
102832	M2	0.7	1.24
102832	S2	26.2	0.28
102832	N2	345	0.29
102832	K1	161.1	0.22
102832	M4	123.7	0.05
102832	O1	194.3	0.13
102832	M6	199.5	0.05
102832	MK3	347.9	0.01
102832	NU2	339.4	0.06
102832	MU2	341.7	0.07
102832	2N2	331	0.04
102832	OO1	127.7	0.01
102832	LDA2	12.5	0.01
102832	S1	194	0.02
102832	M1	177.7	0.01
102832	J1	144.4	0.01
102832	SSA	64.4	0.06
102832	SA	145.7	0.17
102832	RHO1	208.7	0.01
102832	Q1	170	0.04
102832	T2	26.1	0.02
102832	P1	158.4	0.05
102832	M3	55.7	0.02
102832	L2	269.2	0.04
102832	2MK3	328.9	0.02
102832	K2	18.8	0.08
102832	MS4	148.8	0.03
102833	M2	48.5	0.92
102833	S2	60.7	0.18
102833	N2	25.6	0.25
102833	K1	174.8	0.22
102833	M4	16.7	0.07
102833	O1	215.8	0.14
102833	M6	158.3	0.04
102833	NU2	28.7	0.05
102833	MU2	252.4	0.02
102833	2N2	2.7	0.03
102833	OO1	133.8	0.01
102833	LDA2	54.1	0.01
102833	M1	195.2	0.01
102833	J1	154.5	0.01
102833	RHO1	233.4	0.01
102833	Q1	236.2	0.03
102833	T2	60.2	0.01
102833	P1	177.9	0.07
102833	L2	71.4	0.03
102833	K2	61.6	0.05
102833	M8	250.1	0.01
102834	M2	48.2	0.93
102834	S2	58.6	0.19
102834	N2	25.6	0.25
102834	K1	178.9	0.23
102834	M4	343.2	0.07
102834	O1	207.6	0.16
102834	M6	159.9	0.04
102834	MK3	11.7	0.02
102834	S4	343.7	0.01
102834	MN4	310	0.04
102834	NU2	29.1	0.04
102834	MU2	353.9	0.06
102834	2N2	3.2	0.04
102834	OO1	193.4	0.02
102834	LDA2	146.6	0.01
102834	S1	123.4	0.02
102834	M1	245.9	0.02
102834	J1	203.7	0.02
102834	SA	148.7	0.21
102834	RHO1	199.9	0.01
102834	Q1	201.6	0.04
102834	T2	43.6	0.02
102834	R2	206.4	0.01
102834	2Q1	281.9	0.01
102834	P1	191.6	0.08
102834	2SM2	49.8	0.01
102834	M3	21.8	0.01
102834	L2	142.1	0.02
102834	2MK3	358.7	0.02
102834	K2	59.8	0.05
102834	MS4	15.8	0.01
102835	M2	60.1	1.06
102835	S2	73.8	0.2
102835	N2	37.6	0.26
102835	K1	178.9	0.24
102835	M4	344	0.07
102835	O1	208.1	0.15
102835	M6	194.2	0.05
102835	MK3	22.2	0.02
102835	S4	327.9	0.01
102835	MN4	309.3	0.04
102835	NU2	47	0.05
102835	S6	216.6	0.01
102835	MU2	344.3	0.04
102835	2N2	33.9	0.04
102835	OO1	186	0.01
102835	LDA2	130.9	0.02
102835	S1	91.6	0.04
102835	M1	205.5	0.02
102835	J1	242.9	0.03
102835	SSA	69.4	0.06
102835	SA	135.3	0.18
102835	RHO1	223.5	0.02
102835	Q1	192.7	0.04
102835	T2	65.6	0.02
102835	2Q1	130.2	0.01
102835	P1	199.6	0.08
102835	2SM2	35.4	0.01
102835	M3	45.8	0.01
102835	L2	86.4	0.02
102835	2MK3	355	0.02
102835	K2	68.9	0.05
102835	MS4	11.4	0.01
102836	M2	78	1.16
102836	S2	89.1	0.21
102836	N2	50	0.27
102836	K1	186.4	0.23
102836	M4	284.1	0.03
102836	O1	214.9	0.15
102836	M6	166.7	0.02
102836	MK3	0	0.02
102836	S4	330.4	0.01
102836	MN4	291.5	0.02
102836	NU2	59.1	0.05
102836	MU2	358.3	0.05
102836	2N2	9	0.05
102836	OO1	226.2	0.01
102836	LDA2	142	0.02
102836	S1	135.1	0.02
102836	M1	209.9	0.02
102836	SSA	50.9	0.11
102836	SA	135.1	0.23
102836	RHO1	193.8	0.02
102836	Q1	211.7	0.05
102836	T2	54.6	0.02
102836	R2	236.2	0.01
102836	2Q1	137	0.01
102836	P1	191.7	0.06
102836	2SM2	47.8	0.01
102836	M3	74.4	0.01
102836	L2	148.1	0.09
102836	2MK3	14.1	0.02
102836	K2	85.2	0.06
102836	M8	247	0.01
102836	MS4	232.9	0.01
102837	M2	73.6	1.22
102837	S2	84.7	0.22
102837	N2	44.6	0.29
102837	K1	180.5	0.25
102837	M4	12.1	0.04
102837	O1	212.7	0.17
102837	M6	237.1	0.02
102837	MN4	319.5	0.03
102837	NU2	55.6	0.05
102837	MU2	350.4	0.06
102837	2N2	16.1	0.04
102837	OO1	225.5	0.02
102837	LDA2	134.1	0.03
102837	S1	148.9	0.02
102837	M1	201.1	0.02
102837	J1	230.1	0.02
102837	SSA	50.9	0.11
102837	SA	135.1	0.23
102837	Q1	202.7	0.05
102837	T2	56.2	0.02
102837	2Q1	169.6	0.02
102837	P1	188.7	0.08
102837	M3	65.4	0.01
102837	L2	139.2	0.07
102837	2MK3	15.8	0.01
102837	K2	80.1	0.06
102838	M2	91.3	1.14
102838	S2	101.3	0.19
102838	N2	63.9	0.25
102838	K1	188.2	0.24
102838	M4	3.7	0.06
102838	O1	230.5	0.18
102838	M6	219.2	0.01
102838	NU2	67.5	0.05
102838	MU2	81.3	0.03
102838	2N2	36.5	0.03
102838	OO1	145.6	0.01
102838	LDA2	95.9	0.01
102838	M1	209.1	0.01
102838	J1	167.2	0.01
102838	SSA	50.9	0.11
102838	SA	135.1	0.23
102838	RHO1	248.8	0.01
102838	Q1	251.6	0.04
102838	T2	100.9	0.01
102838	P1	191.3	0.08
102838	L2	118.6	0.03
102838	K2	102.1	0.05
102838	M8	212.9	0.01
102839	M2	83.3	1.2
102839	S2	93.1	0.19
102839	N2	58.4	0.26
102839	K1	195.9	0.22
102839	M4	350.9	0.06
102839	O1	233	0.17
102839	M6	135.3	0.01
102839	S4	325.6	0.01
102839	NU2	61.7	0.05
102839	S6	201	0.01
102839	MU2	73.5	0.03
102839	2N2	33.5	0.03
102839	OO1	160	0.01
102839	LDA2	87.9	0.01
102839	M1	214.6	0.01
102839	J1	178.4	0.01
102839	SSA	69.4	0.06
102839	SA	135.3	0.18
102839	RHO1	248.7	0.01
102839	Q1	251.3	0.03
102839	T2	92.6	0.01
102839	P1	198.7	0.07
102839	L2	108	0.03
102839	K2	93.9	0.05
102839	M8	223.7	0.01
102840	M2	92.2	1.15
102840	S2	104.1	0.18
102840	N2	64.7	0.25
102840	K1	187.5	0.24
102840	M4	330	0.06
102840	O1	228	0.18
102840	M6	224.3	0.01
102840	NU2	68.4	0.05
102840	MU2	80.2	0.03
102840	2N2	37.2	0.03
102840	OO1	147	0.01
102840	LDA2	97.7	0.01
102840	M1	207.5	0.01
102840	J1	167.9	0.01
102840	SSA	50.9	0.11
102840	SA	135.1	0.23
102840	RHO1	245.3	0.01
102840	Q1	248	0.04
102840	T2	103.6	0.01
102840	P1	190.6	0.08
102840	L2	119.6	0.03
102840	K2	105.1	0.05
102840	M8	233.6	0.01
102841	M2	353.6	1.44
102841	S2	22.7	0.3
102841	N2	338.9	0.32
102841	K1	172	0.21
102841	M4	46	0.14
102841	O1	174.7	0.13
102841	M6	260	0.02
102841	S4	238.3	0.01
102841	NU2	340.9	0.06
102841	MU2	325	0.04
102841	2N2	324.2	0.04
102841	LDA2	7	0.01
102841	M1	173.5	0.01
102841	J1	171.3	0.01
102841	SSA	42.9	0.09
102841	SA	129.1	0.22
102841	Q1	175.6	0.02
102841	T2	21.6	0.02
102841	P1	172.2	0.07
102841	L2	8.3	0.04
102841	K2	25	0.08
102841	M8	353.1	0.01
102842	M2	7.8	1.35
102842	S2	38.4	0.27
102842	N2	355.9	0.3
102842	K1	181.7	0.22
102842	M4	329.1	0.04
102842	O1	185.9	0.16
102842	M6	333	0.02
102842	S4	311.7	0.01
102842	NU2	357.5	0.06
102842	MU2	337.3	0.03
102842	2N2	343.9	0.04
102842	OO1	179	0.01
102842	LDA2	22	0.01
102842	M1	184.2	0.01
102842	J1	180	0.01
102842	SSA	42.9	0.09
102842	SA	129.1	0.22
102842	RHO1	186	0.01
102842	Q1	187.3	0.03
102842	T2	37.1	0.02
102842	P1	182.1	0.07
102842	L2	19.7	0.04
102842	K2	40.9	0.07
102843	M2	113.9	2.48
102843	S2	136.6	0.42
102843	N2	90.7	0.5
102843	K1	196.7	0.27
102843	M4	223.7	0.02
102843	O1	220.5	0.17
102843	M6	349.9	0.08
102843	MK3	229.5	0.01
102843	MN4	194.2	0.01
102843	NU2	86.9	0.12
102843	2N2	71.4	0.02
102843	OO1	170	0.02
102843	LDA2	141.6	0.05
102843	S1	87.2	0.05
102843	M1	265.2	0.02
102843	SSA	61.2	0.1
102843	SA	138.2	0.28
102843	RHO1	201.2	0.02
102843	Q1	200.1	0.05
102843	T2	72	0.04
102843	R2	0.8	0.03
102843	P1	187.2	0.1
102843	L2	152.9	0.16
102843	K2	137.5	0.11
102844	M2	135.3	1.32
102844	S2	161.2	0.19
102844	N2	116.7	0.24
102844	K1	206.7	0.26
102844	M4	161.7	0.05
102844	O1	248.7	0.18
102844	M6	79.6	0.04
102844	S4	219.6	0.01
102844	NU2	119.2	0.05
102844	MU2	324.3	0.03
102844	2N2	98.1	0.03
102844	OO1	164.7	0.01
102844	LDA2	147.3	0.01
102844	M1	227.5	0.01
102844	J1	185.9	0.01
102844	RHO1	266.7	0.01
102844	Q1	269.5	0.04
102844	T2	160.2	0.01
102844	P1	209.9	0.09
102844	L2	153.9	0.04
102844	K2	163.3	0.05
102844	M8	72.3	0.01
102845	M2	48.9	1.11
102845	S2	66.3	0.2
102845	N2	37.6	0.23
102845	K1	202.8	0.23
102845	M4	38.1	0.13
102845	O1	211.4	0.12
102845	M6	110.7	0.03
102845	MK3	172.9	0.03
102845	S4	81.1	0.01
102845	MN4	27.4	0.06
102845	NU2	26	0.06
102845	MU2	112.9	0.06
102845	2N2	317.5	0.01
102845	OO1	243.7	0.01
102845	LDA2	44.4	0.03
102845	S1	184	0.02
102845	M1	236	0.01
102845	J1	288.1	0.01
102845	SSA	50.9	0.11
102845	SA	135.1	0.23
102845	RHO1	238.8	0.01
102845	Q1	222.6	0.04
102845	T2	80.1	0.04
102845	R2	83.5	0.06
102845	2Q1	230.6	0.01
102845	P1	211.7	0.06
102845	2SM2	257.2	0.01
102845	M3	189.8	0.01
102845	L2	10.1	0.07
102845	2MK3	94.5	0.02
102845	K2	65.6	0.06
102845	M8	111.6	0.01
102845	MS4	74.3	0.05
102846	M2	111.9	2.55
102846	S2	135.6	0.41
102846	N2	87.4	0.52
102846	K1	191.3	0.29
102846	M4	242.3	0.01
102846	O1	221.5	0.19
102846	M6	345.1	0.08
102846	MK3	224.1	0.01
102846	NU2	91.9	0.12
102846	MU2	305.9	0.01
102846	2N2	66.1	0.05
102846	OO1	203.8	0.01
102846	LDA2	143.2	0.06
102846	S1	125.4	0.02
102846	M1	222.5	0.01
102846	J1	223.7	0.02
102846	SSA	61.2	0.07
102846	SA	132	0.21
102846	RHO1	194.4	0.02
102846	Q1	213.4	0.04
102846	T2	108.3	0.04
102846	2Q1	274.5	0.01
102846	P1	205.5	0.09
102846	2SM2	107.2	0.01
102846	M3	203.7	0.01
102846	L2	156.7	0.14
102846	2MK3	211.4	0.01
102846	K2	136.4	0.11
102846	M8	97.5	0.01
102847	M2	36.4	0.85
102847	S2	69.7	0.14
102847	N2	27.3	0.18
102847	K1	210.8	0.16
102847	M4	24.7	0.04
102847	O1	212.7	0.13
102847	M6	146.4	0.02
102847	S4	9.5	0.01
102847	NU2	28.5	0.03
102847	MU2	3	0.02
102847	2N2	18.2	0.02
102847	OO1	205.8	0.01
102847	LDA2	51.9	0.01
102847	M1	212.2	0.01
102847	J1	209.9	0.01
102847	SSA	50.9	0.11
102847	SA	135.1	0.23
102847	Q1	213	0.03
102847	T2	68.1	0.01
102847	P1	211.1	0.06
102847	L2	45.4	0.02
102847	K2	72.4	0.04
102848	M2	351.1	1.36
102848	S2	18.4	0.27
102848	N2	332.6	0.3
102848	K1	168.8	0.2
102848	M4	87.3	0.12
102848	O1	168.4	0.12
102848	M6	190.8	0.02
102848	S4	264.2	0.01
102848	NU2	335.1	0.06
102848	MU2	323.8	0.03
102848	2N2	314.1	0.04
102848	LDA2	3.7	0.01
102848	M1	169.1	0.01
102848	J1	170.9	0.01
102848	SSA	50.9	0.11
102848	SA	135.1	0.23
102848	Q1	167.7	0.02
102848	T2	17.2	0.02
102848	P1	168.9	0.07
102848	L2	9.6	0.04
102848	K2	20.6	0.07
102848	M8	161.2	0.01
102849	M2	77.8	0.52
102849	S2	114.6	0.08
102849	N2	56.6	0.11
102849	K1	235.4	0.13
102849	M4	43.9	0.03
102849	O1	232	0.09
102849	M6	142.1	0.01
102849	MK3	183	0.02
102849	MN4	34.5	0.02
102849	NU2	71.3	0.03
102849	MU2	183.9	0.01
102849	2N2	11.9	0.02
102849	OO1	297.8	0.01
102849	LDA2	105.7	0.01
102849	S1	184.8	0.02
102849	M1	2.1	0.01
102849	J1	273.5	0.01
102849	SSA	50.9	0.11
102849	SA	135.1	0.23
102849	RHO1	174.8	0.01
102849	Q1	228.9	0.02
102849	R2	306.2	0.01
102849	P1	242.6	0.05
102849	2SM2	349.2	0.01
102849	L2	87.8	0.03
102849	2MK3	139.3	0.01
102849	K2	107.3	0.02
102849	M8	185.9	0.01
102849	MS4	84	0.01
102850	M2	104	0.49
102850	S2	135.7	0.07
102850	N2	82.2	0.09
102850	K1	251.2	0.12
102850	M4	143.2	0.03
102850	O1	248.4	0.08
102850	M6	323.3	0.02
102850	MK3	211.7	0.01
102850	MN4	109.5	0.01
102850	NU2	99.4	0.02
102850	MU2	212.2	0.01
102850	2N2	25.5	0.01
102850	LDA2	132	0.02
102850	S1	182.3	0.02
102850	M1	352.5	0.01
102850	J1	303.1	0.01
102850	RHO1	269	0.01
102850	Q1	264.8	0.02
102850	T2	84.5	0.01
102850	P1	255.3	0.03
102850	L2	100.5	0.03
102850	2MK3	147.1	0.01
102850	K2	139.3	0.02
102850	MS4	175.8	0.01
102851	M2	113	3.06
102851	S2	144.6	0.5
102851	N2	90.4	0.6
102851	K1	192.8	0.3
102851	M4	176.3	0.03
102851	O1	219.3	0.2
102851	M6	348.9	0.07
102851	MK3	220.8	0.02
102851	MN4	140	0.02
102851	NU2	93.6	0.11
102851	MU2	339.1	0.02
102851	2N2	60.3	0.03
102851	OO1	238.1	0.02
102851	LDA2	145.5	0.06
102851	S1	222.5	0.03
102851	M1	217	0.02
102851	J1	212.6	0.02
102851	SSA	61.2	0.07
102851	SA	132	0.21
102851	RHO1	164.3	0.03
102851	Q1	210.4	0.07
102851	T2	23.9	0.08
102851	2Q1	95.3	0.02
102851	P1	195.8	0.06
102851	2SM2	95.8	0.02
102851	M3	231.2	0.01
102851	L2	152.3	0.2
102851	2MK3	218.5	0.01
102851	K2	130.1	0.12
102851	M8	354.9	0.01
102852	M2	113.5	3.12
102852	S2	139.9	0.51
102852	N2	90.8	0.64
102852	K1	193.1	0.31
102852	M4	165.6	0.03
102852	O1	221.5	0.2
102852	M6	340.2	0.06
102852	MK3	207.9	0.02
102852	S4	143.6	0.01
102852	MN4	124.3	0.02
102852	NU2	93.4	0.15
102852	2N2	70.3	0.08
102852	OO1	232.1	0.02
102852	LDA2	137	0.07
102852	S1	132.7	0.03
102852	M1	244.2	0.02
102852	J1	235	0.02
102852	SSA	54.3	0.08
102852	SA	133.4	0.23
102852	RHO1	187	0.01
102852	Q1	213	0.06
102852	T2	111.3	0.05
102852	2Q1	195.9	0.01
102852	P1	205.7	0.09
102852	2SM2	68.4	0.01
102852	M3	193.1	0.01
102852	L2	139.6	0.17
102852	2MK3	205.7	0.02
102852	K2	140.1	0.14
102852	M8	357.3	0.01
102853	M2	82.5	0.54
102853	S2	106.2	0.07
102853	N2	60.4	0.1
102853	K1	236.2	0.14
102853	M4	110.2	0.02
102853	O1	244.1	0.11
102853	M6	219	0.01
102853	NU2	63.3	0.02
102853	MU2	58.8	0.01
102853	2N2	38.2	0.01
102853	M1	240.1	0.01
102853	J1	232.3	0.01
102853	SSA	42.9	0.09
102853	SA	129.1	0.22
102853	Q1	248	0.02
102853	P1	236.8	0.05
102853	L2	104.7	0.02
102853	K2	108.1	0.02
102854	M2	9	0.91
102854	S2	30.9	0.15
102854	N2	351.7	0.18
102854	K1	199	0.16
102854	M4	249.6	0.02
102854	O1	195.6	0.12
102854	S4	303.7	0.01
102854	NU2	354	0.04
102854	S6	138.3	0.01
102854	MU2	347	0.02
102854	2N2	334.4	0.02
102854	OO1	200.3	0.01
102854	LDA2	19.2	0.01
102854	M1	197.3	0.01
102854	J1	200	0.01
102854	SSA	42.9	0.09
102854	SA	129.1	0.22
102854	Q1	194.1	0.02
102854	T2	30	0.01
102854	P1	198.9	0.05
102854	L2	25.8	0.03
102854	K2	32.7	0.04
102855	M2	116	3.64
102855	S2	144.9	0.59
102855	N2	89.5	0.74
102855	K1	188.1	0.33
102855	M4	144.8	0.07
102855	O1	221.5	0.21
102855	M6	182.6	0.06
102855	S4	165.9	0.01
102855	NU2	93.1	0.14
102855	MU2	300.5	0.09
102855	2N2	63	0.1
102855	OO1	154.7	0.01
102855	LDA2	129.4	0.03
102855	M1	204.7	0.02
102855	J1	171.6	0.02
102855	SSA	61.2	0.07
102855	SA	132	0.21
102855	RHO1	235.8	0.01
102855	Q1	238	0.04
102855	T2	143.7	0.04
102855	2Q1	254.2	0.01
102855	P1	190.6	0.11
102855	L2	142.7	0.1
102855	K2	147.2	0.16
102855	M8	302.4	0.01
102856	M2	114.1	3.58
102856	S2	137.5	0.55
102856	N2	94.9	0.77
102856	K1	184.9	0.32
102856	M4	151.6	0.07
102856	O1	222.2	0.2
102856	M6	178.3	0.05
102856	MK3	190.5	0.03
102856	S4	173.9	0.01
102856	MN4	119.9	0.05
102856	NU2	83.6	0.16
102856	MU2	119	0.02
102856	2N2	52.8	0.09
102856	OO1	204.9	0.02
102856	LDA2	140.3	0.1
102856	S1	188.8	0.04
102856	M1	219	0.03
102856	J1	231.2	0.02
102856	SSA	61.2	0.07
102856	SA	132	0.21
102856	RHO1	214.6	0.01
102856	Q1	201.4	0.07
102856	T2	95.5	0.06
102856	R2	200.7	0.04
102856	2Q1	236.1	0.01
102856	P1	197.9	0.09
102856	2SM2	90.2	0.01
102856	M3	166.1	0.02
102856	L2	107.5	0.22
102856	2MK3	190	0.02
102856	K2	145.9	0.18
102856	M8	302.2	0.01
102856	MS4	187.1	0.01
102857	M2	114.7	3.51
102857	S2	148.8	0.55
102857	N2	87.4	0.69
102857	K1	186.7	0.31
102857	M4	147.9	0.07
102857	O1	220.9	0.21
102857	M6	168.4	0.05
102857	S4	139.9	0.01
102857	NU2	91	0.13
102857	MU2	293.8	0.09
102857	2N2	60	0.09
102857	OO1	152.6	0.01
102857	LDA2	130.5	0.02
102857	M1	203.7	0.02
102857	J1	169.8	0.02
102857	SSA	61.2	0.07
102857	SA	132	0.21
102857	RHO1	235.4	0.01
102857	Q1	237.8	0.04
102857	T2	147.4	0.03
102857	2Q1	254.7	0.01
102857	P1	189.3	0.1
102857	L2	141.9	0.1
102857	K2	151.5	0.15
102857	M8	303	0.01
102858	M2	115.8	3.74
102858	S2	144.5	0.62
102858	N2	90.3	0.76
102858	K1	188	0.33
102858	M4	146.9	0.08
102858	O1	221.1	0.21
102858	M6	173.2	0.11
102858	S4	148.8	0.01
102858	NU2	93.7	0.15
102858	MU2	300.1	0.09
102858	2N2	64.7	0.1
102858	OO1	155	0.01
102858	LDA2	129.1	0.03
102858	M1	204.4	0.02
102858	J1	171.6	0.02
102858	SSA	60.1	0.08
102858	SA	135.5	0.21
102858	RHO1	235.3	0.01
102858	Q1	237.6	0.04
102858	T2	143.4	0.04
102858	2Q1	254	0.01
102858	P1	190.5	0.11
102858	L2	141.4	0.1
102858	K2	146.9	0.17
102858	M8	279.7	0.01
102859	M2	20.8	1.41
102859	S2	56.1	0.25
102859	N2	6.9	0.27
102859	K1	198.5	0.21
102859	M4	246.5	0.02
102859	O1	187.4	0.16
102859	M6	97.2	0.05
102859	S4	2.9	0.02
102859	NU2	8.8	0.05
102859	S6	240.6	0.01
102859	MU2	345.3	0.03
102859	2N2	353.2	0.04
102859	OO1	209.7	0.01
102859	LDA2	37.4	0.01
102859	M1	193.1	0.01
102859	J1	204.1	0.01
102859	SSA	42.9	0.09
102859	SA	129.1	0.22
102859	RHO1	182.8	0.01
102859	Q1	181.9	0.03
102859	T2	54.7	0.01
102859	P1	197.7	0.07
102859	L2	34.8	0.04
102859	K2	59	0.07
102860	M2	116.9	3.79
102860	S2	147.3	0.62
102860	N2	91	0.78
102860	K1	188.8	0.33
102860	M4	167.7	0.1
102860	O1	220.3	0.22
102860	M6	184	0.12
102860	S4	162.6	0.01
102860	NU2	94.5	0.15
102860	MU2	299.5	0.09
102860	2N2	65	0.1
102860	OO1	157.2	0.01
102860	LDA2	131	0.03
102860	M1	204.4	0.02
102860	J1	173.1	0.02
102860	SSA	60.1	0.08
102860	SA	135.5	0.21
102860	RHO1	233.9	0.01
102860	Q1	236	0.04
102860	T2	146.1	0.04
102860	R2	148.4	0.01
102860	2Q1	251.7	0.01
102860	P1	191.1	0.11
102860	L2	143	0.1
102860	K2	149.8	0.17
102860	M8	258.9	0.02
102861	M2	2.4	1.95
102861	S2	31.1	0.32
102861	N2	349.9	0.42
102861	K1	172.3	0.35
102861	M4	50.6	0.01
102861	O1	180.2	0.15
102861	M6	29.8	0.05
102861	S4	75.9	0.01
102861	NU2	351.5	0.08
102861	MU2	333.7	0.05
102861	2N2	337.3	0.06
102861	OO1	164	0.01
102861	LDA2	15.8	0.01
102861	M1	176.2	0.01
102861	J1	168.2	0.01
102861	SSA	42.9	0.09
102861	SA	129.1	0.22
102861	RHO1	184.1	0.01
102861	Q1	184.2	0.03
102861	T2	30	0.02
102861	P1	172.8	0.11
102861	L2	14.9	0.06
102861	K2	33.4	0.09
102862	M2	11.8	2.02
102862	S2	45.6	0.34
102862	N2	2.2	0.43
102862	K1	177.2	0.35
102862	M4	269.8	0.09
102862	O1	186.7	0.18
102862	M6	79.9	0.08
102862	S4	88.1	0.01
102862	NU2	3.5	0.08
102862	S6	32.1	0.01
102862	MU2	337.9	0.05
102862	2N2	352.7	0.06
102862	OO1	167.9	0.01
102862	LDA2	27.4	0.01
102862	M1	181.9	0.01
102862	J1	172.5	0.01
102862	SSA	42.9	0.09
102862	SA	129.1	0.22
102862	RHO1	191.5	0.01
102862	Q1	191.5	0.03
102862	T2	44.3	0.02
102862	P1	178	0.11
102862	L2	21.3	0.06
102862	K2	48.3	0.1
102862	M8	320.3	0.01
102863	M2	115.6	3.83
102863	S2	141.3	0.59
102863	N2	95.1	0.76
102863	K1	186.8	0.33
102863	M4	143.2	0.1
102863	O1	229.1	0.25
102863	M6	168.4	0.19
102863	S4	169.1	0.01
102863	NU2	97.9	0.15
102863	S6	246.8	0.01
102863	MU2	90	0.09
102863	2N2	74.6	0.1
102863	OO1	144.3	0.01
102863	LDA2	127.6	0.03
102863	M1	208	0.02
102863	J1	165.6	0.02
102863	SSA	60.1	0.08
102863	SA	135.5	0.21
102863	RHO1	247.3	0.01
102863	Q1	250.3	0.05
102863	T2	140.2	0.04
102863	2Q1	271.2	0.01
102863	P1	190	0.11
102863	L2	136.2	0.11
102863	K2	143.4	0.16
102863	M8	187.5	0.01
102864	M2	116.8	3.84
102864	S2	145.6	0.64
102864	N2	91.1	0.78
102864	K1	187.9	0.33
102864	M4	145.9	0.09
102864	O1	220.8	0.22
102864	M6	169	0.2
102864	S4	164.6	0.01
102864	NU2	94.5	0.15
102864	MU2	300.6	0.09
102864	2N2	65.4	0.1
102864	OO1	155.1	0.01
102864	LDA2	130.2	0.03
102864	M1	204.2	0.02
102864	J1	171.5	0.02
102864	SSA	60.1	0.08
102864	SA	135.5	0.21
102864	RHO1	235	0.01
102864	Q1	237.1	0.04
102864	T2	144.5	0.04
102864	R2	146.9	0.01
102864	2Q1	253.7	0.01
102864	P1	190.4	0.11
102864	L2	142.5	0.11
102864	K2	148	0.17
102864	M8	208.5	0.01
102865	M2	15.8	2.13
102865	S2	51.9	0.35
102865	N2	8.1	0.45
102865	K1	180.4	0.36
102865	M4	288.4	0.09
102865	O1	188.8	0.18
102865	M6	82.8	0.09
102865	S4	113.8	0.01
102865	NU2	9.2	0.09
102865	MU2	339.5	0.05
102865	2N2	0.5	0.06
102865	OO1	172.2	0.01
102865	LDA2	32.6	0.02
102865	M1	184.5	0.01
102865	J1	176.2	0.01
102865	SSA	42.9	0.09
102865	SA	129.1	0.22
102865	RHO1	193.2	0.01
102865	Q1	192.9	0.04
102865	T2	50.5	0.02
102865	P1	181.1	0.12
102865	L2	23.4	0.06
102865	K2	54.8	0.1
102865	M8	265.7	0.01
102866	M2	10.2	2
102866	S2	45.1	0.4
102866	N2	357.3	0.4
102866	K1	187.6	0.27
102866	M4	264.6	0.05
102866	O1	171.2	0.21
102866	M6	55.2	0.06
102866	S4	9	0.03
102866	NU2	359	0.08
102866	S6	233.8	0.02
102866	MU2	335.2	0.05
102866	2N2	344.5	0.05
102866	OO1	204.7	0.01
102866	LDA2	26.4	0.01
102866	M1	179.6	0.01
102866	J1	195.9	0.02
102866	SSA	42.9	0.09
102866	SA	129.1	0.22
102866	RHO1	164.1	0.01
102866	Q1	162.9	0.04
102866	T2	43.7	0.02
102866	P1	186.3	0.09
102866	L2	23.1	0.06
102866	K2	47.9	0.11
102866	M8	276	0.01
102867	M2	118.3	3.89
102867	S2	149	0.65
102867	N2	93.9	0.82
102867	K1	187.9	0.34
102867	M4	146.8	0.1
102867	O1	221.8	0.22
102867	M6	171.5	0.26
102867	NU2	97.1	0.16
102867	S6	213.1	0.01
102867	MU2	300.3	0.1
102867	2N2	69.5	0.11
102867	OO1	153.9	0.01
102867	LDA2	132.6	0.03
102867	M1	204.7	0.02
102867	J1	171.2	0.02
102867	SSA	60.1	0.08
102867	SA	135.5	0.21
102867	RHO1	236.4	0.01
102867	Q1	238.7	0.04
102867	T2	147.9	0.04
102867	R2	150.3	0.01
102867	2Q1	255.5	0.01
102867	P1	190.4	0.11
102867	L2	142.8	0.11
102867	K2	151.5	0.18
102867	M8	191.1	0.02
102868	M2	359.9	2.06
102868	S2	28.4	0.36
102868	N2	346.6	0.45
102868	K1	169.6	0.35
102868	M4	61	0.01
102868	O1	174.6	0.16
102868	M6	21.6	0.05
102868	S4	53.6	0.01
102868	NU2	348.4	0.09
102868	MU2	331.3	0.05
102868	2N2	333.3	0.06
102868	OO1	164.4	0.01
102868	LDA2	13.2	0.01
102868	M1	172	0.01
102868	J1	167.2	0.01
102868	SSA	42.9	0.09
102868	SA	129.1	0.22
102868	RHO1	177.2	0.01
102868	Q1	177	0.03
102868	T2	27.2	0.02
102868	P1	170	0.12
102868	L2	13.2	0.06
102868	K2	30.8	0.1
102869	M2	18.2	2.57
102869	S2	48.9	0.49
102869	N2	7.8	0.58
102869	K1	187.8	0.33
102869	M4	309.7	0.1
102869	O1	175.5	0.21
102869	M6	100.7	0.1
102869	S4	33.5	0.07
102869	NU2	9.2	0.11
102869	S6	342.4	0.01
102869	MU2	347.5	0.06
102869	2N2	357.4	0.08
102869	OO1	198.3	0.01
102869	LDA2	32.3	0.02
102869	M1	181.6	0.02
102869	J1	193.5	0.02
102869	SSA	42.9	0.09
102869	SA	129.1	0.09
102869	RHO1	171.6	0.01
102869	Q1	169.5	0.04
102869	T2	47.7	0.03
102869	P1	186.8	0.11
102869	L2	28.5	0.07
102869	K2	51.4	0.13
102869	M8	324.6	0.01
102870	M2	115.7	3.77
102870	S2	142.5	0.62
102870	N2	94.5	0.8
102870	K1	193	0.33
102870	M4	146.1	0.11
102870	O1	220.9	0.21
102870	M6	160.1	0.27
102870	MK3	206.1	0.03
102870	S4	159	0.01
102870	MN4	120.6	0.07
102870	NU2	94.7	0.17
102870	S6	190.1	0.01
102870	MU2	146	0.01
102870	2N2	77.7	0.1
102870	OO1	217.8	0.02
102870	LDA2	142.2	0.08
102870	S1	114.2	0.03
102870	M1	265.7	0.03
102870	J1	240.5	0.03
102870	SSA	74.3	0.11
102870	SA	142.8	0.32
102870	RHO1	203.7	0.01
102870	Q1	217.3	0.06
102870	T2	116.2	0.05
102870	R2	215.8	0.01
102870	2Q1	256.8	0.02
102870	P1	203.9	0.1
102870	2SM2	76.8	0.02
102870	M3	183	0.02
102870	L2	135.8	0.22
102870	2MK3	202.8	0.03
102870	K2	142.4	0.17
102870	M8	156.4	0.02
102870	MS4	163.1	0.03
102871	M2	116.2	3.62
102871	S2	142.2	0.6
102871	N2	94.3	0.73
102871	K1	193.1	0.32
102871	M4	147.3	0.12
102871	O1	220.7	0.21
102871	M6	160	0.25
102871	MK3	207.6	0.04
102871	S4	146.3	0.01
102871	MN4	121.9	0.07
102871	NU2	95	0.16
102871	MU2	96.1	0.01
102871	2N2	72.9	0.09
102871	OO1	232.3	0.02
102871	LDA2	139.5	0.08
102871	S1	116.2	0.03
102871	M1	263.1	0.02
102871	J1	235.8	0.02
102871	SSA	60.1	0.08
102871	SA	135.5	0.21
102871	RHO1	254.8	0.01
102871	Q1	206.2	0.06
102871	T2	117	0.06
102871	R2	143.3	0.01
102871	2Q1	224.2	0.01
102871	P1	206.1	0.1
102871	M3	216.7	0.02
102871	L2	140.9	0.17
102871	2MK3	215.6	0.03
102871	K2	141.3	0.18
102871	M8	150.3	0.02
102871	MS4	160.7	0.03
102872	M2	13.2	2.54
102872	S2	44.2	0.5
102872	N2	1	0.54
102872	K1	180.2	0.33
102872	M4	311.1	0.09
102872	O1	170.5	0.16
102872	M6	84.1	0.08
102872	MK3	106.9	0.04
102872	S4	59.3	0.03
102872	MN4	320.2	0.04
102872	NU2	349.5	0.11
102872	MU2	51.2	0.1
102872	2N2	4.7	0.07
102872	OO1	187	0.02
102872	LDA2	348.5	0.04
102872	S1	152.2	0.06
102872	M1	248	0.02
102872	J1	192.8	0.01
102872	SSA	42.9	0.09
102872	SA	129.1	0.22
102872	RHO1	172.1	0.01
102872	Q1	187.6	0.05
102872	T2	32.8	0.07
102872	R2	178.3	0.01
102872	2Q1	255.7	0.02
102872	P1	182.8	0.09
102872	M3	99.7	0.04
102872	L2	343.2	0.11
102872	2MK3	23	0.02
102872	K2	45	0.14
102872	MS4	269.3	0.03
102873	M2	15.4	2.58
102873	S2	48.2	0.45
102873	N2	3.5	0.55
102873	K1	180.9	0.33
102873	M4	303.1	0.09
102873	O1	172.7	0.16
102873	M6	91.7	0.1
102873	MK3	104	0.04
102873	S4	64.7	0.03
102873	MN4	313.9	0.04
102873	NU2	354.4	0.1
102873	MU2	53.6	0.1
102873	2N2	3.4	0.07
102873	OO1	164.1	0.02
102873	LDA2	341.9	0.05
102873	S1	151.5	0.08
102873	M1	247.8	0.02
102873	J1	187.1	0.01
102873	SSA	42.9	0.09
102873	SA	129.1	0.22
102873	RHO1	190.4	0.01
102873	Q1	193	0.05
102873	T2	39.3	0.04
102873	R2	44.8	0.04
102873	2Q1	255.2	0.02
102873	P1	182.2	0.09
102873	2SM2	182.1	0.01
102873	M3	105.2	0.04
102873	L2	347	0.13
102873	2MK3	21.5	0.02
102873	K2	49.7	0.17
102873	M8	312.4	0.01
102873	MS4	277.5	0.04
102874	M2	118.5	3.59
102874	S2	144.7	0.56
102874	N2	97.4	0.73
102874	K1	188.8	0.33
102874	M4	166.4	0.14
102874	O1	227.7	0.24
102874	M6	162.1	0.34
102874	S4	178.2	0.01
102874	NU2	100.2	0.14
102874	S6	224.6	0.01
102874	MU2	92.2	0.09
102874	2N2	76.3	0.1
102874	OO1	149.7	0.01
102874	LDA2	130.7	0.03
102874	M1	208	0.02
102874	J1	169	0.02
102874	SSA	60.1	0.08
102874	SA	135.5	0.21
102874	RHO1	244.4	0.01
102874	Q1	247.1	0.05
102874	T2	143.7	0.03
102874	2Q1	266.3	0.01
102874	P1	191.7	0.11
102874	L2	139.5	0.1
102874	K2	146.9	0.15
102874	M8	142.4	0.04
102875	M2	117.5	3.58
102875	S2	145.6	0.6
102875	N2	91.6	0.69
102875	K1	189.5	0.32
102875	M4	165.3	0.14
102875	O1	239	0.21
102875	M6	156.1	0.35
102875	NU2	95.1	0.13
102875	S6	272.2	0.01
102875	MU2	89.4	0.09
102875	2N2	65.7	0.09
102875	OO1	140	0.01
102875	LDA2	130.5	0.03
102875	M1	214	0.01
102875	J1	164.9	0.02
102875	SSA	60.1	0.08
102875	SA	135.5	0.21
102875	RHO1	260.2	0.01
102875	Q1	263.5	0.04
102875	T2	144.5	0.04
102875	2Q1	288.1	0.01
102875	P1	193.2	0.11
102875	L2	143.4	0.1
102875	K2	147.9	0.16
102875	M8	149	0.04
102876	M2	6.3	2.33
102876	S2	35.5	0.43
102876	N2	351.5	0.5
102876	K1	174.4	0.33
102876	M4	317.4	0.04
102876	O1	167.6	0.16
102876	M6	62.5	0.05
102876	MK3	95.7	0.02
102876	S4	38.1	0.02
102876	MN4	324.9	0.02
102876	NU2	345.3	0.1
102876	MU2	30.1	0.07
102876	2N2	344	0.06
102876	OO1	163.9	0.02
102876	LDA2	345.7	0.03
102876	S1	158.6	0.07
102876	M1	232.4	0.02
102876	J1	182.4	0.01
102876	SSA	42.9	0.09
102876	SA	129.1	0.22
102876	RHO1	188.9	0.01
102876	Q1	186.7	0.05
102876	T2	34.5	0.05
102876	R2	21.7	0.02
102876	2Q1	228.6	0.02
102876	P1	170.4	0.09
102876	2SM2	171	0.01
102876	M3	82.5	0.03
102876	L2	349.5	0.09
102876	2MK3	40.8	0.01
102876	K2	36.2	0.14
102876	M8	146.2	0.01
102876	MS4	204.2	0.02
102877	M2	24	2.14
102877	S2	42	0.42
102877	N2	359.5	0.54
102877	K1	191	0.35
102877	M4	184.3	0.05
102877	O1	172.7	0.21
102877	M6	167.2	0.1
102877	S4	349	0.06
102877	NU2	2.7	0.1
102877	S6	269.3	0.01
102877	MU2	218	0.05
102877	2N2	334.9	0.07
102877	OO1	209.3	0.01
102877	LDA2	32.4	0.02
102877	M1	181.9	0.02
102877	J1	200.1	0.02
102877	SSA	47.4	0.1
102877	SA	129.9	0.23
102877	RHO1	164.9	0.01
102877	Q1	163.6	0.04
102877	T2	41.3	0.03
102877	2Q1	154.6	0.01
102877	P1	189.6	0.12
102877	L2	48.6	0.06
102877	K2	43.5	0.11
102877	M8	284.8	0.02
102878	M2	113.9	3.73
102878	S2	140.8	0.62
102878	N2	91.1	0.72
102878	K1	192.6	0.32
102878	M4	134.5	0.1
102878	O1	217.6	0.22
102878	M6	164.1	0.16
102878	MK3	205.6	0.04
102878	S4	137.9	0.01
102878	MN4	115.3	0.05
102878	NU2	92	0.16
102878	MU2	263.7	0.02
102878	2N2	83.1	0.05
102878	OO1	231.6	0.02
102878	LDA2	144.1	0.08
102878	S1	144.1	0.03
102878	M1	221.7	0.01
102878	J1	205.2	0.02
102878	MM	313	0.16
102878	SSA	64.6	0.12
102878	SA	112.3	0.23
102878	MSF	278.5	0.07
102878	MF	257.4	0.04
102878	RHO1	157.7	0.02
102878	Q1	220.5	0.06
102878	T2	101.2	0.06
102878	R2	334.4	0.01
102878	2Q1	113.8	0.01
102878	P1	205.4	0.08
102878	2SM2	95	0.02
102878	M3	237	0.02
102878	L2	162.1	0.23
102878	2MK3	215.7	0.03
102878	K2	141	0.17
102878	M8	216	0.01
102878	MS4	142.8	0.02
102879	M2	117.2	3.78
102879	S2	143.8	0.59
102879	N2	96.5	0.76
102879	K1	189	0.34
102879	M4	145.3	0.13
102879	O1	227.2	0.24
102879	M6	162.3	0.29
102879	S4	169.9	0.01
102879	NU2	99.3	0.15
102879	S6	208.5	0.01
102879	MU2	90.6	0.09
102879	2N2	75.8	0.1
102879	OO1	150.4	0.01
102879	LDA2	129.6	0.03
102879	M1	207.8	0.02
102879	J1	169.7	0.02
102879	SSA	60.1	0.08
102879	SA	135.5	0.21
102879	RHO1	243.6	0.01
102879	Q1	246.2	0.05
102879	T2	142.8	0.04
102879	2Q1	265.3	0.01
102879	P1	191.8	0.11
102879	L2	137.9	0.1
102879	K2	146	0.16
102879	M8	147.7	0.02
102880	M2	116.5	3.3
102880	S2	141.4	0.54
102880	N2	91.6	0.71
102880	K1	194.4	0.33
102880	M4	171.7	0.12
102880	O1	218.2	0.22
102880	M6	160	0.31
102880	MK3	204.9	0.02
102880	S4	133.3	0.01
102880	MN4	139.5	0.07
102880	NU2	93.9	0.15
102880	S6	203.3	0.01
102880	MU2	26.2	0.02
102880	2N2	79.9	0.1
102880	OO1	235.3	0.02
102880	LDA2	137.1	0.07
102880	S1	127.9	0.03
102880	M1	207.8	0.02
102880	J1	260.3	0.03
102880	SSA	47.4	0.1
102880	SA	129.9	0.23
102880	RHO1	109.5	0.02
102880	Q1	211.5	0.05
102880	T2	99	0.04
102880	R2	140.3	0.01
102880	2Q1	81.8	0.02
102880	P1	211.9	0.1
102880	2SM2	83.8	0.01
102880	M3	172.1	0.03
102880	L2	154.6	0.18
102880	2MK3	212.2	0.02
102880	K2	142.1	0.15
102880	M8	163.4	0.03
102880	MS4	198.6	0.04
102881	M2	92.2	2.14
102881	S2	118.1	0.33
102881	N2	71	0.45
102881	K1	185.7	0.34
102881	M4	249.5	0.09
102881	O1	214	0.19
102881	M6	175.4	0.25
102881	S4	136.1	0.01
102881	NU2	73.9	0.09
102881	MU2	66.4	0.05
102881	2N2	49.8	0.06
102881	OO1	156.9	0.01
102881	LDA2	104.2	0.02
102881	M1	199.7	0.01
102881	J1	171.6	0.02
102881	SSA	47.4	0.1
102881	SA	129.9	0.23
102881	RHO1	226.2	0.01
102881	Q1	228.1	0.04
102881	T2	117	0.02
102881	2Q1	242.9	0.01
102881	P1	187.8	0.11
102881	L2	113.5	0.06
102881	K2	120.2	0.09
102881	M8	215.2	0.01
102882	M2	93.8	2.22
102882	S2	116.1	0.38
102882	N2	73.6	0.49
102882	K1	186.9	0.33
102882	M4	237.1	0.07
102882	O1	201.7	0.17
102882	M6	170.3	0.25
102882	MK3	146.3	0.01
102882	S4	65.2	0.01
102882	MN4	208.7	0.02
102882	NU2	64.8	0.1
102882	S6	218.3	0.01
102882	MU2	46.4	0.04
102882	2N2	42.5	0.07
102882	OO1	204.8	0.02
102882	LDA2	138.2	0.05
102882	S1	116.8	0.03
102882	M1	227.5	0.02
102882	J1	240.3	0.02
102882	MM	49.3	0.09
102882	SSA	76.2	0.19
102882	SA	127.2	0.34
102882	MSF	13.7	0.12
102882	MF	81.5	0.05
102882	RHO1	236	0.01
102882	Q1	209.3	0.05
102882	T2	89.4	0.04
102882	R2	300.3	0.01
102882	P1	204	0.1
102882	2SM2	79.8	0.01
102882	M3	126.8	0.01
102882	L2	94.2	0.11
102882	2MK3	135.7	0.01
102882	K2	118.9	0.1
102882	M8	223.1	0.01
102882	MS4	261.2	0.03
102883	M2	61.4	1.88
102883	S2	80.5	0.33
102883	N2	36.9	0.42
102883	K1	186.1	0.34
102883	M4	240.5	0.08
102883	O1	192.6	0.16
102883	M6	175.3	0.19
102883	S4	23	0.04
102883	NU2	40.2	0.08
102883	S6	261.9	0.01
102883	MU2	254.4	0.05
102883	2N2	12.5	0.06
102883	OO1	180.6	0.01
102883	LDA2	70.3	0.01
102883	M1	189.7	0.01
102883	J1	184.3	0.01
102883	SSA	47.4	0.1
102883	SA	129.9	0.23
102883	RHO1	195.4	0.01
102883	Q1	195.5	0.03
102883	T2	79.8	0.02
102883	P1	186.5	0.11
102883	L2	85.9	0.05
102883	K2	82	0.09
102883	M8	264.5	0.02
102884	M2	36.8	1.9
102884	S2	59.6	0.32
102884	N2	16.8	0.42
102884	K1	179.4	0.35
102884	M4	249.2	0.08
102884	O1	184.8	0.15
102884	M6	167.5	0.13
102884	S4	3.2	0.02
102884	NU2	19.5	0.08
102884	MU2	226	0.05
102884	2N2	356.9	0.06
102884	OO1	173.9	0.01
102884	LDA2	47.4	0.01
102884	M1	181.7	0.01
102884	J1	176.9	0.01
102884	SSA	47.4	0.1
102884	SA	129.9	0.23
102884	RHO1	187	0.01
102884	Q1	187.5	0.03
102884	T2	58.7	0.02
102884	P1	179.8	0.12
102884	L2	56.7	0.05
102884	K2	61.4	0.09
102884	M8	295.5	0.02
102885	M2	18.2	2.2
102885	S2	42.9	0.42
102885	N2	0.5	0.51
102885	K1	178.5	0.34
102885	M4	264.1	0.08
102885	O1	176.3	0.17
102885	M6	150.4	0.08
102885	MK3	69.5	0.03
102885	S4	20.8	0.04
102885	MN4	265.9	0.04
102885	NU2	359.7	0.09
102885	MU2	10	0.08
102885	2N2	347.7	0.07
102885	OO1	209.5	0.01
102885	LDA2	10.5	0.03
102885	S1	132.1	0.04
102885	M1	247.4	0.01
102885	J1	196.6	0.01
102885	SSA	55.3	0.1
102885	SA	144.6	0.31
102885	RHO1	143.9	0.01
102885	Q1	196.6	0.04
102885	T2	32.4	0.04
102885	R2	299.9	0.01
102885	2Q1	234.6	0.01
102885	P1	178.8	0.11
102885	2SM2	357.9	0.01
102885	M3	66.1	0.03
102885	L2	21	0.08
102885	2MK3	44.7	0.02
102885	K2	44.5	0.12
102885	M8	332.2	0.01
102885	MS4	258.9	0.05
102886	M2	42.8	1.88
102886	S2	70.8	0.3
102886	N2	24.4	0.4
102886	K1	195.4	0.31
102886	M4	272.4	0.1
102886	O1	201.9	0.12
102886	M6	185.9	0.07
102886	S4	141.2	0.01
102886	NU2	26.8	0.08
102886	MU2	14.7	0.05
102886	2N2	5.9	0.05
102886	OO1	189.9	0.01
102886	LDA2	55.8	0.01
102886	M1	198.6	0.01
102886	J1	192.1	0.01
102886	SSA	47.4	0.1
102886	SA	129.9	0.23
102886	Q1	205.2	0.02
102886	T2	69.7	0.02
102886	P1	195.9	0.1
102886	L2	61.2	0.05
102886	K2	73.1	0.08
102886	M8	80.2	0.02
102887	M2	46	1.77
102887	S2	71.5	0.34
102887	N2	23.6	0.38
102887	K1	192.3	0.27
102887	M4	263.5	0.06
102887	O1	199.4	0.13
102887	M6	190	0.08
102887	S4	43.3	0.02
102887	NU2	26.6	0.07
102887	2N2	1.2	0.05
102887	OO1	185.1	0.01
102887	LDA2	57.8	0.01
102887	M1	195.8	0.01
102887	J1	188.7	0.01
102887	RHO1	202.5	0.01
102887	Q1	202.8	0.03
102887	T2	71.4	0.02
102887	P1	192.2	0.09
102887	L2	68.4	0.05
102887	K2	71.4	0.09
102887	M8	62.7	0.01
102888	M2	47.6	1.79
102888	S2	74	0.33
102888	N2	23.4	0.4
102888	K1	189.5	0.27
102888	M4	279.3	0.06
102888	O1	190.8	0.13
102888	M6	189.6	0.07
102888	S4	14.6	0.01
102888	NU2	26.7	0.08
102888	MU2	21.2	0.04
102888	2N2	359.2	0.05
102888	OO1	188.2	0.01
102888	LDA2	59.9	0.01
102888	M1	190.2	0.01
102888	J1	188.9	0.01
102888	SSA	47.4	0.1
102888	SA	129.9	0.23
102888	Q1	191.5	0.03
102888	T2	73	0.02
102888	P1	189.6	0.09
102888	L2	71.8	0.05
102888	K2	76.1	0.09
102888	M8	78.4	0.01
102889	M2	94.8	1.52
102889	S2	118.9	0.27
102889	N2	73.1	0.29
102889	K1	238.6	0.27
102889	M4	106.2	0.09
102889	O1	235.8	0.15
102889	M6	26.3	0.05
102889	MK3	206.7	0.04
102889	S4	183.9	0.02
102889	MN4	96.5	0.04
102889	NU2	66.1	0.08
102889	MU2	236.7	0.02
102889	2N2	64.1	0.05
102889	OO1	297.9	0.01
102889	LDA2	109.9	0.04
102889	S1	212.3	0.06
102889	M1	28.6	0.02
102889	J1	84.9	0.01
102889	MM	186.6	0.02
102889	SSA	68.5	0.13
102889	SA	109.4	0.18
102889	MSF	37.7	0.08
102889	MF	204.3	0.08
102889	Q1	258.6	0.03
102889	T2	109.6	0.02
102889	R2	6.5	0.02
102889	P1	233.3	0.08
102889	2SM2	23.2	0.01
102889	M3	167.4	0.02
102889	L2	129.7	0.1
102889	2MK3	178.8	0.05
102889	K2	118.9	0.07
102889	M8	323.2	0.01
102889	MS4	96.8	0.02
102890	M2	124.7	1.51
102890	S2	148.3	0.24
102890	N2	104.5	0.3
102890	K1	244.7	0.37
102890	M4	145.5	0.07
102890	O1	265.7	0.19
102890	M6	111.9	0.06
102890	S4	318.8	0.01
102890	NU2	107.2	0.06
102890	MU2	101	0.04
102890	2N2	84.3	0.04
102890	OO1	223.9	0.01
102890	LDA2	135.7	0.01
102890	M1	255	0.01
102890	J1	234.5	0.02
102890	RHO1	274.5	0.01
102890	Q1	275.8	0.04
102890	T2	147.2	0.01
102890	P1	246.3	0.12
102890	L2	145	0.04
102890	K2	150.2	0.07
102891	M2	158.5	1.65
102891	S2	182.9	0.25
102891	N2	135.9	0.32
102891	K1	256	0.41
102891	M4	227.9	0.1
102891	O1	277.6	0.21
102891	M6	184.3	0.07
102891	S4	25.6	0.01
102891	NU2	139	0.06
102891	MU2	133.9	0.04
102891	2N2	113.3	0.04
102891	OO1	234.5	0.01
102891	LDA2	170.1	0.01
102891	M1	266.9	0.02
102891	J1	245.2	0.02
102891	RHO1	286.8	0.01
102891	Q1	288.4	0.04
102891	T2	181.9	0.01
102891	2Q1	298.6	0.01
102891	P1	257.6	0.13
102891	L2	181.2	0.05
102891	K2	184.9	0.07
102891	M8	163	0.01
102892	M2	183.5	1.79
102892	S2	208.7	0.29
102892	N2	159.7	0.36
102892	K1	272.4	0.38
102892	M4	263	0.16
102892	O1	270.2	0.2
102892	M6	245.4	0.07
102892	MK3	320.7	0.06
102892	S4	333.7	0.01
102892	MN4	243.1	0.07
102892	NU2	163.8	0.07
102892	MU2	19.5	0.02
102892	2N2	143.1	0.05
102892	LDA2	202.7	0.05
102892	S1	229.4	0.07
102892	M1	28.1	0.03
102892	J1	111.3	0.01
102892	SSA	62.5	0.12
102892	SA	139.4	0.21
102892	MSF	57.4	0.08
102892	RHO1	254.4	0.01
102892	Q1	294.6	0.04
102892	T2	198.4	0.03
102892	2Q1	300.2	0.01
102892	P1	270.4	0.11
102892	2SM2	121.2	0.01
102892	M3	278.2	0.03
102892	L2	209.3	0.1
102892	2MK3	293.2	0.06
102892	K2	213.1	0.09
102892	M8	351.6	0.01
102892	MS4	280.7	0.04
102893	M2	269.1	2.25
102893	S2	301.5	0.32
102893	N2	249.3	0.42
102893	K1	313.6	0.37
102893	M4	85.1	0.3
102893	O1	307.7	0.21
102893	M6	178	0.15
102893	MK3	98.7	0.1
102893	S4	139.4	0.01
102893	MN4	67.7	0.11
102893	NU2	241.7	0.08
102893	MU2	45.8	0.08
102893	2N2	209.7	0.04
102893	OO1	13.3	0.01
102893	LDA2	270.3	0.12
102893	S1	274.8	0.09
102893	M1	57.1	0.03
102893	J1	157.9	0.02
102893	SSA	78.5	0.31
102893	SA	21.7	0.39
102893	RHO1	255.8	0.01
102893	Q1	324.6	0.04
102893	T2	127.8	0.01
102893	2Q1	215.3	0.01
102893	P1	312.3	0.1
102893	2SM2	224.3	0.02
102893	M3	54.2	0.04
102893	L2	277.9	0.22
102893	2MK3	65.1	0.1
102893	K2	303.2	0.11
102893	M8	9.6	0.04
102893	MS4	111.2	0.09
102894	M2	9.5	2.18
102894	S2	36.1	0.42
102894	N2	350.1	0.48
102894	K1	177.9	0.38
102894	M4	267.9	0.07
102894	O1	174	0.15
102894	M6	109.6	0.06
102894	S4	356.5	0.04
102894	NU2	352.7	0.09
102894	MU2	342.9	0.05
102894	2N2	330.8	0.06
102894	OO1	179.5	0.01
102894	LDA2	21.9	0.02
102894	M1	175.9	0.01
102894	J1	177.5	0.01
102894	SSA	71.6	0.12
102894	SA	142.3	0.32
102894	RHO1	172.3	0.01
102894	Q1	172.7	0.03
102894	T2	35.1	0.02
102894	P1	177.7	0.12
102894	L2	28.9	0.06
102894	K2	38.3	0.11
102894	M8	307.7	0.01
102895	M2	8.8	2.19
102895	S2	33.8	0.37
102895	N2	353.5	0.49
102895	K1	170.2	0.36
102895	M4	245.9	0.08
102895	O1	177.5	0.16
102895	M6	117.6	0.05
102895	S4	92.1	0.02
102895	NU2	355.5	0.1
102895	MU2	343.7	0.05
102895	2N2	338.1	0.07
102895	OO1	162.8	0.01
102895	LDA2	20.4	0.02
102895	M1	173.6	0.01
102895	J1	166.5	0.01
102895	SSA	42.9	0.09
102895	SA	129.1	0.22
102895	RHO1	181.1	0.01
102895	Q1	181.1	0.03
102895	T2	32.7	0.02
102895	P1	170.8	0.12
102895	L2	24.1	0.06
102895	K2	35.8	0.1
102896	M2	4.6	2.35
102896	S2	32.4	0.4
102896	N2	350.9	0.51
102896	K1	168.2	0.37
102896	M4	250.4	0.1
102896	O1	175	0.18
102896	M6	91.9	0.09
102896	S4	81.7	0.02
102896	NU2	352.8	0.1
102896	S6	45.6	0.01
102896	MU2	336.7	0.06
102896	2N2	337.2	0.07
102896	OO1	161.8	0.01
102896	LDA2	17.6	0.02
102896	M1	171.7	0.01
102896	J1	164.9	0.01
102896	SSA	42.9	0.09
102896	SA	129.1	0.22
102896	RHO1	178.3	0.01
102896	Q1	178.3	0.04
102896	T2	31.4	0.02
102896	P1	168.8	0.12
102896	L2	18.3	0.07
102896	K2	34.7	0.11
102896	M8	43	0.01
102897	M2	18.1	2.38
102897	S2	46.4	0.45
102897	N2	1.7	0.54
102897	K1	179.4	0.33
102897	M4	275.2	0.11
102897	O1	178.4	0.16
102897	M6	164.1	0.08
102897	MK3	59.2	0.03
102897	S4	34.6	0.04
102897	MN4	271.8	0.05
102897	NU2	358.9	0.1
102897	MU2	29.6	0.09
102897	2N2	347.9	0.08
102897	OO1	226.5	0.01
102897	LDA2	357.1	0.03
102897	S1	140.9	0.04
102897	M1	238.7	0.01
102897	J1	197.9	0.02
102897	SA	132.5	0.31
102897	RHO1	192.2	0.01
102897	Q1	195.9	0.04
102897	T2	33.5	0.04
102897	2Q1	201.5	0.01
102897	P1	178.2	0.11
102897	M3	69.3	0.04
102897	L2	14.3	0.1
102897	2MK3	42.2	0.03
102897	K2	48.1	0.13
102897	M8	43.6	0.01
102897	MS4	268.7	0.07
102898	M2	24.6	2.46
102898	S2	56.8	0.46
102898	N2	8.9	0.53
102898	K1	185	0.34
102898	M4	303.1	0.11
102898	O1	183.9	0.17
102898	M6	184.7	0.07
102898	MK3	80.4	0.03
102898	S4	47.9	0.05
102898	MN4	310.1	0.05
102898	NU2	13.2	0.1
102898	S6	298.3	0.01
102898	MU2	53.9	0.1
102898	2N2	7.8	0.05
102898	OO1	239.8	0.02
102898	LDA2	359.5	0.05
102898	S1	131.8	0.06
102898	M1	222.6	0.02
102898	J1	204.5	0.02
102898	SA	132.5	0.31
102898	RHO1	255.5	0.01
102898	Q1	188.8	0.05
102898	T2	43.9	0.05
102898	R2	295.7	0.03
102898	2Q1	131.8	0.02
102898	P1	192.9	0.1
102898	2SM2	288.2	0.01
102898	M3	96.2	0.04
102898	L2	13.5	0.1
102898	2MK3	59.7	0.03
102898	K2	55.7	0.1
102898	MS4	289	0.06
102899	M2	10.9	2.5
102899	S2	41.9	0.47
102899	N2	355	0.56
102899	K1	179.1	0.39
102899	M4	275.1	0.1
102899	O1	169.3	0.17
102899	M6	117	0.1
102899	MK3	25.5	0.01
102899	S4	49.8	0.05
102899	MN4	278.7	0.05
102899	NU2	0.5	0.1
102899	MU2	37.9	0.1
102899	2N2	341.1	0.09
102899	OO1	221.3	0.01
102899	LDA2	352.9	0.05
102899	S1	106.7	0.13
102899	M1	162.2	0.01
102899	J1	215.8	0.03
102899	MM	339.1	0.06
102899	SSA	42.9	0.09
102899	SA	129.1	0.22
102899	MSF	233.5	0.06
102899	MF	219.2	0.09
102899	RHO1	154.6	0.01
102899	Q1	193.7	0.05
102899	T2	11	0.05
102899	R2	283.3	0.02
102899	2Q1	319	0.02
102899	P1	172.8	0.08
102899	2SM2	93.5	0.01
102899	M3	60.3	0.04
102899	L2	18.5	0.13
102899	2MK3	40.8	0.03
102899	K2	40.7	0.13
102899	M8	48.2	0.01
102899	MS4	255.8	0.06
102900	M2	11.7	2.41
102900	S2	45.2	0.49
102900	N2	359.8	0.55
102900	K1	172.1	0.36
102900	M4	261	0.09
102900	O1	180.9	0.19
102900	M6	128.7	0.09
102900	S4	63	0.02
102900	NU2	1.4	0.1
102900	MU2	338.2	0.06
102900	2N2	348	0.07
102900	OO1	161.6	0.01
102900	LDA2	27.2	0.02
102900	M1	176.2	0.01
102900	J1	166.8	0.02
102900	SSA	42.9	0.09
102900	SA	129.1	0.22
102900	RHO1	184.2	0.01
102900	Q1	185.5	0.04
102900	T2	43.9	0.03
102900	2Q1	191.4	0.01
102900	P1	172.8	0.12
102900	L2	23.5	0.07
102900	K2	47.9	0.13
102901	M2	10.9	2.37
102901	S2	39.3	0.44
102901	N2	354.6	0.5
102901	K1	181	0.43
102901	M4	297.1	0.12
102901	O1	175.7	0.18
102901	M6	113.3	0.1
102901	S4	3.5	0.06
102901	NU2	356.7	0.1
102901	MU2	193.9	0.06
102901	2N2	338.3	0.07
102901	OO1	183.7	0.01
102901	LDA2	24	0.02
102901	M1	177.8	0.01
102901	J1	181.7	0.01
102901	SSA	42.9	0.09
102901	SA	129.1	0.22
102901	RHO1	173.7	0.01
102901	Q1	173.6	0.04
102901	T2	38.2	0.03
102901	P1	180.8	0.14
102901	L2	26.8	0.07
102901	K2	41.6	0.12
102901	M8	43	0.02
102902	M2	11.3	2.47
102902	S2	39.1	0.51
102902	N2	358.4	0.57
102902	K1	176.9	0.35
102902	M4	283.8	0.11
102902	O1	174.4	0.2
102902	M6	126.4	0.11
102902	MK3	67.4	0.05
102902	S4	62.7	0.04
102902	MN4	288.9	0.06
102902	NU2	350.7	0.1
102902	MU2	31.3	0.09
102902	2N2	338.6	0.07
102902	OO1	265.9	0.01
102902	LDA2	347.7	0.05
102902	S1	166	0.04
102902	M1	176.4	0.03
102902	SSA	42.9	0.09
102902	SA	129.1	0.22
102902	RHO1	262.7	0.02
102902	Q1	190.8	0.03
102902	T2	27.2	0.06
102902	R2	147.3	0.02
102902	2Q1	235.6	0.02
102902	P1	168	0.1
102902	2SM2	103.8	0.02
102902	M3	60.4	0.04
102902	L2	342.8	0.15
102902	2MK3	9.3	0.04
102902	K2	49.7	0.15
102902	M8	57.1	0.01
102902	MS4	258.4	0.06
102903	M2	25.3	2.66
102903	S2	57.9	0.38
102903	N2	15.7	0.62
102903	K1	188.7	0.35
102903	M4	299.6	0.1
102903	O1	193.3	0.18
102903	M6	179.4	0.13
102903	MK3	53.5	0.05
102903	S4	92.9	0.03
102903	MN4	303.4	0.05
102903	NU2	4.6	0.08
102903	S6	132.5	0.01
102903	MU2	67.1	0.17
102903	2N2	14.5	0.05
102903	OO1	15.2	0.03
102903	LDA2	338.4	0.09
102903	S1	149.4	0.06
102903	M1	184.9	0.04
102903	J1	243.5	0.02
102903	SSA	42.9	0.09
102903	SA	129.1	0.22
102903	RHO1	275.4	0.02
102903	Q1	230.4	0.05
102903	T2	352.1	0.05
102903	R2	48	0.16
102903	2Q1	203.9	0.01
102903	P1	194.5	0.07
102903	2SM2	153.7	0.04
102903	M3	99.1	0.04
102903	L2	339.7	0.22
102903	2MK3	26.9	0.07
102903	K2	61	0.25
102903	M8	107.4	0.01
102903	MS4	280.6	0.1
102904	M2	14.9	2.55
102904	S2	47.6	0.51
102904	N2	3.5	0.58
102904	K1	180.2	0.36
102904	M4	292.5	0.14
102904	O1	184.4	0.18
102904	M6	137.9	0.12
102904	MK3	68.1	0.05
102904	S4	32.4	0.06
102904	MN4	290.9	0.06
102904	NU2	1.3	0.13
102904	S6	352.1	0.01
102904	MU2	45.8	0.11
102904	2N2	349.1	0.06
102904	OO1	254.9	0.02
102904	LDA2	354.2	0.07
102904	S1	156.1	0.05
102904	M1	188.9	0.03
102904	J1	322.9	0.01
102904	SSA	42.9	0.09
102904	SA	129.1	0.22
102904	RHO1	336.6	0.02
102904	Q1	170.5	0.04
102904	T2	44.2	0.07
102904	R2	262	0.03
102904	2Q1	156.1	0.02
102904	P1	176.1	0.09
102904	2SM2	156.6	0.02
102904	M3	70.9	0.04
102904	L2	345	0.14
102904	2MK3	14.7	0.05
102904	K2	43.2	0.15
102904	M8	81.3	0.01
102904	MS4	268.2	0.08
102905	M2	23.8	2.65
102905	S2	58.4	0.56
102905	N2	13.7	0.61
102905	K1	185	0.35
102905	M4	305.6	0.15
102905	O1	184.7	0.2
102905	M6	175.5	0.13
102905	MK3	82.7	0.06
102905	S4	93.8	0.05
102905	MN4	310.8	0.08
102905	NU2	4.9	0.09
102905	S6	96.9	0.01
102905	MU2	64.5	0.15
102905	2N2	2.5	0.07
102905	OO1	333.1	0.02
102905	LDA2	349.3	0.06
102905	S1	193.5	0.04
102905	M1	186.1	0.04
102905	J1	256.2	0.01
102905	SSA	69	0.09
102905	SA	129.1	0.22
102905	RHO1	279.7	0.02
102905	Q1	208.4	0.04
102905	T2	67.4	0.06
102905	R2	169	0.08
102905	2Q1	272.2	0.01
102905	P1	174.8	0.1
102905	2SM2	145.3	0.03
102905	M3	83.2	0.04
102905	L2	344.3	0.21
102905	2MK3	24.7	0.07
102905	K2	77.2	0.15
102905	M8	109.6	0.01
102905	MS4	289.5	0.1
102906	M2	5.6	2.23
102906	S2	32.4	0.43
102906	N2	350	0.51
102906	K1	173.9	0.34
102906	M4	255.8	0.05
102906	O1	172.1	0.17
102906	M6	83.6	0.05
102906	MK3	48.8	0.02
102906	S4	11	0.04
102906	MN4	268.5	0.02
102906	NU2	348.6	0.1
102906	MU2	12.9	0.08
102906	2N2	338.8	0.08
102906	OO1	205.1	0.01
102906	LDA2	342.8	0.03
102906	S1	129.3	0.03
102906	M1	235.1	0.02
102906	J1	193.6	0.02
102906	SSA	71.6	0.12
102906	SA	142.3	0.32
102906	Q1	189.6	0.04
102906	T2	20.1	0.04
102906	2Q1	229.2	0.01
102906	P1	174.1	0.11
102906	M3	55	0.03
102906	L2	356.7	0.09
102906	2MK3	23.6	0.02
102906	K2	32.5	0.12
102906	MS4	231.4	0.04
102907	M2	39.1	1.63
102907	S2	69.9	0.26
102907	N2	22.5	0.32
102907	K1	199.9	0.27
102907	M4	163.4	0.01
102907	O1	198.6	0.15
102907	M6	143.9	0.06
102907	MK3	128.1	0.01
102907	S4	51.6	0.01
102907	NU2	15.9	0.08
102907	MU2	101.1	0.04
102907	2N2	8	0.03
102907	OO1	194.6	0.01
102907	LDA2	30.3	0.04
102907	S1	209.8	0.03
102907	M1	294.3	0.01
102907	SSA	42.9	0.09
102907	SA	129.1	0.22
102907	RHO1	124.9	0.01
102907	Q1	206.8	0.04
102907	T2	63.4	0.03
102907	2Q1	251.6	0.01
102907	P1	200.3	0.07
102907	M3	127.8	0.02
102907	L2	42.4	0.1
102907	2MK3	68.7	0.02
102907	K2	70.1	0.08
102907	M8	312.5	0.01
102907	MS4	237.7	0.02
102908	M2	122.6	0.33
102908	S2	139.7	0.05
102908	N2	92.7	0.06
102908	K1	294	0.11
102908	M4	127.6	0.01
102908	O1	266.4	0.08
102908	M6	336.6	0.02
102908	NU2	96.2	0.01
102908	MU2	106.2	0.01
102908	2N2	63.3	0.01
102908	M1	280.2	0.01
102908	J1	306.5	0.01
102908	SSA	40	0.1
102908	SA	145.5	0.23
102908	Q1	252.7	0.02
102908	P1	291.8	0.04
102908	L2	152.3	0.01
102908	K2	140.4	0.01
102908	M8	13	0.01
102909	M2	91.2	0.3
102909	S2	108.2	0.04
102909	N2	73.5	0.06
102909	K1	262.7	0.11
102909	M4	54.6	0.01
102909	O1	250.9	0.08
102909	M6	249.5	0.02
102909	MN4	21.6	0.01
102909	NU2	71.8	0.01
102909	MU2	233.7	0.01
102909	OO1	233.5	0.01
102909	LDA2	105.2	0.01
102909	S1	244.5	0.02
102909	M1	8.9	0.01
102909	SSA	40	0.1
102909	SA	145.5	0.23
102909	Q1	274.8	0.01
102909	2Q1	297.6	0.01
102909	P1	258.5	0.04
102909	L2	106.9	0.03
102909	2MK3	100.4	0.01
102909	K2	134.5	0.01
102910	M2	2.9	1.12
102910	S2	27.2	0.21
102910	N2	347	0.25
102910	K1	183.3	0.22
102910	M4	297.2	0.03
102910	O1	178.1	0.13
102910	M6	74.3	0.03
102910	MK3	102.4	0.02
102910	S4	321.2	0.01
102910	MN4	288.9	0.02
102910	NU2	344.9	0.05
102910	MU2	2.7	0.03
102910	2N2	327	0.02
102910	OO1	215.6	0.01
102910	LDA2	0.1	0.02
102910	S1	123.5	0.01
102910	M1	212.1	0.01
102910	SSA	40	0.1
102910	SA	145.5	0.23
102910	RHO1	319.5	0.01
102910	Q1	178.5	0.03
102910	T2	357.2	0.02
102910	R2	249	0.01
102910	P1	187.6	0.07
102910	2SM2	96.9	0.01
102910	M3	42.7	0.02
102910	L2	8.4	0.07
102910	2MK3	84.9	0.01
102910	K2	29.2	0.05
102910	MS4	326.3	0.01
102911	M2	24.6	1.29
102911	S2	51.6	0.21
102911	N2	8.3	0.27
102911	K1	201.5	0.28
102911	M4	103.3	0.03
102911	O1	191.2	0.17
102911	M6	118	0.05
102911	MK3	102	0.01
102911	MN4	92.9	0.01
102911	NU2	3.6	0.06
102911	MU2	69.7	0.02
102911	2N2	355.8	0.03
102911	OO1	241.6	0.01
102911	LDA2	27.6	0.02
102911	S1	133.9	0.02
102911	M1	269.4	0.01
102911	J1	216.7	0.01
102911	SSA	60.7	0.13
102911	SA	149.5	0.32
102911	Q1	204.4	0.03
102911	T2	28.2	0.02
102911	2Q1	237.9	0.01
102911	P1	198.6	0.08
102911	M3	64	0.01
102911	L2	25.2	0.08
102911	2MK3	56.3	0.01
102911	K2	49.8	0.07
102911	M8	221.9	0.01
102911	MS4	131.6	0.01
102912	M2	72.9	1.76
102912	S2	120	0.26
102912	N2	65.8	0.34
102912	K1	237.8	0.34
102912	M4	4.1	0.16
102912	O1	227.1	0.28
102912	M6	267.4	0.08
102912	MK3	124	0.1
102912	S4	34.8	0.01
102912	MN4	352.1	0.07
102912	NU2	58.9	0.09
102912	MU2	153.3	0.13
102912	2N2	180.6	0.01
102912	OO1	261.4	0.03
102912	LDA2	78.6	0.1
102912	S1	192.9	0.02
102912	M1	280.2	0.02
102912	J1	302.2	0.01
102912	RHO1	228.7	0.01
102912	Q1	246.9	0.06
102912	T2	47.8	0.03
102912	R2	111.4	0.02
102912	2Q1	144.7	0.01
102912	P1	231.1	0.08
102912	2SM2	337.8	0.02
102912	M3	184.1	0.05
102912	L2	54	0.19
102912	2MK3	91.3	0.1
102912	K2	125.5	0.09
102912	M8	184.5	0.01
102912	MS4	44.1	0.05
102913	M2	355.5	1.91
102913	S2	20.1	0.38
102913	N2	337.3	0.45
102913	K1	181.3	0.36
102913	M4	180.1	0.03
102913	O1	167.4	0.24
102913	M6	74.8	0.02
102913	MK3	59.1	0.01
102913	S4	207.5	0.01
102913	MN4	157.5	0.02
102913	NU2	337	0.08
102913	S6	109.4	0.01
102913	MU2	344.1	0.07
102913	2N2	325.9	0.07
102913	OO1	185.5	0.01
102913	LDA2	359.7	0.01
102913	S1	107.2	0.02
102913	M1	183.6	0.01
102913	J1	172.6	0.02
102913	SSA	60.7	0.13
102913	SA	149.5	0.32
102913	RHO1	148.7	0.01
102913	Q1	165.8	0.05
102913	T2	359.8	0.03
102913	2Q1	166.5	0.01
102913	P1	179.1	0.11
102913	2SM2	5	0.01
102913	M3	41.3	0.02
102913	L2	354.6	0.06
102913	2MK3	20.7	0.01
102913	K2	18.3	0.1
102913	MS4	173.3	0.01
102914	M2	355.1	1.93
102914	S2	19.9	0.38
102914	N2	335.9	0.44
102914	K1	182.3	0.36
102914	M4	186	0.03
102914	O1	167.1	0.25
102914	M6	70.1	0.01
102914	MK3	90.6	0.01
102914	S4	232.6	0.01
102914	MN4	160.2	0.02
102914	NU2	336.9	0.09
102914	MU2	339.5	0.07
102914	2N2	317.9	0.06
102914	OO1	193.3	0.01
102914	LDA2	10.8	0.02
102914	S1	110.1	0.03
102914	M1	173.6	0.01
102914	J1	170.8	0.02
102914	SSA	39.8	0.09
102914	SA	132.9	0.25
102914	RHO1	181.3	0.01
102914	Q1	168.5	0.04
102914	T2	358.6	0.03
102914	R2	257.5	0.01
102914	2Q1	159.5	0.01
102914	P1	180.4	0.11
102914	2SM2	8.8	0.01
102914	M3	44.9	0.02
102914	L2	8.7	0.04
102914	2MK3	77.4	0.01
102914	K2	17.3	0.1
102914	MS4	163.3	0.01
102915	M2	35.8	1.74
102915	S2	72.9	0.28
102915	N2	24	0.34
102915	K1	213.6	0.39
102915	M4	309.1	0.07
102915	O1	195.8	0.27
102915	M6	158.2	0.06
102915	NU2	25.6	0.07
102915	MU2	209.5	0.04
102915	2N2	12.2	0.05
102915	OO1	231.2	0.01
102915	LDA2	53	0.01
102915	M1	204.7	0.02
102915	J1	222.3	0.02
102915	RHO1	188.1	0.01
102915	Q1	187	0.05
102915	T2	71.4	0.02
102915	2Q1	178.3	0.01
102915	P1	212.2	0.13
102915	L2	47.6	0.05
102915	K2	75.9	0.08
102915	M8	102.4	0.01
102916	M2	8.2	1.79
102916	S2	37.3	0.33
102916	N2	356.1	0.39
102916	K1	193.6	0.33
102916	M4	311.1	0.03
102916	O1	181.1	0.23
102916	M6	76.4	0.02
102916	S4	283.1	0.01
102916	NU2	357.7	0.08
102916	MU2	190.1	0.04
102916	2N2	343.8	0.05
102916	OO1	205.5	0.01
102916	LDA2	21.6	0.01
102916	M1	187.3	0.02
102916	J1	199.4	0.02
102916	SSA	40	0.1
102916	SA	145.5	0.23
102916	RHO1	175.7	0.01
102916	Q1	174.9	0.04
102916	T2	36.1	0.02
102916	2Q1	168.7	0.01
102916	P1	192.8	0.11
102916	L2	20.4	0.05
102916	K2	39.6	0.09
102916	M8	84.7	0.01
102917	M2	59.4	1.64
102917	S2	106	0.2
102917	N2	50.8	0.25
102917	K1	235.1	0.38
102917	M4	338.3	0.2
102917	O1	222.7	0.29
102917	M6	239.1	0.07
102917	NU2	51.9	0.05
102917	MU2	13.4	0.04
102917	2N2	42.3	0.03
102917	OO1	247.5	0.01
102917	LDA2	80.9	0.01
102917	M1	228.9	0.02
102917	J1	241.3	0.02
102917	RHO1	217.4	0.01
102917	Q1	216.5	0.06
102917	T2	105.9	0.01
102917	2Q1	210.3	0.01
102917	P1	235.1	0.13
102917	L2	67.9	0.05
102917	K2	106	0.06
102918	M2	51.6	2.62
102918	S2	84.4	0.41
102918	N2	35.9	0.54
102918	K1	211.8	0.36
102918	M4	350.8	0.1
102918	O1	199.9	0.27
102918	M6	183.8	0.07
102918	MK3	141.6	0.04
102918	S4	5.3	0.01
102918	MN4	333.8	0.05
102918	NU2	29	0.12
102918	MU2	118.7	0.07
102918	2N2	26.6	0.07
102918	LDA2	51.1	0.06
102918	S1	154.8	0.06
102918	M1	236.5	0.02
102918	J1	224.7	0.01
102918	SSA	47	0.15
102918	SA	148.1	0.31
102918	RHO1	170.8	0.01
102918	Q1	201.3	0.05
102918	T2	61.3	0.04
102918	R2	22.8	0.01
102918	2Q1	167.3	0.01
102918	P1	207.1	0.12
102918	M3	111.1	0.02
102918	L2	52.3	0.17
102918	2MK3	108.8	0.04
102918	K2	81.5	0.12
102918	M8	61.1	0.02
102918	MS4	31.1	0.03
102919	M2	8.5	1.87
102919	S2	37.1	0.33
102919	N2	354.1	0.4
102919	K1	194.2	0.34
102919	M4	162.2	0.04
102919	O1	178.8	0.27
102919	M6	45	0.01
102919	MK3	354.7	0.02
102919	S4	230.7	0.01
102919	MN4	154.7	0.03
102919	NU2	345.9	0.09
102919	MU2	26.3	0.06
102919	2N2	343.4	0.06
102919	LDA2	18.8	0.03
102919	S1	115.7	0.03
102919	J1	198.7	0.02
102919	SSA	40	0.1
102919	SA	145.5	0.23
102919	RHO1	213.3	0.02
102919	Q1	184.4	0.04
102919	T2	18.7	0.03
102919	P1	183.7	0.11
102919	2SM2	196.1	0.01
102919	M3	84.9	0.02
102919	L2	5.9	0.07
102919	2MK3	329.4	0.02
102919	K2	29.8	0.11
102919	MS4	177	0.02
102920	M2	8.9	1.9
102920	S2	38.1	0.38
102920	N2	351.8	0.4
102920	K1	197.4	0.33
102920	M4	154.6	0.03
102920	O1	180.6	0.26
102920	M6	39.6	0.02
102920	MK3	345.6	0.02
102920	S4	272	0.01
102920	MN4	149.9	0.02
102920	NU2	343.4	0.09
102920	MU2	27.7	0.05
102920	2N2	329.9	0.05
102920	OO1	154	0.02
102920	LDA2	10.5	0.03
102920	S1	143.4	0.06
102920	M1	227.7	0.02
102920	J1	175.4	0.02
102920	SSA	40	0.1
102920	SA	145.5	0.23
102920	Q1	199.3	0.04
102920	T2	43.5	0.07
102920	R2	199.5	0.04
102920	2Q1	148.8	0.02
102920	P1	196.3	0.1
102920	M3	74.4	0.02
102920	L2	8.6	0.08
102920	2MK3	344.7	0.02
102920	K2	33.7	0.08
102920	MS4	162.8	0.02
102921	M2	23.6	1.93
102921	S2	58.6	0.33
102921	N2	11.6	0.43
102921	K1	204.2	0.36
102921	M4	244.1	0.06
102921	O1	191.3	0.27
102921	M6	68.2	0.04
102921	MK3	27	0.04
102921	S4	298.6	0.01
102921	MN4	226	0.03
102921	NU2	0.1	0.08
102921	MU2	67.3	0.08
102921	2N2	7.7	0.06
102921	OO1	217.5	0.01
102921	LDA2	359.7	0.04
102921	S1	148	0.02
102921	M1	226.8	0.02
102921	J1	220.9	0.02
102921	SSA	60.7	0.13
102921	SA	149.5	0.32
102921	RHO1	168.6	0.01
102921	Q1	195.7	0.05
102921	T2	21.9	0.03
102921	2Q1	184	0.01
102921	P1	201.7	0.11
102921	M3	138.6	0.01
102921	L2	4.2	0.12
102921	2MK3	4.7	0.04
102921	K2	53.1	0.1
102921	M8	273.7	0.01
102921	MS4	265.6	0.02
102922	M2	1	2.05
102922	S2	22.8	0.42
102922	N2	343.6	0.49
102922	K1	185.6	0.37
102922	M4	166	0.03
102922	O1	172	0.28
102922	M6	255.7	0.02
102922	S4	237.5	0.01
102922	NU2	345.9	0.1
102922	MU2	338.5	0.05
102922	2N2	326.5	0.07
102922	OO1	199.9	0.01
102922	LDA2	11	0.01
102922	M1	178.9	0.02
102922	J1	192.7	0.02
102922	SSA	40	0.1
102922	SA	145.5	0.23
102922	RHO1	166	0.01
102922	Q1	165.1	0.05
102922	T2	21.9	0.03
102922	2Q1	158.1	0.01
102922	P1	184.6	0.12
102922	L2	17.9	0.06
102922	K2	24.6	0.11
102923	M2	28.6	2.29
102923	S2	56	0.4
102923	N2	8.8	0.5
102923	K1	200.2	0.34
102923	M4	102.2	0.04
102923	O1	186.8	0.27
102923	M6	25.4	0.03
102923	MK3	165.4	0.01
102923	MN4	104.9	0.01
102923	NU2	7	0.1
102923	MU2	44.7	0.04
102923	2N2	351.6	0.07
102923	OO1	226.3	0.01
102923	LDA2	44.2	0.03
102923	S1	162.6	0.02
102923	M1	200.6	0.01
102923	J1	198.1	0.02
102923	SSA	45.7	0.13
102923	SA	149.7	0.28
102923	RHO1	156.6	0.01
102923	Q1	179.4	0.05
102923	T2	28.6	0.03
102923	R2	314.1	0.01
102923	2Q1	122	0.01
102923	P1	197.3	0.11
102923	2SM2	55.7	0.01
102923	M3	98	0.02
102923	L2	43.7	0.12
102923	2MK3	111.4	0.01
102923	K2	55.1	0.11
102923	M8	205.8	0.01
102923	MS4	140.8	0.02
102924	M2	43.3	2.64
102924	S2	73.8	0.45
102924	N2	27.1	0.59
102924	K1	212	0.36
102924	M4	320	0.09
102924	O1	193.9	0.29
102924	M6	147.8	0.05
102924	S4	14.1	0.02
102924	NU2	29.2	0.11
102924	MU2	223.1	0.06
102924	2N2	10.8	0.08
102924	OO1	226.9	0.01
102924	LDA2	57.5	0.02
102924	M1	202.1	0.02
102924	J1	218.4	0.02
102924	SSA	40.3	0.1
102924	SA	147.7	0.19
102924	RHO1	186.9	0.01
102924	Q1	185.7	0.05
102924	T2	72.6	0.03
102924	2Q1	177.5	0.01
102924	P1	210.5	0.12
102924	L2	59.5	0.07
102924	K2	76.3	0.12
102924	M8	55.1	0.02
102925	M2	56.4	2.72
102925	S2	89.9	0.41
102925	N2	41.1	0.59
102925	K1	216.5	0.38
102925	M4	15.2	0.12
102925	O1	200.2	0.28
102925	M6	212.6	0.06
102925	NU2	43.1	0.11
102925	MU2	22.8	0.07
102925	2N2	25.8	0.08
102925	OO1	232.5	0.01
102925	LDA2	72	0.02
102925	M1	208.4	0.02
102925	J1	224.4	0.02
102925	SSA	40.3	0.1
102925	SA	147.7	0.19
102925	RHO1	193.4	0.01
102925	Q1	192.4	0.05
102925	T2	88.6	0.02
102925	2Q1	184.5	0.01
102925	P1	215.3	0.12
102925	L2	71.7	0.08
102925	K2	92.7	0.11
102925	M8	131.9	0.01
102926	M2	71.9	2.67
102926	S2	105.5	0.39
102926	N2	54.7	0.52
102926	K1	221	0.36
102926	M4	34.1	0.11
102926	O1	207.3	0.27
102926	M6	273.2	0.07
102926	MK3	167	0.04
102926	S4	74.6	0.01
102926	MN4	20.3	0.05
102926	NU2	52.2	0.13
102926	MU2	160.1	0.07
102926	2N2	39.2	0.07
102926	OO1	269	0.01
102926	LDA2	84.1	0.07
102926	S1	181.1	0.05
102926	M1	233.8	0.01
102926	J1	252.5	0.01
102926	SSA	54.1	0.17
102926	SA	140.4	0.37
102926	RHO1	173	0.01
102926	Q1	207	0.05
102926	T2	88	0.03
102926	R2	69.5	0.01
102926	2Q1	159.8	0.01
102926	P1	215.3	0.11
102926	M3	162.1	0.01
102926	L2	80	0.21
102926	2MK3	138.8	0.04
102926	K2	105.4	0.12
102926	M8	200.9	0.01
102926	MS4	90.6	0.03
102927	M2	173.3	2.41
102927	S2	209	0.3
102927	N2	164.4	0.33
102927	K1	280.1	0.33
102927	M4	233.3	0.29
102927	O1	248.8	0.23
102927	M6	216.9	0.16
102927	S4	282.8	0.02
102927	NU2	165.6	0.07
102927	S6	335.3	0.01
102927	MU2	137.3	0.06
102927	2N2	155.8	0.04
102927	OO1	309.9	0.01
102927	LDA2	189.9	0.02
102927	M1	264.5	0.02
102927	J1	295	0.02
102927	SSA	63	0.3
102927	SA	119.2	0.49
102927	RHO1	235.6	0.01
102927	Q1	233.9	0.04
102927	T2	207.5	0.02
102927	2Q1	223.4	0.01
102927	P1	277.7	0.11
102927	L2	182.1	0.07
102927	K2	211.8	0.08
102927	M8	285	0.06
102928	M2	200.5	2.91
102928	S2	241.6	0.33
102928	N2	187.5	0.5
102928	K1	291.2	0.32
102928	M4	302.8	0.26
102928	O1	269.8	0.26
102928	M6	272	0.16
102928	MK3	357.7	0.08
102928	S4	249.1	0.01
102928	MN4	286.9	0.1
102928	NU2	173.6	0.16
102928	MU2	317.6	0.17
102928	2N2	119.5	0.03
102928	OO1	54.3	0.01
102928	LDA2	205.1	0.1
102928	S1	240.8	0.08
102928	M1	325.5	0.04
102928	MM	49.1	0.17
102928	SSA	57.7	0.31
102928	SA	121.4	0.43
102928	MSF	31.1	0.11
102928	MF	89.8	0.05
102928	RHO1	154	0.02
102928	Q1	265.5	0.04
102928	T2	206.7	0.02
102928	2Q1	70.8	0.01
102928	P1	293.5	0.1
102928	2SM2	161.3	0.02
102928	M3	284.4	0.03
102928	L2	190	0.36
102928	2MK3	321.9	0.09
102928	K2	237.5	0.1
102928	M8	17.2	0.08
102928	MS4	344.9	0.06
102929	M2	214	3.28
102929	S2	260	0.37
102929	N2	198.3	0.53
102929	K1	295.8	0.36
102929	M4	338.4	0.38
102929	O1	278.4	0.27
102929	M6	347.8	0.1
102929	MK3	21.2	0.1
102929	MN4	321	0.13
102929	NU2	192.6	0.18
102929	MU2	329.4	0.19
102929	2N2	182.1	0.06
102929	OO1	343	0.02
102929	LDA2	224.4	0.11
102929	S1	236.4	0.07
102929	M1	298.5	0.01
102929	J1	356.6	0.01
102929	MM	40.3	0.12
102929	SSA	59.1	0.17
102929	SA	122.5	0.3
102929	MSF	37.5	0.11
102929	RHO1	244.1	0.02
102929	Q1	285.1	0.04
102929	T2	235.6	0.03
102929	R2	264.7	0.01
102929	P1	285.4	0.11
102929	2SM2	140.6	0.01
102929	M3	330	0.01
102929	L2	226.2	0.38
102929	2MK3	342.7	0.11
102929	K2	258.2	0.12
102929	M8	68.6	0.04
102929	MS4	27.8	0.1
102930	M2	220.2	3.27
102930	S2	254.2	0.43
102930	N2	190	0.59
102930	K1	280.3	0.23
102930	M4	358.5	0.52
102930	O1	257.6	0.22
102930	M6	47.4	0.15
102930	S4	84.5	0.11
102930	NU2	194	0.11
102930	S6	123.1	0.03
102930	MU2	37.7	0.08
102930	2N2	159.8	0.08
102930	OO1	301.8	0.01
102930	LDA2	235.5	0.02
102930	M1	268.8	0.02
102930	J1	290.6	0.02
102930	SSA	91.1	0.24
102930	SA	139.4	0.35
102930	RHO1	248.2	0.01
102930	Q1	246.7	0.04
102930	T2	252.8	0.03
102930	2Q1	236.1	0.01
102930	P1	278.6	0.08
102930	L2	251	0.09
102930	K2	256.9	0.11
102930	M8	173.8	0.08
102931	M2	220.3	3.67
102931	S2	266.4	0.46
102931	N2	203.2	0.58
102931	K1	297.9	0.36
102931	M4	357.3	0.57
102931	O1	279.4	0.28
102931	M6	39.1	0.3
102931	MK3	28.9	0.12
102931	S4	78.3	0.01
102931	MN4	340.1	0.2
102931	NU2	198	0.2
102931	MU2	330.4	0.23
102931	2N2	194.2	0.07
102931	OO1	3.6	0.01
102931	LDA2	229.5	0.13
102931	S1	230.6	0.08
102931	M1	115.2	0.01
102931	J1	303.3	0.01
102931	SSA	66.3	0.19
102931	SA	88	0.33
102931	RHO1	277.5	0.01
102931	Q1	297.5	0.04
102931	T2	262.3	0.03
102931	2Q1	268.2	0.01
102931	P1	296.6	0.1
102931	2SM2	121.1	0.02
102931	M3	91.1	0.04
102931	L2	236	0.36
102931	2MK3	355.4	0.14
102931	K2	268.3	0.13
102931	M8	173	0.14
102931	MS4	47.2	0.15
102932	M2	146	2.55
102932	S2	181.5	0.32
102932	N2	130.2	0.44
102932	K1	261.8	0.33
102932	M4	195	0.3
102932	O1	246	0.28
102932	M6	156.2	0.12
102932	MK3	277.3	0.07
102932	S4	229.4	0.01
102932	MN4	178.9	0.11
102932	NU2	121.9	0.14
102932	MU2	263.3	0.11
102932	2N2	125	0.05
102932	OO1	254.2	0.01
102932	LDA2	154.7	0.08
102932	S1	208	0.07
102932	M1	337.3	0.01
102932	J1	242.1	0.01
102932	MM	58	0.12
102932	SSA	56.5	0.18
102932	SA	127.7	0.38
102932	MSF	33.5	0.11
102932	RHO1	196.5	0.02
102932	Q1	267.8	0.03
102932	T2	166.7	0.02
102932	P1	252.8	0.1
102932	2SM2	6.4	0.01
102932	M3	237.7	0.01
102932	L2	158.4	0.25
102932	2MK3	242.3	0.07
102932	K2	182	0.09
102932	M8	186.3	0.04
102932	MS4	240.1	0.09
102933	M2	184.2	2.71
102933	S2	224.3	0.3
102933	N2	166.5	0.45
102933	K1	281.1	0.34
102933	M4	252.5	0.27
102933	O1	264.9	0.26
102933	M6	246.2	0.16
102933	MK3	331.1	0.08
102933	MN4	235.9	0.1
102933	NU2	163.5	0.15
102933	MU2	305.5	0.14
102933	2N2	151.2	0.05
102933	OO1	323	0.02
102933	LDA2	196.8	0.09
102933	S1	236.5	0.06
102933	M1	291.3	0.01
102933	J1	340.7	0.01
102933	MM	37.8	0.1
102933	SSA	52.4	0.16
102933	SA	126.7	0.37
102933	MSF	20.6	0.1
102933	RHO1	229.5	0.02
102933	Q1	271.5	0.04
102933	T2	211.2	0.03
102933	R2	197.3	0.01
102933	P1	273.5	0.1
102933	2SM2	105.4	0.01
102933	M3	287.7	0.01
102933	L2	198.9	0.3
102933	2MK3	294.8	0.08
102933	K2	223	0.1
102933	M8	327	0.05
102933	MS4	300.6	0.07
102934	M2	195.1	2.71
102934	S2	235.1	0.31
102934	N2	175.8	0.43
102934	K1	289.7	0.34
102934	M4	286	0.36
102934	O1	273.2	0.25
102934	M6	289.8	0.16
102934	MK3	351.6	0.04
102934	MN4	271	0.14
102934	NU2	171.3	0.16
102934	MU2	312.2	0.12
102934	2N2	147.6	0.09
102934	OO1	306.2	0.01
102934	LDA2	198	0.08
102934	S1	233.8	0.06
102934	M1	281.4	0.02
102934	J1	298	0.02
102934	MM	66.2	0.14
102934	SSA	62.3	0.16
102934	SA	110.2	0.28
102934	MSF	15.1	0.2
102934	MF	2.4	0.12
102934	Q1	299.9	0.04
102934	T2	235	0.02
102934	R2	170	0.05
102934	P1	277.3	0.1
102934	L2	209.5	0.21
102934	2MK3	312.8	0.08
102934	K2	238	0.08
102934	M8	22.8	0.06
102934	MS4	339	0.11
102935	M2	193.6	2.82
102935	S2	236.3	0.32
102935	N2	176.3	0.47
102935	K1	285.3	0.34
102935	M4	276.8	0.24
102935	O1	269	0.26
102935	M6	261.6	0.16
102935	MK3	346.4	0.08
102935	MN4	259	0.09
102935	NU2	172.5	0.16
102935	MU2	313.9	0.15
102935	2N2	160.3	0.05
102935	OO1	334	0.01
102935	LDA2	205.7	0.09
102935	S1	232.2	0.07
102935	M1	289.6	0.01
102935	J1	340.9	0.01
102935	MM	37.8	0.1
102935	SSA	52.4	0.16
102935	SA	126.7	0.37
102935	MSF	20.6	0.1
102935	RHO1	234.1	0.02
102935	Q1	275.5	0.04
102935	T2	221.7	0.02
102935	R2	206.9	0.01
102935	P1	276.7	0.1
102935	2SM2	115.3	0.01
102935	M3	295.2	0.01
102935	L2	207.8	0.31
102935	2MK3	309.5	0.08
102935	K2	233.6	0.1
102935	M8	355.8	0.06
102935	MS4	323.4	0.07
102936	M2	218.7	3.54
102936	S2	264.8	0.39
102936	N2	203.3	0.58
102936	K1	297.3	0.37
102936	M4	347.1	0.49
102936	O1	280.4	0.28
102936	M6	29.8	0.21
102936	MK3	26.2	0.12
102936	MN4	330.5	0.17
102936	NU2	196.9	0.2
102936	MU2	332.4	0.21
102936	2N2	188.8	0.06
102936	OO1	344.1	0.02
102936	LDA2	228.9	0.12
102936	S1	245.1	0.06
102936	M1	305.3	0.01
102936	J1	2.8	0.02
102936	MM	45.5	0.12
102936	SSA	52.4	0.2
102936	SA	110	0.29
102936	MSF	25.8	0.1
102936	RHO1	244.6	0.02
102936	Q1	287.3	0.05
102936	T2	235.9	0.03
102936	R2	256.8	0.01
102936	P1	286.4	0.12
102936	2SM2	154.5	0.01
102936	L2	230.8	0.41
102936	2MK3	348.3	0.13
102936	K2	263.4	0.12
102936	M8	151.9	0.08
102936	MS4	39.9	0.12
102937	M2	113.6	2.52
102937	S2	148.8	0.32
102937	N2	96.7	0.45
102937	K1	245.3	0.33
102937	M4	140.1	0.21
102937	O1	231.3	0.26
102937	M6	59.1	0.11
102937	MK3	235.9	0.06
102937	S4	148.9	0.01
102937	MN4	122.3	0.08
102937	NU2	93.8	0.13
102937	MU2	224.2	0.1
102937	2N2	82.1	0.05
102937	OO1	292.9	0.01
102937	LDA2	126.1	0.07
102937	S1	201.1	0.06
102937	M1	253.7	0.01
102937	J1	297.5	0.01
102937	MM	42.7	0.1
102937	SSA	60.1	0.18
102937	SA	135.5	0.42
102937	MSF	28	0.07
102937	RHO1	201.1	0.01
102937	Q1	234.3	0.05
102937	T2	132.3	0.02
102937	R2	117.8	0.01
102937	2Q1	196.1	0.01
102937	P1	238.9	0.1
102937	2SM2	17	0.01
102937	M3	215.7	0.01
102937	L2	126.3	0.24
102937	2MK3	196.8	0.06
102937	K2	147.9	0.1
102937	M8	64.3	0.02
102937	MS4	184.9	0.06
102938	M2	108.4	2.5
102938	S2	144.3	0.32
102938	N2	91.5	0.44
102938	K1	244	0.3
102938	M4	126.2	0.17
102938	O1	225.1	0.22
102938	M6	51.6	0.1
102938	MK3	218.1	0.06
102938	S4	165.6	0.01
102938	MN4	108.2	0.07
102938	NU2	88.8	0.13
102938	MU2	219.4	0.1
102938	2N2	77.5	0.06
102938	OO1	303.7	0.01
102938	LDA2	119.5	0.07
102938	S1	199.2	0.07
102938	J1	322.5	0.01
102938	MM	49.7	0.08
102938	SSA	48.4	0.16
102938	SA	128.7	0.41
102938	RHO1	173.7	0.01
102938	Q1	234.7	0.04
102938	T2	123.6	0.02
102938	R2	140.3	0.01
102938	P1	240	0.09
102938	M3	206.6	0.01
102938	L2	121.6	0.24
102938	2MK3	184.8	0.06
102938	K2	143.7	0.11
102938	M8	32	0.02
102938	MS4	174.2	0.05
102939	M2	62.6	2.55
102939	S2	92.7	0.47
102939	N2	47.5	0.52
102939	K1	219	0.35
102939	M4	29.3	0.11
102939	O1	200.8	0.29
102939	M6	214	0.05
102939	MK3	178.6	0.04
102939	S4	12.7	0.01
102939	MN4	10.4	0.05
102939	NU2	41.5	0.11
102939	MU2	118.4	0.05
102939	2N2	30.3	0.07
102939	OO1	231.1	0.01
102939	LDA2	70.1	0.05
102939	S1	194.2	0.05
102939	M1	269.7	0.01
102939	J1	197.8	0.02
102939	SSA	41.3	0.1
102939	SA	140.5	0.17
102939	RHO1	253	0.01
102939	Q1	212.9	0.04
102939	T2	42.9	0.04
102939	2Q1	155.8	0.02
102939	P1	214	0.06
102939	2SM2	345.6	0.01
102939	M3	146.6	0.02
102939	L2	71	0.16
102939	2MK3	132.2	0.04
102939	K2	86.8	0.15
102939	M8	127	0.01
102939	MS4	75.6	0.03
102940	M2	37.4	2.31
102940	S2	64.7	0.39
102940	N2	17.1	0.51
102940	K1	202.7	0.35
102940	M4	142.6	0.02
102940	O1	190.5	0.27
102940	M6	53.6	0.01
102940	MK3	153.3	0.01
102940	S4	298.7	0.01
102940	MN4	159.6	0.01
102940	NU2	17.4	0.1
102940	MU2	55.9	0.03
102940	2N2	7.5	0.07
102940	OO1	198.6	0.01
102940	LDA2	55.3	0.03
102940	S1	150.5	0.03
102940	M1	190	0.02
102940	J1	201	0.02
102940	SSA	45.7	0.13
102940	SA	149.7	0.28
102940	RHO1	181	0.01
102940	Q1	184.2	0.05
102940	T2	34.6	0.04
102940	R2	293.4	0.01
102940	2Q1	164.7	0.01
102940	P1	199.8	0.11
102940	2SM2	35.1	0.01
102940	M3	95.1	0.02
102940	L2	54	0.14
102940	2MK3	108.4	0.02
102940	K2	63.1	0.11
102940	MS4	171	0.01
102941	M2	31.2	1.93
102941	S2	57.2	0.34
102941	N2	9.3	0.43
102941	K1	202.2	0.33
102941	M4	191.2	0.04
102941	O1	189.4	0.27
102941	M6	349.1	0.02
102941	MK3	131.3	0.01
102941	S4	287.5	0.01
102941	MN4	176.2	0.02
102941	NU2	10.9	0.08
102941	MU2	13.9	0.04
102941	2N2	350.6	0.06
102941	OO1	226.9	0.01
102941	LDA2	49.4	0.03
102941	S1	134.8	0.02
102941	M1	196.7	0.01
102941	J1	198.1	0.02
102941	SSA	47	0.15
102941	SA	148.1	0.31
102941	RHO1	166.7	0.01
102941	Q1	178.9	0.05
102941	T2	32	0.03
102941	R2	286.8	0.01
102941	2Q1	129.8	0.01
102941	P1	198.1	0.11
102941	2SM2	46.2	0.01
102941	M3	86.9	0.01
102941	L2	53.7	0.08
102941	2MK3	105	0.01
102941	K2	57.9	0.09
102941	M8	222.8	0.01
102941	MS4	209.4	0.01
102942	M2	24.1	1.23
102942	S2	47.5	0.22
102942	N2	1.9	0.28
102942	K1	210.6	0.23
102942	M4	179.7	0.07
102942	O1	198.9	0.2
102942	M6	248.7	0.01
102942	MK3	17.1	0.02
102942	MN4	165.5	0.04
102942	NU2	4.6	0.05
102942	MU2	354.2	0.02
102942	2N2	349.3	0.03
102942	OO1	222.2	0.01
102942	LDA2	35	0.01
102942	S1	122.9	0.02
102942	M1	204.6	0.01
102942	J1	216.4	0.02
102942	MM	243.6	0.06
102942	SSA	43.6	0.1
102942	SA	153.5	0.2
102942	MF	182.2	0.05
102942	RHO1	193.8	0.01
102942	Q1	193.4	0.03
102942	T2	47.4	0.01
102942	2Q1	187.1	0.01
102942	P1	203.9	0.08
102942	L2	43.9	0.05
102942	2MK3	13.1	0.02
102942	K2	42.6	0.06
102942	MS4	203.3	0.02
102943	M2	57.7	1.16
102943	S2	87.6	0.18
102943	N2	44.2	0.24
102943	K1	231	0.25
102943	M4	20.5	0.08
102943	O1	219.5	0.21
102943	M6	211.5	0.04
102943	MK3	125.2	0.03
102943	MN4	4.6	0.03
102943	NU2	30.2	0.06
102943	MU2	118.3	0.03
102943	2N2	35.9	0.03
102943	LDA2	47.3	0.03
102943	S1	166.7	0.02
102943	M1	301.4	0.01
102943	J1	224.2	0.01
102943	SSA	47	0.15
102943	SA	148.1	0.31
102943	RHO1	166	0.01
102943	Q1	213.9	0.03
102943	T2	62.6	0.02
102943	P1	222.3	0.07
102943	M3	71.5	0.01
102943	L2	35.2	0.06
102943	2MK3	87.7	0.03
102943	K2	89.7	0.06
102943	M8	257	0.01
102943	MS4	61.4	0.03
102944	M2	110.1	0.32
102944	S2	139.2	0.04
102944	N2	95.5	0.06
102944	K1	281.2	0.1
102944	M4	87.6	0.01
102944	O1	271.1	0.1
102944	M6	332.4	0.01
102944	MK3	143.5	0.01
102944	NU2	90.8	0.01
102944	MU2	249.6	0.01
102944	2N2	81.9	0.01
102944	LDA2	111	0.01
102944	S1	254.9	0.02
102944	M1	83.7	0.01
102944	MM	69.5	0.09
102944	SSA	69.2	0.15
102944	SA	147.2	0.29
102944	Q1	268.9	0.02
102944	T2	118.4	0.01
102944	P1	280.9	0.02
102944	L2	117.8	0.02
102944	2MK3	125.8	0.01
102944	K2	140.6	0.01
102945	M2	0.9	1.64
102945	S2	24.6	0.32
102945	N2	342.1	0.38
102945	K1	194.4	0.29
102945	M4	221.5	0.02
102945	O1	185.3	0.28
102945	M6	311.3	0.05
102945	S4	211.3	0.01
102945	MN4	185.2	0.02
102945	NU2	341.6	0.08
102945	MU2	339.9	0.07
102945	2N2	328.6	0.05
102945	OO1	203.4	0.01
102945	LDA2	11.8	0.01
102945	S1	112.7	0.03
102945	M1	189.8	0.02
102945	J1	198.9	0.02
102945	MM	278.9	0.09
102945	SSA	51.1	0.11
102945	SA	155.7	0.2
102945	RHO1	181.3	0.01
102945	Q1	172	0.05
102945	T2	24.6	0.02
102945	2Q1	176.1	0.01
102945	P1	192.7	0.1
102945	L2	19.5	0.05
102945	K2	23.4	0.08
102946	M2	8.6	1
102946	S2	31.5	0.18
102946	N2	348.5	0.23
102946	K1	210.5	0.18
102946	M4	171.6	0.07
102946	O1	200	0.17
102946	M6	268.2	0.01
102946	MK3	359.5	0.02
102946	S4	210.9	0.01
102946	MN4	152.5	0.03
102946	NU2	346	0.05
102946	MU2	342	0.03
102946	2N2	333.4	0.03
102946	OO1	203.7	0.01
102946	LDA2	20.4	0.01
102946	S1	153.8	0.01
102946	J1	197.8	0.01
102946	MM	69.5	0.09
102946	SSA	69.2	0.15
102946	SA	147.2	0.29
102946	RHO1	181.6	0.01
102946	Q1	191.3	0.03
102946	T2	6.9	0.02
102946	R2	249.8	0.01
102946	P1	198.9	0.06
102946	M3	13	0.01
102946	L2	28.2	0.04
102946	2MK3	0.9	0.02
102946	K2	30.5	0.05
102946	M8	346.3	0.01
102946	MS4	187.9	0.01
102947	M2	141.9	0.2
102947	S2	164.2	0.03
102947	N2	127.1	0.05
102947	K1	295.6	0.08
102947	M4	250.1	0.01
102947	O1	291.5	0.06
102947	M6	194.1	0.01
102947	NU2	128.7	0.01
102947	2N2	112.5	0.01
102947	SSA	40.3	0.12
102947	SA	155.3	0.2
102947	Q1	288.1	0.01
102947	P1	295.5	0.03
102947	L2	159.7	0.01
102947	K2	166.8	0.01
102948	M2	142.3	0.22
102948	S2	171.7	0.04
102948	N2	131.1	0.05
102948	K1	298.5	0.08
102948	M4	201	0.02
102948	O1	292	0.06
102948	M6	52.7	0.01
102948	NU2	132.6	0.01
102948	MU2	322	0.01
102948	2N2	119.8	0.01
102948	J1	301.2	0.01
102948	SSA	40.3	0.12
102948	SA	155.3	0.2
102948	Q1	289	0.01
102948	P1	298.1	0.02
102948	L2	153.9	0.01
102948	K2	174.1	0.01
102949	M2	131.1	0.25
102949	S2	163.5	0.04
102949	N2	115	0.05
102949	K1	284.3	0.06
102949	M4	178.8	0.02
102949	O1	295.1	0.07
102949	M6	44	0.01
102949	MN4	157.9	0.01
102949	NU2	126.9	0.01
102949	MU2	265.1	0.01
102949	2N2	118.1	0.01
102949	LDA2	148.5	0.01
102949	S1	246.5	0.03
102949	J1	269.3	0.01
102949	RHO1	183.7	0.01
102949	Q1	302.2	0.01
102949	T2	151.1	0.01
102949	R2	45.8	0.01
102949	2Q1	280.5	0.01
102949	P1	276.3	0.03
102949	L2	139.4	0.02
102949	K2	149.9	0.02
102949	MS4	225.7	0.01
102950	M2	150.3	0.9
102950	S2	181.2	0.16
102950	N2	144.1	0.15
102950	K1	275.4	0.17
102950	M4	213.3	0.03
102950	O1	259.2	0.16
102950	M6	201.7	0.02
102950	NU2	145	0.03
102950	MU2	327.7	0.02
102950	2N2	137.9	0.02
102950	OO1	291.6	0.01
102950	LDA2	164.6	0.01
102950	M1	267.3	0.01
102950	J1	283.5	0.01
102950	RHO1	252.2	0.01
102950	Q1	251.1	0.03
102950	T2	180	0.01
102950	P1	274.2	0.06
102950	L2	156.5	0.03
102950	K2	183.7	0.04
102951	M2	162.4	0.74
102951	S2	191.6	0.11
102951	N2	141.1	0.15
102951	K1	279.9	0.1
102951	M4	217.4	0.04
102951	O1	293.4	0.09
102951	M6	243	0.02
102951	NU2	143.9	0.03
102951	MU2	341	0.02
102951	2N2	119.9	0.02
102951	LDA2	175.9	0.01
102951	M1	286.9	0.01
102951	J1	274.2	0.01
102951	SSA	35.7	0.12
102951	SA	133.1	0.27
102951	Q1	299.7	0.02
102951	T2	190.5	0.01
102951	P1	280.9	0.03
102951	L2	183.7	0.02
102951	K2	194	0.03
102952	M2	263.1	0.61
102952	S2	92.6	0.03
102952	N2	232.9	0.04
102952	K1	3.4	0.09
102952	M4	359.8	0.07
102952	O1	339.4	0.07
102952	M6	118.1	0.04
102952	S4	12.8	0.01
102952	NU2	236.9	0.01
102952	MU2	282.8	0.02
102952	2N2	202.7	0.01
102952	M1	351.5	0.01
102952	J1	15.3	0.01
102952	Q1	327.4	0.01
102952	P1	1.6	0.03
102952	L2	293.3	0.02
102952	K2	78.8	0.01
102953	M2	182.9	0.85
102953	S2	210	0.13
102953	N2	159.2	0.18
102953	K1	275.5	0.12
102953	M4	281.6	0.06
102953	O1	295.8	0.1
102953	M6	337.4	0.01
102953	MK3	313.2	0.02
102953	MN4	253.9	0.02
102953	NU2	154.5	0.04
102953	MU2	199.4	0.01
102953	2N2	137.3	0.02
102953	OO1	298.2	0.01
102953	LDA2	203.6	0.02
102953	S1	288.4	0.03
102953	J1	287.2	0.01
102953	MM	53.7	0.07
102953	SSA	57	0.16
102953	SA	130.8	0.37
102953	MF	325	0.03
102953	Q1	267.8	0.02
102953	T2	201.4	0.01
102953	P1	274.8	0.05
102953	M3	271.4	0.01
102953	L2	210.3	0.05
102953	2MK3	313.6	0.02
102953	K2	205.4	0.04
102953	MS4	330.1	0.02
102954	M2	191.5	1.02
102954	S2	221.2	0.16
102954	N2	175.4	0.22
102954	K1	282.2	0.14
102954	M4	303.9	0.06
102954	O1	298.8	0.11
102954	M6	32.4	0.01
102954	MK3	315.4	0.02
102954	MN4	282.1	0.02
102954	NU2	173.2	0.06
102954	MU2	235.1	0.02
102954	2N2	148.7	0.03
102954	OO1	326.8	0.01
102954	LDA2	230	0.02
102954	S1	276.7	0.03
102954	M1	263	0.01
102954	J1	298.1	0.01
102954	RHO1	251.9	0.02
102954	Q1	266.8	0.03
102954	T2	222.8	0.01
102954	2Q1	6.8	0.02
102954	P1	295	0.05
102954	M3	42.5	0.01
102954	L2	198.9	0.04
102954	2MK3	315.1	0.02
102954	K2	213.9	0.05
102954	MS4	354.3	0.02
102955	M2	194.1	0.58
102955	S2	209	0.1
102955	N2	168.1	0.13
102955	K1	305.1	0.1
102955	M4	243.6	0.02
102955	O1	325.1	0.08
102955	M6	277.5	0.01
102955	MK3	312.7	0.01
102955	MN4	218.7	0.01
102955	NU2	172.8	0.03
102955	2N2	148.9	0.02
102955	OO1	320.4	0.01
102955	LDA2	232.8	0.01
102955	S1	288.6	0.05
102955	M1	46.1	0.01
102955	SSA	36.1	0.11
102955	SA	131.4	0.29
102955	RHO1	43.4	0.01
102955	Q1	301.6	0.02
102955	T2	199.5	0.02
102955	R2	337	0.02
102955	P1	291	0.05
102955	M3	266.6	0.01
102955	L2	229.9	0.06
102955	2MK3	308.7	0.01
102955	K2	238.3	0.03
102956	M2	221.4	1.52
102956	S2	261.2	0.26
102956	N2	204.7	0.28
102956	K1	290.9	0.17
102956	M4	293.5	0.06
102956	O1	320.3	0.12
102956	M6	42.7	0.02
102956	S4	55.6	0.01
102956	NU2	207	0.06
102956	MU2	181.7	0.04
102956	2N2	188	0.04
102956	OO1	262.6	0.01
102956	LDA2	239.8	0.01
102956	M1	306.1	0.01
102956	J1	277.4	0.01
102956	SSA	57	0.16
102956	SA	130.8	0.4
102956	Q1	334.9	0.02
102956	T2	259.7	0.02
102956	P1	293.1	0.06
102956	L2	238.2	0.04
102956	K2	264.5	0.07
102956	M8	19.1	0.01
102957	M2	255.7	0.59
102957	S2	289.3	0.08
102957	N2	237.1	0.11
102957	K1	343.6	0.12
102957	M4	349.1	0.03
102957	O1	358.4	0.1
102957	M6	73	0.01
102957	MK3	8.6	0.02
102957	MN4	329.2	0.01
102957	NU2	226.6	0.03
102957	MU2	341.4	0.02
102957	2N2	266	0.01
102957	LDA2	248.3	0.02
102957	S1	313.7	0.04
102957	J1	131.4	0.01
102957	SSA	54.2	0.16
102957	SA	145.2	0.34
102957	RHO1	271.3	0.02
102957	Q1	308.9	0.02
102957	T2	203.1	0.01
102957	R2	240.8	0.01
102957	2Q1	36.1	0.01
102957	P1	342.1	0.05
102957	2SM2	200.3	0.01
102957	M3	82.6	0.01
102957	L2	274.7	0.05
102957	2MK3	4.1	0.02
102957	K2	280.8	0.03
102957	MS4	31.5	0.01
102958	M2	258.1	0.94
102958	S2	284.5	0.06
102958	N2	243.2	0.16
102958	K1	332	0.14
102958	M4	354.3	0.09
102958	O1	330.1	0.09
102958	M6	99.5	0.05
102958	S4	336.8	0.01
102958	NU2	245.2	0.03
102958	MU2	80	0.02
102958	2N2	228.4	0.02
102958	LDA2	270.3	0.01
102958	M1	331.1	0.01
102958	J1	333	0.01
102958	Q1	329.2	0.02
102958	P1	331.9	0.05
102958	L2	272.9	0.03
102958	K2	286.7	0.02
102958	M8	179.2	0.01
102959	M2	279.7	1.04
102959	S2	321.6	0.14
102959	N2	263.7	0.19
102959	K1	332.5	0.15
102959	M4	34.7	0.1
102959	O1	353.9	0.11
102959	M6	174	0.04
102959	MK3	63	0.05
102959	MN4	16.7	0.04
102959	NU2	257.6	0.04
102959	MU2	38.8	0.04
102959	2N2	259.9	0.02
102959	OO1	12.7	0.01
102959	LDA2	290.1	0.03
102959	S1	295.8	0.03
102959	M1	338.9	0.01
102959	MM	53.7	0.07
102959	SSA	57	0.16
102959	SA	130.8	0.37
102959	MF	325	0.03
102959	RHO1	356.2	0.01
102959	Q1	337.4	0.03
102959	T2	248.9	0.02
102959	R2	136.3	0.01
102959	P1	322.9	0.05
102959	2SM2	194.2	0.01
102959	M3	349.3	0.02
102959	L2	298.5	0.12
102959	2MK3	71.8	0.05
102959	K2	324.5	0.04
102959	M8	270.6	0.01
102959	MS4	76	0.03
102960	M2	256.8	0.77
102960	S2	285.5	0.11
102960	N2	234.1	0.15
102960	K1	341	0.16
102960	M4	81.2	0.04
102960	O1	350.5	0.13
102960	M6	182.7	0.01
102960	MK3	80.9	0.02
102960	MN4	51.3	0.02
102960	NU2	239.3	0.03
102960	2N2	211.5	0.02
102960	OO1	357.5	0.01
102960	LDA2	281.9	0.02
102960	S1	300.7	0.06
102960	M1	36.9	0.01
102960	J1	317.5	0.01
102960	SSA	46.8	0.12
102960	SA	140	0.35
102960	RHO1	323.8	0.01
102960	Q1	338.7	0.03
102960	T2	272.3	0.01
102960	2Q1	249	0.01
102960	P1	326.1	0.06
102960	M3	10.9	0.01
102960	L2	283.3	0.06
102960	2MK3	71.6	0.02
102960	K2	287.9	0.04
102960	MS4	126.3	0.01
102961	M2	262.1	0.51
102961	S2	293	0.08
102961	N2	237.1	0.1
102961	K1	344.5	0.17
102961	M4	65.2	0.01
102961	O1	355	0.13
102961	M6	88.3	0.01
102961	MK3	88.1	0.01
102961	MN4	31	0.01
102961	NU2	244.8	0.02
102961	2N2	190.9	0.01
102961	OO1	338.6	0.01
102961	LDA2	285	0.01
102961	S1	301.6	0.06
102961	M1	29	0.01
102961	J1	319	0.01
102961	MM	52	0.03
102961	SSA	62.2	0.12
102961	SA	134.2	0.37
102961	MSF	241.1	0.02
102961	MF	335.8	0.03
102961	RHO1	348.3	0.01
102961	Q1	334.3	0.03
102961	T2	271	0.01
102961	R2	105.4	0.01
102961	2Q1	325.1	0.01
102961	P1	330	0.06
102961	L2	289.6	0.03
102961	2MK3	75.8	0.01
102961	K2	288.1	0.02
102962	M2	272	0.7
102962	S2	302.1	0.11
102962	N2	248.5	0.15
102962	K1	343.7	0.24
102962	M4	108.4	0.05
102962	O1	6.3	0.14
102962	M6	226.5	0.01
102962	NU2	251.7	0.03
102962	MU2	241.8	0.02
102962	2N2	225.1	0.02
102962	OO1	321.2	0.01
102962	M1	354.9	0.01
102962	J1	332.5	0.01
102962	SSA	44.5	0.12
102962	SA	128.4	0.34
102962	RHO1	16	0.01
102962	Q1	17.5	0.03
102962	T2	300.9	0.01
102962	P1	345.4	0.08
102962	L2	295.4	0.02
102962	K2	304.5	0.03
102963	M2	267.6	0.51
102963	S2	297.4	0.07
102963	N2	245.8	0.1
102963	K1	346	0.16
102963	M4	51.5	0.01
102963	O1	358.4	0.14
102963	MK3	89.4	0.01
102963	MN4	28.2	0.01
102963	NU2	252.1	0.03
102963	2N2	226.8	0.01
102963	LDA2	308.4	0.01
102963	S1	292.8	0.05
102963	J1	289.2	0.01
102963	MM	334.9	0.04
102963	SSA	0.3	0.08
102963	SA	129.3	0.22
102963	MSF	257.3	0.06
102963	MF	179.9	0.02
102963	Q1	340.2	0.02
102963	T2	253.2	0.01
102963	P1	334	0.06
102963	L2	297.8	0.03
102963	2MK3	95.5	0.01
102963	K2	292.1	0.03
102964	M2	13.9	1.03
102964	S2	110	0.09
102964	N2	358.1	0.12
102964	K1	40.8	0.2
102964	M4	231.7	0.1
102964	O1	44.3	0.16
102964	M6	85.9	0.05
102964	NU2	0.2	0.02
102964	MU2	125.9	0.03
102964	2N2	342.3	0.02
102964	OO1	37.3	0.01
102964	LDA2	58.5	0.01
102964	M1	42.6	0.01
102964	J1	39	0.01
102964	RHO1	45.9	0.01
102964	Q1	46.1	0.03
102964	T2	106.1	0.01
102964	P1	41.1	0.07
102964	L2	29.7	0.03
102964	K2	117.7	0.03
102965	M2	292.5	0.46
102965	S2	323.7	0.07
102965	N2	269.4	0.1
102965	K1	352.3	0.19
102965	M4	33.6	0.01
102965	O1	356.2	0.15
102965	M6	127.5	0.01
102965	MK3	121.3	0.01
102965	NU2	269.7	0.02
102965	2N2	249.3	0.01
102965	LDA2	311.2	0.01
102965	S1	288.9	0.06
102965	SSA	54	0.11
102965	SA	130.6	0.35
102965	P1	344.7	0.06
102965	L2	322.8	0.03
102965	2MK3	112.2	0.01
102965	K2	318.4	0.02
102966	M2	322.7	0.54
102966	S2	355.3	0.08
102966	N2	298.1	0.11
102966	K1	1.6	0.21
102966	O1	11.1	0.17
102966	MK3	167.8	0.01
102966	NU2	303.5	0.03
102966	2N2	274.3	0.01
102966	LDA2	2	0.01
102966	S1	301	0.06
102966	J1	318.5	0.01
102966	SSA	44.5	0.12
102966	SA	128.4	0.34
102966	RHO1	351.8	0.01
102966	Q1	331.6	0.02
102966	T2	355.8	0.01
102966	2Q1	161.3	0.01
102966	P1	346.6	0.06
102966	L2	342.4	0.03
102966	2MK3	150.4	0.01
102966	K2	353.8	0.02
102967	M2	8.3	1.04
102967	S2	51.9	0.14
102967	N2	349.8	0.2
102967	K1	19.4	0.25
102967	M4	159.4	0.01
102967	O1	33.9	0.19
102967	M6	67.8	0.02
102967	MK3	238.4	0.03
102967	NU2	321.2	0.05
102967	MU2	87	0.03
102967	2N2	15.9	0.04
102967	OO1	62.7	0.01
102967	LDA2	4.3	0.03
102967	S1	318.5	0.07
102967	M1	116.1	0.01
102967	J1	106.2	0.02
102967	SSA	62.3	0.11
102967	SA	143.5	0.36
102967	RHO1	306.8	0.01
102967	Q1	342.8	0.02
102967	R2	60.9	0.01
102967	2Q1	29.5	0.02
102967	P1	9.1	0.09
102967	M3	308	0.01
102967	L2	25.7	0.09
102967	2MK3	222.7	0.04
102967	K2	45.5	0.05
102968	M2	347	0.55
102968	S2	10.9	0.08
102968	N2	322	0.12
102968	K1	4.6	0.22
102968	M4	215.5	0.01
102968	O1	13.2	0.18
102968	MK3	175.7	0.01
102968	MN4	191.2	0.01
102968	NU2	323.8	0.02
102968	2N2	304.6	0.01
102968	OO1	22.2	0.01
102968	LDA2	22.4	0.02
102968	S1	279.7	0.06
102968	M1	63.7	0.01
102968	J1	333.5	0.01
102968	SSA	46.4	0.12
102968	SA	131.5	0.38
102968	RHO1	336.6	0.01
102968	Q1	357.1	0.04
102968	2Q1	274.7	0.01
102968	P1	352.3	0.06
102968	L2	16.8	0.03
102968	2MK3	167.4	0.01
102968	K2	9.9	0.03
102969	M2	47.5	0.73
102969	S2	92.6	0.1
102969	N2	16.9	0.13
102969	K1	19.2	0.26
102969	M4	263.4	0.01
102969	O1	20.9	0.17
102969	MK3	320.7	0.02
102969	NU2	27.4	0.03
102969	MU2	149.1	0.01
102969	2N2	343	0.01
102969	OO1	344.1	0.01
102969	LDA2	86.8	0.02
102969	S1	277.3	0.06
102969	M1	225.7	0.01
102969	J1	251.3	0.01
102969	RHO1	324.7	0.02
102969	Q1	17.2	0.02
102969	T2	104.7	0.03
102969	R2	170.8	0.01
102969	2Q1	85.8	0.02
102969	P1	1.4	0.07
102969	L2	87.2	0.06
102969	2MK3	301.7	0.02
102969	K2	108.8	0.03
102970	M2	70.6	0.98
102970	S2	112.9	0.14
102970	N2	43.1	0.18
102970	K1	21.1	0.2
102970	M4	120.5	0.04
102970	O1	37.8	0.15
102970	M6	196.8	0.01
102970	MK3	299.3	0.02
102970	S4	224.9	0.01
102970	MN4	98.6	0.01
102970	NU2	40.1	0.05
102970	MU2	210.3	0.02
102970	2N2	34.8	0.02
102970	OO1	35.1	0.02
102970	LDA2	114.3	0.02
102970	S1	317.9	0.05
102970	M1	112.7	0.01
102970	J1	261.2	0.01
102970	SSA	53.2	0.1
102970	SA	127.9	0.35
102970	RHO1	10.2	0.03
102970	Q1	22.5	0.02
102970	T2	99.1	0.03
102970	R2	320	0.01
102970	2Q1	185	0.01
102970	P1	12.4	0.08
102970	2SM2	11.8	0.01
102970	M3	205.4	0.01
102970	L2	84.1	0.12
102970	2MK3	296.3	0.03
102970	K2	99.5	0.05
102970	MS4	154.1	0.01
102971	M2	92.4	1.35
102971	S2	129.8	0.18
102971	N2	72.2	0.22
102971	K1	348.4	0.11
102971	M4	140	0.07
102971	O1	7.3	0.05
102971	M6	103.9	0.03
102971	MK3	280.4	0.03
102971	S4	204.9	0.01
102971	MN4	127.1	0.02
102971	NU2	73.3	0.07
102971	MU2	214.7	0.06
102971	2N2	62.8	0.03
102971	OO1	320	0.01
102971	LDA2	99.5	0.04
102971	S1	248.6	0.03
102971	M1	111.9	0.01
102971	J1	358.6	0.01
102971	SSA	56.2	0.13
102971	SA	131.2	0.4
102971	Q1	336	0.02
102971	T2	123	0.02
102971	2Q1	309.2	0.01
102971	P1	337.4	0.02
102971	2SM2	9.3	0.01
102971	M3	283.1	0.01
102971	L2	112.5	0.13
102971	2MK3	259.9	0.02
102971	K2	139.5	0.06
102971	M8	94.5	0.01
102971	MS4	179.9	0.02
102972	M2	71.9	0.93
102972	S2	112.8	0.16
102972	N2	44.5	0.17
102972	K1	27.7	0.28
102972	M4	43.3	0.06
102972	O1	32.2	0.19
102972	MK3	348.5	0.04
102972	MN4	16.7	0.02
102972	NU2	45.8	0.04
102972	MU2	212.3	0.03
102972	2N2	17.2	0.02
102972	OO1	23.1	0.01
102972	LDA2	91.8	0.04
102972	S1	141.7	0.03
102972	M1	29.8	0.01
102972	J1	25.5	0.02
102972	SSA	53.9	0.11
102972	SA	104.8	0.25
102972	RHO1	34	0.01
102972	Q1	7.8	0.04
102972	T2	81.8	0.03
102972	2Q1	36.6	0.01
102972	P1	19.5	0.06
102972	2SM2	79.2	0.01
102972	L2	106.9	0.07
102972	2MK3	341.6	0.04
102972	K2	107.7	0.03
102972	MS4	72.5	0.02
102973	M2	27.8	0.58
102973	S2	59.7	0.07
102973	N2	354.8	0.11
102973	K1	9.1	0.35
102973	M4	254.8	0.04
102973	O1	30.5	0.14
102973	M6	112	0.02
102973	NU2	359.2	0.02
102973	MU2	203.6	0.01
102973	2N2	321.5	0.01
102973	OO1	346.1	0.01
102973	M1	19.3	0.01
102973	J1	357.2	0.01
102973	RHO1	40	0.01
102973	Q1	41.5	0.03
102973	P1	10.7	0.12
102973	L2	60.5	0.02
102973	K2	62.2	0.02
102974	M2	336.3	0.5
102974	S2	8.3	0.08
102974	N2	313.1	0.11
102974	K1	7	0.21
102974	M4	243.7	0.03
102974	O1	14	0.18
102974	M6	356.4	0.01
102974	MK3	180.2	0.02
102974	MN4	212.6	0.01
102974	NU2	311.4	0.02
102974	MU2	310.3	0.01
102974	2N2	294.9	0.01
102974	OO1	26.3	0.01
102974	LDA2	12.9	0.01
102974	S1	291.6	0.06
102974	M1	67.7	0.01
102974	J1	341.2	0.01
102974	SSA	49.5	0.13
102974	SA	132.6	0.44
102974	RHO1	339.1	0.01
102974	Q1	358.5	0.04
102974	T2	333.3	0.01
102974	2Q1	277.2	0.01
102974	P1	2.2	0.07
102974	L2	357.6	0.03
102974	2MK3	160.1	0.01
102974	K2	8.9	0.03
102974	MS4	277	0.01
102975	M2	336.5	0.51
102975	S2	7.5	0.08
102975	N2	315.3	0.11
102975	K1	6.9	0.22
102975	M4	247.2	0.03
102975	O1	16.4	0.18
102975	M6	7.2	0.01
102975	MK3	179.3	0.02
102975	MN4	215.5	0.01
102975	NU2	327.2	0.02
102975	MU2	325.8	0.01
102975	2N2	268.8	0.02
102975	OO1	28.1	0.02
102975	LDA2	23.6	0.01
102975	S1	283.6	0.06
102975	M1	294.6	0.01
102975	J1	343.7	0.01
102975	SSA	53.2	0.1
102975	SA	127.9	0.35
102975	RHO1	338.5	0.02
102975	Q1	345.2	0.05
102975	R2	60.4	0.01
102975	2Q1	68	0.02
102975	P1	0.3	0.06
102975	M3	29.2	0.01
102975	L2	330.2	0.01
102975	2MK3	159.4	0.01
102975	K2	353.5	0.02
102975	MS4	275.6	0.01
102976	M2	289.9	0.43
102976	S2	322.8	0.07
102976	N2	270.5	0.09
102976	K1	356.7	0.18
102976	M4	58.6	0.01
102976	O1	6.8	0.15
102976	M6	157.1	0.01
102976	MK3	117.5	0.01
102976	NU2	266.2	0.02
102976	MU2	329.5	0.01
102976	2N2	264.7	0.01
102976	OO1	56.3	0.01
102976	LDA2	316.7	0.01
102976	S1	290.2	0.06
102976	M1	61.7	0.01
102976	J1	354	0.01
102976	SSA	54.7	0.14
102976	SA	134.5	0.43
102976	Q1	347.1	0.04
102976	T2	274.6	0.01
102976	2Q1	293.1	0.01
102976	P1	343.9	0.06
102976	L2	296.3	0.03
102976	2MK3	112.1	0.01
102976	K2	322.8	0.02
102977	M2	223.6	0.47
102977	S2	250.3	0.07
102977	N2	194.9	0.09
102977	K1	339.3	0.11
102977	M4	286.4	0.01
102977	O1	351.4	0.1
102977	M6	336.6	0.01
102977	MK3	0.4	0.01
102977	NU2	202.9	0.02
102977	2N2	169.6	0.01
102977	LDA2	258.4	0.01
102977	S1	303.5	0.04
102977	M1	265	0.01
102977	J1	310.8	0.01
102977	SSA	36.1	0.11
102977	SA	131.4	0.29
102977	RHO1	305.3	0.01
102977	Q1	305.3	0.02
102977	T2	251.5	0.01
102977	P1	325.4	0.04
102977	L2	255.7	0.04
102977	2MK3	345.5	0.01
102977	K2	257.6	0.02
102978	M2	207.6	0.46
102978	S2	231.3	0.08
102978	N2	177.3	0.1
102978	K1	350.7	0.07
102978	M4	257.2	0.01
102978	O1	338.9	0.06
102978	M6	316.5	0.01
102978	NU2	181.4	0.02
102978	MU2	31.1	0.01
102978	2N2	147	0.01
102978	SSA	36.1	0.11
102978	SA	131.4	0.29
102978	Q1	333	0.01
102978	P1	349.8	0.02
102978	L2	237.8	0.01
102978	K2	233.2	0.02
102979	M2	199.2	0.56
102979	S2	224.1	0.08
102979	N2	174.6	0.12
102979	K1	319.1	0.09
102979	M4	279	0.02
102979	O1	333.7	0.08
102979	M6	301.8	0.01
102979	MK3	328.6	0.01
102979	MN4	255.5	0.01
102979	NU2	177.7	0.03
102979	2N2	159	0.01
102979	LDA2	233.3	0.01
102979	S1	292.3	0.04
102979	SSA	48	0.14
102979	SA	136.9	0.35
102979	Q1	317.5	0.02
102979	T2	198.3	0.01
102979	P1	312	0.04
102979	L2	226.5	0.03
102979	2MK3	327.1	0.01
102979	K2	224.2	0.03
102979	MS4	329.9	0.01
102980	M2	252	0.86
102980	S2	289	0.1
102980	N2	228.9	0.1
102980	K1	321.2	0.11
102980	M4	12.7	0.05
102980	O1	3.3	0.07
102980	M6	120.9	0.03
102980	NU2	232	0.02
102980	MU2	61.5	0.02
102980	2N2	205.9	0.01
102980	LDA2	269.2	0.01
102980	M1	342.1	0.01
102980	J1	300.4	0.01
102980	Q1	24.1	0.01
102980	T2	287.6	0.01
102980	P1	324.4	0.04
102980	L2	275	0.02
102980	K2	292	0.03
102981	M2	30.7	1.34
102981	S2	81.5	0.16
102981	N2	9.9	0.25
102981	K1	10.1	0.13
102981	M4	343.7	0.18
102981	O1	22.1	0.12
102981	M6	258	0.04
102981	S4	47.4	0.01
102981	NU2	12.8	0.05
102981	MU2	185.7	0.03
102981	2N2	348	0.03
102981	LDA2	54.4	0.01
102981	M1	15.3	0.01
102981	J1	1.9	0.01
102981	SSA	40	0.12
102981	SA	110.6	0.25
102981	Q1	28.5	0.02
102981	T2	79.4	0.01
102981	P1	10.7	0.04
102981	L2	52.1	0.04
102981	K2	85.6	0.04
102981	M8	164.4	0.01
102982	M2	21.1	1.27
102982	S2	64.1	0.17
102982	N2	357.8	0.24
102982	K1	356.2	0.14
102982	M4	319.8	0.13
102982	O1	19.6	0.1
102982	M6	185.8	0.03
102982	MK3	262.3	0.03
102982	MN4	293.7	0.05
102982	NU2	358.5	0.06
102982	MU2	99.1	0.03
102982	2N2	342.8	0.03
102982	OO1	169.4	0.01
102982	LDA2	36.7	0.04
102982	S1	331.4	0.04
102982	SSA	61.1	0.19
102982	SA	123.3	0.41
102982	RHO1	31.4	0.01
102982	Q1	8.7	0.02
102982	T2	109.3	0.02
102982	R2	77.4	0.01
102982	P1	11.2	0.04
102982	2SM2	340.4	0.01
102982	M3	243.4	0.01
102982	L2	47.9	0.1
102982	2MK3	267.1	0.04
102982	K2	57.9	0.06
102982	M8	102.3	0.01
102982	MS4	4.4	0.04
102983	M2	70.8	0.33
102983	S2	89.8	0.05
102983	N2	56.5	0.06
102983	K1	261.7	0.05
102983	M4	80.6	0.05
102983	O1	260.5	0.08
102983	M6	268	0.02
102983	S4	328	0.01
102983	NU2	58.7	0.01
102983	MU2	52	0.01
102983	2N2	42.8	0.01
102983	M1	261.4	0.01
102983	J1	262.9	0.01
102983	MM	278.9	0.09
102983	SSA	51.1	0.11
102983	SA	155.7	0.2
102983	Q1	259.9	0.02
102983	P1	261.3	0.02
102983	L2	85.4	0.01
102983	K2	91.1	0.01
102983	M8	278.6	0.01
102984	M2	21.1	0.77
102984	S2	53.6	0.14
102984	N2	7.9	0.16
102984	K1	203.8	0.11
102984	M4	338.9	0.03
102984	O1	218	0.13
102984	M6	134.9	0.02
102984	MK3	42.5	0.01
102984	MN4	311.5	0.01
102984	NU2	352.5	0.03
102984	MU2	66	0.01
102984	2N2	357.3	0.02
102984	LDA2	24.2	0.01
102984	S1	178.8	0.01
102984	J1	206.6	0.01
102984	MM	69.5	0.09
102984	SSA	69.2	0.15
102984	SA	147.2	0.29
102984	RHO1	244.9	0.01
102984	Q1	221.4	0.02
102984	R2	262.9	0.02
102984	2Q1	197.1	0.01
102984	P1	208.5	0.04
102984	M3	34.2	0.01
102984	L2	21.8	0.04
102984	2MK3	30.3	0.01
102984	K2	40.7	0.03
102984	MS4	40.6	0.01
102985	M2	12.8	1.07
102985	S2	42.2	0.18
102985	N2	358.6	0.23
102985	K1	193.8	0.16
102985	M4	328.4	0.03
102985	O1	208.1	0.18
102985	M6	103.1	0.04
102985	NU2	0.5	0.04
102985	2N2	344.5	0.03
102985	OO1	179.4	0.01
102985	LDA2	26.3	0.01
102985	M1	200.9	0.01
102985	J1	186.6	0.01
102985	RHO1	214.1	0.01
102985	Q1	215.1	0.03
102985	T2	42.1	0.01
102985	P1	193.7	0.05
102985	L2	26.9	0.03
102985	K2	42.2	0.05
102986	M2	5.7	1.33
102986	S2	30.4	0.24
102986	N2	349	0.31
102986	K1	196.5	0.18
102986	M4	184.8	0.05
102986	O1	204.1	0.19
102986	M6	66.2	0.03
102986	MK3	359.9	0.02
102986	S4	248	0.02
102986	MN4	178	0.02
102986	NU2	346.9	0.06
102986	MU2	359.3	0.03
102986	2N2	338.5	0.04
102986	OO1	178.7	0.01
102986	LDA2	7.7	0.02
102986	S1	152.4	0.02
102986	M1	233.5	0.01
102986	J1	186	0.02
102986	MM	296.8	0.03
102986	SSA	50	0.1
102986	SA	167.1	0.22
102986	MSF	178.3	0.03
102986	MF	272.4	0.01
102986	RHO1	192.1	0.01
102986	Q1	184.7	0.04
102986	T2	4.9	0.02
102986	2Q1	168.1	0.01
102986	P1	193	0.06
102986	M3	44.7	0.01
102986	L2	355.2	0.05
102986	2MK3	349.1	0.02
102986	K2	27.5	0.06
102986	M8	3.9	0.01
102986	MS4	121.3	0.01
102987	M2	23	1.78
102987	S2	58	0.31
102987	N2	11.8	0.39
102987	K1	201.4	0.26
102987	M4	206.2	0.06
102987	O1	212.6	0.27
102987	M6	93.9	0.07
102987	MK3	357.6	0.03
102987	S4	303.5	0.02
102987	MN4	210.1	0.03
102987	NU2	2.3	0.08
102987	S6	261.9	0.01
102987	MU2	60.1	0.08
102987	2N2	0.7	0.05
102987	OO1	203.9	0.01
102987	LDA2	358.6	0.04
102987	S1	167.5	0.04
102987	M1	236.6	0.01
102987	J1	232.2	0.02
102987	SSA	33.5	0.16
102987	SA	153.8	0.24
102987	RHO1	190.3	0.01
102987	Q1	202.9	0.05
102987	T2	28.7	0.04
102987	R2	256.7	0.01
102987	2Q1	158.7	0.01
102987	P1	204.6	0.09
102987	M3	83.4	0.01
102987	L2	1.2	0.1
102987	2MK3	4.2	0.03
102987	K2	53.2	0.09
102987	M8	295.7	0.01
102987	MS4	214	0.02
102988	M2	32.7	1.26
102988	S2	57.5	0.22
102988	N2	14.3	0.28
102988	K1	194.3	0.19
102988	M4	290.4	0.01
102988	O1	215.5	0.15
102988	M6	293.5	0.02
102988	MK3	74.7	0.01
102988	S4	317.9	0.01
102988	MN4	265.3	0.01
102988	NU2	11.6	0.06
102988	MU2	23.3	0.03
102988	2N2	3.2	0.04
102988	OO1	223.2	0.01
102988	LDA2	50.9	0.02
102988	S1	106.9	0.02
102988	M1	238.2	0.01
102988	J1	197.6	0.01
102988	SSA	44.7	0.16
102988	SA	156	0.29
102988	RHO1	204.2	0.01
102988	Q1	195.7	0.04
102988	T2	36.7	0.02
102988	R2	288.6	0.01
102988	2Q1	190.5	0.01
102988	P1	196.6	0.06
102988	M3	85.5	0.01
102988	L2	36.3	0.05
102988	2MK3	88.2	0.01
102988	K2	54.6	0.06
102988	MS4	155.9	0.01
102989	M2	44.3	1.12
102989	S2	69.6	0.2
102989	N2	24.2	0.25
102989	K1	198.4	0.17
102989	M4	325.4	0.04
102989	O1	216.6	0.12
102989	M6	333.2	0.01
102989	S4	307.7	0.01
102989	NU2	26.9	0.05
102989	MU2	19	0.03
102989	2N2	4.3	0.03
102989	OO1	180.4	0.01
102989	LDA2	56.1	0.01
102989	M1	207.3	0.01
102989	J1	189.5	0.01
102989	SSA	37.6	0.13
102989	SA	150.6	0.19
102989	Q1	225.9	0.02
102989	T2	68.6	0.01
102989	P1	199.8	0.06
102989	L2	64.5	0.03
102989	K2	71.7	0.05
102990	M2	86.8	0.78
102990	S2	113	0.11
102990	N2	66.9	0.14
102990	K1	222.4	0.13
102990	M4	32	0.05
102990	O1	248.5	0.1
102990	M6	63.3	0.02
102990	NU2	69.6	0.03
102990	MU2	268.6	0.02
102990	2N2	47	0.02
102990	LDA2	99	0.01
102990	M1	235.4	0.01
102990	J1	209.5	0.01
102990	Q1	261.5	0.02
102990	T2	112	0.01
102990	P1	224.4	0.04
102990	L2	106.7	0.02
102990	K2	115.2	0.03
102991	M2	95.4	0.85
102991	S2	130.5	0.11
102991	N2	68.4	0.17
102991	K1	234.6	0.14
102991	M4	92.3	0.05
102991	O1	248.9	0.11
102991	M6	146.5	0.01
102991	S4	85.1	0.01
102991	NU2	72	0.03
102991	MU2	268.5	0.02
102991	2N2	41.5	0.02
102991	OO1	220.3	0.01
102991	LDA2	111.7	0.01
102991	M1	241.7	0.01
102991	J1	227.5	0.01
102991	Q1	256.1	0.02
102991	T2	129.1	0.01
102991	P1	235.7	0.05
102991	L2	122.4	0.02
102991	K2	133.3	0.03
102992	M2	133.9	0.75
102992	S2	158.9	0.1
102992	N2	118.4	0.16
102992	K1	258.2	0.13
102992	M4	169.9	0.02
102992	O1	255.1	0.1
102992	M6	168.9	0.01
102992	NU2	120.5	0.03
102992	MU2	316.8	0.02
102992	2N2	103	0.02
102992	LDA2	145.5	0.01
102992	M1	256.7	0.01
102992	J1	259.8	0.01
102992	Q1	253.6	0.02
102992	T2	157.9	0.01
102992	P1	258	0.04
102992	L2	149.3	0.02
102992	K2	160.9	0.03
102993	M2	142.3	1.07
102993	S2	152.1	0.22
102993	N2	119.6	0.23
102993	K1	248.7	0.15
102993	M4	203.6	0.09
102993	O1	266.2	0.11
102993	M6	260.6	0.02
102993	MK3	255.9	0.02
102993	S4	179.7	0.01
102993	MN4	162	0.04
102993	NU2	100.9	0.04
102993	MU2	120.9	0.02
102993	2N2	157.6	0.03
102993	OO1	337.5	0.01
102993	LDA2	175.6	0.01
102993	S1	293.6	0.06
102993	M1	269.1	0.01
102993	J1	292.4	0.01
102993	SSA	35.7	0.12
102993	SA	133.1	0.27
102993	RHO1	205.8	0.01
102993	Q1	263	0.02
102993	T2	12.1	0.03
102993	R2	349.5	0.08
102993	P1	309	0.03
102993	M3	264.7	0.01
102993	L2	185	0.07
102993	2MK3	275.3	0.02
102993	K2	155.6	0.07
102993	MS4	261.6	0.02
102994	M2	221.8	0.77
102994	S2	258.7	0.12
102994	N2	202.2	0.17
102994	K1	299	0.09
102994	M4	7.5	0.03
102994	O1	323.7	0.08
102994	M6	93.6	0.01
102994	MK3	42.7	0.01
102994	MN4	342.1	0.01
102994	NU2	197.3	0.03
102994	MU2	227.7	0.02
102994	2N2	185.3	0.02
102994	LDA2	232.8	0.01
102994	S1	290.4	0.03
102994	J1	269.7	0.01
102994	SSA	38.7	0.1
102994	SA	142.2	0.31
102994	RHO1	297.9	0.01
102994	Q1	308.7	0.02
102994	T2	256.9	0.01
102994	2Q1	268.9	0.01
102994	P1	308.2	0.03
102994	M3	346.5	0.01
102994	L2	224.8	0.04
102994	2MK3	35.9	0.01
102994	K2	253.1	0.04
102994	MS4	56.1	0.01
102995	M2	214.6	0.79
102995	S2	249.4	0.12
102995	N2	192.8	0.17
102995	K1	293.7	0.09
102995	M4	332.9	0.02
102995	O1	321.7	0.08
102995	M6	62.2	0.01
102995	MK3	22.8	0.01
102995	MN4	306.3	0.01
102995	NU2	187.7	0.04
102995	MU2	232	0.01
102995	2N2	170.3	0.02
102995	OO1	299.4	0.01
102995	LDA2	229.5	0.02
102995	S1	289.4	0.03
102995	J1	276.5	0.01
102995	SSA	26.2	0.15
102995	SA	123.7	0.38
102995	Q1	300	0.02
102995	T2	263.8	0.01
102995	2Q1	154.5	0.01
102995	P1	301.9	0.03
102995	M3	354.6	0.01
102995	L2	229.9	0.05
102995	2MK3	30.5	0.01
102995	K2	246.1	0.04
102996	M2	317.1	0.94
102996	S2	354.9	0.12
102996	N2	299.7	0.15
102996	K1	319.9	0.12
102996	M4	134.4	0.06
102996	O1	347.6	0.09
102996	M6	277.1	0.05
102996	MK3	125.9	0.03
102996	MN4	110.9	0.03
102996	NU2	296.5	0.06
102996	MU2	75.9	0.04
102996	2N2	256.5	0.04
102996	LDA2	341.8	0.03
102996	S1	297.8	0.04
102996	M1	90.4	0.01
102996	J1	162.3	0.01
102996	SSA	35.7	0.12
102996	SA	133.1	0.27
102996	RHO1	267.3	0.01
102996	Q1	340	0.02
102996	T2	26.8	0.01
102996	R2	58.6	0.01
102996	2Q1	260.8	0.02
102996	P1	328.1	0.02
102996	2SM2	240.1	0.01
102996	M3	62.2	0.01
102996	L2	344.1	0.08
102996	2MK3	140.4	0.04
102996	K2	356.7	0.04
102996	M8	106.5	0.01
102996	MS4	177.1	0.02
102997	M2	176.3	0.59
102997	S2	202.8	0.09
102997	N2	154.3	0.13
102997	K1	280.5	0.07
102997	M4	214	0.01
102997	O1	299.4	0.06
102997	M6	263.9	0.01
102997	MK3	312.1	0.01
102997	MN4	181.2	0.01
102997	NU2	153.5	0.03
102997	MU2	143.6	0.01
102997	2N2	142.7	0.02
102997	OO1	294.2	0.01
102997	LDA2	204	0.01
102997	S1	304.3	0.03
102997	SSA	42	0.17
102997	SA	131.1	0.32
102997	Q1	283	0.01
102997	T2	181.8	0.01
102997	P1	288.6	0.03
102997	L2	194.6	0.03
102997	2MK3	306.6	0.01
102997	K2	200.8	0.03
102998	M2	168	0.85
102998	S2	193.8	0.13
102998	N2	144.6	0.17
102998	K1	245.4	0.11
102998	M4	218.5	0.06
102998	O1	274.4	0.08
102998	M6	242.4	0.01
102998	MK3	282.8	0.02
102998	S4	247.7	0.01
102998	MN4	191.9	0.03
102998	NU2	144.5	0.04
102998	MU2	184.2	0.01
102998	2N2	108.5	0.02
102998	LDA2	191.6	0.02
102998	S1	219.5	0.01
102998	SSA	48	0.1
102998	SA	156	0.3
102998	Q1	269.2	0.02
102998	T2	173.6	0.01
102998	P1	249.4	0.03
102998	M3	286.5	0.01
102998	L2	186.1	0.04
102998	2MK3	304.5	0.02
102998	K2	193.4	0.04
102998	MS4	255.3	0.01
102999	M2	102.9	0.56
102999	S2	126.1	0.09
102999	N2	82	0.13
102999	K1	225.5	0.1
102999	M4	89.7	0.03
102999	O1	247.2	0.08
102999	M6	96.5	0.01
102999	MK3	188.7	0.01
102999	MN4	63	0.01
102999	NU2	79.9	0.02
102999	MU2	84.1	0.01
102999	2N2	64.9	0.02
102999	LDA2	123.2	0.01
102999	J1	225.3	0.01
102999	SSA	40	0.16
102999	SA	141.8	0.32
102999	Q1	232.8	0.02
102999	T2	110.7	0.01
102999	2Q1	188.4	0.01
102999	P1	232.7	0.03
102999	L2	116	0.03
102999	2MK3	190.4	0.01
102999	K2	125.6	0.03
102999	MS4	151.9	0.01
103000	M2	186.6	1.31
103000	S2	228.7	0.21
103000	N2	179.6	0.28
103000	K1	250	0.18
103000	M4	220.4	0.11
103000	O1	286.9	0.07
103000	M6	235.8	0.05
103000	S4	349.2	0.03
103000	NU2	180.6	0.05
103000	MU2	350.6	0.03
103000	2N2	172.6	0.04
103000	LDA2	206.1	0.01
103000	M1	268.3	0.01
103000	J1	231.7	0.01
103000	Q1	305.3	0.01
103000	T2	227	0.01
103000	P1	252.8	0.06
103000	L2	193.6	0.04
103000	K2	232.1	0.06
103000	M8	252.9	0.01
103001	M2	264.3	1.34
103001	S2	302.8	0.16
103001	N2	230.9	0.25
103001	K1	296.4	0.22
103001	M4	60.4	0.19
103001	O1	325.8	0.2
103001	M6	163.4	0.08
103001	S4	77.8	0.01
103001	NU2	235.5	0.05
103001	S6	264.9	0.01
103001	MU2	226.3	0.03
103001	2N2	197.5	0.03
103001	OO1	266.4	0.01
103001	LDA2	282.2	0.01
103001	M1	310.7	0.01
103001	J1	281.6	0.02
103001	RHO1	336.4	0.01
103001	Q1	340.3	0.04
103001	T2	301.1	0.01
103001	2Q1	356.8	0.01
103001	P1	298.6	0.07
103001	L2	297.4	0.04
103001	K2	305.9	0.04
103001	M8	327.8	0.04
103002	M2	47.7	0.8
103002	S2	72.6	0.15
103002	N2	29	0.18
103002	K1	197.4	0.13
103002	M4	21.4	0.05
103002	O1	218.9	0.09
103002	M6	357.7	0.01
103002	MK3	129.5	0.02
103002	S4	352.8	0.01
103002	MN4	356.9	0.02
103002	NU2	28.9	0.04
103002	MU2	50.9	0.02
103002	2N2	358.3	0.02
103002	OO1	169.9	0.01
103002	LDA2	53.2	0.01
103002	S1	99.3	0.01
103002	J1	219.3	0.01
103002	SSA	43.6	0.13
103002	SA	147	0.21
103002	RHO1	188.4	0.01
103002	Q1	218.3	0.03
103002	T2	58.7	0.01
103002	R2	235.5	0.01
103002	2Q1	129.5	0.01
103002	P1	197.7	0.03
103002	M3	101	0.01
103002	L2	71.8	0.03
103002	2MK3	142.3	0.01
103002	K2	69.5	0.04
103002	MS4	80.7	0.01
103003	M2	41	1.02
103003	S2	68.4	0.17
103003	N2	20.3	0.2
103003	K1	190.6	0.14
103003	M4	15.7	0.04
103003	O1	223.5	0.14
103003	M6	344	0.02
103003	NU2	23.1	0.04
103003	MU2	221.1	0.02
103003	2N2	359.6	0.03
103003	OO1	157.9	0.01
103003	LDA2	53.7	0.01
103003	M1	206.9	0.01
103003	J1	174.4	0.01
103003	SSA	37.6	0.13
103003	SA	150.6	0.19
103003	RHO1	237.5	0.01
103003	Q1	239.7	0.03
103003	T2	67.4	0.01
103003	P1	193.1	0.05
103003	L2	61.7	0.03
103003	K2	70.7	0.05
103004	M2	53.6	1.18
103004	S2	80	0.21
103004	N2	36.2	0.26
103004	K1	198.2	0.17
103004	M4	68.9	0.02
103004	O1	221	0.12
103004	M6	72.8	0.01
103004	MK3	117.3	0.01
103004	S4	26.4	0.02
103004	NU2	33.1	0.05
103004	MU2	50.1	0.04
103004	2N2	19.5	0.03
103004	OO1	175.3	0.01
103004	LDA2	66.4	0.02
103004	S1	108.6	0.03
103004	M1	209.5	0.01
103004	J1	186.9	0.01
103004	SSA	43.6	0.13
103004	SA	147	0.21
103004	RHO1	230.7	0.01
103004	Q1	202.5	0.03
103004	T2	68.7	0.02
103004	P1	192.7	0.05
103004	M3	141.5	0.01
103004	L2	50	0.05
103004	K2	72.3	0.06
103004	MS4	196.9	0.01
103005	M2	52.9	1.08
103005	S2	78.3	0.19
103005	N2	33.7	0.24
103005	K1	196.7	0.16
103005	M4	46.4	0.02
103005	O1	221.8	0.12
103005	M6	74.5	0.01
103005	MK3	114.2	0.01
103005	S4	22.8	0.01
103005	MN4	4.4	0.01
103005	NU2	33.6	0.05
103005	MU2	54	0.03
103005	2N2	20.8	0.03
103005	LDA2	60.4	0.02
103005	S1	127	0.03
103005	M1	223.2	0.01
103005	J1	225	0.01
103005	MM	63	0.09
103005	SSA	62.1	0.18
103005	SA	146.1	0.31
103005	Q1	200.2	0.02
103005	T2	86.5	0.02
103005	R2	315.5	0.01
103005	2Q1	142.9	0.01
103005	P1	194.3	0.04
103005	M3	122.4	0.01
103005	L2	62.5	0.05
103005	2MK3	129.7	0.01
103005	K2	74.4	0.05
103005	MS4	182.5	0.01
103006	M2	130.7	0.9
103006	S2	161.8	0.13
103006	N2	115.9	0.18
103006	K1	256.1	0.16
103006	M4	177.8	0.04
103006	O1	278	0.13
103006	M6	152.2	0.03
103006	MK3	218.6	0.02
103006	MN4	152.1	0.02
103006	NU2	110.2	0.04
103006	MU2	209.1	0.02
103006	2N2	100.6	0.02
103006	LDA2	136.5	0.03
103006	S1	203	0.04
103006	M1	337.4	0.01
103006	J1	330.4	0.01
103006	SSA	45.4	0.2
103006	SA	150.1	0.29
103006	RHO1	258.4	0.01
103006	Q1	262.3	0.03
103006	T2	139.7	0.01
103006	R2	59.7	0.01
103006	2Q1	240	0.01
103006	P1	239.3	0.04
103006	2SM2	22.4	0.01
103006	M3	213.5	0.01
103006	L2	131.1	0.07
103006	2MK3	223.3	0.02
103006	K2	158.6	0.04
103006	MS4	225.7	0.01
103007	M2	90.5	1.06
103007	S2	121.8	0.15
103007	N2	73	0.23
103007	K1	233.2	0.2
103007	M4	47.8	0.03
103007	O1	255.6	0.13
103007	M6	28.9	0.04
103007	NU2	75.3	0.05
103007	MU2	59.1	0.03
103007	2N2	55.4	0.03
103007	LDA2	105	0.01
103007	M1	243.1	0.01
103007	J1	221.2	0.01
103007	SSA	33.9	0.12
103007	SA	149.2	0.16
103007	RHO1	269	0.01
103007	Q1	267	0.02
103007	T2	120.6	0.01
103007	P1	234.8	0.07
103007	L2	108.1	0.03
103007	K2	124.3	0.04
103008	M2	54.5	1.31
103008	S2	86.6	0.24
103008	N2	38.4	0.3
103008	K1	196.7	0.17
103008	M4	345.3	0.03
103008	O1	225.9	0.12
103008	M6	108.5	0.03
103008	MK3	76.1	0.02
103008	S4	44.6	0.01
103008	MN4	332.8	0.02
103008	NU2	33.1	0.05
103008	MU2	72.3	0.04
103008	2N2	21.7	0.03
103008	OO1	188.9	0.02
103008	LDA2	57.3	0.02
103008	S1	144.7	0.02
103008	M1	259.6	0.02
103008	J1	214.2	0.01
103008	SSA	33.9	0.12
103008	SA	149.2	0.16
103008	RHO1	47.1	0.01
103008	Q1	220	0.03
103008	T2	81.7	0.03
103008	R2	293.8	0.01
103008	2Q1	136.2	0.01
103008	P1	166.1	0.04
103008	2SM2	118.4	0.01
103008	M3	167.8	0.01
103008	L2	30	0.08
103008	2MK3	81	0.02
103008	K2	70	0.06
103008	MS4	258.8	0.01
103009	M2	84.3	1.16
103009	S2	113.4	0.2
103009	N2	62	0.24
103009	K1	222.4	0.17
103009	M4	72.2	0.05
103009	O1	243.2	0.14
103009	M6	13.5	0.02
103009	MK3	147.7	0.02
103009	S4	83.3	0.01
103009	MN4	52.3	0.02
103009	NU2	60.7	0.06
103009	MU2	122.4	0.03
103009	2N2	29.8	0.02
103009	OO1	218.7	0.01
103009	LDA2	90.5	0.03
103009	S1	161	0.04
103009	M1	277.9	0.01
103009	SSA	33.9	0.12
103009	SA	149.2	0.16
103009	RHO1	36.5	0.01
103009	Q1	203	0.01
103009	T2	81.4	0.01
103009	R2	155.8	0.01
103009	2Q1	259.6	0.01
103009	P1	212.9	0.04
103009	2SM2	197.5	0.01
103009	M3	181.6	0.01
103009	L2	80.2	0.05
103009	2MK3	169.8	0.02
103009	K2	102.3	0.06
103009	MS4	111.6	0.01
103010	M2	103	1.09
103010	S2	138.6	0.19
103010	N2	91	0.23
103010	K1	227	0.18
103010	M4	117.4	0.05
103010	O1	250.1	0.14
103010	M6	38.4	0.03
103010	S4	127.5	0.01
103010	NU2	92.6	0.05
103010	MU2	274	0.03
103010	2N2	79.1	0.03
103010	OO1	203.9	0.01
103010	LDA2	119.5	0.01
103010	M1	238.5	0.01
103010	J1	215.6	0.01
103010	SSA	33.9	0.12
103010	SA	149.2	0.16
103010	RHO1	260	0.01
103010	Q1	261.6	0.03
103010	T2	137.1	0.01
103010	P1	228.8	0.06
103010	L2	114.9	0.03
103010	K2	141.4	0.05
103011	M2	124.2	0.94
103011	S2	159.9	0.15
103011	N2	112.3	0.19
103011	K1	242.9	0.2
103011	M4	156.2	0.05
103011	O1	277.5	0.13
103011	M6	124.9	0.03
103011	S4	277.7	0.01
103011	NU2	113.9	0.04
103011	MU2	295	0.02
103011	2N2	100.5	0.03
103011	OO1	208.4	0.01
103011	LDA2	140.8	0.01
103011	M1	260.1	0.01
103011	J1	225.8	0.01
103011	SSA	33.9	0.12
103011	SA	149.2	0.16
103011	RHO1	292.3	0.01
103011	Q1	294.6	0.03
103011	T2	158.5	0.01
103011	P1	245.5	0.07
103011	L2	136.1	0.03
103011	K2	162.8	0.04
103011	M8	122.1	0.01
103012	M2	181.4	1.22
103012	S2	223.6	0.19
103012	N2	170.2	0.23
103012	K1	279.2	0.19
103012	M4	180.8	0.06
103012	O1	301.2	0.15
103012	M6	323.5	0.05
103012	MK3	256.7	0.07
103012	S4	311.8	0.01
103012	MN4	198.7	0.03
103012	NU2	156.8	0.07
103012	MU2	261.4	0.06
103012	2N2	128.3	0.04
103012	LDA2	182.4	0.04
103012	S1	217.9	0.05
103012	M1	347.7	0.01
103012	J1	30.7	0.01
103012	SSA	33.9	0.12
103012	SA	149.2	0.16
103012	RHO1	292.4	0.01
103012	Q1	308.4	0.03
103012	T2	209.6	0.01
103012	R2	230.5	0.01
103012	2Q1	223.8	0.01
103012	P1	258.5	0.04
103012	2SM2	63.7	0.01
103012	M3	243.6	0.01
103012	L2	183.1	0.1
103012	2MK3	274.7	0.07
103012	K2	221.6	0.05
103012	M8	19	0.01
103012	MS4	223.3	0.02
103013	M2	155.5	0.85
103013	S2	187	0.12
103013	N2	135.9	0.17
103013	K1	264.8	0.17
103013	M4	198.7	0.06
103013	O1	287.7	0.13
103013	M6	197.3	0.05
103013	MK3	240.6	0.02
103013	MN4	180.7	0.03
103013	NU2	139.1	0.05
103013	MU2	249.4	0.02
103013	2N2	124	0.03
103013	LDA2	159.7	0.03
103013	S1	207.9	0.04
103013	M1	310.9	0.01
103013	J1	9.7	0.01
103013	SSA	33.9	0.12
103013	SA	149.2	0.16
103013	RHO1	283.2	0.01
103013	Q1	285.2	0.02
103013	T2	186.4	0.01
103013	2Q1	198.9	0.01
103013	P1	251.6	0.04
103013	2SM2	88.3	0.01
103013	M3	195.3	0.01
103013	L2	179.9	0.07
103013	2MK3	251.2	0.03
103013	K2	183.2	0.04
103013	M8	244.8	0.01
103013	MS4	246.4	0.02
103014	M2	202.5	0.97
103014	S2	230.2	0.11
103014	N2	181.5	0.2
103014	K1	287.9	0.26
103014	M4	242.5	0.07
103014	O1	296.8	0.15
103014	M6	276.5	0.03
103014	NU2	184.3	0.04
103014	MU2	174.9	0.02
103014	2N2	160.6	0.03
103014	LDA2	215.4	0.01
103014	M1	290.7	0.01
103014	J1	277	0.01
103014	RHO1	299.9	0.01
103014	Q1	301.9	0.03
103014	T2	229	0.01
103014	P1	288.5	0.09
103014	L2	223.6	0.03
103014	K2	232.5	0.03
103014	M8	342.5	0.01
103015	M2	230.7	1.14
103015	S2	268.7	0.12
103015	N2	214.9	0.21
103015	K1	294.2	0.18
103015	M4	312.9	0.06
103015	O1	315	0.16
103015	M6	18	0.04
103015	MK3	351.8	0.04
103015	MN4	293.8	0.02
103015	NU2	198.5	0.06
103015	MU2	348.6	0.05
103015	LDA2	239.1	0.04
103015	S1	246.3	0.06
103015	M1	5.3	0.02
103015	J1	76.5	0.01
103015	SSA	33.9	0.12
103015	SA	149.2	0.16
103015	RHO1	262.2	0.01
103015	Q1	323.6	0.03
103015	T2	251.3	0.01
103015	P1	274.6	0.05
103015	2SM2	121	0.01
103015	M3	304.2	0.01
103015	L2	236.6	0.13
103015	2MK3	11.3	0.03
103015	K2	262.6	0.04
103015	M8	101.5	0.01
103015	MS4	355.9	0.01
103016	M2	248.5	1.38
103016	S2	290.3	0.19
103016	N2	240.8	0.24
103016	K1	295.9	0.25
103016	M4	349	0.13
103016	O1	326.9	0.19
103016	M6	96.4	0.09
103016	S4	217.4	0.02
103016	NU2	241.8	0.05
103016	S6	339.3	0.01
103016	MU2	51.9	0.03
103016	2N2	233.1	0.03
103016	OO1	264.9	0.01
103016	LDA2	267.9	0.01
103016	M1	311.2	0.01
103016	J1	280.5	0.02
103016	SSA	33.9	0.12
103016	SA	149.2	0.16
103016	RHO1	340.2	0.01
103016	Q1	342.2	0.04
103016	T2	288.6	0.01
103016	2Q1	357.6	0.01
103016	P1	298.2	0.08
103016	L2	256.1	0.04
103016	K2	293.7	0.05
103016	M8	200.5	0.03
103017	M2	264.1	1.39
103017	S2	315.4	0.17
103017	N2	247.2	0.23
103017	K1	308.4	0.2
103017	M4	60.3	0.17
103017	O1	329.2	0.16
103017	M6	145.6	0.09
103017	MK3	56.9	0.06
103017	MN4	43.6	0.06
103017	NU2	244	0.07
103017	MU2	28.9	0.07
103017	2N2	240.2	0.05
103017	LDA2	251.7	0.06
103017	S1	257.7	0.06
103017	M1	335.3	0.01
103017	J1	110.3	0.01
103017	MM	40.2	0.25
103017	SSA	78.7	0.33
103017	SA	295.8	0.18
103017	MSF	321.3	0.25
103017	MF	48.4	0.1
103017	Q1	325.9	0.02
103017	T2	12.8	0.03
103017	R2	262.2	0.02
103017	2Q1	216.9	0.01
103017	P1	292.4	0.03
103017	L2	290.1	0.14
103017	2MK3	64	0.06
103017	K2	290.2	0.04
103017	M8	321	0.04
103017	MS4	115.5	0.05
103018	M2	47.1	1.15
103018	S2	76.2	0.21
103018	N2	27.5	0.26
103018	K1	199.8	0.17
103018	M4	308.9	0.01
103018	O1	223.8	0.13
103018	M6	3.2	0.01
103018	MK3	74.4	0.01
103018	S4	0	0.01
103018	MN4	294.5	0.01
103018	NU2	23.2	0.05
103018	MU2	47.6	0.03
103018	2N2	11.3	0.04
103018	OO1	197.2	0.01
103018	LDA2	57.2	0.02
103018	S1	101.6	0.04
103018	M1	243.3	0.01
103018	J1	230.8	0.01
103018	SSA	45.4	0.2
103018	SA	150.1	0.29
103018	RHO1	189.5	0.01
103018	Q1	209.5	0.04
103018	T2	72	0.02
103018	2Q1	171.7	0.01
103018	P1	198	0.05
103018	M3	113.2	0.01
103018	L2	61.2	0.05
103018	2MK3	102.1	0.01
103018	K2	71.8	0.06
103018	MS4	221.7	0.01
103019	M2	51.6	1.32
103019	S2	81.6	0.24
103019	N2	38.3	0.29
103019	K1	201.1	0.18
103019	M4	23.4	0.02
103019	O1	222.2	0.14
103019	M6	98.1	0.02
103019	MK3	90.7	0.02
103019	S4	358.3	0.02
103019	MN4	339	0.01
103019	NU2	27.6	0.06
103019	MU2	72.1	0.03
103019	2N2	12	0.03
103019	OO1	193	0.01
103019	LDA2	57	0.02
103019	S1	94	0.03
103019	M1	233.7	0.01
103019	J1	207	0.01
103019	SSA	33.9	0.12
103019	SA	149.2	0.16
103019	RHO1	251.8	0.02
103019	Q1	202.1	0.04
103019	T2	68.8	0.02
103019	R2	355.4	0.01
103019	2Q1	146.2	0.01
103019	P1	192.7	0.05
103019	M3	131.3	0.01
103019	L2	30.7	0.05
103019	2MK3	86.8	0.02
103019	K2	78.6	0.07
103019	MS4	211.2	0.01
103020	M2	52.4	1.27
103020	S2	78.7	0.22
103020	N2	36.2	0.3
103020	K1	194.2	0.17
103020	M4	344.7	0.03
103020	O1	227.9	0.13
103020	M6	78.4	0.02
103020	MK3	82	0.02
103020	S4	47.8	0.01
103020	MN4	335.4	0.02
103020	NU2	30.8	0.05
103020	MU2	64.7	0.04
103020	2N2	17.2	0.03
103020	OO1	212.1	0.02
103020	LDA2	85.2	0.02
103020	S1	70.5	0.02
103020	M1	246.6	0.01
103020	SSA	33.9	0.12
103020	SA	149.2	0.16
103020	Q1	224.1	0.03
103020	T2	68.5	0.04
103020	R2	117.4	0.02
103020	P1	187.8	0.05
103020	L2	37.3	0.09
103020	2MK3	77.7	0.02
103020	K2	83.8	0.07
103020	MS4	226.9	0.01
103021	M2	21.2	1.23
103021	S2	46.9	0.23
103021	N2	3.1	0.28
103021	K1	185.8	0.18
103021	M4	192.5	0.02
103021	O1	209	0.15
103021	M6	292	0.02
103021	S4	291.5	0.01
103021	MN4	194.1	0.01
103021	NU2	0.4	0.06
103021	MU2	12.7	0.04
103021	2N2	348.8	0.04
103021	OO1	217.9	0.01
103021	LDA2	27.2	0.01
103021	S1	81.3	0.03
103021	M1	230.9	0.01
103021	J1	232	0.01
103021	SSA	44.7	0.19
103021	SA	151.6	0.27
103021	RHO1	184.2	0.01
103021	Q1	187	0.03
103021	T2	39.7	0.02
103021	R2	282.2	0.01
103021	2Q1	161.4	0.01
103021	P1	183.5	0.06
103021	M3	74.1	0.01
103021	L2	20.3	0.03
103021	K2	41.9	0.06
103021	MS4	152.9	0.01
103022	M2	22.5	1.28
103022	S2	47.1	0.23
103022	N2	3.7	0.3
103022	K1	187	0.19
103022	M4	225.7	0.02
103022	O1	210.6	0.15
103022	M6	297.7	0.02
103022	MK3	47	0.01
103022	S4	285.8	0.01
103022	MN4	217.2	0.02
103022	NU2	1.7	0.06
103022	MU2	13.3	0.04
103022	2N2	350.6	0.04
103022	OO1	203.9	0.01
103022	LDA2	31.2	0.02
103022	S1	91.3	0.02
103022	M1	231.2	0.01
103022	J1	200.5	0.01
103022	SSA	34	0.14
103022	SA	152	0.18
103022	RHO1	173.4	0.01
103022	Q1	195.1	0.04
103022	T2	32	0.02
103022	R2	282.7	0.01
103022	2Q1	175.7	0.01
103022	P1	186.6	0.06
103022	M3	71	0.01
103022	L2	27.1	0.05
103022	2MK3	69.2	0.01
103022	K2	47.5	0.07
103022	MS4	175.7	0.01
103023	M2	5.6	1.59
103023	S2	29.9	0.29
103023	N2	345.6	0.35
103023	K1	175.5	0.25
103023	M4	201.8	0.02
103023	O1	201	0.18
103023	M6	278.9	0.03
103023	S4	250.4	0.01
103023	MN4	190.5	0.01
103023	NU2	343.8	0.06
103023	MU2	1.2	0.07
103023	2N2	332.6	0.04
103023	OO1	203.7	0.01
103023	LDA2	24	0.01
103023	S1	126.8	0.04
103023	M1	250.1	0.01
103023	J1	202.7	0.01
103023	SSA	37.2	0.12
103023	SA	169.5	0.19
103023	RHO1	95.6	0.01
103023	Q1	178.1	0.05
103023	T2	8.1	0.03
103023	R2	255.8	0.01
103023	2Q1	169.8	0.01
103023	P1	179.8	0.08
103023	2SM2	14.2	0.01
103023	M3	45.9	0.02
103023	L2	45.4	0.01
103023	K2	26.7	0.08
103023	MS4	94.4	0.01
103024	M2	54	1.33
103024	S2	83.3	0.23
103024	N2	36.4	0.31
103024	K1	201.3	0.17
103024	O1	227.2	0.14
103024	M6	113.6	0.02
103024	MK3	73.8	0.01
103024	S4	19.3	0.01
103024	MN4	320.7	0.01
103024	NU2	32.7	0.05
103024	S6	348.5	0.01
103024	MU2	68.6	0.04
103024	2N2	24.8	0.04
103024	OO1	234.5	0.01
103024	LDA2	53.5	0.03
103024	S1	101	0.03
103024	M1	252.2	0.01
103024	J1	238.6	0.01
103024	SSA	40.7	0.19
103024	SA	155.4	0.26
103024	RHO1	202.1	0.01
103024	Q1	213.4	0.04
103024	T2	68.7	0.02
103024	R2	319.5	0.01
103024	2Q1	193.1	0.01
103024	P1	194.2	0.05
103024	M3	124.3	0.01
103024	L2	54.6	0.07
103024	2MK3	97	0.02
103024	K2	79.7	0.06
103024	MS4	229.6	0.01
103025	M2	358	1.56
103025	S2	22.1	0.28
103025	N2	338.5	0.38
103025	K1	172.9	0.28
103025	M4	212.6	0.01
103025	O1	190.9	0.18
103025	M6	229.1	0.03
103025	S4	214.8	0.01
103025	MN4	189	0.01
103025	NU2	338	0.07
103025	S6	31.9	0.01
103025	MU2	343	0.06
103025	2N2	323.1	0.05
103025	OO1	188.6	0.01
103025	LDA2	17.8	0.01
103025	S1	92	0.04
103025	M1	216.2	0.01
103025	J1	176.1	0.02
103025	SSA	44.1	0.18
103025	SA	170	0.3
103025	RHO1	157.4	0.01
103025	Q1	187.2	0.05
103025	T2	356.4	0.02
103025	P1	171.8	0.09
103025	2SM2	14.3	0.01
103025	M3	34.2	0.01
103025	L2	8.9	0.05
103025	K2	21.7	0.07
103025	MS4	73.7	0.01
103026	M2	87.8	0.08
103026	S2	142	0.02
103026	N2	78.4	0.01
103026	K1	341.3	0.04
103026	M4	79.6	0.01
103026	O1	256.9	0.02
103026	M6	320.4	0.01
103026	MM	18.4	0.07
103026	SSA	10.5	0.09
103026	SA	158.9	0.15
103026	P1	341	0.01
103026	K2	146.3	0.01
103027	M2	82.5	0.12
103027	S2	162.2	0.02
103027	N2	66.9	0.02
103027	K1	308.5	0.02
103027	M4	72.2	0.01
103027	O1	233.9	0.04
103027	M6	268.3	0.01
103027	SSA	10.5	0.09
103027	SA	158.9	0.15
103027	Q1	265.9	0.01
103027	P1	308.1	0.01
103028	M2	81.1	0.12
103028	S2	158.7	0.02
103028	N2	65.9	0.02
103028	K1	336.2	0.03
103028	M4	69.3	0.01
103028	O1	239.1	0.03
103028	M6	270.1	0.01
103028	SSA	10.5	0.09
103028	SA	158.9	0.15
103028	Q1	269.4	0.01
103028	P1	339.3	0.01
103028	K2	164.3	0.01
103029	M2	16.6	0.39
103029	S2	32.5	0.06
103029	N2	358.9	0.09
103029	K1	190.9	0.09
103029	M4	346.3	0.03
103029	O1	194.1	0.07
103029	M6	209.5	0.01
103029	MK3	166.1	0.01
103029	MN4	327.9	0.01
103029	NU2	351.5	0.02
103029	MU2	27.4	0.01
103029	2N2	351.7	0.01
103029	LDA2	41	0.01
103029	S1	248.9	0.04
103029	M1	210.3	0.01
103029	J1	211.2	0.01
103029	MM	56.5	0.06
103029	SSA	56.9	0.1
103029	SA	154.6	0.24
103029	RHO1	218.4	0.01
103029	Q1	219.8	0.01
103029	T2	14.4	0.01
103029	R2	238.2	0.01
103029	P1	218.6	0.04
103029	L2	34.2	0.01
103029	2MK3	185.5	0.01
103029	K2	23.4	0.01
103029	MS4	28.2	0.01
103030	M2	26.7	0.29
103030	S2	38.8	0.04
103030	N2	8.1	0.07
103030	K1	218.1	0.04
103030	M4	4.1	0.01
103030	O1	215	0.06
103030	M6	211.7	0.01
103030	NU2	10.6	0.01
103030	MU2	224.6	0.01
103030	2N2	349.4	0.01
103030	MM	56.5	0.06
103030	SSA	56.9	0.1
103030	SA	154.6	0.24
103030	Q1	242.1	0.01
103030	P1	215.9	0.01
103030	L2	46	0.01
103030	K2	39.7	0.01
103031	M2	0	1.04
103031	S2	24.9	0.19
103031	N2	341.8	0.22
103031	K1	179.8	0.25
103031	M4	176.9	0.01
103031	O1	183.8	0.13
103031	M6	205	0.02
103031	NU2	344.2	0.04
103031	MU2	335.7	0.03
103031	2N2	323.5	0.03
103031	OO1	176.5	0.01
103031	LDA2	11.4	0.01
103031	M1	181.9	0.01
103031	J1	177.5	0.01
103031	MM	18.4	0.07
103031	SSA	10.5	0.09
103031	SA	158.9	0.15
103031	RHO1	185.5	0.01
103031	Q1	185.8	0.03
103031	T2	24.2	0.01
103031	P1	180.2	0.08
103031	L2	18.2	0.03
103031	K2	26.9	0.05
103032	M2	86.9	0.17
103032	S2	131.7	0.03
103032	N2	48.3	0.03
103032	K1	257.6	0.03
103032	M4	128.4	0.02
103032	O1	260.9	0.01
103032	M6	58.9	0.01
103032	MK3	304.5	0.01
103032	NU2	79	0.01
103032	MU2	210.9	0.01
103032	2N2	18.8	0.01
103032	OO1	353.1	0.01
103032	LDA2	58.2	0.01
103032	S1	273.7	0.04
103032	SSA	56.9	0.1
103032	SA	154.6	0.24
103032	RHO1	60.2	0.01
103032	Q1	81	0.01
103032	R2	282.6	0.01
103032	2Q1	61.7	0.01
103032	P1	229.5	0.02
103032	L2	150.4	0.01
103032	K2	127.5	0.01
103032	MS4	137.8	0.01
103033	M2	224.8	0.12
103033	N2	189.1	0.02
103033	K1	343.8	0.07
103033	M4	254.8	0.01
103033	O1	309.6	0.03
103033	NU2	191.2	0.01
103033	P1	342.4	0.02
103034	M2	95.3	0.15
103034	S2	68	0.03
103034	N2	75.4	0.04
103034	K1	267.9	0.04
103034	M4	106.1	0.01
103034	O1	242.1	0.03
103034	MN4	133.1	0.01
103034	NU2	56.8	0.01
103034	2N2	40.5	0.01
103034	LDA2	130	0.01
103034	S1	225.1	0.04
103034	M1	14	0.01
103034	J1	115.9	0.01
103034	MM	56.5	0.06
103034	SSA	56.9	0.1
103034	SA	154.6	0.24
103034	RHO1	264	0.01
103034	Q1	237.2	0.01
103034	T2	195	0.01
103034	R2	61.8	0.03
103034	P1	207.5	0.03
103034	2SM2	159.3	0.01
103034	K2	237.9	0.01
103035	M2	89.2	0.14
103035	S2	106.1	0.02
103035	N2	37.5	0.04
103035	K1	292.6	0.08
103035	M4	140.1	0.01
103035	O1	226	0.02
103035	NU2	43.7	0.01
103035	P1	289.4	0.03
103035	K2	109.1	0.01
103036	M2	353.2	1.49
103036	S2	16.2	0.27
103036	N2	331.3	0.35
103036	K1	184.6	0.31
103036	O1	186.4	0.25
103036	M6	170.1	0.01
103036	NU2	335.1	0.07
103036	MU2	333	0.05
103036	2N2	312.3	0.05
103036	OO1	205.9	0.01
103036	LDA2	2.4	0.01
103036	S1	192.3	0.03
103036	M1	196.6	0.01
103036	J1	192.2	0.02
103036	SSA	56.9	0.13
103036	SA	171.7	0.21
103036	RHO1	192.3	0.01
103036	Q1	180.8	0.05
103036	T2	358.9	0.02
103036	2Q1	188.2	0.01
103036	P1	186.3	0.1
103036	L2	31.2	0.03
103036	K2	16.7	0.07
103037	M2	37.2	0.14
103037	S2	73.8	0.03
103037	N2	16.5	0.03
103037	K1	248.6	0.03
103037	M4	322.6	0.01
103037	O1	214.7	0.03
103037	M6	148.8	0.01
103037	MK3	169.3	0.01
103037	MN4	314	0.01
103037	NU2	12.1	0.01
103037	S1	346.3	0.03
103037	MM	63.3	0.1
103037	SSA	7.1	0.14
103037	Q1	166.5	0.01
103037	T2	256.7	0.01
103037	R2	47.3	0.01
103037	P1	258.6	0.02
103037	L2	56.2	0.01
103037	K2	26	0.01
103038	M2	5.7	0.34
103038	S2	28.5	0.06
103038	N2	348.7	0.08
103038	K1	202.4	0.08
103038	M4	344.1	0.03
103038	O1	208	0.07
103038	M6	196.1	0.02
103038	MK3	179.8	0.01
103038	MN4	338.2	0.01
103038	NU2	331.4	0.02
103038	MU2	1.9	0.01
103038	2N2	343.2	0.01
103038	S1	338	0.01
103038	J1	174.7	0.01
103038	MM	329.8	0.08
103038	SSA	43.7	0.17
103038	SA	166.4	0.3
103038	MSF	97.7	0.09
103038	MF	38.5	0.04
103038	Q1	218.7	0.01
103038	P1	207.3	0.02
103038	L2	26.4	0.01
103038	2MK3	177.1	0.01
103038	K2	28.2	0.02
103038	MS4	14.5	0.01
103039	M2	5.5	0.44
103039	S2	34.6	0.08
103039	N2	347.5	0.12
103039	K1	191.7	0.1
103039	M4	338.4	0.04
103039	O1	198.6	0.09
103039	M6	210.4	0.02
103039	NU2	349.9	0.02
103039	MU2	336.3	0.01
103039	2N2	329.6	0.02
103039	M1	195	0.01
103039	J1	188.2	0.01
103039	Q1	201.9	0.02
103039	T2	33.4	0.01
103039	P1	192.1	0.03
103039	L2	23.3	0.02
103039	K2	37	0.02
103040	M2	207.1	0.03
103040	S2	208.3	0.01
103040	N2	173.9	0.02
103040	K1	306.8	0.02
103040	M4	120.2	0.01
103040	O1	288.9	0.04
103040	MU2	18.7	0.01
103040	2N2	154.9	0.01
103040	OO1	228.6	0.01
103040	S1	101.1	0.03
103040	J1	46.8	0.01
103040	MM	63.3	0.1
103040	SSA	7.1	0.14
103040	RHO1	234.3	0.01
103040	Q1	263.3	0.02
103040	R2	174.9	0.01
103040	2Q1	243.5	0.01
103040	P1	47.1	0.01
103040	L2	152.9	0.01
103041	M2	112.4	0.02
103041	S2	88.3	0.01
103041	N2	97.9	0.01
103041	K1	284.6	0.02
103041	O1	277.8	0.03
103041	S1	63.4	0.02
103041	MM	63.3	0.1
103041	SSA	7.1	0.14
103041	Q1	272.2	0.02
103042	M2	119.8	0.27
103042	S2	152.7	0.04
103042	N2	63.9	0.05
103042	K1	269.3	0.1
103042	M4	172.7	0.03
103042	O1	265.4	0.1
103042	M6	87.8	0.01
103042	NU2	71.4	0.01
103042	MU2	294.2	0.01
103042	2N2	8	0.01
103042	M1	267.4	0.01
103042	J1	271.2	0.01
103042	Q1	263.5	0.02
103042	P1	269	0.03
103042	L2	175.7	0.01
103042	K2	155.4	0.01
103043	M2	27.7	1.03
103043	S2	66.3	0.15
103043	N2	16.5	0.23
103043	K1	197.9	0.21
103043	M4	19.1	0.07
103043	O1	217	0.19
103043	M6	159.5	0.03
103043	NU2	18	0.04
103043	MU2	349	0.02
103043	2N2	5	0.03
103043	OO1	177.5	0.01
103043	LDA2	45.6	0.01
103043	M1	207.1	0.01
103043	J1	187.7	0.02
103043	SSA	43.7	0.17
103043	SA	166.4	0.3
103043	RHO1	225.3	0.01
103043	Q1	226.9	0.04
103043	T2	64.8	0.01
103043	P1	199.4	0.07
103043	L2	39	0.03
103043	K2	69.4	0.04
103043	M8	130.1	0.01
103044	M2	87.4	0.51
103044	S2	126.7	0.07
103044	N2	68.7	0.09
103044	K1	244.8	0.13
103044	M4	101.8	0.04
103044	O1	253.8	0.12
103044	M6	313.3	0.01
103044	S4	65	0.01
103044	NU2	71.2	0.02
103044	MU2	45.9	0.01
103044	2N2	50.1	0.01
103044	OO1	234.4	0.01
103044	M1	249.1	0.01
103044	J1	239.7	0.01
103044	SSA	57.1	0.12
103044	SA	166	0.22
103044	Q1	258.5	0.02
103044	P1	245.5	0.04
103044	L2	106	0.01
103044	K2	129.8	0.02
103045	M2	53.3	0.76
103045	S2	68	0.1
103045	N2	36.9	0.15
103045	K1	229.8	0.21
103045	M4	346.1	0.05
103045	O1	230.8	0.17
103045	M6	199.9	0.02
103045	S4	300.8	0.01
103045	NU2	39.1	0.03
103045	MU2	38.5	0.02
103045	2N2	20.5	0.02
103045	OO1	228.9	0.01
103045	LDA2	60.1	0.01
103045	M1	230.3	0.01
103045	J1	229.4	0.01
103045	SSA	57.1	0.12
103045	SA	166	0.22
103045	RHO1	231.2	0.01
103045	Q1	231.2	0.03
103045	T2	67.4	0.01
103045	P1	229.9	0.07
103045	L2	69.6	0.02
103045	K2	69.2	0.03
103045	M8	169.8	0.01
103046	M2	6.4	1.5
103046	S2	30	0.24
103046	N2	349.4	0.33
103046	K1	197.8	0.27
103046	M4	294.8	0.01
103046	O1	205	0.21
103046	M6	54.4	0.02
103046	MK3	15.5	0.01
103046	S4	302.3	0.02
103046	MN4	228.6	0.01
103046	NU2	345.6	0.07
103046	MU2	14.7	0.04
103046	2N2	338.4	0.05
103046	OO1	218.4	0.01
103046	LDA2	6.7	0.02
103046	S1	178.1	0.03
103046	M1	222.2	0.01
103046	J1	198.7	0.02
103046	SSA	43.7	0.17
103046	SA	166.4	0.3
103046	RHO1	209.6	0.01
103046	Q1	199.6	0.04
103046	T2	15.3	0.02
103046	R2	243.1	0.01
103046	2Q1	187.6	0.01
103046	P1	198.8	0.09
103046	2SM2	28.7	0.01
103046	M3	33.7	0.02
103046	L2	8	0.07
103046	2MK3	17	0.01
103046	K2	27.3	0.07
103046	M8	118.2	0.01
103046	MS4	132.2	0.02
103047	M2	151.4	1.47
103047	S2	183.1	0.21
103047	N2	130.7	0.33
103047	K1	270.3	0.28
103047	M4	155.8	0.03
103047	O1	279.6	0.23
103047	M6	156.3	0.02
103047	S4	254.4	0.01
103047	NU2	133.5	0.06
103047	MU2	326.2	0.04
103047	2N2	110.2	0.04
103047	OO1	260.8	0.01
103047	LDA2	166.1	0.01
103047	M1	274.9	0.02
103047	J1	265.5	0.02
103047	SSA	43.7	0.17
103047	SA	166.4	0.3
103047	RHO1	283.6	0.01
103047	Q1	284.3	0.05
103047	T2	181.9	0.01
103047	2Q1	288.9	0.01
103047	P1	271	0.09
103047	L2	171.9	0.04
103047	K2	185.7	0.06
103048	M2	350.8	1.8
103048	S2	10.9	0.31
103048	N2	329.5	0.43
103048	K1	185.4	0.31
103048	M4	236.2	0.02
103048	O1	190.8	0.24
103048	M6	254.3	0.02
103048	S4	265.9	0.03
103048	NU2	330.8	0.08
103048	MU2	336.6	0.07
103048	2N2	310.2	0.05
103048	OO1	201	0.02
103048	LDA2	15.1	0.02
103048	S1	162	0.04
103048	J1	192.1	0.02
103048	SSA	57.1	0.12
103048	SA	166	0.22
103048	RHO1	170.1	0.01
103048	Q1	184.2	0.05
103048	T2	359.5	0.03
103048	R2	237.3	0.01
103048	P1	187.9	0.1
103048	2SM2	6.7	0.01
103048	M3	14	0.03
103048	L2	20.1	0.05
103048	2MK3	50	0.01
103048	K2	16.1	0.08
103048	MS4	113.2	0.04
103049	M2	52.7	0.71
103049	S2	77.8	0.09
103049	N2	41.2	0.14
103049	K1	239	0.2
103049	M4	4.7	0.04
103049	O1	240.3	0.17
103049	M6	155	0.02
103049	MK3	109	0.01
103049	S4	31.8	0.01
103049	MN4	338.1	0.02
103049	NU2	46.3	0.03
103049	MU2	131.7	0.01
103049	2N2	6.3	0.02
103049	OO1	256.8	0.01
103049	LDA2	54.5	0.01
103049	S1	215.8	0.04
103049	M1	281.8	0.01
103049	J1	240.2	0.02
103049	SSA	43.7	0.17
103049	SA	166.4	0.3
103049	RHO1	220.9	0.02
103049	Q1	216.1	0.04
103049	T2	73.3	0.01
103049	R2	323.6	0.01
103049	2Q1	222.9	0.01
103049	P1	237.3	0.06
103049	M3	65.1	0.01
103049	L2	42.9	0.04
103049	2MK3	113.2	0.01
103049	K2	77.3	0.02
103049	M8	112.1	0.01
103049	MS4	52.2	0.01
103050	M2	348.4	1.77
103050	S2	11.3	0.34
103050	N2	328.7	0.41
103050	K1	171.7	0.3
103050	M4	267.3	0.02
103050	O1	194.9	0.25
103050	M6	252	0.02
103050	S4	326.8	0.03
103050	NU2	331.3	0.08
103050	S6	54.9	0.01
103050	MU2	325.4	0.04
103050	2N2	308.8	0.06
103050	OO1	148.5	0.01
103050	LDA2	359.1	0.01
103050	M1	183.2	0.02
103050	J1	160.2	0.02
103050	SSA	57.1	0.12
103050	SA	166	0.22
103050	RHO1	204.9	0.01
103050	Q1	206.5	0.05
103050	T2	10.4	0.02
103050	2Q1	218	0.01
103050	P1	173.4	0.1
103050	L2	8.4	0.05
103050	K2	13.2	0.09
103051	M2	45.1	0.25
103051	S2	80.4	0.03
103051	N2	32.7	0.05
103051	K1	244.4	0.09
103051	M4	18.5	0.03
103051	O1	253.9	0.07
103051	M6	213	0.03
103051	MN4	347.8	0.01
103051	NU2	37.2	0.01
103051	2N2	2.2	0.01
103051	S1	228	0.01
103051	J1	274.9	0.01
103051	SSA	50.3	0.19
103051	SA	165	0.35
103051	RHO1	255.8	0.01
103051	Q1	227.8	0.02
103051	T2	349.4	0.01
103051	R2	274.2	0.01
103051	2Q1	255.3	0.01
103051	P1	278.9	0.03
103051	L2	47.3	0.01
103051	K2	91.4	0.01
103051	MS4	75.8	0.01
103052	M2	24.1	1.58
103052	S2	52	0.2
103052	N2	13	0.35
103052	K1	210.7	0.3
103052	M4	307.8	0.06
103052	O1	211.8	0.24
103052	M6	81.4	0.06
103052	MK3	68	0.02
103052	S4	25.5	0.02
103052	MN4	293.1	0.04
103052	NU2	11.7	0.07
103052	MU2	55.4	0.06
103052	2N2	344.1	0.05
103052	OO1	236.8	0.01
103052	LDA2	2.5	0.03
103052	S1	166.8	0.06
103052	M1	229.8	0.02
103052	J1	202.1	0.02
103052	SSA	50.3	0.19
103052	SA	165	0.35
103052	RHO1	183.7	0.02
103052	Q1	183	0.05
103052	T2	34.5	0.04
103052	R2	313.4	0.05
103052	2Q1	176.3	0.01
103052	P1	201.5	0.1
103052	2SM2	112.7	0.01
103052	M3	49	0.02
103052	L2	356.3	0.07
103052	2MK3	72.6	0.01
103052	K2	54.9	0.05
103052	M8	26.3	0.01
103052	MS4	291.1	0.01
103053	M2	59.5	2.14
103053	S2	96.2	0.27
103053	N2	49.1	0.43
103053	K1	227.2	0.28
103053	M4	344	0.18
103053	O1	231.6	0.22
103053	M6	271.7	0.11
103053	MK3	104.8	0.06
103053	S4	127.5	0.02
103053	MN4	340.5	0.08
103053	NU2	37	0.09
103053	MU2	139.7	0.09
103053	2N2	52.8	0.05
103053	OO1	265.7	0.01
103053	LDA2	52	0.07
103053	S1	194.6	0.07
103053	M1	276.7	0.02
103053	J1	242.1	0.02
103053	SSA	56.1	0.19
103053	SA	158.4	0.29
103053	RHO1	228.1	0.01
103053	Q1	226.2	0.04
103053	T2	74.2	0.03
103053	R2	324.8	0.02
103053	2Q1	209.1	0.01
103053	P1	228.2	0.09
103053	2SM2	180	0.01
103053	M3	139.8	0.02
103053	L2	52.3	0.18
103053	2MK3	89.1	0.06
103053	K2	89.1	0.08
103053	M8	229.7	0.02
103053	MS4	17.4	0.07
103054	M2	7	1.85
103054	S2	33.1	0.26
103054	N2	353.1	0.42
103054	K1	200.8	0.32
103054	M4	167.8	0.02
103054	O1	202.2	0.25
103054	M6	35.9	0.05
103054	MK3	336	0.02
103054	S4	353.7	0.03
103054	MN4	217.3	0.02
103054	NU2	355.7	0.08
103054	MU2	20.3	0.07
103054	2N2	329.2	0.06
103054	OO1	225.3	0.01
103054	LDA2	329.7	0.02
103054	S1	157.8	0.06
103054	M1	210.1	0.02
103054	J1	185.3	0.02
103054	SSA	50.3	0.19
103054	SA	165	0.35
103054	RHO1	174.7	0.02
103054	Q1	169	0.05
103054	T2	13.8	0.05
103054	R2	286.6	0.05
103054	2Q1	155.5	0.01
103054	P1	185.5	0.1
103054	2SM2	107.5	0.01
103054	M3	53.2	0.03
103054	L2	333.2	0.07
103054	2MK3	325.5	0.01
103054	K2	34.9	0.07
103054	MS4	185.5	0.04
103055	M2	353.1	1.95
103055	S2	14.1	0.34
103055	N2	333.7	0.47
103055	K1	186.4	0.31
103055	M4	267.7	0.04
103055	O1	192.6	0.23
103055	M6	25.4	0.02
103055	S4	307.4	0.04
103055	MN4	242.1	0.03
103055	NU2	331.2	0.09
103055	MU2	338.6	0.07
103055	LDA2	4.5	0.02
103055	S1	136.5	0.03
103055	J1	177.7	0.02
103055	SSA	50.3	0.19
103055	SA	165	0.35
103055	RHO1	175.3	0.02
103055	Q1	186.1	0.05
103055	T2	355.7	0.03
103055	P1	187.5	0.11
103055	M3	25.1	0.04
103055	L2	358.3	0.06
103055	K2	13.2	0.09
103055	MS4	154.3	0.03
103056	M2	38	1.89
103056	S2	64	0.26
103056	N2	25	0.41
103056	K1	202.9	0.33
103056	M4	340.3	0.08
103056	O1	225.2	0.19
103056	M6	169	0.07
103056	NU2	26.8	0.08
103056	MU2	12.2	0.05
103056	2N2	11.9	0.06
103056	OO1	184.9	0.01
103056	LDA2	50	0.01
103056	M1	214.5	0.01
103056	J1	193.3	0.02
103056	MM	16.3	0.08
103056	SSA	24.9	0.17
103056	MSF	36.6	0.07
103056	RHO1	234.6	0.01
103056	Q1	235.6	0.04
103056	T2	63.1	0.02
103056	2Q1	246	0.01
103056	P1	204.6	0.11
103056	L2	51	0.05
103056	K2	66.2	0.07
103056	M8	111.1	0.01
103057	M2	26.4	1.88
103057	S2	51.6	0.28
103057	N2	12.6	0.41
103057	K1	196.5	0.31
103057	M4	330.4	0.04
103057	O1	214.8	0.2
103057	M6	130.6	0.07
103057	S4	16.3	0.01
103057	NU2	14.4	0.08
103057	MU2	1.2	0.05
103057	2N2	358.8	0.06
103057	OO1	176.5	0.01
103057	LDA2	38	0.01
103057	M1	205.8	0.01
103057	J1	186.3	0.02
103057	MM	16.3	0.08
103057	SSA	24.9	0.17
103057	MF	36.6	0.07
103057	RHO1	223.7	0.01
103057	Q1	224.5	0.04
103057	T2	50.5	0.02
103057	2Q1	233.5	0.01
103057	P1	197.9	0.1
103057	L2	40.2	0.05
103057	K2	53.7	0.08
103058	M2	8.6	2.06
103058	S2	31.7	0.3
103058	N2	348.4	0.44
103058	K1	195.6	0.34
103058	M4	287.2	0.02
103058	O1	199.7	0.22
103058	M6	94.6	0.05
103058	S4	41.3	0.01
103058	NU2	351.1	0.09
103058	S6	67.7	0.01
103058	MU2	189.5	0.05
103058	2N2	328.3	0.06
103058	OO1	191.5	0.01
103058	LDA2	19.3	0.01
103058	M1	197.6	0.02
103058	J1	193.6	0.02
103058	RHO1	201.4	0.01
103058	Q1	201.7	0.04
103058	T2	30.8	0.02
103058	2Q1	203.7	0.01
103058	P1	195.9	0.11
103058	L2	28.8	0.06
103058	K2	33.6	0.08
103058	M8	142.6	0.01
103059	M2	354.6	2.28
103059	S2	15.8	0.39
103059	N2	336.7	0.53
103059	K1	190.4	0.31
103059	M4	217.7	0.02
103059	O1	195.9	0.23
103059	M6	98.8	0.01
103059	MK3	121.7	0.01
103059	S4	355	0.02
103059	MN4	270.7	0.02
103059	NU2	340.7	0.1
103059	MU2	345.9	0.08
103059	2N2	322.3	0.08
103059	OO1	62.2	0.02
103059	LDA2	20.8	0.03
103059	S1	144.3	0.06
103059	M1	259.4	0.01
103059	J1	181.7	0.03
103059	SSA	50.1	0.17
103059	SA	170.9	0.27
103059	RHO1	218	0.05
103059	Q1	170	0.06
103059	T2	26.4	0.04
103059	R2	359.1	0.01
103059	2Q1	241.2	0.02
103059	P1	194.5	0.12
103059	M3	55.2	0.05
103059	L2	344.8	0.04
103059	2MK3	133.4	0.01
103059	K2	20.1	0.1
103059	MS4	203.9	0.03
103060	M2	31.3	1.81
103060	S2	58.6	0.23
103060	N2	19.6	0.37
103060	K1	203.1	0.31
103060	M4	312	0.1
103060	O1	225.8	0.24
103060	M6	161.5	0.01
103060	S4	71.9	0.01
103060	NU2	21.1	0.07
103060	MU2	4.2	0.04
103060	2N2	8.1	0.05
103060	OO1	180.2	0.01
103060	LDA2	43.9	0.01
103060	M1	214.4	0.02
103060	J1	192.2	0.02
103060	SSA	50.1	0.17
103060	SA	170.9	0.27
103060	RHO1	235.7	0.01
103060	Q1	236.9	0.05
103060	T2	57.3	0.01
103060	2Q1	248.4	0.01
103060	P1	204.8	0.1
103060	L2	42.8	0.05
103060	K2	60.8	0.06
103061	M2	6	2.16
103061	S2	30.1	0.27
103061	N2	353.6	0.47
103061	K1	196.8	0.34
103061	M4	260.1	0.03
103061	O1	205.3	0.26
103061	M6	57.6	0.05
103061	MK3	354.5	0.01
103061	S4	45.7	0.02
103061	MN4	282.1	0.03
103061	NU2	351.9	0.07
103061	MU2	32.6	0.07
103061	2N2	334.1	0.07
103061	OO1	223.7	0.01
103061	LDA2	333	0.04
103061	S1	148.2	0.09
103061	M1	224.2	0.02
103061	J1	176.7	0.03
103061	SSA	50.1	0.17
103061	SA	170.9	0.27
103061	RHO1	183	0.02
103061	Q1	175	0.06
103061	T2	3.3	0.05
103061	R2	293.3	0.09
103061	2Q1	160.6	0.02
103061	P1	187.1	0.1
103061	2SM2	127.9	0.02
103061	M3	73.3	0.04
103061	L2	334.5	0.08
103061	2MK3	46.8	0.01
103061	K2	26.7	0.08
103061	MS4	262.4	0.04
103062	M2	355.9	2.35
103062	S2	13.1	0.38
103062	N2	339	0.56
103062	K1	188.9	0.32
103062	M4	271	0.02
103062	O1	196.1	0.23
103062	M6	101.5	0.01
103062	MK3	119.4	0.01
103062	S4	15.2	0.03
103062	MN4	267.2	0.02
103062	NU2	334	0.12
103062	MU2	355.8	0.09
103062	2N2	327.8	0.09
103062	OO1	192.7	0.01
103062	LDA2	18.1	0.02
103062	S1	120.7	0.05
103062	M1	220	0.03
103062	J1	182.6	0.03
103062	SSA	50.1	0.17
103062	SA	32.4	0.27
103062	RHO1	173.4	0.02
103062	Q1	180.7	0.05
103062	T2	33.9	0.03
103062	R2	200.9	0.06
103062	2Q1	321.1	0.02
103062	P1	188.3	0.12
103062	2SM2	38.1	0.02
103062	M3	53.5	0.06
103062	L2	323.8	0.06
103062	2MK3	132.7	0.01
103062	K2	6.4	0.12
103062	MS4	223.7	0.04
103063	M2	115.7	0.6
103063	S2	106.8	0.05
103063	N2	80.5	0.1
103063	K1	270.7	0.13
103063	M4	129.7	0.16
103063	O1	288.5	0.11
103063	M6	260	0.07
103063	NU2	86.8	0.02
103063	MU2	106.1	0.01
103063	2N2	39.5	0.01
103063	M1	279.5	0.01
103063	J1	261.5	0.01
103063	SSA	50.1	0.17
103063	SA	170.9	0.27
103063	Q1	297	0.02
103063	P1	272.1	0.04
103063	L2	140	0.01
103063	K2	100.4	0.01
103063	M8	314.2	0.03
103064	M2	357.9	2.39
103064	S2	20.3	0.4
103064	N2	340.6	0.56
103064	K1	187.6	0.33
103064	M4	257	0.03
103064	O1	191.4	0.25
103064	M6	315.8	0.01
103064	MK3	78.2	0.01
103064	S4	33.1	0.02
103064	MN4	274.4	0.02
103064	NU2	338.5	0.11
103064	MU2	350.3	0.08
103064	2N2	331.2	0.08
103064	OO1	212.3	0.02
103064	LDA2	8.5	0.03
103064	S1	143.5	0.05
103064	M1	203.1	0.01
103064	J1	184.5	0.03
103064	SSA	52.2	0.22
103064	SA	172.9	0.33
103064	RHO1	174.3	0.01
103064	Q1	181.2	0.05
103064	T2	10.4	0.04
103064	R2	263.8	0.02
103064	2Q1	156.8	0.01
103064	P1	185.3	0.1
103064	2SM2	32	0.01
103064	M3	58.6	0.06
103064	L2	349	0.08
103064	2MK3	59	0.01
103064	K2	17.8	0.1
103064	MS4	246.5	0.04
103065	M2	128.3	1
103065	S2	185	0.1
103065	N2	125.9	0.15
103065	K1	283.1	0.19
103065	M4	108.5	0.14
103065	O1	283.2	0.15
103065	M6	89.3	0.08
103065	MK3	200.1	0.05
103065	MN4	95.8	0.05
103065	NU2	130.5	0.06
103065	MU2	238.8	0.08
103065	2N2	186.6	0.01
103065	LDA2	148.3	0.03
103065	S1	230.4	0.04
103065	M1	40.8	0.02
103065	J1	30.6	0.01
103065	SSA	50.1	0.17
103065	SA	170.9	0.27
103065	RHO1	293.3	0.01
103065	Q1	299.9	0.03
103065	T2	241.7	0.02
103065	R2	356.9	0.01
103065	P1	270.2	0.05
103065	2SM2	314.8	0.01
103065	M3	282.2	0.02
103065	L2	131.6	0.14
103065	2MK3	189	0.06
103065	K2	152.8	0.02
103065	M8	89.2	0.02
103065	MS4	153.9	0.04
103066	M2	44	1.85
103066	S2	81.6	0.26
103066	N2	36.1	0.39
103066	K1	218.7	0.31
103066	M4	358.1	0.17
103066	O1	218.2	0.25
103066	M6	129.7	0.05
103066	MK3	133.3	0.03
103066	S4	128	0.02
103066	MN4	352.9	0.09
103066	NU2	16.1	0.08
103066	MU2	119	0.1
103066	2N2	63.1	0.05
103066	LDA2	37.3	0.06
103066	S1	173.1	0.06
103066	M1	222.8	0.03
103066	J1	175	0.02
103066	SSA	50.1	0.17
103066	SA	170.9	0.27
103066	RHO1	272.4	0.01
103066	Q1	237	0.06
103066	T2	87.4	0.02
103066	R2	286.6	0.01
103066	P1	218.3	0.1
103066	2SM2	179.8	0.01
103066	M3	114.7	0.03
103066	L2	32.6	0.25
103066	2MK3	95.9	0.03
103066	K2	78.8	0.07
103066	M8	117.4	0.03
103066	MS4	26.8	0.08
103067	M2	359	2.39
103067	S2	19.9	0.4
103067	N2	342	0.57
103067	K1	193.8	0.36
103067	M4	265	0.02
103067	O1	194.6	0.23
103067	M6	333.3	0.01
103067	S4	26.1	0.02
103067	NU2	344.3	0.11
103067	MU2	338.2	0.06
103067	2N2	325.1	0.08
103067	OO1	193.1	0.01
103067	LDA2	8.7	0.02
103067	M1	194.3	0.02
103067	J1	192.6	0.02
103067	SSA	50.1	0.17
103067	SA	170.9	0.27
103067	RHO1	196	0.01
103067	Q1	194.9	0.04
103067	T2	19	0.02
103067	2Q1	195	0.01
103067	P1	193.8	0.12
103067	L2	15.9	0.07
103067	K2	21.6	0.11
103067	M8	49.9	0.01
103068	M2	99.5	1.15
103068	S2	135.6	0.14
103068	N2	83.4	0.17
103068	K1	261.3	0.18
103068	M4	66.4	0.15
103068	O1	264	0.17
103068	M6	23.7	0.08
103068	NU2	85.9	0.03
103068	MU2	62.7	0.03
103068	2N2	68.3	0.02
103068	OO1	262.7	0.01
103068	LDA2	116	0.01
103068	M1	263.2	0.01
103068	J1	263.4	0.01
103068	SSA	50.1	0.17
103068	SA	170.9	0.27
103068	RHO1	264.8	0.01
103068	Q1	264.4	0.03
103068	T2	133.6	0.01
103068	P1	261.5	0.06
103068	L2	116.2	0.03
103068	K2	138.4	0.04
103068	M8	21.6	0.02
103069	M2	42.1	1.84
103069	S2	70.5	0.27
103069	N2	30	0.41
103069	K1	228.8	0.31
103069	M4	339.6	0.15
103069	O1	222.4	0.26
103069	M6	115.2	0.08
103069	S4	70.2	0.01
103069	NU2	31.6	0.08
103069	S6	177.4	0.01
103069	MU2	13.8	0.04
103069	2N2	17.9	0.05
103069	OO1	234.2	0.01
103069	LDA2	55.3	0.01
103069	M1	225.6	0.02
103069	J1	231.1	0.02
103069	RHO1	220.3	0.01
103069	Q1	219.5	0.05
103069	T2	69.4	0.02
103069	2Q1	216.9	0.01
103069	P1	228.3	0.1
103069	L2	54.2	0.05
103069	K2	72.9	0.07
103069	M8	75.7	0.03
103070	M2	84.7	1.42
103070	S2	112.8	0.15
103070	N2	80.7	0.21
103070	K1	252.9	0.23
103070	M4	47.1	0.18
103070	O1	254.6	0.19
103070	M6	352.1	0.08
103070	S4	224.3	0.01
103070	NU2	81.3	0.04
103070	MU2	61.2	0.03
103070	2N2	76.3	0.03
103070	OO1	248.6	0.01
103070	LDA2	94.9	0.01
103070	M1	253.5	0.01
103070	J1	250	0.01
103070	SSA	50.1	0.17
103070	SA	170.9	0.27
103070	RHO1	256.5	0.01
103070	Q1	255.9	0.04
103070	T2	111.9	0.01
103070	P1	253.1	0.08
103070	L2	89.2	0.04
103070	K2	115.3	0.04
103070	M8	336.6	0.03
103071	M2	28.4	1.67
103071	S2	62.4	0.23
103071	N2	24.9	0.32
103071	K1	214.1	0.35
103071	M4	319.8	0.17
103071	O1	222.5	0.3
103071	M6	177.9	0.06
103071	S4	78.2	0.02
103071	NU2	25.2	0.06
103071	S6	219.9	0.01
103071	MU2	354.6	0.04
103071	2N2	21	0.04
103071	OO1	206.8	0.01
103071	LDA2	44.1	0.01
103071	M1	218.8	0.02
103071	J1	211.3	0.02
103071	RHO1	224.6	0.01
103071	Q1	226	0.06
103071	T2	60.8	0.01
103071	2Q1	228.7	0.01
103071	P1	214.8	0.11
103071	L2	31.6	0.05
103071	K2	65.2	0.06
103071	M8	93.8	0.03
103072	M2	0.1	2.35
103072	S2	20.6	0.41
103072	N2	342.6	0.56
103072	K1	192.2	0.32
103072	M4	277.8	0.02
103072	O1	196.9	0.23
103072	M6	322.2	0.01
103072	MK3	110.2	0.01
103072	S4	45.2	0.02
103072	MN4	302.1	0.01
103072	NU2	344.6	0.11
103072	S6	162.3	0.01
103072	MU2	354.4	0.08
103072	2N2	328.1	0.07
103072	OO1	124.3	0.03
103072	LDA2	32.8	0.02
103072	S1	127.3	0.06
103072	M1	227.5	0.03
103072	J1	194.7	0.03
103072	MM	247.5	0.02
103072	SSA	100.8	0.13
103072	SA	140	0.45
103072	MSF	272	0.14
103072	MF	8.4	0.09
103072	RHO1	249.8	0.02
103072	Q1	167.7	0.05
103072	T2	10.8	0.04
103072	R2	216.3	0.02
103072	P1	188.1	0.12
103072	2SM2	13.5	0.01
103072	M3	57.3	0.07
103072	L2	342.8	0.08
103072	2MK3	344.2	0.01
103072	K2	15	0.09
103072	MS4	249	0.04
103073	M2	25.4	1.5
103073	S2	55.4	0.16
103073	N2	14.4	0.27
103073	K1	212.2	0.32
103073	M4	329.4	0.23
103073	O1	226.9	0.3
103073	M6	206.7	0.06
103073	S4	170.9	0.01
103073	NU2	15.9	0.05
103073	S6	169.1	0.01
103073	MU2	355.2	0.04
103073	2N2	3.5	0.04
103073	OO1	197.4	0.01
103073	LDA2	39.4	0.01
103073	M1	219.7	0.02
103073	J1	205.3	0.02
103073	SSA	50.1	0.17
103073	SA	170.9	0.27
103073	RHO1	232.4	0.01
103073	Q1	234.3	0.06
103073	T2	54.3	0.01
103073	2Q1	239.4	0.01
103073	P1	213.3	0.1
103073	L2	36.1	0.04
103073	K2	57.9	0.05
103073	M8	124.8	0.02
103074	M2	32.1	2
103074	S2	67.8	0.31
103074	N2	21.9	0.44
103074	K1	214.6	0.33
103074	M4	226.7	0.15
103074	O1	217	0.26
103074	M6	78.8	0.1
103074	MK3	39.1	0.06
103074	S4	73.8	0.01
103074	MN4	232.4	0.06
103074	NU2	15	0.09
103074	MU2	93.9	0.09
103074	2N2	19.1	0.05
103074	OO1	268.8	0.01
103074	LDA2	10.6	0.06
103074	S1	139.4	0.05
103074	M1	211.2	0.01
103074	J1	252.4	0.03
103074	MM	25	0.11
103074	SSA	44.9	0.23
103074	SA	170.1	0.35
103074	RHO1	154.5	0.01
103074	Q1	218	0.07
103074	T2	43.4	0.03
103074	R2	301.7	0.03
103074	P1	212.2	0.1
103074	2SM2	154.7	0.01
103074	M3	125.7	0.03
103074	L2	17.2	0.16
103074	2MK3	44.5	0.05
103074	K2	65.6	0.08
103074	MS4	294.9	0.06
103075	M2	20.6	2.16
103075	S2	52.1	0.38
103075	N2	8.3	0.5
103075	K1	206.6	0.34
103075	M4	192.3	0.14
103075	O1	215.9	0.25
103075	M6	56.7	0.05
103075	MK3	18.7	0.05
103075	S4	56.2	0.01
103075	MN4	187.9	0.06
103075	NU2	0	0.1
103075	MU2	72.9	0.05
103075	2N2	9.8	0.05
103075	OO1	137.5	0.02
103075	LDA2	18.1	0.02
103075	S1	164.6	0.04
103075	M1	238.4	0.05
103075	J1	248.3	0.02
103075	SSA	44.1	0.15
103075	SA	118.6	0.22
103075	RHO1	262.1	0.03
103075	Q1	195.6	0.05
103075	T2	39.5	0.07
103075	R2	315.1	0.01
103075	2Q1	91.3	0.01
103075	P1	204.3	0.1
103075	2SM2	131.5	0.01
103075	M3	116.8	0.02
103075	L2	353.4	0.13
103075	2MK3	17.4	0.06
103075	K2	48.7	0.08
103075	M8	154.1	0.01
103075	MS4	250.2	0.07
103076	M2	24.7	1.84
103076	S2	50.6	0.28
103076	N2	6.6	0.37
103076	K1	208.5	0.28
103076	M4	24.5	0.04
103076	O1	213.1	0.21
103076	M6	126.5	0.04
103076	MK3	70.7	0.01
103076	S4	96.5	0.01
103076	MN4	353.4	0.03
103076	NU2	8.7	0.09
103076	MU2	74.5	0.03
103076	2N2	354.5	0.05
103076	OO1	225.7	0.01
103076	LDA2	25.5	0.04
103076	S1	181.4	0.03
103076	M1	280.4	0.01
103076	J1	210.9	0.01
103076	SSA	25.5	0.21
103076	SA	173.3	0.19
103076	RHO1	211.1	0.01
103076	Q1	211.6	0.04
103076	T2	29.8	0.03
103076	R2	282.8	0.02
103076	2Q1	188.6	0.01
103076	P1	207.8	0.09
103076	M3	106.6	0.03
103076	L2	36.2	0.1
103076	2MK3	71	0.02
103076	K2	47.2	0.07
103076	M8	221	0.01
103076	MS4	359.1	0.02
103077	M2	50.1	1.78
103077	S2	80.3	0.21
103077	N2	43.1	0.32
103077	K1	218.9	0.28
103077	M4	342.2	0.17
103077	O1	234.4	0.21
103077	M6	232.8	0.08
103077	S4	139.2	0.01
103077	NU2	44	0.06
103077	MU2	20.1	0.04
103077	2N2	36	0.04
103077	OO1	202.8	0.01
103077	LDA2	63.9	0.01
103077	M1	226.8	0.01
103077	J1	211.3	0.02
103077	SSA	50.1	0.17
103077	SA	170.9	0.27
103077	RHO1	240.7	0.01
103077	Q1	242	0.04
103077	T2	79.1	0.01
103077	2Q1	250.5	0.01
103077	P1	220	0.09
103077	L2	57	0.05
103077	K2	82.8	0.06
103077	M8	187.7	0.02
103078	M2	56.3	1.69
103078	S2	96.8	0.2
103078	N2	45.8	0.31
103078	K1	228.1	0.22
103078	M4	8.8	0.15
103078	O1	235.7	0.21
103078	M6	246.4	0.07
103078	MK3	128.4	0.05
103078	S4	123.8	0.01
103078	MN4	7.8	0.07
103078	NU2	24	0.08
103078	MU2	163.3	0.06
103078	2N2	50.5	0.05
103078	OO1	350.8	0.02
103078	LDA2	76.4	0.04
103078	S1	192.4	0.07
103078	M1	332.5	0.03
103078	J1	281.1	0.02
103078	SSA	50.1	0.17
103078	SA	170.9	0.27
103078	RHO1	81.7	0.01
103078	Q1	216.5	0.05
103078	T2	130.5	0.02
103078	R2	29.1	0.02
103078	2Q1	273.8	0.01
103078	P1	223.6	0.07
103078	M3	141.6	0.03
103078	L2	59.5	0.13
103078	2MK3	104	0.04
103078	K2	86.8	0.07
103078	M8	207.6	0.02
103078	MS4	46.9	0.05
103079	M2	67.8	1.6
103079	S2	103.9	0.2
103079	N2	58.6	0.31
103079	K1	234.8	0.23
103079	M4	37	0.15
103079	O1	243.8	0.18
103079	M6	285.2	0.08
103079	MK3	131.5	0.03
103079	S4	189.1	0.01
103079	MN4	28.2	0.07
103079	NU2	40.8	0.09
103079	MU2	173.1	0.06
103079	2N2	41.3	0.01
103079	OO1	193.3	0.01
103079	LDA2	61	0.05
103079	S1	193.6	0.05
103079	M1	281.6	0.04
103079	J1	309.7	0.01
103079	MM	3.6	0.07
103079	SSA	138.7	0.12
103079	SA	131.7	0.31
103079	MSF	306.6	0.12
103079	MF	5.2	0.08
103079	RHO1	299.8	0.01
103079	Q1	211.5	0.04
103079	T2	82.6	0.02
103079	R2	285.2	0.01
103079	2Q1	236.3	0.01
103079	P1	234.6	0.07
103079	2SM2	283	0.01
103079	M3	141.1	0.02
103079	L2	55.8	0.17
103079	2MK3	105	0.04
103079	K2	93.1	0.06
103079	M8	274.7	0.02
103079	MS4	72.7	0.05
103080	M2	30.5	1.78
103080	S2	63.6	0.22
103080	N2	23.7	0.35
103080	K1	210.6	0.31
103080	M4	321.6	0.18
103080	O1	227.3	0.24
103080	M6	192.8	0.04
103080	S4	115.3	0.01
103080	NU2	24.6	0.07
103080	MU2	357.7	0.04
103080	2N2	17.1	0.05
103080	OO1	194.2	0.01
103080	LDA2	45.7	0.01
103080	M1	218.9	0.02
103080	J1	202.7	0.02
103080	SSA	49.2	0.25
103080	SA	173.2	0.33
103080	RHO1	234.8	0.01
103080	Q1	235.4	0.05
103080	T2	62.4	0.01
103080	2Q1	244.2	0.01
103080	P1	211.9	0.1
103080	L2	37.2	0.05
103080	K2	66.3	0.06
103080	M8	93.2	0.01
103081	M2	10.1	2.32
103081	S2	37.6	0.32
103081	N2	0.5	0.51
103081	K1	188.5	0.35
103081	M4	268.7	0.07
103081	O1	209.2	0.25
103081	M6	88.3	0.05
103081	S4	317.5	0.01
103081	NU2	1.8	0.1
103081	S6	280.7	0.01
103081	MU2	342.9	0.06
103081	2N2	350.8	0.07
103081	OO1	167.2	0.01
103081	LDA2	22.7	0.02
103081	M1	198.7	0.02
103081	J1	177.8	0.02
103081	SSA	49.2	0.25
103081	SA	173.2	0.33
103081	RHO1	218.4	0.01
103081	Q1	219.8	0.05
103081	T2	36.4	0.02
103081	2Q1	230.2	0.01
103081	P1	190	0.11
103081	L2	19.7	0.07
103081	K2	39.8	0.09
103081	M8	192.3	0.01
103082	M2	50.1	2.13
103082	S2	84.4	0.31
103082	N2	37.1	0.44
103082	K1	230.2	0.31
103082	M4	274.9	0.2
103082	O1	234.3	0.24
103082	M6	232.7	0.09
103082	MK3	60.7	0.05
103082	MN4	263.4	0.09
103082	NU2	31.1	0.1
103082	MU2	118.2	0.07
103082	2N2	34.3	0.05
103082	OO1	246.6	0.01
103082	LDA2	41.5	0.06
103082	S1	190.5	0.09
103082	M1	289.9	0.01
103082	J1	272.9	0.01
103082	MM	9.5	0.12
103082	SSA	42.9	0.15
103082	SA	184.8	0.16
103082	MSF	34.7	0.13
103082	RHO1	235.5	0.01
103082	Q1	234.2	0.05
103082	T2	85.2	0.03
103082	R2	319.9	0.02
103082	2Q1	238.4	0.01
103082	P1	219.6	0.11
103082	M3	176.5	0.04
103082	L2	43.7	0.15
103082	2MK3	62.4	0.05
103082	K2	81.1	0.08
103082	M8	99.4	0.01
103082	MS4	307.3	0.06
103083	M2	27.5	2.77
103083	S2	67	0.4
103083	N2	19.7	0.6
103083	K1	213.8	0.37
103083	M4	225.3	0.28
103083	O1	217.1	0.29
103083	M6	138.8	0.06
103083	MK3	21.4	0.08
103083	S4	37.1	0.01
103083	MN4	219.2	0.12
103083	NU2	5.3	0.1
103083	S6	12.9	0.01
103083	MU2	83.8	0.14
103083	2N2	27.6	0.09
103083	OO1	212.1	0.04
103083	LDA2	341.8	0.05
103083	S1	152.9	0.04
103083	M1	270.4	0.03
103083	J1	264.5	0.03
103083	SSA	50.5	0.17
103083	SA	176.3	0.26
103083	Q1	200	0.07
103083	T2	64	0.07
103083	R2	306.8	0.03
103083	2Q1	257.4	0.01
103083	P1	205.7	0.13
103083	2SM2	230.5	0.01
103083	M3	136.3	0.09
103083	L2	9.1	0.25
103083	2MK3	11	0.08
103083	K2	50.6	0.09
103083	M8	308	0.02
103083	MS4	265.5	0.09
103084	M2	25.1	2.57
103084	S2	54.4	0.32
103084	N2	10	0.54
103084	K1	205.8	0.4
103084	M4	224.8	0.23
103084	O1	213.1	0.28
103084	M6	167.1	0.08
103084	NU2	12	0.1
103084	MU2	203.4	0.04
103084	2N2	354.7	0.07
103084	OO1	197.7	0.01
103084	LDA2	38.8	0.02
103084	M1	209.3	0.02
103084	J1	201.7	0.02
103084	SSA	50.5	0.17
103084	SA	176.3	0.26
103084	RHO1	216.4	0.01
103084	Q1	216.9	0.05
103084	T2	53.3	0.02
103084	2Q1	220.7	0.01
103084	P1	206.3	0.13
103084	L2	40.3	0.07
103084	K2	56.8	0.09
103084	M8	6.1	0.01
103085	M2	44.6	2.63
103085	S2	90.1	0.36
103085	N2	49.9	0.54
103085	K1	222.5	0.42
103085	M4	270.1	0.4
103085	O1	238.4	0.32
103085	M6	188.8	0.1
103085	S4	36.6	0.02
103085	NU2	49.1	0.1
103085	S6	24.3	0.01
103085	MU2	0.2	0.06
103085	2N2	55.6	0.07
103085	OO1	206.2	0.01
103085	LDA2	65.2	0.02
103085	M1	230.4	0.02
103085	J1	214.7	0.03
103085	SSA	49.2	0.25
103085	SA	173.2	0.33
103085	RHO1	245.2	0.01
103085	Q1	246.3	0.06
103085	T2	88.2	0.02
103085	2Q1	253.7	0.01
103085	P1	223.7	0.14
103085	L2	38.9	0.07
103085	K2	93.8	0.1
103085	M8	10.6	0.03
103086	M2	6.9	2.29
103086	S2	31.5	0.38
103086	N2	354.6	0.52
103086	K1	197.9	0.33
103086	M4	139.4	0.07
103086	O1	202.3	0.24
103086	M6	39.3	0.04
103086	MK3	305.1	0.02
103086	S4	263.1	0.01
103086	MN4	128.6	0.04
103086	NU2	339.3	0.11
103086	S6	266.5	0.01
103086	MU2	28.3	0.08
103086	2N2	340.1	0.09
103086	OO1	176.7	0.01
103086	LDA2	2.6	0.04
103086	S1	136.8	0.03
103086	M1	273.2	0.02
103086	J1	192.3	0.02
103086	SSA	50.5	0.17
103086	SA	176.3	0.26
103086	RHO1	180.8	0.01
103086	Q1	204.8	0.05
103086	T2	65.3	0.03
103086	R2	263.1	0.03
103086	2Q1	19.6	0.01
103086	P1	200.2	0.11
103086	2SM2	32.9	0.02
103086	M3	100.4	0.05
103086	L2	341.7	0.09
103086	2MK3	325.4	0.03
103086	K2	28.6	0.11
103086	M8	91.5	0.02
103086	MS4	170.6	0.02
103087	M2	22	2.68
103087	S2	47.5	0.44
103087	N2	11.5	0.58
103087	K1	211.9	0.36
103087	M4	241.3	0.18
103087	O1	207.3	0.3
103087	M6	166.1	0.05
103087	MK3	17.8	0.07
103087	S4	11.1	0.02
103087	MN4	230.3	0.09
103087	NU2	13	0.11
103087	S6	7.6	0.01
103087	MU2	85.8	0.13
103087	2N2	348.9	0.09
103087	OO1	216.6	0.06
103087	LDA2	337.9	0.08
103087	S1	180.7	0.04
103087	M1	178.6	0.01
103087	J1	258.7	0.01
103087	SSA	50.5	0.17
103087	SA	176.3	0.26
103087	RHO1	204.8	0.02
103087	Q1	205.5	0.05
103087	T2	72.5	0.05
103087	R2	12.1	0.09
103087	2Q1	45.7	0.02
103087	P1	215.6	0.13
103087	2SM2	232.7	0.01
103087	M3	130.1	0.06
103087	L2	7.5	0.22
103087	2MK3	34	0.04
103087	K2	50.8	0.07
103087	M8	215.5	0.01
103087	MS4	274.8	0.06
103088	M2	10.1	2.52
103088	S2	36	0.38
103088	N2	354.9	0.57
103088	K1	198.4	0.34
103088	M4	207.8	0.12
103088	O1	202	0.26
103088	M6	129.1	0.03
103088	MK3	10.6	0.03
103088	S4	333.8	0.01
103088	MN4	198.8	0.05
103088	NU2	351.5	0.11
103088	MU2	38.1	0.08
103088	2N2	345.5	0.08
103088	OO1	227.4	0.01
103088	LDA2	358.8	0.05
103088	S1	171.6	0.06
103088	M1	219.1	0.02
103088	J1	212.8	0.02
103088	SSA	49.2	0.25
103088	SA	173.2	0.33
103088	RHO1	191.2	0.01
103088	Q1	199.2	0.05
103088	T2	16.8	0.04
103088	R2	275.7	0.03
103088	P1	197.5	0.11
103088	2SM2	79.4	0.01
103088	M3	116.7	0.05
103088	L2	3.5	0.14
103088	2MK3	28.3	0.04
103088	K2	36	0.1
103088	MS4	239.7	0.04
103089	M2	50.2	2.6
103089	S2	94.9	0.39
103089	N2	43.9	0.4
103089	K1	227.2	0.3
103089	M4	250.2	0.37
103089	O1	230.5	0.27
103089	M6	153.8	0.14
103089	S4	119.5	0.03
103089	NU2	44.8	0.08
103089	S6	119.6	0.01
103089	MU2	5.3	0.06
103089	2N2	37.8	0.05
103089	OO1	225.7	0.01
103089	LDA2	71	0.02
103089	M1	229.1	0.02
103089	J1	226.4	0.02
103089	SSA	49.2	0.25
103089	SA	173.2	0.33
103089	RHO1	232.2	0.01
103089	Q1	231.7	0.05
103089	T2	93.1	0.02
103089	2Q1	234	0.01
103089	P1	227.4	0.1
103089	L2	56.1	0.07
103089	K2	98.5	0.11
103089	M8	5.6	0.02
103090	M2	31.4	2.69
103090	S2	64	0.36
103090	N2	23.4	0.54
103090	K1	223.8	0.29
103090	M4	269.6	0.26
103090	O1	217.9	0.25
103090	M6	167.2	0.09
103090	S4	65.1	0.02
103090	NU2	24.5	0.1
103090	S6	59.5	0.01
103090	MU2	358.8	0.07
103090	2N2	15.5	0.07
103090	OO1	228.3	0.01
103090	LDA2	46.5	0.02
103090	M1	220.5	0.02
103090	J1	225.8	0.02
103090	SSA	51.8	0.2
103090	SA	176	0.28
103090	RHO1	215.8	0.01
103090	Q1	215.4	0.05
103090	T2	62.6	0.02
103090	2Q1	212.9	0.01
103090	P1	223.4	0.1
103090	L2	39.6	0.08
103090	K2	66.6	0.1
103090	M8	325.7	0.01
103091	M2	48	3.28
103091	S2	91.3	0.51
103091	N2	51	0.72
103091	K1	214.6	0.4
103091	M4	283.7	0.36
103091	O1	227.9	0.31
103091	M6	175.1	0.14
103091	S4	99.6	0.04
103091	NU2	50.6	0.14
103091	S6	12.6	0.01
103091	MU2	4.6	0.08
103091	2N2	54.2	0.1
103091	OO1	201.1	0.01
103091	LDA2	68.1	0.02
103091	M1	221.4	0.02
103091	J1	207.8	0.02
103091	SSA	52.9	0.28
103091	SA	174.2	0.36
103091	RHO1	233.4	0.01
103091	Q1	234.5	0.06
103091	T2	89.6	0.03
103091	2Q1	240.4	0.01
103091	P1	215.6	0.13
103091	L2	44.8	0.09
103091	K2	94.9	0.14
103091	M8	53.3	0.02
103092	M2	49.7	3.576
103092	S2	95.9	0.574
103092	N2	44.1	0.82
103092	K1	200	0.387
103092	M4	279.6	0.417
103092	O1	230.1	0.217
103092	M6	179.2	0.174
103092	S4	48.3	0.01
103092	NU2	44.9	0.161
103092	S6	114.6	0.01
103092	MU2	201.8	0.085
103092	2N2	38.6	0.108
103092	OO1	169.9	0.01
103092	LDA2	71.1	0.026
103092	M1	214.9	0.016
103092	J1	185.1	0.016
103092	RHO1	243	0.01
103092	Q1	245	0.043
103092	T2	94.1	0.033
103092	R2	97.8	0.003
103092	2Q1	259.9	0.007
103092	P1	202.3	0.128
103092	L2	55.2	0.102
103092	K2	99.7	0.157
103092	M8	20.5	0.03
103093	M2	40.7	3.3
103093	S2	76.8	0.51
103093	N2	30.2	0.7
103093	K1	221.3	0.28
103093	M4	260	0.27
103093	O1	218.3	0.27
103093	M6	142.4	0.1
103093	S4	97.8	0.02
103093	NU2	31.6	0.13
103093	S6	46.7	0.01
103093	MU2	281.5	0.01
103093	2N2	19.7	0.09
103093	OO1	221	0.01
103093	LDA2	57.4	0.02
103093	M1	219	0.02
103093	J1	221	0.02
103093	SSA	51.8	0.2
103093	SA	176	0.28
103093	RHO1	217.7	0.01
103093	Q1	217.6	0.05
103093	T2	75.4	0.03
103093	2Q1	216.9	0.01
103093	P1	221.1	0.09
103093	L2	51.3	0.09
103093	K2	79.7	0.14
103093	M8	354.8	0.02
103094	M2	9.6	2.9
103094	S2	33.3	0.5
103094	N2	356.3	0.67
103094	K1	198.9	0.35
103094	M4	210.1	0.1
103094	O1	202.4	0.26
103094	M6	22.1	0.04
103094	MK3	15.9	0.02
103094	S4	16.1	0.03
103094	MN4	203.3	0.04
103094	NU2	346.7	0.14
103094	MU2	23.4	0.09
103094	2N2	332.7	0.07
103094	OO1	239.2	0.01
103094	LDA2	13.9	0.05
103094	S1	182.7	0.06
103094	M1	212.8	0.02
103094	J1	224.4	0.02
103094	SSA	50.5	0.17
103094	SA	176.3	0.26
103094	Q1	194.1	0.06
103094	T2	8.8	0.03
103094	R2	302.7	0.03
103094	2Q1	160.3	0.01
103094	P1	202.4	0.12
103094	2SM2	86.7	0.01
103094	M3	135.8	0.06
103094	L2	347.2	0.12
103094	2MK3	18.2	0.03
103094	K2	36.9	0.11
103094	M8	111.3	0.01
103094	MS4	245.2	0.05
103095	M2	25.5	3.22
103095	S2	55.8	0.54
103095	N2	11.8	0.68
103095	K1	211.8	0.29
103095	M4	252.2	0.21
103095	O1	206	0.23
103095	M6	108.2	0.05
103095	S4	75.2	0.03
103095	NU2	13.6	0.13
103095	S6	13.1	0.01
103095	MU2	355.2	0.08
103095	2N2	357.9	0.09
103095	OO1	216.2	0.01
103095	LDA2	39.6	0.02
103095	M1	208.4	0.02
103095	J1	213.6	0.02
103095	SSA	51.8	0.2
103095	SA	176	0.28
103095	RHO1	204.5	0.01
103095	Q1	203.4	0.04
103095	T2	54.6	0.03
103095	2Q1	201.8	0.01
103095	P1	211.6	0.1
103095	L2	39.6	0.09
103095	K2	58.3	0.15
103095	M8	336.8	0.01
103096	M2	25	3.6
103096	S2	59.1	0.6
103096	N2	19.1	0.8
103096	K1	197.6	0.4
103096	M4	207.3	0.19
103096	O1	212.4	0.29
103096	M6	98.3	0.11
103096	S4	60.1	0.03
103096	NU2	19.9	0.15
103096	S6	257.8	0.01
103096	MU2	351.1	0.09
103096	2N2	13.3	0.1
103096	OO1	182.3	0.01
103096	LDA2	40.8	0.03
103096	M1	204.9	0.02
103096	J1	190	0.02
103096	SSA	52.9	0.28
103096	SA	174.2	0.36
103096	RHO1	218.7	0.01
103096	Q1	219.7	0.06
103096	T2	57.7	0.04
103096	2Q1	226.8	0.01
103096	P1	198.7	0.13
103096	L2	30.8	0.1
103096	K2	61.8	0.16
103096	M8	291.9	0.02
103097	M2	35.1	3.97
103097	S2	69.9	0.64
103097	N2	28	0.77
103097	K1	205.1	0.43
103097	M4	261.4	0.32
103097	O1	218.3	0.3
103097	M6	223.8	0.1
103097	S4	299.3	0.02
103097	NU2	28.9	0.15
103097	MU2	0.9	0.1
103097	2N2	20.8	0.1
103097	OO1	191.8	0.01
103097	LDA2	50.8	0.03
103097	M1	211.7	0.02
103097	J1	198.5	0.02
103097	SSA	51.8	0.2
103097	SA	176	0.28
103097	RHO1	223.9	0.01
103097	Q1	224.7	0.06
103097	T2	68.4	0.04
103097	R2	72.3	0.01
103097	2Q1	231.2	0.01
103097	P1	206.1	0.14
103097	L2	42.5	0.11
103097	K2	72.7	0.17
103097	M8	6.1	0.04
103098	M2	34.2	3.8
103098	S2	71.3	0.56
103098	N2	22.6	0.76
103098	K1	213.5	0.39
103098	M4	290.5	0.22
103098	O1	216	0.27
103098	M6	201.5	0.05
103098	MK3	53.1	0.05
103098	S4	85.9	0.04
103098	MN4	278.2	0.1
103098	NU2	17.2	0.16
103098	MU2	103.6	0.16
103098	2N2	32.8	0.05
103098	OO1	211	0.01
103098	LDA2	14.1	0.14
103098	S1	169.4	0.07
103098	M1	214.6	0.02
103098	J1	212.3	0.02
103098	SSA	58.8	0.2
103098	SA	173.6	0.29
103098	RHO1	216.9	0.01
103098	Q1	212.6	0.07
103098	T2	65.5	0.08
103098	2Q1	218.3	0.01
103098	P1	211.7	0.13
103098	2SM2	140.5	0.04
103098	M3	173.5	0.1
103098	L2	18.2	0.32
103098	2MK3	63.2	0.04
103098	K2	61.8	0.15
103098	M8	356	0.03
103098	MS4	326	0.12
103099	M2	17.5	3.31
103099	S2	45.3	0.52
103099	N2	2.1	0.74
103099	K1	200	0.36
103099	M4	241.4	0.14
103099	O1	205.2	0.26
103099	M6	76	0.02
103099	MK3	37.9	0.03
103099	S4	43.3	0.02
103099	MN4	234.7	0.07
103099	NU2	357.4	0.15
103099	MU2	48.3	0.1
103099	2N2	351.7	0.1
103099	OO1	232	0.01
103099	LDA2	11.6	0.07
103099	S1	168.5	0.07
103099	M1	231.6	0.01
103099	J1	220.2	0.02
103099	SSA	52.9	0.28
103099	SA	174.2	0.36
103099	RHO1	206.1	0.01
103099	Q1	203.4	0.05
103099	T2	25.9	0.06
103099	R2	291	0.05
103099	2Q1	167.6	0.01
103099	P1	198.6	0.12
103099	2SM2	88.6	0.01
103099	M3	153.4	0.07
103099	L2	9.4	0.19
103099	2MK3	71.1	0.04
103099	K2	45.1	0.13
103099	M8	242.8	0.01
103099	MS4	272.9	0.07
103100	M2	30.7	3.46
103100	S2	52.8	0.69
103100	N2	19.5	0.86
103100	K1	219.5	0.36
103100	M4	214.8	0.22
103100	O1	214.4	0.25
103100	M6	141.7	0.08
103100	S4	47.2	0.02
103100	NU2	21	0.17
103100	S6	41	0.01
103100	MU2	8.6	0.08
103100	2N2	8.3	0.11
103100	OO1	224.5	0.01
103100	LDA2	40.9	0.02
103100	M1	217	0.02
103100	J1	221.9	0.02
103100	SSA	51.8	0.2
103100	SA	176	0.28
103100	RHO1	212.3	0.01
103100	Q1	211.9	0.05
103100	T2	51.9	0.04
103100	R2	53.7	0.01
103100	2Q1	209.5	0.01
103100	P1	219.1	0.12
103100	L2	41.9	0.1
103100	K2	54.6	0.19
103100	M8	271.9	0.02
103101	M2	30.5	3.45
103101	S2	51.7	0.69
103101	N2	19.5	0.85
103101	K1	218.8	0.35
103101	M4	204.7	0.2
103101	O1	214.7	0.25
103101	M6	134.3	0.08
103101	S4	52.9	0.02
103101	NU2	20.9	0.16
103101	S6	32.3	0.01
103101	MU2	9.4	0.08
103101	2N2	8.4	0.11
103101	OO1	222.9	0.01
103101	LDA2	40.3	0.02
103101	M1	216.8	0.02
103101	J1	220.8	0.02
103101	SSA	51.8	0.2
103101	SA	176	0.28
103101	RHO1	212.9	0.01
103101	Q1	212.7	0.05
103101	T2	50.8	0.04
103101	R2	52.5	0.01
103101	2Q1	210.6	0.01
103101	P1	218.5	0.11
103101	L2	41.6	0.1
103101	K2	53.4	0.19
103101	M8	276	0.01
103102	M2	21.2	3.16
103102	S2	41.5	0.63
103102	N2	7	0.76
103102	K1	211	0.33
103102	M4	219.8	0.11
103102	O1	208.7	0.23
103102	M6	96.2	0.05
103102	S4	23.8	0.03
103102	NU2	8.9	0.15
103102	MU2	0.9	0.08
103102	2N2	352.9	0.1
103102	OO1	213.4	0.01
103102	LDA2	30.6	0.02
103102	M1	209.9	0.02
103102	J1	212.2	0.02
103102	SSA	51.8	0.2
103102	SA	176	0.28
103102	RHO1	207.7	0.01
103102	Q1	207.6	0.05
103102	T2	40.7	0.04
103102	R2	42.4	0.01
103102	2Q1	206.4	0.01
103102	P1	210.9	0.11
103102	L2	35.4	0.09
103102	K2	43.2	0.17
103102	M8	146.2	0.01
103103	M2	24.1	3.27
103103	S2	44.6	0.65
103103	N2	11	0.8
103103	K1	214	0.34
103103	M4	215.3	0.14
103103	O1	211.1	0.24
103103	M6	108.8	0.06
103103	S4	37.5	0.02
103103	NU2	12.7	0.15
103103	S6	23.5	0.01
103103	MU2	3.7	0.08
103103	2N2	357.8	0.1
103103	OO1	216.9	0.01
103103	LDA2	33.6	0.02
103103	M1	212.6	0.02
103103	J1	215.4	0.02
103103	SSA	51.8	0.2
103103	SA	176	0.28
103103	RHO1	209.9	0.01
103103	Q1	209.7	0.05
103103	T2	43.7	0.04
103103	R2	45.4	0.01
103103	2Q1	208.3	0.01
103103	P1	213.8	0.11
103103	L2	37.3	0.09
103103	K2	46.2	0.18
103103	M8	171.2	0.01
103104	M2	90.1	2.04
103104	S2	155.6	0.24
103104	N2	115.1	0.33
103104	K1	258.5	0.36
103104	M4	42.5	0.32
103104	O1	269.4	0.26
103104	M6	336.7	0.11
103104	S4	197.4	0.03
103104	NU2	111.6	0.07
103104	S6	200.2	0.01
103104	MU2	24.4	0.05
103104	2N2	140.8	0.05
103104	OO1	248.2	0.01
103104	LDA2	120.7	0.01
103104	M1	264	0.02
103104	J1	253.4	0.02
103104	SSA	52.9	0.28
103104	SA	174.2	0.36
103104	RHO1	273	0.01
103104	Q1	274.9	0.05
103104	T2	153.1	0.01
103104	2Q1	279.9	0.01
103104	P1	259.4	0.12
103104	L2	65.8	0.06
103104	K2	160.8	0.07
103104	M8	289.4	0.02
103105	M2	20.2	3.36
103105	S2	48.6	0.61
103105	N2	7	0.68
103105	K1	202.8	0.3
103105	M4	237.9	0.12
103105	O1	210.1	0.25
103105	M6	137.2	0.05
103105	S4	81.1	0.05
103105	NU2	8.8	0.13
103105	S6	347.1	0.01
103105	MU2	351.5	0.08
103105	2N2	353.8	0.09
103105	OO1	195.2	0.01
103105	LDA2	33.4	0.02
103105	M1	206.3	0.02
103105	J1	199.5	0.02
103105	SSA	52.9	0.28
103105	SA	174.2	0.36
103105	RHO1	213.7	0.01
103105	Q1	213.7	0.05
103105	T2	47.5	0.04
103105	R2	49.4	0.01
103105	2Q1	218.1	0.01
103105	P1	203.3	0.1
103105	L2	33.3	0.1
103105	K2	50.9	0.17
103105	M8	311.8	0.01
103106	M2	28.7	3.46
103106	S2	64.4	0.54
103106	N2	20	0.8
103106	K1	206.5	0.36
103106	M4	245.2	0.17
103106	O1	211	0.27
103106	M6	145.1	0.08
103106	S4	84	0.02
103106	NU2	21.1	0.16
103106	S6	201.2	0.01
103106	MU2	352.8	0.08
103106	2N2	11.2	0.1
103106	OO1	204.8	0.01
103106	LDA2	45.3	0.02
103106	M1	209.5	0.02
103106	J1	206.1	0.02
103106	SSA	51.8	0.2
103106	SA	176	0.28
103106	RHO1	212	0.01
103106	Q1	212.6	0.05
103106	T2	62.9	0.03
103106	2Q1	213.8	0.01
103106	P1	206.8	0.12
103106	L2	37.5	0.1
103106	K2	67.3	0.15
103106	M8	336.5	0.01
103107	M2	37.2	3.41
103107	S2	76.9	0.51
103107	N2	30.8	0.77
103107	K1	212.3	0.37
103107	M4	276.5	0.29
103107	O1	217.9	0.27
103107	M6	177	0.08
103107	S4	82.1	0.02
103107	NU2	31.7	0.15
103107	S6	233.1	0.01
103107	MU2	357.3	0.08
103107	2N2	24.4	0.1
103107	OO1	209.6	0.01
103107	LDA2	55.7	0.02
103107	M1	215.8	0.02
103107	J1	211.5	0.02
103107	SSA	51.8	0.2
103107	SA	176	0.28
103107	RHO1	219.3	0.01
103107	Q1	220	0.05
103107	T2	75.2	0.03
103107	2Q1	221.7	0.01
103107	P1	212.7	0.12
103107	L2	43.6	0.1
103107	K2	80	0.14
103107	M8	353.1	0.01
103108	M2	20.7	3.32
103108	S2	52.9	0.53
103108	N2	8.3	0.8
103108	K1	196.5	0.36
103108	M4	268.2	0.13
103108	O1	205.4	0.26
103108	M6	116.1	0.03
103108	S4	62.7	0.03
103108	NU2	10	0.15
103108	S6	128.5	0.01
103108	MU2	348.4	0.08
103108	2N2	355.9	0.11
103108	OO1	187.8	0.01
103108	LDA2	35.6	0.02
103108	M1	201	0.02
103108	J1	192.3	0.02
103108	SSA	51.8	0.2
103108	SA	176	0.28
103108	RHO1	209.2	0.01
103108	Q1	209.9	0.05
103108	T2	51.7	0.03
103108	2Q1	214.1	0.01
103108	P1	197.2	0.12
103108	L2	33.1	0.09
103108	K2	55.5	0.14
103108	M8	272.6	0.01
103109	M2	23.7	3.29
103109	S2	56	0.51
103109	N2	13.4	0.76
103109	K1	202.8	0.35
103109	M4	265.6	0.1
103109	O1	204.5	0.25
103109	M6	116	0.03
103109	S4	60.6	0.03
103109	NU2	14.7	0.15
103109	MU2	351.4	0.08
103109	2N2	3.1	0.1
103109	OO1	205.3	0.01
103109	LDA2	38.7	0.02
103109	M1	204.5	0.02
103109	J1	205	0.02
103109	SSA	51.8	0.2
103109	SA	176	0.28
103109	RHO1	204.7	0.01
103109	Q1	204.5	0.05
103109	T2	54.6	0.03
103109	2Q1	205.1	0.01
103109	P1	202.9	0.12
103109	L2	34.2	0.09
103109	K2	58.5	0.14
103109	M8	252.2	0.01
103110	M2	31	3.52
103110	S2	67.5	0.56
103110	N2	22.8	0.82
103110	K1	206.7	0.37
103110	M4	258.3	0.15
103110	O1	211.4	0.27
103110	M6	153.7	0.08
103110	S4	93	0.03
103110	NU2	23.8	0.16
103110	S6	189.7	0.01
103110	MU2	354.2	0.09
103110	2N2	14.5	0.11
103110	OO1	204.8	0.01
103110	LDA2	48.1	0.03
103110	M1	209.7	0.02
103110	J1	206.2	0.02
103110	SSA	51.8	0.2
103110	SA	176	0.28
103110	RHO1	212.3	0.01
103110	Q1	212.9	0.05
103110	T2	66	0.03
103110	2Q1	214.1	0.01
103110	P1	207	0.12
103110	L2	39.2	0.1
103110	K2	70.5	0.15
103110	M8	312.5	0.02
103111	M2	27	3.31
103111	S2	60.7	0.5
103111	N2	16.7	0.75
103111	K1	203.2	0.35
103111	M4	280.6	0.13
103111	O1	209.4	0.26
103111	M6	156.7	0.03
103111	S4	58.6	0.02
103111	NU2	18.1	0.14
103111	MU2	353.1	0.08
103111	2N2	6.6	0.1
103111	OO1	200.3	0.01
103111	LDA2	42.7	0.02
103111	M1	207.1	0.02
103111	J1	202.9	0.02
103111	SSA	54.7	0.23
103111	SA	196.6	0.28
103111	RHO1	210.7	0.01
103111	Q1	211.3	0.05
103111	T2	59.3	0.03
103111	2Q1	213.2	0.01
103111	P1	203.6	0.11
103111	L2	37.2	0.09
103111	K2	63.5	0.14
103111	M8	321.9	0.01
103112	M2	41.5	3.83
103112	S2	83.8	0.59
103112	N2	33.4	0.78
103112	K1	209.8	0.46
103112	M4	231.6	0.32
103112	O1	230.2	0.32
103112	M6	144.4	0.05
103112	S4	346.8	0.02
103112	NU2	34.5	0.15
103112	S6	314.8	0.01
103112	MU2	359.2	0.09
103112	2N2	25.3	0.1
103112	OO1	189.5	0.01
103112	LDA2	61.1	0.03
103112	M1	219.9	0.02
103112	J1	199.7	0.03
103112	SSA	54.7	0.23
103112	SA	196.6	0.28
103112	RHO1	238.9	0.01
103112	Q1	240.3	0.06
103112	T2	82.1	0.04
103112	2Q1	250.4	0.01
103112	P1	211.4	0.15
103112	L2	49.6	0.11
103112	K2	87.2	0.16
103112	M8	332.5	0.03
103113	M2	23.4	3.2
103113	S2	51.1	0.52
103113	N2	8.1	0.74
103113	K1	201.2	0.35
103113	M4	303.6	0.09
103113	O1	208	0.25
103113	M6	192.5	0.02
103113	MK3	67.1	0.03
103113	S4	2.2	0.03
103113	MN4	284.4	0.06
103113	NU2	359.6	0.14
103113	MU2	52.6	0.09
103113	2N2	357.4	0.1
103113	OO1	216.3	0.02
103113	LDA2	7.4	0.05
103113	S1	170.3	0.06
103113	M1	213.2	0.01
103113	J1	229.1	0.02
103113	SSA	47.7	0.37
103113	SA	168.2	0.37
103113	RHO1	210.8	0.01
103113	Q1	201.6	0.06
103113	T2	30.3	0.05
103113	R2	291.3	0.02
103113	2Q1	214.6	0.01
103113	P1	202.7	0.12
103113	2SM2	77.2	0.01
103113	M3	171.3	0.05
103113	L2	17.2	0.19
103113	2MK3	96.4	0.03
103113	K2	53.1	0.13
103113	MS4	285.9	0.04
103114	M2	32	3.4
103114	S2	67.3	0.53
103114	N2	21.8	0.79
103114	K1	204.3	0.36
103114	M4	261.8	0.14
103114	O1	212.3	0.26
103114	M6	155.6	0.04
103114	S4	31.5	0.03
103114	NU2	23.2	0.15
103114	MU2	356.5	0.08
103114	2N2	11.7	0.1
103114	OO1	198.8	0.01
103114	LDA2	48.4	0.02
103114	M1	208.9	0.02
103114	J1	202	0.02
103114	SSA	54.7	0.23
103114	SA	196.6	0.28
103114	RHO1	214.6	0.01
103114	Q1	215.9	0.05
103114	T2	65.8	0.03
103114	2Q1	218.2	0.01
103114	P1	204.9	0.12
103114	L2	42.1	0.1
103114	K2	70.1	0.14
103114	M8	326.4	0.01
103115	M2	28.1	3.17
103115	S2	58.6	0.48
103115	N2	15.4	0.73
103115	K1	199.4	0.33
103115	M4	315.3	0.07
103115	O1	208.8	0.25
103115	M6	187.4	0.02
103115	S4	13.8	0.02
103115	NU2	17.1	0.14
103115	S6	346.9	0.01
103115	MU2	357.5	0.08
103115	2N2	2.6	0.1
103115	OO1	191.9	0.01
103115	LDA2	42.3	0.02
103115	M1	204.7	0.02
103115	J1	196.4	0.02
103115	SSA	54.7	0.23
103115	SA	196.6	0.28
103115	RHO1	211.8	0.01
103115	Q1	212.6	0.05
103115	T2	57.5	0.03
103115	2Q1	216.2	0.01
103115	P1	200	0.11
103115	L2	40.9	0.09
103115	K2	61.1	0.13
103115	M8	299.6	0.01
103116	M2	54.8	3.06
103116	S2	94.4	0.45
103116	N2	54.4	0.65
103116	K1	236.3	0.36
103116	M4	348.2	0.26
103116	O1	233.2	0.25
103116	M6	265.3	0.09
103116	S4	81.1	0.02
103116	NU2	54.4	0.12
103116	S6	207.8	0.01
103116	MU2	15.6	0.07
103116	2N2	54	0.09
103116	OO1	238.9	0.01
103116	LDA2	73	0.02
103116	M1	234.5	0.02
103116	J1	237.4	0.02
103116	SSA	54.7	0.23
103116	SA	196.6	0.28
103116	RHO1	231.7	0.01
103116	Q1	232	0.05
103116	T2	92.5	0.03
103116	2Q1	230.2	0.01
103116	P1	236.1	0.12
103116	L2	55.5	0.09
103116	K2	97.5	0.12
103116	M8	123	0.01
103117	M2	36.3	3.12
103117	S2	67.7	0.51
103117	N2	19.7	0.68
103117	K1	209.5	0.35
103117	M4	207.5	0.13
103117	O1	218	0.26
103117	M6	165.8	0.03
103117	MK3	31.7	0.06
103117	S4	353.4	0.02
103117	MN4	205	0.07
103117	NU2	19.2	0.16
103117	MU2	70.2	0.11
103117	2N2	340.1	0.09
103117	OO1	200.9	0.01
103117	LDA2	30.4	0.08
103117	S1	174.3	0.06
103117	M1	261.7	0.03
103117	J1	205.2	0.02
103117	RHO1	221.7	0.01
103117	Q1	217.2	0.06
103117	T2	45.9	0.07
103117	R2	307	0.04
103117	2Q1	226.4	0.01
103117	P1	207.2	0.12
103117	2SM2	96.2	0.01
103117	M3	183	0.03
103117	L2	29.2	0.13
103117	2MK3	45.1	0.03
103117	K2	66.1	0.13
103117	M8	317.4	0.02
103117	MS4	236.8	0.07
103118	M2	38.6	3.02
103118	S2	68.9	0.43
103118	N2	25.6	0.6
103118	K1	212.3	0.35
103118	M4	222.4	0.12
103118	O1	216.7	0.25
103118	M6	176.8	0.05
103118	MK3	43.9	0.04
103118	S4	1.6	0.02
103118	MN4	226	0.05
103118	NU2	11.9	0.14
103118	MU2	83	0.1
103118	2N2	27.6	0.09
103118	OO1	212.3	0.01
103118	LDA2	33.5	0.08
103118	S1	170.6	0.04
103118	M1	248	0.01
103118	J1	195	0.02
103118	SSA	49	0.29
103118	SA	184.8	0.36
103118	RHO1	185.4	0.01
103118	Q1	214.8	0.06
103118	T2	46	0.03
103118	R2	277.9	0.04
103118	2Q1	171.6	0.01
103118	P1	211.5	0.11
103118	2SM2	153.3	0.01
103118	M3	180.7	0.04
103118	L2	25.8	0.15
103118	2MK3	41.4	0.04
103118	K2	61	0.11
103118	M8	315.8	0.01
103118	MS4	249.2	0.05
103119	M2	37.4	3
103119	S2	67	0.46
103119	N2	25.2	0.62
103119	K1	212	0.33
103119	M4	222	0.11
103119	O1	216.9	0.26
103119	M6	161.8	0.03
103119	MK3	36.9	0.05
103119	S4	359.9	0.02
103119	MN4	223.8	0.06
103119	NU2	21.5	0.13
103119	MU2	92.1	0.11
103119	2N2	31.1	0.08
103119	OO1	211.2	0.03
103119	LDA2	16.8	0.07
103119	S1	161.2	0.05
103119	M1	268.7	0.01
103119	J1	276.8	0.02
103119	SSA	54.7	0.23
103119	SA	196.6	0.28
103119	RHO1	201.3	0.02
103119	Q1	210.1	0.04
103119	T2	104.7	0.05
103119	R2	236.8	0.06
103119	2Q1	308.2	0.01
103119	P1	208.8	0.11
103119	2SM2	45.5	0.03
103119	M3	179.2	0.05
103119	L2	15.5	0.16
103119	2MK3	43.8	0.03
103119	K2	48.2	0.14
103119	M8	328	0.02
103119	MS4	247.8	0.06
103120	M2	45.2	2.83
103120	S2	70.9	0.41
103120	N2	39.4	0.56
103120	K1	218.2	0.34
103120	M4	265	0.1
103120	O1	227.6	0.27
103120	M6	195.6	0.04
103120	MK3	64.1	0.05
103120	S4	17.1	0.03
103120	MN4	266.1	0.07
103120	NU2	18.1	0.1
103120	MU2	112.9	0.09
103120	2N2	30.4	0.1
103120	LDA2	19.3	0.07
103120	S1	163	0.05
103120	J1	234.1	0.04
103120	SSA	54.7	0.23
103120	SA	196.6	0.28
103120	Q1	225.7	0.07
103120	T2	67.1	0.09
103120	R2	13.6	0.07
103120	P1	228	0.13
103120	M3	213.1	0.05
103120	L2	26.3	0.19
103120	2MK3	56.6	0.06
103120	K2	60	0.13
103120	M8	2.6	0.02
103120	MS4	283.9	0.05
103121	M2	59.7	2.37
103121	S2	98	0.3
103121	N2	57.8	0.41
103121	K1	221.8	0.29
103121	M4	321.3	0.14
103121	O1	248.5	0.22
103121	M6	248.6	0.07
103121	S4	28.5	0.01
103121	NU2	58	0.08
103121	S6	135.8	0.01
103121	MU2	21.8	0.06
103121	2N2	55.7	0.05
103121	OO1	198.5	0.01
103121	LDA2	77.4	0.02
103121	M1	235.2	0.02
103121	J1	210.3	0.02
103121	SSA	54.7	0.23
103121	SA	196.6	0.28
103121	RHO1	259.6	0.01
103121	Q1	261.3	0.04
103121	T2	96.5	0.02
103121	2Q1	271.6	0.01
103121	P1	223.8	0.1
103121	L2	61.4	0.07
103121	K2	101.1	0.08
103121	M8	79.2	0.02
103122	M2	26.8	2.93
103122	S2	57.3	0.19
103122	N2	9.9	0.623
103122	K1	200.7	0.404
103122	M4	152.4	0.062
103122	O1	216	0.272
103122	M6	153.3	0.023
103122	MK3	24	0.036
103122	S4	340.6	0.026
103122	MN4	170.4	0.033
103122	NU2	357.6	0.118
103122	S6	42.4	0.003
103122	MU2	52.6	0.079
103122	2N2	351.8	0.079
103122	OO1	183.1	0.036
103122	LDA2	358.3	0.046
103122	S1	141.4	0.098
103122	M1	230.7	0.023
103122	J1	224.2	0.013
103122	SSA	54.7	0.23
103122	SA	119.6	0.282
103122	RHO1	353.4	0.013
103122	Q1	215.1	0.062
103122	T2	2.2	0.138
103122	R2	291.4	0.272
103122	2Q1	125.3	0.01
103122	P1	186.1	0.098
103122	2SM2	138.1	0.003
103122	M3	160	0.039
103122	L2	27	0.135
103122	2MK3	356.2	0.01
103122	K2	146.4	0.089
103122	M8	273.6	0.013
103122	MS4	203.3	0.039
103123	M2	16.3	2.81
103123	S2	37.6	0.44
103123	N2	353.7	0.62
103123	K1	192.8	0.34
103123	M4	354.5	0.03
103123	O1	205.4	0.25
103123	M6	138.1	0.01
103123	MK3	86.1	0.01
103123	S4	293.7	0.02
103123	MN4	310.8	0.02
103123	NU2	1.3	0.12
103123	MU2	4.2	0.09
103123	2N2	339.8	0.07
103123	OO1	207.4	0.03
103123	LDA2	24	0.03
103123	S1	156.3	0.05
103123	M1	216.1	0.01
103123	J1	199.5	0.02
103123	SSA	54.7	0.23
103123	SA	119.6	0.28
103123	RHO1	264.9	0.02
103123	Q1	193.4	0.05
103123	T2	23.5	0.05
103123	R2	257.6	0.03
103123	P1	190.3	0.12
103123	2SM2	31.8	0.02
103123	M3	154.1	0.04
103123	L2	45.2	0.06
103123	2MK3	157.3	0.03
103123	K2	41.6	0.1
103123	MS4	123.2	0.01
103124	M2	41	2.99
103124	S2	75.6	0.46
103124	N2	38	0.6
103124	K1	208.7	0.34
103124	M4	218.4	0.16
103124	O1	225	0.29
103124	M6	149.1	0.02
103124	S4	27.6	0.04
103124	NU2	38.4	0.11
103124	S6	304.9	0.01
103124	MU2	202.9	0.07
103124	2N2	34.8	0.08
103124	OO1	196.7	0.01
103124	LDA2	57.3	0.02
103124	M1	217.8	0.02
103124	J1	203.7	0.02
103124	SSA	54.7	0.23
103124	SA	196.6	0.28
103124	RHO1	231.2	0.01
103124	Q1	232.2	0.06
103124	T2	74.2	0.03
103124	2Q1	239.3	0.01
103124	P1	209.9	0.11
103124	L2	44.4	0.08
103124	K2	78.4	0.12
103124	M8	320.4	0.03
103125	M2	33.7	2.85
103125	S2	62.1	0.44
103125	N2	17.8	0.64
103125	K1	209.1	0.34
103125	M4	203.7	0.1
103125	O1	214.4	0.25
103125	M6	140	0.03
103125	MK3	41	0.04
103125	S4	338.4	0.02
103125	MN4	201.4	0.05
103125	NU2	13.3	0.13
103125	MU2	65.4	0.08
103125	2N2	6.6	0.09
103125	OO1	223	0.01
103125	LDA2	29.5	0.05
103125	S1	168.5	0.05
103125	M1	238.4	0.01
103125	J1	235.6	0.02
103125	SSA	49	0.29
103125	SA	184.8	0.36
103125	RHO1	212.4	0.01
103125	Q1	210.2	0.05
103125	T2	38.3	0.05
103125	R2	304	0.04
103125	2Q1	176.4	0.01
103125	P1	207.9	0.11
103125	2SM2	99.1	0.01
103125	M3	192.7	0.03
103125	L2	28.7	0.17
103125	2MK3	58.3	0.03
103125	K2	61.9	0.1
103125	M8	290.9	0.01
103125	MS4	230.7	0.05
103126	M2	43.4	2.92
103126	S2	73.5	0.45
103126	N2	33.9	0.61
103126	K1	225.9	0.37
103126	M4	230.8	0.15
103126	O1	215.8	0.23
103126	M6	92	0.03
103126	S4	356.7	0.03
103126	NU2	35.2	0.12
103126	S6	146.8	0.01
103126	MU2	210.1	0.07
103126	2N2	24.4	0.08
103126	OO1	235.8	0.01
103126	LDA2	57.4	0.02
103126	M1	220.8	0.02
103126	J1	230.7	0.02
103126	SSA	54.7	0.23
103126	SA	196.6	0.28
103126	RHO1	211.5	0.01
103126	Q1	210.9	0.05
103126	T2	72.3	0.03
103126	2Q1	205.9	0.01
103126	P1	225.1	0.12
103126	L2	52.8	0.08
103126	K2	75.9	0.12
103126	M8	297.5	0.03
103127	M2	157.5	1
103127	S2	221.7	0.03
103127	N2	168.2	0.24
103127	K1	312.6	0.26
103127	M4	145.1	0.16
103127	O1	322	0.17
103127	M6	134.7	0.04
103127	S4	155.9	0.02
103127	NU2	166.7	0.05
103127	S6	190.3	0.01
103127	MU2	290	0.02
103127	2N2	178.9	0.03
103127	OO1	303.2	0.01
103127	LDA2	187.3	0.01
103127	M1	317.3	0.01
103127	J1	307.9	0.01
103127	RHO1	326.1	0.01
103127	Q1	326.7	0.03
103127	P1	313.3	0.09
103127	L2	146.7	0.03
103127	K2	226.9	0.01
103127	M8	102.2	0.01
103128	M2	51.9	2.17
103128	S2	86.6	0.23
103128	N2	40.3	0.38
103128	K1	231.2	0.34
103128	M4	355	0.15
103128	O1	229.2	0.36
103128	M6	184.1	0.06
103128	S4	231.1	0.01
103128	NU2	41.8	0.08
103128	MU2	17.2	0.05
103128	2N2	28.6	0.05
103128	OO1	233.1	0.02
103128	LDA2	68	0.02
103128	M1	230.2	0.03
103128	J1	232.1	0.03
103128	RHO1	228.4	0.01
103128	Q1	228.2	0.07
103128	T2	85.2	0.01
103128	2Q1	227.3	0.01
103128	P1	231	0.11
103128	L2	63.5	0.06
103128	K2	89.4	0.06
103128	M8	133.9	0.01
103129	M2	75.9	2.09
103129	S2	117.9	0.28
103129	N2	66.7	0.4
103129	K1	241.3	0.3
103129	M4	5.7	0.16
103129	O1	245.9	0.24
103129	M6	255.1	0.08
103129	MK3	115.2	0.07
103129	S4	75.2	0.02
103129	MN4	353.9	0.08
103129	NU2	53.6	0.14
103129	MU2	147.8	0.11
103129	2N2	18.8	0.06
103129	OO1	272.6	0.01
103129	LDA2	65.7	0.04
103129	S1	221.8	0.03
103129	M1	340.8	0.03
103129	J1	309.4	0.01
103129	RHO1	240.2	0.02
103129	Q1	247.8	0.06
103129	T2	95	0.05
103129	R2	320.8	0.03
103129	2Q1	192.5	0.01
103129	P1	238.1	0.09
103129	2SM2	56.8	0.02
103129	M3	221.6	0.02
103129	L2	70.3	0.16
103129	2MK3	111.7	0.06
103129	K2	115.7	0.06
103129	M8	150.2	0.02
103129	MS4	37.1	0.05
103130	M2	68.3	1.45
103130	S2	100.6	0.19
103130	N2	56.3	0.3
103130	K1	247.3	0.15
103130	M4	47.1	0.08
103130	O1	243.7	0.11
103130	M6	351.4	0.06
103130	S4	11	0.01
103130	NU2	58	0.06
103130	MU2	35.4	0.04
103130	2N2	44.4	0.04
103130	LDA2	83.5	0.01
103130	M1	245.1	0.01
103130	J1	248.8	0.01
103130	MM	227.6	0.08
103130	SSA	54.9	0.25
103130	SA	189.9	0.38
103130	MSF	197.6	0.13
103130	Q1	242.4	0.02
103130	T2	99.2	0.01
103130	P1	246.9	0.05
103130	L2	80.7	0.04
103130	K2	103.2	0.05
103130	M8	23.9	0.01
103131	M2	46.3	2.1
103131	S2	75.7	0.31
103131	N2	36.4	0.43
103131	K1	228.1	0.28
103131	M4	282.3	0.08
103131	O1	220.6	0.19
103131	M6	266.5	0.03
103131	S4	339.7	0.02
103131	NU2	37.7	0.08
103131	MU2	16.9	0.05
103131	2N2	26.5	0.06
103131	LDA2	59.8	0.01
103131	M1	224.2	0.01
103131	J1	231.4	0.02
103131	SSA	55.4	0.25
103131	SA	190.2	0.38
103131	Q1	217.2	0.04
103131	T2	74.4	0.02
103131	P1	227.5	0.09
103131	L2	56.1	0.06
103131	K2	78.1	0.09
103131	M8	16.4	0.01
103132	M2	45.6	1.77
103132	S2	72.4	0.24
103132	N2	32.2	0.36
103132	K1	225.2	0.21
103132	M4	19.3	0.03
103132	O1	219.3	0.15
103132	M6	270.5	0.06
103132	S4	347.3	0.02
103132	NU2	34	0.07
103132	S6	68.7	0.01
103132	MU2	18.9	0.04
103132	2N2	18.7	0.05
103132	OO1	230.6	0.01
103132	LDA2	58	0.01
103132	M1	222.4	0.01
103132	J1	229.3	0.01
103132	MM	227.6	0.08
103132	SSA	54.9	0.25
103132	SA	189.9	0.38
103132	MSF	197.6	0.13
103132	RHO1	216.5	0.01
103132	Q1	216	0.03
103132	T2	71.2	0.01
103132	P1	224.8	0.07
103132	L2	59.1	0.05
103132	K2	74.6	0.07
103132	M8	301.9	0.01
103133	M2	20.9	2.31
103133	S2	43.6	0.37
103133	N2	5.6	0.52
103133	K1	199.7	0.29
103133	M4	152.3	0.09
103133	O1	205.6	0.21
103133	M6	179.2	0.02
103133	MK3	30.2	0.02
103133	S4	292.6	0.02
103133	MN4	163.2	0.03
103133	NU2	355.7	0.11
103133	MU2	17	0.06
103133	2N2	345.5	0.07
103133	OO1	193.7	0.01
103133	LDA2	29.7	0.03
103133	S1	156.8	0.03
103133	M1	230.1	0.02
103133	J1	219.2	0.01
103133	MM	230.4	0.08
103133	SSA	55.4	0.25
103133	SA	190.2	0.38
103133	MSF	202.7	0.13
103133	RHO1	208.1	0.01
103133	Q1	199.7	0.04
103133	T2	35.4	0.04
103133	2Q1	211.4	0.01
103133	P1	197.3	0.1
103133	2SM2	84.7	0.02
103133	M3	174.2	0.03
103133	L2	11.2	0.08
103133	2MK3	37.8	0.02
103133	K2	41.3	0.1
103133	MS4	162.2	0.04
103134	M2	80.1	1.31
103134	S2	115.5	0.17
103134	N2	72.5	0.25
103134	K1	255.8	0.16
103134	M4	90.4	0.02
103134	O1	245.5	0.09
103134	M6	50.8	0.08
103134	S4	47.4	0.01
103134	NU2	73.6	0.05
103134	MU2	44.5	0.03
103134	2N2	65	0.03
103134	LDA2	96.5	0.01
103134	M1	251.4	0.01
103134	SSA	55.4	0.25
103134	SA	190.2	0.38
103134	Q1	239.6	0.02
103134	T2	114	0.01
103134	P1	255	0.05
103134	L2	87.5	0.04
103134	K2	118.3	0.05
103134	M8	322.2	0.01
103135	M2	20	2.35
103135	S2	43.5	0.38
103135	N2	357.5	0.52
103135	K1	192.1	0.27
103135	M4	117.4	0.04
103135	O1	205.6	0.21
103135	M6	133	0.01
103135	MK3	23.7	0.01
103135	S4	276.1	0.01
103135	MN4	107	0.01
103135	NU2	351.9	0.1
103135	MU2	9.7	0.07
103135	2N2	353.2	0.06
103135	OO1	203.8	0.02
103135	LDA2	66.2	0.02
103135	S1	172.4	0.07
103135	M1	235.8	0.01
103135	J1	206	0.01
103135	MM	230.4	0.08
103135	SSA	55.4	0.25
103135	SA	190.2	0.38
103135	MSF	202.7	0.13
103135	RHO1	249.8	0.02
103135	Q1	196.2	0.05
103135	T2	50.4	0.05
103135	R2	290.1	0.04
103135	2Q1	69.7	0.01
103135	P1	197.9	0.1
103135	2SM2	28.2	0.02
103135	M3	151.4	0.02
103135	L2	55.8	0.04
103135	2MK3	150.8	0.02
103135	K2	40.8	0.09
103135	M8	325.3	0.01
103135	MS4	139	0.03
103136	M2	26.4	2.19
103136	S2	49.9	0.34
103136	N2	8.2	0.47
103136	K1	204.3	0.28
103136	M4	163.8	0.1
103136	O1	211	0.19
103136	M6	195.7	0.03
103136	MK3	22.2	0.03
103136	S4	288.9	0.01
103136	MN4	161.2	0.03
103136	NU2	5.8	0.1
103136	MU2	30.9	0.05
103136	2N2	349.2	0.06
103136	OO1	245.5	0.01
103136	LDA2	39.4	0.03
103136	S1	170.8	0.04
103136	M1	249.7	0.01
103136	J1	209.2	0.02
103136	SSA	52.8	0.31
103136	SA	188.2	0.37
103136	RHO1	240.4	0.01
103136	Q1	207.6	0.04
103136	T2	40.1	0.04
103136	R2	285.7	0.02
103136	2Q1	198.4	0.01
103136	P1	201	0.1
103136	2SM2	73.3	0.01
103136	M3	155.8	0.03
103136	L2	29.9	0.08
103136	2MK3	44.8	0.02
103136	K2	47.6	0.09
103136	M8	353.1	0.01
103136	MS4	179.7	0.04
103137	M2	49.5	1.73
103137	S2	77.9	0.25
103137	N2	32.9	0.35
103137	K1	219	0.2
103137	M4	302.2	0.05
103137	O1	225	0.14
103137	M6	297.9	0.07
103137	MK3	76.5	0.04
103137	S4	353.2	0.01
103137	MN4	284.8	0.03
103137	NU2	29.8	0.08
103137	MU2	120.6	0.03
103137	2N2	17.2	0.04
103137	OO1	229.1	0.01
103137	LDA2	46.5	0.04
103137	S1	205.4	0.03
103137	J1	228.2	0.01
103137	SSA	52.8	0.31
103137	SA	188.2	0.37
103137	Q1	219.5	0.03
103137	T2	64.2	0.04
103137	R2	321	0.02
103137	P1	216.8	0.07
103137	2SM2	115.2	0.01
103137	M3	206	0.01
103137	L2	52.9	0.12
103137	2MK3	74.8	0.04
103137	K2	75.2	0.06
103137	M8	42.9	0.01
103137	MS4	280.5	0.02
103138	M2	28.1	2.17
103138	S2	51.5	0.36
103138	N2	10.1	0.49
103138	K1	203.9	0.27
103138	M4	170.5	0.08
103138	O1	212.2	0.2
103138	M6	212.2	0.03
103138	MK3	38.3	0.03
103138	MN4	171.4	0.03
103138	NU2	6.6	0.11
103138	MU2	28.6	0.06
103138	2N2	5.6	0.06
103138	OO1	195.5	0.01
103138	LDA2	34.1	0.04
103138	S1	164.2	0.03
103138	M1	208	0.01
103138	J1	199.8	0.02
103138	MM	230.4	0.08
103138	SSA	55.4	0.25
103138	SA	190.2	0.38
103138	MSF	202.7	0.13
103138	RHO1	215.8	0.01
103138	Q1	201	0.04
103138	T2	51.4	0.02
103138	2Q1	220.5	0.01
103138	P1	196.3	0.09
103138	L2	28.9	0.12
103138	K2	50	0.1
103138	MS4	180.9	0.04
103139	M2	27.5	2.15
103139	S2	49.5	0.3
103139	N2	8.7	0.46
103139	K1	205	0.27
103139	M4	160	0.09
103139	O1	213.1	0.19
103139	M6	195.8	0.04
103139	MK3	19.1	0.03
103139	S4	299.8	0.02
103139	MN4	164.1	0.04
103139	NU2	1.2	0.09
103139	S6	16.4	0.01
103139	MU2	55.9	0.04
103139	2N2	5.9	0.06
103139	OO1	172.8	0.04
103139	LDA2	22.2	0.03
103139	S1	162	0.03
103139	M1	235.6	0.01
103139	J1	155	0.01
103139	MM	230.4	0.08
103139	SSA	55.4	0.25
103139	SA	190.2	0.38
103139	MSF	202.7	0.13
103139	MF	116.2	0.15
103139	RHO1	256.2	0.01
103139	Q1	201.3	0.05
103139	T2	61.3	0.04
103139	R2	197.5	0.01
103139	2Q1	312.9	0.01
103139	P1	191.4	0.09
103139	M3	157.3	0.03
103139	L2	50.3	0.09
103139	2MK3	27.2	0.02
103139	K2	38.5	0.09
103139	M8	350.6	0.01
103139	MS4	175	0.03
103140	M2	61	1.26
103140	S2	87.3	0.19
103140	N2	52.4	0.24
103140	K1	242.1	0.14
103140	M4	63.7	0.06
103140	O1	234.3	0.11
103140	M6	331	0.07
103140	S4	25.1	0.01
103140	NU2	53.5	0.05
103140	MU2	231.5	0.03
103140	2N2	43.8	0.03
103140	LDA2	73.1	0.01
103140	M1	238.1	0.01
103140	J1	245.7	0.01
103140	SSA	55.4	0.25
103140	SA	190.2	0.38
103140	Q1	230.5	0.02
103140	T2	86.3	0.01
103140	P1	241.4	0.05
103140	L2	69.3	0.04
103140	K2	89.5	0.05
103140	M8	40.9	0.01
103141	M2	74.5	0.88
103141	S2	105	0.12
103141	N2	56.3	0.16
103141	K1	247.2	0.09
103141	M4	351.9	0.06
103141	O1	256.4	0.07
103141	M6	10.5	0.05
103141	MK3	124.5	0.03
103141	S4	53.9	0.01
103141	MN4	341.1	0.03
103141	NU2	57	0.04
103141	MU2	158.8	0.02
103141	2N2	30.4	0.02
103141	LDA2	77.6	0.03
103141	S1	221.5	0.02
103141	MM	344.6	0.04
103141	SSA	54.6	0.34
103141	SA	206.2	0.51
103141	MSF	257.5	0.06
103141	Q1	244.9	0.01
103141	T2	103.2	0.02
103141	R2	335.1	0.01
103141	P1	242.3	0.04
103141	M3	230.5	0.01
103141	L2	77	0.07
103141	2MK3	121.8	0.03
103141	K2	99.3	0.03
103141	M8	333	0.01
103141	MS4	11.8	0.01
103142	M2	64.3	1.24
103142	S2	95.2	0.17
103142	N2	49.7	0.26
103142	K1	230.4	0.14
103142	M4	41.9	0.05
103142	O1	240.2	0.1
103142	M6	334.3	0.07
103142	MK3	110.7	0.03
103142	S4	33.8	0.01
103142	MN4	10.5	0.03
103142	NU2	40.7	0.05
103142	MU2	155.2	0.03
103142	2N2	63.2	0.03
103142	OO1	264.8	0.01
103142	LDA2	78	0.04
103142	S1	198.6	0.02
103142	M1	252.3	0.01
103142	J1	244.3	0.01
103142	MM	344.9	0.08
103142	SSA	27.9	0.29
103142	SA	159.5	0.5
103142	MSF	321	0.05
103142	MF	308	0.02
103142	Q1	231.4	0.02
103142	T2	51.8	0.03
103142	P1	227.6	0.05
103142	L2	67.6	0.16
103142	2MK3	109.6	0.03
103142	K2	96.9	0.05
103142	M8	42.6	0.01
103142	MS4	74.6	0.01
103143	M2	15.6	2.48
103143	S2	35.1	0.4
103143	N2	352.9	0.58
103143	K1	193.1	0.36
103143	M4	19.1	0.04
103143	O1	205.5	0.26
103143	M6	92.2	0.02
103143	S4	293.6	0.02
103143	NU2	356	0.11
103143	S6	290.5	0.01
103143	MU2	193.2	0.06
103143	2N2	330.2	0.08
103143	OO1	180.8	0.01
103143	LDA2	24.8	0.02
103143	M1	199.3	0.02
103143	J1	187.1	0.02
103143	SSA	52	0.2
103143	SA	193.3	0.33
103143	RHO1	210.9	0.01
103143	Q1	211.7	0.05
103143	T2	34.3	0.02
103143	2Q1	217.8	0.01
103143	P1	194.1	0.12
103143	L2	38.4	0.07
103143	K2	36.7	0.11
103143	M8	332.2	0.01
103144	M2	108.5	0.44
103144	S2	135.1	0.05
103144	N2	94.1	0.08
103144	K1	279.9	0.07
103144	M4	189.5	0.03
103144	O1	282.4	0.05
103144	M6	120.9	0.03
103144	MK3	174.9	0.01
103144	MN4	158.8	0.01
103144	NU2	94	0.02
103144	MU2	210	0.01
103144	2N2	82.9	0.01
103144	LDA2	114.1	0.01
103144	S1	240.4	0.02
103144	SSA	68.1	0.28
103144	SA	191.3	0.45
103144	Q1	277.5	0.01
103144	T2	121.3	0.01
103144	2Q1	291.3	0.01
103144	P1	269.2	0.02
103144	M3	280.9	0.01
103144	L2	115.8	0.04
103144	2MK3	161.9	0.01
103144	K2	136.4	0.02
103144	MS4	251.7	0.01
103145	M2	130.1	0.4
103145	S2	168.9	0.05
103145	N2	121.6	0.07
103145	K1	286.2	0.07
103145	M4	219.2	0.04
103145	O1	294.7	0.05
103145	M6	184.8	0.05
103145	NU2	123	0.01
103145	MU2	91.1	0.01
103145	2N2	113.1	0.01
103145	Q1	303.1	0.01
103145	P1	286.1	0.02
103145	L2	139.7	0.01
103145	K2	172.3	0.01
103145	M8	288.8	0.01
103146	M2	154.8	0.46
103146	S2	183.5	0.05
103146	N2	145.9	0.09
103146	K1	292.3	0.07
103146	M4	252.9	0.03
103146	O1	296.5	0.06
103146	M6	234.1	0.03
103146	NU2	147.4	0.02
103146	MU2	126.8	0.01
103146	2N2	136.7	0.01
103146	SSA	68.1	0.28
103146	SA	191.3	0.45
103146	Q1	299.2	0.01
103146	P1	292.3	0.02
103146	L2	164.8	0.01
103146	K2	186.1	0.01
103147	M2	53.4	1.97
103147	S2	85.1	0.26
103147	N2	41.4	0.37
103147	K1	223.9	0.31
103147	M4	270	0.11
103147	O1	228	0.24
103147	M6	160.5	0.08
103147	MK3	80.4	0.06
103147	S4	338.6	0.01
103147	MN4	263.6	0.05
103147	NU2	25.4	0.11
103147	MU2	126	0.07
103147	2N2	14.2	0.09
103147	OO1	226.6	0.01
103147	LDA2	52.1	0.04
103147	S1	190.8	0.04
103147	M1	316.3	0.02
103147	J1	254	0.02
103147	SSA	52.8	0.31
103147	SA	188.2	0.37
103147	RHO1	251.7	0.01
103147	Q1	213.9	0.06
103147	T2	50.3	0.04
103147	R2	334.9	0.04
103147	P1	220.9	0.1
103147	2SM2	112.4	0.01
103147	M3	224.8	0.01
103147	L2	37.6	0.1
103147	2MK3	77.3	0.06
103147	K2	83.9	0.06
103147	M8	350.7	0.01
103147	MS4	294.1	0.03
103148	M2	168.9	0.41
103148	S2	202.3	0.05
103148	N2	155.4	0.08
103148	K1	302.8	0.07
103148	M4	247.3	0.02
103148	O1	305.6	0.06
103148	M6	233.8	0.03
103148	MK3	234.8	0.01
103148	MN4	221.5	0.01
103148	NU2	146.9	0.02
103148	MU2	298.4	0.01
103148	2N2	114.3	0.01
103148	LDA2	179.1	0.01
103148	S1	252.9	0.02
103148	M1	45.5	0.01
103148	Q1	312.2	0.01
103148	T2	176.3	0.01
103148	P1	295.8	0.02
103148	L2	162.8	0.03
103148	2MK3	227	0.01
103148	K2	196.4	0.01
103148	M8	317.1	0.01
103149	M2	27.8	2.04
103149	S2	50.8	0.31
103149	N2	12.7	0.47
103149	K1	206.5	0.31
103149	M4	171.8	0.01
103149	O1	212.1	0.23
103149	M6	120.9	0.04
103149	MK3	76.4	0.02
103149	S4	286.4	0.02
103149	MN4	196.2	0.01
103149	NU2	8.1	0.1
103149	S6	300.8	0.01
103149	MU2	34	0.05
103149	2N2	345.7	0.06
103149	OO1	232.3	0.01
103149	LDA2	56.5	0.03
103149	S1	162.1	0.04
103149	M1	265.5	0.01
103149	J1	207.9	0.02
103149	MM	100.4	0.16
103149	SSA	14.7	0.29
103149	SA	204.9	0.5
103149	MSF	132.6	0.1
103149	MF	98.4	0.06
103149	RHO1	215	0.01
103149	Q1	209.4	0.05
103149	T2	17.7	0.03
103149	R2	286.3	0.02
103149	2Q1	195.4	0.01
103149	P1	200.9	0.1
103149	M3	179.3	0.01
103149	L2	19.1	0.08
103149	2MK3	76.5	0.02
103149	K2	50.1	0.08
103149	MS4	131.3	0.02
103150	M2	35	2.02
103150	S2	57.9	0.31
103150	N2	20.9	0.45
103150	K1	213.7	0.33
103150	M4	235.9	0.02
103150	O1	217.4	0.23
103150	M6	129.5	0.05
103150	MK3	66.8	0.03
103150	S4	300.5	0.03
103150	MN4	211.7	0.02
103150	NU2	20.7	0.1
103150	S6	322.9	0.01
103150	MU2	57.2	0.06
103150	2N2	353.3	0.04
103150	OO1	250.8	0.01
103150	LDA2	62.6	0.03
103150	S1	186.2	0.03
103150	M1	254.4	0.02
103150	J1	236.8	0.02
103150	RHO1	221.3	0.01
103150	Q1	216.5	0.05
103150	T2	55.9	0.03
103150	R2	326.5	0.03
103150	2Q1	226.3	0.01
103150	P1	209.8	0.11
103150	M3	231.9	0.01
103150	L2	14.3	0.09
103150	2MK3	60.9	0.02
103150	K2	62.9	0.07
103150	MS4	186.4	0.02
103151	M2	14.9	2.23
103151	S2	34.5	0.37
103151	N2	352.4	0.52
103151	K1	195.3	0.34
103151	M4	54.6	0.04
103151	O1	202.4	0.24
103151	M6	90.8	0.02
103151	MK3	123.8	0.01
103151	S4	258.2	0.02
103151	MN4	42.1	0.01
103151	NU2	354.5	0.1
103151	MU2	357.9	0.07
103151	2N2	333.6	0.07
103151	OO1	196	0.01
103151	LDA2	29.2	0.02
103151	S1	193.4	0.03
103151	M1	211.8	0.01
103151	J1	212.1	0.02
103151	SSA	52	0.2
103151	SA	193.3	0.33
103151	RHO1	212.3	0.01
103151	Q1	196.7	0.05
103151	T2	32.6	0.04
103151	R2	265.2	0.02
103151	2Q1	209.5	0.01
103151	P1	192	0.11
103151	2SM2	48.5	0.01
103151	M3	124.8	0.02
103151	L2	49.8	0.07
103151	2MK3	134	0.02
103151	K2	37.2	0.09
103151	MS4	96.5	0.03
103152	M2	207.9	0.52
103152	S2	244.3	0.05
103152	N2	188.4	0.08
103152	K1	315.7	0.07
103152	M4	338.6	0.02
103152	O1	320.3	0.06
103152	M6	340.4	0.03
103152	MK3	316.5	0.01
103152	MN4	312.9	0.01
103152	NU2	189.9	0.02
103152	MU2	333.1	0.02
103152	LDA2	224.9	0.02
103152	S1	290.8	0.01
103152	SSA	55.4	0.25
103152	SA	190.2	0.38
103152	Q1	331.7	0.01
103152	T2	210.8	0.01
103152	P1	305.8	0.02
103152	M3	39.2	0.01
103152	L2	226.8	0.05
103152	2MK3	298	0.01
103152	K2	233.5	0.02
103152	M8	94.5	0.01
103153	M2	54.9	1.88
103153	S2	88	0.27
103153	N2	44.5	0.4
103153	K1	225.1	0.3
103153	M4	1.3	0.09
103153	O1	227.9	0.24
103153	M6	203.9	0.1
103153	MK3	107.5	0.03
103153	S4	16.3	0.02
103153	MN4	338.2	0.04
103153	NU2	31.6	0.1
103153	S6	1.3	0.01
103153	MU2	109.4	0.06
103153	2N2	20.5	0.05
103153	OO1	262.3	0.01
103153	LDA2	44.5	0.05
103153	S1	196.3	0.03
103153	M1	288.3	0.02
103153	J1	258	0.01
103153	MM	74.8	0.19
103153	SSA	14.8	0.27
103153	SA	209	0.42
103153	MSF	148.2	0.02
103153	MF	302.3	0.01
103153	RHO1	226.5	0.01
103153	Q1	221.7	0.05
103153	T2	82.4	0.02
103153	R2	331.4	0.01
103153	2Q1	247.4	0.01
103153	P1	221.8	0.09
103153	2SM2	146.7	0.01
103153	M3	244	0.01
103153	L2	39	0.1
103153	2MK3	95.2	0.03
103153	K2	87.1	0.08
103153	M8	88.7	0.01
103153	MS4	51.3	0.01
103154	M2	25.1	1.69
103154	S2	47.4	0.26
103154	N2	7.3	0.38
103154	K1	215.1	0.28
103154	M4	0.6	0.05
103154	O1	202.6	0.19
103154	M6	137.8	0.03
103154	S4	219.8	0.01
103154	NU2	9.6	0.08
103154	S6	84.2	0.01
103154	MU2	200.4	0.04
103154	2N2	349.4	0.05
103154	OO1	227.6	0.01
103154	LDA2	35.4	0.01
103154	M1	208.9	0.01
103154	J1	221.3	0.02
103154	SSA	52	0.2
103154	SA	193.3	0.33
103154	RHO1	197.2	0.01
103154	Q1	196.4	0.04
103154	T2	46.5	0.02
103154	2Q1	190.2	0.01
103154	P1	214.2	0.09
103154	L2	42.9	0.05
103154	K2	49.2	0.07
103154	M8	11	0.01
103155	M2	104	0.68
103155	S2	139.5	0.08
103155	N2	101.1	0.13
103155	K1	264.1	0.16
103155	M4	89.4	0.04
103155	O1	265.8	0.13
103155	M6	2.2	0.03
103155	MK3	168.7	0.01
103155	MN4	78.6	0.02
103155	NU2	95.3	0.04
103155	MU2	186.2	0.04
103155	2N2	46.3	0.01
103155	LDA2	108.3	0.03
103155	S1	244	0.03
103155	M1	341.1	0.01
103155	MM	79.2	0.19
103155	SSA	22.6	0.28
103155	SA	206.9	0.48
103155	MSF	82	0.1
103155	MF	113	0.07
103155	RHO1	263.3	0.01
103155	Q1	260.3	0.03
103155	T2	134.5	0.01
103155	R2	32.9	0.01
103155	P1	257.6	0.05
103155	2SM2	299.3	0.01
103155	L2	93.9	0.05
103155	2MK3	156.6	0.01
103155	K2	131.6	0.02
103155	MS4	134.1	0.01
103156	M2	242.9	0.53
103156	S2	284.1	0.06
103156	N2	227.3	0.09
103156	K1	333.6	0.06
103156	M4	82.5	0.06
103156	O1	340.4	0.04
103156	M6	170.4	0.05
103156	MK3	13.5	0.01
103156	MN4	62.7	0.02
103156	NU2	225.2	0.03
103156	MU2	355.6	0.02
103156	2N2	189	0.01
103156	LDA2	261.5	0.01
103156	S1	338.8	0.01
103156	M1	74.6	0.01
103156	MM	128.2	0.15
103156	SSA	13.2	0.37
103156	SA	212.6	0.62
103156	MSF	122	0.06
103156	MF	113.1	0.04
103156	Q1	357.8	0.01
103156	T2	212.6	0.01
103156	P1	355.9	0.01
103156	2SM2	87.2	0.01
103156	M3	101.9	0.01
103156	L2	250.4	0.04
103156	2MK3	4.4	0.02
103156	K2	270.5	0.02
103156	M8	355.1	0.01
103156	MS4	132.3	0.01
103157	M2	227.3	0.63
103157	S2	265.7	0.07
103157	N2	213.9	0.1
103157	K1	324.7	0.07
103157	M4	37.8	0.05
103157	O1	330.9	0.05
103157	M6	96.7	0.05
103157	MK3	350.7	0.01
103157	MN4	16.3	0.01
103157	NU2	208.1	0.03
103157	MU2	344.3	0.03
103157	2N2	168.8	0.02
103157	LDA2	243.8	0.02
103157	S1	324.7	0.01
103157	M1	61.8	0.01
103157	MM	126.1	0.16
103157	SSA	15.6	0.33
103157	SA	213.2	0.58
103157	MSF	107.3	0.06
103157	MF	104.8	0.04
103157	Q1	343.2	0.01
103157	T2	211.2	0.01
103157	P1	344	0.01
103157	2SM2	69	0.01
103157	M3	76.3	0.01
103157	L2	229.4	0.05
103157	2MK3	340	0.02
103157	K2	257.5	0.02
103157	M8	235.2	0.01
103157	MS4	85.3	0.01
103158	M2	256.9	0.19
103158	S2	279.6	0.02
103158	N2	238.5	0.03
103158	K1	337.2	0.02
103158	M4	136.8	0.04
103158	O1	2	0.02
103158	M6	258.4	0.03
103158	NU2	241	0.01
103158	P1	339	0.01
103158	L2	271.4	0.02
103158	K2	281.3	0.01
103159	M2	10.9	1.952
103159	S2	32.4	0.348
103159	N2	349.6	0.482
103159	K1	196.4	0.328
103159	O1	200.9	0.253
103159	NU2	352.4	0.095
103159	MU2	353.1	0.059
103159	2N2	328.4	0.066
103159	OO1	191.8	0.01
103159	LDA2	20.8	0.013
103159	M1	198.5	0.016
103159	J1	194.2	0.02
103159	SSA	52.4	0.253
103159	SA	197.5	0.341
103159	Q1	197.9	0.049
103159	T2	32.3	0.02
103159	P1	190.7	0.108
103159	L2	31	0.079
103159	K2	33.9	0.072
103160	M2	11.2	1.87
103160	S2	31.8	0.31
103160	N2	349.1	0.44
103160	K1	196.8	0.32
103160	M4	74.7	0.03
103160	O1	201.4	0.24
103160	M6	349.2	0.01
103160	MK3	133.6	0.01
103160	S4	233.6	0.02
103160	MN4	64.6	0.01
103160	NU2	345.7	0.09
103160	S6	206.4	0.01
103160	MU2	355.1	0.06
103160	2N2	332.6	0.06
103160	OO1	205.7	0.02
103160	LDA2	57.3	0.02
103160	S1	157.7	0.03
103160	M1	214.8	0.01
103160	J1	206.5	0.02
103160	SSA	49.2	0.2
103160	SA	195.3	0.32
103160	RHO1	196.2	0.01
103160	Q1	196.2	0.05
103160	T2	12.9	0.03
103160	R2	247.5	0.01
103160	2Q1	155.6	0.01
103160	P1	195.6	0.1
103160	2SM2	43.8	0.01
103160	M3	73.8	0.01
103160	L2	43.5	0.05
103160	2MK3	126.7	0.01
103160	K2	34.8	0.08
103160	MS4	99.2	0.03
103161	M2	21.4	1.43
103161	S2	43.1	0.21
103161	N2	3.9	0.31
103161	K1	205.3	0.26
103161	M4	119.8	0.02
103161	O1	210.9	0.2
103161	M6	158.4	0.02
103161	MK3	55.4	0.01
103161	S4	253.3	0.01
103161	MN4	159.5	0.01
103161	NU2	357.5	0.08
103161	MU2	20.4	0.03
103161	2N2	345.9	0.06
103161	OO1	215.1	0.01
103161	LDA2	25	0.01
103161	S1	161.6	0.03
103161	M1	298.6	0.01
103161	J1	209.1	0.02
103161	SSA	53.9	0.28
103161	SA	205.2	0.35
103161	Q1	200.9	0.05
103161	T2	21.1	0.02
103161	R2	285.3	0.02
103161	2Q1	192.1	0.01
103161	P1	202.4	0.09
103161	2SM2	54.2	0.01
103161	M3	88.3	0.01
103161	L2	10.8	0.04
103161	2MK3	52.1	0.01
103161	K2	38.4	0.05
103161	M8	202.2	0.01
103161	MS4	122.6	0.02
103162	M2	37.1	1.17
103162	S2	58.9	0.14
103162	N2	18.1	0.26
103162	K1	208.4	0.22
103162	M4	327.3	0.03
103162	O1	225.3	0.17
103162	M6	191.6	0.03
103162	S4	310.9	0.01
103162	NU2	20.6	0.05
103162	MU2	15.4	0.03
103162	2N2	359.1	0.03
103162	OO1	191.4	0.01
103162	LDA2	47.2	0.01
103162	M1	216.8	0.01
103162	J1	199.9	0.01
103162	RHO1	232.6	0.01
103162	Q1	233.6	0.03
103162	T2	57.9	0.01
103162	P1	209.6	0.08
103162	L2	56.1	0.03
103162	K2	60.6	0.04
103163	M2	67.2	0.52
103163	S2	93.5	0.07
103163	N2	57.3	0.1
103163	K1	224	0.09
103163	M4	93.8	0.04
103163	O1	232.4	0.08
103163	M6	310.8	0.04
103163	NU2	58.7	0.02
103163	MU2	40.8	0.01
103163	2N2	46.9	0.01
103163	J1	221.2	0.01
103163	Q1	235.6	0.01
103163	P1	224.8	0.03
103163	L2	77.3	0.01
103163	K2	95.8	0.02
103163	M8	359	0.01
103164	M2	115	0.21
103164	S2	147.1	0.03
103164	N2	115.5	0.03
103164	K1	209.1	0.05
103164	M4	182.6	0.02
103164	O1	248.6	0.03
103164	M6	60.9	0.01
103164	NU2	115.5	0.01
103164	MU2	82.9	0.01
103164	Q1	268.2	0.01
103164	P1	212.1	0.02
103164	L2	114.5	0.01
103164	K2	149.7	0.01
103165	M2	7.2	1.63
103165	S2	27.8	0.26
103165	N2	346.5	0.4
103165	K1	200.7	0.32
103165	M4	116.6	0.01
103165	O1	206.6	0.25
103165	M6	301.1	0.03
103165	MK3	137.9	0.01
103165	S4	221.2	0.01
103165	MN4	115.5	0.01
103165	NU2	345.3	0.08
103165	S6	143.2	0.01
103165	MU2	349.8	0.05
103165	2N2	328.3	0.06
103165	OO1	204.5	0.01
103165	LDA2	34.1	0.02
103165	S1	200.1	0.02
103165	M1	213.6	0.01
103165	J1	202	0.02
103165	SSA	53.9	0.28
103165	SA	205.2	0.35
103165	RHO1	194.9	0.01
103165	Q1	197.7	0.05
103165	T2	12.7	0.03
103165	R2	251.2	0.01
103165	2Q1	159.6	0.01
103165	P1	202.2	0.1
103165	2SM2	23.9	0.01
103165	M3	43.4	0.01
103165	L2	22.1	0.05
103165	2MK3	99.1	0.01
103165	K2	29	0.07
103165	M8	316.8	0.01
103165	MS4	94.2	0.01
103166	M2	5.5	1.74
103166	S2	27.1	0.29
103166	N2	347.5	0.39
103166	K1	201.3	0.35
103166	M4	104	0.01
103166	O1	203.5	0.26
103166	M6	293.9	0.03
103166	S4	232.4	0.02
103166	NU2	341.4	0.09
103166	S6	135	0.02
103166	MU2	345.2	0.06
103166	2N2	336.1	0.06
103166	OO1	199	0.01
103166	LDA2	15.4	0.01
103166	S1	155.1	0.02
103166	M1	202.3	0.02
103166	J1	200.2	0.02
103166	RHO1	204.3	0.01
103166	Q1	198.7	0.07
103166	T2	2.6	0.04
103166	2Q1	205.6	0.01
103166	P1	208.6	0.11
103166	2SM2	15.8	0.02
103166	L2	348.8	0.04
103166	K2	24.9	0.08
103166	MS4	91.4	0.02
103167	M2	7.2	1.63
103167	S2	28.2	0.25
103167	N2	348.6	0.38
103167	K1	201.6	0.33
103167	M4	114.9	0.01
103167	O1	206	0.24
103167	M6	314.1	0.03
103167	S4	220.6	0.01
103167	MN4	124	0.01
103167	NU2	347.6	0.08
103167	S6	135.4	0.01
103167	MU2	346.2	0.05
103167	2N2	335.3	0.06
103167	OO1	228	0.01
103167	LDA2	47.6	0.02
103167	S1	184.5	0.03
103167	M1	251.1	0.02
103167	J1	205.1	0.02
103167	SSA	49.2	0.2
103167	SA	195.3	0.32
103167	RHO1	221.3	0.01
103167	Q1	192	0.06
103167	T2	19.9	0.03
103167	R2	256.4	0.01
103167	P1	200.8	0.11
103167	2SM2	52.6	0.01
103167	M3	28.7	0.01
103167	L2	348.1	0.04
103167	2MK3	143.5	0.01
103167	K2	28.2	0.07
103167	M8	339.4	0.01
103167	MS4	94	0.02
103168	M2	121.2	0.08
103168	S2	144.3	0.01
103168	N2	104.8	0.02
103168	K1	283.4	0.02
103168	M4	155.6	0.01
103168	O1	276.9	0.01
103168	S1	84.1	0.02
103168	SSA	53.9	0.28
103168	SA	205.2	0.35
103168	Q1	292.8	0.01
103168	P1	14.9	0.01
103169	M2	119.8	0.34
103169	S2	165.3	0.03
103169	N2	97.9	0.07
103169	K1	284.4	0.06
103169	M4	165.7	0.02
103169	O1	281.9	0.08
103169	M6	33.5	0.01
103169	NU2	100.5	0.01
103169	MU2	263.7	0.01
103169	2N2	75.3	0.01
103169	J1	285.3	0.01
103169	Q1	280.5	0.01
103169	P1	284.8	0.02
103169	L2	142.1	0.01
103169	K2	167.3	0.01
103170	M2	37.7	0.73
103170	S2	51.3	0.11
103170	N2	11.1	0.17
103170	K1	234.8	0.16
103170	M4	257.5	0.02
103170	O1	245.3	0.14
103170	M6	214	0.01
103170	NU2	14.6	0.03
103170	MU2	223.5	0.02
103170	2N2	344.4	0.02
103170	OO1	224.3	0.01
103170	LDA2	44	0.01
103170	M1	240	0.01
103170	J1	229.6	0.01
103170	RHO1	249.8	0.01
103170	Q1	250.5	0.03
103170	T2	50.8	0.01
103170	P1	235.6	0.06
103170	L2	64.4	0.02
103170	K2	52.4	0.03
103171	M2	20.2	0.99
103171	S2	42.2	0.15
103171	N2	356.8	0.23
103171	K1	219.7	0.19
103171	M4	189.7	0.05
103171	O1	232.7	0.16
103171	M6	193.2	0.01
103171	NU2	359.9	0.05
103171	MU2	197.6	0.02
103171	2N2	333.5	0.03
103171	OO1	206.2	0.01
103171	LDA2	30.4	0.01
103171	M1	226	0.01
103171	J1	212.9	0.01
103171	RHO1	238.4	0.01
103171	Q1	239.3	0.03
103171	T2	41.3	0.01
103171	P1	220.7	0.06
103171	L2	43.5	0.03
103171	K2	44	0.04
103172	M2	39.1	0.68
103172	S2	60.9	0.09
103172	N2	11.2	0.16
103172	K1	241.4	0.16
103172	M4	222.2	0.03
103172	O1	252.7	0.14
103172	M6	194.4	0.02
103172	NU2	14.9	0.03
103172	MU2	17.3	0.02
103172	2N2	343.3	0.02
103172	OO1	230.1	0.01
103172	M1	247	0.01
103172	J1	235.8	0.01
103172	RHO1	257.6	0.01
103172	Q1	258.3	0.03
103172	T2	60	0.01
103172	P1	242.3	0.05
103172	L2	67	0.02
103172	K2	62.6	0.03
103173	M2	92.4	0.64
103173	S2	129.3	0.08
103173	N2	79.8	0.13
103173	K1	269	0.15
103173	M4	116.7	0.04
103173	O1	273.6	0.12
103173	M6	297.9	0.03
103173	MK3	10.5	0.01
103173	MN4	105.3	0.01
103173	NU2	66.9	0.03
103173	MU2	192.5	0.02
103173	2N2	64.2	0.02
103173	OO1	261.8	0.01
103173	LDA2	94.2	0.02
103173	S1	136.2	0.01
103173	M1	9.9	0.01
103173	J1	239.1	0.01
103173	Q1	267.9	0.02
103173	T2	130.3	0.01
103173	P1	274.1	0.04
103173	M3	133.2	0.01
103173	L2	82.9	0.04
103173	2MK3	42.4	0.01
103173	K2	112.4	0.02
103173	M8	319.7	0.01
103173	MS4	153.8	0.01
103174	M2	89.4	0.62
103174	S2	124.1	0.07
103174	N2	76.9	0.12
103174	K1	267.1	0.15
103174	M4	107.2	0.04
103174	O1	272	0.12
103174	M6	276.8	0.02
103174	MK3	351.3	0.01
103174	MN4	88.2	0.02
103174	NU2	55.1	0.03
103174	MU2	189.4	0.01
103174	2N2	66	0.02
103174	LDA2	97	0.01
103174	M1	11.9	0.01
103174	RHO1	243.7	0.01
103174	Q1	262.7	0.02
103174	T2	110.6	0.01
103174	R2	300.2	0.01
103174	P1	278	0.05
103174	M3	127.2	0.01
103174	L2	82.6	0.04
103174	2MK3	30.8	0.01
103174	K2	115.3	0.02
103174	MS4	149.1	0.01
103175	M2	52.2	0.64
103175	S2	75	0.09
103175	N2	36.8	0.13
103175	K1	248.6	0.16
103175	M4	343.7	0.01
103175	O1	255	0.14
103175	M6	177	0.03
103175	MN4	327.8	0.01
103175	NU2	32.4	0.04
103175	2N2	14	0.02
103175	LDA2	70.8	0.02
103175	M1	346.5	0.01
103175	J1	222.3	0.01
103175	RHO1	241.6	0.01
103175	Q1	241.3	0.02
103175	T2	54.8	0.01
103175	R2	2.9	0.01
103175	P1	254.2	0.05
103175	L2	49	0.03
103175	2MK3	76.2	0.01
103175	K2	72	0.02
103176	M2	22.8	0.98
103176	S2	42.5	0.14
103176	N2	5	0.22
103176	K1	230.2	0.19
103176	M4	161.5	0.08
103176	O1	241.4	0.15
103176	M6	179.8	0.02
103176	MK3	343.5	0.02
103176	MN4	153.3	0.03
103176	NU2	1.5	0.05
103176	MU2	5.1	0.02
103176	2N2	349.7	0.04
103176	OO1	213.7	0.01
103176	LDA2	37.6	0.01
103176	S1	169.3	0.01
103176	M1	309.7	0.01
103176	J1	198.6	0.01
103176	SSA	21.9	0.03
103176	SA	251	0.01
103176	RHO1	209	0.01
103176	Q1	230.1	0.03
103176	T2	45	0.01
103176	2Q1	229.2	0.01
103176	P1	228.2	0.06
103176	M3	84.3	0.01
103176	L2	27.7	0.03
103176	2MK3	5.9	0.02
103176	K2	44.8	0.04
103176	M8	342.8	0.01
103176	MS4	175.7	0.02
103177	M2	35.9	1.23
103177	S2	67.3	0.2
103177	N2	18.1	0.28
103177	K1	234.4	0.19
103177	M4	326.6	0.02
103177	O1	245.8	0.16
103177	M6	112.5	0.04
103177	MK3	253.8	0.01
103177	MN4	303.8	0.01
103177	NU2	19.6	0.06
103177	MU2	61.9	0.03
103177	2N2	346.1	0.05
103177	OO1	261.6	0.01
103177	LDA2	21.2	0.02
103177	S1	297.4	0.01
103177	M1	312.9	0.01
103177	J1	238	0.01
103177	SSA	68.4	0.18
103177	SA	204.5	0.26
103177	Q1	254.3	0.03
103177	T2	50	0.03
103177	R2	299.7	0.01
103177	P1	238.8	0.05
103177	L2	53.8	0.05
103177	K2	60.1	0.05
103178	M2	20.1	1.31
103178	S2	47	0.22
103178	N2	358.5	0.31
103178	K1	222.5	0.2
103178	M4	166.6	0.01
103178	O1	236.6	0.16
103178	M6	48	0.01
103178	S4	264.2	0.01
103178	MN4	161	0.01
103178	NU2	357.4	0.06
103178	MU2	10.5	0.04
103178	2N2	342.4	0.05
103178	OO1	229.3	0.01
103178	LDA2	35.2	0.01
103178	S1	308.5	0.01
103178	M1	247.8	0.01
103178	J1	225.5	0.01
103178	SSA	51.6	0.24
103178	SA	190.6	0.44
103178	RHO1	236.7	0.01
103178	Q1	235.5	0.03
103178	T2	28.5	0.02
103178	R2	272.2	0.01
103178	P1	226.8	0.06
103178	M3	45.6	0.01
103178	L2	47.9	0.05
103178	K2	45.1	0.06
103178	MS4	157.3	0.01
103179	M2	58	1.22
103179	S2	92.5	0.2
103179	N2	44.8	0.22
103179	K1	240.1	0.18
103179	M4	53.2	0.07
103179	O1	253	0.15
103179	M6	177.1	0.04
103179	NU2	46.6	0.04
103179	MU2	223.4	0.03
103179	2N2	31.6	0.03
103179	OO1	227.1	0.01
103179	LDA2	74	0.01
103179	M1	246.5	0.01
103179	J1	233.6	0.01
103179	RHO1	258.6	0.01
103179	Q1	259.5	0.03
103179	T2	91.1	0.01
103179	P1	241	0.06
103179	L2	71.2	0.03
103179	K2	95.3	0.06
103179	M8	163.9	0.01
103180	M2	13.8	1.34
103180	S2	35	0.22
103180	N2	354.1	0.31
103180	K1	219	0.19
103180	M4	187	0.01
103180	O1	236.2	0.15
103180	S4	258.5	0.01
103180	MN4	173.5	0.01
103180	NU2	353.1	0.06
103180	MU2	353.4	0.04
103180	2N2	339.3	0.05
103180	OO1	226.6	0.01
103180	LDA2	37.3	0.01
103180	S1	249.1	0.01
103180	M1	253.7	0.01
103180	J1	216.1	0.01
103180	SSA	68.4	0.18
103180	SA	204.5	0.26
103180	RHO1	230.4	0.01
103180	Q1	232.6	0.03
103180	T2	21.9	0.03
103180	R2	251	0.01
103180	P1	219.6	0.06
103180	2SM2	39.4	0.01
103180	M3	36.3	0.01
103180	L2	15.2	0.03
103180	K2	35.1	0.06
103180	MS4	133.3	0.01
103181	M2	67.1	1.16
103181	S2	106.6	0.17
103181	N2	49.4	0.23
103181	K1	251.6	0.17
103181	M4	75.3	0.08
103181	O1	264.7	0.13
103181	M6	239.7	0.04
103181	MK3	306.5	0.02
103181	MN4	50	0.03
103181	NU2	42.8	0.06
103181	MU2	144.7	0.05
103181	2N2	56.1	0.02
103181	OO1	245.9	0.01
103181	LDA2	57	0.03
103181	S1	348.9	0.01
103181	M1	312.7	0.01
103181	J1	257.4	0.01
103181	RHO1	250.1	0.01
103181	Q1	270.7	0.03
103181	T2	90.2	0.03
103181	R2	186.3	0.01
103181	P1	260.2	0.05
103181	L2	45.8	0.09
103181	2MK3	345.7	0.02
103181	K2	94.2	0.05
103181	M8	256.6	0.01
103181	MS4	118.4	0.03
103182	M2	68.5	1.12
103182	S2	108.7	0.17
103182	N2	55.8	0.28
103182	K1	261.8	0.21
103182	M4	95.2	0.08
103182	O1	267.5	0.13
103182	M6	227.4	0.05
103182	NU2	57.5	0.05
103182	MU2	28.4	0.03
103182	2N2	43	0.04
103182	OO1	256	0.01
103182	LDA2	87.1	0.01
103182	M1	264.6	0.01
103182	J1	258.9	0.01
103182	Q1	270.3	0.02
103182	T2	107.1	0.01
103182	P1	262.2	0.07
103182	L2	81.3	0.03
103182	K2	111.9	0.05
103182	M8	240.4	0.02
103183	M2	76.6	1.11
103183	S2	122.2	0.16
103183	N2	62.1	0.24
103183	K1	267.7	0.2
103183	M4	103.1	0.07
103183	O1	276.8	0.12
103183	M6	224	0.03
103183	NU2	64	0.05
103183	MU2	31.1	0.03
103183	2N2	47.5	0.03
103183	OO1	258.5	0.01
103183	LDA2	97.8	0.01
103183	M1	272.2	0.01
103183	J1	263.1	0.01
103183	Q1	281.3	0.02
103183	T2	120.4	0.01
103183	P1	268.4	0.07
103183	L2	91.2	0.03
103183	K2	125.9	0.05
103183	M8	260.7	0.01
103184	M2	75.7	1.03
103184	S2	120.8	0.16
103184	N2	60.9	0.24
103184	K1	267.9	0.19
103184	M4	122.9	0.06
103184	O1	276.8	0.12
103184	M6	166.5	0.01
103184	NU2	62.9	0.05
103184	MU2	30.6	0.03
103184	2N2	46.2	0.03
103184	OO1	259	0.01
103184	LDA2	96.6	0.01
103184	M1	272.3	0.01
103184	J1	263.5	0.01
103184	Q1	281.3	0.02
103184	T2	119	0.01
103184	P1	268.6	0.06
103184	L2	90.5	0.03
103184	K2	124.4	0.04
103185	M2	52.4	1.04
103185	S2	87.5	0.16
103185	N2	37.7	0.2
103185	K1	247.9	0.15
103185	M4	358.2	0.02
103185	O1	264.4	0.11
103185	M6	119.8	0.01
103185	MK3	263.8	0.01
103185	MN4	343.5	0.01
103185	NU2	34.1	0.05
103185	MU2	122.9	0.03
103185	2N2	42.2	0.02
103185	OO1	253	0.01
103185	LDA2	50	0.02
103185	M1	297.3	0.01
103185	J1	254.1	0.01
103185	RHO1	272.6	0.01
103185	Q1	262.3	0.03
103185	T2	106.7	0.03
103185	R2	89.1	0.01
103185	P1	249.7	0.05
103185	M3	65.6	0.01
103185	L2	56.9	0.07
103185	2MK3	340.6	0.01
103185	K2	80.1	0.04
103185	MS4	62.8	0.01
103186	M2	39.5	1.16
103186	S2	69.5	0.22
103186	N2	25.6	0.24
103186	K1	240.4	0.16
103186	M4	334.5	0.01
103186	O1	261.4	0.13
103186	M6	106.4	0.03
103186	NU2	27.4	0.05
103186	MU2	9.5	0.03
103186	2N2	11.5	0.03
103186	OO1	219.4	0.01
103186	LDA2	53.4	0.01
103186	M1	250.8	0.01
103186	J1	230	0.01
103186	Q1	271.9	0.02
103186	T2	68.3	0.01
103186	P1	242	0.05
103186	L2	53.5	0.03
103186	K2	71.9	0.06
103187	M2	32.9	1.14
103187	S2	65.5	0.24
103187	N2	12.1	0.25
103187	K1	233.3	0.13
103187	M4	340.8	0.02
103187	O1	257	0.11
103187	M6	88.7	0.02
103187	MK3	228.5	0.01
103187	MN4	301.5	0.01
103187	NU2	15.6	0.03
103187	MU2	64.9	0.03
103187	2N2	341	0.04
103187	OO1	245.7	0.01
103187	LDA2	352.6	0.01
103187	S1	225.5	0.03
103187	J1	239.8	0.01
103187	Q1	257.7	0.03
103187	T2	52.1	0.05
103187	R2	273.2	0.05
103187	P1	257.1	0.04
103187	M3	79.1	0.01
103187	L2	59.6	0.04
103187	K2	38.9	0.06
103187	MS4	52	0.01
103188	M2	15.7	1.26
103188	S2	36.6	0.26
103188	N2	352.1	0.31
103188	K1	219.7	0.16
103188	M4	208.4	0.01
103188	O1	250.8	0.12
103188	MK3	166.7	0.01
103188	S4	266.2	0.01
103188	MN4	181.2	0.01
103188	NU2	351.5	0.06
103188	MU2	0	0.04
103188	2N2	344.3	0.04
103188	OO1	210.6	0.01
103188	LDA2	70.3	0.01
103188	S1	44.1	0.02
103188	M1	236.5	0.01
103188	J1	189.6	0.01
103188	SSA	68.4	0.18
103188	SA	204.5	0.26
103188	RHO1	226.3	0.01
103188	Q1	246.7	0.03
103188	T2	37.5	0.04
103188	R2	98.4	0.02
103188	P1	243.1	0.05
103188	2SM2	66.4	0.01
103188	M3	56.5	0.01
103188	L2	48.2	0.05
103188	2MK3	133.1	0.01
103188	K2	41.5	0.08
103188	MS4	167.7	0.01
103189	M2	39.7	0.99
103189	S2	65.3	0.15
103189	N2	25.5	0.21
103189	K1	238.7	0.12
103189	M4	36.9	0.01
103189	O1	269	0.09
103189	M6	134.4	0.02
103189	NU2	27.5	0.04
103189	MU2	14.1	0.02
103189	2N2	12.1	0.03
103189	LDA2	51.6	0.01
103189	M1	254.1	0.01
103189	J1	224.3	0.01
103189	SSA	59.5	0.2
103189	SA	208.5	0.34
103189	Q1	283.7	0.02
103189	T2	64.3	0.01
103189	P1	241	0.04
103189	L2	54	0.03
103189	K2	67.4	0.04
103190	M2	20.4	1.23
103190	S2	45.8	0.22
103190	N2	0.3	0.29
103190	K1	231.3	0.14
103190	M4	160.1	0.02
103190	O1	256.2	0.12
103190	S4	268.3	0.01
103190	MN4	161.5	0.01
103190	NU2	358.7	0.06
103190	MU2	359.8	0.04
103190	2N2	344.8	0.04
103190	OO1	215.6	0.01
103190	LDA2	44.7	0.01
103190	S1	253.2	0.01
103190	M1	261.3	0.01
103190	J1	223.5	0.01
103190	SSA	59.5	0.2
103190	SA	208.5	0.34
103190	Q1	256	0.03
103190	T2	27.9	0.02
103190	R2	246.2	0.01
103190	P1	235	0.04
103190	M3	47.9	0.01
103190	L2	29.7	0.04
103190	K2	46.8	0.06
103190	MS4	163.3	0.01
103191	M2	19.6	1.22
103191	S2	46.7	0.23
103191	N2	357.4	0.28
103191	K1	237.8	0.14
103191	M4	202.7	0.02
103191	O1	262.3	0.11
103191	MN4	190.9	0.01
103191	NU2	359.9	0.06
103191	MU2	355.7	0.04
103191	2N2	336.9	0.04
103191	OO1	213.2	0.01
103191	LDA2	32.2	0.01
103191	M1	250	0.01
103191	J1	225.6	0.01
103191	SSA	46.2	0.2
103191	SA	193.7	0.25
103191	MF	349	0.04
103191	Q1	274.4	0.02
103191	T2	45.5	0.01
103191	P1	235.2	0.04
103191	L2	41.7	0.04
103191	K2	44.4	0.06
103192	M2	41	1.06
103192	S2	72.7	0.19
103192	N2	24.5	0.23
103192	K1	259.7	0.11
103192	M4	323.1	0.01
103192	O1	284.1	0.09
103192	M6	169	0.04
103192	MK3	266.1	0.01
103192	S4	315.7	0.01
103192	MN4	289.5	0.01
103192	NU2	11.6	0.05
103192	MU2	52	0.03
103192	2N2	3.3	0.03
103192	OO1	262	0.01
103192	LDA2	56.4	0.02
103192	J1	245.1	0.01
103192	SSA	58.3	0.18
103192	SA	190.6	0.27
103192	RHO1	288.7	0.01
103192	Q1	285	0.02
103192	T2	63.5	0.02
103192	P1	257.5	0.03
103192	L2	19.8	0.05
103192	K2	69.9	0.05
103193	M2	20.4	1.22
103193	S2	44.5	0.25
103193	N2	0.8	0.28
103193	K1	244.8	0.14
103193	O1	268.7	0.11
103193	NU2	3.4	0.05
103193	MU2	356.7	0.04
103193	2N2	341.2	0.04
103193	SSA	68.7	0.2
103193	SA	198.8	0.29
103193	Q1	280.5	0.02
103193	T2	44.4	0.01
103193	P1	248.4	0.04
103193	L2	23.2	0.03
103193	K2	56.4	0.07
103194	M2	25.8	1.13
103194	S2	53.3	0.21
103194	N2	7.4	0.26
103194	K1	250.5	0.12
103194	M4	143.3	0.05
103194	O1	277.6	0.1
103194	M6	130.6	0.01
103194	MN4	143.1	0.02
103194	NU2	3.7	0.05
103194	MU2	10.3	0.03
103194	2N2	346.5	0.03
103194	OO1	223.3	0.01
103194	LDA2	42.1	0.01
103194	M1	264	0.01
103194	J1	237.1	0.01
103194	SSA	58.3	0.18
103194	SA	190.6	0.27
103194	Q1	276.3	0.03
103194	T2	35.2	0.02
103194	P1	248.4	0.04
103194	L2	8.1	0.04
103194	K2	54	0.06
103194	MS4	166.9	0.03
103195	M2	39.3	0.98
103195	S2	70	0.16
103195	N2	21.2	0.21
103195	K1	262.5	0.1
103195	M4	92.9	0.02
103195	O1	290	0.09
103195	M6	163.4	0.03
103195	MK3	277	0.01
103195	MN4	67.8	0.01
103195	NU2	18.4	0.04
103195	MU2	46.8	0.02
103195	2N2	7.6	0.03
103195	LDA2	46.5	0.01
103195	S1	271.5	0.01
103195	J1	233.2	0.01
103195	SSA	60.5	0.21
103195	SA	194.1	0.3
103195	Q1	290.8	0.02
103195	T2	55.6	0.02
103195	P1	263.6	0.03
103195	L2	42.3	0.04
103195	2MK3	308.5	0.01
103195	K2	68.2	0.05
103195	M8	208	0.01
103195	MS4	131.3	0.01
103196	M2	64.1	0.89
103196	S2	100.2	0.15
103196	N2	44.2	0.18
103196	K1	282.5	0.1
103196	M4	51	0.05
103196	O1	301.7	0.08
103196	M6	217.7	0.04
103196	MK3	289.2	0.02
103196	MN4	24.1	0.02
103196	NU2	48.4	0.05
103196	MU2	120.6	0.02
103196	2N2	35.1	0.02
103196	OO1	256.2	0.01
103196	LDA2	57.5	0.02
103196	SSA	86.9	0.21
103196	SA	214.9	0.43
103196	Q1	298.4	0.02
103196	T2	78.8	0.02
103196	2Q1	315.8	0.01
103196	P1	265.1	0.03
103196	M3	16.5	0.01
103196	L2	78.7	0.05
103196	2MK3	324.5	0.02
103196	K2	88.9	0.04
103196	M8	209.5	0.01
103196	MS4	101	0.02
103197	M2	65.1	0.73
103197	S2	93.4	0.12
103197	N2	48	0.14
103197	K1	285.7	0.1
103197	M4	60.3	0.03
103197	O1	301.6	0.08
103197	M6	219.9	0.01
103197	NU2	50.3	0.03
103197	MU2	36.8	0.02
103197	2N2	31.1	0.02
103197	LDA2	78.1	0.01
103197	M1	293.5	0.01
103197	J1	277.7	0.01
103197	SSA	58.3	0.18
103197	SA	190.6	0.27
103197	Q1	309.4	0.02
103197	T2	92.1	0.01
103197	P1	286.9	0.03
103197	L2	82.1	0.02
103197	K2	95.5	0.03
103198	M2	96.7	0.66
103198	S2	139.5	0.1
103198	N2	82.7	0.14
103198	K1	304.6	0.08
103198	M4	133.3	0.06
103198	O1	317.7	0.07
103198	M6	306.8	0.02
103198	NU2	84.6	0.03
103198	MU2	53.9	0.02
103198	2N2	68.6	0.02
103198	J1	298.1	0.01
103198	SSA	58.3	0.18
103198	SA	190.6	0.27
103198	Q1	324.2	0.01
103198	T2	137.8	0.01
103198	P1	305.6	0.03
103198	L2	110.8	0.02
103198	K2	143	0.03
103198	M8	352.7	0.01
103199	M2	102.7	0.68
103199	S2	140.7	0.1
103199	N2	85.3	0.16
103199	K1	309.5	0.1
103199	M4	140.3	0.07
103199	O1	322.3	0.07
103199	M6	317.1	0.03
103199	NU2	87.6	0.03
103199	MU2	64.6	0.02
103199	2N2	67.5	0.02
103199	M1	315.3	0.01
103199	J1	301.8	0.01
103199	SSA	58.3	0.18
103199	SA	190.6	0.27
103199	Q1	329.4	0.01
103199	T2	139.2	0.01
103199	P1	310.3	0.03
103199	L2	120.2	0.02
103199	K2	143.8	0.03
103199	M8	14.4	0.01
103200	M2	110.1	0.42
103200	S2	148.3	0.07
103200	N2	85	0.08
103200	K1	313	0.05
103200	M4	154.2	0.02
103200	O1	357.7	0.05
103200	M6	350.7	0.01
103200	NU2	87.9	0.02
103200	MU2	72	0.01
103200	2N2	58.4	0.01
103200	SSA	58.3	0.18
103200	SA	190.6	0.27
103200	Q1	19.8	0.01
103200	P1	316.3	0.02
103200	L2	135.7	0.01
103200	K2	151.2	0.02
103201	M2	119.8	0.32
103201	S2	149.6	0.05
103201	N2	100.7	0.06
103201	K1	335.6	0.05
103201	M4	219.6	0.03
103201	O1	344	0.05
103201	M6	335.5	0.01
103201	NU2	103.3	0.01
103201	MU2	90.1	0.01
103201	2N2	80.5	0.01
103201	SSA	58.3	0.18
103201	SA	190.6	0.27
103201	Q1	348.5	0.01
103201	P1	336.3	0.02
103201	L2	138.8	0.01
103201	K2	151.9	0.01
103202	M2	140	0.26
103202	S2	177.1	0.04
103202	N2	123.3	0.04
103202	K1	344.3	0.04
103202	M4	245.1	0.01
103202	O1	6.3	0.03
103202	M6	3.4	0.01
103202	MK3	77.1	0.01
103202	NU2	133.8	0.01
103202	MU2	249.5	0.01
103202	2N2	144.2	0.01
103202	LDA2	126.9	0.01
103202	S1	77.6	0.01
103202	MM	3.3	0.1
103202	SSA	49.1	0.26
103202	SA	204.2	0.23
103202	MSF	22.3	0.09
103202	MF	34.4	0.02
103202	Q1	357.5	0.01
103202	T2	176.9	0.01
103202	P1	328.6	0.01
103202	L2	181.4	0.02
103202	2MK3	103.6	0.01
103202	K2	174.4	0.01
103203	M2	41	0.8
103203	S2	66.3	0.19
103203	N2	22.9	0.17
103203	K1	337.6	0.21
103203	M4	226.2	0.02
103203	O1	338.8	0.24
103203	M6	113.4	0.01
103203	MN4	212.7	0.02
103203	NU2	24.4	0.04
103203	MU2	7.5	0.03
103203	2N2	5	0.02
103203	OO1	336.3	0.01
103203	LDA2	52.7	0.01
103203	S1	356.8	0.02
103203	M1	338.1	0.02
103203	J1	337	0.02
103203	SSA	51.9	0.14
103203	SA	198.7	0.32
103203	MF	356.5	0.04
103203	RHO1	339.3	0.01
103203	Q1	326.4	0.06
103203	T2	66.2	0.01
103203	2Q1	339.9	0.01
103203	P1	339.5	0.07
103203	L2	59	0.02
103203	K2	64.7	0.05
103203	MS4	211.6	0.01
103204	M2	164.6	0.18
103204	S2	229	0.05
103204	N2	121	0.02
103204	K1	33.7	0.24
103204	M4	80	0.05
103204	O1	26.8	0.24
103204	M6	56.1	0.02
103204	MK3	264.6	0.03
103204	MN4	71.3	0.02
103204	NU2	175.6	0.01
103204	MU2	359.6	0.03
103204	LDA2	185.8	0.01
103204	S1	139.2	0.01
103204	M1	79.1	0.01
103204	J1	88.2	0.01
103204	MM	359.7	0.04
103204	SSA	79.7	0.13
103204	SA	186.1	0.35
103204	MSF	18.7	0.06
103204	MF	4	0.05
103204	RHO1	14.5	0.01
103204	Q1	16.8	0.06
103204	R2	188.9	0.01
103204	2Q1	13.6	0.01
103204	P1	38.9	0.07
103204	2SM2	67.6	0.01
103204	M3	161.8	0.01
103204	L2	192.1	0.02
103204	2MK3	254.9	0.02
103204	K2	235.8	0.02
103204	MS4	111.1	0.03
103205	M2	97.3	0.34
103205	S2	140.3	0.09
103205	N2	71.8	0.06
103205	K1	21.5	0.27
103205	M4	28	0.05
103205	O1	17.1	0.25
103205	M6	263.2	0.01
103205	S4	47.1	0.01
103205	NU2	75.3	0.01
103205	MU2	250.6	0.01
103205	2N2	46.6	0.01
103205	OO1	25.6	0.01
103205	M1	19.3	0.02
103205	J1	23.5	0.02
103205	RHO1	15.3	0.01
103205	Q1	15	0.05
103205	T2	138.6	0.01
103205	2Q1	12.8	0.01
103205	P1	21.2	0.09
103205	L2	122.9	0.01
103205	K2	143.8	0.03
103206	M2	126.4	0.43
103206	S2	155.5	0.13
103206	N2	112.2	0.08
103206	K1	28.4	0.3
103206	M4	28.2	0.03
103206	O1	22.7	0.25
103206	M6	299.5	0.01
103206	NU2	114.1	0.02
103206	MU2	294	0.01
103206	2N2	98	0.01
103206	OO1	34	0.01
103206	M1	25.5	0.02
103206	J1	31.1	0.02
103206	RHO1	20.3	0.01
103206	Q1	19.9	0.05
103206	T2	154.4	0.01
103206	2Q1	17.1	0.01
103206	P1	27.9	0.1
103206	L2	140	0.01
103206	K2	157.9	0.04
103207	M2	66.9	0.59
103207	S2	89.4	0.17
103207	N2	48.9	0.12
103207	K1	354.8	0.28
103207	M4	243.3	0.03
103207	O1	351.9	0.29
103207	MK3	122.7	0.01
103207	MN4	223.9	0.02
103207	NU2	54.1	0.02
103207	MU2	9.1	0.02
103207	2N2	34.7	0.01
103207	OO1	2.1	0.01
103207	LDA2	110.3	0.01
103207	S1	4.3	0.02
103207	M1	11.6	0.01
103207	J1	353.4	0.01
103207	SSA	57.6	0.17
103207	SA	183.1	0.31
103207	MF	355.6	0.05
103207	RHO1	337.8	0.01
103207	Q1	342	0.07
103207	T2	80.8	0.01
103207	2Q1	324.4	0.01
103207	P1	357.8	0.09
103207	L2	85.6	0.02
103207	2MK3	118.8	0.01
103207	K2	92	0.05
103207	MS4	246.6	0.02
103208	M2	48.7	0.57
103208	S2	69.3	0.17
103208	N2	26.6	0.12
103208	K1	348	0.28
103208	M4	229.8	0.02
103208	O1	349.1	0.28
103208	NU2	29.6	0.02
103208	MU2	224.3	0.01
103208	2N2	4.5	0.02
103208	OO1	347	0.01
103208	M1	348.5	0.02
103208	J1	347.5	0.02
103208	SSA	56.5	0.13
103208	SA	187.8	0.26
103208	RHO1	349.5	0.01
103208	Q1	349.6	0.05
103208	T2	68.5	0.01
103208	2Q1	350.1	0.01
103208	P1	348.1	0.09
103208	L2	70.9	0.02
103208	K2	71	0.05
103209	M2	131.6	1.21
103209	S2	146	0.38
103209	N2	120.1	0.22
103209	K1	0.4	0.46
103209	M4	37.1	0.02
103209	O1	354.5	0.43
103209	M6	104	0.01
103209	NU2	121.7	0.04
103209	2N2	108.7	0.03
103209	OO1	6.2	0.02
103209	LDA2	138.1	0.01
103209	M1	357.5	0.03
103209	J1	3.4	0.03
103209	SSA	56.5	0.13
103209	SA	187.8	0.26
103209	RHO1	352	0.02
103209	Q1	351.6	0.08
103209	T2	145.4	0.02
103209	2Q1	348.6	0.01
103209	P1	0	0.15
103209	L2	143.2	0.03
103209	K2	147.1	0.1
103210	M2	78.7	0.449
103210	S2	92	0.151
103210	N2	66.2	0.095
103210	K1	359.5	0.354
103210	M4	250	0.016
103210	O1	354.3	0.364
103210	MN4	220.3	0.01
103210	NU2	82.1	0.016
103210	MU2	37.5	0.013
103210	2N2	62.1	0.01
103210	OO1	353.9	0.013
103210	S1	4.6	0.023
103210	M1	355.7	0.026
103210	J1	29.1	0.023
103210	SSA	56.5	0.135
103210	SA	187.8	0.262
103210	MF	354.6	0.039
103210	RHO1	338.2	0.013
103210	Q1	345.5	0.085
103210	T2	86	0.01
103210	2Q1	334.9	0.013
103210	P1	356.2	0.112
103210	L2	99.1	0.01
103210	K2	86.9	0.043
103210	MS4	233.7	0.007
103211	M2	193.1	1.34
103211	S2	215.2	0.43
103211	N2	183.6	0.22
103211	K1	35.2	0.58
103211	M4	287.5	0.05
103211	O1	25.8	0.46
103211	NU2	184.9	0.04
103211	MU2	171	0.03
103211	2N2	174.8	0.03
103211	OO1	44.1	0.02
103211	LDA2	203.3	0.01
103211	M1	30.4	0.03
103211	J1	39.4	0.04
103211	SA	150.7	0.27
103211	RHO1	21.9	0.02
103211	Q1	21.3	0.09
103211	T2	214.4	0.03
103211	2Q1	16.8	0.01
103211	P1	34.5	0.19
103211	L2	202	0.04
103211	K2	217	0.12
103212	M2	188.8	1.35
103212	S2	211.4	0.43
103212	N2	175.2	0.24
103212	K1	28.1	0.57
103212	M4	285	0.05
103212	O1	26.6	0.49
103212	S4	345.4	0.01
103212	NU2	177	0.05
103212	MU2	166.4	0.03
103212	2N2	161.9	0.03
103212	OO1	29.7	0.02
103212	LDA2	199.3	0.01
103212	M1	27.2	0.03
103212	J1	28.8	0.04
103212	SSA	66.7	0.1
103212	SA	167.9	0.25
103212	RHO1	25.5	0.02
103212	Q1	25.8	0.1
103212	T2	210.5	0.02
103212	2Q1	25.4	0.01
103212	P1	28	0.19
103212	L2	202.2	0.04
103212	K2	213.2	0.11
103213	M2	155.8	0.93
103213	S2	177.5	0.31
103213	N2	139.8	0.19
103213	K1	9	0.5
103213	M4	124.2	0.01
103213	O1	7.7	0.4
103213	M6	108.9	0.01
103213	S4	312.1	0.01
103213	NU2	142	0.04
103213	MU2	134.4	0.02
103213	2N2	124	0.02
103213	OO1	10.1	0.02
103213	LDA2	165.9	0.01
103213	M1	8.3	0.03
103213	J1	9.5	0.03
103213	SSA	66.7	0.1
103213	SA	167.9	0.25
103213	RHO1	7.3	0.02
103213	Q1	7.2	0.08
103213	T2	176.6	0.02
103213	2Q1	6.6	0.01
103213	P1	8.9	0.16
103213	L2	172	0.03
103213	K2	179.2	0.09
103214	M2	170	0.88
103214	S2	184.1	0.27
103214	N2	151.5	0.17
103214	K1	25.2	0.44
103214	M4	146.8	0.02
103214	O1	13.7	0.44
103214	M6	174.8	0.02
103214	NU2	153.9	0.03
103214	MU2	156	0.02
103214	2N2	133.3	0.02
103214	OO1	36.6	0.02
103214	LDA2	176.5	0.01
103214	M1	19.5	0.03
103214	J1	30.9	0.03
103214	SSA	66.7	0.1
103214	SA	167.9	0.25
103214	RHO1	8.9	0.02
103214	Q1	8.1	0.09
103214	T2	183.6	0.01
103214	2Q1	2.2	0.01
103214	P1	24.4	0.14
103214	L2	188.4	0.03
103214	K2	185.3	0.07
103215	M2	201.3	0.86
103215	S2	224.5	0.25
103215	N2	193.2	0.14
103215	K1	45.7	0.37
103215	M4	272.9	0.03
103215	O1	34.8	0.38
103215	M6	250.4	0.02
103215	S4	357.1	0.01
103215	NU2	194.2	0.03
103215	MU2	178.2	0.02
103215	2N2	184.7	0.02
103215	OO1	58.8	0.02
103215	LDA2	212.1	0.01
103215	M1	40.7	0.03
103215	J1	52.2	0.03
103215	SSA	66.7	0.1
103215	SA	167.9	0.25
103215	RHO1	29.8	0.02
103215	Q1	28.9	0.08
103215	T2	223.7	0.02
103215	2Q1	23.7	0.01
103215	P1	44.9	0.12
103215	L2	208.6	0.02
103215	K2	226.4	0.07
103215	M8	314.7	0.01
103216	M2	171.5	0.86
103216	S2	195.8	0.24
103216	N2	160	0.15
103216	K1	32.8	0.4
103216	M4	166.9	0.03
103216	O1	24.7	0.39
103216	M6	174.1	0.02
103216	NU2	161.6	0.03
103216	MU2	147.2	0.02
103216	2N2	148.6	0.02
103216	OO1	40.8	0.02
103216	LDA2	182.8	0.01
103216	M1	28.8	0.03
103216	J1	36.7	0.03
103216	SSA	66.7	0.1
103216	SA	167.9	0.25
103216	RHO1	21.3	0.01
103216	Q1	20.8	0.08
103216	T2	194.8	0.01
103216	2Q1	16.8	0.01
103216	P1	32.3	0.13
103216	L2	183	0.02
103216	K2	197.7	0.06
103217	M2	144.8	0.89
103217	S2	157.1	0.29
103217	N2	130.2	0.18
103217	K1	9.3	0.48
103217	M4	119.8	0.06
103217	O1	3.3	0.44
103217	M6	130.1	0.03
103217	MK3	314.3	0.03
103217	S4	247.3	0.01
103217	MN4	86.4	0.02
103217	NU2	140.6	0.04
103217	MU2	58.4	0.03
103217	2N2	124.5	0.02
103217	OO1	1.3	0.01
103217	LDA2	196.9	0.01
103217	S1	107.9	0.05
103217	M1	40.7	0.02
103217	J1	15.4	0.03
103217	SSA	42.3	0.13
103217	SA	158.5	0.31
103217	MF	342.7	0.03
103217	RHO1	351.9	0.02
103217	Q1	353.4	0.1
103217	T2	148.4	0.02
103217	R2	52.5	0.01
103217	2Q1	342.1	0.02
103217	P1	6.7	0.16
103217	M3	327.8	0.01
103217	L2	181.1	0.03
103217	2MK3	298.5	0.03
103217	K2	150.3	0.09
103217	MS4	141.9	0.02
103218	M2	162.3	0.88
103218	S2	179.9	0.31
103218	N2	146.4	0.18
103218	K1	19.1	0.51
103218	M4	173.8	0.06
103218	O1	18.1	0.46
103218	M6	182.5	0.02
103218	S4	290.2	0.02
103218	NU2	148.5	0.04
103218	MU2	144.7	0.02
103218	2N2	130.5	0.02
103218	OO1	20.1	0.02
103218	LDA2	170.5	0.01
103218	M1	18.6	0.03
103218	J1	19.6	0.04
103218	SSA	42.3	0.13
103218	SA	158.5	0.31
103218	MF	342.7	0.03
103218	RHO1	17.6	0.02
103218	Q1	17.5	0.09
103218	T2	179.2	0.02
103218	2Q1	17	0.01
103218	P1	19	0.17
103218	L2	178.2	0.02
103218	K2	181.3	0.08
103218	M8	206.3	0.01
103219	M2	170.3	0.74
103219	S2	187.5	0.2
103219	N2	159.7	0.13
103219	K1	34.2	0.42
103219	M4	205.1	0.03
103219	O1	20.9	0.39
103219	M6	219	0.02
103219	NU2	161.2	0.03
103219	MU2	152.8	0.02
103219	2N2	149	0.02
103219	OO1	46.9	0.02
103219	LDA2	178.2	0.01
103219	M1	27.5	0.03
103219	J1	40.2	0.03
103219	SSA	42.3	0.13
103219	SA	158.5	0.31
103219	MF	342.7	0.03
103219	RHO1	15.6	0.01
103219	Q1	14.6	0.08
103219	T2	186.1	0.01
103219	2Q1	8.2	0.01
103219	P1	33.2	0.14
103219	L2	180.9	0.02
103219	K2	188.9	0.06
103220	M2	172.6	0.76
103220	S2	200.3	0.21
103220	N2	161.6	0.13
103220	K1	35.7	0.42
103220	M4	219.5	0.05
103220	O1	22.3	0.39
103220	M6	220.1	0.03
103220	S4	354.6	0.01
103220	NU2	163.1	0.03
103220	S6	325.2	0.01
103220	MU2	144.9	0.02
103220	2N2	150.6	0.02
103220	OO1	49.1	0.02
103220	LDA2	185.5	0.01
103220	M1	29.1	0.03
103220	J1	42.3	0.03
103220	SSA	66.7	0.1
103220	SA	167.9	0.25
103220	RHO1	16.6	0.01
103220	Q1	15.7	0.08
103220	T2	199.2	0.01
103220	2Q1	9.1	0.01
103220	P1	34.7	0.14
103220	L2	183.6	0.02
103220	K2	202.6	0.06
103220	M8	256	0.01
103221	M2	164.9	0.74
103221	S2	179.9	0.23
103221	N2	153.4	0.14
103221	K1	20.7	0.47
103221	M4	202.5	0.02
103221	O1	17.7	0.41
103221	M6	180.7	0.02
103221	MK3	108.7	0.02
103221	MN4	80.7	0.01
103221	NU2	163.8	0.03
103221	MU2	354.8	0.02
103221	2N2	151.1	0.03
103221	OO1	36.4	0.02
103221	LDA2	171	0.02
103221	S1	157.8	0.06
103221	M1	38.9	0.02
103221	J1	69.8	0.02
103221	SSA	42.3	0.13
103221	SA	158.5	0.31
103221	MF	342.7	0.03
103221	RHO1	2.2	0.02
103221	Q1	16.1	0.09
103221	T2	188.2	0.02
103221	R2	147.2	0.01
103221	2Q1	349.2	0.02
103221	P1	39.8	0.15
103221	2SM2	342.1	0.01
103221	M3	349.6	0.01
103221	L2	181.9	0.05
103221	2MK3	90.3	0.01
103221	K2	174.9	0.09
103221	MS4	331	0.01
103222	M2	175.5	0.78
103222	S2	199.3	0.2
103222	N2	165.9	0.13
103222	K1	34.9	0.43
103222	M4	204.7	0.05
103222	O1	23.2	0.41
103222	M6	213	0.03
103222	S4	11.1	0.01
103222	NU2	167.2	0.03
103222	S6	338.3	0.01
103222	MU2	151.7	0.02
103222	2N2	156.4	0.02
103222	OO1	46.5	0.02
103222	LDA2	186.6	0.01
103222	M1	29.1	0.03
103222	J1	40.7	0.03
103222	SSA	66.7	0.1
103222	SA	167.9	0.25
103222	RHO1	18.2	0.02
103222	Q1	17.5	0.08
103222	T2	198.4	0.01
103222	2Q1	11.7	0.01
103222	P1	34	0.14
103222	L2	185.1	0.02
103222	K2	201.3	0.05
103222	M8	212	0.01
103223	M2	178	0.66
103223	S2	182.4	0.24
103223	N2	170.7	0.12
103223	K1	37.9	0.39
103223	M4	241	0.04
103223	O1	32.4	0.39
103223	M6	250.3	0.02
103223	MK3	100.8	0.04
103223	S4	337	0.02
103223	MN4	234	0.01
103223	NU2	173.4	0.02
103223	S6	132.2	0.01
103223	MU2	317.4	0.01
103223	OO1	44.1	0.02
103223	LDA2	183	0.01
103223	S1	189.9	0.04
103223	M1	95.7	0.02
103223	J1	34.1	0.03
103223	SSA	66.7	0.1
103223	SA	167.9	0.25
103223	RHO1	144.7	0.01
103223	Q1	30.7	0.1
103223	T2	278.8	0.02
103223	R2	130.8	0.07
103223	2Q1	45	0.01
103223	P1	46.7	0.12
103223	2SM2	2.4	0.01
103223	M3	340.7	0.01
103223	L2	180	0.04
103223	2MK3	113.5	0.05
103223	K2	201.2	0.06
103223	MS4	281.8	0.02
103224	M2	206.7	0.6
103224	S2	251.8	0.1
103224	N2	196.7	0.09
103224	K1	63.5	0.37
103224	M4	342.3	0.02
103224	O1	53.6	0.35
103224	M6	303.3	0.01
103224	NU2	198	0.02
103224	S6	46	0.01
103224	MU2	161.5	0.01
103224	2N2	186.7	0.01
103224	OO1	73.4	0.02
103224	M1	58.6	0.03
103224	J1	68.4	0.03
103224	SSA	66.7	0.1
103224	SA	167.9	0.25
103224	RHO1	49.4	0.01
103224	Q1	48.7	0.07
103224	T2	250	0.01
103224	2Q1	43.8	0.01
103224	P1	62.8	0.12
103224	L2	216.6	0.02
103224	K2	255.5	0.03
103225	M2	161.1	0.74
103225	S2	175.9	0.24
103225	N2	151.4	0.14
103225	K1	20.2	0.44
103225	M4	158.9	0.05
103225	O1	15.5	0.41
103225	M6	197.6	0.03
103225	MK3	335.3	0.02
103225	S4	265.8	0.01
103225	MN4	118.3	0.02
103225	NU2	162.6	0.03
103225	MU2	19.7	0.02
103225	2N2	177.6	0.02
103225	OO1	31	0.02
103225	LDA2	160.5	0.01
103225	S1	117.4	0.02
103225	M1	76	0.03
103225	J1	46.1	0.03
103225	SSA	42.3	0.13
103225	SA	158.5	0.31
103225	MF	342.7	0.03
103225	RHO1	16.3	0.02
103225	Q1	7.1	0.08
103225	T2	173.9	0.01
103225	R2	199.5	0.01
103225	2Q1	343	0.01
103225	P1	22.6	0.15
103225	2SM2	12.6	0.01
103225	M3	307.6	0.01
103225	L2	166.7	0.03
103225	2MK3	319.1	0.02
103225	K2	170.4	0.08
103225	MS4	214.8	0.01
103226	M2	170.2	0.709
103226	S2	182.1	0.203
103226	N2	160.5	0.128
103226	K1	32.1	0.436
103226	M4	200.2	0.046
103226	O1	20.2	0.404
103226	M6	237	0.023
103226	NU2	161.8	0.026
103226	S6	298.3	0.003
103226	MU2	158.3	0.016
103226	2N2	150.7	0.016
103226	OO1	43.6	0.016
103226	LDA2	176	0.007
103226	M1	26.2	0.03
103226	J1	37.7	0.033
103226	SSA	42.3	0.135
103226	SA	158.5	0.315
103226	MF	342.7	0.033
103226	RHO1	15.2	0.016
103226	Q1	14.4	0.079
103226	T2	182	0.013
103226	2Q1	8.7	0.01
103226	P1	31.2	0.144
103226	L2	180	0.02
103226	K2	182.9	0.056
103226	M8	306.6	0.003
103227	M2	242.3	0.28
103227	S2	259.5	0.07
103227	N2	227.8	0.05
103227	K1	86.7	0.25
103227	M4	330.8	0.01
103227	O1	79.3	0.23
103227	M6	324.2	0.01
103227	MK3	242.6	0.02
103227	NU2	232.4	0.01
103227	MU2	69.9	0.02
103227	2N2	239.2	0.02
103227	OO1	189.7	0.01
103227	LDA2	266.8	0.01
103227	S1	193.9	0.04
103227	M1	120.2	0.01
103227	J1	189.5	0.01
103227	MM	5.3	0.04
103227	SSA	51.1	0.1
103227	SA	151.6	0.36
103227	MSF	10.4	0.07
103227	RHO1	55.1	0.01
103227	Q1	84.9	0.05
103227	T2	271.4	0.01
103227	R2	262.7	0.01
103227	2Q1	228.2	0.01
103227	P1	95.1	0.08
103227	M3	118.8	0.01
103227	L2	245.1	0.03
103227	2MK3	232.6	0.02
103227	K2	257.8	0.05
103228	M2	157.8	0.48
103228	S2	170.2	0.17
103228	N2	149.5	0.11
103228	K1	27.5	0.41
103228	M4	264.3	0.02
103228	O1	18.1	0.41
103228	M6	93.2	0.01
103228	NU2	150.5	0.02
103228	MU2	145.2	0.01
103228	2N2	141.2	0.01
103228	OO1	36.8	0.02
103228	M1	22.9	0.03
103228	J1	32.1	0.03
103228	SSA	66.7	0.1
103228	SA	167.9	0.25
103228	RHO1	14.3	0.02
103228	Q1	13.5	0.08
103228	T2	169.7	0.01
103228	2Q1	9	0.01
103228	P1	26.8	0.13
103228	L2	166.3	0.01
103228	K2	171.2	0.05
103229	M2	207.4	0.48
103229	S2	231.4	0.13
103229	N2	199.2	0.09
103229	K1	52	0.4
103229	M4	303.2	0.03
103229	O1	45.7	0.38
103229	M6	329.4	0.02
103229	MK3	177.3	0.04
103229	MN4	294.4	0.01
103229	NU2	205	0.02
103229	MU2	27.2	0.03
103229	2N2	285.7	0.03
103229	OO1	73.4	0.02
103229	LDA2	227.6	0.01
103229	S1	97.4	0.02
103229	M1	113.3	0.03
103229	J1	91.5	0.03
103229	MM	5.3	0.04
103229	SSA	51.1	0.1
103229	SA	151.6	0.36
103229	MSF	10.4	0.07
103229	RHO1	40.4	0.02
103229	Q1	38.4	0.07
103229	T2	217.8	0.02
103229	R2	246.6	0.02
103229	2Q1	2.5	0.01
103229	P1	65.1	0.15
103229	2SM2	83.9	0.01
103229	M3	32.6	0.01
103229	L2	201.4	0.03
103229	2MK3	164.3	0.04
103229	K2	213.4	0.08
103229	MS4	351.2	0.02
103230	M2	255.2	0.34
103230	S2	271.9	0.1
103230	N2	244.3	0.06
103230	K1	93.3	0.27
103230	M4	62.2	0.01
103230	O1	85.7	0.24
103230	M6	56.8	0.01
103230	MK3	266.7	0.04
103230	NU2	248.8	0.02
103230	MU2	64.9	0.02
103230	OO1	215.1	0.02
103230	LDA2	269.9	0.01
103230	S1	181.4	0.06
103230	M1	203.8	0.01
103230	J1	169.9	0.01
103230	MM	5.3	0.04
103230	SSA	51.1	0.1
103230	SA	151.6	0.36
103230	MSF	10.4	0.07
103230	RHO1	43.9	0.01
103230	Q1	86.6	0.05
103230	T2	282.7	0.01
103230	R2	233.3	0.01
103230	2Q1	83	0.01
103230	P1	106.4	0.07
103230	L2	275	0.02
103230	2MK3	250	0.04
103230	K2	268.8	0.05
103230	MS4	104.3	0.01
103231	M2	189.2	0.36
103231	S2	190.7	0.1
103231	N2	175.5	0.07
103231	K1	52.5	0.39
103231	M4	253.7	0.01
103231	O1	37.1	0.38
103231	NU2	177.4	0.01
103231	MU2	187.3	0.01
103231	2N2	162.4	0.01
103231	OO1	67.6	0.02
103231	M1	44.7	0.03
103231	J1	59.6	0.03
103231	SSA	66.7	0.1
103231	SA	167.9	0.25
103231	RHO1	30.9	0.01
103231	Q1	29.7	0.08
103231	T2	190.4	0.01
103231	2Q1	21.8	0.01
103231	P1	51.3	0.13
103231	L2	203.1	0.01
103231	K2	191.1	0.03
103232	M2	155.9	0.36
103232	S2	158.8	0.13
103232	N2	143.2	0.07
103232	K1	30.1	0.41
103232	M4	71.9	0.02
103232	O1	21.1	0.38
103232	M6	168.6	0.01
103232	NU2	144.9	0.01
103232	MU2	152.9	0.01
103232	2N2	130.4	0.01
103232	OO1	38.9	0.02
103232	M1	25.6	0.03
103232	J1	34.4	0.03
103232	SSA	66.7	0.1
103232	SA	167.9	0.25
103232	RHO1	17.3	0.01
103232	Q1	16.7	0.07
103232	T2	158.5	0.01
103232	2Q1	12.3	0.01
103232	P1	29.4	0.13
103232	L2	168.2	0.01
103232	K2	159	0.04
103233	M2	214.8	0.36
103233	S2	176.4	0.07
103233	N2	208.4	0.06
103233	K1	57.6	0.38
103233	M4	305.7	0.01
103233	O1	48.5	0.36
103233	M6	304.7	0.01
103233	MK3	185	0.01
103233	S4	339	0.01
103233	NU2	213.4	0.02
103233	MU2	43.1	0.03
103233	OO1	193.1	0.01
103233	LDA2	263.5	0.01
103233	S1	225	0.01
103233	M1	116.6	0.03
103233	J1	38.4	0.03
103233	SSA	66.7	0.1
103233	SA	167.9	0.25
103233	RHO1	17.3	0.01
103233	Q1	54.8	0.08
103233	T2	305	0.03
103233	R2	29.8	0.08
103233	2Q1	139.6	0.01
103233	P1	58.6	0.13
103233	M3	343.3	0.01
103233	L2	227.9	0.02
103233	2MK3	193.5	0.02
103233	K2	202.5	0.12
103233	MS4	355.5	0.01
103234	M2	165	0.36
103234	S2	170.3	0.13
103234	N2	156.3	0.07
103234	K1	40.6	0.42
103234	M4	230.5	0.01
103234	O1	31.9	0.34
103234	M6	206.2	0.01
103234	NU2	157.5	0.01
103234	MU2	159.8	0.01
103234	2N2	147.7	0.01
103234	OO1	49.8	0.01
103234	M1	36.4	0.02
103234	J1	45	0.03
103234	SSA	66.7	0.1
103234	SA	167.9	0.25
103234	RHO1	28.5	0.01
103234	Q1	27.6	0.07
103234	T2	169.8	0.01
103234	2Q1	23.8	0.01
103234	P1	40	0.14
103234	L2	173.4	0.01
103234	K2	170.7	0.04
103235	M2	230	0.48
103235	S2	230.8	0.14
103235	N2	215.4	0.1
103235	K1	69.2	0.48
103235	M4	11.1	0.01
103235	O1	62.7	0.37
103235	M6	71.9	0.01
103235	S4	2	0.01
103235	NU2	217.4	0.02
103235	MU2	229.3	0.01
103235	2N2	200.8	0.01
103235	OO1	75.6	0.02
103235	M1	66	0.03
103235	J1	72.4	0.03
103235	SSA	66.7	0.1
103235	SA	167.9	0.25
103235	RHO1	60	0.01
103235	Q1	59.5	0.07
103235	T2	230.7	0.01
103235	2Q1	56.3	0.01
103235	P1	68.7	0.16
103235	L2	244.6	0.01
103235	K2	230.8	0.04
103236	M2	246.3	0.52
103236	S2	261.6	0.11
103236	N2	238.8	0.08
103236	K1	77.2	0.43
103236	M4	39.9	0.02
103236	O1	65.3	0.41
103236	M6	93.6	0.01
103236	MK3	246.1	0.06
103236	S4	75.6	0.01
103236	NU2	220.3	0.02
103236	MU2	28.7	0.05
103236	2N2	61.6	0.03
103236	OO1	105.1	0.02
103236	LDA2	246.9	0.04
103236	S1	178.5	0.15
103236	M1	178.1	0.03
103236	J1	59.9	0.03
103236	SSA	66.7	0.1
103236	SA	167.9	0.25
103236	RHO1	130.4	0.03
103236	Q1	70.3	0.09
103236	T2	243.3	0.03
103236	R2	155.6	0.08
103236	2Q1	79.8	0.02
103236	P1	106.5	0.13
103236	2SM2	73.2	0.01
103236	M3	96.5	0.01
103236	L2	235.4	0.04
103236	2MK3	231.7	0.07
103236	K2	281.5	0.07
103236	MS4	90	0.01
103237	M2	188.9	0.36
103237	S2	205	0.11
103237	N2	184.4	0.07
103237	K1	55.4	0.39
103237	M4	317.8	0.01
103237	O1	48.6	0.37
103237	S4	353.4	0.01
103237	NU2	185	0.01
103237	MU2	174.4	0.01
103237	2N2	180.5	0.01
103237	OO1	62.5	0.02
103237	M1	52.2	0.03
103237	J1	59.2	0.03
103237	SSA	66.7	0.1
103237	SA	167.9	0.25
103237	RHO1	45.7	0.01
103237	Q1	45.1	0.07
103237	T2	204.4	0.01
103237	2Q1	41.3	0.01
103237	P1	54.9	0.13
103237	L2	193.7	0.01
103237	K2	206.4	0.03
103238	M2	282.3	0.482
103238	S2	300.5	0.115
103238	N2	275.1	0.085
103238	K1	99.5	0.371
103238	M4	84.8	0.02
103238	O1	87.3	0.354
103238	M6	174.8	0.007
103238	S4	195.6	0.003
103238	NU2	276.6	0.016
103238	S6	50	0.003
103238	MU2	264.9	0.01
103238	2N2	266.2	0.01
103238	OO1	115.3	0.013
103238	LDA2	290.7	0.003
103238	M1	94.2	0.023
103238	J1	107.7	0.026
103238	SSA	66.7	0.098
103238	SA	167.9	0.246
103238	RHO1	81.5	0.013
103238	Q1	80.4	0.069
103238	T2	298.2	0.007
103238	2Q1	73.8	0.01
103238	P1	98.6	0.121
103238	L2	285.6	0.013
103238	K2	302.1	0.03
103238	M8	299.5	0.003
103239	M2	117.8	0.56
103239	S2	127.6	0.19
103239	N2	111.8	0.13
103239	K1	8.7	0.49
103239	M4	56.8	0.01
103239	O1	3	0.45
103239	M6	68.6	0.01
103239	MK3	322.2	0.01
103239	S4	199.3	0.01
103239	MN4	67.2	0.01
103239	NU2	113.3	0.02
103239	MU2	66.7	0.02
103239	2N2	91.7	0.02
103239	OO1	23.5	0.02
103239	LDA2	103.9	0.01
103239	S1	91.6	0.09
103239	M1	28	0.02
103239	J1	41.1	0.02
103239	SSA	66.7	0.1
103239	SA	167.9	0.25
103239	RHO1	346.4	0.02
103239	Q1	352	0.09
103239	R2	156.5	0.03
103239	2Q1	354.1	0.01
103239	P1	359.5	0.12
103239	2SM2	116.2	0.01
103239	M3	289.2	0.01
103239	L2	124.9	0.01
103239	2MK3	317.6	0.03
103239	K2	128.8	0.06
103239	MS4	17.2	0.01
103240	M2	124.9	0.51
103240	S2	135.7	0.18
103240	N2	118.4	0.1
103240	K1	13	0.48
103240	M4	43.3	0.01
103240	O1	5.4	0.42
103240	M6	98.2	0.01
103240	MK3	35.9	0.01
103240	MN4	357.1	0.01
103240	NU2	125.3	0.02
103240	MU2	16.1	0.01
103240	2N2	107.7	0.02
103240	OO1	358.9	0.02
103240	LDA2	80.2	0.01
103240	S1	149.2	0.02
103240	M1	17.9	0.02
103240	J1	27.5	0.03
103240	SSA	66.7	0.1
103240	SA	167.9	0.25
103240	RHO1	335.9	0.02
103240	Q1	3.6	0.09
103240	T2	112.6	0.01
103240	R2	54	0.02
103240	2Q1	324.2	0.02
103240	P1	25.9	0.16
103240	2SM2	290	0.01
103240	M3	289.5	0.01
103240	L2	178.5	0.03
103240	2MK3	342.2	0.01
103240	K2	128.5	0.06
103240	MS4	15.3	0.01
103241	M2	181.8	0.5
103241	S2	204.2	0.16
103241	N2	174.8	0.09
103241	K1	46.4	0.49
103241	M4	219.8	0.02
103241	O1	34.4	0.43
103241	M6	255.6	0.01
103241	MK3	122.8	0.03
103241	MN4	219.2	0.01
103241	NU2	184	0.02
103241	MU2	0.6	0.02
103241	2N2	170	0.04
103241	OO1	66	0.02
103241	LDA2	156.6	0.02
103241	S1	191.3	0.03
103241	M1	32.3	0.01
103241	J1	87.5	0.03
103241	SSA	48.2	0.14
103241	SA	155	0.35
103241	MF	193.2	0.04
103241	RHO1	16.7	0.02
103241	Q1	34.3	0.08
103241	T2	253.9	0.01
103241	R2	62.1	0.02
103241	2Q1	25	0.01
103241	P1	67.3	0.14
103241	2SM2	32.3	0.01
103241	M3	12.2	0.02
103241	L2	201.6	0.03
103241	2MK3	103.4	0.04
103241	K2	200.3	0.08
103241	MS4	251.7	0.01
103242	M2	130.4	0.54
103242	S2	141.7	0.24
103242	N2	122.1	0.12
103242	K1	20.4	0.47
103242	M4	57.3	0.04
103242	O1	10.6	0.46
103242	MK3	291.4	0.02
103242	NU2	117.5	0.02
103242	MU2	64	0.03
103242	2N2	73.9	0.02
103242	OO1	48.5	0.02
103242	LDA2	282.7	0.01
103242	S1	111.2	0.03
103242	M1	3.4	0.01
103242	J1	28.4	0.03
103242	RHO1	4	0.03
103242	Q1	2.8	0.1
103242	2Q1	14.4	0.01
103242	P1	13.9	0.15
103242	2SM2	107.9	0.01
103242	L2	207.1	0.01
103242	2MK3	289.1	0.02
103242	K2	133.9	0.08
103242	MS4	65.7	0.03
103243	M2	137.3	0.51
103243	S2	152.5	0.2
103243	N2	132.5	0.1
103243	K1	24.3	0.49
103243	M4	63.3	0.02
103243	O1	14.2	0.45
103243	M6	141.4	0.01
103243	MK3	307.9	0.01
103243	MN4	50.7	0.01
103243	NU2	139.3	0.02
103243	MU2	77.5	0.02
103243	2N2	114.2	0.02
103243	OO1	36	0.01
103243	S1	130.5	0.06
103243	M1	357.2	0.01
103243	J1	29.3	0.03
103243	RHO1	351	0.03
103243	Q1	7	0.09
103243	T2	167.4	0.01
103243	2Q1	10.5	0.01
103243	P1	14.2	0.15
103243	M3	303	0.01
103243	L2	176.3	0.01
103243	2MK3	298	0.02
103243	K2	146.4	0.06
103243	MS4	68.4	0.02
103244	M2	174.6	0.52
103244	S2	187.5	0.17
103244	N2	168.1	0.09
103244	K1	39.9	0.51
103244	M4	161	0.01
103244	O1	26.9	0.46
103244	M6	179.1	0.01
103244	MK3	46.3	0.01
103244	NU2	183.1	0.03
103244	MU2	27.7	0.03
103244	2N2	145.4	0.01
103244	OO1	84.3	0.01
103244	LDA2	207.5	0.01
103244	S1	134.2	0.05
103244	M1	81.8	0.01
103244	J1	69.3	0.02
103244	SSA	60.4	0.12
103244	SA	156.1	0.35
103244	RHO1	349.8	0.02
103244	Q1	18.9	0.09
103244	T2	179.9	0.01
103244	2Q1	341.8	0.01
103244	P1	45.8	0.15
103244	2SM2	68.3	0.01
103244	M3	338.8	0.01
103244	L2	209.5	0.02
103244	2MK3	21.2	0.01
103244	K2	190.9	0.07
103244	MS4	167	0.01
103245	M2	226.5	0.41
103245	S2	261.2	0.15
103245	N2	224.3	0.08
103245	K1	62.8	0.5
103245	M4	351.7	0.01
103245	O1	61.8	0.44
103245	M6	284.4	0.01
103245	S4	100	0.01
103245	NU2	224.6	0.01
103245	MU2	27.2	0.01
103245	2N2	222.2	0.01
103245	OO1	63.6	0.02
103245	M1	62.3	0.03
103245	J1	63.2	0.04
103245	RHO1	61.4	0.02
103245	Q1	61.3	0.09
103245	T2	259.8	0.01
103245	2Q1	60.9	0.01
103245	P1	62.8	0.16
103245	L2	229.6	0.01
103245	K2	264	0.04
103246	M2	199.4	0.54
103246	S2	214.8	0.17
103246	N2	190.4	0.09
103246	K1	49.8	0.53
103246	M4	237.1	0.01
103246	O1	36.6	0.48
103246	M6	218.2	0.01
103246	MK3	137.2	0.01
103246	NU2	203.2	0.03
103246	MU2	26.3	0.03
103246	2N2	176.2	0.01
103246	OO1	84.7	0.01
103246	LDA2	222.7	0.02
103246	S1	140.3	0.05
103246	M1	90.7	0.02
103246	J1	78.6	0.03
103246	SSA	55	0.11
103246	SA	152.9	0.34
103246	MSF	7.3	0.05
103246	RHO1	7.6	0.03
103246	Q1	26.6	0.09
103246	T2	197	0.01
103246	2Q1	14.6	0.01
103246	P1	58.5	0.15
103246	2SM2	86	0.01
103246	M3	6.5	0.01
103246	L2	225	0.03
103246	2MK3	136.1	0.01
103246	K2	215.1	0.08
103247	M2	205.6	0.63
103247	S2	221.5	0.21
103247	N2	193.5	0.1
103247	K1	63.7	0.51
103247	M4	265.4	0.02
103247	O1	42.9	0.48
103247	M6	317.2	0.02
103247	NU2	195.2	0.02
103247	MU2	189.4	0.02
103247	2N2	181.8	0.01
103247	OO1	84.4	0.02
103247	M1	53.3	0.03
103247	J1	73.7	0.04
103247	SSA	41	0.11
103247	SA	150.8	0.3
103247	RHO1	34	0.02
103247	Q1	32.6	0.1
103247	T2	220.8	0.01
103247	2Q1	22.3	0.01
103247	P1	62.1	0.17
103247	L2	218	0.02
103247	K2	222.8	0.06
103248	M2	216.1	0.64
103248	S2	234	0.2
103248	N2	210	0.1
103248	K1	57.2	0.56
103248	M4	283.1	0.01
103248	O1	43.9	0.51
103248	MK3	229.3	0.03
103248	NU2	215	0.04
103248	MU2	22.1	0.04
103248	2N2	227.1	0.01
103248	OO1	130.8	0.02
103248	LDA2	228.8	0.02
103248	S1	143.5	0.06
103248	M1	100.7	0.02
103248	J1	101.9	0.03
103248	SSA	58.9	0.12
103248	SA	151.2	0.39
103248	MSF	7.3	0.04
103248	RHO1	2.2	0.03
103248	Q1	37.1	0.09
103248	T2	220.3	0.01
103248	R2	196.8	0.01
103248	2Q1	4.4	0.01
103248	P1	66.9	0.15
103248	2SM2	87.1	0.01
103248	M3	112.2	0.01
103248	L2	235.6	0.04
103248	2MK3	204.1	0.03
103248	K2	230.1	0.1
103249	M2	201	0.72
103249	S2	220.6	0.24
103249	N2	191.5	0.13
103249	K1	55.6	0.49
103249	M4	263.3	0.03
103249	O1	41.8	0.52
103249	M6	311.6	0.03
103249	NU2	192.7	0.02
103249	S6	264.6	0.01
103249	MU2	181.2	0.02
103249	2N2	181.5	0.02
103249	OO1	69.8	0.02
103249	LDA2	209.8	0.01
103249	M1	49	0.04
103249	J1	63	0.04
103249	SSA	41	0.11
103249	SA	150.8	0.3
103249	RHO1	36	0.02
103249	Q1	34.8	0.1
103249	T2	219.9	0.01
103249	2Q1	28.3	0.01
103249	P1	54.6	0.16
103249	L2	210	0.02
103249	K2	222.1	0.06
103250	M2	202.4	0.71
103250	S2	219.6	0.23
103250	N2	196.7	0.12
103250	K1	51	0.56
103250	M4	259.6	0.03
103250	O1	37.9	0.5
103250	M6	327.2	0.03
103250	MK3	147.8	0.02
103250	S4	343.2	0.01
103250	MN4	233.9	0.01
103250	NU2	204.7	0.04
103250	MU2	18.8	0.04
103250	2N2	184.2	0.01
103250	OO1	157.3	0.02
103250	LDA2	224.3	0.02
103250	S1	134.2	0.08
103250	M1	107	0.01
103250	J1	91	0.03
103250	SSA	52.3	0.12
103250	SA	151.2	0.35
103250	RHO1	348.7	0.02
103250	Q1	34.5	0.1
103250	T2	223.8	0.02
103250	R2	172.9	0.01
103250	2Q1	27.3	0.01
103250	P1	55.2	0.15
103250	2SM2	76.4	0.01
103250	M3	76	0.01
103250	L2	229.4	0.04
103250	2MK3	135.5	0.02
103250	K2	217.8	0.1
103250	MS4	280.2	0.02
103251	M2	202.1	0.67
103251	S2	212	0.22
103251	N2	189.7	0.1
103251	K1	53.2	0.59
103251	M4	264.1	0.03
103251	O1	38	0.5
103251	M6	330.8	0.03
103251	MK3	127.7	0.02
103251	S4	2.8	0.01
103251	MN4	241.8	0.01
103251	NU2	199.7	0.04
103251	MU2	32	0.04
103251	2N2	175.6	0.04
103251	OO1	81.4	0.02
103251	LDA2	196.5	0.02
103251	S1	108.2	0.1
103251	M1	20.4	0.02
103251	J1	70.1	0.05
103251	SSA	41	0.11
103251	SA	150.8	0.3
103251	RHO1	359.2	0.05
103251	Q1	37.4	0.09
103251	T2	255.6	0.04
103251	R2	133.5	0.05
103251	2Q1	12.5	0.01
103251	P1	57.2	0.21
103251	2SM2	52.3	0.02
103251	M3	48	0.02
103251	L2	228.1	0.05
103251	2MK3	128.7	0.02
103251	K2	231.3	0.11
103251	MS4	284.9	0.02
103252	M2	123.1	0.81
103252	S2	141	0.31
103252	N2	120.3	0.15
103252	K1	12.4	0.52
103252	M4	76	0.03
103252	O1	3.6	0.5
103252	MK3	331.7	0.01
103252	MN4	51	0.02
103252	NU2	121.6	0.03
103252	2N2	110.1	0.02
103252	OO1	4.7	0.02
103252	LDA2	131.4	0.01
103252	S1	93.8	0.04
103252	M1	15.7	0.02
103252	J1	20.8	0.03
103252	SSA	48.2	0.12
103252	SA	151.9	0.3
103252	RHO1	341.8	0.02
103252	Q1	348	0.1
103252	T2	119.1	0.02
103252	2Q1	340.8	0.02
103252	P1	12.5	0.17
103252	M3	298.6	0.01
103252	L2	143.1	0.02
103252	2MK3	309	0.01
103252	K2	134.6	0.09
103252	MS4	90.5	0.02
103253	M2	242.2	0.68
103253	S2	262	0.25
103253	N2	237.9	0.12
103253	K1	68.7	0.65
103253	M4	17	0.03
103253	O1	57.9	0.53
103253	NU2	238.5	0.03
103253	MU2	58.5	0.02
103253	2N2	233.5	0.02
103253	OO1	78.8	0.02
103253	M1	63.2	0.04
103253	J1	73.5	0.04
103253	RHO1	53.4	0.02
103253	Q1	52.7	0.1
103253	T2	261.2	0.01
103253	2Q1	47.5	0.01
103253	P1	67.8	0.21
103253	L2	246.4	0.02
103253	K2	263.6	0.07
103254	M2	134	0.94
103254	S2	153.1	0.38
103254	N2	127.5	0.16
103254	K1	14.1	0.61
103254	M4	127.3	0.02
103254	O1	5.1	0.47
103254	S4	294.9	0.01
103254	NU2	128.4	0.03
103254	S6	339.1	0.01
103254	MU2	114.8	0.02
103254	2N2	121	0.02
103254	OO1	23.2	0.02
103254	LDA2	142.9	0.01
103254	M1	9.7	0.03
103254	J1	18.6	0.04
103254	SSA	48.2	0.12
103254	SA	151.9	0.3
103254	RHO1	1.3	0.02
103254	Q1	0.7	0.09
103254	T2	152.4	0.02
103254	2Q1	356.2	0.01
103254	P1	13.5	0.2
103254	L2	140.4	0.03
103254	K2	154.7	0.1
103255	M2	193.7	0.85
103255	S2	246.6	0.35
103255	N2	195.9	0.16
103255	K1	38.2	0.54
103255	M4	321.3	0.05
103255	O1	48.5	0.48
103255	M6	160	0.01
103255	S4	53.7	0.03
103255	NU2	195.6	0.03
103255	MU2	141.5	0.02
103255	2N2	198	0.02
103255	OO1	28.7	0.02
103255	LDA2	217.9	0.01
103255	M1	43.6	0.04
103255	J1	33.5	0.04
103255	SSA	48.2	0.12
103255	SA	151.9	0.3
103255	RHO1	52.8	0.02
103255	Q1	53.3	0.09
103255	T2	244.6	0.02
103255	2Q1	58.5	0.01
103255	P1	38.9	0.18
103255	L2	190.8	0.02
103255	K2	250.9	0.1
103256	M2	236.2	0.7
103256	S2	289.4	0.25
103256	N2	236.9	0.09
103256	K1	86.5	0.36
103256	M4	51.2	0.08
103256	O1	76.3	0.39
103256	M6	275.2	0.02
103256	MK3	239.9	0.12
103256	S4	139.3	0.01
103256	MN4	51.4	0.02
103256	NU2	211.7	0.03
103256	MU2	359.8	0.09
103256	2N2	180	0.05
103256	OO1	155	0.03
103256	LDA2	145.4	0.01
103256	S1	188	0.04
103256	M1	191.2	0.03
103256	J1	95	0.03
103256	RHO1	56.6	0.01
103256	Q1	59	0.07
103256	T2	287.2	0.01
103256	2Q1	52.8	0.04
103256	P1	83.6	0.13
103256	2SM2	20.2	0.01
103256	M3	32.7	0.01
103256	L2	259	0.05
103256	2MK3	222.5	0.11
103256	K2	265.6	0.14
103256	MS4	91.1	0.05
103257	M2	328	0.14
103257	S2	358	0.04
103257	N2	333.8	0.02
103257	K1	166.4	0.11
103257	M4	209.8	0.02
103257	O1	143.9	0.13
103257	OO1	188.8	0.01
103257	M1	155.1	0.01
103257	J1	177.5	0.01
103257	RHO1	134.1	0.01
103257	Q1	132.6	0.03
103257	P1	164.6	0.04
103257	K2	0.3	0.01
103258	M2	300.7	0.34
103258	S2	351.6	0.13
103258	N2	290.4	0.04
103258	K1	135.6	0.22
103258	M4	172.8	0.04
103258	O1	125.8	0.26
103258	M6	75.9	0.01
103258	MK3	340.6	0.07
103258	MN4	160.2	0.01
103258	NU2	279.7	0.01
103258	MU2	74.4	0.05
103258	2N2	249.1	0.04
103258	OO1	118.3	0.01
103258	LDA2	256.3	0.01
103258	S1	187.5	0.03
103258	M1	225.3	0.02
103258	J1	182.8	0.01
103258	RHO1	151.8	0.02
103258	Q1	101.8	0.04
103258	T2	349.5	0.01
103258	2Q1	85.1	0.03
103258	P1	135	0.09
103258	2SM2	71.4	0.01
103258	L2	336.7	0.02
103258	2MK3	323.8	0.07
103258	K2	341.5	0.1
103258	MS4	211	0.03
103259	M2	246.2	0.56
103259	S2	290.2	0.17
103259	N2	245.2	0.09
103259	K1	106.2	0.27
103259	M4	77.1	0.07
103259	O1	81.9	0.37
103259	M6	302.4	0.01
103259	S4	173.4	0.01
103259	NU2	245.3	0.02
103259	MU2	175.8	0.01
103259	2N2	244.3	0.01
103259	OO1	130.4	0.02
103259	M1	94	0.03
103259	J1	118.3	0.03
103259	RHO1	71.4	0.01
103259	Q1	69.7	0.07
103259	T2	288.3	0.01
103259	2Q1	57.7	0.01
103259	P1	104.3	0.09
103259	L2	247	0.01
103259	K2	293.8	0.05
103260	M2	336.8	0.17
103260	S2	356.6	0.04
103260	N2	329.9	0.02
103260	K1	165.2	0.13
103260	M4	227.4	0.02
103260	O1	158.2	0.16
103260	MK3	23.4	0.03
103260	MN4	225.5	0.01
103260	MU2	110.2	0.03
103260	OO1	172.1	0.01
103260	S1	202.7	0.03
103260	M1	161.6	0.01
103260	J1	168.7	0.01
103260	RHO1	155.1	0.01
103260	Q1	154.6	0.03
103260	P1	164.6	0.04
103260	2MK3	7.7	0.03
103260	K2	358.2	0.01
103260	MS4	262.9	0.01
103261	M2	334.6	0.19
103261	S2	17.5	0.04
103261	N2	13.7	0.02
103261	K1	161.6	0.12
103261	M4	206.7	0.02
103261	O1	152.4	0.15
103261	OO1	170.6	0.01
103261	M1	157	0.01
103261	J1	166	0.01
103261	RHO1	148.5	0.01
103261	Q1	147.9	0.03
103261	P1	160.8	0.04
103261	K2	21	0.01
103262	M2	248.5	0.59
103262	S2	299.8	0.18
103262	N2	251.9	0.08
103262	K1	101.2	0.27
103262	M4	73.1	0.1
103262	O1	97.6	0.3
103262	M6	273.8	0.02
103262	S4	169.1	0.01
103262	NU2	251.5	0.01
103262	MU2	174.8	0.01
103262	2N2	255.5	0.01
103262	OO1	104.7	0.01
103262	M1	99.3	0.02
103262	J1	102.9	0.02
103262	RHO1	96	0.01
103262	Q1	95.7	0.06
103262	T2	297.6	0.01
103262	2Q1	93.9	0.01
103262	P1	100.8	0.09
103262	L2	245	0.01
103262	K2	304	0.05
103263	M2	204.5	1.24
103263	S2	244.8	0.41
103263	N2	201.8	0.18
103263	K1	55.6	0.45
103263	M4	324.4	0.07
103263	O1	42.6	0.49
103263	M6	289.2	0.01
103263	S4	72.9	0.02
103263	NU2	202.2	0.04
103263	MU2	138.3	0.03
103263	2N2	199.3	0.02
103263	OO1	68.5	0.02
103263	LDA2	223.2	0.01
103263	M1	49	0.04
103263	J1	62	0.04
103263	RHO1	37	0.02
103263	Q1	36.1	0.1
103263	T2	243.2	0.02
103263	2Q1	29.7	0.01
103263	P1	54.5	0.15
103263	L2	207.1	0.03
103263	K2	248.1	0.11
103264	M2	261.2	0.69
103264	S2	311.2	0.23
103264	N2	253.7	0.11
103264	K1	110.3	0.27
103264	M4	86.8	0.08
103264	O1	93.3	0.37
103264	M6	12	0.01
103264	S4	242.3	0.02
103264	NU2	254.7	0.02
103264	MU2	186	0.02
103264	2N2	246.2	0.01
103264	OO1	127.2	0.02
103264	LDA2	284.4	0.01
103264	M1	101.8	0.03
103264	J1	118.7	0.03
103264	RHO1	86	0.01
103264	Q1	84.8	0.07
103264	T2	309.1	0.01
103264	2Q1	76.4	0.01
103264	P1	108.9	0.09
103264	L2	268.7	0.02
103264	K2	315.2	0.06
103265	M2	270.8	0.7
103265	S2	314.8	0.2
103265	N2	276	0.09
103265	K1	96.1	0.27
103265	M4	92.2	0.06
103265	O1	85.1	0.3
103265	M6	114.6	0.01
103265	S4	201.3	0.01
103265	NU2	275.3	0.02
103265	MU2	201.7	0.02
103265	2N2	281.3	0.01
103265	OO1	107	0.01
103265	LDA2	291.1	0.01
103265	M1	90.5	0.02
103265	J1	101.6	0.02
103265	RHO1	80.3	0.01
103265	Q1	79.5	0.06
103265	T2	312.9	0.01
103265	2Q1	74.1	0.01
103265	P1	95.2	0.09
103265	L2	265.5	0.01
103265	K2	318.4	0.06
103266	M2	243.2	0.79
103266	S2	282.7	0.25
103266	N2	241.8	0.11
103266	K1	90.7	0.26
103266	M4	43.9	0.06
103266	O1	68.4	0.36
103266	M6	42.1	0.01
103266	S4	135.5	0.02
103266	NU2	242	0.02
103266	MU2	178.2	0.02
103266	2N2	240.5	0.02
103266	OO1	112.9	0.02
103266	LDA2	261.4	0.01
103266	M1	79.6	0.03
103266	J1	101.8	0.03
103266	SSA	201.2	0.03
103266	SA	280.6	0.11
103266	RHO1	58.8	0.01
103266	Q1	57.2	0.07
103266	T2	281	0.02
103266	2Q1	46.3	0.01
103266	P1	88.9	0.09
103266	L2	244.4	0.02
103266	K2	285.9	0.07
103267	M2	216.5	1
103267	S2	253.6	0.31
103267	N2	212.4	0.15
103267	K1	71.6	0.34
103267	M4	4.5	0.1
103267	O1	54.3	0.4
103267	S4	99.8	0.02
103267	NU2	212.9	0.03
103267	MU2	153.7	0.02
103267	2N2	208.4	0.02
103267	OO1	88.8	0.02
103267	LDA2	233.6	0.01
103267	M1	62.8	0.03
103267	J1	80.2	0.03
103267	SSA	201.2	0.02
103267	SA	280.6	0.09
103267	RHO1	46.8	0.02
103267	Q1	45.6	0.08
103267	T2	252	0.02
103267	2Q1	37	0.01
103267	P1	70.2	0.11
103267	L2	220.4	0.02
103267	K2	256.6	0.08
103268	M2	188.9	1.25
103268	S2	225.7	0.4
103268	N2	181.9	0.22
103268	K1	35	0.55
103268	M4	252.4	0.03
103268	O1	26.9	0.52
103268	M6	195.7	0.01
103268	MK3	169.1	0.02
103268	MN4	229.5	0.01
103268	NU2	181	0.06
103268	MU2	292	0.05
103268	2N2	183.3	0.02
103268	OO1	106.4	0.01
103268	LDA2	233.1	0.03
103268	S1	135	0.02
103268	M1	90.7	0.02
103268	J1	58.6	0.03
103268	SSA	41.1	0.1
103268	SA	140	0.39
103268	RHO1	359.5	0.03
103268	Q1	11.9	0.12
103268	T2	219.8	0.03
103268	R2	51.4	0.05
103268	2Q1	342	0.02
103268	P1	26.9	0.19
103268	2SM2	87.7	0.02
103268	L2	198.6	0.06
103268	2MK3	160.5	0.03
103268	K2	224.1	0.1
103268	MS4	292	0.02
103269	M2	183	1.23
103269	S2	200.1	0.48
103269	N2	180	0.22
103269	K1	34.7	0.64
103269	M4	247.8	0.06
103269	O1	21.3	0.52
103269	M6	339.1	0.01
103269	S4	342.5	0.02
103269	NU2	180.3	0.04
103269	MU2	166.1	0.03
103269	2N2	177.1	0.03
103269	OO1	49.1	0.02
103269	LDA2	190.8	0.01
103269	M1	28.4	0.04
103269	J1	41.9	0.04
103269	SSA	41.1	0.1
103269	SA	140	0.39
103269	RHO1	15.3	0.02
103269	Q1	14.4	0.1
103269	T2	199.3	0.03
103269	2Q1	7.4	0.01
103269	P1	33.7	0.21
103269	L2	185.2	0.03
103269	K2	201.4	0.13
103269	M8	212.6	0.01
103270	M2	187	1.18
103270	S2	215.3	0.45
103270	N2	181	0.17
103270	K1	32.3	0.48
103270	M4	285.2	0.06
103270	O1	25.5	0.5
103270	M6	212.9	0.01
103270	S4	335.4	0.02
103270	NU2	181.8	0.03
103270	MU2	158.7	0.03
103270	2N2	174.8	0.02
103270	OO1	40.7	0.02
103270	LDA2	200.4	0.01
103270	M1	29.2	0.04
103270	J1	36.6	0.04
103270	SA	136.4	0.31
103270	RHO1	22.3	0.02
103270	Q1	21.8	0.1
103270	T2	214.2	0.03
103270	2Q1	18.6	0.01
103270	P1	31.8	0.16
103270	L2	194	0.03
103270	K2	217.6	0.12
103271	M2	198	1.14
103271	S2	217.2	0.46
103271	N2	202.5	0.21
103271	K1	39.5	0.62
103271	M4	357.2	0.07
103271	O1	26.6	0.51
103271	M6	4.5	0.01
103271	S4	29.2	0.02
103271	NU2	201.9	0.04
103271	MU2	179.5	0.03
103271	2N2	207.3	0.03
103271	OO1	52	0.02
103271	LDA2	206.7	0.01
103271	M1	33.1	0.04
103271	J1	46	0.04
103271	SSA	41.1	0.1
103271	SA	140	0.39
103271	RHO1	21.1	0.02
103271	Q1	20.2	0.1
103271	T2	216.5	0.03
103271	2Q1	13.9	0.01
103271	P1	38.5	0.2
103271	L2	194.1	0.03
103271	K2	218.7	0.12
103272	M2	197.7	1.2
103272	S2	221.2	0.51
103272	N2	189.8	0.19
103272	K1	35.3	0.48
103272	M4	5.7	0.05
103272	O1	31.1	0.47
103272	MK3	161.7	0.09
103272	MN4	12.7	0.03
103272	NU2	197.2	0.05
103272	MU2	316.1	0.06
103272	2N2	155.4	0.04
103272	OO1	87.2	0.07
103272	LDA2	195.3	0.03
103272	S1	116.4	0.03
103272	M1	166.3	0.03
103272	SSA	43.3	0.13
103272	SA	135.7	0.38
103272	RHO1	62.8	0.03
103272	Q1	18.1	0.1
103272	T2	185.6	0.06
103272	R2	54.7	0.09
103272	2Q1	353.7	0.03
103272	P1	45.3	0.17
103272	2SM2	2.9	0.03
103272	L2	218.1	0.07
103272	2MK3	144.1	0.06
103272	K2	185.7	0.18
103272	MS4	25.6	0.06
103273	M2	209.9	0.99
103273	S2	242	0.46
103273	N2	199.4	0.15
103273	K1	35.2	0.59
103273	M4	62.7	0.05
103273	O1	37.2	0.52
103273	S4	106	0.05
103273	NU2	200.6	0.03
103273	S6	295.3	0.01
103273	MU2	177.7	0.02
103273	2N2	189.6	0.02
103273	OO1	32.7	0.02
103273	LDA2	224.9	0.01
103273	M1	36.2	0.04
103273	J1	34	0.04
103273	SSA	41.1	0.1
103273	SA	140	0.39
103273	RHO1	38.3	0.02
103273	Q1	38.4	0.1
103273	T2	240.7	0.03
103273	2Q1	39.6	0.01
103273	P1	35.3	0.19
103273	L2	222.5	0.03
103273	K2	244.6	0.12
103274	M2	230.5	1.14
103274	S2	256.3	0.46
103274	N2	243.7	0.2
103274	K1	53.3	0.62
103274	M4	264.7	0.02
103274	O1	38.2	0.45
103274	M6	17.1	0.01
103274	NU2	242	0.04
103274	MU2	205.1	0.03
103274	2N2	256.4	0.03
103274	OO1	67.3	0.02
103274	LDA2	242.4	0.01
103274	M1	45.7	0.03
103274	J1	60.3	0.04
103274	SSA	41.1	0.1
103274	SA	140	0.39
103274	RHO1	32	0.02
103274	Q1	31	0.09
103274	T2	255.3	0.03
103274	2Q1	23.7	0.01
103274	P1	52.2	0.21
103274	L2	218.1	0.03
103274	K2	258.4	0.13
103274	M8	47	0.01
103275	M2	197.9	1.17
103275	S2	224.8	0.49
103275	N2	193.5	0.22
103275	K1	30.8	0.57
103275	O1	27.6	0.5
103275	MK3	132.8	0.04
103275	NU2	246.2	0.04
103275	MU2	308.4	0.02
103275	2N2	189.1	0.03
103275	OO1	33.9	0.02
103275	LDA2	217.5	0.03
103275	S1	109.3	0.09
103275	M1	29.1	0.04
103275	J1	32.4	0.04
103275	SSA	53.6	0.1
103275	SA	138.8	0.33
103275	RHO1	1.5	0.04
103275	Q1	11.8	0.14
103275	T2	162.3	0.04
103275	2Q1	24.3	0.01
103275	P1	34.3	0.15
103275	2SM2	25.9	0.01
103275	M3	220.6	0.02
103275	L2	253	0.05
103275	2MK3	128.1	0.05
103275	K2	212.3	0.12
103275	MS4	42.3	0.01
103276	M2	227.3	1.19
103276	S2	250.1	0.48
103276	N2	239.6	0.21
103276	K1	49.3	0.64
103276	M4	350.7	0.03
103276	O1	37.4	0.48
103276	M6	26	0.02
103276	S4	103.9	0.01
103276	NU2	238	0.04
103276	MU2	204.8	0.03
103276	2N2	252.3	0.03
103276	OO1	60.1	0.02
103276	LDA2	237.7	0.01
103276	M1	43.2	0.03
103276	J1	54.6	0.04
103276	SSA	45.5	0.16
103276	SA	145.5	0.36
103276	MSF	32.6	0.06
103276	RHO1	32.6	0.02
103276	Q1	31.8	0.09
103276	T2	249.2	0.03
103276	2Q1	26.1	0.01
103276	P1	48.5	0.21
103276	L2	215.1	0.03
103276	K2	252	0.13
103276	M8	61.1	0.01
103277	M2	208.2	1.19
103277	S2	234.3	0.46
103277	N2	203.5	0.21
103277	K1	36.1	0.6
103277	M4	19	0.01
103277	O1	29.6	0.53
103277	MK3	151.4	0.05
103277	NU2	196.7	0.05
103277	MU2	334.2	0.03
103277	2N2	198.9	0.03
103277	OO1	42.5	0.02
103277	LDA2	220.2	0.01
103277	S1	111.8	0.05
103277	M1	32.8	0.04
103277	J1	46.1	0.04
103277	SSA	43.3	0.13
103277	SA	135.7	0.38
103277	RHO1	26.7	0.02
103277	Q1	16.5	0.12
103277	T2	234.2	0.03
103277	R2	201.8	0.03
103277	2Q1	23	0.01
103277	P1	39.6	0.18
103277	2SM2	64.7	0.01
103277	L2	228.6	0.04
103277	2MK3	133.5	0.05
103277	K2	229.2	0.13
103277	MS4	51.7	0.02
103278	M2	222.3	0.97
103278	S2	250.9	0.41
103278	N2	217	0.15
103278	K1	42.6	0.48
103278	M4	41.9	0.02
103278	O1	40.7	0.49
103278	M6	5.4	0.01
103278	S4	285.5	0.01
103278	NU2	217.7	0.03
103278	MU2	193.6	0.02
103278	2N2	211.8	0.02
103278	OO1	44.4	0.02
103278	LDA2	235.6	0.01
103278	M1	41.6	0.04
103278	J1	43.5	0.04
103278	RHO1	39.9	0.02
103278	Q1	39.8	0.1
103278	T2	249.8	0.02
103278	2Q1	38.8	0.01
103278	P1	42.4	0.16
103278	L2	227.5	0.03
103278	K2	253.3	0.11
103279	M2	214.4	1.15
103279	S2	240.8	0.44
103279	N2	209.3	0.2
103279	K1	39.7	0.58
103279	M4	359.7	0.01
103279	O1	35.1	0.52
103279	M6	288.4	0.01
103279	MK3	156.5	0.05
103279	MN4	44.6	0.01
103279	NU2	190.7	0.04
103279	MU2	322.4	0.03
103279	2N2	198.8	0.02
103279	OO1	52.6	0.02
103279	LDA2	219	0.04
103279	S1	97.1	0.04
103279	M1	106.2	0.03
103279	J1	59.3	0.04
103279	SSA	41.1	0.1
103279	SA	140	0.39
103279	RHO1	58.7	0.03
103279	Q1	8.9	0.12
103279	T2	239.6	0.03
103279	R2	195.5	0.03
103279	2Q1	76.1	0.01
103279	P1	46.2	0.18
103279	2SM2	98.8	0.02
103279	M3	322.4	0.01
103279	L2	219.5	0.06
103279	2MK3	142.5	0.07
103279	K2	235.3	0.15
103279	MS4	73.1	0.01
103280	M2	200.3	0.84
103280	S2	221.8	0.31
103280	N2	190.1	0.16
103280	K1	29.8	0.56
103280	M4	352	0.02
103280	O1	24	0.52
103280	MK3	115.8	0.01
103280	NU2	191.6	0.03
103280	MU2	57.7	0.03
103280	2N2	180	0.02
103280	OO1	35.5	0.02
103280	LDA2	210.2	0.01
103280	S1	77.5	0.04
103280	M1	26.8	0.04
103280	J1	44.1	0.04
103280	SSA	47.4	0.12
103280	SA	134	0.38
103280	RHO1	21.5	0.02
103280	Q1	1.9	0.12
103280	T2	221.7	0.02
103280	2Q1	18.1	0.01
103280	P1	31.3	0.17
103280	2SM2	96.8	0.02
103280	L2	235.3	0.04
103280	K2	232.8	0.1
103281	M2	209.3	0.68
103281	S2	235	0.27
103281	N2	211.2	0.12
103281	K1	29.5	0.57
103281	M4	1.4	0.02
103281	O1	27	0.5
103281	M6	162	0.01
103281	S4	211.6	0.01
103281	NU2	210.8	0.02
103281	S6	255.1	0.01
103281	MU2	183.7	0.02
103281	2N2	213.3	0.02
103281	OO1	31.8	0.02
103281	M1	28.2	0.03
103281	J1	30.3	0.04
103281	SSA	47.4	0.12
103281	SA	134	0.38
103281	RHO1	26.2	0.02
103281	Q1	25.9	0.1
103281	T2	234	0.02
103281	2Q1	25	0.01
103281	P1	29.3	0.19
103281	L2	207.9	0.02
103281	K2	237.1	0.07
103282	M2	210.6	0.73
103282	S2	231.2	0.3
103282	N2	199.1	0.11
103282	K1	33.1	0.58
103282	M4	345.7	0.03
103282	O1	24.9	0.5
103282	M6	202.3	0.01
103282	S4	66.5	0.01
103282	NU2	200.6	0.02
103282	MU2	190.6	0.02
103282	2N2	185.2	0.01
103282	OO1	41.4	0.02
103282	LDA2	219.9	0.01
103282	M1	29	0.04
103282	J1	37.3	0.04
103282	SSA	47.4	0.12
103282	SA	134	0.38
103282	RHO1	21.3	0.02
103282	Q1	20.8	0.1
103282	T2	230.2	0.02
103282	2Q1	16.8	0.01
103282	P1	32.5	0.19
103282	L2	220	0.02
103282	K2	232.9	0.08
103283	M2	212.5	0.62
103283	S2	240.9	0.23
103283	N2	193.2	0.1
103283	K1	34.1	0.5
103283	M4	27.6	0.02
103283	O1	32.2	0.44
103283	M6	181.4	0.01
103283	S4	125	0.01
103283	NU2	195.9	0.02
103283	S6	32.2	0.01
103283	MU2	184	0.02
103283	2N2	173.4	0.01
103283	OO1	35.8	0.02
103283	M1	33.1	0.03
103283	J1	35	0.04
103283	SSA	28.7	0.12
103283	SA	145.1	0.25
103283	RHO1	31.2	0.02
103283	Q1	31.2	0.09
103283	T2	239.9	0.01
103283	2Q1	30.3	0.01
103283	P1	34	0.16
103283	L2	232	0.02
103283	K2	243.2	0.06
103284	M2	233.8	0.63
103284	S2	256.9	0.22
103284	N2	214.9	0.12
103284	K1	42.6	0.59
103284	M4	76.4	0.01
103284	O1	36.7	0.47
103284	S4	212.7	0.01
103284	NU2	217.7	0.02
103284	MU2	210.4	0.02
103284	2N2	197.3	0.02
103284	OO1	50.9	0.02
103284	M1	40.3	0.03
103284	J1	47.3	0.04
103284	SSA	47.4	0.12
103284	SA	134	0.38
103284	RHO1	33.8	0.02
103284	Q1	33.3	0.09
103284	T2	256.5	0.01
103284	2Q1	29.8	0.01
103284	P1	42.1	0.19
103284	L2	250.8	0.02
103284	K2	258.9	0.06
103285	M2	220.5	0.64
103285	S2	249.4	0.25
103285	N2	205.5	0.12
103285	K1	33.8	0.57
103285	M4	1.2	0.02
103285	O1	31.8	0.46
103285	M6	225.7	0.01
103285	S4	147.3	0.01
103285	NU2	207.8	0.02
103285	S6	63.5	0.01
103285	MU2	191.9	0.01
103285	2N2	189.7	0.02
103285	OO1	35.6	0.02
103285	M1	32.7	0.03
103285	J1	34.6	0.04
103285	SSA	47.4	0.12
103285	SA	134	0.38
103285	RHO1	31.1	0.02
103285	Q1	30.9	0.09
103285	T2	248.3	0.01
103285	2Q1	30.2	0.01
103285	P1	33.7	0.19
103285	L2	236.3	0.02
103285	K2	251.7	0.07
103286	M2	266.2	0.55
103286	S2	281.2	0.16
103286	N2	267.8	0.09
103286	K1	61.7	0.55
103286	M4	78.8	0.06
103286	O1	47.3	0.43
103286	M6	231.3	0.01
103286	S4	223.2	0.01
103286	NU2	267.6	0.02
103286	S6	70.2	0.01
103286	MU2	248.6	0.01
103286	2N2	268.8	0.01
103286	OO1	75.8	0.02
103286	M1	54.5	0.03
103286	J1	68.7	0.03
103286	SSA	45.5	0.16
103286	SA	145.5	0.36
103286	MSF	32.6	0.06
103286	RHO1	41.1	0.02
103286	Q1	40.2	0.09
103286	T2	279.7	0.01
103286	2Q1	33	0.01
103286	P1	60.5	0.18
103286	L2	264.3	0.02
103286	K2	282.7	0.05
103287	M2	118.3	0.55
103287	S2	128.3	0.21
103287	N2	107.3	0.07
103287	K1	341.4	0.46
103287	M4	136.9	0.02
103287	O1	340.7	0.42
103287	MK3	53	0.02
103287	S4	283.1	0.01
103287	MN4	128.5	0.01
103287	NU2	139.6	0.02
103287	MU2	313.8	0.01
103287	2N2	163.8	0.02
103287	OO1	340.1	0.01
103287	LDA2	110.8	0.01
103287	S1	34.9	0.1
103287	M1	10	0.03
103287	J1	357.5	0.02
103287	SSA	45.5	0.16
103287	SA	145.5	0.36
103287	MSF	32.6	0.06
103287	RHO1	330.1	0.02
103287	Q1	330.5	0.09
103287	T2	88.6	0.04
103287	R2	240.9	0.06
103287	P1	335.3	0.11
103287	2SM2	42.1	0.01
103287	L2	125	0.03
103287	2MK3	52.1	0.02
103287	K2	135.2	0.07
103287	MS4	126.5	0.01
103288	M2	242.8	0.4
103288	S2	274.6	0.15
103288	N2	247.3	0.08
103288	K1	42.8	0.49
103288	M4	63.3	0.02
103288	O1	36.9	0.44
103288	S4	203.7	0.01
103288	NU2	247.1	0.02
103288	MU2	210.9	0.01
103288	2N2	250.3	0.01
103288	OO1	48.9	0.02
103288	M1	40	0.03
103288	J1	45.9	0.04
103288	RHO1	34.5	0.02
103288	Q1	34	0.09
103288	T2	273.5	0.01
103288	2Q1	30.5	0.01
103288	P1	42.4	0.16
103288	L2	233.9	0.01
103288	K2	277.1	0.04
103289	M2	232.7	0.31
103289	S2	251.4	0.09
103289	N2	201	0.05
103289	K1	37.3	0.45
103289	M4	77.8	0.02
103289	O1	31.4	0.42
103289	S4	151.2	0.01
103289	NU2	202	0.01
103289	MU2	214.4	0.01
103289	OO1	44	0.02
103289	M1	34.6	0.03
103289	J1	40.7	0.03
103289	SSA	28.7	0.12
103289	SA	145.1	0.25
103289	RHO1	28.9	0.02
103289	Q1	28.4	0.08
103289	T2	250.7	0.01
103289	2Q1	25.5	0.01
103289	P1	36.9	0.15
103289	L2	265.1	0.01
103289	K2	252.8	0.02
103290	M2	256.9	0.41
103290	S2	285	0.13
103290	N2	245.1	0.07
103290	K1	52.8	0.44
103290	M4	75	0.02
103290	O1	45.7	0.4
103290	MK3	254.9	0.03
103290	S4	190.8	0.01
103290	MN4	43.9	0.01
103290	NU2	262	0.02
103290	MU2	58.3	0.02
103290	2N2	258.6	0.01
103290	OO1	101.9	0.02
103290	LDA2	293.6	0.01
103290	S1	85.5	0.03
103290	M1	125.4	0.01
103290	J1	81.1	0.02
103290	SSA	45.5	0.16
103290	SA	145.5	0.36
103290	MSF	32.6	0.06
103290	RHO1	16.8	0.02
103290	Q1	30.7	0.09
103290	T2	305.1	0.01
103290	R2	246.7	0.01
103290	2Q1	344.7	0.01
103290	P1	55.6	0.13
103290	2SM2	148.5	0.01
103290	M3	322.3	0.01
103290	L2	263.1	0.02
103290	2MK3	249.2	0.02
103290	K2	258	0.05
103290	MS4	94.6	0.01
103291	M2	273.7	0.42
103291	S2	298.9	0.14
103291	N2	270.6	0.07
103291	K1	59.5	0.49
103291	M4	120.7	0.02
103291	O1	51.7	0.42
103291	S4	207.3	0.01
103291	NU2	271.7	0.01
103291	MU2	248.4	0.01
103291	2N2	262.5	0.01
103291	OO1	66.4	0.02
103291	M1	55.3	0.03
103291	J1	62.3	0.03
103291	SSA	28.7	0.12
103291	SA	145.1	0.25
103291	RHO1	48.9	0.02
103291	Q1	48.1	0.08
103291	T2	297.7	0.01
103291	2Q1	44	0.01
103291	P1	59	0.16
103291	L2	283.5	0.01
103291	K2	300.7	0.04
103292	M2	273	0.28
103292	S2	290.8	0.08
103292	N2	272.8	0.05
103292	K1	65.5	0.37
103292	M4	112.6	0.01
103292	O1	55.8	0.33
103292	MK3	290.1	0.03
103292	MN4	75.5	0.01
103292	NU2	276.6	0.01
103292	MU2	61.2	0.02
103292	2N2	342.9	0.01
103292	OO1	82	0.02
103292	LDA2	308.9	0.02
103292	S1	46.6	0.02
103292	M1	143.5	0.02
103292	J1	79.3	0.02
103292	SSA	28.7	0.12
103292	SA	145.1	0.25
103292	RHO1	21.1	0.01
103292	Q1	53.5	0.08
103292	T2	24	0.01
103292	R2	359.2	0.01
103292	2Q1	5	0.01
103292	P1	80.4	0.12
103292	2SM2	151.8	0.01
103292	M3	346.5	0.01
103292	L2	285	0.02
103292	2MK3	271.2	0.02
103292	K2	267.4	0.05
103292	MS4	135.7	0.01
103293	M2	259.3	0.39
103293	S2	280.1	0.1
103293	N2	263.7	0.07
103293	K1	45.8	0.46
103293	M4	80.1	0.01
103293	O1	39	0.39
103293	NU2	262.9	0.01
103293	MU2	234	0.01
103293	2N2	268.8	0.01
103293	OO1	52.6	0.02
103293	M1	42.5	0.03
103293	J1	49.1	0.03
103293	SSA	45.5	0.16
103293	SA	145.5	0.36
103293	MSF	32.6	0.06
103293	RHO1	36	0.02
103293	Q1	35.6	0.08
103293	T2	278.8	0.01
103293	2Q1	32.2	0.01
103293	P1	45.3	0.15
103293	L2	255.1	0.01
103293	K2	281.2	0.03
103294	M2	313.2	0.23
103294	S2	340.3	0.07
103294	N2	301.8	0.04
103294	K1	85.9	0.37
103294	M4	177.4	0.02
103294	O1	76.2	0.32
103294	NU2	305.1	0.01
103294	MU2	287.7	0.01
103294	2N2	289.6	0.01
103294	OO1	95.5	0.01
103294	M1	81	0.02
103294	J1	90.4	0.03
103294	SSA	28.7	0.12
103294	SA	145.1	0.25
103294	RHO1	72.2	0.01
103294	Q1	71.5	0.06
103294	2Q1	67	0.01
103294	P1	85.2	0.12
103294	L2	325.3	0.01
103294	K2	342.5	0.02
103295	M2	303.2	0.31
103295	S2	341.7	0.1
103295	N2	286.7	0.06
103295	K1	63.1	0.44
103295	M4	236.9	0.01
103295	O1	56.9	0.43
103295	M6	349.2	0.01
103295	S4	48.4	0.01
103295	NU2	288.5	0.01
103295	S6	345.7	0.01
103295	MU2	264.9	0.01
103295	2N2	273.9	0.01
103295	OO1	70.3	0.02
103295	M1	60.3	0.03
103295	J1	67	0.03
103295	SSA	28.7	0.12
103295	SA	145.1	0.25
103295	RHO1	54	0.02
103295	Q1	53.5	0.08
103295	T2	341.2	0.01
103295	2Q1	50.2	0.01
103295	P1	62.6	0.15
103295	L2	320.2	0.01
103295	K2	344.9	0.03
103296	M2	354	0.11
103296	S2	9.4	0.04
103296	N2	291.9	0.02
103296	K1	94.1	0.24
103296	O1	87.2	0.23
103296	OO1	99.7	0.01
103296	M1	90.3	0.02
103296	J1	97.1	0.02
103296	SSA	45.5	0.16
103296	SA	145.5	0.36
103296	MSF	32.6	0.06
103296	RHO1	85	0.01
103296	Q1	84	0.04
103296	2Q1	82.1	0.01
103296	P1	93.6	0.08
103296	K2	11.1	0.01
103297	M2	274.3	0.22
103297	S2	286.7	0.08
103297	N2	272.9	0.03
103297	K1	35.7	0.46
103297	M4	232.6	0.01
103297	O1	27.5	0.36
103297	M6	26.6	0.01
103297	NU2	273.7	0.01
103297	MU2	262.1	0.01
103297	OO1	44	0.02
103297	M1	31.7	0.03
103297	J1	39.8	0.03
103297	SSA	45.5	0.16
103297	SA	145.5	0.36
103297	MSF	32.6	0.06
103297	RHO1	24	0.01
103297	Q1	23.5	0.07
103297	2Q1	19.4	0.01
103297	P1	35.1	0.15
103297	L2	275.4	0.01
103297	K2	287.7	0.02
103298	M2	21.6	0.04
103298	S2	59.6	0.02
103298	K1	58.3	0.31
103298	M4	346.7	0.03
103298	O1	48.6	0.29
103298	MK3	51.1	0.01
103298	S4	116.6	0.01
103298	MN4	307.4	0.01
103298	MU2	135.8	0.01
103298	2N2	124.4	0.01
103298	OO1	43.6	0.02
103298	S1	118.2	0.01
103298	M1	36.3	0.01
103298	J1	95.3	0.01
103298	SSA	28.7	0.12
103298	SA	145.1	0.25
103298	RHO1	36.3	0.01
103298	Q1	40.4	0.06
103298	R2	71.4	0.01
103298	2Q1	324.6	0.01
103298	P1	58.5	0.1
103298	L2	14.5	0.01
103298	2MK3	41.9	0.01
103298	MS4	3.8	0.01
103299	M2	98.5	0.08
103299	S2	101.3	0.04
103299	N2	97.6	0.01
103299	K1	34.5	0.37
103299	M4	354.5	0.07
103299	O1	23.7	0.34
103299	M6	277.1	0.01
103299	S4	189.8	0.01
103299	OO1	45.1	0.01
103299	M1	29.2	0.02
103299	J1	39.8	0.03
103299	SSA	68.9	0.16
103299	SA	160.7	0.33
103299	MSF	25.9	0.03
103299	RHO1	19	0.01
103299	Q1	18.3	0.07
103299	2Q1	12.7	0.01
103299	P1	33.7	0.12
103299	K2	101.9	0.01
103300	M2	128.9	0.13
103300	S2	132.7	0.06
103300	N2	142.9	0.03
103300	K1	33.5	0.49
103300	M4	30.5	0.08
103300	O1	23.2	0.46
103300	M6	316.4	0.03
103300	S4	158.1	0.03
103300	MN4	348.6	0.04
103300	NU2	138.6	0.01
103300	S6	284	0.01
103300	MU2	115.3	0.01
103300	2N2	117.1	0.01
103300	OO1	56.1	0.03
103300	S1	143.5	0.03
103300	M1	50.5	0.03
103300	J1	22.7	0.04
103300	SSA	39.8	0.15
103300	SA	152	0.37
103300	RHO1	2.4	0.02
103300	Q1	13.1	0.09
103300	T2	139.2	0.01
103300	2Q1	18.3	0.01
103300	P1	33.1	0.15
103300	K2	110.9	0.02
103300	MS4	48.4	0.05
103301	M2	130.7	0.12
103301	S2	125.9	0.06
103301	N2	140.7	0.03
103301	K1	33.7	0.48
103301	M4	33.8	0.1
103301	O1	21.9	0.46
103301	M6	317.5	0.05
103301	S4	155.3	0.02
103301	NU2	141.5	0.01
103301	S6	340.2	0.02
103301	OO1	45.5	0.02
103301	M1	27.9	0.03
103301	J1	39.5	0.04
103301	RHO1	16.9	0.02
103301	Q1	16.1	0.09
103301	2Q1	10.2	0.01
103301	P1	32.9	0.16
103301	K2	125.5	0.02
103302	M2	167.6	0.11
103302	S2	195.1	0.04
103302	N2	232.7	0.01
103302	K1	60.6	0.51
103302	M4	121.3	0.02
103302	O1	41.1	0.46
103302	M6	12.4	0.02
103302	S4	247.5	0.01
103302	OO1	80.1	0.02
103302	M1	50.9	0.03
103302	J1	70.3	0.04
103302	SSA	45.3	0.15
103302	SA	149.3	0.37
103302	RHO1	32.7	0.02
103302	Q1	31.4	0.09
103302	2Q1	21.8	0.01
103302	P1	59.2	0.17
103302	K2	197.4	0.01
103303	M2	96.4	0.11
103303	S2	98.4	0.06
103303	N2	102.2	0.03
103303	K1	17.6	0.46
103303	M4	324.1	0.07
103303	O1	6.6	0.45
103303	M6	209.3	0.02
103303	S4	105.5	0.01
103303	S6	225.3	0.01
103303	OO1	28.6	0.02
103303	M1	12.1	0.03
103303	J1	23	0.04
103303	SSA	39.8	0.15
103303	SA	152	0.37
103303	RHO1	1.9	0.02
103303	Q1	1.2	0.09
103303	2Q1	355.8	0.01
103303	P1	16.8	0.15
103303	K2	98.4	0.01
103304	M2	101.9	0.12
103304	S2	91.4	0.06
103304	N2	112.4	0.02
103304	K1	18.7	0.51
103304	M4	330.4	0.11
103304	O1	8.1	0.47
103304	M6	189.9	0.02
103304	S4	34.3	0.02
103304	S6	349.9	0.01
103304	OO1	29.3	0.02
103304	M1	13.4	0.03
103304	J1	24	0.04
103304	SSA	45.5	0.16
103304	SA	145.5	0.36
103304	MSF	32.6	0.06
103304	RHO1	3.6	0.02
103304	Q1	2.9	0.09
103304	2Q1	357.5	0.01
103304	P1	17.9	0.17
103304	K2	90.7	0.02
103305	M2	154.6	0.13
103305	S2	158.5	0.06
103305	N2	182.5	0.02
103305	K1	46.4	0.53
103305	M4	91.5	0.01
103305	O1	32.7	0.49
103305	NU2	180.3	0.01
103305	OO1	60.4	0.02
103305	M1	39.7	0.03
103305	J1	53.2	0.04
103305	SSA	45.3	0.15
103305	SA	149.3	0.37
103305	RHO1	26.7	0.02
103305	Q1	25.8	0.1
103305	2Q1	18.9	0.01
103305	P1	45.4	0.18
103305	K2	157.9	0.02
103306	M2	148.4	0.12
103306	S2	158.5	0.06
103306	N2	182.6	0.02
103306	K1	44.6	0.55
103306	M4	69.3	0.02
103306	O1	31	0.48
103306	OO1	58.6	0.02
103306	M1	37.9	0.03
103306	J1	51.6	0.04
103306	SSA	45.3	0.15
103306	SA	149.3	0.37
103306	RHO1	25.3	0.02
103306	Q1	24.2	0.09
103306	2Q1	17.4	0.01
103306	P1	43.6	0.18
103306	K2	159.6	0.02
103307	M2	136.1	0.1
103307	S2	149.6	0.04
103307	N2	156.3	0.02
103307	K1	34.8	0.47
103307	M4	346	0.01
103307	O1	25.6	0.45
103307	M6	95.3	0.01
103307	MK3	84.7	0.01
103307	OO1	22.6	0.02
103307	S1	164.7	0.02
103307	M1	67.6	0.02
103307	J1	51.4	0.03
103307	SSA	45.3	0.15
103307	SA	149.3	0.37
103307	RHO1	15.8	0.02
103307	Q1	12	0.1
103307	2Q1	346.3	0.01
103307	P1	37.8	0.15
103307	L2	116.5	0.01
103307	2MK3	69	0.01
103307	K2	118.6	0.03
103308	M2	143.8	0.09
103308	S2	139.9	0.03
103308	N2	166.3	0.01
103308	K1	39.9	0.44
103308	M4	342.4	0.01
103308	O1	27.7	0.44
103308	OO1	52.2	0.02
103308	M1	33.9	0.03
103308	J1	46.1	0.03
103308	SSA	45.3	0.15
103308	SA	149.3	0.37
103308	RHO1	22.4	0.02
103308	Q1	21.6	0.09
103308	2Q1	14.9	0.01
103308	P1	39	0.15
103308	K2	139.6	0.01
103309	M2	142.6	0.1
103309	S2	151.9	0.04
103309	N2	158.3	0.02
103309	K1	38.9	0.5
103309	M4	21.6	0.01
103309	O1	29.3	0.45
103309	MK3	138.6	0.01
103309	MN4	332.9	0.01
103309	MU2	221.3	0.01
103309	2N2	248.8	0.01
103309	OO1	21	0.03
103309	S1	251.8	0.02
103309	M1	81.2	0.03
103309	J1	42	0.02
103309	SSA	45.3	0.15
103309	SA	149.3	0.37
103309	RHO1	33.7	0.03
103309	Q1	12.1	0.1
103309	2Q1	58.4	0.02
103309	P1	49.3	0.13
103309	L2	154.4	0.01
103309	2MK3	104.5	0.01
103309	K2	122.8	0.03
103310	M2	159.7	0.12
103310	S2	167.5	0.04
103310	N2	190.9	0.02
103310	K1	46.3	0.48
103310	M4	96	0.02
103310	O1	34.5	0.44
103310	M6	273	0.01
103310	OO1	58.1	0.02
103310	M1	40.5	0.03
103310	J1	52.2	0.04
103310	SSA	45.3	0.15
103310	SA	149.3	0.37
103310	RHO1	29.5	0.02
103310	Q1	28.6	0.09
103310	2Q1	22.7	0.01
103310	P1	45.4	0.16
103310	K2	168.4	0.01
103311	M2	91	0.11
103311	S2	92.9	0.05
103311	N2	104.5	0.02
103311	K1	17.1	0.47
103311	M4	314.1	0.03
103311	O1	9	0.46
103311	M6	71.7	0.01
103311	S4	84.8	0.01
103311	MN4	281.4	0.02
103311	MU2	84.1	0.01
103311	OO1	37.2	0.02
103311	S1	102.1	0.03
103311	M1	39.3	0.01
103311	J1	22.1	0.03
103311	SSA	68.9	0.16
103311	SA	160.7	0.33
103311	MSF	25.9	0.03
103311	RHO1	351.8	0.02
103311	Q1	354.4	0.1
103311	2Q1	334.9	0.01
103311	P1	16.8	0.15
103311	K2	77.9	0.02
103311	MS4	327.1	0.02
103312	M2	150	0.02
103312	S2	150.6	0.01
103312	K1	108.5	0.17
103312	O1	92	0.16
103312	OO1	125	0.01
103312	M1	100.2	0.01
103312	J1	116.7	0.01
103312	SSA	68.9	0.16
103312	SA	160.7	0.33
103312	MSF	25.9	0.03
103312	RHO1	85	0.01
103312	Q1	83.8	0.03
103312	P1	107.2	0.06
103313	M2	158.3	0.02
103313	S2	102.2	0.01
103313	K1	107.8	0.15
103313	O1	93.6	0.16
103313	OO1	121.9	0.01
103313	M1	100.7	0.01
103313	J1	114.8	0.01
103313	SSA	43.2	0.16
103313	SA	148.3	0.29
103313	RHO1	87.6	0.01
103313	Q1	86.6	0.03
103313	P1	106.7	0.05
103314	M2	159	0.01
103314	S2	142.8	0.01
103314	K1	107.4	0.16
103314	O1	96.2	0.15
103314	OO1	118.6	0.01
103314	M1	101.8	0.01
103314	J1	113	0.01
103314	SSA	43.2	0.16
103314	SA	148.3	0.29
103314	RHO1	91.4	0.01
103314	Q1	90.6	0.03
103314	P1	106.5	0.05
103315	M2	170.1	0.02
103315	S2	157	0.01
103315	K1	106.1	0.15
103315	O1	95.9	0.15
103315	OO1	105.4	0.02
103315	S1	126	0.01
103315	M1	118.2	0.01
103315	SSA	43.2	0.16
103315	SA	148.3	0.29
103315	Q1	91.4	0.03
103315	2Q1	15.8	0.01
103315	P1	112.5	0.04
103316	M2	91.4	0.11
103316	S2	97.2	0.07
103316	N2	93.3	0.02
103316	K1	18.7	0.48
103316	M4	316.1	0.03
103316	O1	11.1	0.46
103316	M6	123.9	0.01
103316	S4	108.8	0.01
103316	S6	357.3	0.01
103316	OO1	26.4	0.02
103316	M1	14.9	0.03
103316	J1	22.5	0.04
103316	SSA	43.2	0.16
103316	SA	148.3	0.29
103316	RHO1	7.7	0.02
103316	Q1	7.2	0.09
103316	2Q1	3.4	0.01
103316	P1	18.1	0.16
103316	K2	97.9	0.02
103317	M2	174.5	0.04
103317	S2	321.2	0.01
103317	K1	84.3	0.25
103317	O1	74.4	0.26
103317	OO1	93.5	0.01
103317	M1	79.3	0.02
103317	J1	88.8	0.02
103317	SSA	43.2	0.16
103317	SA	148.3	0.29
103317	RHO1	70.5	0.01
103317	Q1	69.6	0.05
103317	2Q1	65	0.01
103317	P1	83.5	0.08
103318	M2	90.3	0.1
103318	S2	97.3	0.05
103318	N2	105.6	0.02
103318	K1	19.1	0.47
103318	M4	318.1	0.03
103318	O1	10.7	0.45
103318	MN4	282.2	0.01
103318	OO1	27.5	0.02
103318	S1	92.3	0.01
103318	M1	14.9	0.03
103318	J1	23.5	0.03
103318	MM	321.5	0.06
103318	SSA	70.1	0.16
103318	SA	160.1	0.31
103318	MSF	218	0.05
103318	MF	13.7	0.04
103318	RHO1	7.1	0.02
103318	Q1	357.8	0.1
103318	2Q1	2.3	0.01
103318	P1	20	0.15
103318	K2	97.2	0.01
103318	MS4	329	0.01
103319	M2	179.5	0.11
103319	S2	214.2	0.03
103319	N2	211.3	0.02
103319	K1	54.3	0.5
103319	M4	94.1	0.01
103319	O1	43.9	0.48
103319	MK3	194.5	0.02
103319	MN4	76.8	0.01
103319	NU2	163.8	0.01
103319	2N2	186.3	0.03
103319	OO1	50.6	0.04
103319	LDA2	156	0.01
103319	S1	156.2	0.04
103319	M1	59.6	0.03
103319	J1	56.4	0.02
103319	SSA	43.2	0.16
103319	SA	148.3	0.29
103319	RHO1	4.7	0.02
103319	Q1	32.9	0.1
103319	R2	222.7	0.02
103319	2Q1	2.9	0.04
103319	P1	57	0.14
103319	M3	81.8	0.01
103319	L2	194.1	0.01
103319	2MK3	215.2	0.01
103319	K2	206.7	0.05
103319	MS4	101.7	0.01
103320	M2	177.5	0.07
103320	S2	178.9	0.03
103320	N2	199.7	0.01
103320	K1	63.4	0.47
103320	M4	77	0.01
103320	O1	53.6	0.44
103320	MK3	227.3	0.02
103320	MN4	60.4	0.01
103320	NU2	160.2	0.01
103320	MU2	286.8	0.01
103320	2N2	325.7	0.02
103320	OO1	41	0.04
103320	S1	238	0.02
103320	M1	142.7	0.03
103320	J1	71.3	0.01
103320	SSA	43.2	0.16
103320	SA	148.3	0.29
103320	RHO1	47.1	0.03
103320	Q1	35.1	0.08
103320	T2	159.1	0.01
103320	R2	184.4	0.02
103320	2Q1	121.6	0.02
103320	P1	71.3	0.13
103320	M3	60.3	0.01
103320	L2	232.6	0.01
103320	2MK3	202.3	0.02
103320	K2	175	0.04
103320	MS4	96.4	0.01
103321	M2	187.9	0.07
103321	S2	208.8	0.03
103321	N2	173	0.01
103321	K1	68.1	0.47
103321	M4	50.7	0.01
103321	O1	54.3	0.41
103321	OO1	81.3	0.02
103321	M1	61.2	0.03
103321	J1	74.8	0.03
103321	SSA	43.2	0.16
103321	SA	148.3	0.29
103321	RHO1	48.5	0.02
103321	Q1	47.5	0.08
103321	2Q1	40.9	0.01
103321	P1	67	0.15
103321	K2	211.2	0.01
103322	M2	218.2	0.11
103322	S2	249.3	0.08
103322	N2	224.6	0.04
103322	K1	84.8	0.39
103322	M4	203	0.02
103322	O1	63.4	0.42
103322	M6	103.6	0.01
103322	NU2	224	0.01
103322	2N2	230.2	0.01
103322	OO1	105.2	0.02
103322	M1	74	0.03
103322	J1	95.1	0.03
103322	SSA	43.2	0.16
103322	SA	148.3	0.29
103322	RHO1	54	0.02
103322	Q1	53	0.08
103322	T2	248.1	0.01
103322	2Q1	42	0.01
103322	P1	83.2	0.13
103322	K2	251.8	0.02
103323	M2	188	0.12
103323	S2	226.1	0.06
103323	N2	221.9	0.01
103323	K1	61.2	0.53
103323	M4	127.9	0.02
103323	O1	48.3	0.5
103323	MK3	228.3	0.02
103323	S4	329.6	0.01
103323	MN4	98.2	0.02
103323	NU2	192.6	0.01
103323	2N2	179	0.03
103323	OO1	52.5	0.04
103323	LDA2	116.1	0.01
103323	S1	163.8	0.05
103323	M1	72.5	0.03
103323	J1	62.5	0.02
103323	SSA	43.2	0.16
103323	SA	148.3	0.29
103323	RHO1	7.2	0.02
103323	Q1	34.4	0.1
103323	T2	178	0.01
103323	R2	259	0.01
103323	2Q1	18.5	0.02
103323	P1	67	0.16
103323	2SM2	316.4	0.01
103323	L2	164.6	0.01
103323	2MK3	227.3	0.02
103323	K2	202.3	0.05
103323	MS4	143.5	0.01
103324	M2	196.2	0.13
103324	S2	234.9	0.07
103324	N2	228.8	0.02
103324	K1	64.8	0.54
103324	M4	146.4	0.03
103324	O1	51.6	0.5
103324	M6	90.4	0.01
103324	MK3	231	0.02
103324	S4	347.3	0.01
103324	MN4	115.8	0.02
103324	NU2	211.5	0.01
103324	2N2	184.8	0.03
103324	OO1	53.2	0.04
103324	LDA2	128	0.01
103324	S1	167.9	0.05
103324	M1	77.9	0.03
103324	J1	67.2	0.03
103324	SSA	43.2	0.16
103324	SA	148.3	0.29
103324	RHO1	21.9	0.02
103324	Q1	36.9	0.1
103324	T2	173.7	0.01
103324	R2	262.5	0.01
103324	2Q1	27.3	0.02
103324	P1	71	0.16
103324	M3	130.6	0.01
103324	L2	160.3	0.01
103324	2MK3	228.8	0.02
103324	K2	207.4	0.05
103324	MS4	162.9	0.02
103325	M2	193.7	0.08
103325	S2	281.8	0.02
103325	N2	223	0.01
103325	K1	65.4	0.42
103325	M4	78.4	0.01
103325	O1	55.6	0.46
103325	OO1	75.3	0.02
103325	M1	60.5	0.03
103325	J1	70.3	0.04
103325	SSA	43.2	0.16
103325	SA	148.3	0.29
103325	RHO1	51.4	0.02
103325	Q1	50.7	0.09
103325	2Q1	45.8	0.01
103325	P1	64.7	0.14
103326	M2	186.2	0.05
103326	S2	113	0.03
103326	N2	196.5	0.01
103326	K1	64.8	0.39
103326	M4	353.2	0.01
103326	O1	53.7	0.39
103326	OO1	75.9	0.02
103326	M1	59.3	0.03
103326	J1	70.3	0.03
103326	SSA	43.2	0.16
103326	SA	148.3	0.29
103326	RHO1	48.7	0.01
103326	Q1	48.2	0.08
103326	2Q1	42.7	0.01
103326	P1	64	0.13
103326	K2	107.4	0.01
103327	M2	92	0.1
103327	S2	100	0.06
103327	N2	105.9	0.02
103327	K1	18.2	0.48
103327	M4	319.1	0.03
103327	O1	11	0.45
103327	M6	94	0.01
103327	S4	91.1	0.01
103327	OO1	25.4	0.02
103327	M1	14.7	0.03
103327	J1	21.8	0.04
103327	SSA	43.2	0.16
103327	SA	148.3	0.29
103327	RHO1	7.9	0.02
103327	Q1	7.4	0.09
103327	2Q1	3.9	0.01
103327	P1	17.6	0.16
103327	K2	100.7	0.02
103328	M2	178.6	0.1
103328	S2	203.5	0.04
103328	N2	200.9	0.01
103328	K1	56.7	0.49
103328	M4	52.4	0.01
103328	O1	45.4	0.46
103328	MK3	206.7	0.01
103328	MN4	13.4	0.01
103328	NU2	190.8	0.01
103328	2N2	175.4	0.02
103328	OO1	48.9	0.04
103328	S1	161.6	0.03
103328	M1	70.9	0.03
103328	J1	63.4	0.02
103328	SSA	43.2	0.16
103328	SA	148.3	0.29
103328	RHO1	21.7	0.02
103328	Q1	31.5	0.1
103328	2Q1	18.5	0.02
103328	P1	60.5	0.14
103328	L2	152.3	0.01
103328	2MK3	199	0.01
103328	K2	191.5	0.03
103329	M2	185.4	0.1
103329	S2	203.5	0.05
103329	N2	201.7	0.02
103329	K1	65.4	0.52
103329	M4	31.6	0.01
103329	O1	51.1	0.48
103329	M6	243.1	0.01
103329	OO1	79.6	0.02
103329	M1	58.3	0.03
103329	J1	72.3	0.04
103329	SSA	43.2	0.16
103329	SA	148.3	0.29
103329	RHO1	45.2	0.02
103329	Q1	44	0.09
103329	2Q1	36.9	0.01
103329	P1	64.3	0.17
103329	K2	203.9	0.01
103330	M2	172.1	0.06
103330	S2	175.9	0.02
103330	N2	195.9	0.01
103330	K1	58.2	0.41
103330	M4	320.1	0.01
103330	O1	47.9	0.4
103330	MK3	186.2	0.01
103330	OO1	34.8	0.04
103330	M1	96.4	0.02
103330	J1	89.8	0.02
103330	SSA	49.1	0.18
103330	SA	150.4	0.37
103330	RHO1	33.3	0.02
103330	Q1	37.9	0.09
103330	2Q1	33.1	0.01
103330	P1	63.8	0.12
103330	2MK3	171.7	0.01
103330	K2	186.2	0.02
103331	M2	151.8	0.04
103331	N2	60.4	0.01
103331	K1	98.5	0.24
103331	M4	117.5	0.01
103331	O1	96.8	0.25
103331	M6	276.5	0.01
103331	S4	98	0.01
103331	OO1	100.3	0.01
103331	M1	97.7	0.02
103331	J1	99.4	0.02
103331	RHO1	96.1	0.01
103331	Q1	95.9	0.05
103331	2Q1	95.1	0.01
103331	P1	98.4	0.08
103332	M2	135.7	0.04
103332	S2	136.3	0.02
103332	N2	120.2	0.01
103332	K1	49.2	0.36
103332	M4	321.9	0.02
103332	O1	43.2	0.35
103332	S4	146.1	0.01
103332	OO1	55.3	0.02
103332	M1	46.2	0.03
103332	J1	52.2	0.03
103332	SSA	43.2	0.16
103332	SA	148.3	0.29
103332	RHO1	40.6	0.01
103332	Q1	40.3	0.07
103332	2Q1	37.2	0.01
103332	P1	48.7	0.12
103332	K2	133.8	0.01
103333	M2	175.4	0.02
103333	S2	210.8	0.02
103333	K1	95.7	0.22
103333	O1	94.2	0.23
103333	OO1	97.3	0.01
103333	M1	95	0.02
103333	J1	96.5	0.02
103333	RHO1	93.5	0.01
103333	Q1	93.4	0.04
103333	2Q1	92.6	0.01
103333	P1	95.6	0.07
103333	K2	213.6	0.01
103334	M2	157.9	0.02
103334	S2	92.4	0.02
103334	N2	122.9	0.01
103334	K1	90.3	0.23
103334	O1	82.4	0.24
103334	OO1	98.1	0.01
103334	M1	86.4	0.02
103334	J1	94.1	0.02
103334	RHO1	79	0.01
103334	Q1	78.5	0.05
103334	2Q1	74.6	0.01
103334	P1	89.7	0.08
103335	M2	102.1	0.06
103335	S2	128.5	0.05
103335	N2	130.9	0.03
103335	K1	31.5	0.31
103335	M4	307.4	0.03
103335	O1	26.7	0.3
103335	M6	80.5	0.01
103335	S4	149.9	0.01
103335	NU2	127	0.01
103335	OO1	36.3	0.01
103335	M1	29.1	0.02
103335	J1	33.9	0.02
103335	RHO1	24.7	0.01
103335	Q1	24.3	0.06
103335	2Q1	22	0.01
103335	P1	31.1	0.1
103335	K2	130.7	0.01
103335	M8	210.5	0.01
103336	M2	161.2	0.02
103336	S2	132.4	0.02
103336	N2	143	0.01
103336	K1	92.7	0.26
103336	O1	85.5	0.25
103336	OO1	100	0.01
103336	M1	89.1	0.02
103336	J1	96.4	0.02
103336	SSA	43.2	0.16
103336	SA	148.3	0.29
103336	RHO1	82.4	0.01
103336	Q1	81.9	0.05
103336	2Q1	78.2	0.01
103336	P1	92.1	0.09
103337	M2	95.9	0.1
103337	S2	100.5	0.06
103337	N2	120	0.02
103337	K1	17.6	0.47
103337	M4	324.5	0.03
103337	O1	11.1	0.45
103337	S4	58.3	0.01
103337	OO1	24.1	0.02
103337	M1	14.4	0.03
103337	J1	20.9	0.04
103337	SSA	51.3	0.16
103337	SA	156.3	0.26
103337	RHO1	8.4	0.02
103337	Q1	7.9	0.09
103337	2Q1	4.7	0.01
103337	P1	17.1	0.16
103337	K2	100.6	0.02
103338	M2	170.6	0.05
103338	S2	222	0.02
103338	N2	207.1	0.01
103338	K1	64.7	0.36
103338	M4	84.4	0.01
103338	O1	55.9	0.38
103338	M6	263.1	0.01
103338	MK3	198.2	0.01
103338	NU2	223.8	0.01
103338	2N2	54.5	0.01
103338	OO1	58.6	0.04
103338	LDA2	143.3	0.01
103338	S1	216.5	0.01
103338	J1	102.8	0.02
103338	SSA	51.3	0.16
103338	SA	156.3	0.26
103338	RHO1	25	0.02
103338	Q1	42.1	0.08
103338	T2	159.9	0.01
103338	P1	57.7	0.1
103338	2MK3	171.3	0.01
103338	K2	201	0.02
103338	MS4	112	0.01
103339	M2	183.6	0.09
103339	S2	203.2	0.04
103339	N2	215.8	0.01
103339	K1	55.1	0.51
103339	M4	113.3	0.01
103339	O1	45.1	0.49
103339	MK3	174.5	0.02
103339	MN4	65.6	0.01
103339	OO1	34.9	0.04
103339	S1	176.4	0.04
103339	M1	71.1	0.02
103339	J1	83	0.03
103339	SSA	53.1	0.17
103339	SA	143.1	0.3
103339	MSF	14.2	0.05
103339	RHO1	45	0.03
103339	Q1	32.2	0.11
103339	T2	178.8	0.01
103339	P1	56	0.16
103339	2MK3	158.8	0.01
103339	K2	204.5	0.05
103339	MS4	122.6	0.01
103340	M2	183.2	0.09
103340	S2	193	0.08
103340	N2	221.3	0.02
103340	K1	62.4	0.58
103340	M4	266	0.01
103340	O1	44.3	0.48
103340	S6	169.2	0.01
103340	OO1	80.5	0.02
103340	M1	53.4	0.03
103340	J1	71.4	0.04
103340	SSA	31.7	0.16
103340	SA	128.3	0.35
103340	RHO1	36.6	0.02
103340	Q1	35.4	0.09
103340	2Q1	26.4	0.01
103340	P1	61	0.19
103340	K2	193.8	0.02
103340	M8	32.9	0.01
103341	M2	159.4	0.06
103341	S2	235.7	0.04
103341	N2	220.1	0.02
103341	K1	60.4	0.52
103341	M4	149.1	0.01
103341	O1	58.3	0.49
103341	M6	303.2	0.01
103341	S4	262.5	0.01
103341	OO1	62.5	0.02
103341	M1	59.4	0.04
103341	J1	61.5	0.04
103341	SSA	54	0.19
103341	SA	150.6	0.24
103341	RHO1	57.4	0.02
103341	Q1	57.3	0.1
103341	2Q1	56.3	0.01
103341	P1	60.3	0.17
103341	K2	241.9	0.01
103342	M2	141.9	0.03
103342	S2	148.8	0.03
103342	N2	273.8	0.02
103342	K1	70.2	0.52
103342	M4	214.6	0.01
103342	O1	67.4	0.5
103342	S4	332	0.01
103342	OO1	73	0.02
103342	M1	68.8	0.04
103342	J1	71.6	0.04
103342	SSA	54	0.19
103342	SA	150.6	0.24
103342	RHO1	66.2	0.02
103342	Q1	66	0.1
103342	2Q1	64.6	0.01
103342	P1	70	0.17
103342	K2	149.3	0.01
103343	M2	129.4	0.05
103343	S2	128	0.02
103343	N2	149.8	0.01
103343	K1	48.6	0.43
103343	M4	347.1	0.01
103343	O1	39.5	0.42
103343	MK3	130.4	0.01
103343	MN4	309.8	0.01
103343	OO1	32	0.02
103343	S1	291.9	0.01
103343	M1	82.1	0.02
103343	J1	70	0.02
103343	SSA	51.4	0.19
103343	SA	149.5	0.32
103343	RHO1	29.8	0.02
103343	Q1	27.9	0.09
103343	2Q1	352.1	0.01
103343	P1	49.8	0.13
103343	2MK3	135	0.01
103343	K2	208.3	0.02
103344	M2	132.5	0.05
103344	S2	117.3	0.02
103344	K1	50.6	0.46
103344	O1	41.9	0.45
103344	OO1	56.4	0.04
103344	S1	290	0.01
103344	M1	99.5	0.03
103344	J1	65.9	0.02
103344	SSA	51.3	0.16
103344	SA	156.3	0.26
103344	RHO1	15.7	0.02
103344	Q1	26.6	0.1
103344	2Q1	46.2	0.01
103344	P1	49.9	0.14
103344	K2	222.8	0.02
103345	M2	201.8	0.1
103345	S2	227.7	0.04
103345	N2	244	0.02
103345	K1	61.5	0.53
103345	M4	186	0.01
103345	O1	50.9	0.5
103345	MK3	212.3	0.02
103345	S4	355	0.01
103345	MN4	135.2	0.01
103345	2N2	231.8	0.01
103345	OO1	40.1	0.04
103345	S1	218.1	0.04
103345	M1	70.2	0.02
103345	J1	94.8	0.03
103345	MM	343.4	0.05
103345	SSA	40.7	0.2
103345	SA	140.4	0.29
103345	RHO1	50.3	0.03
103345	Q1	43.2	0.1
103345	T2	154.5	0.01
103345	2Q1	37.7	0.01
103345	P1	64	0.16
103345	2MK3	197.1	0.02
103345	K2	222.1	0.05
103346	M2	197	0.08
103346	S2	211.8	0.03
103346	N2	237.6	0.01
103346	K1	60	0.5
103346	M4	151.8	0.01
103346	O1	50.1	0.48
103346	MK3	195.8	0.01
103346	2N2	215	0.01
103346	OO1	38.6	0.04
103346	S1	239.7	0.03
103346	M1	73	0.02
103346	J1	95.2	0.03
103346	MM	344.3	0.06
103346	SSA	41.3	0.21
103346	SA	146.4	0.3
103346	RHO1	51.3	0.03
103346	Q1	41.3	0.1
103346	2Q1	29.1	0.01
103346	P1	62.3	0.15
103346	2MK3	184.1	0.01
103346	K2	218.6	0.04
103347	M2	206.3	0.1
103347	S2	234.4	0.05
103347	N2	253.3	0.02
103347	K1	63.3	0.54
103347	M4	189.2	0.01
103347	O1	52.3	0.5
103347	MK3	222.8	0.02
103347	MN4	143.9	0.01
103347	2N2	226.4	0.01
103347	OO1	42.7	0.05
103347	S1	176.4	0.05
103347	M1	74.9	0.02
103347	J1	99.9	0.02
103347	MM	342.7	0.06
103347	SSA	37.5	0.21
103347	SA	135	0.31
103347	RHO1	52.7	0.03
103347	Q1	43.3	0.1
103347	T2	154.4	0.01
103347	2Q1	38.5	0.01
103347	P1	68	0.17
103347	2MK3	202.3	0.02
103347	K2	222.5	0.06
103347	MS4	206.6	0.01
103348	M2	214.6	0.08
103348	S2	264.5	0.05
103348	N2	255.8	0.02
103348	K1	70	0.52
103348	M4	202.8	0.01
103348	O1	59.8	0.49
103348	MK3	251.7	0.02
103348	S4	338.7	0.01
103348	MN4	155.4	0.01
103348	2N2	334.6	0.01
103348	OO1	57.2	0.04
103348	S1	211.3	0.07
103348	M1	124.2	0.02
103348	J1	100.8	0.02
103348	SSA	31.7	0.16
103348	SA	128.3	0.35
103348	RHO1	45.9	0.02
103348	Q1	50	0.1
103348	T2	120.6	0.01
103348	R2	262.2	0.01
103348	2Q1	54.7	0.01
103348	P1	73.4	0.14
103348	2MK3	236.1	0.02
103348	K2	230.4	0.04
103349	M2	228.1	0.12
103349	S2	262.2	0.06
103349	N2	264.3	0.03
103349	K1	70.4	0.55
103349	M4	225.6	0.02
103349	O1	59.5	0.51
103349	MK3	256.7	0.02
103349	S4	358.9	0.01
103349	MN4	180.5	0.01
103349	OO1	37.1	0.05
103349	S1	183.5	0.06
103349	M1	98.5	0.02
103349	J1	101.2	0.02
103349	SSA	52.7	0.17
103349	SA	137	0.18
103349	RHO1	49.3	0.03
103349	Q1	48	0.11
103349	T2	167.5	0.01
103349	R2	330.5	0.01
103349	2Q1	56.8	0.01
103349	P1	75.1	0.16
103349	L2	209.8	0.01
103349	2MK3	237.7	0.02
103349	K2	234	0.06
103349	MS4	244.8	0.01
103350	M2	260.1	0.08
103350	S2	330.2	0.11
103350	N2	336.4	0.06
103350	K1	102.8	0.55
103350	M4	348.6	0.03
103350	O1	86.8	0.57
103350	NU2	326.2	0.01
103350	2N2	52.7	0.01
103350	OO1	118.8	0.02
103350	M1	94.8	0.04
103350	J1	110.7	0.05
103350	RHO1	79.9	0.02
103350	Q1	78.8	0.11
103350	T2	327.4	0.01
103350	2Q1	70.9	0.02
103350	P1	101.6	0.18
103350	K2	335.9	0.03
103351	M2	161.6	0.11
103351	S2	190.8	0.05
103351	N2	191.1	0.02
103351	K1	44.4	0.52
103351	M4	106.3	0.04
103351	O1	34.9	0.49
103351	M6	253.1	0.01
103351	MK3	53.5	0.01
103351	S4	234	0.01
103351	MN4	66.4	0.02
103351	2N2	201.2	0.01
103351	OO1	17.6	0.03
103351	S1	188	0.04
103351	M1	56.5	0.03
103351	J1	78	0.03
103351	MM	358.9	0.07
103351	SSA	57.8	0.22
103351	SA	152.2	0.34
103351	RHO1	30	0.03
103351	Q1	28.4	0.11
103351	2Q1	19.4	0.01
103351	P1	44.3	0.16
103351	2MK3	34.3	0.01
103351	K2	148.7	0.03
103351	MS4	130.5	0.01
103352	M2	144.6	0.11
103352	S2	168.7	0.06
103352	N2	168.2	0.02
103352	K1	35.9	0.52
103352	M4	80.7	0.04
103352	O1	26.8	0.49
103352	MK3	41.2	0.01
103352	S4	206.7	0.01
103352	MN4	34.2	0.02
103352	MU2	139.1	0.01
103352	2N2	179.1	0.01
103352	OO1	27	0.02
103352	S1	167.8	0.04
103352	M1	37.1	0.02
103352	J1	55.7	0.03
103352	MM	346.8	0.05
103352	SSA	45.8	0.22
103352	SA	146.5	0.33
103352	RHO1	24.2	0.03
103352	Q1	16.9	0.11
103352	T2	135.8	0.01
103352	R2	8.4	0.01
103352	2Q1	15	0.01
103352	P1	36	0.16
103352	2MK3	23.6	0.01
103352	K2	133.3	0.03
103352	MS4	99.9	0.02
103353	M2	146	0.11
103353	S2	164.8	0.07
103353	N2	177.5	0.03
103353	K1	37.6	0.51
103353	M4	90.5	0.04
103353	O1	31.2	0.48
103353	M6	241.3	0.01
103353	MK3	92.7	0.01
103353	S4	192.7	0.01
103353	MN4	53	0.02
103353	2N2	179.7	0.01
103353	OO1	48	0.02
103353	S1	130.7	0.05
103353	M1	71.9	0.02
103353	J1	48.2	0.03
103353	RHO1	348.6	0.02
103353	Q1	18.9	0.11
103353	T2	128.4	0.01
103353	R2	12.6	0.01
103353	2Q1	353	0.02
103353	P1	35.8	0.15
103353	K2	125.1	0.03
103353	MS4	97.2	0.01
103354	M2	134.4	0.1
103354	S2	143.4	0.05
103354	N2	157.5	0.02
103354	K1	32	0.49
103354	M4	63.7	0.02
103354	O1	23.4	0.48
103354	NU2	155.4	0.01
103354	OO1	40.9	0.02
103354	M1	27.9	0.03
103354	J1	36.4	0.04
103354	RHO1	19.6	0.02
103354	Q1	19.1	0.1
103354	2Q1	14.7	0.01
103354	P1	31.4	0.16
103354	K2	145	0.01
103355	M2	137.4	0.08
103355	S2	246.8	0.05
103355	N2	130.5	0.02
103355	K1	31.3	0.57
103355	M4	43.8	0.02
103355	O1	25.4	0.52
103355	MK3	163.9	0.01
103355	MN4	6.9	0.02
103355	NU2	229.4	0.01
103355	MU2	161.1	0.02
103355	2N2	293.2	0.02
103355	OO1	4.2	0.02
103355	LDA2	180	0.01
103355	S1	219	0.08
103355	M1	64.5	0.05
103355	J1	42.8	0.04
103355	SSA	40	0.19
103355	SA	141.3	0.38
103355	RHO1	5.2	0.03
103355	Q1	3.3	0.08
103355	T2	7.2	0.05
103355	R2	42.5	0.09
103355	2Q1	353.7	0.01
103355	P1	39.8	0.15
103355	2SM2	3.3	0.02
103355	M3	233	0.01
103355	L2	206.9	0.01
103355	2MK3	63.2	0.01
103355	K2	17.9	0.03
103355	MS4	62.3	0.01
103356	M2	134.9	0.09
103356	S2	155.3	0.06
103356	N2	171.6	0.02
103356	K1	32.4	0.5
103356	M4	72.3	0.03
103356	O1	24.8	0.48
103356	MK3	81.5	0.01
103356	S4	191.6	0.01
103356	MN4	26	0.01
103356	MU2	137.2	0.01
103356	2N2	180.5	0.01
103356	OO1	38.1	0.02
103356	S1	146.6	0.03
103356	M1	53.1	0.02
103356	J1	52.5	0.03
103356	SSA	47.6	0.21
103356	SA	143.6	0.43
103356	RHO1	8.7	0.02
103356	Q1	14.9	0.1
103356	T2	125	0.01
103356	2Q1	358.5	0.02
103356	P1	26.9	0.14
103356	2MK3	63.6	0.01
103356	K2	130.1	0.02
103356	MS4	94.6	0.01
103357	M2	142	0.1
103357	S2	163.5	0.05
103357	N2	202.8	0.03
103357	K1	33.8	0.47
103357	M4	92.5	0.02
103357	O1	28.3	0.51
103357	S4	129.1	0.01
103357	NU2	194.6	0.01
103357	OO1	39.3	0.02
103357	M1	31.1	0.04
103357	J1	36.6	0.04
103357	RHO1	25.9	0.02
103357	Q1	25.6	0.1
103357	2Q1	22.8	0.01
103357	P1	33.4	0.16
103357	K2	165.3	0.01
103357	M8	6.3	0.01
103358	M2	145.6	0.09
103358	S2	167.2	0.06
103358	N2	183.6	0.02
103358	K1	37.1	0.5
103358	M4	92	0.02
103358	O1	29.5	0.47
103358	MK3	108	0.01
103358	S4	211.7	0.01
103358	MN4	42.1	0.01
103358	2N2	191.3	0.01
103358	OO1	41.4	0.02
103358	S1	150.4	0.03
103358	M1	64.3	0.02
103358	J1	50.7	0.03
103358	SSA	40	0.19
103358	SA	141.3	0.38
103358	RHO1	12.6	0.02
103358	Q1	17.4	0.1
103358	T2	112	0.01
103358	2Q1	6.2	0.02
103358	P1	32.8	0.14
103358	2MK3	92.1	0.01
103358	K2	144.7	0.03
103358	MS4	114.4	0.01
103359	M2	170.2	0.07
103359	S2	191.6	0.05
103359	N2	207	0.01
103359	K1	47.8	0.46
103359	M4	121.1	0.02
103359	O1	39.5	0.43
103359	MK3	136.7	0.01
103359	S4	243.7	0.01
103359	MN4	72.2	0.01
103359	2N2	3.8	0.01
103359	OO1	28.2	0.02
103359	S1	217.5	0.02
103359	M1	59.6	0.02
103359	J1	81	0.03
103359	SSA	40	0.19
103359	SA	141.3	0.51
103359	RHO1	35	0.03
103359	Q1	35.9	0.1
103359	2Q1	318.7	0.01
103359	P1	51.5	0.14
103359	2SM2	2.3	0.01
103359	2MK3	89.4	0.01
103359	K2	176.9	0.03
103359	MS4	114.6	0.01
103360	M2	153.1	0.11
103360	S2	179.6	0.07
103360	N2	167.5	0.02
103360	K1	37.6	0.52
103360	M4	104.6	0.03
103360	O1	29.7	0.49
103360	MK3	106.8	0.01
103360	S4	220.5	0.01
103360	MN4	59.9	0.01
103360	NU2	194.2	0.01
103360	MU2	144.9	0.01
103360	2N2	210.1	0.02
103360	OO1	38.5	0.02
103360	LDA2	111.3	0.01
103360	S1	149.7	0.06
103360	M1	87.8	0.01
103360	J1	68.6	0.03
103360	SSA	57.9	0.16
103360	SA	121.9	0.32
103360	RHO1	10.6	0.02
103360	Q1	21.5	0.1
103360	2Q1	0.2	0.03
103360	P1	34.4	0.14
103360	2SM2	231.9	0.01
103360	M3	231	0.01
103360	L2	111.3	0.01
103360	2MK3	84.4	0.01
103360	K2	156.4	0.04
103360	MS4	111.6	0.01
103361	M2	135.5	0.11
103361	S2	185.5	0.07
103361	K1	38.3	0.52
103361	M4	115.9	0.03
103361	O1	26.8	0.53
103361	S4	250.4	0.02
103361	OO1	49.8	0.02
103361	M1	32.6	0.04
103361	J1	44	0.04
103361	RHO1	21.8	0.02
103361	Q1	21.1	0.1
103361	2Q1	15.4	0.01
103361	P1	37.4	0.17
103361	K2	189.6	0.02
103362	M2	181.6	0.14
103362	S2	204.4	0.05
103362	N2	204.9	0.04
103362	K1	56.7	0.54
103362	M4	170.4	0.03
103362	O1	41.9	0.46
103362	M6	284.3	0.01
103362	NU2	200.9	0.01
103362	2N2	230.1	0.01
103362	OO1	71.1	0.02
103362	M1	49.2	0.03
103362	J1	63.7	0.04
103362	SSA	40	0.19
103362	SA	141.3	0.38
103362	RHO1	35.2	0.02
103362	Q1	34.8	0.09
103362	2Q1	28	0.01
103362	P1	55.6	0.18
103362	K2	204.8	0.01
103363	M2	180.3	0.1
103363	S2	210	0.08
103363	N2	219.3	0.03
103363	K1	47.4	0.55
103363	M4	160.5	0.03
103363	O1	39.3	0.55
103363	MK3	158.2	0.02
103363	S4	310	0.01
103363	MN4	134.9	0.01
103363	NU2	268.7	0.01
103363	MU2	143.2	0.01
103363	2N2	144.3	0.02
103363	OO1	53.3	0.06
103363	LDA2	317.7	0.01
103363	S1	182	0.06
103363	M1	98	0.02
103363	J1	38.6	0.03
103363	SSA	40	0.19
103363	SA	141.3	0.38
103363	RHO1	1.1	0.05
103363	Q1	17.7	0.12
103363	T2	159.8	0.01
103363	R2	219.1	0.01
103363	P1	50.3	0.16
103363	2SM2	245.5	0.01
103363	M3	232	0.01
103363	2MK3	134.3	0.01
103363	K2	182.8	0.05
103363	MS4	194.5	0.01
103364	M2	194.4	0.12
103364	S2	208.2	0.11
103364	N2	242.4	0.03
103364	K1	47.7	0.66
103364	M4	166.6	0.03
103364	O1	38.8	0.54
103364	M6	347.8	0.01
103364	S4	343.3	0.01
103364	NU2	235.3	0.01
103364	OO1	57	0.02
103364	M1	43.5	0.04
103364	J1	52.5	0.04
103364	SSA	57.9	0.16
103364	SA	121.9	0.32
103364	RHO1	34.8	0.02
103364	Q1	34.3	0.1
103364	T2	207.5	0.01
103364	2Q1	30.4	0.01
103364	P1	47	0.22
103364	K2	209.3	0.03
103365	M2	181.9	0.1
103365	S2	185.2	0.05
103365	N2	160.4	0.03
103365	K1	49.1	0.49
103365	M4	157.4	0.03
103365	O1	38	0.55
103365	S4	173.4	0.01
103365	NU2	163.3	0.01
103365	OO1	60.3	0.02
103365	M1	43.6	0.04
103365	J1	54.6	0.04
103365	RHO1	33.2	0.02
103365	Q1	32.4	0.1
103365	2Q1	26.9	0.01
103365	P1	48.3	0.16
103365	K2	185.5	0.01
103366	M2	197.9	0.1
103366	S2	221	0.1
103366	N2	256.8	0.03
103366	K1	53	0.63
103366	M4	174.5	0.02
103366	O1	43.7	0.51
103366	M6	344.6	0.01
103366	S4	25.7	0.01
103366	NU2	249	0.01
103366	OO1	62.5	0.02
103366	M1	48.5	0.04
103366	J1	57.9	0.04
103366	RHO1	39.6	0.02
103366	Q1	39.2	0.1
103366	T2	219	0.01
103366	2Q1	34.9	0.01
103366	P1	52.3	0.21
103366	K2	222.9	0.03
103367	M2	182.1	0.12
103367	S2	206.7	0.1
103367	N2	216.9	0.03
103367	K1	45.8	0.56
103367	M4	162.8	0.02
103367	O1	37.7	0.56
103367	MK3	147	0.01
103367	S4	305.5	0.01
103367	MN4	133.9	0.01
103367	NU2	292.6	0.01
103367	MU2	156.4	0.01
103367	2N2	140	0.01
103367	OO1	49.9	0.07
103367	S1	172.4	0.07
103367	M1	94.5	0.02
103367	J1	34.8	0.03
103367	SSA	40.1	0.17
103367	SA	131	0.22
103367	RHO1	0.6	0.05
103367	Q1	16.2	0.12
103367	T2	159.1	0.01
103367	R2	277.4	0.01
103367	P1	46.8	0.16
103367	2SM2	233.1	0.01
103367	M3	217.5	0.01
103367	L2	170.9	0.01
103367	2MK3	129	0.01
103367	K2	178.1	0.04
103367	MS4	202	0.01
103368	M2	189.1	0.11
103368	S2	201.7	0.1
103368	N2	234.7	0.03
103368	K1	45.5	0.66
103368	M4	141.8	0.02
103368	O1	37.3	0.52
103368	M6	265.7	0.01
103368	S4	293.3	0.01
103368	NU2	231.3	0.01
103368	OO1	54.1	0.02
103368	M1	41.5	0.04
103368	J1	49.8	0.04
103368	RHO1	34	0.02
103368	Q1	33.2	0.1
103368	T2	200.3	0.01
103368	2Q1	29.5	0.01
103368	P1	44.9	0.22
103368	K2	202.9	0.03
103369	M2	170.2	0.11
103369	S2	194.5	0.08
103369	N2	195.5	0.02
103369	K1	42.9	0.56
103369	M4	135	0.02
103369	O1	33.2	0.52
103369	MK3	122.5	0.01
103369	S4	255.8	0.01
103369	MN4	93.6	0.01
103369	2N2	217.4	0.01
103369	OO1	28.5	0.02
103369	LDA2	154	0.01
103369	S1	148.1	0.05
103369	M1	62.6	0.02
103369	J1	56.7	0.03
103369	SSA	65.7	0.24
103369	SA	154.2	0.3
103369	RHO1	21.2	0.02
103369	Q1	23.5	0.11
103369	T2	137.7	0.01
103369	2Q1	353.6	0.02
103369	P1	42.2	0.15
103369	2MK3	92	0.01
103369	K2	166.2	0.04
103369	MS4	149.9	0.01
103370	M2	160.3	0.16
103370	S2	185.9	0.09
103370	N2	145.8	0.03
103370	K1	50.1	0.47
103370	M4	132.9	0.03
103370	O1	33.2	0.49
103370	S4	184.9	0.01
103370	NU2	141.7	0.01
103370	OO1	65.7	0.02
103370	M1	40.8	0.03
103370	J1	56.1	0.03
103370	RHO1	26.3	0.02
103370	Q1	25.4	0.09
103370	2Q1	17.8	0.01
103370	P1	48.9	0.16
103370	K2	188.2	0.02
103371	M2	189	0.1
103371	S2	198	0.1
103371	N2	231.4	0.03
103371	K1	44.4	0.65
103371	M4	138.6	0.02
103371	O1	37.1	0.53
103371	S4	305.1	0.01
103371	NU2	223.8	0.01
103371	OO1	52	0.02
103371	M1	40.9	0.04
103371	J1	48.2	0.04
103371	RHO1	34.2	0.02
103371	Q1	33.5	0.1
103371	T2	196.5	0.01
103371	2Q1	30.3	0.01
103371	P1	43.8	0.22
103371	K2	198.8	0.03
103372	M2	175.7	0.13
103372	S2	216	0.11
103372	N2	237.1	0.04
103372	K1	51.5	0.53
103372	M4	185.3	0.02
103372	O1	39.8	0.55
103372	NU2	228.9	0.01
103372	OO1	63.3	0.02
103372	M1	45.7	0.04
103372	J1	57.4	0.04
103372	RHO1	34.7	0.02
103372	Q1	33.9	0.11
103372	T2	214.4	0.01
103372	2Q1	28.1	0.01
103372	P1	50.6	0.18
103372	K2	219.3	0.03
103373	M2	185.5	0.19
103373	S2	202.7	0.09
103373	N2	166	0.05
103373	K1	63.7	0.48
103373	M4	194.4	0.02
103373	O1	41.5	0.48
103373	S4	249.6	0.01
103373	NU2	164.4	0.01
103373	OO1	71.6	0.02
103373	M1	49.5	0.03
103373	J1	65.4	0.03
103373	RHO1	34.5	0.02
103373	Q1	33.2	0.09
103373	2Q1	25.4	0.01
103373	P1	62.2	0.16
103373	K2	204.1	0.02
103374	M2	200.9	0.22
103374	S2	223.4	0.11
103374	N2	178.2	0.06
103374	K1	72.2	0.5
103374	M4	257.9	0.04
103374	O1	47.5	0.48
103374	S4	287.4	0.01
103374	NU2	182.3	0.01
103374	OO1	82.1	0.01
103374	M1	56.9	0.03
103374	J1	75.1	0.03
103374	RHO1	39.6	0.02
103374	Q1	38.3	0.09
103374	T2	220.9	0.01
103374	2Q1	29.2	0.01
103374	P1	70.6	0.16
103374	K2	225.9	0.03
103375	M2	200.6	0.15
103375	S2	226.7	0.1
103375	N2	228.2	0.04
103375	K1	53.9	0.59
103375	M4	236.9	0.02
103375	O1	43.3	0.56
103375	MK3	179.3	0.02
103375	S4	6.3	0.01
103375	MN4	191	0.01
103375	MU2	204.7	0.01
103375	2N2	255.3	0.02
103375	OO1	36.5	0.03
103375	LDA2	194.7	0.01
103375	S1	168.5	0.06
103375	M1	100	0.02
103375	J1	75.8	0.03
103375	SSA	62.1	0.16
103375	SA	132.7	0.23
103375	RHO1	32.5	0.02
103375	Q1	33.7	0.12
103375	T2	162.6	0.01
103375	R2	233.6	0.01
103375	2Q1	24.2	0.02
103375	P1	54.5	0.17
103375	2SM2	293.1	0.01
103375	M3	281.6	0.01
103375	L2	185.2	0.01
103375	2MK3	157.5	0.02
103375	K2	187.4	0.06
103375	MS4	271.7	0.01
103376	M2	159.9	0.11
103376	S2	178.7	0.07
103376	N2	174.1	0.03
103376	K1	37	0.5
103376	M4	111.4	0.02
103376	O1	31.2	0.51
103376	S4	214.2	0.01
103376	NU2	174.3	0.01
103376	OO1	42.6	0.02
103376	M1	34	0.04
103376	J1	39.6	0.04
103376	SSA	57	0.19
103376	SA	139.3	0.26
103376	RHO1	29	0.02
103376	Q1	28.4	0.1
103376	2Q1	25.8	0.01
103376	P1	36.5	0.16
103376	K2	180.7	0.02
103377	M2	199.2	0.21
103377	S2	219.2	0.12
103377	N2	193.3	0.05
103377	K1	68.7	0.51
103377	M4	248	0.03
103377	O1	48.4	0.5
103377	S4	322.1	0.01
103377	NU2	196	0.01
103377	OO1	76.8	0.02
103377	M1	56.4	0.04
103377	J1	72.4	0.03
103377	RHO1	41.4	0.02
103377	Q1	40.3	0.1
103377	T2	219.2	0.01
103377	2Q1	33.1	0.01
103377	P1	67.2	0.17
103377	K2	220.8	0.03
103378	M2	200	0.2
103378	S2	222.7	0.11
103378	N2	188.5	0.05
103378	K1	65.6	0.52
103378	M4	248	0.04
103378	O1	44.1	0.51
103378	S4	320.5	0.01
103378	NU2	190.4	0.01
103378	OO1	78.5	0.02
103378	M1	52.9	0.04
103378	J1	70.4	0.04
103378	SSA	57	0.19
103378	SA	139.3	0.26
103378	RHO1	36.1	0.02
103378	Q1	34.9	0.1
103378	T2	220.7	0.01
103378	2Q1	26.5	0.01
103378	P1	64.1	0.17
103378	L2	205.3	0.01
103378	K2	224.6	0.03
103379	M2	206.9	0.16
103379	S2	228.4	0.12
103379	N2	226.5	0.04
103379	K1	57.6	0.59
103379	M4	246.6	0.03
103379	O1	47.1	0.57
103379	M6	26.4	0.01
103379	MK3	184	0.02
103379	S4	33.4	0.01
103379	MN4	205.1	0.01
103379	NU2	141.7	0.01
103379	MU2	27.4	0.01
103379	2N2	134.4	0.02
103379	OO1	54.1	0.05
103379	S1	167.6	0.09
103379	M1	96	0.04
103379	J1	51.9	0.04
103379	SSA	40.7	0.26
103379	SA	138.5	0.44
103379	RHO1	15.5	0.05
103379	Q1	29.7	0.12
103379	T2	214.7	0.01
103379	R2	238.4	0.01
103379	2Q1	8.7	0.01
103379	P1	49.9	0.19
103379	2SM2	260.1	0.01
103379	M3	286.1	0.01
103379	L2	142.7	0.01
103379	2MK3	169.5	0.02
103379	K2	205.5	0.04
103379	MS4	286.7	0.02
103380	M2	168.8	0.12
103380	S2	187.6	0.09
103380	N2	199.3	0.03
103380	K1	39.9	0.56
103380	M4	139.5	0.03
103380	O1	30.7	0.52
103380	MK3	138.6	0.01
103380	S4	262	0.01
103380	MN4	93.1	0.01
103380	MU2	161.4	0.01
103380	2N2	185.9	0.01
103380	OO1	37.9	0.03
103380	S1	133.2	0.05
103380	M1	55.7	0.02
103380	J1	54.3	0.03
103380	SSA	57	0.19
103380	SA	139.3	0.26
103380	RHO1	9.7	0.02
103380	Q1	17	0.12
103380	T2	73.1	0.01
103380	2Q1	352	0.02
103380	P1	40.5	0.14
103380	L2	185.8	0.01
103380	2MK3	108.6	0.01
103380	K2	163.8	0.03
103380	MS4	167.4	0.01
103381	M2	194.7	0.11
103381	S2	206.6	0.08
103381	N2	221.1	0.03
103381	K1	52.4	0.55
103381	M4	180.1	0.02
103381	O1	42	0.55
103381	MK3	187.8	0.01
103381	S4	341	0.01
103381	MN4	146.7	0.01
103381	NU2	315.6	0.01
103381	MU2	161.7	0.01
103381	2N2	204.6	0.01
103381	OO1	43.3	0.07
103381	S1	136.9	0.06
103381	M1	93.5	0.02
103381	J1	35	0.02
103381	SSA	40.7	0.26
103381	SA	138.5	0.44
103381	RHO1	19.6	0.02
103381	Q1	30.7	0.11
103381	T2	136.2	0.01
103381	2Q1	34.2	0.02
103381	P1	52.4	0.15
103381	L2	159.6	0.01
103381	2MK3	164.3	0.01
103381	K2	191.6	0.03
103381	MS4	191.5	0.01
103382	M2	205.7	0.1
103382	S2	216.1	0.09
103382	N2	238.4	0.02
103382	K1	58.5	0.55
103382	M4	223.7	0.02
103382	O1	48.8	0.51
103382	MK3	209.4	0.02
103382	S4	343.6	0.01
103382	MN4	165.9	0.01
103382	2N2	246.2	0.01
103382	OO1	55.6	0.04
103382	S1	137	0.05
103382	M1	105.7	0.02
103382	J1	82.6	0.03
103382	SSA	40.7	0.26
103382	SA	138.5	0.44
103382	RHO1	28.6	0.02
103382	Q1	37.6	0.1
103382	T2	111.2	0.01
103382	R2	241.2	0.01
103382	2Q1	8.9	0.02
103382	P1	60.8	0.14
103382	L2	206.1	0.01
103382	2MK3	193.2	0.02
103382	K2	202.3	0.04
103382	MS4	275.4	0.01
103383	M2	210.7	0.11
103383	S2	222.1	0.09
103383	N2	228	0.03
103383	K1	59.5	0.62
103383	M4	202.5	0.02
103383	O1	48.3	0.58
103383	MK3	209.8	0.02
103383	S4	348.8	0.01
103383	MN4	173	0.01
103383	NU2	225.7	0.01
103383	MU2	195.4	0.01
103383	2N2	230.9	0.01
103383	OO1	50.1	0.05
103383	S1	128.3	0.07
103383	M1	53.9	0.04
103383	J1	65.2	0.05
103383	SSA	57	0.19
103383	SA	139.3	0.26
103383	RHO1	33.9	0.03
103383	Q1	30.4	0.14
103383	T2	221.6	0.01
103383	2Q1	13.1	0.02
103383	P1	63	0.16
103383	L2	193.4	0.01
103383	2MK3	177.8	0.02
103383	K2	196.1	0.05
103384	M2	121.1	0.06
103384	S2	116.4	0.04
103384	N2	141.4	0.02
103384	K1	22	0.43
103384	M4	337.1	0.01
103384	O1	13.6	0.41
103384	MN4	308.7	0.01
103384	2N2	124.1	0.01
103384	OO1	34.6	0.01
103384	S1	347.6	0.02
103384	M1	355.3	0.02
103384	J1	40	0.03
103384	MM	245.8	0.05
103384	SSA	32.4	0.31
103384	SA	163.9	0.39
103384	MSF	340.1	0.08
103384	MF	354.8	0.07
103384	RHO1	351.9	0.02
103384	Q1	9.5	0.09
103384	2Q1	354.3	0.02
103384	P1	16.3	0.13
103384	K2	91.8	0.01
103384	MS4	342.4	0.01
103385	M2	116.3	0.06
103385	S2	108.3	0.04
103385	N2	137.6	0.02
103385	K1	18	0.46
103385	O1	10.9	0.44
103385	OO1	32.9	0.02
103385	S1	24.1	0.02
103385	M1	28.4	0.02
103385	J1	33.8	0.03
103385	SSA	58	0.26
103385	SA	159.3	0.31
103385	RHO1	0	0.02
103385	Q1	358.6	0.1
103385	2Q1	338.4	0.02
103385	P1	18.1	0.13
103385	K2	107.6	0.01
103386	M2	201.4	0.1
103386	S2	210.1	0.05
103386	N2	224.8	0.01
103386	K1	50.2	0.52
103386	M4	196.3	0.01
103386	O1	43.5	0.49
103386	OO1	57	0.02
103386	M1	46.9	0.04
103386	J1	53.6	0.04
103386	SSA	40.7	0.26
103386	SA	138.5	0.44
103386	RHO1	40.6	0.02
103386	Q1	40.1	0.1
103386	2Q1	36.7	0.01
103386	P1	49.7	0.17
103386	K2	210.8	0.01
103387	M2	167.2	0.03
103387	S2	140.9	0.02
103387	N2	190.3	0.01
103387	K1	47	0.31
103387	M4	37	0.01
103387	O1	36.7	0.31
103387	OO1	75.5	0.01
103387	S1	311.5	0.04
103387	M1	48.5	0.01
103387	J1	58.7	0.02
103387	MM	340.4	0.06
103387	SA	47.9	0.41
103387	RHO1	29.1	0.02
103387	Q1	20.3	0.08
103387	2Q1	3.9	0.01
103387	P1	50.5	0.09
103387	K2	153.5	0.01
103388	M2	180.4	0.02
103388	S2	176	0.01
103388	N2	218.2	0.01
103388	K1	61.2	0.25
103388	O1	45.8	0.25
103388	2N2	182.2	0.01
103388	OO1	59.4	0.01
103388	S1	334.9	0.04
103388	M1	109.2	0.01
103388	J1	39.2	0.01
103388	RHO1	30.2	0.02
103388	Q1	34.8	0.06
103388	2Q1	36.5	0.01
103388	P1	51.2	0.06
103388	K2	191	0.01
103389	M2	210.9	0.07
103389	S2	199.8	0.04
103389	N2	240.6	0.02
103389	K1	56	0.45
103389	O1	44.3	0.42
103389	MU2	244.4	0.01
103389	2N2	289.5	0.01
103389	OO1	57.7	0.02
103389	S1	14.3	0.04
103389	M1	24.4	0.02
103389	J1	96.1	0.03
103389	RHO1	1	0.02
103389	Q1	42.6	0.1
103389	T2	85.4	0.01
103389	R2	345.3	0.01
103389	2Q1	66.5	0.03
103389	P1	43.2	0.14
103389	K2	189.5	0.01
103390	M2	125.6	0.05
103390	S2	99.9	0.04
103390	N2	145.2	0.02
103390	K1	19.9	0.43
103390	M4	322.3	0.01
103390	O1	12.7	0.42
103390	OO1	38.4	0.01
103390	S1	335.9	0.03
103390	M1	34.5	0.02
103390	J1	22.6	0.02
103390	SSA	52.2	0.15
103390	SA	145.6	0.27
103390	RHO1	354.9	0.02
103390	Q1	359.5	0.1
103390	2Q1	352.8	0.01
103390	P1	19.1	0.14
103390	K2	94.4	0.01
103391	M2	123	0.06
103391	S2	105.5	0.04
103391	N2	141.8	0.02
103391	K1	20.6	0.44
103391	M4	319.6	0.01
103391	O1	12	0.43
103391	MU2	97	0.01
103391	OO1	35.4	0.02
103391	S1	6	0.04
103391	M1	48.9	0.01
103391	J1	12.9	0.02
103391	SSA	58.3	0.18
103391	SA	155.2	0.26
103391	RHO1	5.2	0.01
103391	Q1	357.6	0.11
103391	2Q1	319.7	0.01
103391	P1	20.7	0.14
103391	K2	90.6	0.01
103392	M2	173	0.04
103392	S2	167.7	0.04
103392	N2	176	0.01
103392	K1	40.4	0.48
103392	M4	9.5	0.01
103392	O1	31.2	0.45
103392	M6	98.7	0.01
103392	OO1	49.4	0.02
103392	M1	35.8	0.03
103392	J1	44.8	0.04
103392	MM	340.4	0.06
103392	SA	47.9	0.41
103392	RHO1	27.4	0.02
103392	Q1	26.7	0.09
103392	2Q1	21.9	0.01
103392	P1	39.7	0.16
103392	K2	167.1	0.01
103393	M2	293.1	0.08
103393	S2	315	0.05
103393	N2	325.7	0.02
103393	K1	96.5	0.46
103393	M4	354.7	0.01
103393	O1	83.3	0.43
103393	MK3	11.5	0.02
103393	MN4	313.7	0.01
103393	OO1	97.4	0.05
103393	LDA2	271.9	0.01
103393	S1	72.4	0.04
103393	M1	147.5	0.02
103393	J1	103.4	0.02
103393	MM	340.9	0.04
103393	SSA	63.4	0.29
103393	SA	167.5	0.32
103393	MSF	32.6	0.03
103393	MF	277.2	0.03
103393	RHO1	66.5	0.02
103393	Q1	67.9	0.09
103393	R2	268.3	0.01
103393	2Q1	34	0.01
103393	P1	96.9	0.13
103393	2SM2	137.5	0.01
103393	L2	305.6	0.01
103393	2MK3	355.7	0.02
103393	K2	298.8	0.05
103394	M2	312.3	0.1
103394	S2	291.6	0.05
103394	N2	323.9	0.02
103394	K1	107	0.35
103394	M4	33	0.01
103394	O1	80	0.33
103394	S4	43.5	0.01
103394	S6	58.6	0.01
103394	OO1	134	0.01
103394	M1	93.6	0.02
103394	J1	120.4	0.03
103394	SSA	60.5	0.19
103394	SA	146.7	0.4
103394	RHO1	68.4	0.01
103394	Q1	66.6	0.07
103394	2Q1	53.2	0.01
103394	P1	105	0.11
103394	K2	290	0.01
103395	M2	314.4	0.06
103395	S2	280.7	0.03
103395	N2	335.3	0.02
103395	K1	108.3	0.21
103395	O1	85.5	0.24
103395	M6	126.4	0.01
103395	S4	22.7	0.01
103395	S6	90.5	0.01
103395	OO1	131.2	0.01
103395	M1	97	0.02
103395	J1	119.7	0.02
103395	SSA	44.9	0.25
103395	SA	147.4	0.33
103395	RHO1	75.6	0.01
103395	Q1	74.1	0.05
103395	2Q1	62.8	0.01
103395	P1	106.6	0.07
103395	K2	278	0.01
103396	M2	276.8	0.01
103396	S2	301.1	0.02
103396	N2	243.1	0.01
103396	K1	101.4	0.18
103396	O1	94.8	0.17
103396	OO1	110.3	0.01
103396	M1	98.6	0.01
103396	J1	105.7	0.01
103396	SSA	49.7	0.2
103396	SA	149.7	0.29
103396	RHO1	91.4	0.01
103396	Q1	91	0.03
103396	P1	100.9	0.06
103397	M2	264.4	0.03
103397	S2	257.4	0.02
103397	N2	271.8	0.01
103397	K1	96.6	0.3
103397	O1	83.4	0.3
103397	OO1	109.4	0.01
103397	M1	90.1	0.02
103397	J1	103.3	0.02
103397	MM	340.4	0.06
103397	SA	47.9	0.41
103397	RHO1	77.5	0.01
103397	Q1	76.7	0.06
103397	2Q1	69.5	0.01
103397	P1	95.7	0.1
103397	K2	255.9	0.01
103398	M2	229	0.04
103398	S2	12	0.07
103398	N2	147.5	0.02
103398	K1	103.9	0.37
103398	M4	8.9	0.02
103398	O1	95	0.41
103398	M6	293.8	0.01
103398	OO1	112.7	0.02
103398	M1	99.5	0.03
103398	J1	108.2	0.03
103398	RHO1	91.3	0.02
103398	Q1	90.7	0.08
103398	2Q1	86.3	0.01
103398	P1	103.2	0.12
103398	K2	23.6	0.02
103399	M2	169.4	0.04
103399	K1	47	0.38
103399	O1	40.3	0.37
103399	OO1	53.7	0.02
103399	M1	43.7	0.03
103399	J1	50.4	0.03
103399	SSA	34.9	0.25
103399	SA	152.4	0.26
103399	RHO1	37.4	0.01
103399	Q1	29.7	0.08
103399	P1	48.8	0.11
103400	M2	163	0.04
103400	S2	154.6	0.02
103400	N2	176.1	0.02
103400	K1	37.4	0.37
103400	O1	30.8	0.37
103400	OO1	33.5	0.02
103400	S1	4.6	0.02
103400	M1	42.1	0.02
103400	J1	41.2	0.02
103400	SSA	49.7	0.2
103400	SA	149.7	0.29
103400	RHO1	17.3	0.02
103400	Q1	19.2	0.08
103400	2Q1	3.6	0.01
103400	P1	37.2	0.12
103400	K2	153.8	0.01
103401	M2	197.9	0.02
103401	S2	172.2	0.02
103401	N2	213.9	0.01
103401	K1	52.9	0.33
103401	M4	52.7	0.01
103401	O1	45.7	0.32
103401	MK3	193.3	0.01
103401	2N2	266	0.01
103401	OO1	62.1	0.02
103401	S1	357.1	0.02
103401	M1	88.5	0.02
103401	J1	39	0.01
103401	SSA	49.7	0.2
103401	SA	149.7	0.29
103401	RHO1	11.5	0.02
103401	Q1	28.3	0.07
103401	2Q1	72.3	0.01
103401	P1	50.6	0.1
103401	2MK3	186.2	0.01
103401	K2	190	0.01
103402	M2	230	0.01
103402	S2	188.1	0.01
103402	N2	262.6	0.01
103402	K1	65.6	0.3
103402	M4	103.1	0.01
103402	O1	56.4	0.29
103402	MK3	243.7	0.01
103402	2N2	43.4	0.01
103402	OO1	54.2	0.02
103402	M1	231.2	0.01
103402	J1	70.5	0.01
103402	SSA	49.7	0.2
103402	SA	149.7	0.29
103402	RHO1	22.9	0.01
103402	Q1	39.6	0.07
103402	2Q1	305.7	0.01
103402	P1	68.9	0.08
103402	2MK3	224.9	0.02
103402	K2	207	0.01
103403	M2	159.6	0.05
103403	S2	148.6	0.03
103403	N2	161.1	0.01
103403	K1	42.1	0.34
103403	M4	338.7	0.01
103403	O1	34.6	0.34
103403	MK3	180.9	0.01
103403	2N2	155.8	0.01
103403	OO1	38.8	0.02
103403	S1	32.5	0.01
103403	M1	61.1	0.01
103403	J1	33.7	0.02
103403	SSA	49.7	0.2
103403	SA	149.7	0.29
103403	RHO1	2.4	0.01
103403	Q1	16.2	0.08
103403	2Q1	301.9	0.01
103403	P1	41.6	0.1
103403	2MK3	187.9	0.01
103404	S2	288.7	0.01
103404	K1	146.9	0.07
103404	O1	135.8	0.07
103404	2N2	87.3	0.01
103404	OO1	138	0.01
103404	S1	229.7	0.01
103404	SSA	49.7	0.2
103404	SA	149.7	0.29
103404	Q1	132.7	0.02
103404	2Q1	217.9	0.01
103404	P1	140.6	0.02
103405	M2	49.6	0.01
103405	S2	327.1	0.01
103405	K1	190.5	0.12
103405	O1	176.4	0.12
103405	OO1	199.7	0.01
103405	S1	147.8	0.02
103405	M1	263.1	0.01
103405	SSA	44.9	0.25
103405	SA	147.4	0.33
103405	RHO1	135.4	0.01
103405	Q1	156.9	0.02
103405	P1	190.6	0.03
103405	K2	72.1	0.01
103406	M2	178	0.06
103406	S2	166.2	0.03
103406	N2	185.6	0.02
103406	K1	30.7	0.44
103406	M4	8.7	0.01
103406	O1	23.1	0.42
103406	OO1	36.2	0.02
103406	S1	351.6	0.02
103406	M1	34.7	0.02
103406	J1	43.4	0.02
103406	SSA	54.2	0.24
103406	SA	165.3	0.31
103406	RHO1	12.6	0.02
103406	Q1	11.5	0.1
103406	2Q1	352	0.01
103406	P1	29.2	0.13
103407	M2	284	0.04
103407	S2	283.8	0.02
103407	N2	303.2	0.01
103407	K1	80.7	0.27
103407	O1	72.3	0.27
103407	MK3	274.1	0.01
103407	2N2	322.3	0.01
103407	OO1	61.1	0.02
103407	S1	320.3	0.01
103407	M1	169.3	0.02
103407	J1	118.4	0.01
103407	SSA	49.7	0.2
103407	SA	149.7	0.29
103407	RHO1	60.3	0.01
103407	Q1	68.6	0.05
103407	2Q1	100.1	0.02
103407	P1	85	0.09
103407	2MK3	263.1	0.01
103407	K2	270.4	0.01
103408	M2	49.7	0.01
103408	S2	357.3	0.01
103408	K1	132.8	0.16
103408	O1	121.1	0.15
103408	MK3	53.9	0.01
103408	2N2	157.5	0.01
103408	OO1	124.8	0.02
103408	S1	276.1	0.04
103408	M1	339	0.01
103408	J1	295.9	0.01
103408	RHO1	114.2	0.01
103408	Q1	105.6	0.03
103408	2Q1	303.2	0.01
103408	P1	140.6	0.03
103408	2MK3	41.6	0.01
103408	K2	338.5	0.01
103409	M2	251.5	0.04
103409	S2	238.2	0.01
103409	N2	252.2	0.02
103409	K1	46.8	0.46
103409	O1	35.6	0.43
103409	MK3	197.7	0.01
103409	NU2	267.5	0.01
103409	MU2	79.2	0.01
103409	2N2	24.5	0.01
103409	OO1	44	0.03
103409	LDA2	195.1	0.01
103409	S1	299.9	0.05
103409	M1	108.8	0.01
103409	J1	50.8	0.01
103409	SSA	49.7	0.2
103409	SA	149.7	0.29
103409	RHO1	23.7	0.02
103409	Q1	23.3	0.1
103409	R2	90.7	0.01
103409	P1	43.8	0.12
103409	M3	34.2	0.01
103409	2MK3	180.5	0.01
103409	K2	196.1	0.02
103410	S2	322.8	0.01
103410	N2	226.3	0.01
103410	K1	151.5	0.2
103410	O1	131.2	0.16
103410	OO1	171.1	0.01
103410	M1	141.1	0.01
103410	J1	161.2	0.01
103410	SSA	49.7	0.2
103410	SA	149.7	0.29
103410	RHO1	123.6	0.01
103410	Q1	121.2	0.03
103410	P1	150.1	0.07
103411	M2	42.2	0.01
103411	S2	45	0.01
103411	K1	195.4	0.11
103411	O1	178.9	0.1
103411	OO1	198.5	0.01
103411	S1	280.7	0.01
103411	SSA	60.5	0.19
103411	SA	146.7	0.4
103411	Q1	157.6	0.02
103411	P1	188	0.03
103411	K2	66.9	0.01
103412	M2	29	0.01
103412	S2	39.1	0.01
103412	K1	187	0.15
103412	O1	172.7	0.14
103412	OO1	192.7	0.02
103412	S1	247.3	0.01
103412	J1	245.5	0.01
103412	MM	349.1	0.08
103412	SSA	45.5	0.34
103412	SA	166.8	0.22
103412	RHO1	184.4	0.01
103412	Q1	151.9	0.03
103412	P1	185.7	0.04
103412	2MK3	184.5	0.01
103412	K2	63	0.01
103413	M2	340	0.02
103413	S2	331.9	0.01
103413	K1	109.8	0.12
103413	O1	102.7	0.12
103413	MK3	356.1	0.01
103413	OO1	109.6	0.01
103413	S1	269.2	0.02
103413	SSA	49.7	0.2
103413	SA	149.7	0.29
103413	RHO1	120.3	0.01
103413	Q1	91.3	0.03
103413	2Q1	343.4	0.02
103413	P1	110.5	0.03
103413	2MK3	343.1	0.01
103413	K2	293.7	0.01
103414	M2	194.7	0.08
103414	S2	159.4	0.03
103414	N2	183.7	0.03
103414	K1	24.2	0.46
103414	M4	35.6	0.01
103414	O1	17.5	0.42
103414	M6	82	0.01
103414	NU2	185.6	0.01
103414	OO1	30.4	0.02
103414	M1	20.8	0.03
103414	J1	27.4	0.03
103414	SSA	45.2	0.17
103414	SA	174.5	0.34
103414	RHO1	14.6	0.02
103414	Q1	14.2	0.08
103414	2Q1	10.9	0.01
103414	P1	23.6	0.15
103414	K2	157.7	0.01
103415	M2	252	0.06
103415	S2	238.5	0.03
103415	N2	241.8	0.02
103415	K1	54.7	0.36
103415	O1	49.3	0.36
103415	OO1	48.8	0.04
103415	S1	298.1	0.01
103415	SSA	49.7	0.2
103415	SA	149.7	0.29
103415	MF	339.3	0.04
103415	Q1	23.6	0.07
103415	P1	52	0.1
103415	K2	229.5	0.02
103416	M2	222.4	0.17
103416	S2	215.8	0.07
103416	N2	214	0.06
103416	K1	26.3	0.5
103416	M4	126.2	0.02
103416	O1	21.7	0.47
103416	M6	256.4	0.01
103416	MK3	310.6	0.01
103416	S4	198.9	0.01
103416	MN4	108.5	0.01
103416	NU2	246.9	0.01
103416	2N2	198.2	0.01
103416	OO1	71.1	0.03
103416	LDA2	327.6	0.01
103416	S1	215.7	0.01
103416	M1	55.7	0.02
103416	J1	30.8	0.03
103416	RHO1	297.6	0.02
103416	Q1	12.4	0.09
103416	R2	30.9	0.01
103416	2Q1	355.4	0.03
103416	P1	23.8	0.16
103416	M3	195	0.01
103416	2MK3	279.9	0.01
103416	K2	244.4	0.01
103416	MS4	158.4	0.01
103417	M2	304.3	0.25
103417	S2	288	0.09
103417	N2	278.5	0.06
103417	K1	56.4	0.39
103417	M4	246.4	0.01
103417	O1	43.7	0.39
103417	NU2	281.3	0.01
103417	S6	258.2	0.01
103417	MU2	320.5	0.01
103417	2N2	246.9	0.01
103417	OO1	67.8	0.02
103417	M1	49.9	0.03
103417	J1	62	0.03
103417	SSA	60.5	0.11
103417	SA	103.4	0.38
103417	RHO1	38.4	0.02
103417	Q1	37.6	0.08
103417	T2	288.5	0.01
103417	2Q1	31.5	0.01
103417	P1	55.4	0.13
103417	L2	325.3	0.01
103417	K2	286.7	0.02
103418	M2	16.3	0.11
103418	S2	15	0.04
103418	N2	353.3	0.03
103418	K1	82.9	0.16
103418	M4	4.6	0.01
103418	O1	74.4	0.16
103418	MK3	35.4	0.02
103418	MN4	333.6	0.01
103418	NU2	308.1	0.01
103418	MU2	232.3	0.01
103418	2N2	277.4	0.02
103418	OO1	88.7	0.01
103418	LDA2	358.6	0.01
103418	S1	36.9	0.07
103418	M1	81.9	0.01
103418	J1	349.6	0.01
103418	RHO1	65.4	0.01
103418	Q1	59.1	0.04
103418	T2	152.7	0.02
103418	R2	39.7	0.02
103418	2Q1	286.5	0.01
103418	P1	76.5	0.04
103418	M3	78.1	0.01
103418	L2	95.6	0.01
103418	2MK3	26.3	0.03
103418	K2	321.8	0.01
103418	MS4	8.5	0.01
103419	M2	356.9	0.09
103419	S2	348.4	0.03
103419	N2	335.7	0.03
103419	K1	75.8	0.14
103419	M4	325	0.01
103419	O1	68.2	0.13
103419	MK3	11.6	0.01
103419	NU2	353	0.01
103419	2N2	334	0.01
103419	S1	296.4	0.03
103419	M1	116.8	0.01
103419	J1	85.8	0.01
103419	SSA	108.8	0.29
103419	SA	36.8	1.02
103419	RHO1	38.9	0.01
103419	Q1	53.7	0.02
103419	T2	82.9	0.01
103419	R2	54.7	0.01
103419	P1	76.7	0.04
103419	2MK3	3.6	0.01
103419	K2	311.8	0.01
103420	M2	285.2	0.29
103420	S2	282.1	0.1
103420	N2	265.4	0.08
103420	K1	39.5	0.43
103420	M4	209.8	0.01
103420	O1	33.7	0.38
103420	MK3	271.4	0.02
103420	S4	15.1	0.01
103420	MN4	160.8	0.01
103420	NU2	270.8	0.02
103420	MU2	175.8	0.01
103420	2N2	268.7	0.01
103420	OO1	73.2	0.02
103420	S1	270.9	0.03
103420	M1	87.8	0.02
103420	J1	42.5	0.02
103420	SSA	60.5	0.11
103420	SA	103.4	0.38
103420	RHO1	359.1	0.01
103420	Q1	19.2	0.07
103420	R2	26.3	0.02
103420	2Q1	15.7	0.02
103420	P1	30.3	0.13
103420	2SM2	76.9	0.01
103420	M3	255.5	0.01
103420	L2	328.9	0.01
103420	2MK3	267.1	0.03
103420	K2	254.1	0.02
103421	M2	256.8	0.33
103421	S2	254.2	0.12
103421	N2	209.2	0.12
103421	K1	28.5	0.52
103421	M4	189.6	0.03
103421	O1	20.3	0.49
103421	M6	312.4	0.01
103421	S4	159.1	0.01
103421	NU2	215.6	0.02
103421	S6	233.6	0.01
103421	MU2	76.5	0.01
103421	2N2	161.7	0.02
103421	OO1	36.8	0.02
103421	M1	24.5	0.04
103421	J1	32.6	0.04
103421	RHO1	16.8	0.02
103421	Q1	16.2	0.1
103421	T2	254.3	0.01
103421	2Q1	12.1	0.01
103421	P1	27.9	0.17
103421	L2	304.3	0.01
103421	K2	254	0.03
103422	M2	255.3	0.34
103422	S2	251	0.12
103422	N2	235.2	0.1
103422	K1	25.8	0.52
103422	M4	194.5	0.03
103422	O1	20.2	0.46
103422	MK3	283.7	0.02
103422	S4	333.4	0.01
103422	MN4	158	0.01
103422	NU2	261.9	0.02
103422	MU2	145.8	0.02
103422	2N2	190.8	0.02
103422	OO1	67.1	0.02
103422	LDA2	347.2	0.01
103422	S1	293.9	0.02
103422	M1	23.4	0.02
103422	J1	61.3	0.03
103422	MM	359.3	0.08
103422	SSA	45.6	0.26
103422	SA	135	0.26
103422	RHO1	19.3	0.02
103422	Q1	6.8	0.1
103422	R2	34	0.01
103422	2Q1	338	0.01
103422	P1	19.8	0.17
103422	M3	230.6	0.02
103422	L2	333.5	0.01
103422	2MK3	243.9	0.02
103422	K2	246	0.02
103422	MS4	223.6	0.01
103423	M2	1.4	0.25
103423	S2	18.4	0.08
103423	N2	6.1	0.08
103423	K1	87.4	0.53
103423	M4	218.4	0.02
103423	O1	84	0.42
103423	NU2	5.5	0.02
103423	S6	205	0.01
103423	2N2	10.8	0.01
103423	OO1	90.7	0.02
103423	M1	85.7	0.03
103423	J1	89	0.03
103423	SSA	298.4	0.1
103423	SA	102.1	0.44
103423	RHO1	82.5	0.02
103423	Q1	82.3	0.08
103423	2Q1	80.6	0.01
103423	P1	87.1	0.18
103423	K2	19.8	0.02
103423	M8	36	0.01
103424	M2	351.7	0.23
103424	S2	358.6	0.1
103424	N2	343.6	0.04
103424	K1	78	0.41
103424	M4	189.2	0.01
103424	O1	69.3	0.42
103424	NU2	344.6	0.01
103424	MU2	161	0.01
103424	2N2	335.5	0.01
103424	OO1	86.7	0.02
103424	M1	73.7	0.03
103424	J1	82.3	0.03
103424	RHO1	65.6	0.02
103424	Q1	65	0.08
103424	T2	358.3	0.01
103424	2Q1	60.7	0.01
103424	P1	77.3	0.14
103424	L2	359.8	0.01
103424	K2	359.1	0.03
103425	M2	14.9	0.27
103425	S2	13.7	0.07
103425	N2	356.5	0.07
103425	K1	87.7	0.47
103425	M4	170.1	0.01
103425	O1	74.2	0.37
103425	S4	263.8	0.01
103425	NU2	359.4	0.01
103425	MU2	15.5	0.01
103425	2N2	336.2	0.01
103425	OO1	100	0.02
103425	M1	80.9	0.03
103425	J1	93.8	0.03
103425	SSA	54.7	0.21
103425	SA	148.3	0.33
103425	RHO1	68.4	0.01
103425	Q1	67.8	0.07
103425	2Q1	61.1	0.01
103425	P1	86.7	0.16
103425	L2	33.3	0.01
103425	K2	13	0.02
103426	M2	34.6	0.26
103426	S2	26	0.06
103426	N2	19.8	0.07
103426	K1	97.9	0.42
103426	M4	246.1	0.01
103426	O1	84.8	0.29
103426	S4	293	0.01
103426	NU2	21.4	0.01
103426	MU2	45.4	0.01
103426	2N2	4.3	0.01
103426	OO1	111.4	0.01
103426	M1	91.4	0.02
103426	J1	104.2	0.02
103426	SSA	54.7	0.21
103426	SA	148.3	0.33
103426	RHO1	80.1	0.01
103426	Q1	78.5	0.06
103426	2Q1	74.2	0.01
103426	P1	96.9	0.14
103426	L2	49.4	0.01
103426	K2	24.6	0.01
103426	M8	314.8	0.01
103427	M2	58.5	0.12
103427	S2	48.7	0.03
103427	N2	31.1	0.03
103427	K1	113.6	0.22
103427	M4	359.5	0.01
103427	O1	97.3	0.21
103427	NU2	37.2	0.01
103427	OO1	129.6	0.01
103427	M1	105.3	0.02
103427	J1	121.5	0.02
103427	RHO1	91	0.01
103427	Q1	89.6	0.04
103427	2Q1	81.2	0.01
103427	P1	112.4	0.07
103427	K2	45	0.01
103428	M2	44.1	0.2
103428	S2	55.8	0.03
103428	N2	30.6	0.05
103428	K1	101.3	0.31
103428	M4	259.5	0.01
103428	O1	87.1	0.22
103428	S4	304.5	0.01
103428	NU2	33	0.01
103428	2N2	15.4	0.01
103428	OO1	115.9	0.01
103428	M1	93.9	0.02
103428	J1	108.2	0.02
103428	RHO1	79.8	0.01
103428	Q1	80.4	0.04
103428	2Q1	73.5	0.01
103428	P1	100.2	0.1
103428	L2	57.6	0.01
103428	K2	48	0.01
103429	M2	245.9	0.43
103429	S2	236.4	0.14
103429	N2	223.2	0.12
103429	K1	22.7	0.54
103429	M4	34.5	0.02
103429	O1	15.9	0.49
103429	M6	300.9	0.01
103429	S4	223.1	0.01
103429	MN4	356.8	0.01
103429	NU2	238.4	0.03
103429	MU2	177.9	0.02
103429	2N2	208.5	0.02
103429	OO1	43.6	0.02
103429	LDA2	25.7	0.01
103429	S1	266	0.01
103429	M1	50.5	0.03
103429	J1	26.3	0.04
103429	SSA	54.7	0.21
103429	SA	148.3	0.33
103429	RHO1	6.6	0.02
103429	Q1	1.1	0.1
103429	T2	253.2	0.01
103429	R2	355	0.01
103429	2Q1	352.3	0.01
103429	P1	14	0.17
103429	2SM2	299.3	0.01
103429	M3	190.1	0.01
103429	L2	312.8	0.01
103429	2MK3	159.1	0.01
103429	K2	261.5	0.01
103430	M2	252.7	0.48
103430	S2	236	0.19
103430	N2	232.9	0.13
103430	K1	17.3	0.52
103430	M4	303	0.01
103430	O1	14.1	0.53
103430	M6	264.5	0.01
103430	NU2	235.6	0.03
103430	MU2	269.5	0.01
103430	2N2	213.1	0.02
103430	OO1	20.6	0.02
103430	M1	15.7	0.04
103430	J1	18.9	0.04
103430	SSA	54.7	0.21
103430	SA	148.3	0.33
103430	RHO1	12.7	0.02
103430	Q1	12.5	0.1
103430	T2	236.6	0.01
103430	2Q1	10.9	0.01
103430	P1	17.1	0.17
103430	L2	272.6	0.01
103430	K2	234.6	0.05
103430	M8	139.5	0.01
103431	M2	353.6	0.19
103431	S2	12.2	0.07
103431	N2	328.5	0.06
103431	K1	71.6	0.26
103431	O1	58	0.23
103431	MK3	72.8	0.03
103431	S4	42	0.01
103431	NU2	0.3	0.01
103431	MU2	305.3	0.02
103431	2N2	290.8	0.02
103431	OO1	253.3	0.01
103431	LDA2	130.6	0.01
103431	S1	96.3	0.07
103431	M1	59.6	0.02
103431	J1	79.5	0.01
103431	SSA	67.5	0.24
103431	SA	143.9	0.36
103431	Q1	69.6	0.05
103431	T2	204.1	0.01
103431	R2	196.9	0.02
103431	P1	99.4	0.09
103431	2SM2	46.1	0.01
103431	M3	348.5	0.01
103431	2MK3	36.4	0.02
103431	K2	29.9	0.03
103431	MS4	234.4	0.02
103432	M2	273.9	0.44
103432	S2	276.3	0.15
103432	N2	254.6	0.11
103432	K1	31.7	0.47
103432	M4	36.8	0.02
103432	O1	23	0.43
103432	M6	223.5	0.01
103432	MK3	238.6	0.02
103432	MN4	348.5	0.01
103432	NU2	241.7	0.02
103432	MU2	263.5	0.01
103432	2N2	222.1	0.03
103432	OO1	36.7	0.02
103432	LDA2	33.4	0.02
103432	S1	222.2	0.03
103432	M1	35	0.03
103432	J1	39.4	0.02
103432	SSA	67.5	0.24
103432	SA	143.9	0.36
103432	RHO1	10.5	0.02
103432	Q1	24.5	0.09
103432	T2	13.2	0.02
103432	R2	72.2	0.04
103432	2Q1	355.5	0.03
103432	P1	46.4	0.14
103432	2SM2	183.6	0.02
103432	M3	200.7	0.01
103432	L2	316.3	0.01
103432	2MK3	181.2	0.01
103432	K2	312.9	0.04
103432	MS4	52.5	0.01
103433	M2	50.7	0.3
103433	S2	33.2	0.08
103433	N2	23.7	0.07
103433	K1	107.5	0.36
103433	M4	3.9	0.02
103433	O1	96.5	0.32
103433	MK3	75.5	0.02
103433	MN4	340.6	0.01
103433	NU2	34.1	0.02
103433	MU2	274.5	0.02
103433	2N2	14.8	0.01
103433	OO1	121.2	0.02
103433	LDA2	69.9	0.01
103433	S1	138.2	0.03
103433	M1	171	0.01
103433	J1	99.4	0.01
103433	SSA	57.9	0.2
103433	SA	123.9	0.31
103433	RHO1	81.7	0.01
103433	Q1	80.5	0.06
103433	T2	146.6	0.01
103433	R2	19.2	0.01
103433	2Q1	77.6	0.01
103433	P1	105.8	0.09
103433	M3	28.9	0.01
103433	L2	85.3	0.02
103433	2MK3	72.7	0.02
103433	K2	63.1	0.04
103433	MS4	5.4	0.01
103434	M2	356.3	0.21
103434	S2	338.5	0.06
103434	N2	332.6	0.05
103434	K1	87.6	0.31
103434	M4	219.4	0.01
103434	O1	74.7	0.3
103434	MK3	351.5	0.01
103434	MN4	223.9	0.01
103434	NU2	324.3	0.01
103434	MU2	202.4	0.01
103434	2N2	326.1	0.03
103434	OO1	77.5	0.02
103434	LDA2	77.4	0.01
103434	S1	226.9	0.01
103434	M1	90.2	0.02
103434	J1	141.2	0.01
103434	SSA	67.5	0.24
103434	SA	143.9	0.36
103434	RHO1	59	0.02
103434	Q1	76.5	0.06
103434	T2	49.1	0.01
103434	R2	220.2	0.01
103434	2Q1	23.9	0.04
103434	P1	96.9	0.1
103434	2SM2	282.9	0.01
103434	L2	80.7	0.02
103434	K2	16	0.03
103434	MS4	237.8	0.01
103435	M2	45.2	0.26
103435	S2	28.6	0.07
103435	N2	21.5	0.06
103435	K1	104.9	0.35
103435	M4	339.9	0.01
103435	O1	91.9	0.31
103435	MK3	65.2	0.02
103435	MN4	324.8	0.01
103435	NU2	38.8	0.01
103435	MU2	259.4	0.02
103435	2N2	352.2	0.01
103435	OO1	118.5	0.02
103435	LDA2	77.7	0.01
103435	S1	138.9	0.02
103435	M1	116.4	0.01
103435	J1	136.6	0.01
103435	SSA	60	0.27
103435	SA	129	0.27
103435	RHO1	68.9	0.01
103435	Q1	80.1	0.06
103435	T2	91.8	0.01
103435	R2	51.8	0.01
103435	2Q1	19.1	0.01
103435	P1	103.4	0.1
103435	M3	37	0.01
103435	L2	91.7	0.02
103435	2MK3	46.6	0.01
103435	K2	51.1	0.03
103435	MS4	344.9	0.01
103436	M2	254.4	0.45
103436	S2	249.7	0.13
103436	N2	233.8	0.12
103436	K1	31.6	0.48
103436	M4	343.1	0.03
103436	O1	26.4	0.43
103436	M6	259.8	0.01
103436	MK3	96.3	0.03
103436	MN4	319.6	0.01
103436	NU2	243.6	0.02
103436	MU2	201	0.02
103436	2N2	198.6	0.02
103436	OO1	57.6	0.02
103436	LDA2	31.5	0.01
103436	S1	281.2	0.02
103436	M1	52.7	0.02
103436	J1	39.9	0.03
103436	SSA	67.5	0.24
103436	SA	143.9	0.36
103436	RHO1	12.4	0.01
103436	Q1	7.8	0.1
103436	T2	291.8	0.01
103436	2Q1	12	0.02
103436	P1	25.6	0.14
103436	2SM2	317.9	0.01
103436	M3	209.5	0.01
103436	L2	310.6	0.01
103436	2MK3	102.7	0.03
103436	K2	313.4	0.03
103436	MS4	351	0.01
103437	M2	60.2	0.17
103437	S2	19.1	0.05
103437	N2	38.2	0.04
103437	K1	117.9	0.26
103437	M4	352.6	0.01
103437	O1	106	0.24
103437	MK3	62	0.01
103437	MN4	342.9	0.01
103437	MU2	271	0.01
103437	2N2	22.5	0.02
103437	OO1	118.9	0.02
103437	S1	286.1	0.02
103437	M1	129.8	0.02
103437	SSA	67.5	0.24
103437	SA	143.9	0.36
103437	RHO1	51.3	0.02
103437	Q1	109.7	0.04
103437	T2	74	0.02
103437	R2	13.8	0.02
103437	2Q1	40.3	0.03
103437	P1	126.7	0.08
103437	2SM2	347.6	0.01
103437	L2	97	0.02
103437	2MK3	10.1	0.01
103437	MS4	25.2	0.01
103438	M2	357.9	0.13
103438	S2	1.2	0.04
103438	N2	329.8	0.03
103438	K1	89.6	0.27
103438	M4	236.3	0.01
103438	O1	79.7	0.25
103438	MK3	8.2	0.01
103438	NU2	331.8	0.01
103438	MU2	243.4	0.01
103438	2N2	323.1	0.02
103438	OO1	99.8	0.01
103438	LDA2	117.6	0.01
103438	S1	334.7	0.04
103438	M1	99.2	0.01
103438	SSA	52	0.25
103438	SA	135.7	0.21
103438	RHO1	59	0.02
103438	Q1	77.3	0.04
103438	R2	200.2	0.01
103438	2Q1	50.1	0.02
103438	P1	101.3	0.07
103438	M3	285.4	0.01
103438	L2	106.7	0.01
103438	2MK3	343.5	0.01
103438	K2	28.3	0.02
103439	M2	320.7	0.17
103439	S2	313.4	0.06
103439	N2	296.5	0.05
103439	K1	74.1	0.3
103439	O1	64.1	0.28
103439	MK3	164.9	0.01
103439	NU2	308.5	0.01
103439	MU2	231.2	0.01
103439	2N2	253.2	0.01
103439	OO1	91.6	0.02
103439	S1	335.4	0.01
103439	M1	70.1	0.01
103439	J1	73.1	0.01
103439	SSA	46.2	0.34
103439	SA	127.7	0.33
103439	RHO1	52.6	0.01
103439	Q1	47	0.05
103439	2Q1	5.1	0.01
103439	P1	67.7	0.08
103439	L2	48.3	0.01
103439	2MK3	167	0.01
103439	K2	19	0.02
103440	M2	28.2	0.17
103440	S2	15.5	0.05
103440	N2	1.8	0.04
103440	K1	101.8	0.29
103440	M4	334	0.01
103440	O1	89.1	0.27
103440	MK3	51.6	0.01
103440	NU2	11.5	0.01
103440	MU2	267.9	0.01
103440	2N2	348	0.01
103440	OO1	117.2	0.02
103440	S1	339	0.01
103440	M1	117.8	0.01
103440	J1	96.7	0.01
103440	MM	19.7	0.09
103440	SSA	58.9	0.34
103440	SA	112.9	0.27
103440	RHO1	55.3	0.01
103440	Q1	73.8	0.05
103440	2Q1	51.8	0.01
103440	P1	97.6	0.08
103440	L2	83.5	0.01
103440	2MK3	20.9	0.01
103440	K2	29.4	0.02
103441	M2	290.7	0.25
103441	S2	284.7	0.08
103441	N2	268.3	0.06
103441	K1	58.7	0.32
103441	M4	334.9	0.01
103441	O1	50.7	0.31
103441	NU2	305.8	0.02
103441	2N2	212.7	0.02
103441	OO1	63	0.01
103441	S1	321.4	0.02
103441	M1	320.7	0.01
103441	J1	77.7	0.01
103441	SSA	67	0.34
103441	SA	125.7	0.23
103441	RHO1	20.4	0.02
103441	Q1	41.3	0.07
103441	T2	283.3	0.01
103441	2Q1	205.9	0.01
103441	P1	43.6	0.1
103441	L2	10.2	0.01
103441	K2	341.4	0.03
103442	M2	78.8	0.3
103442	S2	70.3	0.09
103442	N2	44.7	0.07
103442	K1	119.1	0.49
103442	M4	70.3	0.02
103442	O1	100.8	0.46
103442	MK3	89.8	0.02
103442	S4	268.9	0.01
103442	MN4	43.7	0.01
103442	NU2	87.7	0.02
103442	MU2	261.2	0.01
103442	2N2	70.7	0.04
103442	OO1	123.5	0.04
103442	LDA2	203.3	0.01
103442	S1	135.4	0.02
103442	M1	133.9	0.04
103442	SSA	71.3	0.33
103442	SA	133	0.33
103442	RHO1	113.3	0.02
103442	Q1	97.7	0.07
103442	T2	149	0.01
103442	R2	44.1	0.01
103442	2Q1	64.6	0.05
103442	P1	128.2	0.14
103442	M3	333.8	0.01
103442	L2	165.1	0.03
103442	2MK3	40	0.02
103442	K2	105.5	0.05
103442	MS4	81.7	0.01
103443	M2	51	0.17
103443	S2	35.1	0.04
103443	N2	36.1	0.03
103443	K1	111.7	0.35
103443	M4	343.4	0.02
103443	O1	97.4	0.34
103443	NU2	43.4	0.02
103443	MU2	258.2	0.02
103443	2N2	155.2	0.01
103443	OO1	95.2	0.03
103443	LDA2	119.2	0.01
103443	S1	315.7	0.03
103443	M1	166.5	0.02
103443	J1	150.6	0.01
103443	SSA	28.1	0.2
103443	SA	159.8	0.31
103443	RHO1	97.4	0.02
103443	Q1	89.7	0.06
103443	T2	109.2	0.02
103443	R2	107.7	0.01
103443	2Q1	136.1	0.01
103443	P1	94.8	0.1
103443	K2	60.2	0.02
103444	M2	275.5	0.4
103444	S2	271.5	0.13
103444	N2	254.4	0.11
103444	K1	40.7	0.43
103444	M4	318.9	0.02
103444	O1	34.6	0.4
103444	MK3	141.2	0.02
103444	NU2	269.5	0.02
103444	MU2	210.3	0.02
103444	2N2	220.4	0.02
103444	OO1	61.4	0.02
103444	S1	306.3	0.04
103444	M1	36.9	0.02
103444	J1	47.1	0.02
103444	SSA	52	0.25
103444	SA	135.7	0.21
103444	RHO1	23.8	0.02
103444	Q1	21.8	0.09
103444	T2	271.7	0.01
103444	2Q1	28.5	0.01
103444	P1	33.1	0.13
103444	L2	5.1	0.01
103444	2MK3	132.8	0.02
103444	K2	338.5	0.03
103445	M2	47.6	0.15
103445	S2	15.8	0.05
103445	N2	87.6	0.02
103445	K1	111.6	0.23
103445	M4	330.8	0.01
103445	O1	102.1	0.22
103445	OO1	121.2	0.01
103445	M1	106.9	0.02
103445	J1	116.4	0.02
103445	RHO1	98	0.01
103445	Q1	97.3	0.04
103445	2Q1	92.6	0.01
103445	P1	110.9	0.08
103445	K2	13.3	0.01
103446	M2	65	0.19
103446	S2	49.6	0.04
103446	N2	37.9	0.05
103446	K1	111.2	0.43
103446	O1	98.6	0.42
103446	NU2	47.6	0.01
103446	MU2	297.4	0.01
103446	OO1	131.1	0.05
103446	LDA2	99.1	0.01
103446	S1	128.3	0.01
103446	M1	202.1	0.01
103446	J1	78.5	0.01
103446	SSA	71.3	0.33
103446	SA	133	0.33
103446	RHO1	101.7	0.02
103446	Q1	82.4	0.08
103446	R2	17.8	0.01
103446	2Q1	50.2	0.01
103446	P1	114.6	0.11
103446	L2	96	0.01
103446	K2	87.1	0.03
103447	M2	59.1	0.17
103447	S2	45.8	0.04
103447	N2	32.8	0.04
103447	K1	110.4	0.37
103447	M4	338.2	0.01
103447	O1	103.5	0.37
103447	MK3	26	0.01
103447	NU2	50.3	0.01
103447	MU2	257.3	0.01
103447	2N2	288.3	0.02
103447	OO1	119.3	0.05
103447	S1	277.7	0.04
103447	M1	227.5	0.02
103447	J1	121.5	0.01
103447	SSA	48.9	0.37
103447	SA	146.4	0.29
103447	RHO1	143.5	0.01
103447	Q1	71.5	0.08
103447	T2	112.9	0.01
103447	R2	90.6	0.01
103447	2Q1	290.6	0.01
103447	P1	113	0.09
103447	2SM2	70.9	0.01
103447	L2	93.6	0.01
103447	K2	72.4	0.03
103447	MS4	342.4	0.01
103448	M2	100.7	0.31
103448	S2	103	0.06
103448	N2	85.6	0.06
103448	K1	127.6	0.44
103448	M4	149	0.01
103448	O1	119.9	0.4
103448	S4	8.2	0.01
103448	NU2	87.5	0.01
103448	MU2	95.7	0.01
103448	2N2	70.8	0.01
103448	OO1	135.6	0.02
103448	M1	123.8	0.03
103448	J1	131.5	0.03
103448	SSA	71.3	0.33
103448	SA	133	0.33
103448	RHO1	116.8	0.02
103448	Q1	116	0.08
103448	2Q1	112	0.01
103448	P1	127.1	0.14
103448	L2	116.7	0.01
103448	K2	102.2	0.02
103449	M2	76.3	0.28
103449	S2	67	0.07
103449	N2	46.8	0.07
103449	K1	112.4	0.5
103449	M4	97.3	0.01
103449	O1	99.5	0.47
103449	MK3	99.7	0.02
103449	MN4	95.5	0.01
103449	NU2	70.1	0.01
103449	MU2	310.7	0.01
103449	2N2	111.7	0.02
103449	OO1	129.3	0.08
103449	S1	126.9	0.03
103449	M1	205.5	0.02
103449	J1	148.5	0.02
103449	SSA	71.3	0.33
103449	SA	133	0.33
103449	RHO1	62.9	0.01
103449	Q1	77.7	0.09
103449	T2	86.9	0.01
103449	R2	35.3	0.01
103449	2Q1	99.7	0.02
103449	P1	118.8	0.14
103449	L2	114.5	0.01
103449	2MK3	53.4	0.01
103449	K2	108.5	0.05
103450	M2	84.5	0.24
103450	S2	78.4	0.07
103450	N2	63	0.06
103450	K1	120.4	0.43
103450	M4	53.9	0.01
103450	O1	107.8	0.39
103450	NU2	61	0.02
103450	MU2	4.8	0.01
103450	2N2	131.6	0.02
103450	OO1	125	0.04
103450	LDA2	175.1	0.01
103450	S1	88.9	0.02
103450	M1	156.6	0.02
103450	J1	201.3	0.01
103450	SSA	35.4	0.34
103450	SA	141.8	0.43
103450	RHO1	50	0.03
103450	Q1	93.4	0.07
103450	T2	133.4	0.02
103450	R2	72.6	0.01
103450	2Q1	107.8	0.02
103450	P1	130.3	0.1
103450	L2	140.5	0.03
103450	K2	99.7	0.03
103451	M2	266	0.55
103451	S2	252.7	0.19
103451	N2	244.9	0.13
103451	K1	30.2	0.58
103451	M4	254.5	0.01
103451	O1	20.8	0.51
103451	S4	98.3	0.02
103451	NU2	247.9	0.02
103451	MU2	278	0.01
103451	2N2	223.5	0.02
103451	OO1	39.6	0.02
103451	M1	25.5	0.04
103451	J1	34.8	0.04
103451	SSA	52	0.25
103451	SA	135.7	0.21
103451	RHO1	16.7	0.02
103451	Q1	16.1	0.1
103451	T2	252.9	0.01
103451	2Q1	11.7	0.01
103451	P1	29.5	0.19
103451	L2	286.9	0.02
103451	K2	251.6	0.05
103452	M2	78.3	0.3
103452	S2	67.9	0.08
103452	N2	53.9	0.07
103452	K1	117.2	0.48
103452	M4	74.6	0.01
103452	O1	102.3	0.45
103452	MK3	86.4	0.02
103452	MN4	48.8	0.01
103452	NU2	64.5	0.01
103452	MU2	299.4	0.02
103452	2N2	24.5	0.01
103452	OO1	120.6	0.05
103452	LDA2	109.9	0.01
103452	S1	139.3	0.01
103452	M1	139.7	0.01
103452	J1	123.8	0.01
103452	SSA	44.3	0.36
103452	SA	134.7	0.36
103452	RHO1	95.3	0.02
103452	Q1	87.3	0.08
103452	T2	119.4	0.01
103452	2Q1	68.3	0.01
103452	P1	123.1	0.13
103452	L2	129.8	0.02
103452	2MK3	60	0.02
103452	K2	104.7	0.04
103452	MS4	83.8	0.01
103453	M2	34.8	0.2
103453	S2	36.9	0.06
103453	N2	10.3	0.05
103453	K1	100.6	0.4
103453	M4	10.7	0.02
103453	O1	91.3	0.38
103453	MK3	359.2	0.02
103453	S4	239.6	0.01
103453	MN4	346.5	0.01
103453	NU2	19.7	0.01
103453	MU2	280	0.01
103453	2N2	310	0.01
103453	OO1	115.6	0.04
103453	S1	13.3	0.05
103453	M1	124.9	0.01
103453	J1	147.1	0.02
103453	SSA	52.4	0.31
103453	SA	142.8	0.34
103453	RHO1	51.8	0.01
103453	Q1	73.4	0.07
103453	T2	238.9	0.01
103453	R2	64.9	0.01
103453	2Q1	2.7	0.01
103453	P1	90.3	0.1
103453	L2	86.9	0.01
103453	2MK3	349	0.01
103453	K2	70.6	0.03
103453	MS4	15.7	0.01
103454	M2	265.6	0.46
103454	S2	267.5	0.15
103454	N2	244.8	0.12
103454	K1	34	0.48
103454	M4	326.6	0.02
103454	O1	26.4	0.44
103454	MK3	128.4	0.03
103454	MN4	299.6	0.01
103454	NU2	254.9	0.02
103454	MU2	193.5	0.02
103454	2N2	219.6	0.02
103454	OO1	57.8	0.03
103454	S1	279	0.02
103454	M1	33.6	0.03
103454	J1	42.8	0.03
103454	SSA	47	0.35
103454	SA	135.1	0.34
103454	RHO1	15.9	0.02
103454	Q1	10.4	0.1
103454	T2	293.5	0.01
103454	R2	104.6	0.01
103454	2Q1	335.3	0.01
103454	P1	28	0.15
103454	2SM2	330.5	0.01
103454	M3	212.2	0.01
103454	L2	358.3	0.01
103454	2MK3	121.3	0.03
103454	K2	337.3	0.02
103454	MS4	345.2	0.01
103455	M2	41.7	0.17
103455	S2	37.5	0.06
103455	N2	12.7	0.04
103455	K1	104.5	0.4
103455	M4	351.3	0.01
103455	O1	88.7	0.4
103455	NU2	27.8	0.01
103455	MU2	267.8	0.01
103455	2N2	17.4	0.03
103455	OO1	115.1	0.04
103455	LDA2	93	0.01
103455	S1	273.4	0.01
103455	M1	112.5	0.02
103455	J1	164.8	0.01
103455	SSA	48.9	0.37
103455	SA	146.4	0.29
103455	RHO1	73.9	0.02
103455	Q1	89.3	0.07
103455	T2	173.2	0.01
103455	2Q1	34.8	0.05
103455	P1	109	0.13
103455	L2	133.8	0.01
103455	2MK3	353.6	0.01
103455	K2	70.4	0.04
103456	M2	94.7	0.12
103456	S2	81.3	0.03
103456	N2	96.4	0.03
103456	K1	133	0.34
103456	M4	313.9	0.01
103456	O1	118.2	0.34
103456	NU2	155.2	0.01
103456	MU2	305.4	0.01
103456	2N2	260	0.02
103456	OO1	136.4	0.05
103456	LDA2	239.8	0.01
103456	S1	36.2	0.01
103456	M1	282.1	0.01
103456	J1	166.6	0.01
103456	SSA	68.1	0.38
103456	SA	126.4	0.22
103456	RHO1	117.7	0.02
103456	Q1	115.2	0.08
103456	T2	193.7	0.01
103456	2Q1	256.7	0.02
103456	P1	140.1	0.09
103456	K2	110.5	0.03
103457	M2	24.8	0.19
103457	S2	14.4	0.06
103457	N2	357.2	0.04
103457	K1	97.5	0.39
103457	M4	322.4	0.02
103457	O1	86.7	0.42
103457	MK3	320.3	0.02
103457	S4	164.7	0.01
103457	MN4	294.6	0.01
103457	NU2	16.4	0.01
103457	MU2	275.3	0.01
103457	2N2	34.5	0.01
103457	OO1	108.5	0.03
103457	LDA2	109.6	0.01
103457	S1	348.4	0.05
103457	M1	123.3	0.02
103457	J1	114.1	0.02
103457	SSA	65.2	0.35
103457	SA	134.6	0.33
103457	RHO1	74.5	0.02
103457	Q1	75.7	0.06
103457	T2	209.2	0.01
103457	2Q1	84.1	0.03
103457	P1	91.3	0.11
103457	M3	212.7	0.01
103457	L2	88.7	0.02
103457	2MK3	319.6	0.02
103457	K2	58.2	0.03
103457	MS4	318.9	0.01
103458	M2	23	0.1
103458	S2	19.9	0.04
103458	N2	355.9	0.03
103458	K1	99.7	0.36
103458	M4	211.1	0.01
103458	O1	88.1	0.36
103458	MK3	259.4	0.01
103458	NU2	340.4	0.01
103458	MU2	279.9	0.01
103458	2N2	293.9	0.01
103458	OO1	110.9	0.03
103458	S1	339.3	0.03
103458	M1	115.4	0.01
103458	J1	80.5	0.01
103458	SSA	60	0.29
103458	SA	144.6	0.27
103458	RHO1	85.5	0.01
103458	Q1	70.1	0.07
103458	T2	1.7	0.01
103458	2Q1	44.8	0.01
103458	P1	99.8	0.09
103458	L2	92.5	0.01
103458	2MK3	254.2	0.01
103458	K2	76.5	0.02
103459	M2	262.3	0.57
103459	S2	245.4	0.25
103459	N2	248.8	0.16
103459	K1	26.4	0.57
103459	M4	287.1	0.01
103459	O1	15.7	0.5
103459	M6	204.4	0.01
103459	S4	70.6	0.02
103459	NU2	250.6	0.03
103459	S6	199.3	0.01
103459	MU2	279.2	0.01
103459	2N2	235.2	0.02
103459	OO1	37.2	0.02
103459	M1	21.1	0.04
103459	J1	31.8	0.04
103459	SSA	52	0.25
103459	SA	135.7	0.21
103459	RHO1	11.1	0.02
103459	Q1	10.3	0.1
103459	T2	246.1	0.01
103459	2Q1	5	0.01
103459	P1	25.6	0.19
103459	L2	275.9	0.02
103459	K2	244	0.07
103460	M2	262.3	0.48
103460	S2	249	0.17
103460	N2	241.8	0.11
103460	K1	30.3	0.57
103460	M4	252.8	0.01
103460	O1	19.5	0.51
103460	S4	94.7	0.01
103460	NU2	244.4	0.02
103460	MU2	274.9	0.01
103460	2N2	221.3	0.01
103460	OO1	41	0.02
103460	M1	25	0.04
103460	J1	35.7	0.04
103460	SSA	52	0.25
103460	SA	135.7	0.21
103460	RHO1	14.7	0.02
103460	Q1	14.2	0.1
103460	T2	250.1	0.01
103460	2Q1	9	0.01
103460	P1	29.6	0.19
103460	L2	284	0.01
103460	K2	247.7	0.05
103461	M2	262.6	0.55
103461	S2	254.2	0.17
103461	N2	236.9	0.15
103461	K1	23.3	0.57
103461	M4	284.5	0.02
103461	O1	16.3	0.53
103461	MK3	257.9	0.01
103461	MN4	245.9	0.01
103461	NU2	249.5	0.03
103461	MU2	181.3	0.02
103461	2N2	216	0.03
103461	OO1	50.5	0.02
103461	S1	324.6	0.02
103461	M1	48.1	0.01
103461	J1	27.2	0.03
103461	SSA	52	0.25
103461	SA	135.7	0.21
103461	RHO1	5.4	0.02
103461	Q1	2.1	0.12
103461	T2	315.6	0.01
103461	R2	311.3	0.01
103461	2Q1	333	0.01
103461	P1	19.3	0.17
103461	M3	209.5	0.01
103461	2MK3	270.8	0.01
103461	K2	275.7	0.04
103461	MS4	281.1	0.01
103462	M2	346.7	0.15
103462	S2	338.3	0.04
103462	N2	304	0.04
103462	K1	89.6	0.36
103462	M4	210.8	0.01
103462	O1	76.8	0.35
103462	NU2	309.4	0.01
103462	2N2	261.8	0.01
103462	OO1	102.2	0.02
103462	M1	83.2	0.03
103462	J1	95.8	0.03
103462	SSA	48.9	0.37
103462	SA	146.4	0.29
103462	RHO1	71.2	0.01
103462	Q1	70.6	0.07
103462	2Q1	64.8	0.01
103462	P1	88.7	0.12
103462	K2	336.7	0.01
103463	M2	334.5	0.11
103463	S2	337.9	0.04
103463	N2	303	0.03
103463	K1	96	0.34
103463	M4	205.4	0.01
103463	O1	82.1	0.31
103463	S4	54.4	0.01
103463	NU2	308	0.01
103463	OO1	110	0.01
103463	M1	89.2	0.02
103463	J1	103	0.03
103463	SSA	55.6	0.28
103463	SA	155.7	0.22
103463	RHO1	76.4	0.01
103463	Q1	75.2	0.06
103463	2Q1	67.8	0.01
103463	P1	95	0.11
103463	K2	339.6	0.01
103464	M2	290.7	0.26
103464	S2	286.9	0.08
103464	N2	265.3	0.07
103464	K1	60.4	0.46
103464	O1	54.3	0.46
103464	MK3	128.1	0.05
103464	NU2	254.7	0.02
103464	MU2	249.1	0.01
103464	2N2	256	0.01
103464	OO1	105.8	0.05
103464	S1	345.1	0.05
103464	M1	97.6	0.03
103464	J1	58.9	0.01
103464	SSA	48.9	0.41
103464	SA	155.5	0.25
103464	RHO1	38.9	0.02
103464	Q1	34	0.1
103464	T2	340.6	0.01
103464	2Q1	345.2	0.01
103464	P1	54.7	0.13
103464	L2	315.9	0.01
103464	2MK3	117.1	0.04
103464	K2	10.2	0.05
103465	M2	281.5	0.36
103465	S2	289	0.1
103465	N2	257.4	0.09
103465	K1	40.8	0.48
103465	M4	232.7	0.01
103465	O1	33.1	0.46
103465	M6	278.9	0.01
103465	MK3	107.4	0.01
103465	S4	210.2	0.01
103465	MN4	193.1	0.01
103465	NU2	271.3	0.02
103465	MU2	218.4	0.01
103465	2N2	244.1	0.01
103465	OO1	85.1	0.02
103465	S1	320.2	0.04
103465	M1	67.3	0.02
103465	J1	30.7	0.03
103465	SSA	76	0.27
103465	SA	154.9	0.25
103465	RHO1	21.7	0.02
103465	Q1	14.6	0.1
103465	T2	269.2	0.01
103465	R2	133.4	0.01
103465	2Q1	3.2	0.02
103465	P1	35.8	0.14
103465	2SM2	348.2	0.01
103465	L2	330.6	0.01
103465	2MK3	96.3	0.01
103465	K2	344.2	0.02
103466	M2	261.9	0.56
103466	S2	259.8	0.17
103466	N2	241	0.13
103466	K1	24.5	0.58
103466	M4	272.6	0.02
103466	O1	16.4	0.53
103466	S4	15.5	0.01
103466	MN4	214.6	0.01
103466	NU2	247.5	0.03
103466	S6	33.8	0.01
103466	MU2	177.2	0.02
103466	2N2	220.6	0.03
103466	OO1	57.6	0.02
103466	LDA2	27.6	0.01
103466	S1	279.6	0.02
103466	M1	86.2	0.03
103466	J1	359.4	0.03
103466	SSA	52	0.25
103466	SA	135.7	0.21
103466	RHO1	18.1	0.02
103466	Q1	354.7	0.11
103466	T2	316.3	0.02
103466	R2	215.8	0.01
103466	2Q1	333.3	0.02
103466	P1	24.5	0.17
103466	2SM2	63.5	0.01
103466	M3	184.1	0.01
103466	L2	308.6	0.02
103466	K2	270.9	0.02
103466	M8	33.2	0.01
103466	MS4	275.4	0.01
103467	M2	276.3	0.45
103467	S2	270.6	0.14
103467	N2	252.5	0.12
103467	K1	27.7	0.55
103467	M4	225	0.02
103467	O1	21	0.52
103467	M6	287.9	0.01
103467	MK3	2.3	0.01
103467	S4	347.5	0.01
103467	MN4	210.2	0.01
103467	NU2	258.2	0.02
103467	MU2	190.9	0.02
103467	2N2	245.6	0.02
103467	OO1	57.8	0.02
103467	LDA2	358.5	0.01
103467	S1	266.8	0.01
103467	M1	74.3	0.02
103467	J1	24.9	0.03
103467	SSA	76	0.27
103467	SA	154.9	0.25
103467	RHO1	24	0.03
103467	Q1	358.8	0.12
103467	T2	314.6	0.02
103467	R2	335.5	0.01
103467	2Q1	357.1	0.02
103467	P1	25.6	0.16
103467	2SM2	331.6	0.01
103467	L2	334	0.01
103467	2MK3	26.4	0.01
103467	K2	303	0.03
103467	MS4	239.4	0.01
103468	M2	295.7	0.29
103468	S2	293.1	0.09
103468	N2	274	0.08
103468	K1	53.3	0.43
103468	M4	255.4	0.02
103468	O1	45.5	0.41
103468	NU2	292.1	0.02
103468	MU2	227.7	0.01
103468	2N2	239.3	0.02
103468	OO1	82.3	0.03
103468	S1	352.2	0.03
103468	M1	44.4	0.02
103468	J1	51	0.02
103468	SSA	55.6	0.28
103468	SA	155.7	0.22
103468	RHO1	30.5	0.02
103468	Q1	29.4	0.09
103468	T2	293.2	0.01
103468	2Q1	37.9	0.01
103468	P1	46.6	0.13
103468	L2	317.2	0.01
103468	K2	19.3	0.01
103469	M2	314.3	0.22
103469	S2	314.2	0.08
103469	N2	292.5	0.06
103469	K1	68.9	0.39
103469	M4	272.5	0.01
103469	O1	58.8	0.38
103469	MK3	177	0.01
103469	MN4	216.8	0.01
103469	NU2	302.5	0.01
103469	MU2	251.1	0.01
103469	2N2	257.5	0.01
103469	OO1	93.4	0.03
103469	S1	329.2	0.03
103469	M1	67.3	0.02
103469	J1	64.7	0.02
103469	MM	19.1	0.09
103469	SSA	49.6	0.37
103469	SA	150.2	0.27
103469	RHO1	43.8	0.02
103469	Q1	40.6	0.08
103469	T2	344.8	0.01
103469	2Q1	14.1	0.01
103469	P1	62.7	0.11
103469	L2	38.2	0.01
103469	2MK3	161.8	0.01
103469	K2	39.4	0.02
103470	M2	276.1	0.46
103470	S2	267.9	0.11
103470	N2	254.6	0.12
103470	K1	28	0.56
103470	M4	203.3	0.02
103470	O1	20.3	0.53
103470	NU2	270.9	0.03
103470	MU2	197.1	0.02
103470	2N2	228.8	0.02
103470	OO1	46.2	0.02
103470	S1	327	0.05
103470	M1	24.2	0.03
103470	J1	34.5	0.03
103470	SSA	55.2	0.3
103470	SA	157.4	0.25
103470	RHO1	4	0.02
103470	Q1	7	0.12
103470	T2	268.1	0.01
103470	2Q1	349.5	0.01
103470	P1	24.3	0.17
103470	L2	352.1	0.01
103470	K2	275.6	0.02
103470	MS4	224.7	0.01
103471	M2	18.7	0.12
103471	S2	25.8	0.03
103471	N2	347.6	0.03
103471	K1	104.1	0.28
103471	M4	279	0.01
103471	O1	91.2	0.27
103471	NU2	352.7	0.01
103471	OO1	116.7	0.01
103471	M1	97.7	0.02
103471	J1	110.3	0.02
103471	SSA	55.6	0.28
103471	SA	155.7	0.22
103471	RHO1	85.4	0.01
103471	Q1	84.8	0.05
103471	2Q1	78.9	0.01
103471	P1	103.1	0.09
103471	K2	26.9	0.01
103472	M2	284.3	0.21
103472	S2	280.1	0.06
103472	N2	261.7	0.05
103472	K1	43.7	0.37
103472	M4	173.7	0.01
103472	O1	36.1	0.36
103472	MK3	86.2	0.01
103472	NU2	261.1	0.01
103472	MU2	217.8	0.01
103472	2N2	232.1	0.01
103472	OO1	75.1	0.02
103472	S1	282.4	0.01
103472	M1	47.7	0.02
103472	J1	46.7	0.03
103472	SSA	64.8	0.41
103472	SA	145.1	0.34
103472	RHO1	17	0.01
103472	Q1	19.5	0.08
103472	T2	330.8	0.01
103472	2Q1	352	0.01
103472	P1	38.4	0.11
103472	M3	34.8	0.01
103472	2MK3	85	0.01
103472	K2	347.9	0.01
103473	M2	275	0.32
103473	S2	275	0.09
103473	N2	255.5	0.08
103473	K1	26.6	0.49
103473	M4	148.8	0.02
103473	O1	18.9	0.49
103473	M6	187.5	0.01
103473	MN4	128.3	0.01
103473	NU2	241.1	0.01
103473	S6	287.3	0.01
103473	MU2	219.6	0.01
103473	2N2	230.1	0.02
103473	OO1	58.9	0.02
103473	LDA2	355.1	0.01
103473	S1	268	0.02
103473	M1	36.2	0.03
103473	J1	22.3	0.03
103473	SSA	69.3	0.24
103473	SA	155.9	0.28
103473	RHO1	349.7	0.03
103473	Q1	8.8	0.1
103473	T2	305.8	0.01
103473	R2	257.5	0.01
103473	2Q1	321.1	0.02
103473	P1	31.6	0.16
103473	L2	9.9	0.01
103473	K2	258.9	0.02
103474	M2	275.4	0.31
103474	S2	274.6	0.09
103474	N2	253.4	0.08
103474	K1	26.6	0.5
103474	M4	165.8	0.02
103474	O1	18.7	0.48
103474	NU2	253.9	0.02
103474	2N2	242.5	0.01
103474	OO1	36.7	0.02
103474	S1	332.2	0.02
103474	M1	69.2	0.02
103474	J1	28.5	0.03
103474	SSA	64.3	0.24
103474	SA	173.5	0.19
103474	RHO1	358.3	0.03
103474	Q1	0.6	0.11
103474	T2	274.6	0.01
103474	2Q1	341.4	0.01
103474	P1	23.5	0.15
103474	L2	335.5	0.01
103474	K2	279.6	0.02
103475	M2	275.2	0.31
103475	S2	275.9	0.09
103475	N2	252.5	0.08
103475	K1	26.1	0.5
103475	M4	160.5	0.02
103475	O1	19.2	0.48
103475	MN4	133.9	0.01
103475	NU2	258.8	0.02
103475	MU2	199.9	0.01
103475	2N2	247.7	0.01
103475	OO1	39.9	0.02
103475	S1	308.9	0.03
103475	M1	50.4	0.02
103475	J1	28.8	0.03
103475	SSA	69.3	0.24
103475	SA	155.9	0.28
103475	RHO1	9.4	0.02
103475	Q1	2.1	0.1
103475	T2	295.1	0.01
103475	2Q1	341.1	0.01
103475	P1	23.4	0.15
103475	M3	37	0.01
103475	L2	328.5	0.01
103475	K2	281.2	0.02
103475	MS4	180.7	0.01
103476	M2	273.7	0.31
103476	S2	273.6	0.09
103476	N2	253.3	0.08
103476	K1	26.5	0.5
103476	M4	160.7	0.02
103476	O1	18.7	0.48
103476	S4	286.1	0.01
103476	MN4	118.4	0.01
103476	NU2	257.2	0.02
103476	MU2	200.8	0.01
103476	2N2	231.8	0.01
103476	OO1	40.4	0.02
103476	S1	311.1	0.03
103476	M1	30.2	0.03
103476	J1	33.2	0.04
103476	SSA	50.4	0.37
103476	SA	159.8	0.24
103476	RHO1	1.6	0.02
103476	Q1	2.9	0.11
103476	T2	299.1	0.01
103476	2Q1	333.5	0.01
103476	P1	26.4	0.15
103476	M3	34.2	0.01
103476	L2	339.9	0.01
103476	2MK3	351.7	0.01
103476	K2	274.4	0.02
103476	MS4	166.5	0.01
103477	M2	272.6	0.3
103477	S2	267.8	0.08
103477	N2	248.9	0.07
103477	K1	26.2	0.46
103477	M4	165.2	0.02
103477	O1	16.9	0.46
103477	S4	301.6	0.01
103477	MN4	125.6	0.01
103477	NU2	254.9	0.01
103477	MU2	201.2	0.01
103477	2N2	233.5	0.01
103477	OO1	42.7	0.02
103477	S1	302.4	0.01
103477	M1	37.4	0.03
103477	J1	27.5	0.03
103477	SSA	69.3	0.24
103477	SA	115.9	0.28
103477	RHO1	345.8	0.02
103477	Q1	6.8	0.1
103477	T2	304	0.01
103477	R2	201.6	0.01
103477	2Q1	333.6	0.02
103477	P1	27.4	0.16
103477	M3	21.5	0.01
103477	L2	356	0.01
103477	K2	287.1	0.02
103478	M2	293.3	0.1
103478	S2	295	0.03
103478	N2	274.3	0.02
103478	K1	48.5	0.22
103478	M4	138	0.01
103478	O1	41.3	0.22
103478	NU2	289.3	0.01
103478	OO1	58.7	0.01
103478	S1	285.6	0.01
103478	M1	63.7	0.01
103478	J1	56.2	0.01
103478	SSA	58.9	0.37
103478	SA	150.3	0.28
103478	RHO1	17.3	0.01
103478	Q1	25.7	0.05
103478	R2	330.1	0.01
103478	2Q1	337.1	0.01
103478	P1	43.6	0.07
103478	K2	268.2	0.01
103479	M2	84.8	0.01
103479	S2	228.6	0.01
103479	K1	183.9	0.06
103479	O1	162	0.07
103479	OO1	153.9	0.01
103479	S1	197.7	0.03
103479	MM	36.9	0.09
103479	SSA	60.8	0.36
103479	SA	130.7	0.32
103479	Q1	153.5	0.01
103479	P1	211	0.02
103480	M2	316.8	0.04
103480	S2	303.7	0.02
103480	N2	300.5	0.01
103480	K1	77	0.11
103480	M4	168	0.01
103480	O1	72	0.12
103480	MK3	253.1	0.01
103480	OO1	88.4	0.01
103480	S1	144.7	0.01
103480	J1	78.6	0.01
103480	MM	27.5	0.1
103480	SSA	54.6	0.37
103480	SA	148.8	0.29
103480	Q1	54.7	0.02
103480	P1	79.7	0.03
103480	2MK3	232.5	0.01
103480	K2	351.3	0.01
103481	M2	54.3	0.08
103481	S2	41.4	0.02
103481	N2	39	0.02
103481	K1	111.6	0.29
103481	M4	301.8	0.01
103481	O1	97.9	0.29
103481	OO1	99	0.04
103481	S1	206	0.04
103481	M1	138.4	0.01
103481	J1	147.8	0.01
103481	MM	26.8	0.1
103481	SSA	53.2	0.37
103481	SA	129.6	0.37
103481	RHO1	96.8	0.02
103481	Q1	85.5	0.05
103481	T2	93.6	0.01
103481	R2	64.3	0.01
103481	P1	122.5	0.09
103481	L2	83.1	0.01
103481	K2	49.2	0.03
103482	M2	335.3	0.05
103482	S2	356.6	0.02
103482	N2	306.8	0.01
103482	K1	81	0.25
103482	M4	132.4	0.01
103482	O1	70.6	0.25
103482	OO1	84.1	0.02
103482	S1	349.4	0.02
103482	M1	104.5	0.01
103482	J1	102.8	0.01
103482	SSA	54.5	0.35
103482	SA	151.1	0.26
103482	RHO1	57.9	0.01
103482	Q1	54.2	0.05
103482	P1	80.8	0.08
103482	K2	350.6	0.01
103483	M2	241.9	0.14
103483	S2	251.9	0.05
103483	N2	223.8	0.04
103483	K1	45.1	0.37
103483	M4	48	0.02
103483	O1	36.9	0.37
103483	M6	204.5	0.01
103483	MK3	89.8	0.03
103483	MN4	22.5	0.01
103483	NU2	228.8	0.01
103483	MU2	196.9	0.01
103483	2N2	277.3	0.01
103483	OO1	76.4	0.03
103483	S1	329.9	0.03
103483	M1	48	0.02
103483	J1	57.6	0.02
103483	SSA	45.7	0.38
103483	SA	164.4	0.23
103483	RHO1	31.3	0.02
103483	Q1	22.9	0.08
103483	T2	281.3	0.01
103483	2Q1	5.2	0.01
103483	P1	40.7	0.12
103483	M3	20.2	0.01
103483	2MK3	68.9	0.03
103483	K2	349.4	0.04
103483	MS4	51.1	0.01
103484	M2	334.6	0.02
103484	S2	298.4	0.02
103484	N2	329.9	0.01
103484	K1	89.9	0.09
103484	O1	89.4	0.1
103484	MK3	310.1	0.01
103484	OO1	143.5	0.01
103484	S1	344	0.02
103484	M1	125.6	0.01
103484	RHO1	79	0.01
103484	Q1	78.8	0.02
103484	T2	54.6	0.01
103484	R2	0	0.01
103484	2Q1	26.7	0.01
103484	P1	103.6	0.02
103484	K2	266.3	0.01
103485	M2	2.4	0.02
103485	K1	117.4	0.07
103485	O1	108.4	0.08
103485	OO1	135.2	0.01
103485	S1	319.9	0.01
103485	M1	134	0.01
103485	RHO1	45.1	0.01
103485	Q1	95.7	0.01
103485	2Q1	72.1	0.01
103485	P1	124.7	0.02
103486	M2	80.2	0.01
103486	S2	25.3	0.01
103486	K1	177.6	0.07
103486	O1	162.8	0.07
103486	OO1	210	0.01
103486	S1	136.7	0.01
103486	SSA	56.3	0.37
103486	SA	157	0.21
103486	Q1	147.5	0.01
103486	P1	170.2	0.03
103487	M2	16.9	0.03
103487	N2	358.5	0.01
103487	K1	117.3	0.11
103487	O1	112	0.12
103487	OO1	124.6	0.02
103487	S1	313.4	0.01
103487	M1	266.1	0.01
103487	Q1	88.6	0.03
103487	P1	118.4	0.03
103487	K2	76.6	0.01
103488	M2	41.5	0.03
103488	S2	53.4	0.01
103488	N2	59	0.01
103488	K1	127.5	0.12
103488	O1	124.8	0.11
103488	M1	126.2	0.01
103488	J1	129	0.01
103488	Q1	123.4	0.02
103488	P1	127.4	0.04
103489	M2	331.1	0.02
103489	S2	342.5	0.01
103489	N2	307.7	0.01
103489	K1	105.9	0.1
103489	M4	225	0.01
103489	O1	101.1	0.1
103489	MK3	316	0.01
103489	OO1	137.1	0.01
103489	S1	0	0.01
103489	SSA	64.8	0.3
103489	SA	154.3	0.26
103489	Q1	80.1	0.02
103489	P1	102.8	0.03
103490	M2	305.1	0.06
103490	S2	301.6	0.02
103490	N2	291.6	0.01
103490	K1	82.7	0.17
103490	M4	183.7	0.01
103490	O1	71.3	0.18
103490	OO1	94.2	0.01
103490	M1	77.1	0.01
103490	J1	88.4	0.01
103490	RHO1	66.4	0.01
103490	Q1	65.7	0.04
103490	P1	81.8	0.06
103490	K2	303.2	0.01
103491	M2	47.8	0.05
103491	S2	50.1	0.01
103491	N2	33.3	0.01
103491	K1	117.7	0.23
103491	M4	299.3	0.01
103491	O1	104.6	0.21
103491	OO1	129.3	0.01
103491	M1	111.1	0.02
103491	J1	124.1	0.02
103491	RHO1	99	0.01
103491	Q1	98.1	0.04
103491	2Q1	93.2	0.01
103491	P1	116.6	0.08
103492	M2	11.9	0.06
103492	S2	3.8	0.01
103492	N2	348.2	0.01
103492	K1	100.4	0.2
103492	M4	273.3	0.01
103492	O1	89.8	0.22
103492	MK3	359.4	0.01
103492	2N2	235	0.01
103492	OO1	111	0.02
103492	S1	193.4	0.01
103492	J1	81.2	0.01
103492	RHO1	57.5	0.01
103492	Q1	68.4	0.05
103492	2Q1	319.1	0.01
103492	P1	104.2	0.06
103492	2MK3	329.8	0.01
103492	K2	29.2	0.01
103493	M2	75.8	0.04
103493	S2	1.8	0.01
103493	N2	24.8	0.01
103493	K1	144.1	0.18
103493	M4	335.4	0.01
103493	O1	120.6	0.18
103493	MU2	306.8	0.01
103493	OO1	150.2	0.02
103493	LDA2	316.2	0.01
103493	S1	194.2	0.1
103493	M1	44.9	0.01
103493	J1	226.6	0.01
103493	SSA	52.8	0.46
103493	SA	138.5	0.31
103493	RHO1	271.5	0.01
103493	Q1	112.2	0.03
103493	T2	108.6	0.01
103493	R2	30.4	0.01
103493	P1	166.6	0.1
103493	K2	63.6	0.02
103494	M2	15.5	0.06
103494	S2	3.2	0.01
103494	N2	349.7	0.01
103494	K1	106.4	0.2
103494	M4	268.7	0.01
103494	O1	93.7	0.21
103494	MK3	355.6	0.01
103494	OO1	115.3	0.02
103494	S1	182.4	0.02
103494	M1	173.4	0.01
103494	J1	69.5	0.01
103494	SSA	61.5	0.21
103494	SA	159.7	0.21
103494	RHO1	76.5	0.01
103494	Q1	73.3	0.04
103494	2Q1	228.4	0.01
103494	P1	110.3	0.06
103494	2MK3	350.7	0.01
103494	K2	19	0.01
103495	M2	255.3	0.16
103495	S2	262	0.05
103495	N2	237.3	0.04
103495	K1	38.7	0.31
103495	M4	106.2	0.01
103495	O1	31.9	0.31
103495	MK3	123.8	0.01
103495	S4	251.7	0.01
103495	MN4	70.7	0.01
103495	NU2	246.1	0.01
103495	MU2	204.7	0.01
103495	2N2	200.7	0.01
103495	OO1	74.3	0.01
103495	S1	20.8	0.01
103495	M1	46.7	0.02
103495	J1	43.3	0.02
103495	SSA	55.1	0.37
103495	SA	161.7	0.23
103495	RHO1	32.6	0.01
103495	Q1	15.3	0.07
103495	T2	267.3	0.01
103495	2Q1	354.5	0.01
103495	P1	37.3	0.1
103495	M3	47.4	0.01
103495	L2	300.4	0.01
103495	2MK3	98.2	0.01
103495	K2	356.6	0.01
103495	MS4	113	0.01
103496	M2	251.3	0.24
103496	S2	258.9	0.07
103496	N2	233	0.06
103496	K1	28.4	0.42
103496	M4	97.2	0.02
103496	O1	20.8	0.42
103496	MK3	113.7	0.02
103496	S4	251.8	0.01
103496	MN4	58.7	0.01
103496	NU2	236.3	0.01
103496	MU2	192.7	0.01
103496	2N2	210.4	0.01
103496	OO1	49.5	0.02
103496	S1	318.8	0.02
103496	M1	37.4	0.02
103496	J1	36.2	0.03
103496	SSA	53.6	0.38
103496	SA	166	0.19
103496	MF	19.8	0.07
103496	RHO1	13.4	0.02
103496	Q1	6.1	0.09
103496	T2	273	0.01
103496	2Q1	345	0.01
103496	P1	29.1	0.13
103496	M3	44.4	0.01
103496	L2	297	0.01
103496	2MK3	94.8	0.02
103496	K2	338.9	0.01
103496	MS4	106.7	0.01
103497	M2	57.6	0.05
103497	S2	356.4	0.01
103497	N2	31.5	0.01
103497	K1	131.6	0.21
103497	O1	110.9	0.21
103497	MK3	54.7	0.01
103497	NU2	71.5	0.01
103497	2N2	169.2	0.01
103497	OO1	133.5	0.02
103497	S1	184.9	0.07
103497	M1	214.1	0.01
103497	J1	107.5	0.01
103497	MM	28.4	0.09
103497	SSA	57.9	0.38
103497	SA	148.8	0.24
103497	RHO1	88.5	0.01
103497	Q1	93.8	0.04
103497	T2	45.5	0.01
103497	2Q1	264.4	0.01
103497	P1	138.4	0.08
103497	2MK3	53	0.01
103497	K2	47.4	0.02
103498	M2	262.3	0.29
103498	S2	264.5	0.08
103498	N2	241.2	0.07
103498	K1	26.3	0.57
103498	O1	20	0.55
103498	NU2	243.9	0.01
103498	OO1	32.6	0.02
103498	M1	36.5	0.05
103498	J1	29.5	0.04
103498	MM	353.3	0.06
103498	SSA	53.9	0.37
103498	SA	173.9	0.38
103498	MF	118.1	0.13
103498	RHO1	17.3	0.02
103498	Q1	1	0.11
103498	2Q1	13.7	0.02
103498	P1	26	0.18
103498	K2	264.5	0.02
103499	M2	352.7	0.05
103499	S2	347.9	0.01
103499	N2	339.9	0.01
103499	K1	98.4	0.19
103499	M4	215.3	0.01
103499	O1	87.8	0.21
103499	OO1	107.5	0.02
103499	S1	279.7	0.01
103499	M1	343.8	0.01
103499	J1	111.2	0.01
103499	SSA	58.2	0.33
103499	SA	146	0.09
103499	RHO1	60.6	0.01
103499	Q1	76	0.05
103499	2Q1	251.8	0.01
103499	P1	101.1	0.05
103499	K2	43	0.01
103500	M2	16.6	0.06
103500	S2	338.1	0.02
103500	N2	356	0.01
103500	K1	107	0.2
103500	M4	276.9	0.01
103500	O1	92.6	0.22
103500	MK3	12.5	0.01
103500	OO1	107.3	0.02
103500	S1	172.1	0.04
103500	M1	115.7	0.01
103500	J1	98.8	0.01
103500	MM	28.4	0.09
103500	SSA	57.9	0.38
103500	SA	148.8	0.24
103500	RHO1	76.1	0.01
103500	Q1	77.7	0.04
103500	R2	9.2	0.01
103500	P1	114.8	0.07
103500	2MK3	350.6	0.01
103500	K2	33.8	0.01
103501	M2	20.3	0.05
103501	S2	14.3	0.02
103501	N2	5.4	0.01
103501	K1	107.9	0.2
103501	O1	95.2	0.21
103501	OO1	120.9	0.03
103501	S1	326.5	0.01
103501	M1	323.1	0.01
103501	J1	104.8	0.01
103501	SSA	58.1	0.34
103501	SA	178.9	0.08
103501	RHO1	85.6	0.01
103501	Q1	84.3	0.05
103501	2Q1	250.7	0.01
103501	P1	114.9	0.06
103501	K2	36.2	0.01
103502	M2	30	0.02
103502	S2	27.4	0.01
103502	K1	116.5	0.12
103502	O1	107	0.12
103502	OO1	123.3	0.01
103502	S1	13.2	0.04
103502	M1	112	0.01
103502	SSA	51.4	0.38
103502	SA	191.4	0.21
103502	RHO1	107	0.01
103502	Q1	91.7	0.02
103502	2Q1	41.8	0.01
103502	P1	118.7	0.03
103502	K2	49.2	0.01
103503	M2	260	0.26
103503	S2	268.6	0.07
103503	N2	240.2	0.06
103503	K1	24.9	0.49
103503	M4	111.1	0.02
103503	O1	16.9	0.5
103503	S4	260.3	0.01
103503	MN4	71.5	0.01
103503	NU2	242	0.01
103503	MU2	187.1	0.01
103503	2N2	226.3	0.01
103503	OO1	47.3	0.02
103503	S1	270.5	0.01
103503	M1	24	0.02
103503	J1	28.1	0.03
103503	SSA	61	0.32
103503	SA	173.3	0.26
103503	RHO1	6.9	0.02
103503	Q1	1.9	0.12
103503	T2	278.1	0.01
103503	2Q1	349.1	0.01
103503	P1	29.3	0.15
103503	M3	48.6	0.01
103503	L2	314.7	0.01
103503	2MK3	65.3	0.01
103503	K2	265.8	0.02
103503	MS4	118.6	0.01
103504	M2	256.8	0.24
103504	S2	270	0.07
103504	N2	235.1	0.06
103504	K1	24.4	0.44
103504	M4	116.4	0.02
103504	O1	17.7	0.44
103504	MK3	117.3	0.01
103504	S4	260.8	0.01
103504	MN4	76.3	0.01
103504	NU2	239	0.01
103504	MU2	189.4	0.01
103504	OO1	35.4	0.02
103504	LDA2	276.7	0.01
103504	S1	248.2	0.02
103504	M1	42.7	0.03
103504	J1	21.7	0.02
103504	SSA	61	0.32
103504	SA	173.3	0.26
103504	RHO1	27.3	0.02
103504	Q1	7.7	0.1
103504	T2	333.9	0.01
103504	R2	53	0.01
103504	2Q1	341.2	0.02
103504	P1	36.4	0.14
103504	M3	40.4	0.01
103504	L2	327.1	0.01
103504	K2	295.3	0.02
103505	M2	41.6	0.05
103505	S2	17.1	0.01
103505	N2	10.2	0.01
103505	K1	107.4	0.17
103505	O1	101.6	0.18
103505	NU2	355.5	0.01
103505	2N2	86.4	0.01
103505	OO1	100.2	0.01
103505	S1	229.9	0.02
103505	M1	167.9	0.01
103505	J1	84.1	0.01
103505	SSA	58.8	0.23
103505	SA	196.1	0.18
103505	Q1	87.9	0.03
103505	2Q1	159.5	0.01
103505	P1	122.9	0.05
103505	2MK3	352.7	0.01
103505	K2	19.6	0.02
103506	M2	265.1	0.18
103506	S2	271.8	0.05
103506	N2	247.2	0.05
103506	K1	35.4	0.42
103506	O1	28.1	0.43
103506	MK3	77.6	0.01
103506	NU2	255.7	0.01
103506	MU2	188.5	0.01
103506	2N2	226.4	0.01
103506	OO1	46.9	0.02
103506	S1	329.4	0.02
103506	M1	46.4	0.02
103506	J1	43.4	0.03
103506	SSA	53.7	0.35
103506	SA	193.9	0.2
103506	RHO1	16.9	0.02
103506	Q1	15	0.1
103506	T2	290.8	0.01
103506	2Q1	355.2	0.01
103506	P1	35.3	0.13
103506	M3	50	0.01
103506	L2	320.1	0.01
103506	2MK3	61.3	0.01
103506	K2	314.6	0.02
103507	M2	258.1	0.21
103507	S2	267.4	0.06
103507	N2	240.7	0.05
103507	K1	30.7	0.45
103507	O1	23.3	0.45
103507	MK3	63.2	0.01
103507	NU2	251.5	0.01
103507	MU2	192.6	0.01
103507	2N2	220.3	0.01
103507	OO1	43.5	0.02
103507	S1	323.7	0.02
103507	M1	43.1	0.02
103507	J1	38.4	0.03
103507	SSA	53.7	0.33
103507	SA	197.7	0.19
103507	MF	22.6	0.06
103507	RHO1	11.7	0.02
103507	Q1	10.2	0.1
103507	T2	278	0.01
103507	2Q1	351.1	0.01
103507	P1	31.8	0.14
103507	M3	38.4	0.01
103507	L2	314.5	0.01
103507	2MK3	50	0.01
103507	K2	302.3	0.02
103508	M2	258.4	0.24
103508	S2	265.1	0.07
103508	N2	234	0.06
103508	K1	28	0.52
103508	O1	21.5	0.52
103508	NU2	237.2	0.01
103508	OO1	34.5	0.02
103508	M1	24.7	0.04
103508	J1	31.2	0.04
103508	MM	202	0.06
103508	SSA	56.2	0.28
103508	SA	206.6	0.27
103508	MSF	219.6	0.03
103508	MF	321.5	0.1
103508	RHO1	18.7	0.02
103508	Q1	3.4	0.13
103508	2Q1	15	0.01
103508	P1	32.7	0.17
103508	K2	265.1	0.02
103509	M2	274.3	0.21
103509	S2	285.8	0.06
103509	N2	256.8	0.05
103509	K1	36.5	0.43
103509	O1	29	0.43
103509	MK3	110.4	0.01
103509	NU2	260.3	0.01
103509	MU2	205.5	0.01
103509	2N2	216.3	0.01
103509	OO1	57.6	0.02
103509	S1	8.7	0.01
103509	M1	58.5	0.02
103509	J1	39.6	0.03
103509	SSA	49.6	0.26
103509	SA	186.1	0.22
103509	RHO1	15.2	0.02
103509	Q1	12.6	0.09
103509	T2	287.2	0.01
103509	2Q1	4.6	0.01
103509	P1	36.3	0.13
103509	M3	78.7	0.01
103509	L2	339.4	0.01
103509	2MK3	96.1	0.01
103509	K2	312.4	0.01
103510	M2	292	0.2
103510	S2	282.1	0.05
103510	N2	277.6	0.05
103510	K1	45.2	0.41
103510	M4	127.1	0.01
103510	O1	38.2	0.41
103510	MK3	127.4	0.01
103510	MN4	90.3	0.01
103510	NU2	253	0.01
103510	MU2	226	0.01
103510	2N2	274.7	0.01
103510	OO1	43	0.02
103510	LDA2	325.3	0.01
103510	S1	250.1	0.03
103510	M1	65.5	0.03
103510	J1	37.7	0.02
103510	SSA	49.6	0.26
103510	SA	186.1	0.22
103510	RHO1	30	0.01
103510	Q1	34.2	0.09
103510	T2	314	0.02
103510	R2	255.2	0.02
103510	2Q1	353.1	0.03
103510	P1	55.4	0.12
103510	M3	93.9	0.01
103510	L2	354.7	0.01
103510	2MK3	103.4	0.01
103510	K2	309.3	0.01
103511	M2	144.4	1.59
103511	S2	138.4	0.64
103511	N2	122.7	0.37
103511	K1	210.8	1.14
103511	M4	269.9	0.01
103511	O1	194.2	0.71
103511	S4	241.6	0.01
103511	NU2	125.6	0.07
103511	MU2	150.4	0.04
103511	2N2	101	0.05
103511	OO1	227.5	0.03
103511	LDA2	141.6	0.01
103511	M1	202.6	0.05
103511	J1	219.2	0.06
103511	SSA	261	0.05
103511	SA	175.7	0.26
103511	RHO1	187	0.03
103511	Q1	185.9	0.14
103511	T2	138.6	0.04
103511	R2	138.1	0.01
103511	2Q1	177.7	0.02
103511	P1	209.6	0.38
103511	L2	166.1	0.05
103511	K2	137.9	0.17
103512	M2	143.6	1.63
103512	S2	139.6	0.66
103512	N2	122.6	0.38
103512	K1	208.9	1.16
103512	M4	313.2	0.01
103512	O1	192.2	0.69
103512	S4	230.5	0.01
103512	NU2	125.4	0.07
103512	MU2	147.5	0.04
103512	2N2	101.6	0.05
103512	OO1	225.7	0.03
103512	LDA2	141.7	0.01
103512	M1	200.6	0.05
103512	J1	217.3	0.06
103512	SSA	261	0.05
103512	SA	175.7	0.26
103512	RHO1	185	0.03
103512	Q1	183.8	0.13
103512	T2	139.8	0.04
103512	R2	139.5	0.01
103512	2Q1	175.4	0.02
103512	P1	207.7	0.38
103512	L2	164.5	0.05
103512	K2	139.3	0.18
103513	M2	144.7	1.85
103513	S2	142.6	0.78
103513	N2	125.1	0.43
103513	K1	209.3	1.16
103513	M4	251.7	0.01
103513	O1	192.7	0.71
103513	M6	52.1	0.02
103513	S4	213.6	0.01
103513	NU2	127.8	0.09
103513	MU2	146.8	0.05
103513	2N2	105.5	0.06
103513	OO1	225.9	0.03
103513	LDA2	143.7	0.01
103513	M1	201	0.05
103513	J1	217.5	0.06
103513	SA	179.3	0.23
103513	RHO1	185.5	0.03
103513	Q1	184.4	0.14
103513	T2	142.7	0.05
103513	R2	142.5	0.01
103513	2Q1	176.2	0.02
103513	P1	208	0.38
103513	L2	164.3	0.05
103513	K2	142.4	0.21
103514	M2	142.3	1.68
103514	S2	137.9	0.71
103514	N2	123.7	0.4
103514	K1	207.1	1.12
103514	M4	273.3	0.02
103514	O1	191.6	0.7
103514	NU2	126.2	0.08
103514	MU2	146.9	0.04
103514	2N2	105	0.05
103514	OO1	222.4	0.03
103514	LDA2	140.3	0.01
103514	M1	199.4	0.05
103514	J1	214.7	0.06
103514	SA	184.3	0.23
103514	RHO1	185.1	0.03
103514	Q1	184	0.13
103514	T2	138	0.04
103514	2Q1	176.3	0.02
103514	P1	205.9	0.37
103514	L2	161	0.05
103514	K2	137.5	0.19
103515	M2	143.3	1.78
103515	S2	140.4	0.74
103515	N2	123.1	0.41
103515	K1	208.4	1.11
103515	M4	255.5	0.01
103515	O1	192.6	0.7
103515	M6	62.2	0.01
103515	MK3	215.5	0.01
103515	MN4	213.1	0.01
103515	NU2	129.7	0.08
103515	MU2	92	0.05
103515	2N2	95.4	0.05
103515	OO1	241.9	0.04
103515	LDA2	134	0.01
103515	S1	329	0.02
103515	M1	225.1	0.04
103515	J1	220.9	0.06
103515	SA	180.5	0.25
103515	RHO1	184.9	0.03
103515	Q1	185.4	0.13
103515	T2	128.1	0.05
103515	R2	155.6	0.01
103515	2Q1	186.1	0.02
103515	P1	205.9	0.35
103515	2SM2	312.3	0.01
103515	M3	356.5	0.01
103515	L2	124.5	0.04
103515	2MK3	192.8	0.01
103515	K2	134.5	0.22
103515	MS4	203.2	0.01
103516	M2	144	1.68
103516	S2	141.2	0.7
103516	N2	123.7	0.39
103516	K1	208.8	1.13
103516	O1	192.3	0.69
103516	M6	343.1	0.01
103516	S4	218.8	0.01
103516	NU2	126.4	0.08
103516	MU2	146.7	0.04
103516	2N2	103.5	0.05
103516	OO1	225.3	0.03
103516	LDA2	142.7	0.01
103516	M1	200.6	0.05
103516	J1	217	0.06
103516	SSA	261	0.05
103516	SA	175.7	0.26
103516	RHO1	185.2	0.03
103516	Q1	184.1	0.13
103516	T2	141.3	0.04
103516	R2	141.1	0.01
103516	2Q1	175.8	0.02
103516	P1	207.6	0.37
103516	L2	164.2	0.05
103516	K2	141	0.19
103517	M2	142	1.64
103517	S2	138.6	0.67
103517	N2	121.7	0.38
103517	K1	207	1.09
103517	O1	191.8	0.7
103517	NU2	126.5	0.08
103517	MU2	85.4	0.06
103517	2N2	94.2	0.05
103517	OO1	244.2	0.03
103517	LDA2	141.5	0.01
103517	M1	221	0.04
103517	J1	221	0.07
103517	SSA	261	0.05
103517	SA	175.7	0.26
103517	RHO1	180.6	0.02
103517	Q1	184.4	0.12
103517	T2	131.9	0.04
103517	R2	77.4	0.01
103517	2Q1	177.2	0.02
103517	P1	203.1	0.34
103517	M3	346.8	0.01
103517	L2	132	0.03
103517	K2	130.4	0.19
103518	M2	144.4	1.66
103518	S2	140.2	0.67
103518	N2	124.1	0.39
103518	K1	208	1.1
103518	M4	282.4	0.01
103518	O1	192.7	0.71
103518	NU2	126.2	0.07
103518	MU2	84.2	0.05
103518	2N2	97.3	0.05
103518	OO1	239.5	0.04
103518	LDA2	142.4	0.01
103518	S1	312.8	0.02
103518	M1	218	0.04
103518	J1	218.4	0.07
103518	SSA	280.2	0.05
103518	SA	183.4	0.21
103518	RHO1	186.2	0.03
103518	Q1	184.4	0.13
103518	T2	128.8	0.04
103518	R2	140.1	0.01
103518	2Q1	177.5	0.02
103518	P1	203.3	0.35
103518	M3	354.2	0.01
103518	L2	148	0.05
103518	K2	133.1	0.2
103519	M2	145.5	1.69
103519	S2	141.1	0.67
103519	N2	123.7	0.4
103519	K1	207.7	1.13
103519	O1	192.3	0.72
103519	NU2	130.2	0.08
103519	MU2	88.1	0.06
103519	2N2	95.1	0.05
103519	OO1	236.9	0.04
103519	LDA2	166.4	0.01
103519	S1	314.1	0.01
103519	M1	222.6	0.04
103519	J1	219.1	0.07
103519	SA	184.4	0.22
103519	RHO1	182.1	0.03
103519	Q1	185	0.13
103519	T2	129.7	0.04
103519	R2	167.5	0.01
103519	2Q1	186.1	0.01
103519	P1	204.6	0.35
103519	M3	350.1	0.01
103519	L2	134.2	0.03
103519	K2	135.5	0.2
103520	M2	145.6	1.73
103520	S2	140.8	0.68
103520	N2	124	0.41
103520	K1	207.7	1.14
103520	O1	192.4	0.73
103520	NU2	131	0.08
103520	MU2	88.7	0.06
103520	2N2	96.7	0.05
103520	OO1	238.1	0.04
103520	LDA2	143.3	0.01
103520	S1	329.4	0.01
103520	M1	220.1	0.04
103520	J1	220	0.07
103520	SSA	282	0.06
103520	SA	181.6	0.19
103520	MF	135.8	0.02
103520	RHO1	185.8	0.03
103520	Q1	184	0.13
103520	T2	129	0.04
103520	R2	140.7	0.01
103520	2Q1	177.1	0.02
103520	P1	204.1	0.36
103520	M3	352.8	0.01
103520	L2	167.2	0.05
103520	K2	134.7	0.2
103521	M2	146.8	1.67
103521	S2	143.1	0.66
103521	N2	125.3	0.39
103521	K1	208.9	1.12
103521	M4	284.3	0.01
103521	O1	193.5	0.72
103521	S4	270.2	0.01
103521	NU2	132.2	0.08
103521	MU2	88.9	0.06
103521	2N2	97.9	0.05
103521	OO1	236.6	0.04
103521	LDA2	154.6	0.01
103521	S1	290.7	0.01
103521	M1	219	0.04
103521	J1	221.3	0.07
103521	SSA	265.5	0.04
103521	SA	177.9	0.25
103521	RHO1	186	0.03
103521	Q1	185.6	0.13
103521	T2	129.4	0.04
103521	2Q1	182.1	0.02
103521	P1	205.3	0.35
103521	2SM2	347.5	0.01
103521	M3	349.7	0.01
103521	L2	155.3	0.03
103521	K2	135.3	0.19
103522	M2	154.8	1.65
103522	S2	149.1	0.6
103522	N2	133	0.39
103522	K1	211.7	1.16
103522	M4	282.5	0.01
103522	O1	196.7	0.73
103522	NU2	137.2	0.08
103522	MU2	93.3	0.05
103522	2N2	105.5	0.05
103522	OO1	246.7	0.04
103522	LDA2	155.1	0.01
103522	S1	323.6	0.02
103522	M1	222.5	0.04
103522	J1	222.1	0.07
103522	SA	176	0.24
103522	RHO1	186	0.03
103522	Q1	187.6	0.13
103522	T2	138.7	0.03
103522	R2	113.9	0.01
103522	2Q1	188.1	0.01
103522	P1	207.8	0.37
103522	2SM2	332.4	0.01
103522	M3	357.4	0.01
103522	L2	169	0.06
103522	K2	141.4	0.17
103523	M2	156.4	1.63
103523	S2	150.8	0.58
103523	N2	133.2	0.38
103523	K1	212.4	1.16
103523	M4	288.8	0.01
103523	O1	197.2	0.73
103523	NU2	140.1	0.07
103523	MU2	94.8	0.05
103523	2N2	104.2	0.05
103523	OO1	241.2	0.04
103523	LDA2	177.7	0.01
103523	S1	307.9	0.02
103523	M1	220.7	0.04
103523	J1	226.2	0.07
103523	SA	176	0.24
103523	MF	158.4	0.02
103523	RHO1	189.1	0.03
103523	Q1	189.4	0.13
103523	T2	139.5	0.03
103523	R2	113.3	0.01
103523	2Q1	185.6	0.01
103523	P1	207.5	0.37
103523	2SM2	336.3	0.01
103523	M3	1.8	0.01
103523	L2	167.2	0.02
103523	K2	143.1	0.17
103524	M2	158.3	1.6
103524	S2	151.3	0.56
103524	N2	133.2	0.37
103524	K1	211.4	1.16
103524	M4	275.6	0.01
103524	O1	198.4	0.72
103524	S4	311.1	0.01
103524	NU2	136.5	0.07
103524	MU2	165.3	0.04
103524	2N2	108.1	0.05
103524	OO1	224.5	0.03
103524	LDA2	155	0.01
103524	M1	204.9	0.05
103524	J1	217.9	0.06
103524	SA	156.8	0.26
103524	RHO1	192.8	0.03
103524	Q1	191.9	0.14
103524	T2	151.6	0.03
103524	2Q1	185.5	0.02
103524	P1	210.5	0.38
103524	L2	183.4	0.05
103524	K2	150.7	0.15
103525	M2	163.4	1.55
103525	S2	157.5	0.51
103525	N2	139.8	0.36
103525	K1	214.6	1.14
103525	O1	199.1	0.72
103525	NU2	145.4	0.07
103525	MU2	97.3	0.05
103525	2N2	112.3	0.05
103525	OO1	245.5	0.04
103525	LDA2	194.7	0.01
103525	S1	312.5	0.02
103525	M1	226	0.04
103525	J1	223.2	0.07
103525	SSA	268.9	0.07
103525	SA	179.6	0.25
103525	MF	118.4	0.03
103525	RHO1	193.7	0.02
103525	Q1	191.3	0.13
103525	T2	148.3	0.03
103525	2Q1	182.9	0.01
103525	P1	211.5	0.36
103525	2SM2	340	0.01
103525	M3	2.6	0.01
103525	L2	176.6	0.04
103525	K2	150.4	0.15
103526	M2	168.2	1.61
103526	S2	163.8	0.49
103526	N2	143.6	0.37
103526	K1	214.8	1.17
103526	M4	274.8	0.01
103526	O1	198.9	0.73
103526	NU2	150.5	0.07
103526	MU2	103.4	0.05
103526	2N2	114.2	0.05
103526	OO1	247.7	0.04
103526	LDA2	181.6	0.01
103526	S1	326.7	0.02
103526	M1	230.2	0.04
103526	J1	227	0.07
103526	SA	190.6	0.23
103526	MF	129.3	0.03
103526	RHO1	193	0.02
103526	Q1	191.5	0.13
103526	T2	150.9	0.03
103526	2Q1	194.4	0.02
103526	P1	212.2	0.37
103526	2SM2	352.3	0.01
103526	M3	0.9	0.01
103526	L2	169.2	0.03
103526	K2	156.4	0.14
103527	M2	174.8	1.6
103527	S2	173.7	0.45
103527	N2	147.9	0.35
103527	K1	218.7	1.14
103527	M4	321.6	0.01
103527	O1	202.3	0.71
103527	M6	262.3	0.01
103527	S4	256.4	0.01
103527	NU2	151.5	0.07
103527	S6	167.8	0.01
103527	MU2	175.8	0.04
103527	2N2	121.1	0.05
103527	OO1	235.1	0.03
103527	LDA2	174.3	0.01
103527	M1	210.5	0.05
103527	J1	226.8	0.06
103527	SSA	279.1	0.1
103527	SA	191.9	0.18
103527	RHO1	195.2	0.03
103527	Q1	194.1	0.14
103527	T2	173.8	0.03
103527	2Q1	186	0.02
103527	P1	217.5	0.38
103527	L2	201.4	0.05
103527	K2	173.6	0.12
103528	M2	181.3	1.61
103528	S2	180.1	0.43
103528	N2	155	0.37
103528	K1	219.6	1.2
103528	O1	203.5	0.75
103528	NU2	160.9	0.07
103528	MU2	114.7	0.04
103528	2N2	125.4	0.05
103528	OO1	246.4	0.04
103528	LDA2	213.6	0.01
103528	S1	317.1	0.03
103528	M1	224.9	0.04
103528	J1	232.3	0.07
103528	SSA	264.6	0.07
103528	SA	198.5	0.2
103528	MF	138.1	0.04
103528	RHO1	197	0.02
103528	Q1	194.8	0.13
103528	T2	165.3	0.02
103528	2Q1	191.7	0.02
103528	P1	215.8	0.38
103528	M3	7	0.01
103528	L2	213.4	0.04
103528	K2	170.6	0.12
103529	M2	189.9	1.65
103529	S2	197.8	0.4
103529	N2	168.9	0.36
103529	K1	228.4	1.17
103529	M4	113.2	0.06
103529	O1	212.1	0.72
103529	M6	116.9	0.02
103529	MK3	198.5	0.04
103529	MN4	93.9	0.02
103529	NU2	166.5	0.07
103529	MU2	220.3	0.01
103529	2N2	147.5	0.05
103529	OO1	253.9	0.04
103529	LDA2	149.3	0.03
103529	S1	7.4	0.05
103529	M1	239.7	0.05
103529	J1	245.7	0.06
103529	RHO1	178.8	0.02
103529	Q1	208.2	0.12
103529	T2	230.2	0.02
103529	R2	173.5	0.04
103529	2Q1	179.6	0.01
103529	P1	220.2	0.33
103529	2SM2	338.2	0.01
103529	M3	312.9	0.01
103529	L2	167.1	0.07
103529	2MK3	206	0.04
103529	K2	175.4	0.14
103529	M8	74.1	0.01
103529	MS4	122.4	0.03
103530	M2	194.4	1.61
103530	S2	196.5	0.47
103530	N2	173.1	0.37
103530	K1	228.7	1.16
103530	M4	144	0.08
103530	O1	213.9	0.72
103530	M6	147.1	0.04
103530	NU2	176	0.07
103530	MU2	309	0.04
103530	2N2	151.9	0.05
103530	OO1	243.5	0.03
103530	LDA2	195.3	0.01
103530	M1	221.4	0.05
103530	J1	236	0.06
103530	RHO1	207.6	0.03
103530	Q1	206.6	0.14
103530	T2	196.4	0.03
103530	2Q1	199.2	0.02
103530	P1	227.6	0.38
103530	L2	215.7	0.05
103530	K2	196.7	0.13
103530	M8	101.4	0.01
103531	M2	195	1.66
103531	S2	200.6	0.48
103531	N2	174	0.37
103531	K1	229.5	1.15
103531	M4	146.6	0.09
103531	O1	214.2	0.73
103531	M6	148.9	0.05
103531	NU2	176.8	0.07
103531	MU2	248.2	0.02
103531	2N2	153.1	0.05
103531	OO1	244.8	0.03
103531	LDA2	197.4	0.01
103531	M1	221.9	0.05
103531	J1	237.1	0.06
103531	SSA	264.6	0.07
103531	SA	198.5	0.2
103531	MF	138.1	0.04
103531	RHO1	207.5	0.03
103531	Q1	206.6	0.14
103531	T2	200.3	0.03
103531	2Q1	199	0.02
103531	P1	228.4	0.38
103531	L2	215.9	0.05
103531	K2	201.1	0.13
103531	M8	108	0.01
103532	M2	193	1.69
103532	S2	199.1	0.47
103532	N2	171.3	0.4
103532	K1	228.7	1.16
103532	M4	139.1	0.07
103532	O1	214.9	0.73
103532	M6	141	0.03
103532	S4	202.2	0.01
103532	NU2	174.2	0.08
103532	MU2	186.6	0.04
103532	2N2	149.7	0.05
103532	OO1	242.4	0.03
103532	LDA2	195.8	0.01
103532	M1	221.8	0.05
103532	J1	235.5	0.06
103532	RHO1	209	0.03
103532	Q1	208.1	0.14
103532	T2	198.9	0.03
103532	2Q1	201.3	0.02
103532	P1	227.6	0.38
103532	L2	214.5	0.05
103532	K2	199.6	0.13
103532	M8	78.3	0.01
103533	M2	184.1	1.78
103533	S2	189.6	0.47
103533	N2	158.4	0.39
103533	K1	217.3	1.15
103533	M4	283	0.01
103533	O1	203.3	0.74
103533	NU2	161.9	0.08
103533	S6	107.8	0.01
103533	MU2	178.7	0.04
103533	2N2	132.6	0.05
103533	OO1	231.4	0.03
103533	LDA2	186.7	0.01
103533	M1	210.4	0.05
103533	J1	224.3	0.06
103533	SSA	286.9	0.13
103533	SA	221.4	0.12
103533	RHO1	197.2	0.03
103533	Q1	196.3	0.14
103533	T2	189.3	0.03
103533	2Q1	189.3	0.02
103533	P1	216.3	0.38
103533	L2	209.8	0.05
103533	K2	190	0.13
103534	M2	208.2	1.89
103534	S2	216.2	0.45
103534	N2	183.2	0.4
103534	K1	225.4	1.21
103534	M4	136.8	0.07
103534	O1	208.4	0.75
103534	M6	7.3	0.01
103534	MK3	124.1	0.06
103534	MN4	112	0.03
103534	NU2	189.9	0.09
103534	MU2	100.2	0.02
103534	2N2	153.3	0.04
103534	OO1	260	0.04
103534	LDA2	214.3	0.02
103534	S1	282.6	0.02
103534	M1	237.5	0.04
103534	J1	244.3	0.06
103534	SSA	272.3	0.1
103534	SA	200.2	0.14
103534	MF	153.1	0.05
103534	RHO1	200	0.03
103534	Q1	202.4	0.13
103534	T2	204.6	0.03
103534	2Q1	208.6	0.02
103534	P1	222.1	0.37
103534	2SM2	37.3	0.01
103534	M3	37.6	0.01
103534	L2	229.6	0.06
103534	2MK3	92.2	0.05
103534	K2	206	0.13
103534	MS4	149	0.03
103535	M2	213.3	1.99
103535	S2	220.7	0.46
103535	N2	187	0.42
103535	K1	226.8	1.23
103535	M4	135.9	0.1
103535	O1	209.7	0.76
103535	MK3	124	0.09
103535	MN4	108.6	0.04
103535	NU2	191.6	0.09
103535	MU2	88.1	0.02
103535	2N2	154.1	0.05
103535	OO1	262.7	0.04
103535	LDA2	215	0.03
103535	S1	276.5	0.02
103535	M1	248.5	0.04
103535	J1	248.5	0.06
103535	SSA	286.9	0.13
103535	SA	221.4	0.12
103535	RHO1	198.4	0.03
103535	Q1	202.7	0.13
103535	T2	201.8	0.03
103535	2Q1	186.3	0.02
103535	P1	223.8	0.39
103535	M3	29.8	0.03
103535	L2	225.5	0.06
103535	2MK3	91.5	0.06
103535	K2	211.5	0.13
103535	MS4	147.1	0.04
103536	M2	218.9	2.11
103536	S2	227.2	0.47
103536	N2	193.5	0.44
103536	K1	229.5	1.25
103536	M4	135.2	0.08
103536	O1	212.8	0.76
103536	M6	70.7	0.02
103536	MK3	118.8	0.08
103536	MN4	110	0.03
103536	NU2	199	0.09
103536	MU2	76.7	0.02
103536	2N2	160.1	0.05
103536	OO1	263.6	0.05
103536	LDA2	204.9	0.03
103536	S1	273.2	0.02
103536	M1	254.4	0.04
103536	J1	255.6	0.06
103536	SSA	286.9	0.13
103536	SA	221.4	0.12
103536	RHO1	202.5	0.03
103536	Q1	207.3	0.13
103536	T2	217.9	0.03
103536	2Q1	182.6	0.01
103536	P1	227.1	0.39
103536	2SM2	48.4	0.02
103536	M3	37.6	0.03
103536	L2	226.4	0.08
103536	2MK3	86.1	0.07
103536	K2	217.3	0.15
103536	MS4	150.5	0.03
103537	M2	223.6	2.316
103537	S2	236.5	0.535
103537	N2	199.5	0.482
103537	K1	232.1	1.293
103537	M4	141	0.062
103537	O1	214.8	0.768
103537	M6	59.7	0.023
103537	MK3	113.3	0.075
103537	MN4	112.9	0.02
103537	NU2	198.4	0.105
103537	MU2	41.3	0.02
103537	2N2	172.9	0.046
103537	OO1	275	0.043
103537	LDA2	217.5	0.043
103537	S1	271.5	0.039
103537	M1	254	0.049
103537	J1	265.5	0.066
103537	SSA	286.9	0.128
103537	SA	221.4	0.125
103537	RHO1	177.1	0.043
103537	Q1	215.7	0.144
103537	T2	181.5	0.033
103537	R2	250.8	0.02
103537	2Q1	242.2	0.02
103537	P1	231.1	0.407
103537	2SM2	69.1	0.016
103537	M3	43.3	0.026
103537	L2	224.9	0.102
103537	2MK3	81.5	0.079
103537	K2	216.2	0.148
103537	MS4	173.6	0.023
103538	M2	235.5	2.47
103538	S2	246.6	0.54
103538	N2	213.4	0.51
103538	K1	238.3	1.31
103538	M4	179	0.03
103538	O1	221.7	0.79
103538	M6	79.3	0.02
103538	MK3	115.2	0.07
103538	MN4	149.3	0.01
103538	NU2	193.3	0.11
103538	MU2	45.1	0.03
103538	2N2	194.1	0.05
103538	OO1	290.6	0.04
103538	LDA2	187.4	0.01
103538	S1	280.6	0.06
103538	M1	267	0.05
103538	J1	271.9	0.06
103538	SSA	286.9	0.13
103538	SA	221.4	0.12
103538	RHO1	195	0.04
103538	Q1	219.9	0.14
103538	T2	196.7	0.04
103538	R2	23.9	0.04
103538	2Q1	229	0.02
103538	P1	237.5	0.4
103538	2SM2	31.3	0.02
103538	M3	42.7	0.03
103538	L2	233.9	0.13
103538	2MK3	86.5	0.09
103538	K2	228.6	0.17
103539	M2	238	2.71
103539	S2	253.3	0.6
103539	N2	216	0.54
103539	K1	239.5	1.32
103539	M4	340.4	0.04
103539	O1	223.9	0.79
103539	M6	48.2	0.03
103539	MK3	83	0.07
103539	MN4	318.3	0.02
103539	NU2	216.5	0.13
103539	MU2	9	0.06
103539	2N2	199.1	0.06
103539	OO1	281.7	0.05
103539	LDA2	218.6	0.06
103539	S1	229	0.04
103539	M1	274.4	0.05
103539	J1	275.4	0.07
103539	SSA	286.9	0.13
103539	SA	221.4	0.12
103539	MF	139.6	0.04
103539	RHO1	217.3	0.03
103539	Q1	221.4	0.14
103539	T2	225.9	0.03
103539	R2	47.5	0.01
103539	2Q1	236.1	0.02
103539	P1	238.8	0.41
103539	2SM2	56.2	0.03
103539	L2	233.2	0.12
103539	2MK3	65.7	0.11
103539	K2	238.9	0.2
103539	MS4	3	0.03
103540	M2	241.7	2.86
103540	S2	259.8	0.63
103540	N2	219.8	0.59
103540	K1	240.9	1.36
103540	M4	2.1	0.04
103540	O1	225.1	0.81
103540	M6	55.3	0.04
103540	MK3	93	0.1
103540	MN4	13	0.02
103540	NU2	227.5	0.12
103540	MU2	11	0.07
103540	2N2	208.2	0.04
103540	OO1	279.2	0.04
103540	LDA2	216	0.06
103540	S1	222.6	0.05
103540	M1	268.3	0.05
103540	J1	282.5	0.06
103540	SSA	286.9	0.13
103540	SA	221.4	0.12
103540	RHO1	195.3	0.03
103540	Q1	225.9	0.15
103540	T2	234	0.04
103540	R2	260.6	0.01
103540	2Q1	214.8	0.02
103540	P1	237.4	0.42
103540	2SM2	47.4	0.03
103540	M3	3.8	0.03
103540	L2	229.5	0.18
103540	2MK3	77.5	0.13
103540	K2	238.1	0.2
103540	M8	119.2	0.01
103540	MS4	7.1	0.03
103541	M2	246.7	3.04
103541	S2	264.2	0.65
103541	N2	225.6	0.59
103541	K1	244	1.38
103541	M4	10.2	0.06
103541	O1	228.9	0.81
103541	M6	49.9	0.06
103541	MK3	95.6	0.1
103541	MN4	356.7	0.03
103541	NU2	226.8	0.14
103541	MU2	25.7	0.07
103541	2N2	199.6	0.07
103541	OO1	283.2	0.04
103541	LDA2	212.2	0.04
103541	S1	218.3	0.07
103541	M1	272.4	0.05
103541	J1	281.9	0.06
103541	SSA	286.9	0.13
103541	SA	221.4	0.12
103541	RHO1	215.5	0.04
103541	Q1	228.1	0.15
103541	T2	249.3	0.03
103541	R2	264.9	0.01
103541	2Q1	215.9	0.03
103541	P1	240.8	0.45
103541	2SM2	75	0.03
103541	M3	354.4	0.02
103541	L2	237.1	0.19
103541	2MK3	80.6	0.15
103541	K2	244.6	0.24
103541	M8	105.8	0.01
103541	MS4	23.3	0.04
103542	M2	237.2	2.9
103542	S2	254.8	0.66
103542	N2	216.8	0.59
103542	K1	240	1.33
103542	M4	316.8	0.07
103542	O1	224.5	0.78
103542	M6	43.9	0.03
103542	MK3	73.1	0.06
103542	MN4	300.2	0.03
103542	NU2	216.4	0.13
103542	MU2	353.2	0.07
103542	2N2	199.9	0.06
103542	OO1	288.1	0.04
103542	LDA2	215.3	0.06
103542	S1	223.8	0.05
103542	M1	272.8	0.05
103542	J1	276	0.07
103542	SSA	265.9	0.07
103542	SA	181.7	0.18
103542	MF	149.6	0.06
103542	RHO1	222.6	0.03
103542	Q1	222.1	0.14
103542	T2	222.6	0.03
103542	R2	58.6	0.02
103542	2Q1	217.8	0.02
103542	P1	239.3	0.41
103542	2SM2	57.8	0.03
103542	M3	127.9	0.02
103542	L2	233.6	0.16
103542	2MK3	60.2	0.12
103542	K2	239.1	0.21
103542	MS4	343.4	0.04
103543	M2	250.1	3.13
103543	S2	273.8	0.7
103543	N2	232.7	0.63
103543	K1	246.9	1.3
103543	M4	1.6	0.16
103543	O1	232.8	0.74
103543	M6	44.1	0.07
103543	MK3	66.8	0.1
103543	S4	96.4	0.01
103543	MN4	342.8	0.07
103543	NU2	227.1	0.15
103543	MU2	357.2	0.13
103543	2N2	220.2	0.06
103543	OO1	307.7	0.04
103543	LDA2	224.2	0.08
103543	S1	214.9	0.1
103543	M1	283.5	0.06
103543	J1	300.3	0.06
103543	SSA	272.3	0.1
103543	SA	200.2	0.14
103543	RHO1	227	0.03
103543	Q1	235.1	0.13
103543	T2	229	0.04
103543	R2	43.9	0.03
103543	2Q1	246.5	0.01
103543	P1	246.1	0.4
103543	2SM2	68.9	0.04
103543	M3	146.7	0.04
103543	L2	241.2	0.22
103543	2MK3	68	0.16
103543	K2	254.3	0.22
103543	M8	96.2	0.02
103543	MS4	24.3	0.09
103544	M2	239.6	2.53
103544	S2	254.9	0.53
103544	N2	217.5	0.52
103544	K1	242.1	1.31
103544	M4	81.2	0.01
103544	O1	226.5	0.77
103544	M6	71.1	0.01
103544	MK3	95.4	0.09
103544	MN4	39.9	0.01
103544	NU2	223.7	0.14
103544	MU2	357.5	0.03
103544	2N2	175	0.08
103544	OO1	271.4	0.05
103544	LDA2	252.5	0.08
103544	S1	325.5	0.05
103544	M1	269.7	0.06
103544	J1	274.2	0.07
103544	SSA	288.3	0.12
103544	SA	227.8	0.1
103544	MF	147.5	0.04
103544	RHO1	236.1	0.03
103544	Q1	223.3	0.14
103544	T2	250.7	0.08
103544	R2	12.2	0.04
103544	2Q1	175.1	0.02
103544	P1	240.1	0.37
103544	2SM2	61.2	0.03
103544	M3	112.1	0.01
103544	L2	229.7	0.12
103544	2MK3	66.5	0.1
103544	K2	233.4	0.19
103544	MS4	50.8	0.01
103545	M2	221.5	2.19
103545	S2	234.6	0.54
103545	N2	196.4	0.44
103545	K1	229.9	1.24
103545	M4	114.5	0.08
103545	O1	215.7	0.76
103545	M6	64.2	0.01
103545	NU2	199.8	0.09
103545	MU2	208.2	0.05
103545	2N2	171.5	0.06
103545	OO1	244.1	0.03
103545	LDA2	227.6	0.02
103545	M1	222.9	0.06
103545	J1	236.9	0.06
103545	SSA	288.3	0.12
103545	SA	227.8	0.1
103545	MF	147.5	0.04
103545	RHO1	209.6	0.03
103545	Q1	208.7	0.15
103545	T2	234	0.03
103545	2Q1	201.6	0.02
103545	P1	228.8	0.41
103545	L2	246.5	0.06
103545	K2	235.7	0.15
103546	M2	223.3	2.23
103546	S2	234.4	0.5
103546	N2	199.5	0.46
103546	K1	232.7	1.24
103546	M4	138.2	0.05
103546	O1	216.2	0.76
103546	M6	32	0.02
103546	MK3	105.3	0.06
103546	MN4	119.5	0.02
103546	NU2	205.2	0.1
103546	MU2	36.1	0.03
103546	2N2	173.9	0.05
103546	OO1	276.4	0.04
103546	LDA2	217.4	0.03
103546	S1	282.4	0.04
103546	M1	256.9	0.04
103546	J1	258.3	0.06
103546	SSA	272.5	0.1
103546	SA	187.8	0.13
103546	MF	153.2	0.06
103546	RHO1	209.8	0.03
103546	Q1	211.3	0.13
103546	T2	219.7	0.03
103546	R2	68.3	0.01
103546	2Q1	215.2	0.02
103546	P1	230.1	0.38
103546	2SM2	42.8	0.02
103546	M3	121.9	0.01
103546	L2	236.7	0.1
103546	2MK3	72.4	0.07
103546	K2	222.2	0.15
103546	MS4	161.3	0.02
103547	M2	221	2.08
103547	S2	228.9	0.53
103547	N2	197.2	0.45
103547	K1	231.2	1.25
103547	M4	130	0.08
103547	O1	215.4	0.72
103547	M6	79.9	0.02
103547	NU2	200.4	0.09
103547	MU2	213.1	0.05
103547	2N2	173.4	0.06
103547	OO1	246.9	0.03
103547	LDA2	224.7	0.01
103547	M1	223.3	0.05
103547	J1	239	0.06
103547	SSA	288.3	0.12
103547	SA	227.8	0.1
103547	MF	147.5	0.04
103547	RHO1	208.5	0.03
103547	Q1	207.5	0.14
103547	T2	228.6	0.03
103547	2Q1	199.7	0.02
103547	P1	230	0.42
103547	L2	244.6	0.06
103547	K2	229.6	0.14
103548	M2	222.4	2.16
103548	S2	231.5	0.51
103548	N2	199.1	0.4
103548	K1	231.3	1.26
103548	M4	155.1	0.05
103548	O1	216.6	0.76
103548	M6	39	0.03
103548	S4	282.7	0.01
103548	NU2	202.2	0.08
103548	MU2	213.4	0.05
103548	2N2	175.7	0.05
103548	OO1	246	0.03
103548	LDA2	226.6	0.02
103548	M1	224	0.05
103548	J1	238.6	0.06
103548	SSA	288.3	0.12
103548	SA	227.8	0.1
103548	MF	147.5	0.04
103548	RHO1	210.3	0.03
103548	Q1	209.3	0.15
103548	T2	231.1	0.03
103548	2Q1	202	0.02
103548	P1	230.2	0.42
103548	L2	245.8	0.06
103548	K2	232.2	0.14
103548	M8	182.4	0.01
103549	M2	214.8	1.8
103549	S2	222	0.42
103549	N2	189.2	0.4
103549	K1	229.4	1.19
103549	M4	166.5	0.06
103549	O1	212.6	0.74
103549	M6	29.8	0.01
103549	MK3	143.8	0.05
103549	MN4	150.3	0.02
103549	NU2	198.6	0.08
103549	MU2	108.3	0.02
103549	2N2	160.1	0.04
103549	OO1	249.9	0.03
103549	LDA2	224.6	0.03
103549	S1	219.7	0.02
103549	M1	235.3	0.04
103549	J1	246.2	0.07
103549	SSA	272.3	0.1
103549	SA	200.2	0.14
103549	MF	153.1	0.05
103549	RHO1	221.7	0.02
103549	Q1	207.3	0.13
103549	T2	203.3	0.03
103549	2Q1	208	0.02
103549	P1	227.2	0.38
103549	2SM2	45.3	0.01
103549	L2	243.3	0.06
103549	2MK3	104.7	0.04
103549	K2	214.1	0.12
103549	MS4	177.7	0.03
103550	M2	300.4	1.96
103550	S2	301.2	0.37
103550	N2	274.1	0.42
103550	K1	281.2	1.04
103550	M4	161.5	0.12
103550	O1	255.8	0.52
103550	M6	337.6	0.07
103550	S4	347.5	0.01
103550	NU2	277.7	0.08
103550	MU2	55.8	0.05
103550	2N2	247.9	0.06
103550	OO1	306.7	0.02
103550	LDA2	300.8	0.01
103550	M1	268.6	0.04
103550	J1	293.9	0.04
103550	RHO1	244.9	0.02
103550	Q1	243.1	0.1
103550	T2	301.2	0.02
103550	2Q1	230.5	0.01
103550	P1	279.3	0.34
103550	L2	326.7	0.06
103550	K2	301.3	0.1
103550	M8	183.3	0.01
103551	M2	219.7	2.01
103551	S2	229.1	0.47
103551	N2	195.3	0.44
103551	K1	229.9	1.24
103551	M4	186.4	0.04
103551	O1	214.2	0.74
103551	M6	119.9	0.01
103551	S4	293.8	0.01
103551	NU2	198.5	0.09
103551	MU2	210.2	0.05
103551	2N2	170.8	0.06
103551	OO1	245.6	0.03
103551	LDA2	224.1	0.01
103551	M1	222.1	0.05
103551	J1	237.7	0.06
103551	SSA	272.3	0.1
103551	SA	200.2	0.14
103551	MF	153.1	0.05
103551	RHO1	207.3	0.03
103551	Q1	206.3	0.14
103551	T2	228.7	0.03
103551	2Q1	198.6	0.02
103551	P1	228.7	0.41
103551	L2	244.1	0.06
103551	K2	229.9	0.13
103552	M2	215.5	1.85
103552	S2	222.4	0.43
103552	N2	190	0.39
103552	K1	230.6	1.19
103552	M4	181	0.06
103552	O1	212.9	0.73
103552	M6	36.5	0.01
103552	MK3	139.9	0.04
103552	MN4	161.5	0.02
103552	NU2	199.8	0.07
103552	MU2	112.4	0.02
103552	2N2	160.4	0.04
103552	OO1	242.2	0.04
103552	LDA2	215.9	0.03
103552	S1	272.2	0.03
103552	M1	239.9	0.04
103552	J1	245.7	0.07
103552	SSA	272.3	0.1
103552	SA	200.2	0.14
103552	MF	153.1	0.05
103552	RHO1	222.3	0.02
103552	Q1	207.4	0.12
103552	T2	237.9	0.02
103552	2Q1	238.1	0.01
103552	P1	228.5	0.38
103552	2SM2	40.7	0.01
103552	L2	245.1	0.06
103552	2MK3	95.3	0.04
103552	K2	213.1	0.14
103552	MS4	192	0.03
103553	M2	222.4	1.98
103553	S2	231.4	0.45
103553	N2	197.3	0.41
103553	K1	232.6	1.2
103553	M4	224.1	0.03
103553	O1	216.4	0.73
103553	M6	75	0.02
103553	MK3	144.3	0.03
103553	MN4	197.5	0.01
103553	NU2	203.9	0.09
103553	MU2	74.3	0.03
103553	2N2	169.9	0.04
103553	OO1	272.9	0.04
103553	LDA2	223	0.03
103553	S1	266.6	0.03
103553	M1	262.3	0.04
103553	J1	252.5	0.06
103553	SSA	266.6	0.09
103553	SA	189.7	0.15
103553	MF	265	0.09
103553	RHO1	211.6	0.03
103553	Q1	211.7	0.13
103553	T2	211	0.03
103553	2Q1	215.3	0.01
103553	P1	231.6	0.37
103553	2SM2	54	0.01
103553	M3	44.1	0.01
103553	L2	230	0.07
103553	2MK3	84.5	0.05
103553	K2	223.3	0.14
103553	MS4	226.9	0.01
103554	M2	231	1.79
103554	S2	243.7	0.42
103554	N2	203.2	0.42
103554	K1	238.2	1.14
103554	M4	246.8	0.01
103554	O1	223.1	0.68
103554	M6	126.4	0.01
103554	MK3	113	0.04
103554	MN4	242.7	0.01
103554	NU2	189.9	0.1
103554	MU2	165.3	0.01
103554	2N2	201	0.07
103554	OO1	216.3	0.01
103554	LDA2	217.3	0.05
103554	S1	262.6	0.06
103554	M1	250	0.03
103554	J1	268.6	0.05
103554	SSA	272.3	0.1
103554	SA	200.2	0.14
103554	MF	153.1	0.05
103554	RHO1	243.8	0.03
103554	Q1	223.1	0.12
103554	T2	154.8	0.01
103554	R2	117	0.05
103554	2Q1	211.8	0.02
103554	P1	227.8	0.38
103554	2SM2	102.6	0.02
103554	M3	126.8	0.01
103554	L2	245.1	0.08
103554	2MK3	81.3	0.05
103554	K2	214.5	0.07
103554	MS4	305	0.01
103555	M2	217.9	1.24
103555	S2	231.5	0.27
103555	N2	191.4	0.24
103555	K1	244.7	0.89
103555	M4	351.2	0.06
103555	O1	237.1	0.45
103555	M6	13.1	0.02
103555	MK3	357.7	0.08
103555	S4	47.9	0.01
103555	MN4	344.4	0.02
103555	NU2	198.8	0.06
103555	MU2	37.9	0.05
103555	2N2	159.8	0.02
103555	OO1	318.5	0.02
103555	LDA2	207	0.02
103555	S1	299.5	0.02
103555	M1	323.8	0.03
103555	J1	311.1	0.04
103555	SSA	263.3	0.11
103555	SA	213.3	0.19
103555	RHO1	231.5	0.02
103555	Q1	257.6	0.08
103555	T2	224.7	0.02
103555	2Q1	252.2	0.01
103555	P1	246.5	0.26
103555	2SM2	31.1	0.01
103555	M3	80	0.02
103555	L2	214.2	0.06
103555	2MK3	357.2	0.07
103555	K2	203.4	0.11
103555	M8	135.4	0.01
103555	MS4	17.4	0.04
103556	M2	190.4	1.8
103556	S2	196.3	0.45
103556	N2	164.1	0.4
103556	K1	219.9	1.26
103556	O1	204.1	0.77
103556	NU2	170	0.08
103556	MU2	124.5	0.04
103556	2N2	135.3	0.05
103556	OO1	249.8	0.04
103556	LDA2	221.1	0.01
103556	S1	316.3	0.05
103556	M1	227.2	0.04
103556	J1	233.8	0.08
103556	SSA	263.3	0.11
103556	SA	213.3	0.19
103556	RHO1	198.4	0.03
103556	Q1	196.7	0.14
103556	T2	189.4	0.02
103556	2Q1	197.9	0.02
103556	P1	215	0.39
103556	M3	10.8	0.01
103556	L2	219.7	0.03
103556	K2	187	0.12
103557	M2	29.8	1.12
103557	S2	50.9	0.21
103557	N2	10.8	0.2
103557	K1	330.7	0.65
103557	M4	326.6	0.05
103557	O1	326	0.44
103557	M6	155.4	0.05
103557	S4	45.1	0.01
103557	NU2	13.3	0.04
103557	MU2	8.2	0.03
103557	2N2	351.8	0.03
103557	OO1	335.3	0.02
103557	LDA2	39.7	0.01
103557	M1	328.3	0.03
103557	J1	332.9	0.04
103557	MM	34.4	0.05
103557	SSA	264.8	0.14
103557	SA	144.6	0.09
103557	MSF	18.1	0.1
103557	MF	184.3	0.13
103557	RHO1	324.4	0.02
103557	Q1	323.8	0.09
103557	T2	50.5	0.01
103557	2Q1	320.8	0.01
103557	P1	330.3	0.21
103557	L2	48.6	0.03
103557	K2	52.7	0.06
103558	M2	239.4	2.1
103558	S2	253.2	0.51
103558	N2	213.6	0.42
103558	K1	239.3	1.2
103558	M4	36.2	0.01
103558	O1	225.6	0.73
103558	M6	97.5	0.03
103558	S4	5.4	0.01
103558	NU2	217	0.08
103558	MU2	225.4	0.05
103558	2N2	187.7	0.06
103558	OO1	252.9	0.03
103558	LDA2	245.8	0.01
103558	M1	232.5	0.05
103558	J1	246	0.06
103558	SSA	286.9	0.13
103558	SA	221.4	0.12
103558	RHO1	219.7	0.03
103558	Q1	218.9	0.14
103558	T2	252.6	0.03
103558	2Q1	212.1	0.02
103558	P1	238.2	0.4
103558	L2	265.1	0.06
103558	K2	254.3	0.14
103559	M2	318.1	1.31
103559	S2	325.1	0.22
103559	N2	293.6	0.24
103559	K1	298.1	0.76
103559	M4	166.3	0.06
103559	O1	278.5	0.42
103559	M6	328	0.05
103559	MK3	170	0.1
103559	MN4	143.3	0.02
103559	NU2	297.3	0.07
103559	MU2	129.8	0.07
103559	2N2	246.4	0.02
103559	OO1	342.8	0.02
103559	LDA2	300.5	0.03
103559	S1	118.2	0.03
103559	J1	37.3	0.01
103559	SSA	285	0.2
103559	RHO1	280.5	0.04
103559	Q1	290.3	0.07
103559	2Q1	316.4	0.01
103559	P1	283.8	0.22
103559	2SM2	154	0.02
103559	M3	258.8	0.03
103559	L2	350.5	0.1
103559	2MK3	159.2	0.11
103559	K2	311	0.1
103559	MS4	193	0.03
103560	M2	270.2	1.75
103560	S2	287.7	0.31
103560	N2	249.3	0.32
103560	K1	261.7	0.97
103560	M4	54.9	0.03
103560	O1	245.7	0.53
103560	M6	194.2	0.02
103560	NU2	252.2	0.06
103560	MU2	252.8	0.04
103560	2N2	228.5	0.04
103560	OO1	277.7	0.02
103560	LDA2	278.4	0.01
103560	M1	253.7	0.04
103560	J1	269.7	0.04
103560	SSA	285.7	0.2
103560	RHO1	238.8	0.02
103560	Q1	237.7	0.1
103560	T2	287	0.02
103560	2Q1	229.8	0.01
103560	P1	260.5	0.32
103560	L2	291.1	0.05
103560	K2	289.1	0.09
103561	M2	26.2	1.03
103561	S2	47.1	0.19
103561	N2	8.2	0.19
103561	K1	328.9	0.65
103561	M4	312.2	0.03
103561	O1	324	0.43
103561	M6	117.6	0.02
103561	S4	17.6	0.01
103561	NU2	10.6	0.04
103561	MU2	5.3	0.03
103561	2N2	350.1	0.03
103561	OO1	333.9	0.02
103561	LDA2	36.1	0.01
103561	M1	326.6	0.03
103561	J1	331.3	0.04
103561	MM	34.4	0.05
103561	SSA	264.8	0.14
103561	SA	144.6	0.09
103561	MSF	18.1	0.1
103561	MF	184.3	0.13
103561	RHO1	322.1	0.02
103561	Q1	321.6	0.08
103561	T2	46	0.01
103561	2Q1	320.4	0.01
103561	P1	328.6	0.21
103561	L2	44.3	0.03
103561	K2	48.7	0.05
103562	M2	302.2	1.43
103562	S2	317.4	0.28
103562	N2	277.1	0.27
103562	K1	282.8	0.85
103562	M4	142.5	0.05
103562	O1	267.2	0.51
103562	M6	279.7	0.03
103562	MK3	156.4	0.09
103562	MN4	132	0.01
103562	NU2	288.4	0.07
103562	MU2	104.9	0.07
103562	OO1	354.3	0.03
103562	LDA2	285	0.04
103562	S1	306.3	0.04
103562	M1	8	0.06
103562	SSA	285.7	0.2
103562	RHO1	263.3	0.02
103562	Q1	277.6	0.08
103562	T2	298	0.02
103562	2Q1	215.8	0.02
103562	P1	283	0.23
103562	2SM2	117.2	0.02
103562	M3	216.4	0.01
103562	L2	300.4	0.09
103562	2MK3	142.9	0.14
103562	K2	306.7	0.13
103562	MS4	158.3	0.03
103563	M2	257.5	1.97
103563	S2	271.3	0.41
103563	N2	232.5	0.37
103563	K1	251.8	1.1
103563	M4	346.7	0.06
103563	O1	234.4	0.66
103563	M6	135.1	0.04
103563	MK3	101.7	0.05
103563	MN4	328.4	0.02
103563	NU2	243.2	0.09
103563	MU2	63.4	0.06
103563	2N2	206	0.05
103563	OO1	308.1	0.03
103563	LDA2	247.7	0.05
103563	S1	261.2	0.06
103563	M1	271.1	0.04
103563	J1	287.4	0.03
103563	SSA	259.8	0.1
103563	SA	223.9	0.16
103563	RHO1	233.1	0.03
103563	Q1	239	0.1
103563	T2	241.3	0.03
103563	R2	182.3	0.02
103563	2Q1	280.3	0.01
103563	P1	254.7	0.29
103563	2SM2	97.1	0.02
103563	M3	174.2	0.03
103563	L2	280.6	0.14
103563	2MK3	90.2	0.1
103563	K2	257.9	0.16
103563	MS4	27.1	0.02
103564	M2	283.2	1.63
103564	S2	298.1	0.32
103564	N2	258.8	0.31
103564	K1	271	0.9
103564	M4	125	0.04
103564	O1	255.4	0.52
103564	M6	250.4	0.04
103564	MK3	128.8	0.1
103564	MN4	104	0.01
103564	NU2	268.3	0.08
103564	MU2	90.5	0.07
103564	2N2	236.6	0.03
103564	OO1	328.5	0.02
103564	LDA2	279.2	0.04
103564	S1	298.3	0.04
103564	M1	350.5	0.03
103564	J1	349.9	0.01
103564	MM	34.4	0.05
103564	SSA	264.8	0.14
103564	SA	144.6	0.09
103564	MSF	18.1	0.1
103564	MF	184.3	0.13
103564	RHO1	247.7	0.03
103564	Q1	263.4	0.08
103564	T2	265.1	0.02
103564	R2	172.7	0.01
103564	2Q1	264.9	0.01
103564	P1	269.9	0.26
103564	2SM2	123	0.02
103564	M3	210.1	0.02
103564	L2	298.9	0.11
103564	2MK3	118.6	0.14
103564	K2	287.8	0.15
103564	MS4	150.8	0.03
103565	M2	358.3	0.93
103565	S2	22.7	0.19
103565	N2	338.5	0.16
103565	K1	319.8	0.69
103565	M4	231.3	0.04
103565	O1	309.6	0.45
103565	M6	2.1	0.03
103565	S4	311.8	0.01
103565	NU2	341.2	0.03
103565	MU2	333.9	0.02
103565	2N2	318.6	0.02
103565	OO1	329.7	0.02
103565	LDA2	9.7	0.01
103565	M1	314.7	0.03
103565	J1	324.9	0.03
103565	MM	34.4	0.05
103565	SSA	264.8	0.14
103565	SA	144.6	0.09
103565	MSF	18.1	0.1
103565	MF	184.3	0.13
103565	RHO1	305.5	0.02
103565	Q1	304.6	0.09
103565	T2	21.8	0.01
103565	2Q1	298.2	0.01
103565	P1	319	0.23
103565	L2	18.2	0.03
103565	K2	24.5	0.05
103566	M2	260.6	1.96
103566	S2	273.5	0.42
103566	N2	233.8	0.39
103566	K1	253.7	1.1
103566	M4	30.8	0.04
103566	O1	237.2	0.66
103566	M6	147.3	0.03
103566	MK3	117.2	0.06
103566	MN4	347.1	0.01
103566	NU2	237	0.08
103566	MU2	66.7	0.05
103566	2N2	206.8	0.05
103566	OO1	296.4	0.04
103566	LDA2	264.4	0.04
103566	S1	228.9	0.05
103566	M1	327.6	0.05
103566	J1	288	0.05
103566	SSA	259.8	0.1
103566	SA	223.9	0.16
103566	RHO1	230.1	0.03
103566	Q1	234.3	0.1
103566	T2	273.4	0.03
103566	2Q1	220.7	0.02
103566	P1	258.2	0.32
103566	2SM2	93.6	0.01
103566	M3	162	0.02
103566	L2	271.2	0.08
103566	2MK3	92.7	0.1
103566	K2	265.6	0.17
103566	MS4	65.7	0.03
103567	M2	15	0.95
103567	S2	31.9	0.17
103567	N2	356.7	0.17
103567	K1	323.5	0.63
103567	M4	267.9	0.02
103567	O1	317.8	0.42
103567	M6	52.2	0.03
103567	NU2	359.1	0.03
103567	MU2	357.7	0.02
103567	2N2	338.4	0.02
103567	OO1	329.2	0.02
103567	LDA2	23	0.01
103567	M1	320.8	0.03
103567	J1	326.1	0.03
103567	MM	34.4	0.05
103567	SSA	264.8	0.14
103567	SA	144.6	0.09
103567	MSF	18.1	0.1
103567	MF	184.3	0.13
103567	RHO1	315.5	0.02
103567	Q1	315.1	0.08
103567	T2	31.5	0.01
103567	2Q1	313.4	0.01
103567	P1	323	0.21
103567	L2	33.3	0.03
103567	K2	33.2	0.05
103568	M2	257.7	2.03
103568	S2	273.2	0.39
103568	N2	235.8	0.35
103568	K1	256.8	1.13
103568	M4	73.5	0.13
103568	O1	237.9	0.66
103568	M6	179.4	0.03
103568	NU2	238.7	0.07
103568	S6	302.2	0.01
103568	MU2	241.8	0.05
103568	2N2	213.9	0.05
103568	OO1	275.6	0.03
103568	LDA2	265.1	0.01
103568	M1	247.4	0.05
103568	J1	266.1	0.05
103568	SSA	259.8	0.1
103568	SA	223.9	0.16
103568	RHO1	229.7	0.02
103568	Q1	228.5	0.13
103568	T2	272.6	0.02
103568	2Q1	218.8	0.02
103568	P1	255.4	0.37
103568	L2	279.8	0.06
103568	K2	274.3	0.11
103568	M8	53.3	0.01
103569	M2	289.4	1.66
103569	S2	303	0.32
103569	N2	264.1	0.31
103569	K1	273.7	0.98
103569	M4	140.2	0.08
103569	O1	257.5	0.55
103569	M6	246.7	0.03
103569	MK3	135.5	0.12
103569	MN4	113.7	0.03
103569	NU2	267.5	0.08
103569	MU2	85.8	0.07
103569	2N2	262.1	0.06
103569	OO1	321.3	0.03
103569	LDA2	285.3	0.05
103569	M1	307.5	0.04
103569	SSA	339.3	0.2
103569	RHO1	239.9	0.02
103569	Q1	259.8	0.09
103569	P1	282.8	0.26
103569	2SM2	129.3	0.02
103569	M3	203.5	0.05
103569	L2	285	0.16
103569	2MK3	125.4	0.16
103569	K2	290.2	0.17
103569	MS4	155.9	0.04
103570	M2	338.5	1.21
103570	S2	355.9	0.22
103570	N2	304.3	0.22
103570	K1	302.5	0.73
103570	M4	213	0.09
103570	O1	294.2	0.36
103570	M6	17.3	0.03
103570	MK3	199.8	0.1
103570	S4	238.6	0.01
103570	MN4	191.8	0.03
103570	NU2	333.2	0.03
103570	MU2	151.5	0.07
103570	2N2	311.7	0.03
103570	OO1	62.5	0.01
103570	LDA2	326.5	0.05
103570	S1	267.7	0.08
103570	M1	209.4	0.01
103570	J1	43.6	0.03
103570	SSA	285.7	0.2
103570	RHO1	287	0.02
103570	Q1	295.7	0.05
103570	T2	352.4	0.02
103570	R2	65.6	0.02
103570	2Q1	315.9	0.02
103570	P1	308.1	0.27
103570	2SM2	171.2	0.01
103570	M3	280.7	0.03
103570	L2	355.6	0.1
103570	2MK3	191.3	0.1
103570	K2	337	0.1
103570	M8	251.6	0.01
103570	MS4	240.5	0.04
103571	M2	256.6	1.78
103571	S2	277.8	0.29
103571	N2	230.9	0.32
103571	K1	256.5	0.94
103571	M4	100.9	0.16
103571	O1	253.6	0.56
103571	M6	227	0.02
103571	S4	210.4	0.01
103571	NU2	234.3	0.06
103571	MU2	236.3	0.04
103571	2N2	205.6	0.04
103571	OO1	259	0.02
103571	LDA2	265.9	0.01
103571	M1	255	0.04
103571	J1	257.9	0.04
103571	SSA	286.9	0.13
103571	SA	221.4	0.12
103571	RHO1	252.2	0.02
103571	Q1	252.2	0.11
103571	T2	276.8	0.02
103571	2Q1	250.3	0.01
103571	P1	256.2	0.31
103571	L2	282.6	0.05
103571	K2	279.6	0.08
103571	M8	68.3	0.01
103572	M2	265.1	2.28
103572	S2	284.7	0.47
103572	N2	248.6	0.39
103572	K1	263.1	1.15
103572	M4	97.8	0.09
103572	O1	244.8	0.64
103572	M6	201.3	0.05
103572	NU2	250.8	0.08
103572	S6	30.1	0.01
103572	MU2	245.6	0.06
103572	2N2	232	0.05
103572	OO1	281.4	0.03
103572	LDA2	274.2	0.02
103572	M1	253.9	0.05
103572	J1	272.2	0.05
103572	SSA	259.8	0.1
103572	SA	223.9	0.16
103572	RHO1	236.8	0.02
103572	Q1	235.8	0.12
103572	T2	284	0.03
103572	2Q1	227.5	0.02
103572	P1	261.7	0.38
103572	L2	281.9	0.06
103572	K2	286.3	0.13
103573	M2	273.3	2.34
103573	S2	299.3	0.55
103573	N2	258.2	0.44
103573	K1	264.2	1.22
103573	M4	72.1	0.07
103573	O1	253.5	0.71
103573	M6	226.6	0.07
103573	S4	151.1	0.01
103573	NU2	260.2	0.09
103573	MU2	247.5	0.06
103573	2N2	243.2	0.06
103573	OO1	273.8	0.03
103573	LDA2	285.2	0.02
103573	M1	258.7	0.05
103573	J1	268.9	0.06
103573	SSA	259.8	0.1
103573	SA	223.9	0.16
103573	RHO1	249.3	0.03
103573	Q1	248.5	0.14
103573	T2	298.2	0.03
103573	2Q1	243.7	0.02
103573	P1	263.4	0.4
103573	L2	288.3	0.07
103573	K2	301.3	0.15
103573	M8	263.5	0.01
103574	M2	193.5	1.68
103574	S2	203.7	0.4
103574	N2	165.3	0.37
103574	K1	223.2	1.12
103574	M4	28.7	0.03
103574	O1	212.6	0.7
103574	S4	41.4	0.01
103574	NU2	169.1	0.07
103574	MU2	183.3	0.04
103574	2N2	136.9	0.05
103574	OO1	233.7	0.03
103574	LDA2	198.2	0.01
103574	M1	217.9	0.05
103574	J1	228.4	0.06
103574	SSA	272.5	0.19
103574	SA	263	0.24
103574	RHO1	208.1	0.03
103574	Q1	207.4	0.13
103574	T2	203.2	0.02
103574	2Q1	202.2	0.02
103574	P1	222.4	0.37
103574	L2	221.9	0.05
103574	K2	204.5	0.11
103575	M2	195.3	1.87
103575	S2	205.3	0.46
103575	N2	169.4	0.41
103575	K1	223.4	1.22
103575	O1	208	0.76
103575	NU2	174.9	0.08
103575	MU2	133.1	0.05
103575	2N2	141.7	0.05
103575	OO1	250.5	0.04
103575	LDA2	228.7	0.01
103575	S1	327.9	0.04
103575	M1	228.7	0.05
103575	J1	236.3	0.07
103575	SSA	255.5	0.11
103575	SA	227.4	0.23
103575	RHO1	199.6	0.03
103575	Q1	197.9	0.14
103575	T2	201.3	0.02
103575	R2	155.5	0.01
103575	2Q1	201.4	0.02
103575	P1	220.4	0.38
103575	M3	357.8	0.01
103575	L2	226.2	0.04
103575	K2	195.6	0.13
103576	M2	196.6	1.98
103576	S2	211.2	0.49
103576	N2	170.9	0.42
103576	K1	222.8	1.22
103576	O1	207.1	0.77
103576	S4	305	0.01
103576	NU2	174.3	0.08
103576	MU2	181.8	0.05
103576	2N2	145.2	0.06
103576	OO1	238.6	0.03
103576	LDA2	203.4	0.01
103576	M1	215	0.06
103576	J1	230.7	0.06
103576	SSA	272.5	0.19
103576	SA	263	0.24
103576	RHO1	200.3	0.03
103576	Q1	199.3	0.15
103576	T2	210.7	0.03
103576	2Q1	191.5	0.02
103576	P1	221.7	0.4
103576	L2	222.3	0.06
103576	K2	212.4	0.13
103577	M2	200.9	1.97
103577	S2	218.3	0.49
103577	N2	174.5	0.43
103577	K1	225.6	1.2
103577	O1	208.4	0.79
103577	S4	270.5	0.01
103577	NU2	178.1	0.08
103577	MU2	183.4	0.05
103577	2N2	148.2	0.06
103577	OO1	242.8	0.03
103577	LDA2	208.9	0.01
103577	M1	217.1	0.06
103577	J1	234.1	0.06
103577	SSA	272.5	0.19
103577	SA	263	0.24
103577	RHO1	201.1	0.03
103577	Q1	199.9	0.15
103577	T2	217.6	0.03
103577	2Q1	191.4	0.02
103577	P1	224.3	0.4
103577	L2	227.2	0.06
103577	K2	219.7	0.13
103578	M2	221.7	1.89
103578	S2	230.5	0.38
103578	N2	194.2	0.37
103578	K1	248.3	1.22
103578	M4	334.5	0.04
103578	O1	226.8	0.66
103578	M6	292.3	0.01
103578	MK3	358.6	0.08
103578	S4	18.7	0.01
103578	MN4	335.2	0.02
103578	NU2	208.1	0.08
103578	MU2	1.1	0.02
103578	2N2	151.1	0.03
103578	OO1	236.3	0.01
103578	LDA2	222.3	0.01
103578	S1	107.6	0.18
103578	M1	275.2	0.05
103578	J1	273.1	0.08
103578	SSA	264.1	0.12
103578	SA	255	0.21
103578	MF	149	0.05
103578	RHO1	262.1	0.02
103578	Q1	229.8	0.1
103578	T2	81.5	0.07
103578	R2	302	0.14
103578	2Q1	141.8	0.01
103578	P1	242.8	0.47
103578	2SM2	59	0.01
103578	M3	33.9	0.02
103578	L2	223.7	0.05
103578	2MK3	355.9	0.06
103578	K2	250.1	0.14
103578	MS4	334.3	0.02
103579	M2	214.8	2.29
103579	S2	236	0.61
103579	N2	190.6	0.49
103579	K1	232.2	1.35
103579	M4	213	0.04
103579	O1	217.5	0.8
103579	M6	246	0.02
103579	S4	55.2	0.01
103579	NU2	193.8	0.09
103579	MU2	193.6	0.06
103579	2N2	166.3	0.07
103579	OO1	247	0.03
103579	LDA2	224.6	0.02
103579	M1	224.9	0.06
103579	J1	239.6	0.06
103579	SSA	264.1	0.12
103579	SA	255	0.21
103579	MF	149	0.05
103579	RHO1	211.1	0.03
103579	Q1	210.1	0.15
103579	T2	235.1	0.04
103579	2Q1	202.8	0.02
103579	P1	231.2	0.45
103579	L2	239	0.07
103579	K2	237.7	0.17
103580	M2	215.1	2.3
103580	S2	236.6	0.57
103580	N2	190.5	0.49
103580	K1	233.4	1.32
103580	M4	200.6	0.04
103580	O1	217.2	0.82
103580	M6	284.7	0.02
103580	MK3	197.5	0.02
103580	MN4	177.4	0.02
103580	NU2	194.5	0.1
103580	MU2	173	0.03
103580	2N2	164.2	0.06
103580	OO1	265.9	0.04
103580	LDA2	215.8	0.02
103580	S1	35	0.04
103580	M1	252.4	0.04
103580	J1	248.3	0.07
103580	SSA	264.1	0.12
103580	SA	255	0.21
103580	MF	149	0.05
103580	RHO1	210.3	0.03
103580	Q1	211.3	0.14
103580	T2	235.8	0.03
103580	R2	237.5	0.01
103580	2Q1	216.4	0.02
103580	P1	231.2	0.41
103580	L2	225.2	0.05
103580	K2	228.3	0.15
103580	MS4	239.1	0.02
103581	M2	220.2	2.39
103581	S2	243.7	0.63
103581	N2	198.5	0.5
103581	K1	235	1.34
103581	M4	202.6	0.09
103581	O1	221	0.79
103581	M6	294.2	0.07
103581	S4	31.9	0.01
103581	NU2	201.3	0.1
103581	S6	181	0.01
103581	MU2	196.8	0.06
103581	2N2	176.6	0.07
103581	OO1	249.1	0.03
103581	LDA2	231.1	0.02
103581	M1	228.1	0.06
103581	J1	242	0.06
103581	SSA	264.1	0.12
103581	SA	255	0.21
103581	MF	149	0.05
103581	RHO1	215	0.03
103581	Q1	214	0.15
103581	T2	242.8	0.04
103581	R2	244.3	0.01
103581	2Q1	207.1	0.02
103581	P1	234	0.44
103581	L2	242	0.07
103581	K2	245.6	0.17
103581	M8	304.8	0.01
103582	M2	231.9	1.55
103582	S2	265.4	0.35
103582	N2	229.1	0.31
103582	K1	249.6	0.83
103582	M4	44.1	0.12
103582	O1	255.5	0.54
103582	S4	188.4	0.01
103582	NU2	229.4	0.06
103582	MU2	199.9	0.04
103582	2N2	225.2	0.04
103582	OO1	245.1	0.02
103582	LDA2	247.1	0.01
103582	M1	252.5	0.04
103582	J1	247.8	0.04
103582	SSA	262.1	0.13
103582	SA	261.4	0.23
103582	MF	152	0.05
103582	RHO1	257.3	0.02
103582	Q1	257.9	0.1
103582	T2	263.9	0.02
103582	2Q1	259.4	0.01
103582	P1	249.9	0.28
103582	L2	236	0.04
103582	K2	268	0.1
103583	M2	211	2.35
103583	S2	231.7	0.6
103583	N2	185.2	0.5
103583	K1	227.8	1.28
103583	O1	212.6	0.79
103583	NU2	191.2	0.1
103583	MU2	154	0.05
103583	2N2	158.8	0.06
103583	OO1	255	0.05
103583	LDA2	230.9	0.02
103583	S1	4.3	0.03
103583	M1	242.5	0.04
103583	J1	240	0.07
103583	SSA	262.1	0.13
103583	SA	261.4	0.23
103583	MF	152	0.05
103583	RHO1	206.7	0.03
103583	Q1	205.5	0.14
103583	T2	225.8	0.03
103583	R2	232.4	0.01
103583	2Q1	204.9	0.02
103583	P1	225.2	0.4
103583	L2	235.6	0.04
103583	K2	223.6	0.17
103584	M2	216.2	2.19
103584	S2	236.9	0.55
103584	N2	190.6	0.47
103584	K1	228.7	1.21
103584	M4	157.5	0.01
103584	O1	217.4	0.73
103584	M6	164.1	0.01
103584	S4	86.3	0.01
103584	NU2	194.1	0.09
103584	MU2	195.6	0.05
103584	2N2	165.1	0.06
103584	OO1	239.9	0.03
103584	LDA2	225.8	0.02
103584	M1	223.1	0.05
103584	J1	234.3	0.06
103584	SSA	262.1	0.13
103584	SA	261.4	0.23
103584	RHO1	212.6	0.03
103584	Q1	211.8	0.14
103584	T2	236.1	0.03
103584	2Q1	206.2	0.02
103584	P1	227.8	0.4
103584	L2	241.3	0.06
103584	K2	238.7	0.15
103584	M8	165.8	0.01
103585	M2	218.9	2.4
103585	S2	241	0.65
103585	N2	193.5	0.51
103585	K1	230.1	1.32
103585	M4	242.5	0.02
103585	O1	214.2	0.85
103585	M6	205	0.01
103585	MK3	234.1	0.02
103585	S4	345.4	0.01
103585	NU2	196.8	0.1
103585	MU2	158.6	0.06
103585	2N2	165.6	0.06
103585	OO1	230.8	0.05
103585	LDA2	247.6	0.02
103585	S1	225.4	0.02
103585	M1	206.3	0.07
103585	J1	245.4	0.09
103585	SSA	262.1	0.13
103585	SA	261.4	0.23
103585	MF	152	0.05
103585	RHO1	195.8	0.04
103585	Q1	204.7	0.15
103585	T2	245.2	0.04
103585	R2	91.4	0.01
103585	2Q1	175	0.04
103585	P1	224.8	0.4
103585	M3	327.7	0.01
103585	L2	256.4	0.05
103585	2MK3	182.7	0.01
103585	K2	229.7	0.16
103586	M2	216.5	2.44
103586	S2	239	0.65
103586	N2	190.7	0.51
103586	K1	230.9	1.4
103586	O1	214.6	0.86
103586	NU2	196	0.1
103586	MU2	158.2	0.05
103586	2N2	165.9	0.06
103586	OO1	262.2	0.05
103586	LDA2	244.3	0.02
103586	S1	354.1	0.03
103586	M1	240.6	0.05
103586	J1	242.8	0.09
103586	SA	274	0.29
103586	RHO1	200.8	0.03
103586	Q1	206.5	0.15
103586	T2	231.5	0.04
103586	2Q1	201.9	0.02
103586	P1	227.4	0.43
103586	L2	240.6	0.06
103586	K2	232.7	0.17
103587	M2	299.6	1.63
103587	S2	339.6	0.35
103587	N2	281	0.28
103587	K1	295.8	0.91
103587	M4	168	0.13
103587	O1	288.7	0.62
103587	M6	161.7	0.04
103587	S4	279.6	0.02
103587	NU2	283.5	0.05
103587	MU2	259.4	0.04
103587	2N2	262.2	0.04
103587	OO1	302.6	0.03
103587	LDA2	318.1	0.01
103587	M1	292.3	0.04
103587	J1	299.2	0.05
103587	RHO1	286	0.02
103587	Q1	285.1	0.12
103587	T2	337.9	0.02
103587	2Q1	282	0.02
103587	P1	295.2	0.3
103587	L2	318	0.05
103587	K2	342.8	0.1
103587	M8	36	0.01
103588	M2	225.1	2.65
103588	S2	250.7	0.71
103588	N2	200.6	0.55
103588	K1	235.2	1.31
103588	M4	199.6	0.02
103588	O1	220.6	0.81
103588	M6	327.6	0.01
103588	MK3	190.8	0.01
103588	S4	347.6	0.01
103588	MN4	179.1	0.01
103588	NU2	203.5	0.11
103588	MU2	182.6	0.04
103588	2N2	174.2	0.06
103588	OO1	267.8	0.04
103588	LDA2	228.6	0.02
103588	S1	54	0.01
103588	M1	256.2	0.04
103588	J1	246.4	0.08
103588	SA	278.9	0.33
103588	RHO1	214.7	0.03
103588	Q1	214.3	0.14
103588	T2	243.7	0.04
103588	R2	257	0.01
103588	2Q1	216.9	0.02
103588	P1	233.5	0.41
103588	2SM2	46.4	0.01
103588	L2	234.7	0.07
103588	K2	243.8	0.19
103588	MS4	248.1	0.01
103589	M2	230.6	2.45
103589	S2	258	0.67
103589	N2	207	0.51
103589	K1	238.7	1.24
103589	O1	223.8	0.79
103589	M6	329.8	0.02
103589	S4	3.3	0.01
103589	NU2	216	0.1
103589	MU2	187.8	0.03
103589	2N2	186.1	0.06
103589	OO1	260.1	0.05
103589	LDA2	235.1	0.03
103589	S1	17.3	0.01
103589	M1	210.2	0.05
103589	J1	259.7	0.08
103589	SA	283.3	0.34
103589	MF	155.7	0.05
103589	RHO1	213.8	0.03
103589	Q1	216.3	0.14
103589	T2	257.6	0.05
103589	R2	130.3	0.04
103589	2Q1	201.2	0.03
103589	P1	232.1	0.38
103589	M3	2.2	0.01
103589	L2	253.8	0.06
103589	K2	241.1	0.19
103589	MS4	329.4	0.01
103590	M2	255.9	2.54
103590	S2	289.3	0.61
103590	N2	236	0.47
103590	K1	255.2	1.19
103590	M4	7.6	0.04
103590	O1	241.1	0.72
103590	M6	75.9	0.04
103590	S4	100.5	0.01
103590	NU2	238.7	0.09
103590	MU2	222.4	0.06
103590	2N2	216.1	0.06
103590	OO1	269.2	0.03
103590	LDA2	271.4	0.02
103590	M1	248.2	0.05
103590	J1	262.1	0.06
103590	RHO1	235.1	0.03
103590	Q1	234.2	0.14
103590	T2	288	0.04
103590	2Q1	227.3	0.02
103590	P1	254.2	0.39
103590	L2	275.6	0.07
103590	K2	292	0.16
103590	M8	216.2	0.01
103591	M2	250.5	2.56
103591	S2	286.3	0.66
103591	N2	227.9	0.45
103591	K1	250.1	1.25
103591	M4	33	0.03
103591	O1	243.1	0.75
103591	M6	66.1	0.04
103591	S4	133.1	0.01
103591	NU2	230.9	0.09
103591	MU2	214.9	0.06
103591	2N2	205	0.06
103591	OO1	257	0.03
103591	LDA2	266.9	0.02
103591	M1	246.6	0.05
103591	J1	253.5	0.06
103591	SSA	234	0.09
103591	SA	285.9	0.04
103591	MF	183	0.08
103591	RHO1	240	0.03
103591	Q1	239.6	0.14
103591	T2	284.8	0.04
103591	R2	287.7	0.01
103591	2Q1	236.4	0.02
103591	P1	249.6	0.42
103591	L2	273.1	0.07
103591	K2	289.2	0.18
103592	M2	230.8	2.57
103592	S2	261.3	0.69
103592	N2	207.3	0.53
103592	K1	237.7	1.29
103592	M4	278.9	0.03
103592	O1	223.3	0.79
103592	M6	339.6	0.01
103592	MK3	287.2	0.02
103592	S4	37.6	0.01
103592	MN4	268.4	0.01
103592	NU2	216.7	0.1
103592	MU2	207.6	0.03
103592	2N2	188.2	0.06
103592	OO1	254.4	0.05
103592	LDA2	237	0.03
103592	S1	339.1	0.05
103592	M1	222.2	0.05
103592	J1	260.7	0.08
103592	SSA	234	0.09
103592	SA	285.9	0.4
103592	MF	183	0.08
103592	RHO1	217.2	0.04
103592	Q1	219.9	0.13
103592	T2	269.4	0.05
103592	R2	161.9	0.05
103592	2Q1	211	0.03
103592	P1	227.3	0.38
103592	2SM2	136.6	0.01
103592	L2	253.1	0.07
103592	2MK3	4.6	0.01
103592	K2	241	0.21
103592	MS4	324.3	0.02
103593	M2	245.5	2.48
103593	S2	282.8	0.6
103593	N2	224.4	0.5
103593	K1	249.6	1.24
103593	M4	355.5	0.06
103593	O1	236.2	0.75
103593	M6	18.2	0.08
103593	MK3	33.3	0.03
103593	MN4	332.9	0.02
103593	NU2	217	0.1
103593	MU2	302	0.03
103593	2N2	196.9	0.06
103593	OO1	293.5	0.06
103593	LDA2	244.2	0.03
103593	S1	104.2	0.01
103593	M1	196.9	0.02
103593	J1	283.1	0.06
103593	SSA	234	0.09
103593	SA	285.9	0.4
103593	MF	183	0.08
103593	RHO1	262.4	0.04
103593	Q1	236.5	0.11
103593	T2	322.3	0.06
103593	R2	239.3	0.06
103593	2Q1	212.4	0.04
103593	P1	245.3	0.35
103593	2SM2	95.5	0.01
103593	L2	258.2	0.1
103593	2MK3	32.9	0.04
103593	K2	270	0.18
103593	M8	112.3	0.01
103593	MS4	9.6	0.04
103594	M2	235.5	2.99
103594	S2	262.1	0.74
103594	N2	214.4	0.67
103594	K1	238	1.42
103594	M4	234.7	0.05
103594	O1	224.8	0.85
103594	M6	314.8	0.03
103594	S4	258.7	0.01
103594	NU2	217.2	0.13
103594	MU2	208.9	0.07
103594	2N2	193.2	0.09
103594	OO1	251.3	0.04
103594	LDA2	247.9	0.02
103594	M1	231.5	0.06
103594	J1	244.6	0.07
103594	SSA	234	0.09
103594	SA	285.9	0.4
103594	MF	183	0.08
103594	RHO1	219.1	0.03
103594	Q1	218.3	0.16
103594	T2	261.1	0.04
103594	R2	263.2	0.01
103594	2Q1	211.7	0.02
103594	P1	237.1	0.47
103594	L2	256.7	0.08
103594	K2	264.3	0.2
103594	M8	236.6	0.01
103595	M2	231.2	2.91
103595	S2	259.3	0.79
103595	N2	207.5	0.6
103595	K1	238.1	1.42
103595	M4	198.8	0.04
103595	O1	221.4	0.86
103595	M6	298.3	0.03
103595	MK3	196.9	0.01
103595	MN4	180.3	0.02
103595	NU2	210.4	0.12
103595	MU2	203.9	0.05
103595	2N2	182.5	0.07
103595	OO1	274.4	0.05
103595	LDA2	223.2	0.02
103595	S1	5.4	0.04
103595	M1	257.9	0.05
103595	J1	256	0.08
103595	SSA	234	0.09
103595	SA	285.9	0.4
103595	MF	183	0.08
103595	RHO1	211.9	0.03
103595	Q1	214.2	0.15
103595	T2	251.7	0.05
103595	R2	213.6	0.01
103595	2Q1	214.4	0.02
103595	P1	233.9	0.44
103595	2SM2	54.2	0.01
103595	L2	235.9	0.07
103595	2MK3	349	0.01
103595	K2	250.6	0.21
103595	M8	260.4	0.01
103595	MS4	239.9	0.02
103596	M2	225	2.92
103596	S2	250.6	0.8
103596	N2	200.3	0.61
103596	K1	235	1.44
103596	O1	218.5	0.89
103596	NU2	208.4	0.12
103596	MU2	171.3	0.07
103596	2N2	171.6	0.07
103596	OO1	266.7	0.06
103596	LDA2	269.6	0.02
103596	S1	37.3	0.02
103596	M1	244.2	0.06
103596	J1	246.7	0.09
103596	MM	174.7	0.09
103596	SSA	258.7	0.06
103596	SA	281.6	0.4
103596	MF	155	0.06
103596	RHO1	213.8	0.03
103596	Q1	212.6	0.16
103596	T2	257.3	0.05
103596	R2	251.7	0.01
103596	2Q1	191.2	0.02
103596	P1	232.7	0.45
103596	L2	251.3	0.07
103596	K2	240.7	0.21
103597	M2	272	1.77
103597	S2	309.3	0.41
103597	N2	251.7	0.31
103597	K1	273	0.92
103597	M4	116.4	0.12
103597	O1	273.7	0.56
103597	M6	84.7	0.03
103597	S4	218.1	0.02
103597	NU2	254.4	0.06
103597	MU2	234.5	0.04
103597	2N2	231.8	0.04
103597	OO1	271.8	0.02
103597	LDA2	289.4	0.01
103597	M1	273.3	0.04
103597	J1	272.3	0.05
103597	RHO1	274.3	0.02
103597	Q1	274.2	0.11
103597	T2	307.8	0.02
103597	2Q1	275	0.01
103597	P1	273.1	0.31
103597	L2	292	0.05
103597	K2	312.3	0.11
103597	M8	299.1	0.01
103598	M2	229	2.53
103598	S2	251.1	0.89
103598	N2	205.8	0.51
103598	K1	239.5	1.15
103598	M4	64.8	0.14
103598	O1	231.9	0.74
103598	M6	92.9	0.04
103598	MK3	78.9	0.13
103598	S4	103.3	0.02
103598	MN4	46.4	0.06
103598	NU2	198.3	0.11
103598	MU2	90.7	0.03
103598	2N2	169.9	0.04
103598	OO1	286.4	0.06
103598	LDA2	222	0.04
103598	S1	227	0.07
103598	M1	150	0.02
103598	J1	266.9	0.06
103598	SSA	234	0.09
103598	SA	285.9	0.4
103598	MF	183	0.08
103598	RHO1	228.1	0.03
103598	Q1	234.7	0.12
103598	T2	224.1	0.14
103598	R2	75.4	0.3
103598	2Q1	233.9	0.03
103598	P1	243.1	0.32
103598	2SM2	57.3	0.01
103598	M3	238	0.04
103598	L2	252	0.09
103598	2MK3	35.1	0.11
103598	K2	202.5	0.21
103598	MS4	82	0.1
103599	M2	261.1	2.33
103599	S2	308.1	0.71
103599	N2	239.9	0.46
103599	K1	263.9	1.1
103599	M4	115.7	0.25
103599	O1	259.7	0.66
103599	M6	39.7	0.04
103599	MK3	115.8	0.26
103599	S4	191	0.02
103599	MN4	94.7	0.1
103599	NU2	238	0.06
103599	MU2	9.5	0.09
103599	2N2	191.9	0.07
103599	OO1	318.7	0.06
103599	LDA2	315.3	0.04
103599	S1	38.2	0.08
103599	M1	48.6	0.05
103599	J1	319.6	0.05
103599	SSA	198	0.05
103599	SA	286.2	0.36
103599	MF	183.4	0.09
103599	RHO1	306.1	0.04
103599	Q1	258.8	0.09
103599	T2	307.4	0.1
103599	R2	165.6	0.18
103599	2Q1	247.9	0.06
103599	P1	237.9	0.29
103599	2SM2	105.8	0.03
103599	M3	271.9	0.04
103599	L2	272.5	0.15
103599	2MK3	81.5	0.24
103599	K2	272.7	0.28
103599	M8	301.1	0.01
103599	MS4	152.2	0.13
103600	M2	242.6	2.88
103600	S2	273	0.77
103600	N2	220	0.58
103600	K1	245.8	1.37
103600	M4	250.4	0.1
103600	O1	229.1	0.83
103600	M6	358.5	0.05
103600	MK3	247.6	0.04
103600	S4	354.4	0.01
103600	MN4	229.9	0.04
103600	NU2	221.8	0.12
103600	MU2	252	0.05
103600	2N2	195.3	0.06
103600	OO1	285	0.04
103600	LDA2	223	0.03
103600	S1	7.7	0.04
103600	M1	272.7	0.05
103600	J1	266.3	0.07
103600	SSA	198	0.05
103600	SA	286.2	0.36
103600	MF	183.4	0.09
103600	RHO1	217.1	0.03
103600	Q1	223.6	0.14
103600	T2	266.1	0.05
103600	R2	184.9	0.01
103600	2Q1	226.9	0.02
103600	P1	242.1	0.42
103600	2SM2	72.4	0.01
103600	M3	227.9	0.01
103600	L2	241.4	0.09
103600	2MK3	308.6	0.01
103600	K2	265.5	0.2
103600	M8	15.9	0.01
103600	MS4	286.6	0.06
103601	M2	230.6	2.84
103601	S2	256.7	0.77
103601	N2	205.5	0.58
103601	K1	238.4	1.35
103601	M4	180.2	0.06
103601	O1	219.7	0.87
103601	M6	50.9	0.02
103601	NU2	208.9	0.11
103601	MU2	204.5	0.07
103601	2N2	180.4	0.08
103601	OO1	257.1	0.04
103601	LDA2	242.7	0.02
103601	M1	229.1	0.06
103601	J1	247.7	0.07
103601	SSA	198	0.05
103601	SA	286.2	0.36
103601	MF	183.4	0.09
103601	RHO1	211.7	0.03
103601	Q1	210.4	0.17
103601	T2	255.7	0.05
103601	R2	257.8	0.01
103601	2Q1	201.2	0.02
103601	P1	237	0.45
103601	L2	255.7	0.08
103601	K2	258.8	0.21
103601	M8	318.1	0.01
103602	M2	253.1	2.88
103602	S2	290.8	0.79
103602	N2	235.6	0.54
103602	K1	254	1.36
103602	M4	74.2	0.13
103602	O1	242.4	0.88
103602	M6	30.2	0.07
103602	S4	180.1	0.03
103602	NU2	237.9	0.1
103602	S6	305.1	0.01
103602	MU2	215.3	0.07
103602	2N2	218.1	0.07
103602	OO1	265.5	0.04
103602	LDA2	270.7	0.02
103602	M1	248.2	0.06
103602	J1	259.8	0.07
103602	RHO1	237.4	0.03
103602	Q1	236.6	0.17
103602	T2	289.4	0.05
103602	R2	292.5	0.01
103602	2Q1	230.9	0.02
103602	P1	253.2	0.45
103602	L2	270.5	0.08
103602	K2	293.9	0.21
103602	M8	201.6	0.01
103603	M2	260.9	3.26
103603	S2	291.9	0.78
103603	N2	239.9	0.63
103603	K1	257.2	1.26
103603	M4	29.8	0.04
103603	O1	242.7	0.85
103603	M6	31.2	0.06
103603	MK3	106.3	0.06
103603	S4	142.4	0.01
103603	MN4	24.6	0.02
103603	NU2	240.7	0.13
103603	MU2	342.9	0.04
103603	2N2	212.8	0.08
103603	OO1	301.9	0.06
103603	LDA2	246.4	0.05
103603	S1	167.5	0.08
103603	M1	182.2	0.01
103603	J1	287.5	0.06
103603	SSA	183	0.15
103603	SA	308.7	0.37
103603	MF	187.9	0.09
103603	RHO1	248.5	0.05
103603	Q1	244.1	0.14
103603	T2	298.2	0.02
103603	R2	345.7	0.1
103603	2Q1	233.7	0.05
103603	P1	253.8	0.4
103603	2SM2	112.7	0.03
103603	L2	276.6	0.12
103603	2MK3	67.4	0.09
103603	K2	298.3	0.22
103603	M8	97.4	0.01
103603	MS4	64.4	0.04
103604	M2	250.6	3.05
103604	S2	278.5	0.82
103604	N2	226.8	0.62
103604	K1	248.4	1.36
103604	M4	245.9	0.05
103604	O1	232.5	0.85
103604	M6	39.2	0.02
103604	MK3	169.7	0.02
103604	S4	18.3	0.01
103604	MN4	225.5	0.01
103604	NU2	230	0.1
103604	MU2	233.3	0.02
103604	2N2	191.4	0.08
103604	OO1	287.1	0.04
103604	LDA2	266.1	0.03
103604	S1	15.7	0.03
103604	M1	289	0.04
103604	J1	268	0.07
103604	SSA	184.1	0.17
103604	SA	307.2	0.36
103604	RHO1	239.8	0.03
103604	Q1	225	0.14
103604	T2	257	0.03
103604	R2	268.6	0.01
103604	2Q1	212.2	0.01
103604	P1	246.8	0.41
103604	2SM2	106.8	0.02
103604	M3	21.6	0.01
103604	L2	267.5	0.09
103604	2MK3	102.6	0.03
103604	K2	271.2	0.23
103604	MS4	296.9	0.03
103605	M2	261.6	3.17
103605	S2	293.8	0.79
103605	N2	239.5	0.6
103605	K1	254.5	1.32
103605	M4	109.1	0.03
103605	O1	239.6	0.8
103605	M6	124.1	0.04
103605	MK3	113.3	0.08
103605	S4	160	0.01
103605	MN4	79.1	0.02
103605	NU2	240.9	0.13
103605	MU2	356.5	0.06
103605	2N2	214	0.06
103605	OO1	294.3	0.04
103605	LDA2	257.3	0.07
103605	S1	24.5	0.04
103605	M1	302.6	0.05
103605	J1	282.8	0.05
103605	SSA	183	0.15
103605	SA	308.7	0.37
103605	MF	187.9	0.09
103605	RHO1	239.9	0.02
103605	Q1	240	0.14
103605	T2	296.4	0.05
103605	R2	356.4	0.01
103605	2Q1	253.7	0.02
103605	P1	251.4	0.37
103605	2SM2	121.5	0.03
103605	M3	15.4	0.01
103605	L2	267.4	0.15
103605	2MK3	91.4	0.1
103605	K2	283.4	0.25
103605	MS4	107.6	0.02
103606	M2	299.9	2.52
103606	S2	334.3	0.59
103606	N2	278.7	0.46
103606	K1	281.8	0.95
103606	M4	171.7	0.25
103606	O1	272.9	0.52
103606	M6	279.4	0.03
103606	MK3	154.6	0.23
103606	S4	270	0.01
103606	MN4	151	0.09
103606	NU2	278.6	0.11
103606	MU2	53.4	0.09
103606	2N2	250	0.04
103606	OO1	350.7	0.03
103606	LDA2	290.2	0.07
103606	S1	127.5	0.03
103606	M1	340.7	0.04
103606	J1	329.4	0.03
103606	SSA	183	0.15
103606	SA	308.7	0.37
103606	MF	187.9	0.09
103606	RHO1	300.6	0.01
103606	Q1	282.4	0.1
103606	T2	343.9	0.05
103606	R2	18.4	0.03
103606	2Q1	286.6	0.01
103606	P1	280.1	0.26
103606	2SM2	168.3	0.04
103606	M3	61.1	0.04
103606	L2	307	0.16
103606	2MK3	137.2	0.19
103606	K2	318.8	0.22
103606	M8	116.1	0.01
103606	MS4	205.8	0.12
103607	M2	52.2	0.83
103607	S2	84.3	0.17
103607	N2	33.6	0.13
103607	K1	12.4	0.53
103607	M4	22.4	0.17
103607	O1	19.8	0.22
103607	M6	10.3	0.02
103607	MK3	327.2	0.15
103607	MN4	2.7	0.05
103607	NU2	57.4	0.03
103607	MU2	162.3	0.03
103607	2N2	356.6	0.04
103607	OO1	81.3	0.02
103607	LDA2	6.5	0.01
103607	S1	188.9	0.14
103607	M1	58.4	0.04
103607	J1	46.5	0.03
103607	RHO1	20.2	0.01
103607	Q1	23.1	0.05
103607	T2	123.5	0.02
103607	R2	151.8	0.06
103607	2Q1	343.8	0.02
103607	P1	309.5	0.18
103607	2SM2	279.3	0.01
103607	M3	112.7	0.02
103607	L2	89.1	0.06
103607	2MK3	314.7	0.11
103607	K2	85.3	0.09
103607	M8	77	0.01
103607	MS4	52.8	0.09
103608	M2	21.4	0.87
103608	S2	53.6	0.19
103608	N2	0.5	0.16
103608	K1	346.2	0.43
103608	M4	308.7	0.14
103608	O1	356.9	0.19
103608	M6	237.7	0.02
103608	MK3	277	0.12
103608	MN4	287.7	0.05
103608	NU2	356.2	0.04
103608	MU2	133.6	0.04
103608	2N2	312	0.01
103608	OO1	79.2	0.02
103608	LDA2	18.6	0.03
103608	S1	259.7	0.05
103608	M1	36.6	0.03
103608	J1	37.3	0.02
103608	SSA	183	0.15
103608	SA	308.7	0.37
103608	MF	187.9	0.09
103608	RHO1	75.9	0.01
103608	Q1	5.1	0.05
103608	T2	86.8	0.03
103608	R2	128.2	0.04
103608	2Q1	4.8	0.01
103608	P1	327.7	0.11
103608	2SM2	264.7	0.01
103608	M3	182.1	0.02
103608	L2	39.5	0.06
103608	2MK3	258.8	0.08
103608	K2	43.6	0.1
103608	M8	39.4	0.01
103608	MS4	344.4	0.07
103609	M2	31.2	0.85
103609	S2	59.9	0.2
103609	N2	11.4	0.13
103609	K1	357.9	0.44
103609	M4	345.8	0.23
103609	O1	6.7	0.23
103609	M6	333.3	0.05
103609	MK3	296.3	0.16
103609	S4	74.8	0.01
103609	MN4	326.3	0.07
103609	NU2	38.4	0.03
103609	MU2	132.5	0.03
103609	2N2	337.1	0.04
103609	OO1	81.3	0.02
103609	LDA2	343.6	0.02
103609	S1	255	0.11
103609	M1	42.1	0.05
103609	J1	35.1	0.03
103609	Q1	12.1	0.05
103609	T2	69.4	0.03
103609	R2	136.3	0.06
103609	2Q1	333	0.01
103609	P1	342.4	0.1
103609	2SM2	258.1	0.01
103609	M3	115	0.02
103609	L2	62.8	0.05
103609	2MK3	283.7	0.13
103609	K2	61.9	0.1
103609	M8	46.7	0.01
103609	MS4	20.1	0.13
103610	M2	106.4	0.45
103610	S2	145.8	0.1
103610	N2	92.1	0.09
103610	K1	45.9	0.3
103610	M4	112.8	0.09
103610	O1	62.8	0.18
103610	M6	121.5	0.02
103610	S4	289.2	0.02
103610	NU2	94	0.02
103610	MU2	78.6	0.01
103610	2N2	76.9	0.01
103610	M1	55.4	0.01
103610	J1	44.1	0.01
103610	RHO1	69	0.01
103610	Q1	67.4	0.03
103610	T2	145.6	0.01
103610	P1	47.2	0.1
103610	L2	116.4	0.01
103610	K2	149.4	0.03
103611	M2	153.4	0.39
103611	S2	189.8	0.12
103611	N2	141	0.07
103611	K1	32.5	0.35
103611	M4	205.4	0.09
103611	O1	61	0.19
103611	M6	255.4	0.03
103611	S4	259.9	0.01
103611	NU2	143.3	0.01
103611	MU2	117.6	0.01
103611	2N2	128.8	0.01
103611	OO1	11.3	0.01
103611	M1	47.1	0.02
103611	J1	22.4	0.02
103611	RHO1	77.6	0.01
103611	Q1	76.4	0.03
103611	T2	188.4	0.01
103611	P1	34.1	0.11
103611	L2	163.1	0.01
103611	K2	192.7	0.03
103612	M2	58.2	0.75
103612	S2	91.1	0.16
103612	N2	37.2	0.13
103612	K1	8	0.39
103612	M4	37	0.14
103612	O1	25.4	0.18
103612	M6	26.6	0.01
103612	MK3	338.2	0.12
103612	MN4	14.9	0.05
103612	NU2	29.7	0.03
103612	MU2	164.2	0.03
103612	2N2	345.5	0.01
103612	OO1	104.3	0.02
103612	LDA2	60.1	0.03
103612	S1	277.6	0.09
103612	M1	50.2	0.02
103612	J1	48.7	0.02
103612	SSA	183	0.15
103612	SA	308.7	0.37
103612	MF	187.9	0.09
103612	RHO1	95.6	0.01
103612	Q1	27.2	0.05
103612	T2	140.5	0.03
103612	R2	159	0.05
103612	2Q1	14.7	0.01
103612	P1	343.8	0.08
103612	2SM2	310	0.01
103612	M3	241.7	0.02
103612	L2	81.4	0.06
103612	2MK3	322.3	0.08
103612	K2	82.3	0.1
103612	MS4	73	0.07
103613	M2	42.4	1.04
103613	S2	76.5	0.22
103613	N2	40.6	0.15
103613	K1	358.3	0.6
103613	M4	4.5	0.17
103613	O1	7.9	0.28
103613	M6	290.6	0.01
103613	S4	170.3	0.01
103613	NU2	40.6	0.03
103613	MU2	8	0.03
103613	2N2	34.9	0.02
103613	OO1	346.1	0.01
103613	LDA2	58.1	0.01
103613	M1	2.8	0.02
103613	J1	352.5	0.02
103613	RHO1	11.5	0.01
103613	Q1	12.9	0.05
103613	T2	75.6	0.01
103613	2Q1	22.4	0.01
103613	P1	358.9	0.2
103613	L2	42.9	0.03
103613	K2	79.3	0.06
103613	M8	89.6	0.01
103614	M2	358.6	1.12
103614	S2	30.7	0.26
103614	N2	332.9	0.21
103614	K1	330.5	0.52
103614	M4	270.7	0.23
103614	O1	330	0.25
103614	M6	215.8	0.02
103614	MK3	236.5	0.16
103614	MN4	242	0.08
103614	NU2	332.6	0.04
103614	MU2	115.5	0.05
103614	2N2	2	0.03
103614	OO1	35.8	0.02
103614	LDA2	348.1	0.04
103614	S1	275.3	0.03
103614	M1	10.8	0.01
103614	J1	28.4	0.03
103614	SSA	183	0.15
103614	SA	308.7	0.37
103614	MF	187.9	0.09
103614	RHO1	290.8	0.02
103614	Q1	341	0.05
103614	T2	50.6	0.02
103614	R2	98	0.02
103614	2Q1	357.7	0.03
103614	P1	324.6	0.13
103614	2SM2	224.4	0.02
103614	M3	323.8	0.05
103614	L2	27.3	0.09
103614	2MK3	221.8	0.13
103614	K2	20.5	0.11
103614	M8	338.5	0.01
103614	MS4	304.9	0.11
103615	M2	338.3	1.42
103615	S2	11.1	0.33
103615	N2	316.9	0.26
103615	K1	314.3	0.58
103615	M4	244.5	0.29
103615	O1	312.1	0.28
103615	M6	173.8	0.01
103615	MK3	210.7	0.2
103615	S4	348.1	0.01
103615	MN4	223	0.1
103615	NU2	317.6	0.06
103615	MU2	96.4	0.05
103615	2N2	279.8	0.03
103615	OO1	36.1	0.02
103615	LDA2	335.8	0.05
103615	S1	207.5	0.02
103615	M1	29.1	0.02
103615	J1	6.9	0.02
103615	MM	39.4	0.25
103615	SSA	151.3	0.74
103615	SA	19	1.41
103615	MSF	37.6	0.46
103615	RHO1	1.4	0.01
103615	Q1	327.7	0.06
103615	T2	14.6	0.04
103615	R2	62	0.03
103615	2Q1	310.5	0.01
103615	P1	309.5	0.15
103615	2SM2	207.2	0.02
103615	M3	101.3	0.03
103615	L2	351.8	0.1
103615	2MK3	194.3	0.15
103615	K2	357.9	0.14
103615	M8	275.9	0.01
103615	MS4	279.9	0.14
103616	M2	307.3	2.39
103616	S2	340.2	0.57
103616	N2	292.6	0.41
103616	K1	287.8	0.92
103616	M4	193.3	0.3
103616	O1	277.2	0.5
103616	M6	299.3	0.05
103616	S4	321.7	0.02
103616	NU2	294.6	0.08
103616	S6	98.8	0.01
103616	MU2	274.3	0.06
103616	2N2	277.9	0.06
103616	OO1	297.7	0.02
103616	LDA2	322.5	0.02
103616	M1	282.4	0.04
103616	J1	292.7	0.04
103616	RHO1	272.4	0.02
103616	Q1	272.2	0.1
103616	T2	338.9	0.03
103616	2Q1	266.9	0.01
103616	P1	287	0.3
103616	L2	322	0.07
103616	K2	342.9	0.15
103616	M8	161.6	0.02
103617	M2	326.5	1.82
103617	S2	358.9	0.43
103617	N2	313.2	0.3
103617	K1	306.6	0.73
103617	M4	229.4	0.37
103617	O1	298.5	0.38
103617	M6	352.3	0.02
103617	S4	9.3	0.02
103617	NU2	314.9	0.06
103617	MU2	294	0.04
103617	2N2	299.8	0.04
103617	OO1	314.1	0.02
103617	LDA2	341.5	0.01
103617	M1	302.5	0.03
103617	J1	310.3	0.03
103617	RHO1	295.6	0.01
103617	Q1	294.7	0.07
103617	T2	357.4	0.03
103617	2Q1	290.8	0.01
103617	P1	305.9	0.24
103617	L2	339.9	0.05
103617	K2	1.4	0.11
103617	M8	257.7	0.03
103618	M2	290.4	2.73
103618	S2	324.3	0.65
103618	N2	269.1	0.5
103618	K1	274.9	1.05
103618	M4	144.9	0.21
103618	O1	264.6	0.59
103618	M6	236.9	0.03
103618	MK3	138.8	0.2
103618	S4	240	0.01
103618	MN4	124.8	0.08
103618	NU2	268.6	0.12
103618	MU2	42.1	0.09
103618	2N2	242	0.05
103618	OO1	339.8	0.03
103618	LDA2	280.5	0.08
103618	S1	142.1	0.03
103618	M1	331.5	0.04
103618	J1	316.8	0.03
103618	SSA	183	0.15
103618	SA	308.7	0.37
103618	MF	187.9	0.09
103618	RHO1	281.3	0.01
103618	Q1	272.3	0.1
103618	T2	331.1	0.05
103618	R2	5.4	0.03
103618	2Q1	277.7	0.02
103618	P1	273.8	0.29
103618	2SM2	158.5	0.04
103618	M3	45.1	0.03
103618	L2	297.1	0.16
103618	2MK3	120.5	0.18
103618	K2	310.6	0.24
103618	M8	64.9	0.01
103618	MS4	177.8	0.1
103619	M2	243.2	2.83
103619	S2	269.6	0.79
103619	N2	218	0.59
103619	K1	245.1	1.36
103619	M4	203.1	0.09
103619	O1	228.2	0.87
103619	M6	298.1	0.01
103619	MK3	195.3	0.04
103619	S4	319.6	0.01
103619	MN4	179.5	0.04
103619	NU2	220.3	0.12
103619	MU2	193	0.05
103619	2N2	189.9	0.07
103619	OO1	278.4	0.04
103619	LDA2	275	0.02
103619	S1	16.5	0.05
103619	M1	261.2	0.05
103619	J1	253.8	0.08
103619	SA	297.3	0.41
103619	MF	149.7	0.07
103619	RHO1	224	0.03
103619	Q1	219.8	0.15
103619	T2	263	0.05
103619	2Q1	215.1	0.02
103619	P1	243.1	0.43
103619	L2	264	0.07
103619	2MK3	178.6	0.02
103619	K2	265.6	0.21
103619	MS4	241.1	0.05
103620	M2	281.9	3.82
103620	S2	323.4	0.88
103620	N2	260.7	0.63
103620	K1	268.8	1.23
103620	M4	20.5	0.24
103620	O1	257.9	0.67
103620	M6	117.6	0.2
103620	S4	186.1	0.02
103620	NU2	263.5	0.12
103620	MU2	240.5	0.09
103620	2N2	239.5	0.09
103620	OO1	279.4	0.03
103620	LDA2	301.2	0.03
103620	M1	263.4	0.05
103620	J1	274.1	0.05
103620	SA	289.8	0.52
103620	MF	161.8	0.08
103620	RHO1	253.2	0.03
103620	Q1	252.5	0.13
103620	T2	321.7	0.05
103620	R2	325	0.01
103620	2Q1	247.3	0.02
103620	P1	267.9	0.41
103620	L2	303.1	0.11
103620	K2	326.8	0.24
103620	M8	208.1	0.03
103621	M2	264.1	3.86
103621	S2	299.6	0.97
103621	N2	237.9	0.74
103621	K1	257.1	1.43
103621	M4	336.6	0.22
103621	O1	242.6	0.87
103621	M6	90.8	0.11
103621	S4	70.5	0.04
103621	NU2	241.5	0.14
103621	2N2	211.7	0.1
103621	OO1	271.6	0.04
103621	LDA2	113.5	0.03
103621	M1	249.8	0.06
103621	J1	264.3	0.07
103621	RHO1	236.4	0.03
103621	Q1	235.3	0.17
103621	T2	299.5	0.06
103621	R2	299.5	0.01
103621	2Q1	228.1	0.02
103621	P1	257.1	0.47
103621	L2	290.3	0.11
103621	K2	299.5	0.26
103621	M8	170.7	0.02
103622	M2	259.7	3.69
103622	S2	291.2	0.98
103622	N2	233.6	0.77
103622	K1	254.8	1.4
103622	M4	317	0.2
103622	O1	239.2	0.87
103622	M6	62.9	0.11
103622	S4	57.2	0.03
103622	NU2	237.1	0.15
103622	2N2	207.3	0.1
103622	OO1	270.4	0.04
103622	LDA2	274.4	0.03
103622	M1	246.9	0.06
103622	J1	262.5	0.07
103622	RHO1	232.4	0.03
103622	Q1	231.3	0.17
103622	T2	291.1	0.06
103622	R2	291.2	0.01
103622	2Q1	223.6	0.02
103622	P1	254.7	0.46
103622	L2	286	0.1
103622	K2	291.1	0.27
103622	M8	143.4	0.01
103623	M2	250.6	3.2
103623	S2	279.5	0.87
103623	N2	226.3	0.65
103623	K1	249	1.39
103623	M4	295.3	0.05
103623	O1	233.3	0.85
103623	M6	32.9	0.02
103623	MK3	249.3	0.02
103623	S4	6.9	0.01
103623	MN4	263.4	0.02
103623	NU2	226.8	0.14
103623	MU2	215.4	0.03
103623	2N2	200.5	0.08
103623	OO1	286	0.05
103623	LDA2	273	0.03
103623	S1	43.2	0.03
103623	M1	272.2	0.04
103623	J1	264.1	0.08
103623	SA	286.7	0.52
103623	RHO1	233.1	0.03
103623	Q1	230	0.15
103623	T2	269.8	0.05
103623	R2	227.2	0.01
103623	2Q1	230.8	0.02
103623	P1	246.8	0.43
103623	M3	54.7	0.01
103623	L2	266.2	0.09
103623	2MK3	169.3	0.01
103623	K2	275.3	0.23
103623	MS4	330	0.03
103624	M2	240.7	3.23
103624	S2	271.3	0.89
103624	N2	217.9	0.67
103624	K1	244	1.39
103624	M4	210	0.09
103624	O1	228.4	0.85
103624	M6	19.9	0.06
103624	MK3	191.2	0.03
103624	MN4	195.2	0.03
103624	NU2	218.6	0.13
103624	MU2	240.8	0.05
103624	2N2	193	0.08
103624	OO1	278	0.05
103624	LDA2	230	0.03
103624	S1	31.3	0.04
103624	M1	268.2	0.05
103624	J1	259.9	0.07
103624	MM	171.2	0.08
103624	SA	289.6	0.41
103624	MF	190.3	0.09
103624	RHO1	220.7	0.03
103624	Q1	222.4	0.15
103624	T2	277.6	0.05
103624	R2	210.1	0.02
103624	2Q1	233.7	0.02
103624	P1	239.9	0.43
103624	2SM2	80.7	0.02
103624	L2	243.1	0.1
103624	2MK3	108.8	0.01
103624	K2	264.3	0.24
103624	M8	11.3	0.01
103624	MS4	254.7	0.04
103625	M2	253.6	3.66
103625	S2	289	0.98
103625	N2	234.4	0.73
103625	K1	250.9	1.42
103625	M4	305.2	0.2
103625	O1	235.8	0.85
103625	M6	41.5	0.13
103625	MK3	314.9	0.04
103625	S4	54.7	0.01
103625	MN4	287.6	0.07
103625	NU2	230	0.15
103625	MU2	303.4	0.11
103625	2N2	188	0.11
103625	OO1	293.3	0.04
103625	LDA2	225.8	0.06
103625	S1	73	0.02
103625	M1	297.5	0.04
103625	J1	281	0.08
103625	MM	306.8	0.05
103625	SSA	203.9	0.05
103625	SA	277.8	0.29
103625	MSF	21.5	0.1
103625	MF	164.6	0.08
103625	RHO1	234.3	0.02
103625	Q1	235.2	0.14
103625	T2	296.4	0.06
103625	R2	265.9	0.02
103625	2Q1	210.5	0.02
103625	P1	248.7	0.42
103625	2SM2	101	0.03
103625	M3	72.9	0.02
103625	L2	254.5	0.12
103625	2MK3	41	0.05
103625	K2	282.5	0.28
103625	M8	105.6	0.03
103625	MS4	345.8	0.11
103626	M2	248.3	1.99
103626	S2	275.5	0.51
103626	N2	224.6	0.4
103626	K1	263.2	0.81
103626	M4	98.8	0.31
103626	O1	266.8	0.46
103626	M6	233.2	0.04
103626	S4	162.4	0.02
103626	NU2	227.8	0.08
103626	MU2	221.1	0.05
103626	2N2	200.6	0.05
103626	OO1	259.5	0.02
103626	LDA2	260.9	0.01
103626	M1	265	0.03
103626	J1	261.5	0.04
103626	MM	171.2	0.08
103626	SA	289.6	0.41
103626	MF	190.3	0.09
103626	RHO1	268.9	0.02
103626	Q1	268.6	0.09
103626	T2	274.5	0.03
103626	2Q1	270.6	0.01
103626	P1	263.4	0.27
103626	L2	271.3	0.06
103626	K2	277.8	0.14
103626	M8	32.6	0.01
103627	M2	234.9	3.06
103627	S2	262	0.87
103627	N2	210.2	0.64
103627	K1	239.6	1.41
103627	O1	223.8	0.86
103627	NU2	213.3	0.13
103627	MU2	184.9	0.07
103627	2N2	183.4	0.07
103627	OO1	266.3	0.05
103627	LDA2	260.2	0.02
103627	S1	346.6	0.02
103627	M1	244.1	0.05
103627	J1	252.8	0.09
103627	SSA	125.8	0.05
103627	SA	286.5	0.56
103627	RHO1	209.7	0.03
103627	Q1	216	0.15
103627	T2	257.4	0.05
103627	R2	258.4	0.01
103627	2Q1	205.4	0.02
103627	P1	235.8	0.44
103627	L2	258.6	0.07
103627	K2	254.4	0.24
103628	M2	238.1	3.07
103628	S2	267	0.9
103628	N2	211.1	0.62
103628	K1	240.6	1.4
103628	O1	224.6	0.9
103628	M6	132.5	0.01
103628	S4	341.1	0.01
103628	NU2	214.7	0.12
103628	S6	209.6	0.01
103628	MU2	209.3	0.07
103628	2N2	184.1	0.08
103628	OO1	256.8	0.04
103628	LDA2	251.5	0.02
103628	M1	232.7	0.07
103628	J1	248.7	0.07
103628	SA	289.9	0.41
103628	MF	164.6	0.06
103628	RHO1	217.6	0.04
103628	Q1	216.6	0.17
103628	T2	265.8	0.05
103628	R2	268.1	0.01
103628	2Q1	208.6	0.02
103628	P1	239.4	0.46
103628	L2	265.2	0.09
103628	K2	269.3	0.24
103629	M2	246.2	2.59
103629	S2	272.5	0.76
103629	N2	222.3	0.55
103629	K1	248.5	1.63
103629	M4	58.8	0.04
103629	O1	231.6	1
103629	M6	184.2	0.02
103629	MK3	325.3	0.05
103629	MN4	28	0.02
103629	NU2	226.5	0.1
103629	MU2	202.5	0.08
103629	2N2	196.6	0.07
103629	OO1	283.5	0.05
103629	LDA2	270	0.01
103629	S1	29.3	0.04
103629	M1	263.4	0.06
103629	J1	264.8	0.09
103629	SA	289.9	0.41
103629	MF	164.6	0.06
103629	RHO1	219.6	0.03
103629	Q1	223.8	0.18
103629	T2	267.2	0.04
103629	R2	288	0.01
103629	2Q1	227.4	0.02
103629	P1	246.8	0.51
103629	L2	265.6	0.04
103629	2MK3	321.6	0.03
103629	K2	266.9	0.19
103629	MS4	68.6	0.02
103630	M2	258	2.19
103630	S2	283.5	0.65
103630	N2	233.9	0.48
103630	K1	252.2	1.78
103630	M4	66.1	0.03
103630	O1	233.5	1.08
103630	M6	187.2	0.03
103630	MK3	5	0.04
103630	S4	89.1	0.01
103630	MN4	33.6	0.01
103630	NU2	238.6	0.1
103630	MU2	216.9	0.08
103630	2N2	220.9	0.07
103630	OO1	283.9	0.05
103630	LDA2	260.1	0.01
103630	S1	45.6	0.07
103630	M1	261.1	0.06
103630	J1	261.2	0.09
103630	SA	289.9	0.41
103630	MF	164.6	0.06
103630	RHO1	232.5	0.05
103630	Q1	226	0.19
103630	T2	272.2	0.04
103630	R2	227.9	0.01
103630	2Q1	211.3	0.03
103630	P1	243.9	0.56
103630	2SM2	295.1	0.01
103630	M3	313.1	0.02
103630	L2	277.4	0.04
103630	2MK3	8.1	0.05
103630	K2	277.8	0.15
103630	MS4	84.2	0.01
103631	M2	266.8	2.01
103631	S2	288.5	0.63
103631	N2	243.5	0.44
103631	K1	254.7	1.77
103631	M4	85.6	0.03
103631	O1	237.1	1.1
103631	M6	195	0.04
103631	S4	356.4	0.01
103631	NU2	246.6	0.09
103631	MU2	245	0.05
103631	2N2	220.2	0.06
103631	OO1	272.5	0.05
103631	LDA2	276.8	0.01
103631	M1	246	0.08
103631	J1	263.6	0.09
103631	SA	289.9	0.41
103631	MF	164.6	0.06
103631	RHO1	229.5	0.04
103631	Q1	228.4	0.21
103631	T2	287.6	0.04
103631	R2	289.4	0.01
103631	2Q1	219.6	0.03
103631	P1	253.4	0.59
103631	L2	290.1	0.06
103631	K2	290.3	0.17
103632	M2	307.3	1.69
103632	S2	326	0.48
103632	N2	279.7	0.38
103632	K1	261.8	2.19
103632	M4	100.5	0.05
103632	O1	241.6	1.28
103632	M6	196.8	0.05
103632	MK3	23.8	0.06
103632	S4	115.4	0.01
103632	MN4	66.2	0.02
103632	NU2	287.3	0.07
103632	MU2	234.5	0.09
103632	2N2	250.3	0.05
103632	OO1	303	0.08
103632	LDA2	53.3	0.02
103632	S1	33.8	0.05
103632	M1	280.6	0.08
103632	J1	280.5	0.12
103632	MM	285.8	0.09
103632	SA	284.3	0.3
103632	MF	155.6	0.07
103632	RHO1	232.3	0.04
103632	Q1	232.2	0.22
103632	T2	330.5	0.03
103632	R2	333.4	0.01
103632	2Q1	221.5	0.02
103632	P1	260	0.69
103632	2SM2	308.6	0.01
103632	M3	350	0.01
103632	L2	31.2	0.04
103632	2MK3	18.5	0.07
103632	K2	332.6	0.09
103632	MS4	115.3	0.03
103633	M2	349.7	2.25
103633	S2	12.6	0.56
103633	N2	320	0.48
103633	K1	270.7	2.51
103633	M4	60.5	0.13
103633	O1	249.8	1.47
103633	M6	246.3	0.03
103633	MK3	332.8	0.09
103633	MN4	29.7	0.05
103633	NU2	331.5	0.09
103633	MU2	239.6	0.09
103633	2N2	286.8	0.06
103633	OO1	317	0.1
103633	LDA2	44.3	0.04
103633	S1	51.2	0.05
103633	M1	303.2	0.08
103633	J1	302.4	0.13
103633	MM	184.6	0.07
103633	SA	292	0.27
103633	MF	144.3	0.07
103633	RHO1	240.4	0.05
103633	Q1	242.3	0.25
103633	T2	14.1	0.04
103633	2Q1	242.4	0.03
103633	P1	269.5	0.79
103633	2SM2	290.6	0.01
103633	M3	228.7	0.01
103633	L2	44.1	0.09
103633	2MK3	341.1	0.06
103633	K2	16.8	0.17
103633	MS4	83.5	0.07
103634	M2	3.4	2.9
103634	S2	29.6	0.72
103634	N2	331.3	0.56
103634	K1	275.9	2.51
103634	M4	180.9	0.06
103634	O1	253.9	1.38
103634	M6	296.4	0.02
103634	S4	140.3	0.01
103634	NU2	335.6	0.11
103634	MU2	337.1	0.07
103634	2N2	299.2	0.08
103634	OO1	297.8	0.06
103634	LDA2	15.6	0.02
103634	M1	265	0.1
103634	J1	286.7	0.11
103634	SSA	231.1	0.11
103634	SA	292.9	0.25
103634	MF	140.5	0.07
103634	RHO1	244.5	0.05
103634	Q1	243.1	0.27
103634	T2	28.6	0.04
103634	R2	30.7	0.01
103634	2Q1	232.2	0.04
103634	P1	274.2	0.83
103634	L2	35.4	0.08
103634	K2	31.8	0.19
103635	M2	4.1	3.36
103635	S2	29.5	0.84
103635	N2	333.5	0.68
103635	K1	274.8	2.74
103635	M4	183.4	0.09
103635	O1	251.9	1.53
103635	M6	85.1	0.03
103635	MK3	73	0.1
103635	S4	211.5	0.01
103635	MN4	141	0.04
103635	NU2	345.1	0.14
103635	MU2	237.2	0.11
103635	2N2	318.2	0.08
103635	OO1	320.2	0.11
103635	LDA2	37.9	0.07
103635	S1	42.1	0.04
103635	M1	308.6	0.07
103635	J1	307.9	0.11
103635	MM	187.7	0.08
103635	SA	287.6	0.33
103635	MF	146.8	0.05
103635	RHO1	247.1	0.06
103635	Q1	247.2	0.26
103635	T2	33.6	0.05
103635	R2	30.4	0.01
103635	2Q1	236.2	0.03
103635	P1	273.9	0.85
103635	2SM2	271.2	0.02
103635	M3	350.4	0.03
103635	L2	65.4	0.13
103635	2MK3	48.8	0.11
103635	K2	28.5	0.24
103635	MS4	199.9	0.05
103636	M2	4.8	3.49
103636	S2	29.6	0.89
103636	N2	333.2	0.62
103636	K1	273.1	2.96
103636	M4	179	0.11
103636	O1	249.4	1.56
103636	M6	87.4	0.06
103636	NU2	337.4	0.12
103636	MU2	340	0.09
103636	2N2	301.5	0.08
103636	OO1	296.9	0.07
103636	LDA2	16.3	0.02
103636	M1	261.4	0.11
103636	J1	284.9	0.12
103636	MM	184.6	0.07
103636	SA	292	0.27
103636	MF	144.3	0.07
103636	RHO1	239.2	0.06
103636	Q1	237.6	0.31
103636	T2	28.6	0.05
103636	R2	30.6	0.01
103636	2Q1	225.9	0.04
103636	P1	271.4	0.98
103636	L2	36.4	0.1
103636	K2	31.6	0.24
103637	M2	17	3.6
103637	S2	45.1	0.89
103637	N2	349	0.7
103637	K1	280.4	2.73
103637	M4	243.9	0.08
103637	O1	257.8	1.5
103637	M6	3	0.06
103637	MK3	120.4	0.09
103637	S4	289.5	0.01
103637	MN4	213.7	0.04
103637	NU2	358.1	0.15
103637	MU2	231.9	0.08
103637	2N2	322.3	0.09
103637	OO1	333.4	0.1
103637	LDA2	45.4	0.06
103637	S1	17.5	0.09
103637	M1	323	0.05
103637	J1	319.5	0.15
103637	SSA	231.1	0.11
103637	SA	292.9	0.25
103637	MF	140.5	0.07
103637	RHO1	272.1	0.05
103637	Q1	251.2	0.24
103637	T2	49.1	0.06
103637	R2	354.8	0.01
103637	2Q1	230.5	0.04
103637	P1	281.3	0.83
103637	2SM2	270.2	0.03
103637	M3	207.2	0.02
103637	L2	63.4	0.12
103637	2MK3	80.3	0.06
103637	K2	39	0.26
103637	M8	224.8	0.01
103637	MS4	267.2	0.05
103638	M2	27.7	4.37
103638	S2	57.6	1.06
103638	N2	4.2	0.81
103638	K1	287.5	2.92
103638	M4	331.3	0.09
103638	O1	260.5	1.51
103638	M6	117.3	0.04
103638	NU2	7.4	0.16
103638	MU2	358	0.1
103638	2N2	340.7	0.1
103638	OO1	314.5	0.06
103638	LDA2	41.6	0.03
103638	M1	274.1	0.1
103638	J1	300.9	0.12
103638	SSA	231.1	0.11
103638	SA	292.9	0.25
103638	MF	140.5	0.07
103638	RHO1	248.9	0.06
103638	Q1	247.1	0.29
103638	T2	56.4	0.06
103638	R2	58.8	0.01
103638	2Q1	233.7	0.04
103638	P1	285.5	0.96
103638	L2	51.4	0.12
103638	K2	60.1	0.29
103638	M8	302.5	0.01
103639	M2	11.8	3.72
103639	S2	37.4	0.93
103639	N2	341.4	0.74
103639	K1	277.4	2.75
103639	M4	208.2	0.07
103639	O1	255.2	1.52
103639	M6	299	0.02
103639	MK3	74.8	0.12
103639	S4	270	0.01
103639	MN4	182.1	0.03
103639	NU2	356.2	0.16
103639	MU2	234.7	0.12
103639	2N2	309.3	0.09
103639	OO1	334.8	0.1
103639	LDA2	48.9	0.07
103639	S1	38.8	0.05
103639	M1	315.3	0.09
103639	J1	312	0.13
103639	SSA	218.2	0.07
103639	SA	281	0.2
103639	MF	139	0.09
103639	RHO1	251.8	0.05
103639	Q1	249.8	0.25
103639	T2	34.8	0.06
103639	R2	47.7	0.01
103639	2Q1	258.4	0.03
103639	P1	277.3	0.85
103639	2SM2	283.7	0.03
103639	M3	344.5	0.02
103639	L2	55.3	0.16
103639	2MK3	43.2	0.11
103639	K2	38.7	0.28
103639	MS4	241.7	0.04
103640	M2	26.2	4.41
103640	S2	55.8	1.06
103640	N2	359.7	0.85
103640	K1	285.7	2.77
103640	M4	281.7	0.1
103640	O1	263.4	1.53
103640	M6	121.7	0.05
103640	MK3	126.9	0.08
103640	S4	267.3	0.01
103640	MN4	250.2	0.04
103640	NU2	6.1	0.19
103640	MU2	205.2	0.09
103640	2N2	339.6	0.1
103640	OO1	19.1	0.1
103640	LDA2	45.8	0.09
103640	S1	328.3	0.07
103640	M1	309.7	0.06
103640	J1	331.8	0.16
103640	SSA	231.1	0.11
103640	SA	292.9	0.25
103640	MF	140.5	0.07
103640	RHO1	268.6	0.06
103640	Q1	261.2	0.24
103640	T2	43.5	0.08
103640	R2	173.9	0.02
103640	2Q1	219.7	0.04
103640	P1	286.7	0.8
103640	2SM2	280.2	0.04
103640	M3	222.9	0.01
103640	L2	65.2	0.2
103640	2MK3	42.6	0.01
103640	K2	51.6	0.3
103640	MS4	310.9	0.06
103641	M2	26.5	3.74
103641	S2	57.2	0.91
103641	N2	1.5	0.72
103641	K1	285.8	2.46
103641	M4	282.6	0.09
103641	O1	261.1	1.32
103641	M6	124.5	0.04
103641	S4	283.8	0.01
103641	NU2	4.9	0.14
103641	MU2	355.7	0.09
103641	2N2	336.5	0.1
103641	OO1	310.6	0.06
103641	LDA2	40.7	0.03
103641	M1	273.6	0.1
103641	J1	298.1	0.1
103641	SSA	231.1	0.11
103641	SA	292.9	0.25
103641	MF	140.5	0.07
103641	RHO1	250.5	0.05
103641	Q1	248.9	0.26
103641	T2	56	0.05
103641	R2	58.4	0.01
103641	2Q1	236.5	0.03
103641	P1	284	0.81
103641	L2	51.5	0.1
103641	K2	59.7	0.25
103642	M2	30.3	4.79
103642	S2	62	1.13
103642	N2	4.5	0.91
103642	K1	289.6	2.88
103642	M4	294.4	0.16
103642	O1	266.4	1.55
103642	M6	143.8	0.1
103642	MK3	145.8	0.1
103642	S4	334.8	0.01
103642	MN4	265.4	0.07
103642	NU2	10.6	0.21
103642	MU2	193	0.08
103642	2N2	345.2	0.11
103642	OO1	5.6	0.09
103642	LDA2	46.8	0.09
103642	S1	63.5	0.06
103642	M1	309	0.06
103642	J1	331.4	0.17
103642	SSA	231.1	0.11
103642	SA	292.9	0.25
103642	MF	140.5	0.07
103642	RHO1	269.8	0.08
103642	Q1	264.7	0.23
103642	T2	69.9	0.05
103642	R2	118.3	0.04
103642	2Q1	238.2	0.03
103642	P1	285.3	0.88
103642	2SM2	273.4	0.05
103642	M3	254.8	0.02
103642	L2	64.4	0.22
103642	2MK3	267.3	0.02
103642	K2	58.8	0.32
103642	M8	18.8	0.01
103642	MS4	313.7	0.1
103643	M2	10.6	3.52
103643	S2	37	0.88
103643	N2	340.8	0.71
103643	K1	277	2.74
103643	M4	200.2	0.07
103643	O1	254.6	1.51
103643	M6	313.6	0.03
103643	MK3	78.1	0.11
103643	MN4	174	0.03
103643	NU2	354.9	0.15
103643	MU2	236.6	0.11
103643	2N2	308.7	0.08
103643	OO1	328.9	0.1
103643	LDA2	48.4	0.07
103643	S1	44.2	0.05
103643	M1	319.8	0.09
103643	J1	315.2	0.13
103643	SSA	231.1	0.11
103643	SA	292.9	0.25
103643	MF	140.5	0.07
103643	RHO1	246.6	0.05
103643	Q1	249.9	0.25
103643	T2	37.1	0.05
103643	R2	38	0.01
103643	2Q1	251.5	0.03
103643	P1	276.6	0.85
103643	2SM2	282.6	0.03
103643	M3	342.4	0.02
103643	L2	56.1	0.15
103643	2MK3	46.7	0.11
103643	K2	37.9	0.26
103643	MS4	229.9	0.04
103644	M2	11.6	3.31
103644	S2	37.1	0.85
103644	N2	345.3	0.61
103644	K1	276.9	2.65
103644	M4	181.5	0.06
103644	O1	258.3	1.53
103644	M6	327.2	0.04
103644	NU2	348.8	0.12
103644	MU2	346.1	0.08
103644	2N2	319	0.08
103644	OO1	295.4	0.07
103644	LDA2	23.4	0.02
103644	M1	267.7	0.11
103644	J1	286.1	0.12
103644	SSA	231.1	0.11
103644	SA	292.9	0.25
103644	MF	140.5	0.07
103644	RHO1	250.4	0.06
103644	Q1	249.1	0.3
103644	T2	36.1	0.05
103644	R2	38.1	0.01
103644	2Q1	240	0.04
103644	P1	275.4	0.88
103644	L2	38.1	0.09
103644	K2	39.2	0.23
103645	M2	15.5	3.37
103645	S2	43.4	0.83
103645	N2	346.3	0.67
103645	K1	281.1	2.61
103645	M4	267.2	0.08
103645	O1	259.9	1.52
103645	M6	350.9	0.03
103645	S4	284.5	0.02
103645	NU2	350.2	0.13
103645	MU2	347.6	0.08
103645	2N2	317.1	0.09
103645	OO1	302.1	0.07
103645	LDA2	28.4	0.02
103645	M1	270.5	0.11
103645	J1	291.5	0.12
103645	SSA	231.1	0.11
103645	SA	292.9	0.25
103645	MF	140.5	0.07
103645	RHO1	250.8	0.06
103645	Q1	249.4	0.3
103645	T2	42.3	0.05
103645	R2	44.5	0.01
103645	2Q1	239	0.04
103645	P1	279.5	0.87
103645	L2	44.7	0.1
103645	K2	45.6	0.23
103645	M8	284.8	0.01
103646	M2	10.7	3.419
103646	S2	36.2	0.83
103646	N2	341.9	0.682
103646	K1	278.3	2.707
103646	M4	185.7	0.069
103646	O1	255.4	1.48
103646	M6	324.7	0.056
103646	S4	274.1	0.007
103646	NU2	345.7	0.131
103646	MU2	345.2	0.082
103646	2N2	313	0.092
103646	OO1	301.1	0.062
103646	LDA2	22.5	0.023
103646	M1	267	0.105
103646	J1	289.6	0.118
103646	SSA	231.1	0.108
103646	SA	292.9	0.253
103646	MF	140.5	0.072
103646	RHO1	245.6	0.056
103646	Q1	244.1	0.285
103646	T2	35.2	0.049
103646	R2	37.2	0.007
103646	2Q1	232.8	0.036
103646	P1	276.6	0.896
103646	L2	39.6	0.095
103646	K2	38.3	0.226
103646	M8	190.2	0.003
103647	M2	12	3.53
103647	S2	37.6	0.87
103647	N2	344.4	0.68
103647	K1	278.1	2.77
103647	M4	186.1	0.07
103647	O1	254.6	1.51
103647	M6	328.7	0.07
103647	S4	244.1	0.01
103647	NU2	348.1	0.13
103647	S6	228.1	0.01
103647	MU2	346.4	0.09
103647	2N2	316.7	0.09
103647	OO1	301.7	0.07
103647	LDA2	23.9	0.02
103647	M1	266.5	0.11
103647	J1	289.8	0.12
103647	SSA	231.1	0.11
103647	SA	292.9	0.25
103647	MF	140.5	0.07
103647	RHO1	244.5	0.06
103647	Q1	242.9	0.29
103647	T2	36.6	0.05
103647	R2	38.6	0.01
103647	2Q1	231.3	0.04
103647	P1	276.4	0.92
103647	L2	39.6	0.1
103647	K2	39.6	0.24
103648	M2	341.1	1.81
103648	S2	357	0.49
103648	N2	311.3	0.42
103648	K1	270.2	2.22
103648	M4	111.9	0.05
103648	O1	251.3	1.31
103648	M6	199.6	0.05
103648	S4	38.4	0.01
103648	NU2	315.4	0.08
103648	MU2	325.2	0.04
103648	2N2	281.6	0.06
103648	OO1	289	0.06
103648	LDA2	348.5	0.01
103648	M1	260.8	0.09
103648	J1	279.5	0.1
103648	SSA	221	0.13
103648	SA	280.4	0.28
103648	RHO1	243.2	0.05
103648	Q1	242	0.25
103648	T2	356.4	0.03
103648	2Q1	232.6	0.03
103648	P1	268.8	0.73
103648	L2	10.9	0.05
103648	K2	358.3	0.13
103649	M2	10.8	3.45
103649	S2	35.3	0.84
103649	N2	342.1	0.7
103649	K1	277.8	2.61
103649	M4	183.8	0.07
103649	O1	257	1.54
103649	M6	323	0.06
103649	S4	203.4	0.02
103649	NU2	346	0.14
103649	MU2	346.3	0.08
103649	2N2	313.5	0.09
103649	OO1	298.8	0.07
103649	LDA2	22.1	0.02
103649	M1	267.5	0.11
103649	J1	288.2	0.12
103649	SSA	231.1	0.11
103649	SA	292.9	0.25
103649	MF	140.5	0.07
103649	RHO1	248	0.06
103649	Q1	246.6	0.3
103649	T2	34.3	0.05
103649	R2	36.2	0.01
103649	2Q1	236.2	0.04
103649	P1	276.3	0.86
103649	L2	39.4	0.1
103649	K2	37.3	0.23
103650	M2	9.7	3.44
103650	S2	35.5	0.84
103650	N2	344.3	0.69
103650	K1	277.3	2.6
103650	M4	184.3	0.07
103650	O1	257.4	1.55
103650	M6	325	0.06
103650	S4	222.4	0.01
103650	NU2	347.7	0.13
103650	MU2	344	0.08
103650	2N2	318.8	0.09
103650	OO1	297.2	0.07
103650	LDA2	21.6	0.02
103650	M1	267.5	0.11
103650	J1	287.2	0.12
103650	SSA	231.1	0.11
103650	SA	292.9	0.25
103650	MF	140.5	0.07
103650	RHO1	248.9	0.06
103650	Q1	247.6	0.3
103650	T2	34.4	0.05
103650	R2	36.5	0.01
103650	2Q1	237.8	0.04
103650	P1	275.8	0.86
103650	L2	35.1	0.1
103650	K2	37.6	0.23
103650	M8	211.3	0.01
103651	M2	18.3	3.37
103651	S2	42	0.85
103651	N2	349.4	0.68
103651	K1	282	2.57
103651	M4	12	0.01
103651	O1	258	1.47
103651	M6	134.8	0.07
103651	S4	211	0.01
103651	NU2	353.3	0.13
103651	MU2	354.6	0.08
103651	2N2	320.5	0.09
103651	OO1	305.9	0.06
103651	LDA2	29.3	0.02
103651	M1	270.1	0.1
103651	J1	293.8	0.11
103651	RHO1	247.8	0.06
103651	Q1	246.2	0.29
103651	T2	41.1	0.05
103651	R2	43	0.01
103651	2Q1	234.4	0.04
103651	P1	280.2	0.85
103651	L2	47.1	0.1
103651	K2	43.9	0.23
103651	M8	13	0.02
103652	M2	18.1	3.18
103652	S2	43.5	0.79
103652	N2	346.2	0.65
103652	K1	279.6	2.68
103652	M4	58.1	0.02
103652	O1	256.6	1.48
103652	M6	149.1	0.07
103652	MK3	82.1	0.1
103652	MN4	20	0.01
103652	NU2	355.8	0.12
103652	MU2	259	0.11
103652	2N2	326.4	0.08
103652	OO1	322	0.1
103652	LDA2	58.8	0.05
103652	S1	25.7	0.1
103652	M1	306.9	0.05
103652	J1	313	0.12
103652	SSA	221	0.13
103652	SA	280.4	0.28
103652	RHO1	262.9	0.08
103652	Q1	252.6	0.23
103652	T2	43.5	0.06
103652	R2	97.5	0.01
103652	2Q1	229.5	0.04
103652	P1	275.7	0.83
103652	2SM2	315.7	0.03
103652	M3	1.6	0.04
103652	L2	81.4	0.1
103652	2MK3	68.1	0.14
103652	K2	45.6	0.24
103652	M8	60	0.02
103652	MS4	46.9	0.02
103653	M2	344.6	1.91
103653	S2	4.7	0.49
103653	N2	313.7	0.43
103653	K1	269.6	2.42
103653	M4	135.5	0.03
103653	O1	247.5	1.37
103653	M6	215.7	0.04
103653	MK3	53.5	0.06
103653	S4	111.1	0.01
103653	MN4	101.4	0.01
103653	NU2	316.1	0.08
103653	MU2	250.4	0.1
103653	2N2	309.1	0.07
103653	OO1	305.8	0.09
103653	LDA2	66.6	0.04
103653	S1	21.7	0.08
103653	M1	285	0.06
103653	J1	286.2	0.12
103653	SSA	221	0.13
103653	SA	280.4	0.28
103653	RHO1	254.5	0.06
103653	Q1	239	0.22
103653	T2	12.6	0.04
103653	R2	301	0.01
103653	2Q1	217.3	0.04
103653	P1	264.4	0.76
103653	2SM2	301.2	0.02
103653	M3	332.7	0.02
103653	L2	63.8	0.05
103653	2MK3	38.9	0.08
103653	K2	20.6	0.1
103653	MS4	130.5	0.02
103654	M2	16.7	3.1
103654	S2	42.9	0.78
103654	N2	347.4	0.63
103654	K1	281.4	2.47
103654	M4	77.1	0.05
103654	O1	259	1.43
103654	M6	154.3	0.07
103654	S4	205.8	0.01
103654	NU2	351.3	0.12
103654	MU2	350.6	0.08
103654	2N2	318	0.08
103654	OO1	303.9	0.06
103654	LDA2	29	0.02
103654	M1	270.3	0.1
103654	J1	292.6	0.11
103654	MM	184.6	0.07
103654	SA	292	0.27
103654	MF	144.3	0.07
103654	RHO1	249.4	0.05
103654	Q1	247.8	0.28
103654	T2	41.9	0.05
103654	R2	44	0.01
103654	2Q1	236.7	0.04
103654	P1	279.8	0.82
103654	L2	46.1	0.09
103654	K2	45.1	0.21
103654	M8	37.8	0.02
103655	M2	18.1	2.31
103655	S2	44.6	0.56
103655	N2	349.1	0.48
103655	K1	282.2	2.56
103655	M4	236.3	0.02
103655	O1	259.4	1.41
103655	M6	234.2	0.04
103655	MK3	172.2	0.04
103655	MN4	195.4	0.01
103655	NU2	357.7	0.1
103655	MU2	254.9	0.07
103655	2N2	316.7	0.05
103655	OO1	336.1	0.14
103655	LDA2	54.3	0.04
103655	S1	52	0.1
103655	M1	296.7	0.1
103655	J1	314	0.14
103655	MM	141.5	0.04
103655	SSA	227.1	0.09
103655	SA	276.9	0.21
103655	RHO1	227.5	0.06
103655	Q1	250.5	0.23
103655	T2	44.5	0.04
103655	R2	300.5	0.01
103655	2Q1	276.3	0.01
103655	P1	281.1	0.79
103655	2SM2	285.2	0.01
103655	M3	235	0.01
103655	L2	56.2	0.1
103655	2MK3	110.7	0.02
103655	K2	34	0.16
103655	M8	113.6	0.01
103655	MS4	220.9	0.01
103656	M2	16.9	2.23
103656	S2	42.6	0.55
103656	N2	345.9	0.5
103656	K1	279.7	2.79
103656	M4	117.3	0.02
103656	O1	254.6	1.47
103656	S4	163.5	0.01
103656	NU2	350	0.1
103656	MU2	351	0.05
103656	2N2	315	0.07
103656	OO1	304.7	0.06
103656	LDA2	28.8	0.02
103656	M1	267.2	0.1
103656	J1	292.1	0.11
103656	SSA	236.5	0.08
103656	SA	280.1	0.16
103656	MF	132.4	0.08
103656	RHO1	244	0.06
103656	Q1	242.2	0.29
103656	T2	41.6	0.03
103656	2Q1	229.8	0.04
103656	P1	277.9	0.92
103656	L2	47.8	0.06
103656	K2	44.7	0.15
103657	M2	22.4	2.38
103657	S2	50.2	0.58
103657	N2	354.7	0.5
103657	K1	283.1	2.65
103657	M4	158.5	0.02
103657	O1	260.5	1.49
103657	M6	59.4	0.01
103657	MK3	12.7	0.01
103657	MN4	120	0.01
103657	NU2	2.2	0.1
103657	MU2	268	0.05
103657	2N2	326.9	0.06
103657	OO1	325.7	0.1
103657	LDA2	56.7	0.03
103657	S1	24.9	0.1
103657	M1	309.3	0.07
103657	J1	321.4	0.14
103657	MM	141.5	0.04
103657	SSA	227.1	0.09
103657	SA	276.9	0.21
103657	RHO1	253.7	0.05
103657	Q1	253.7	0.25
103657	T2	42.4	0.04
103657	2Q1	253.8	0.03
103657	P1	280.6	0.82
103657	2SM2	278.2	0.01
103657	L2	60.4	0.08
103657	2MK3	334.4	0.02
103657	K2	50.8	0.16
103657	MS4	164	0.01
103658	M2	27.1	2.55
103658	S2	54.4	0.62
103658	N2	359.7	0.53
103658	K1	285.6	2.77
103658	M4	174.6	0.02
103658	O1	261	1.53
103658	M6	68.4	0.02
103658	S4	199.3	0.01
103658	NU2	3.3	0.1
103658	MU2	359.8	0.06
103658	2N2	332.2	0.07
103658	OO1	310.1	0.07
103658	LDA2	39.8	0.02
103658	M1	273.4	0.11
103658	J1	297.8	0.12
103658	MM	141.5	0.04
103658	SSA	227.1	0.09
103658	SA	276.9	0.21
103658	RHO1	250.6	0.06
103658	Q1	248.8	0.3
103658	T2	53.3	0.04
103658	R2	55.5	0.01
103658	2Q1	236.8	0.04
103658	P1	283.7	0.92
103658	L2	54.4	0.07
103658	K2	56.6	0.17
103659	M2	24.8	2.5
103659	S2	53.2	0.61
103659	N2	355.8	0.54
103659	K1	286.3	2.57
103659	M4	126.4	0.01
103659	O1	262.3	1.44
103659	M6	26	0.01
103659	NU2	359.6	0.1
103659	MU2	356.4	0.06
103659	2N2	326.7	0.07
103659	OO1	310.3	0.06
103659	LDA2	38	0.02
103659	M1	274.3	0.1
103659	J1	298.2	0.11
103659	SSA	236.5	0.08
103659	SA	280.1	0.16
103659	MF	132.4	0.08
103659	RHO1	252	0.06
103659	Q1	250.3	0.28
103659	T2	52.1	0.04
103659	2Q1	238.4	0.04
103659	P1	284.5	0.85
103659	L2	53.9	0.07
103659	K2	55.6	0.17
103660	M2	15.4	2.03
103660	S2	41.3	0.49
103660	N2	348.7	0.42
103660	K1	281.3	2.58
103660	M4	139.4	0.05
103660	O1	259.1	1.45
103660	M6	201.9	0.01
103660	S4	178.1	0.01
103660	NU2	352.3	0.08
103660	MU2	349.6	0.05
103660	2N2	321.9	0.06
103660	OO1	303.6	0.06
103660	LDA2	27.4	0.01
103660	M1	270.3	0.1
103660	J1	292.3	0.11
103660	SSA	227.5	0.07
103660	SA	274.5	0.25
103660	MF	156.4	0.07
103660	RHO1	249.5	0.06
103660	Q1	248	0.28
103660	T2	40.3	0.03
103660	2Q1	236.9	0.04
103660	P1	279.6	0.85
103660	L2	42	0.06
103660	K2	43.4	0.13
103661	M2	4.7	1.87
103661	S2	28.3	0.44
103661	N2	337.9	0.38
103661	K1	277.7	2.5
103661	M4	143.8	0.05
103661	O1	255	1.39
103661	M6	195.4	0.03
103661	S4	169.3	0.01
103661	NU2	341.6	0.08
103661	S6	173.9	0.01
103661	MU2	341.2	0.05
103661	2N2	311.2	0.05
103661	OO1	300.4	0.06
103661	LDA2	15.6	0.01
103661	M1	266.4	0.1
103661	J1	289	0.11
103661	SSA	221	0.13
103661	SA	280.4	0.28
103661	RHO1	245.2	0.05
103661	Q1	243.7	0.27
103661	T2	27.3	0.03
103661	2Q1	232.4	0.04
103661	P1	276	0.83
103661	L2	31.4	0.05
103661	K2	30.1	0.12
103662	M2	357.2	1.73
103662	S2	17.7	0.41
103662	N2	324.8	0.37
103662	K1	275	2.46
103662	M4	87.1	0.06
103662	O1	253.3	1.43
103662	M6	206.1	0.03
103662	MK3	1.4	0.06
103662	S4	79.3	0.01
103662	MN4	53.6	0.03
103662	NU2	336.1	0.07
103662	MU2	245.4	0.08
103662	2N2	315.2	0.06
103662	OO1	316.2	0.1
103662	LDA2	53.8	0.04
103662	S1	11.8	0.08
103662	M1	293.2	0.05
103662	J1	302.9	0.11
103662	SSA	221	0.13
103662	SA	280.4	0.28
103662	RHO1	257.8	0.06
103662	Q1	244.4	0.24
103662	T2	20.5	0.03
103662	R2	281	0.01
103662	2Q1	205.5	0.04
103662	P1	270.9	0.74
103662	2SM2	277.5	0.01
103662	M3	300	0.03
103662	L2	58.4	0.06
103662	2MK3	11.8	0.06
103662	K2	36	0.11
103662	MS4	107.2	0.04
103663	M2	344.4	1.69
103663	S2	4.2	0.41
103663	N2	316.6	0.35
103663	K1	270.7	2.4
103663	M4	141.9	0.04
103663	O1	249.2	1.34
103663	M6	199.2	0.04
103663	S4	142	0.01
103663	NU2	320.3	0.07
103663	MU2	324.6	0.04
103663	2N2	288.9	0.05
103663	OO1	292.2	0.06
103663	LDA2	353.6	0.01
103663	M1	260	0.1
103663	J1	281.3	0.1
103663	SSA	221	0.13
103663	SA	280.4	0.28
103663	RHO1	240	0.05
103663	Q1	238.5	0.26
103663	T2	3.4	0.02
103663	2Q1	227.9	0.04
103663	P1	269.1	0.79
103663	L2	12	0.05
103663	K2	5.8	0.11
103664	M2	10.6	1.83
103664	S2	35.7	0.43
103664	N2	343	0.39
103664	K1	280.4	2.49
103664	M4	124.6	0.05
103664	O1	258.7	1.42
103664	M6	237.2	0.02
103664	MK3	27.5	0.04
103664	S4	157	0.01
103664	MN4	92	0.02
103664	NU2	350.1	0.08
103664	MU2	266.6	0.06
103664	2N2	309.4	0.04
103664	OO1	325.7	0.1
103664	LDA2	60	0.03
103664	S1	26.8	0.08
103664	M1	298	0.08
103664	J1	315.1	0.14
103664	MM	168.8	0.03
103664	SSA	227.5	0.07
103664	SA	274.5	0.25
103664	MSF	265.1	0.02
103664	MF	156.4	0.07
103664	RHO1	245.9	0.04
103664	Q1	250.7	0.24
103664	T2	39.9	0.04
103664	R2	313.6	0.01
103664	2Q1	253.5	0.03
103664	P1	278	0.77
103664	2SM2	289.1	0.01
103664	L2	52.4	0.07
103664	2MK3	19.5	0.03
103664	K2	44	0.11
103664	MS4	134	0.03
103665	M2	4.3	1.86
103665	S2	27	0.45
103665	N2	338	0.39
103665	K1	277.5	2.48
103665	M4	142.3	0.05
103665	O1	254.7	1.4
103665	M6	203.2	0.03
103665	S4	139.6	0.01
103665	NU2	341.5	0.08
103665	MU2	341.6	0.05
103665	2N2	311.6	0.05
103665	OO1	300.3	0.06
103665	LDA2	14.8	0.01
103665	M1	266.2	0.1
103665	J1	288.8	0.11
103665	SSA	221	0.13
103665	SA	280.4	0.28
103665	RHO1	245	0.05
103665	Q1	243.5	0.27
103665	T2	26	0.03
103665	2Q1	232.1	0.04
103665	P1	275.8	0.82
103665	L2	30.7	0.05
103665	K2	28.8	0.12
103666	M2	0.5	1.88
103666	S2	22	0.47
103666	N2	330.5	0.41
103666	K1	276.4	2.48
103666	M4	121.9	0.08
103666	O1	255.7	1.43
103666	M6	202.5	0.03
103666	MK3	24.6	0.1
103666	S4	149.6	0.01
103666	MN4	89.2	0.04
103666	NU2	340.1	0.08
103666	MU2	260.8	0.09
103666	2N2	279.6	0.05
103666	OO1	332.9	0.1
103666	LDA2	69.3	0.03
103666	S1	57.1	0.06
103666	M1	287.5	0.1
103666	J1	303.5	0.14
103666	MM	187.7	0.08
103666	SA	287.6	0.33
103666	MF	146.8	0.05
103666	RHO1	246	0.05
103666	Q1	245.9	0.25
103666	T2	24.5	0.03
103666	2Q1	243.5	0.02
103666	P1	274.9	0.8
103666	2SM2	317	0.01
103666	M3	44.6	0.02
103666	L2	53.1	0.07
103666	2MK3	15.7	0.07
103666	K2	38.7	0.13
103666	MS4	142.4	0.05
103667	M2	340.1	1.71
103667	S2	0.3	0.44
103667	N2	310.3	0.39
103667	K1	270.9	2.34
103667	M4	110	0.03
103667	O1	247.2	1.35
103667	M6	199.5	0.04
103667	MK3	53.3	0.05
103667	S4	134.6	0.01
103667	MN4	77.4	0.02
103667	NU2	321.4	0.07
103667	MU2	249.8	0.09
103667	2N2	259	0.04
103667	OO1	314.5	0.1
103667	LDA2	77.8	0.02
103667	S1	37	0.08
103667	M1	273.1	0.08
103667	J1	295.8	0.13
103667	MM	187.7	0.08
103667	SA	287.6	0.33
103667	MF	146.8	0.05
103667	RHO1	226.2	0.04
103667	Q1	237.2	0.23
103667	T2	7.4	0.03
103667	2Q1	234.4	0.02
103667	P1	267.4	0.73
103667	2SM2	314.7	0.01
103667	M3	91.7	0.01
103667	L2	50	0.08
103667	2MK3	35.6	0.07
103667	K2	8.1	0.09
103667	MS4	118.2	0.02
103668	M2	348.6	1.44
103668	S2	10	0.35
103668	N2	320.4	0.31
103668	K1	273.2	2.02
103668	M4	107.3	0.06
103668	O1	252.6	1.15
103668	M6	195.4	0.04
103668	S4	142	0.01
103668	NU2	324.2	0.06
103668	MU2	327.2	0.04
103668	2N2	292	0.04
103668	OO1	293.9	0.05
103668	LDA2	358.6	0.01
103668	M1	263	0.08
103668	J1	283.5	0.09
103668	SSA	221	0.13
103668	SA	280.4	0.28
103668	RHO1	243.7	0.04
103668	Q1	242.3	0.22
103668	T2	9.2	0.02
103668	2Q1	232	0.03
103668	P1	271.6	0.67
103668	L2	16.7	0.04
103668	K2	11.8	0.1
103669	M2	272.2	4.93
103669	S2	305.8	1.6
103669	N2	249.8	1.03
103669	K1	262.6	1.51
103669	M4	309.1	0.03
103669	O1	244.3	0.97
103669	M6	122.7	0.01
103669	S4	250	0.01
103669	NU2	252.8	0.2
103669	MU2	238.6	0.12
103669	2N2	227.3	0.14
103669	OO1	281	0.04
103669	LDA2	287.8	0.04
103669	M1	253.5	0.07
103669	J1	271.8	0.08
103669	SSA	161.1	0.1
103669	SA	273.7	0.38
103669	RHO1	236.4	0.04
103669	Q1	235.1	0.19
103669	T2	304.5	0.1
103669	R2	307.2	0.01
103669	2Q1	226	0.03
103669	P1	261.3	0.5
103669	L2	294.7	0.14
103669	K2	308.6	0.44
103669	M8	212.6	0.01
103670	M2	272.3	4.94
103670	S2	304.1	1.52
103670	N2	251.9	0.99
103670	K1	263.4	1.53
103670	M4	297.2	0.04
103670	O1	244.1	0.98
103670	M6	153.6	0.01
103670	S4	24.9	0.01
103670	NU2	254.7	0.19
103670	S6	43.9	0.01
103670	MU2	240.6	0.12
103670	2N2	231.6	0.13
103670	OO1	282.6	0.04
103670	LDA2	287.1	0.04
103670	M1	253.8	0.07
103670	J1	272.9	0.08
103670	SSA	161.1	0.1
103670	SA	273.7	0.38
103670	RHO1	235.9	0.04
103670	Q1	234.6	0.19
103670	T2	302.9	0.09
103670	R2	305.4	0.01
103670	2Q1	225	0.03
103670	P1	261.9	0.51
103670	L2	292.7	0.14
103670	K2	306.7	0.41
103670	M8	215	0.01
103671	M2	268.7	6.04
103671	S2	299.5	1.92
103671	N2	242.3	1.16
103671	K1	262.5	1.68
103671	M4	289	0.04
103671	O1	244.5	1
103671	M6	233.4	0.01
103671	S4	9.2	0.02
103671	NU2	245.8	0.23
103671	MU2	335.3	0.14
103671	2N2	215.9	0.15
103671	OO1	280.6	0.04
103671	LDA2	283	0.04
103671	M1	253.6	0.07
103671	J1	271.5	0.08
103671	SSA	161.1	0.1
103671	SA	273.7	0.38
103671	MF	173	0.09
103671	RHO1	236.7	0.04
103671	Q1	235.5	0.19
103671	T2	298.3	0.11
103671	R2	300.8	0.02
103671	2Q1	226.5	0.03
103671	P1	261.2	0.55
103671	L2	295	0.17
103671	K2	302	0.52
103672	M2	269.2	5.93
103672	S2	304.5	1.9
103672	N2	241.6	1.18
103672	K1	257.6	1.66
103672	M4	310.2	0.03
103672	O1	245.3	1
103672	S4	26.3	0.02
103672	NU2	245.3	0.23
103672	MU2	330.7	0.14
103672	2N2	214.1	0.16
103672	OO1	270	0.04
103672	LDA2	285.6	0.04
103672	M1	251.5	0.07
103672	J1	263.8	0.08
103672	SSA	161.1	0.1
103672	SA	273.7	0.38
103672	RHO1	240	0.04
103672	Q1	239.1	0.19
103672	T2	303.1	0.11
103672	R2	305.9	0.02
103672	2Q1	233	0.03
103672	P1	256.7	0.55
103672	L2	296.7	0.17
103672	K2	307.4	0.52
103672	M8	202.9	0.01
103673	M2	272.6	5
103673	S2	304.2	1.54
103673	N2	253.4	1.04
103673	K1	261.7	1.58
103673	M4	262.3	0.04
103673	O1	248.4	1
103673	M6	100.2	0.02
103673	S4	316.9	0.01
103673	NU2	255.9	0.2
103673	MU2	241	0.12
103673	2N2	234.1	0.14
103673	OO1	275.1	0.04
103673	LDA2	287.3	0.04
103673	M1	255.1	0.07
103673	J1	268.4	0.08
103673	SSA	161.1	0.1
103673	SA	273.1	0.38
103673	MF	173	0.09
103673	RHO1	242.7	0.04
103673	Q1	241.8	0.19
103673	T2	302.9	0.09
103673	R2	305.5	0.01
103673	2Q1	235.2	0.03
103673	P1	260.7	0.52
103673	L2	291.9	0.14
103673	K2	306.8	0.42
103673	M8	224.5	0.01
103674	M2	270.1	6.17
103674	S2	301.8	2.05
103674	N2	245.6	1.25
103674	K1	261.1	1.68
103674	M4	291.6	0.05
103674	O1	244.9	1.02
103674	MK3	9.8	0.02
103674	S4	16.3	0.01
103674	MN4	273.2	0.02
103674	NU2	250	0.24
103674	MU2	231.3	0.13
103674	2N2	219.6	0.15
103674	OO1	292.1	0.06
103674	LDA2	277.9	0.04
103674	S1	45	0.05
103674	M1	276.3	0.05
103674	J1	275.5	0.1
103674	SSA	161.1	0.1
103674	SA	273.7	0.38
103674	MF	173	0.09
103674	RHO1	241	0.04
103674	Q1	237.4	0.18
103674	T2	296.9	0.11
103674	R2	340.5	0.03
103674	2Q1	236.6	0.02
103674	P1	258.5	0.53
103674	2SM2	98.5	0.01
103674	M3	336.4	0.06
103674	L2	281.3	0.14
103674	2MK3	53.1	0.01
103674	K2	295.2	0.56
103674	MS4	332.5	0.04
103675	M2	269.5	3.72
103675	S2	301.6	1.16
103675	N2	241.2	0.77
103675	K1	263.1	1.38
103675	M4	283.5	0.01
103675	O1	245.8	0.9
103675	NU2	245	0.15
103675	MU2	331.5	0.09
103675	2N2	212.9	0.1
103675	OO1	280.5	0.04
103675	LDA2	284.4	0.03
103675	M1	254.5	0.07
103675	J1	271.8	0.07
103675	RHO1	238.3	0.04
103675	Q1	237.2	0.17
103675	T2	300.3	0.07
103675	R2	302.9	0.01
103675	2Q1	228.5	0.02
103675	P1	261.8	0.46
103675	L2	297.8	0.1
103675	K2	304.2	0.31
103675	M8	15.6	0.01
103676	M2	269.3	3.72
103676	S2	301.2	1.1
103676	N2	243	0.78
103676	K1	263.2	1.45
103676	M4	294.3	0.01
103676	O1	247	0.89
103676	NU2	246.5	0.15
103676	MU2	331.2	0.09
103676	2N2	216.7	0.1
103676	OO1	279.4	0.04
103676	LDA2	284.1	0.03
103676	M1	255.1	0.06
103676	J1	271.2	0.07
103676	RHO1	240	0.03
103676	Q1	239	0.17
103676	T2	299.9	0.07
103676	R2	302.5	0.01
103676	2Q1	230.9	0.02
103676	P1	262	0.48
103676	L2	295.7	0.1
103676	K2	303.8	0.3
103677	M2	272.9	6.35
103677	S2	304.3	2.22
103677	N2	246.8	1.35
103677	K1	260.9	1.74
103677	M4	272.3	0.11
103677	O1	246.4	1
103677	M6	355	0.01
103677	S4	41.9	0.02
103677	NU2	250.3	0.26
103677	MU2	336.5	0.15
103677	2N2	220.8	0.18
103677	OO1	275.5	0.04
103677	LDA2	287.5	0.05
103677	M1	253.7	0.07
103677	J1	268.1	0.08
103677	SSA	161.1	0.1
103677	SA	273.7	0.38
103677	RHO1	240.2	0.04
103677	Q1	239.2	0.19
103677	T2	303	0.13
103677	R2	305.5	0.02
103677	2Q1	232	0.03
103677	P1	259.8	0.57
103677	L2	298.9	0.18
103677	K2	306.8	0.6
103678	M2	271.3	6.12
103678	S2	305	2
103678	N2	249.6	1.26
103678	K1	262.3	1.57
103678	M4	334.2	0.05
103678	O1	243.2	1.01
103678	M6	31.7	0.01
103678	S4	314.3	0.01
103678	NU2	252.5	0.24
103678	S6	315.5	0.01
103678	MU2	237.5	0.15
103678	2N2	227.9	0.17
103678	OO1	281.4	0.04
103678	LDA2	286.9	0.04
103678	M1	252.9	0.07
103678	J1	271.8	0.08
103678	SSA	161.1	0.1
103678	SA	273.7	0.38
103678	RHO1	235.1	0.04
103678	Q1	233.8	0.2
103678	T2	303.7	0.12
103678	R2	306.4	0.02
103678	2Q1	224.3	0.03
103678	P1	260.9	0.52
103678	L2	293	0.17
103678	K2	307.8	0.54
103678	M8	18	0.01
103679	M2	267.2	3.86
103679	S2	301.5	1.25
103679	N2	240.8	0.75
103679	K1	260.3	1.38
103679	M4	236	0.02
103679	O1	244.5	0.87
103679	M6	59.1	0.01
103679	NU2	244.4	0.15
103679	S6	23	0.01
103679	MU2	326.4	0.09
103679	2N2	214.4	0.1
103679	OO1	276.2	0.04
103679	LDA2	283.1	0.03
103679	M1	252.5	0.06
103679	J1	268.2	0.07
103679	RHO1	237.7	0.03
103679	Q1	236.6	0.17
103679	T2	300.1	0.08
103679	R2	302.8	0.01
103679	2Q1	228.7	0.02
103679	P1	259.1	0.46
103679	L2	293.7	0.11
103679	K2	304.3	0.34
103680	M2	271.7	6.44
103680	S2	304.8	2.1
103680	N2	244.6	1.33
103680	K1	262.9	1.6
103680	M4	269	0.16
103680	O1	244.8	1.02
103680	M6	351.3	0.01
103680	S4	295.2	0.03
103680	NU2	248.2	0.26
103680	S6	225	0.01
103680	MU2	334.3	0.15
103680	2N2	217.4	0.18
103680	OO1	281.1	0.04
103680	LDA2	287.1	0.05
103680	M1	253.9	0.07
103680	J1	272	0.08
103680	RHO1	237	0.04
103680	Q1	235.8	0.2
103680	T2	303.4	0.12
103680	R2	306.1	0.02
103680	2Q1	226.7	0.03
103680	P1	261.6	0.53
103680	L2	298.9	0.18
103680	K2	307.4	0.57
103681	M2	268.5	6.62
103681	S2	301.2	2.29
103681	N2	244.5	1.31
103681	K1	260.7	1.69
103681	M4	264.8	0.03
103681	O1	245	1
103681	M6	150.5	0.02
103681	S4	357.6	0.01
103681	NU2	247.7	0.25
103681	MU2	235.9	0.16
103681	2N2	220.4	0.17
103681	OO1	276.3	0.04
103681	LDA2	283.7	0.05
103681	M1	252.9	0.07
103681	J1	268.5	0.08
103681	SSA	161.1	0.1
103681	SA	273.7	0.38
103681	MF	173	0.09
103681	RHO1	238.3	0.04
103681	Q1	237.2	0.19
103681	T2	299.9	0.13
103681	R2	302.5	0.02
103681	2Q1	229.4	0.03
103681	P1	259.5	0.56
103681	L2	292.6	0.18
103681	K2	303.8	0.62
103681	M8	349.2	0.01
103682	M2	270.4	6.37
103682	S2	305.4	2.15
103682	N2	242.4	1.3
103682	K1	260.2	1.58
103682	M4	268.8	0.08
103682	O1	244.8	1.01
103682	S4	280.3	0.03
103682	NU2	246.2	0.25
103682	S6	214.5	0.01
103682	MU2	235.4	0.15
103682	2N2	214.4	0.17
103682	OO1	275.5	0.04
103682	LDA2	286.6	0.05
103682	M1	252.5	0.07
103682	J1	267.8	0.08
103682	RHO1	238.2	0.04
103682	Q1	237.2	0.2
103682	T2	304	0.13
103682	R2	306.8	0.02
103682	2Q1	229.6	0.03
103682	P1	259	0.52
103682	L2	298.4	0.18
103682	K2	308.2	0.58
103682	M8	336.6	0.01
103683	M2	272.3	6.49
103683	S2	302.7	2.15
103683	N2	241.3	1.17
103683	K1	261.7	1.71
103683	M4	297.1	0.13
103683	O1	245.5	1.03
103683	M6	13.6	0.01
103683	S4	290.6	0.04
103683	NU2	245.4	0.23
103683	MU2	337.8	0.16
103683	2N2	210.2	0.15
103683	OO1	277.8	0.05
103683	LDA2	286.4	0.05
103683	M1	253.7	0.07
103683	J1	269.7	0.08
103683	RHO1	238.6	0.04
103683	Q1	237.5	0.2
103683	T2	301.5	0.13
103683	R2	303.9	0.02
103683	2Q1	229.5	0.03
103683	P1	260.5	0.56
103683	L2	303.4	0.18
103683	K2	305.2	0.58
103683	M8	220.8	0.02
103684	M2	271.3	4.18
103684	S2	304.9	1.42
103684	N2	250.1	0.9
103684	K1	260.5	1.41
103684	M4	260.4	0.02
103684	O1	247.1	0.91
103684	M6	46.3	0.03
103684	NU2	253	0.17
103684	S6	47.8	0.01
103684	MU2	237.7	0.1
103684	2N2	229	0.12
103684	OO1	274.1	0.04
103684	LDA2	286.9	0.03
103684	M1	253.9	0.07
103684	J1	267.3	0.07
103684	SSA	161.1	0.1
103684	SA	273.7	0.38
103684	MF	173	0.09
103684	RHO1	241.3	0.03
103684	Q1	240.4	0.17
103684	T2	303.5	0.08
103684	R2	306.2	0.01
103684	2Q1	233.7	0.02
103684	P1	259.5	0.47
103684	L2	292.5	0.12
103684	K2	307.6	0.39
103684	M8	268.9	0.01
103685	M2	273	4.44
103685	S2	307	1.52
103685	N2	252.1	0.95
103685	K1	261.3	1.43
103685	M4	217.1	0.02
103685	O1	248	0.92
103685	M6	104.2	0.03
103685	NU2	254.8	0.18
103685	MU2	238.9	0.1
103685	2N2	231.2	0.12
103685	OO1	274.7	0.04
103685	LDA2	288.8	0.03
103685	M1	254.8	0.07
103685	J1	268	0.07
103685	SSA	161.1	0.1
103685	SA	273.7	0.38
103685	MF	173	0.09
103685	RHO1	242.3	0.04
103685	Q1	241.4	0.18
103685	T2	305.7	0.09
103685	R2	308.4	0.01
103685	2Q1	234.8	0.02
103685	P1	260.3	0.47
103685	L2	293.9	0.12
103685	K2	309.7	0.41
103685	M8	223.8	0.01
103686	M2	272.7	6.42
103686	S2	303.4	2.18
103686	N2	247	1.27
103686	K1	263.6	1.76
103686	M4	267.2	0.15
103686	O1	246.4	1.04
103686	M6	300.2	0.01
103686	S4	346.7	0.02
103686	NU2	250.5	0.25
103686	MU2	336.6	0.15
103686	2N2	221.4	0.17
103686	OO1	281	0.05
103686	LDA2	286.9	0.05
103686	M1	255.1	0.08
103686	J1	272.3	0.08
103686	RHO1	239	0.04
103686	Q1	237.8	0.2
103686	T2	302.1	0.13
103686	R2	304.6	0.02
103686	2Q1	229.2	0.03
103686	P1	262.3	0.58
103686	L2	298.3	0.18
103686	K2	305.8	0.59
103686	M8	158.8	0.01
103687	M2	274.7	6.77
103687	S2	305.2	2.18
103687	N2	251.1	1.33
103687	K1	262	1.64
103687	M4	249.1	0.11
103687	O1	249.8	1.02
103687	M6	352.6	0.03
103687	S4	44.6	0.08
103687	NU2	254.3	0.26
103687	S6	92.5	0.03
103687	MU2	341	0.16
103687	2N2	227.6	0.18
103687	OO1	274.1	0.04
103687	LDA2	288.9	0.05
103687	M1	256	0.07
103687	J1	268	0.08
103687	RHO1	244.6	0.04
103687	Q1	243.8	0.2
103687	T2	304	0.13
103687	R2	306.4	0.02
103687	2Q1	237.8	0.03
103687	P1	261.1	0.54
103687	L2	298.2	0.19
103687	K2	307.7	0.59
103687	M8	53.4	0.02
103688	M2	273.4	6.55
103688	S2	304.1	2.17
103688	N2	246.4	1.37
103688	K1	263.4	1.73
103688	M4	260.5	0.2
103688	O1	245.9	1.04
103688	M6	11.2	0.02
103688	S4	14.8	0.04
103688	NU2	250	0.27
103688	MU2	338	0.16
103688	2N2	219.4	0.18
103688	OO1	280.8	0.05
103688	LDA2	287.6	0.05
103688	M1	254.7	0.08
103688	J1	272	0.08
103688	RHO1	238.5	0.04
103688	Q1	237.3	0.2
103688	T2	302.9	0.13
103688	R2	305.3	0.02
103688	2Q1	228.6	0.03
103688	P1	262.1	0.57
103688	L2	300.3	0.18
103688	K2	306.6	0.59
103688	M8	13	0.01
103689	M2	275.7	4.07
103689	S2	307.6	1.35
103689	N2	251.3	0.84
103689	K1	263.1	1.53
103689	M4	281.4	0.01
103689	O1	248	0.94
103689	M6	138	0.01
103689	MK3	258.9	0.02
103689	NU2	255.7	0.16
103689	MU2	233.2	0.1
103689	2N2	226.1	0.1
103689	OO1	295.2	0.05
103689	LDA2	292.1	0.02
103689	S1	43.1	0.03
103689	M1	275.9	0.05
103689	J1	275.4	0.09
103689	SA	271.1	0.35
103689	MF	196.8	0.1
103689	RHO1	238.8	0.03
103689	Q1	240.5	0.17
103689	T2	298	0.07
103689	2Q1	238	0.02
103689	P1	260	0.48
103689	2SM2	91.7	0.01
103689	M3	326.3	0.01
103689	L2	287.6	0.09
103689	2MK3	212.9	0.02
103689	K2	300.2	0.36
103689	MS4	340.5	0.01
103690	M2	270.7	5.84
103690	S2	301.4	1.97
103690	N2	244	1.16
103690	K1	262.3	1.7
103690	M4	227.9	0.09
103690	O1	246.4	0.99
103690	M6	65.2	0.02
103690	S4	16	0.02
103690	NU2	247.6	0.22
103690	S6	34.8	0.01
103690	MU2	333.9	0.14
103690	2N2	217.4	0.15
103690	OO1	278.5	0.04
103690	LDA2	284.9	0.04
103690	M1	254.5	0.07
103690	J1	270.4	0.08
103690	RHO1	239.5	0.04
103690	Q1	238.5	0.19
103690	T2	300.2	0.11
103690	R2	302.7	0.02
103690	2Q1	230.5	0.03
103690	P1	261.1	0.56
103690	L2	297.3	0.16
103690	K2	303.9	0.54
103690	M8	356.2	0.01
103691	M2	273.2	6.41
103691	S2	304.1	2.15
103691	N2	250.5	1.21
103691	K1	264.1	1.79
103691	M4	262.6	0.15
103691	O1	246.4	1.02
103691	M6	353.1	0.01
103691	S4	348	0.02
103691	NU2	253.6	0.24
103691	MU2	337.2	0.15
103691	2N2	227.9	0.16
103691	OO1	281.8	0.04
103691	LDA2	287.5	0.05
103691	M1	255.3	0.07
103691	J1	272.9	0.08
103691	RHO1	238.8	0.04
103691	Q1	237.6	0.2
103691	T2	302.8	0.13
103691	R2	305.3	0.02
103691	2Q1	228.9	0.03
103691	P1	262.8	0.59
103691	L2	295.9	0.18
103691	K2	306.6	0.58
103691	M8	111.6	0.01
103692	M2	274.4	6.51
103692	S2	304.5	2.23
103692	N2	247.3	1.3
103692	K1	263.9	1.78
103692	M4	275.8	0.17
103692	O1	247.5	1.04
103692	M6	23.3	0.02
103692	S4	324.7	0.04
103692	NU2	250.9	0.25
103692	MU2	340.1	0.16
103692	2N2	220.1	0.17
103692	OO1	280.3	0.05
103692	LDA2	288.4	0.05
103692	M1	255.8	0.08
103692	J1	272	0.08
103692	RHO1	240.5	0.04
103692	Q1	239.4	0.2
103692	T2	303.3	0.13
103692	R2	305.7	0.02
103692	2Q1	231.3	0.03
103692	P1	262.7	0.59
103692	L2	301.6	0.18
103692	K2	306.9	0.61
103692	M8	84	0.01
103693	M2	273.4	6.45
103693	S2	304.2	2.13
103693	N2	245.3	1.34
103693	K1	264.1	1.73
103693	M4	260.5	0.21
103693	O1	246.3	1.03
103693	M6	13.1	0.01
103693	S4	18.8	0.04
103693	NU2	249.1	0.26
103693	MU2	337.8	0.15
103693	2N2	217.2	0.18
103693	OO1	281.9	0.05
103693	LDA2	287.7	0.05
103693	M1	255.3	0.07
103693	J1	272.9	0.08
103693	RHO1	238.7	0.04
103693	Q1	237.5	0.2
103693	T2	303	0.12
103693	R2	305.5	0.02
103693	2Q1	228.7	0.03
103693	P1	262.8	0.57
103693	L2	301.5	0.18
103693	K2	306.7	0.58
103693	M8	224.5	0.01
103694	M2	273.4	4.93
103694	S2	303.7	1.69
103694	N2	252.1	1
103694	K1	261	1.57
103694	M4	243	0.07
103694	O1	247.6	0.93
103694	M6	108.4	0.02
103694	NU2	255	0.19
103694	MU2	335.5	0.12
103694	2N2	230.8	0.13
103694	OO1	274.4	0.04
103694	LDA2	287.5	0.04
103694	M1	254.4	0.07
103694	J1	267.6	0.07
103694	RHO1	241.9	0.04
103694	Q1	241	0.18
103694	T2	302.5	0.1
103694	R2	305	0.01
103694	2Q1	234.3	0.02
103694	P1	260	0.52
103694	L2	294.7	0.14
103694	K2	306.2	0.46
103694	M8	89.9	0.02
103695	M2	275.4	6.01
103695	S2	306.1	2.06
103695	N2	253.1	1.21
103695	K1	262.6	1.64
103695	M4	246.3	0.19
103695	O1	248.3	1
103695	M6	40.9	0.01
103695	S4	323.7	0.02
103695	NU2	256.1	0.24
103695	S6	209	0.01
103695	MU2	338.8	0.14
103695	2N2	230.7	0.16
103695	OO1	276.8	0.04
103695	LDA2	289.6	0.04
103695	M1	255.5	0.07
103695	J1	269.6	0.08
103695	RHO1	242.2	0.04
103695	Q1	241.2	0.19
103695	T2	304.9	0.12
103695	R2	307.3	0.02
103695	2Q1	234.1	0.03
103695	P1	261.5	0.54
103695	L2	297.8	0.17
103695	K2	308.6	0.56
103695	M8	150.4	0.01
103696	M2	279.1	6.15
103696	S2	311.1	2.12
103696	N2	257.6	1.23
103696	K1	264.9	1.64
103696	M4	254.2	0.2
103696	O1	250.6	1.01
103696	M6	86.1	0.03
103696	S4	336.5	0.02
103696	NU2	260.5	0.24
103696	S6	219	0.01
103696	MU2	341.2	0.15
103696	2N2	236.1	0.16
103696	OO1	279.1	0.04
103696	LDA2	294	0.04
103696	M1	257.8	0.07
103696	J1	271.9	0.08
103696	RHO1	244.5	0.04
103696	Q1	243.6	0.2
103696	T2	309.8	0.12
103696	R2	312.4	0.02
103696	2Q1	236.5	0.03
103696	P1	263.8	0.54
103696	L2	300.6	0.17
103696	K2	313.7	0.57
103696	M8	116.5	0.01
103697	M2	290.7	6.25
103697	S2	326.8	2.16
103697	N2	273.2	1.26
103697	K1	271.5	1.61
103697	M4	159.6	0.11
103697	O1	257.6	1.03
103697	M6	116.8	0.11
103697	S4	239.1	0.04
103697	NU2	275.5	0.25
103697	S6	251.1	0.01
103697	MU2	348.7	0.15
103697	2N2	255.7	0.17
103697	OO1	285.5	0.05
103697	LDA2	307.4	0.04
103697	M1	264.6	0.07
103697	J1	278.4	0.08
103697	RHO1	251.6	0.04
103697	Q1	250.6	0.2
103697	T2	325.4	0.13
103697	R2	328.3	0.02
103697	2Q1	243.7	0.03
103697	P1	270.5	0.53
103697	L2	308.2	0.17
103697	K2	329.7	0.59
103697	M8	39.7	0.01
103698	M2	293	6.39
103698	S2	329.2	2.21
103698	N2	275.8	1.28
103698	K1	271.8	1.61
103698	M4	132.6	0.18
103698	O1	258.8	1.03
103698	M6	127	0.13
103698	S4	241.1	0.06
103698	NU2	278.1	0.25
103698	S6	10.9	0.01
103698	MU2	351	0.15
103698	2N2	258.7	0.17
103698	OO1	284.8	0.05
103698	LDA2	309.8	0.05
103698	M1	265.3	0.07
103698	J1	278.2	0.08
103698	SSA	161.1	0.1
103698	SA	273.7	0.38
103698	RHO1	253.2	0.04
103698	Q1	252.3	0.2
103698	T2	327.8	0.13
103698	R2	330.7	0.02
103698	2Q1	245.8	0.03
103698	P1	270.8	0.53
103698	L2	310.2	0.18
103698	K2	332.1	0.6
103698	M8	345.4	0.03
103699	M2	286.9	5.98
103699	S2	320.7	2.09
103699	N2	266.6	1.21
103699	K1	266.5	1.64
103699	M4	15.3	0.1
103699	O1	252.4	0.98
103699	M6	82.5	0.11
103699	S4	166.8	0.01
103699	NU2	269.4	0.24
103699	MU2	345.7	0.14
103699	2N2	246.3	0.16
103699	OO1	280.6	0.04
103699	LDA2	302.6	0.04
103699	M1	259.5	0.07
103699	J1	273.5	0.08
103699	RHO1	246.4	0.04
103699	Q1	245.4	0.19
103699	T2	319.3	0.12
103699	R2	322	0.02
103699	2Q1	238.5	0.03
103699	P1	265.5	0.54
103699	L2	307.2	0.17
103699	K2	323.4	0.57
103699	M8	88.1	0.02
103700	M2	272.7	3.53
103700	S2	305	1.1
103700	N2	248.3	0.72
103700	K1	261.2	1.4
103700	O1	243.2	0.88
103700	NU2	251.6	0.14
103700	S6	149.3	0.01
103700	MU2	329.6	0.09
103700	2N2	224	0.1
103700	OO1	279.3	0.04
103700	LDA2	287.7	0.03
103700	M1	252.3	0.06
103700	J1	270.2	0.07
103700	RHO1	235.4	0.03
103700	Q1	234.2	0.17
103700	T2	303.7	0.07
103700	R2	306.3	0.01
103700	2Q1	225.3	0.02
103700	P1	259.9	0.47
103700	L2	297.1	0.1
103700	K2	307.6	0.3
103700	M8	120.9	0.01
103701	M2	283	6.42
103701	S2	319.7	2.1
103701	N2	263.4	1.24
103701	K1	267.9	1.59
103701	M4	47.5	0.12
103701	O1	250.7	0.98
103701	M6	284.1	0.02
103701	S4	130.5	0.02
103701	NU2	266	0.24
103701	MU2	341.4	0.15
103701	2N2	243.7	0.16
103701	OO1	285	0.04
103701	LDA2	300	0.05
103701	M1	259.4	0.07
103701	J1	276.4	0.08
103701	RHO1	243.4	0.04
103701	Q1	242.2	0.19
103701	T2	318.2	0.12
103701	R2	321.1	0.02
103701	2Q1	233.7	0.03
103701	P1	266.6	0.52
103701	L2	302.7	0.18
103701	K2	322.6	0.57
103701	M8	130.7	0.01
103702	M2	287	6.3
103702	S2	322.2	2
103702	N2	264.4	1.14
103702	K1	272.4	1.69
103702	M4	112.2	0.08
103702	O1	253.4	0.97
103702	M6	125.3	0.09
103702	S4	142.1	0.02
103702	NU2	267.5	0.22
103702	S6	15.9	0.01
103702	MU2	345.9	0.15
103702	2N2	241.9	0.15
103702	OO1	291.3	0.04
103702	LDA2	303.3	0.04
103702	M1	263	0.07
103702	J1	281.8	0.08
103702	RHO1	245.3	0.04
103702	Q1	244	0.19
103702	T2	320.8	0.12
103702	R2	323.6	0.02
103702	2Q1	234.6	0.03
103702	P1	270.9	0.56
103702	L2	309.6	0.18
103702	K2	325	0.54
103702	M8	28	0.02
103703	M2	279.7	5.75
103703	S2	313.2	1.77
103703	N2	255.9	1.1
103703	K1	265.8	1.58
103703	M4	354.3	0.07
103703	O1	247.4	0.98
103703	M6	77.5	0.02
103703	S4	53.2	0.01
103703	NU2	259.1	0.21
103703	MU2	338.6	0.14
103703	2N2	232	0.15
103703	OO1	284.2	0.04
103703	LDA2	295.3	0.04
103703	M1	256.7	0.07
103703	J1	274.9	0.08
103703	RHO1	239.5	0.04
103703	Q1	238.3	0.19
103703	T2	311.9	0.1
103703	R2	314.6	0.01
103703	2Q1	229.2	0.03
103703	P1	264.4	0.52
103703	L2	303.5	0.16
103703	K2	315.9	0.48
103703	M8	36	0.02
103704	M2	279.7	4.95
103704	S2	316.1	1.68
103704	N2	252.1	0.98
103704	K1	264	1.53
103704	M4	14.6	0.1
103704	O1	247.7	0.98
103704	M6	38.3	0.02
103704	NU2	255.8	0.19
103704	MU2	243.3	0.12
103704	2N2	224.5	0.13
103704	OO1	280.3	0.04
103704	LDA2	296.6	0.04
103704	M1	255.9	0.07
103704	J1	272.1	0.08
103704	RHO1	240.7	0.04
103704	Q1	239.7	0.19
103704	T2	314.6	0.1
103704	R2	317.5	0.01
103704	2Q1	231.6	0.03
103704	P1	262.8	0.51
103704	L2	307.3	0.14
103704	K2	319	0.46
103705	M2	276.3	5.3
103705	S2	305.7	1.77
103705	N2	254.1	0.96
103705	K1	262.8	1.69
103705	M4	358.1	0.08
103705	O1	246.5	0.94
103705	S4	46.9	0.01
103705	NU2	257.1	0.19
103705	MU2	247	0.13
103705	2N2	232	0.13
103705	OO1	279.1	0.04
103705	LDA2	289.9	0.04
103705	M1	254.7	0.07
103705	J1	270.8	0.08
103705	SA	274.8	0.4
103705	MF	176.8	0.09
103705	RHO1	239.5	0.04
103705	Q1	238.4	0.18
103705	T2	304.5	0.1
103705	R2	306.8	0.01
103705	2Q1	230.3	0.02
103705	P1	261.5	0.56
103705	L2	298.5	0.15
103705	K2	308	0.48
103705	M8	144.6	0.01
103706	M2	279.4	5.65
103706	S2	313.6	1.88
103706	N2	254.3	1.21
103706	K1	259.9	1.63
103706	M4	21.8	0.1
103706	O1	251.2	0.99
103706	M6	285	0.01
103706	S4	39.1	0.02
103706	NU2	257.6	0.24
103706	MU2	337.3	0.13
103706	2N2	229.2	0.16
103706	OO1	268.5	0.04
103706	LDA2	295.3	0.04
103706	M1	255.6	0.07
103706	J1	264.1	0.08
103706	RHO1	247.5	0.04
103706	Q1	246.9	0.19
103706	T2	312.3	0.11
103706	R2	315	0.02
103706	2Q1	242.7	0.03
103706	P1	259.2	0.54
103706	L2	304.4	0.16
103706	K2	316.4	0.51
103707	M2	273.8	3.63
103707	S2	304.9	1.16
103707	N2	249.2	0.75
103707	K1	259.9	1.52
103707	O1	244.4	0.92
103707	NU2	253.6	0.14
103707	MU2	228.7	0.09
103707	2N2	223.8	0.09
103707	OO1	289.1	0.05
103707	LDA2	293	0.03
103707	S1	35.3	0.04
103707	M1	273.4	0.05
103707	J1	272.9	0.09
103707	SA	274.8	0.4
103707	MF	176.8	0.09
103707	RHO1	238.9	0.03
103707	Q1	237.2	0.16
103707	T2	296.6	0.07
103707	R2	306	0.01
103707	2Q1	240.5	0.02
103707	P1	257.6	0.48
103707	L2	288.8	0.08
103707	K2	298.4	0.32
103708	M2	279.3	5.39
103708	S2	310	1.88
103708	N2	255.5	1.07
103708	K1	262.3	1.6
103708	M4	0.6	0.07
103708	O1	248.7	0.96
103708	M6	299.9	0.01
103708	NU2	258.7	0.21
103708	MU2	338.9	0.13
103708	2N2	231.8	0.14
103708	OO1	275.9	0.04
103708	LDA2	293.6	0.04
103708	M1	255.5	0.07
103708	J1	269.1	0.08
103708	RHO1	242.8	0.04
103708	Q1	241.9	0.19
103708	T2	308.8	0.11
103708	R2	311.3	0.02
103708	2Q1	235.1	0.03
103708	P1	261.3	0.53
103708	L2	303	0.15
103708	K2	312.5	0.51
103708	M8	135	0.01
103709	M2	276.6	3.64
103709	S2	309.7	1.14
103709	N2	248.8	0.75
103709	K1	264	1.44
103709	M4	139.4	0.01
103709	O1	246.7	0.94
103709	M6	24.8	0.01
103709	S4	219.3	0.01
103709	NU2	252.5	0.14
103709	MU2	243.4	0.09
103709	2N2	221	0.1
103709	OO1	281.2	0.04
103709	LDA2	291.9	0.03
103709	M1	255.4	0.07
103709	J1	272.5	0.07
103709	SA	274.8	0.4
103709	MF	176.8	0.09
103709	RHO1	239.3	0.04
103709	Q1	238.1	0.18
103709	T2	308.4	0.07
103709	R2	311.1	0.01
103709	2Q1	229.6	0.02
103709	P1	262.7	0.48
103709	L2	304.3	0.1
103709	K2	312.4	0.31
103709	M8	152.8	0.01
103710	M2	280	5.89
103710	S2	312.8	1.94
103710	N2	257.6	1.2
103710	K1	264.3	1.64
103710	M4	8.1	0.09
103710	O1	248.5	0.99
103710	M6	219.6	0.01
103710	S4	31.1	0.02
103710	NU2	260.6	0.23
103710	MU2	247.3	0.14
103710	2N2	235.1	0.16
103710	OO1	280.1	0.04
103710	LDA2	295.3	0.04
103710	M1	256.5	0.07
103710	J1	272.2	0.08
103710	SA	255.6	0.26
103710	MF	176.1	0.08
103710	RHO1	241.7	0.04
103710	Q1	240.7	0.19
103710	T2	311.5	0.11
103710	R2	314.1	0.02
103710	2Q1	232.8	0.03
103710	P1	263.1	0.54
103710	L2	302.3	0.16
103710	K2	315.5	0.53
103711	M2	273.5	3.56
103711	S2	304.8	1.13
103711	N2	251	0.76
103711	K1	263.8	1.56
103711	O1	244.4	0.96
103711	M6	341.2	0.01
103711	NU2	254	0.15
103711	MU2	330.9	0.09
103711	2N2	228.4	0.1
103711	OO1	283.2	0.04
103711	LDA2	288	0.03
103711	M1	254.1	0.07
103711	J1	273.4	0.08
103711	SA	274.8	0.4
103711	MF	176.8	0.09
103711	RHO1	236	0.04
103711	Q1	234.7	0.19
103711	T2	303.5	0.07
103711	R2	306	0.01
103711	2Q1	225.1	0.03
103711	P1	262.3	0.52
103711	L2	296.1	0.1
103711	K2	307.3	0.31
103712	M2	282.4	4.91
103712	S2	314.5	1.61
103712	N2	261.2	1.06
103712	K1	266.2	1.66
103712	M4	35	0.11
103712	O1	247.8	0.97
103712	M6	167.5	0.04
103712	S4	41	0.01
103712	NU2	264.1	0.21
103712	MU2	339	0.12
103712	2N2	240.1	0.14
103712	OO1	284.6	0.04
103712	LDA2	297.3	0.03
103712	M1	257.1	0.07
103712	J1	275.4	0.08
103712	SA	274.8	0.4
103712	MF	176.8	0.09
103712	RHO1	239.9	0.04
103712	Q1	238.7	0.19
103712	T2	313.2	0.1
103712	R2	315.7	0.01
103712	2Q1	229.6	0.03
103712	P1	264.9	0.55
103712	L2	303.5	0.14
103712	K2	317.1	0.44
103712	M8	268.2	0.01
103713	M2	281.2	5.84
103713	S2	313.2	1.96
103713	N2	259.1	1.21
103713	K1	266.7	1.69
103713	M4	21	0.1
103713	O1	248.6	0.99
103713	M6	122.8	0.05
103713	S4	14	0.02
103713	NU2	262	0.24
103713	MU2	338	0.14
103713	2N2	236.9	0.16
103713	OO1	284.9	0.04
103713	LDA2	296.1	0.04
103713	M1	257.7	0.07
103713	J1	275.7	0.08
103713	SA	274.8	0.4
103713	MF	176.8	0.09
103713	RHO1	240.8	0.04
103713	Q1	239.5	0.19
103713	T2	311.9	0.11
103713	R2	314.5	0.02
103713	2Q1	230.5	0.03
103713	P1	265.3	0.56
103713	L2	303.3	0.16
103713	K2	315.8	0.53
103713	M8	308.4	0.01
103714	M2	328.4	4.01
103714	S2	10.1	1.25
103714	N2	317.3	0.75
103714	K1	296	1.32
103714	M4	196.4	0.09
103714	O1	284.5	0.87
103714	M6	261.2	0.12
103714	S4	278.3	0.03
103714	NU2	318.8	0.15
103714	S6	160.7	0.01
103714	MU2	17.9	0.1
103714	2N2	306.3	0.1
103714	OO1	307.5	0.04
103714	LDA2	347.8	0.03
103714	M1	290.3	0.06
103714	J1	301.7	0.07
103714	RHO1	279.6	0.03
103714	Q1	278.8	0.17
103714	T2	8.4	0.08
103714	R2	11.8	0.01
103714	2Q1	273.1	0.02
103714	P1	295.1	0.44
103714	L2	339.5	0.11
103714	K2	13.5	0.34
103714	M8	139.5	0.02
103715	M2	282.5	6.55
103715	S2	315.5	2.23
103715	N2	258.2	1.33
103715	K1	265	1.71
103715	M4	8.9	0.12
103715	O1	250.2	1.02
103715	M6	239.8	0.02
103715	MK3	255.2	0.09
103715	S4	55.6	0.02
103715	MN4	335.8	0.05
103715	NU2	262.8	0.26
103715	MU2	251.7	0.15
103715	2N2	231.4	0.15
103715	OO1	294	0.06
103715	LDA2	285.7	0.04
103715	S1	55.6	0.03
103715	M1	281	0.06
103715	J1	277.7	0.1
103715	SA	255.6	0.26
103715	MF	176.1	0.08
103715	RHO1	241.4	0.03
103715	Q1	243.7	0.18
103715	T2	309.6	0.12
103715	R2	9.6	0.01
103715	2Q1	241.6	0.02
103715	P1	263.7	0.54
103715	2SM2	96.6	0.02
103715	M3	0.8	0.04
103715	L2	289.2	0.15
103715	2MK3	197.3	0.07
103715	K2	309	0.62
103715	MS4	47.7	0.07
103716	M2	281.6	6
103716	S2	315.5	1.94
103716	N2	258.2	1.22
103716	K1	266.1	1.64
103716	M4	27.6	0.13
103716	O1	249.4	1.02
103716	M6	16.7	0.01
103716	NU2	261.3	0.24
103716	S6	24	0.01
103716	MU2	338.1	0.14
103716	2N2	234.9	0.16
103716	OO1	282.9	0.04
103716	LDA2	297.3	0.04
103716	M1	257.9	0.07
103716	J1	274.4	0.08
103716	SA	255.6	0.26
103716	MF	176.1	0.08
103716	RHO1	242.2	0.04
103716	Q1	241.1	0.2
103716	T2	314.1	0.11
103716	R2	316.8	0.02
103716	2Q1	232.8	0.03
103716	P1	264.9	0.54
103716	L2	304.9	0.17
103716	K2	318.2	0.52
103716	M8	337.4	0.01
103717	M2	283.2	5.94
103717	S2	314.1	2.08
103717	N2	259.6	1.21
103717	K1	263.4	1.66
103717	M4	27.9	0.11
103717	O1	249.5	0.99
103717	M6	27.6	0.03
103717	S4	134	0.01
103717	NU2	262.7	0.24
103717	S6	208.9	0.01
103717	MU2	342.4	0.14
103717	2N2	236	0.16
103717	OO1	277.3	0.04
103717	LDA2	297.6	0.04
103717	M1	256.5	0.07
103717	J1	270.3	0.08
103717	RHO1	243.5	0.04
103717	Q1	242.6	0.19
103717	T2	312.9	0.12
103717	R2	315.4	0.02
103717	2Q1	235.7	0.03
103717	P1	262.4	0.55
103717	L2	306.8	0.17
103717	K2	316.7	0.57
103717	M8	113.3	0.01
103718	M2	282	5.97
103718	S2	315.9	2.1
103718	N2	258.5	1.18
103718	K1	265.1	1.63
103718	M4	19.4	0.1
103718	O1	248.6	1
103718	M6	69.1	0.03
103718	NU2	261.7	0.23
103718	MU2	248.2	0.14
103718	2N2	234.9	0.16
103718	OO1	281.6	0.04
103718	LDA2	297.8	0.04
103718	M1	256.9	0.07
103718	J1	273.3	0.08
103718	SA	274.8	0.4
103718	MF	176.8	0.09
103718	RHO1	241.5	0.04
103718	Q1	240.4	0.19
103718	T2	314.6	0.12
103718	R2	317.4	0.02
103718	2Q1	232.3	0.03
103718	P1	263.8	0.54
103718	L2	305.6	0.17
103718	K2	318.7	0.57
103719	M2	284.1	6.66
103719	S2	317.9	2.3
103719	N2	260.3	1.35
103719	K1	265.6	1.74
103719	M4	26	0.13
103719	O1	250.5	1.04
103719	M6	69	0.06
103719	MK3	267.6	0.08
103719	S4	78.3	0.01
103719	MN4	358.1	0.05
103719	NU2	263	0.26
103719	MU2	255.9	0.16
103719	2N2	235.9	0.16
103719	OO1	295.1	0.06
103719	LDA2	273	0.05
103719	S1	50.5	0.02
103719	M1	276.3	0.06
103719	J1	280.8	0.1
103719	MM	143.5	0.05
103719	SSA	312.7	0.03
103719	SA	191.5	0.22
103719	MSF	20.1	0.03
103719	MF	197.1	0.1
103719	RHO1	240.9	0.04
103719	Q1	243.6	0.18
103719	T2	314.8	0.12
103719	R2	95.7	0.02
103719	2Q1	242.2	0.02
103719	P1	261.4	0.54
103719	2SM2	93.7	0.03
103719	M3	359.6	0.05
103719	L2	289.7	0.15
103719	2MK3	201.4	0.05
103719	K2	310.6	0.61
103719	M8	207.1	0.01
103719	MS4	64.2	0.08
103720	M2	282.8	6.48
103720	S2	316.6	2.19
103720	N2	257.6	1.27
103720	K1	267.4	1.63
103720	M4	27.8	0.1
103720	O1	249.5	1.01
103720	M6	72.9	0.06
103720	NU2	261	0.25
103720	S6	223.5	0.01
103720	MU2	338.3	0.15
103720	2N2	232.4	0.17
103720	OO1	285.3	0.04
103720	LDA2	298.5	0.05
103720	M1	258.5	0.07
103720	J1	276.3	0.08
103720	SA	190	0.19
103720	RHO1	241.8	0.04
103720	Q1	240.6	0.2
103720	T2	315.3	0.13
103720	R2	318	0.02
103720	2Q1	231.7	0.03
103720	P1	266.1	0.54
103720	L2	308.1	0.18
103720	K2	319.3	0.6
103721	M2	284.2	5.97
103721	S2	319.8	1.96
103721	N2	263.5	1.23
103721	K1	263.3	1.7
103721	M4	32.4	0.09
103721	O1	252.5	1.02
103721	M6	48.9	0.02
103721	S4	68.5	0.02
103721	NU2	266.3	0.24
103721	S6	45.9	0.01
103721	MU2	337.8	0.14
103721	2N2	242.8	0.16
103721	OO1	274.1	0.04
103721	LDA2	300.7	0.04
103721	M1	257.9	0.07
103721	J1	268.6	0.08
103721	RHO1	247.8	0.04
103721	Q1	247.1	0.2
103721	T2	318.4	0.11
103721	R2	321.2	0.02
103721	2Q1	241.8	0.03
103721	P1	262.5	0.56
103721	L2	304.9	0.17
103721	K2	322.7	0.53
103721	M8	263.1	0.01
103722	M2	288.6	5.79
103722	S2	322.2	1.98
103722	N2	266.1	1.17
103722	K1	267.6	1.72
103722	M4	259.9	0.02
103722	O1	251.5	1.05
103722	M6	349.4	0.02
103722	MK3	285	0.05
103722	S4	274.5	0.01
103722	MN4	196.9	0.01
103722	NU2	265.9	0.23
103722	MU2	272.3	0.13
103722	2N2	234.1	0.16
103722	OO1	291.7	0.06
103722	LDA2	279.5	0.04
103722	S1	27.8	0.04
103722	M1	276.8	0.07
103722	J1	286.6	0.11
103722	SA	272.4	0.36
103722	MF	192.7	0.11
103722	RHO1	245.6	0.04
103722	Q1	242.7	0.18
103722	T2	312.4	0.1
103722	R2	131.7	0.01
103722	2Q1	236.8	0.02
103722	P1	266.7	0.54
103722	2SM2	120.4	0.03
103722	M3	22.8	0.04
103722	L2	302.7	0.14
103722	2MK3	210.9	0.03
103722	K2	316.4	0.55
103722	M8	275.7	0.01
103722	MS4	277.7	0.03
103723	M2	298.7	6.61
103723	S2	335	2.13
103723	N2	277.1	1.21
103723	K1	273.5	1.75
103723	M4	147.4	0.14
103723	O1	258.1	1.02
103723	M6	223.7	0.07
103723	S4	181.7	0.02
103723	NU2	280	0.23
103723	MU2	350.2	0.16
103723	2N2	255.5	0.16
103723	OO1	288.8	0.04
103723	LDA2	315.5	0.05
103723	M1	265.8	0.07
103723	J1	281.1	0.08
103723	RHO1	251.5	0.04
103723	Q1	250.5	0.2
103723	T2	333.6	0.12
103723	R2	336.5	0.02
103723	2Q1	242.9	0.03
103723	P1	272.3	0.58
103723	L2	320.3	0.18
103723	K2	338	0.58
103723	M8	27.3	0.01
103724	M2	276.3	3.9
103724	S2	308	1.25
103724	N2	253.4	0.82
103724	K1	262.5	1.53
103724	M4	268.4	0.03
103724	O1	250.5	0.96
103724	M6	169.9	0.02
103724	S4	105.6	0.01
103724	NU2	256.4	0.16
103724	MU2	332.2	0.1
103724	2N2	230.5	0.11
103724	OO1	274.4	0.04
103724	LDA2	291	0.03
103724	M1	256.6	0.07
103724	J1	268.4	0.08
103724	RHO1	245.4	0.04
103724	Q1	244.6	0.19
103724	T2	306.7	0.08
103724	R2	309.2	0.01
103724	2Q1	238.7	0.03
103724	P1	261.6	0.51
103724	L2	299.2	0.11
103724	K2	310.5	0.34
103724	M8	147.2	0.01
103725	M2	275.5	4.07
103725	S2	306.8	1.34
103725	N2	250.6	0.83
103725	K1	264	1.56
103725	M4	189.2	0.03
103725	O1	248.8	0.96
103725	M6	144.6	0.01
103725	MK3	235.6	0.01
103725	S4	254.3	0.01
103725	MN4	158.5	0.01
103725	NU2	254.7	0.16
103725	MU2	226.1	0.09
103725	2N2	224	0.1
103725	OO1	295.6	0.05
103725	LDA2	296.2	0.03
103725	S1	49.9	0.05
103725	M1	277.3	0.05
103725	J1	273.6	0.09
103725	SA	272.4	0.36
103725	MF	192.7	0.11
103725	RHO1	240.9	0.03
103725	Q1	240.8	0.17
103725	T2	301.2	0.08
103725	2Q1	237.7	0.02
103725	P1	259.8	0.49
103725	2SM2	146.8	0.01
103725	M3	306.5	0.01
103725	L2	292.3	0.1
103725	2MK3	198.4	0.02
103725	K2	299.6	0.36
103725	MS4	228.7	0.02
103726	M2	299.5	6.67
103726	S2	335.6	2.21
103726	N2	280.1	1.31
103726	K1	273.2	1.8
103726	M4	141.1	0.16
103726	O1	258.1	1.06
103726	M6	230.7	0.08
103726	S4	199.2	0.02
103726	NU2	282.7	0.26
103726	S6	209.4	0.01
103726	MU2	349.6	0.16
103726	2N2	260.6	0.17
103726	OO1	288.3	0.05
103726	LDA2	316.3	0.05
103726	M1	265.7	0.08
103726	J1	280.7	0.09
103726	SA	255.6	0.26
103726	MF	176.1	0.08
103726	RHO1	251.6	0.04
103726	Q1	250.6	0.21
103726	T2	334.2	0.13
103726	R2	337.1	0.02
103726	2Q1	243	0.03
103726	P1	272	0.59
103726	L2	318.9	0.19
103726	K2	338.6	0.6
103726	M8	194.2	0.01
103727	M2	281.4	3.7
103727	S2	312.7	1.21
103727	N2	257.2	0.77
103727	K1	268	1.5
103727	O1	252.9	0.93
103727	M6	309.1	0.01
103727	S4	245.8	0.01
103727	NU2	260.7	0.15
103727	MU2	235.2	0.09
103727	2N2	232.3	0.09
103727	OO1	296	0.05
103727	LDA2	298.8	0.02
103727	S1	19.1	0.05
103727	M1	275.4	0.05
103727	J1	280.2	0.09
103727	MM	172.8	0.07
103727	SA	257.9	0.37
103727	MSF	346.3	0.05
103727	MF	203.2	0.11
103727	RHO1	245.7	0.03
103727	Q1	246.3	0.16
103727	T2	303.9	0.07
103727	2Q1	241.3	0.02
103727	P1	264.4	0.47
103727	2SM2	123.9	0.01
103727	M3	266.4	0.01
103727	L2	299.3	0.08
103727	K2	305.8	0.32
103727	M8	230.8	0.01
103727	MS4	35.4	0.01
103728	M2	284.5	3.58
103728	S2	318	1.23
103728	N2	260.7	0.74
103728	K1	268.1	1.42
103728	M4	328.5	0.01
103728	O1	254	0.89
103728	M6	26.4	0.01
103728	NU2	263.9	0.14
103728	S6	93.3	0.01
103728	MU2	250.8	0.09
103728	2N2	237	0.1
103728	OO1	282.3	0.04
103728	LDA2	300	0.03
103728	M1	261.2	0.06
103728	J1	275.2	0.07
103728	SA	257.9	0.37
103728	RHO1	247.9	0.03
103728	Q1	247	0.17
103728	T2	316.6	0.07
103728	R2	319.4	0.01
103728	2Q1	239.9	0.02
103728	P1	267.1	0.47
103728	L2	308.2	0.1
103728	K2	320.7	0.33
103728	M8	230.1	0.01
103729	M2	282.7	3.56
103729	S2	315	1.16
103729	N2	255.4	0.75
103729	K1	268.6	1.37
103729	M4	11.1	0.01
103729	O1	252.2	0.92
103729	S4	210.6	0.01
103729	NU2	259.1	0.14
103729	S6	123.9	0.01
103729	MU2	250.5	0.09
103729	2N2	228.1	0.1
103729	OO1	285	0.04
103729	LDA2	297.7	0.03
103729	M1	260.5	0.07
103729	J1	276.8	0.07
103729	MM	172.8	0.07
103729	SA	257.9	0.37
103729	MSF	346.3	0.05
103729	MF	203.2	0.11
103729	RHO1	245.1	0.04
103729	Q1	244	0.18
103729	T2	313.7	0.07
103729	R2	316.3	0.01
103729	2Q1	235.9	0.02
103729	P1	267.4	0.45
103729	L2	310.1	0.1
103729	K2	317.6	0.31
103729	M8	231.8	0.01
103730	M2	290.2	4.77
103730	S2	322.2	1.63
103730	N2	265.9	0.98
103730	K1	273.7	1.64
103730	M4	13.8	0.18
103730	O1	256.8	1
103730	M6	115.4	0.04
103730	S4	5.3	0.05
103730	MN4	331.1	0.05
103730	NU2	269.5	0.19
103730	MU2	255.5	0.1
103730	2N2	239	0.11
103730	OO1	300.4	0.05
103730	LDA2	297.4	0.03
103730	S1	61.7	0.07
103730	M1	289.1	0.05
103730	J1	287.7	0.1
103730	SA	254.2	0.43
103730	MF	179.9	0.09
103730	RHO1	249.4	0.03
103730	Q1	250.3	0.17
103730	T2	313.8	0.09
103730	R2	323.5	0.01
103730	2Q1	250.9	0.02
103730	P1	271.2	0.51
103730	2SM2	132.8	0.01
103730	M3	277.8	0.02
103730	L2	299.4	0.11
103730	2MK3	174.1	0.01
103730	K2	316.2	0.45
103730	M8	186.7	0.01
103730	MS4	97.1	0.11
103731	M2	287.4	4.46
103731	S2	320.9	1.51
103731	N2	264.2	0.94
103731	K1	272.6	1.56
103731	M4	16.5	0.14
103731	O1	255.3	0.98
103731	M6	176.3	0.01
103731	S4	315.4	0.04
103731	NU2	267.3	0.18
103731	MU2	253.9	0.11
103731	2N2	241	0.12
103731	OO1	289.8	0.04
103731	LDA2	302.9	0.03
103731	M1	264	0.07
103731	J1	281.1	0.08
103731	SA	243.1	0.37
103731	MF	176.5	0.09
103731	RHO1	247.9	0.04
103731	Q1	246.8	0.19
103731	T2	319.6	0.09
103731	R2	322.2	0.01
103731	2Q1	238.2	0.03
103731	P1	271.3	0.52
103731	L2	310.6	0.12
103731	K2	323.6	0.41
103732	M2	287.7	4.57
103732	S2	320.4	1.57
103732	N2	263.1	0.94
103732	K1	272	1.64
103732	M4	19.4	0.15
103732	O1	256	0.99
103732	M6	197.6	0.01
103732	S4	351.1	0.04
103732	MN4	338.4	0.04
103732	NU2	267.6	0.18
103732	MU2	244.4	0.11
103732	2N2	237.9	0.11
103732	OO1	298.1	0.05
103732	LDA2	303.5	0.03
103732	S1	359.1	0.02
103732	M1	286.8	0.05
103732	J1	282.2	0.1
103732	SA	243.1	0.37
103732	MF	176.5	0.09
103732	RHO1	251.8	0.03
103732	Q1	249.4	0.17
103732	T2	306.2	0.09
103732	R2	9.6	0.02
103732	2Q1	249.6	0.02
103732	P1	269.7	0.53
103732	2SM2	136.1	0.01
103732	M3	273.6	0.02
103732	L2	300.1	0.1
103732	K2	313.8	0.43
103732	MS4	103.4	0.11
103733	M2	287.5	3.99
103733	S2	324.1	1.39
103733	N2	264.3	0.86
103733	K1	269.7	1.52
103733	M4	3	0.07
103733	O1	253.6	0.97
103733	M6	211.1	0.01
103733	S4	241	0.02
103733	NU2	267.4	0.17
103733	MU2	250.9	0.1
103733	2N2	241.1	0.11
103733	OO1	285.8	0.04
103733	LDA2	304.5	0.03
103733	M1	261.7	0.07
103733	J1	277.7	0.08
103733	SA	253.8	1.41
103733	MF	170	0.3
103733	RHO1	246.7	0.04
103733	Q1	245.6	0.19
103733	T2	322.7	0.08
103733	R2	325.6	0.01
103733	2Q1	237.6	0.03
103733	P1	268.5	0.5
103733	L2	310.7	0.11
103733	K2	327.1	0.38
103734	M2	286.9	4.37
103734	S2	317.4	1.5
103734	N2	261.8	0.87
103734	K1	271.6	1.62
103734	M4	19.7	0.14
103734	O1	255.5	0.99
103734	M6	202.5	0.01
103734	S4	353.4	0.04
103734	NU2	265.2	0.17
103734	MU2	321.5	0.1
103734	2N2	236.7	0.11
103734	OO1	287.8	0.04
103734	LDA2	301	0.03
103734	M1	263.6	0.07
103734	J1	279.7	0.08
103734	SA	254.2	0.43
103734	MF	179.9	0.09
103734	RHO1	248.6	0.04
103734	Q1	247.5	0.19
103734	T2	316.2	0.09
103734	R2	318.6	0.01
103734	2Q1	239.5	0.03
103734	P1	270.4	0.54
103734	L2	311.9	0.12
103734	K2	319.9	0.41
103734	M8	31.4	0.01
103735	M2	289.5	3.72
103735	S2	319.9	1.26
103735	N2	265.3	0.8
103735	K1	272.1	1.56
103735	M4	32.2	0.05
103735	O1	257.8	0.94
103735	M6	347.1	0.01
103735	S4	311.7	0.01
103735	NU2	268.5	0.15
103735	S6	241.8	0.01
103735	MU2	324.2	0.09
103735	2N2	241.1	0.11
103735	OO1	286.4	0.04
103735	LDA2	303.6	0.03
103735	M1	265	0.07
103735	J1	279.2	0.08
103735	RHO1	251.6	0.04
103735	Q1	250.6	0.18
103735	T2	318.7	0.08
103735	R2	321.2	0.01
103735	2Q1	243.5	0.03
103735	P1	271	0.52
103735	L2	313.7	0.1
103735	K2	322.4	0.34
103735	M8	214.3	0.01
103736	M2	288.8	4.42
103736	S2	319.6	1.49
103736	N2	264.4	0.92
103736	K1	273.2	1.6
103736	M4	33.9	0.12
103736	O1	258	0.96
103736	S4	359.2	0.03
103736	NU2	267.7	0.18
103736	MU2	323.3	0.1
103736	2N2	240	0.12
103736	OO1	288.4	0.04
103736	LDA2	303.1	0.03
103736	M1	265.6	0.07
103736	J1	280.7	0.08
103736	SA	243.1	0.37
103736	RHO1	251.4	0.04
103736	Q1	250.4	0.19
103736	T2	318.4	0.09
103736	R2	320.8	0.01
103736	2Q1	242.9	0.03
103736	P1	272	0.53
103736	L2	313.3	0.12
103736	K2	322.1	0.41
103736	M8	271.5	0.01
103737	M2	287.9	4.58
103737	S2	319	1.51
103737	N2	262.1	0.97
103737	K1	270.4	1.58
103737	M4	25.4	0.12
103737	O1	256.3	1.01
103737	M6	158.7	0.01
103737	S4	24.7	0.07
103737	NU2	265.5	0.19
103737	S6	158.8	0.01
103737	MU2	322	0.11
103737	2N2	236.3	0.13
103737	OO1	284.6	0.04
103737	LDA2	302.3	0.03
103737	M1	263.4	0.07
103737	J1	277.4	0.08
103737	RHO1	250.2	0.04
103737	Q1	249.3	0.2
103737	T2	317.7	0.09
103737	R2	320.2	0.01
103737	2Q1	242.3	0.03
103737	P1	269.4	0.52
103737	L2	313.7	0.13
103737	K2	321.5	0.41
103738	M2	288.9	4.29
103738	S2	318.9	1.46
103738	N2	267	0.87
103738	K1	272.3	1.54
103738	M4	22.8	0.11
103738	O1	258.2	0.97
103738	S4	13.9	0.02
103738	NU2	269.9	0.17
103738	MU2	323.8	0.1
103738	2N2	245.1	0.11
103738	OO1	286.4	0.04
103738	LDA2	302.8	0.03
103738	M1	265.3	0.07
103738	J1	279.3	0.08
103738	SA	254.2	0.43
103738	MF	179.9	0.09
103738	RHO1	252.1	0.04
103738	Q1	251.2	0.19
103738	T2	317.7	0.09
103738	R2	320.1	0.01
103738	2Q1	244.2	0.03
103738	P1	271.3	0.51
103738	L2	310.8	0.12
103738	K2	321.3	0.4
103739	M2	289.1	4.43
103739	S2	319.8	1.54
103739	N2	267.7	0.92
103739	K1	271.6	1.67
103739	M4	33.4	0.11
103739	O1	258.7	0.96
103739	S4	2.5	0.03
103739	NU2	270.6	0.18
103739	MU2	323	0.1
103739	2N2	246.2	0.12
103739	OO1	284.5	0.04
103739	LDA2	303.4	0.03
103739	M1	265.2	0.07
103739	J1	278	0.08
103739	SA	243.1	0.37
103739	RHO1	253.2	0.04
103739	Q1	252.3	0.19
103739	T2	318.6	0.09
103739	R2	321.1	0.01
103739	2Q1	245.9	0.03
103739	P1	270.6	0.55
103739	L2	310.6	0.12
103739	K2	322.3	0.42
103740	M2	288.8	4.32
103740	S2	319.3	1.5
103740	N2	262.5	0.84
103740	K1	272.7	1.55
103740	M4	21.4	0.13
103740	O1	258	0.94
103740	M6	195.1	0.01
103740	S4	17.8	0.04
103740	NU2	266	0.16
103740	MU2	322.9	0.1
103740	2N2	236.1	0.11
103740	OO1	287.5	0.04
103740	LDA2	302.9	0.03
103740	M1	265.4	0.07
103740	J1	280	0.08
103740	SA	254.2	0.43
103740	MF	179.9	0.09
103740	RHO1	251.7	0.04
103740	Q1	250.7	0.18
103740	T2	318.1	0.09
103740	R2	320.5	0.01
103740	2Q1	243.4	0.02
103740	P1	271.6	0.52
103740	L2	315.1	0.12
103740	K2	321.7	0.41
103741	M2	289.6	4.7
103741	S2	323.2	1.59
103741	N2	266.1	0.98
103741	K1	273.6	1.58
103741	M4	23.6	0.17
103741	O1	256.5	1
103741	M6	198.8	0.01
103741	S4	320.2	0.05
103741	NU2	269.3	0.19
103741	S6	339.3	0.01
103741	MU2	256.1	0.11
103741	2N2	242.6	0.13
103741	OO1	290.6	0.04
103741	LDA2	305.2	0.03
103741	M1	265.2	0.07
103741	J1	282	0.08
103741	SA	243.1	0.37
103741	MF	176.5	0.09
103741	RHO1	249.3	0.04
103741	Q1	248.1	0.19
103741	T2	321.9	0.1
103741	R2	324.5	0.01
103741	2Q1	239.7	0.03
103741	P1	272.3	0.52
103741	L2	313.2	0.13
103741	K2	325.9	0.43
103742	M2	288.9	4.49
103742	S2	319	1.53
103742	N2	265	0.92
103742	K1	272.3	1.58
103742	M4	40.1	0.14
103742	O1	257.2	0.95
103742	S4	7.7	0.04
103742	NU2	268.2	0.18
103742	MU2	323.1	0.11
103742	2N2	241.1	0.12
103742	OO1	287.5	0.04
103742	LDA2	302.9	0.03
103742	M1	264.8	0.07
103742	J1	279.8	0.08
103742	SA	253.3	0.39
103742	RHO1	250.6	0.04
103742	Q1	249.6	0.18
103742	T2	317.8	0.09
103742	R2	320.3	0.01
103742	2Q1	242.1	0.03
103742	P1	271.2	0.52
103742	L2	312.8	0.12
103742	K2	321.5	0.42
103743	M2	288.6	4.51
103743	S2	318.9	1.55
103743	N2	265.3	0.93
103743	K1	273.1	1.63
103743	M4	29.1	0.12
103743	O1	258.9	0.96
103743	M6	207.5	0.01
103743	S4	1.3	0.04
103743	NU2	268.5	0.18
103743	MU2	322.5	0.11
103743	2N2	242	0.12
103743	OO1	287.3	0.04
103743	LDA2	302.7	0.03
103743	M1	266.1	0.07
103743	J1	280.2	0.08
103743	SA	243.1	0.37
103743	RHO1	252.8	0.04
103743	Q1	251.8	0.19
103743	T2	317.7	0.09
103743	R2	320.1	0.01
103743	2Q1	244.8	0.03
103743	P1	272	0.54
103743	L2	312	0.12
103743	K2	321.3	0.42
103743	M8	95.2	0.01
103744	M2	288	4.34
103744	S2	319.6	1.56
103744	N2	262.2	0.94
103744	K1	272.5	1.6
103744	M4	22.6	0.1
103744	O1	256.6	0.96
103744	M6	318.2	0.01
103744	S4	315.4	0.03
103744	NU2	265.7	0.18
103744	MU2	320.3	0.1
103744	2N2	236.5	0.12
103744	OO1	288.4	0.04
103744	LDA2	302.7	0.03
103744	M1	264.6	0.07
103744	J1	280.4	0.08
103744	SA	254.2	0.43
103744	MF	179.9	0.09
103744	RHO1	249.8	0.04
103744	Q1	248.7	0.19
103744	T2	318.4	0.09
103744	R2	320.9	0.01
103744	2Q1	240.8	0.03
103744	P1	271.3	0.53
103744	L2	313.7	0.12
103744	K2	322.2	0.42
103745	M2	288.9	4.34
103745	S2	322.2	1.51
103745	N2	260.4	0.87
103745	K1	276.6	1.58
103745	M4	21	0.16
103745	O1	255.6	1.05
103745	M6	281	0.01
103745	S4	11.5	0.06
103745	NU2	264.2	0.17
103745	S6	46.1	0.01
103745	MU2	319.6	0.1
103745	2N2	231.9	0.11
103745	OO1	297.6	0.05
103745	LDA2	304.3	0.03
103745	M1	266.2	0.08
103745	J1	287	0.08
103745	SA	254.2	0.43
103745	MF	179.9	0.09
103745	RHO1	246.5	0.04
103745	Q1	245.1	0.2
103745	T2	320.8	0.09
103745	R2	323.5	0.01
103745	2Q1	234.7	0.03
103745	P1	275	0.52
103745	L2	317.4	0.12
103745	K2	324.9	0.41
103745	M8	283.8	0.02
103746	M2	286.2	3.89
103746	S2	318.6	1.31
103746	N2	263.8	0.75
103746	K1	273.8	1.38
103746	M4	31.8	0.07
103746	O1	256.4	0.99
103746	M6	354.3	0.01
103746	S4	344.7	0.03
103746	NU2	266.8	0.14
103746	S6	124.5	0.01
103746	MU2	317.4	0.09
103746	2N2	241.3	0.1
103746	OO1	291.3	0.04
103746	LDA2	301.3	0.03
103746	M1	265.2	0.07
103746	J1	282.5	0.08
103746	SA	253.3	0.39
103746	MF	163.9	0.08
103746	RHO1	248.9	0.04
103746	Q1	247.8	0.19
103746	T2	317.3	0.08
103746	R2	319.9	0.01
103746	2Q1	239.1	0.03
103746	P1	272.5	0.46
103746	L2	308.8	0.11
103746	K2	321.3	0.36
103746	M8	178.5	0.01
103747	M2	288.6	4.6
103747	S2	320.3	1.6
103747	N2	264.1	0.91
103747	K1	272.2	1.62
103747	M4	16.4	0.17
103747	O1	256.7	0.99
103747	M6	202.9	0.01
103747	S4	353.2	0.06
103747	MN4	334.4	0.05
103747	NU2	270.8	0.19
103747	MU2	245	0.11
103747	2N2	238.2	0.1
103747	OO1	309.4	0.05
103747	LDA2	305.6	0.03
103747	S1	35.8	0.05
103747	M1	279.5	0.06
103747	J1	286	0.1
103747	MM	256.5	0.16
103747	SSA	114.1	0.16
103747	SA	240.6	0.46
103747	MSF	144.2	0.08
103747	MF	162	0.14
103747	RHO1	255.8	0.02
103747	Q1	247.8	0.17
103747	T2	307.1	0.1
103747	R2	209.9	0.01
103747	2Q1	228	0.03
103747	P1	267.8	0.5
103747	2SM2	149.7	0.01
103747	M3	279.8	0.02
103747	L2	304.7	0.12
103747	2MK3	255.4	0.01
103747	K2	312.7	0.43
103747	MS4	102.7	0.1
103748	M2	288	3.93
103748	S2	319.5	1.35
103748	N2	264	0.8
103748	K1	272.9	1.52
103748	M4	22.3	0.03
103748	O1	257.7	0.95
103748	M6	28.6	0.02
103748	MK3	131.1	0.01
103748	S4	10	0.01
103748	MN4	343.6	0.01
103748	NU2	267.2	0.15
103748	MU2	238.8	0.1
103748	2N2	239.1	0.09
103748	OO1	295	0.05
103748	LDA2	307.1	0.02
103748	S1	51.4	0.03
103748	M1	278.5	0.06
103748	J1	286.4	0.09
103748	SA	242.9	0.46
103748	MF	181.9	0.09
103748	RHO1	253.4	0.03
103748	Q1	250.3	0.17
103748	T2	312.4	0.09
103748	2Q1	245.1	0.02
103748	P1	268.8	0.48
103748	M3	276	0.01
103748	L2	312.4	0.09
103748	K2	312.7	0.36
103748	MS4	95.2	0.02
103749	M2	288.6	3.93
103749	S2	318.5	1.39
103749	N2	263.9	0.76
103749	K1	271.4	1.57
103749	M4	37.8	0.04
103749	O1	257.6	0.92
103749	M6	30.7	0.01
103749	S4	327.7	0.01
103749	NU2	267.2	0.15
103749	S6	74.4	0.01
103749	MU2	319.6	0.1
103749	2N2	239.2	0.1
103749	OO1	285.2	0.04
103749	LDA2	302.5	0.03
103749	M1	264.6	0.07
103749	J1	278.2	0.07
103749	SA	253.3	0.39
103749	MF	163.9	0.08
103749	RHO1	251.7	0.04
103749	Q1	250.8	0.18
103749	T2	317.3	0.08
103749	R2	319.7	0.01
103749	2Q1	244	0.02
103749	P1	270.4	0.52
103749	L2	313.3	0.11
103749	K2	320.9	0.38
103749	M8	358.8	0.01
103750	M2	288.8	3.93
103750	S2	322.3	1.38
103750	N2	266.5	0.76
103750	K1	272.9	1.45
103750	M4	30.9	0.03
103750	O1	257.8	0.92
103750	M6	44.9	0.02
103750	S4	48.9	0.01
103750	NU2	269.5	0.15
103750	S6	168.6	0.01
103750	MU2	255.2	0.1
103750	2N2	244.2	0.1
103750	OO1	287.9	0.04
103750	LDA2	304.4	0.03
103750	M1	265.4	0.07
103750	J1	280.3	0.07
103750	SA	253.3	0.39
103750	MF	163.9	0.08
103750	RHO1	251.4	0.04
103750	Q1	250.3	0.18
103750	T2	321	0.08
103750	R2	323.7	0.01
103750	2Q1	242.9	0.02
103750	P1	271.7	0.48
103750	L2	311.2	0.11
103750	K2	325.1	0.38
103750	M8	331.8	0.01
103751	M2	288.9	3.94
103751	S2	320.7	1.36
103751	N2	264	0.8
103751	K1	273.4	1.48
103751	M4	24.7	0.03
103751	O1	258.5	0.93
103751	M6	40.9	0.02
103751	NU2	267.3	0.15
103751	MU2	257	0.1
103751	2N2	239.1	0.1
103751	OO1	288.4	0.04
103751	LDA2	303.6	0.03
103751	M1	266	0.07
103751	J1	280.9	0.07
103751	RHO1	252	0.04
103751	Q1	251	0.18
103751	T2	319.4	0.08
103751	R2	321.9	0.01
103751	2Q1	243.6	0.02
103751	P1	272.3	0.49
103751	L2	313.7	0.11
103751	K2	323.3	0.37
103751	M8	20.2	0.01
103752	M2	288.4	3.96
103752	S2	318.2	1.36
103752	N2	260.2	0.81
103752	K1	273.1	1.5
103752	M4	33.2	0.02
103752	O1	258.7	0.94
103752	M6	44.9	0.02
103752	NU2	264	0.16
103752	MU2	319	0.1
103752	2N2	232.1	0.11
103752	OO1	287.5	0.04
103752	LDA2	302.2	0.03
103752	M1	265.9	0.07
103752	J1	280.2	0.08
103752	SA	253.3	0.39
103752	MF	163.9	0.08
103752	RHO1	252.5	0.04
103752	Q1	251.6	0.18
103752	T2	317	0.08
103752	R2	319.4	0.01
103752	2Q1	244.4	0.02
103752	P1	272	0.5
103752	L2	316.5	0.11
103752	K2	320.6	0.37
103752	M8	25.3	0.01
103753	M2	289.2	4.01
103753	S2	320	1.39
103753	N2	264	0.81
103753	K1	273.2	1.5
103753	M4	28	0.03
103753	O1	257.6	0.93
103753	M6	28.4	0.03
103753	NU2	267.4	0.16
103753	MU2	318.9	0.1
103753	2N2	238.8	0.11
103753	OO1	288.9	0.04
103753	LDA2	303.5	0.03
103753	M1	265.5	0.07
103753	J1	281	0.07
103753	SA	253.3	0.39
103753	MF	163.9	0.08
103753	RHO1	250.9	0.04
103753	Q1	249.9	0.18
103753	T2	318.8	0.08
103753	R2	321.3	0.01
103753	2Q1	242.1	0.02
103753	P1	272.1	0.5
103753	L2	314.4	0.11
103753	K2	322.5	0.38
103754	M2	294.3	4.02
103754	S2	328.6	1.44
103754	N2	270.3	0.83
103754	K1	276	1.51
103754	M4	120.6	0.07
103754	O1	260.7	0.94
103754	M6	77	0.04
103754	S4	260.7	0.01
103754	NU2	273.5	0.16
103754	MU2	319.8	0.1
103754	2N2	246.3	0.11
103754	OO1	291.3	0.04
103754	LDA2	310.2	0.03
103754	M1	268.4	0.07
103754	J1	283.6	0.08
103754	SA	253.3	0.39
103754	MF	163.9	0.08
103754	RHO1	254.1	0.04
103754	Q1	253.1	0.18
103754	T2	327.3	0.09
103754	R2	330	0.01
103754	2Q1	245.5	0.02
103754	P1	274.8	0.5
103754	L2	318.2	0.11
103754	K2	331.4	0.39
103754	M8	303.2	0.01
103755	M2	292.4	4.27
103755	S2	326.9	1.46
103755	N2	268.8	0.9
103755	K1	275.2	1.46
103755	M4	10.6	0.03
103755	O1	258.5	0.95
103755	M6	40.4	0.02
103755	NU2	272	0.17
103755	S6	225	0.01
103755	MU2	258	0.1
103755	2N2	245.3	0.12
103755	OO1	291.8	0.04
103755	LDA2	308.4	0.03
103755	M1	266.9	0.07
103755	J1	283.4	0.08
103755	SA	242.9	0.46
103755	MF	181.9	0.09
103755	RHO1	251.4	0.04
103755	Q1	250.2	0.18
103755	T2	325.4	0.09
103755	R2	328.4	0.01
103755	2Q1	242	0.03
103755	P1	273.9	0.48
103755	L2	315.9	0.12
103755	K2	329.6	0.4
103756	M2	323.9	7.3
103756	S2	358	2.73
103756	N2	297.8	1.51
103756	K1	280	1.83
103756	M4	67.9	0.1
103756	O1	264.2	1.13
103756	M6	195.3	0.05
103756	MK3	204.4	0.07
103756	S4	124.6	0.02
103756	MN4	37.1	0.04
103756	NU2	301.4	0.25
103756	MU2	276.6	0.28
103756	2N2	269.9	0.18
103756	OO1	312.9	0.06
103756	LDA2	320.1	0.03
103756	S1	64.7	0.03
103756	M1	302.3	0.07
103756	J1	294.5	0.1
103756	SA	249.9	0.45
103756	MF	176.3	0.11
103756	RHO1	255	0.04
103756	Q1	257.1	0.21
103756	T2	350.2	0.16
103756	R2	53.6	0.03
103756	2Q1	238.8	0.02
103756	P1	278	0.58
103756	2SM2	129.3	0.02
103756	M3	23.6	0.03
103756	L2	330.4	0.13
103756	2MK3	181.9	0.08
103756	K2	351.7	0.75
103756	M8	352.9	0.01
103756	MS4	114.2	0.09
103757	M2	324.8	7.3
103757	S2	357.3	2.86
103757	N2	300.7	1.61
103757	K1	277.9	1.86
103757	M4	76.1	0.11
103757	O1	263.5	1.11
103757	M6	180.7	0.06
103757	S4	181.5	0.03
103757	NU2	303.9	0.31
103757	S6	36.3	0.01
103757	MU2	349	0.17
103757	2N2	276.7	0.21
103757	OO1	292.4	0.05
103757	LDA2	339.9	0.05
103757	M1	270.8	0.08
103757	J1	285.1	0.09
103757	RHO1	257.2	0.04
103757	Q1	256.3	0.22
103757	T2	356	0.17
103757	R2	358.6	0.02
103757	2Q1	249.1	0.03
103757	P1	276.9	0.62
103757	L2	348.8	0.2
103757	K2	0	0.78
103757	M8	63.3	0.01
103758	M2	325.1	7.48
103758	S2	358.4	2.78
103758	N2	299.5	1.6
103758	K1	279.2	1.81
103758	M4	70.8	0.12
103758	O1	265.8	1.09
103758	M6	199.1	0.07
103758	S4	123.3	0.02
103758	NU2	302.9	0.31
103758	S6	171.9	0.01
103758	MU2	291.8	0.18
103758	2N2	274	0.21
103758	OO1	292.6	0.05
103758	LDA2	340.5	0.05
103758	M1	272.5	0.08
103758	J1	285.9	0.09
103758	SA	250.2	0.41
103758	MSF	171.7	0.08
103758	RHO1	260	0.04
103758	Q1	259.1	0.21
103758	T2	357.1	0.16
103758	R2	359.7	0.02
103758	2Q1	252.5	0.03
103758	P1	278.2	0.6
103758	L2	350.6	0.21
103758	K2	1.1	0.76
103758	M8	22.7	0.02
103759	M2	325.2	7.53
103759	S2	357.9	2.96
103759	N2	301.4	1.66
103759	K1	277.8	1.88
103759	M4	69.5	0.11
103759	O1	263.8	1.11
103759	M6	182.4	0.07
103759	S4	178.7	0.03
103759	NU2	304.6	0.32
103759	S6	31.7	0.01
103759	MU2	350.6	0.18
103759	2N2	277.5	0.22
103759	OO1	291.8	0.05
103759	LDA2	340.4	0.05
103759	M1	270.8	0.08
103759	J1	284.8	0.09
103759	RHO1	257.8	0.04
103759	Q1	256.8	0.22
103759	T2	356.6	0.17
103759	R2	359.2	0.02
103759	2Q1	249.9	0.03
103759	P1	276.8	0.62
103759	L2	349.1	0.21
103759	K2	0.5	0.8
103759	M8	49.6	0.01
103760	M2	335	7.49
103760	S2	6.9	2.66
103760	N2	307	1.49
103760	K1	284.6	1.88
103760	M4	51.9	0.19
103760	O1	269.9	1.13
103760	M6	205.8	0.04
103760	S4	123	0.03
103760	NU2	310.8	0.29
103760	MU2	359.4	0.18
103760	2N2	279	0.2
103760	OO1	299.3	0.05
103760	LDA2	349.8	0.05
103760	M1	277.3	0.08
103760	J1	291.9	0.09
103760	RHO1	263.6	0.04
103760	Q1	262.6	0.22
103760	T2	5.7	0.16
103760	R2	8.2	0.02
103760	2Q1	255.3	0.03
103760	P1	283.5	0.62
103760	L2	3.1	0.21
103760	K2	9.5	0.73
103760	M8	103.5	0.01
103761	M2	353.8	7.78
103761	S2	25	2.92
103761	N2	320.6	1.56
103761	K1	291.8	1.98
103761	M4	175.2	0.09
103761	O1	275.8	1.15
103761	M6	79	0.07
103761	S4	219.9	0.02
103761	NU2	325	0.31
103761	MU2	322.6	0.19
103761	2N2	287.4	0.21
103761	OO1	307.9	0.05
103761	LDA2	8.3	0.06
103761	M1	283.9	0.08
103761	J1	299.8	0.09
103761	SA	250.2	0.41
103761	MF	171.7	0.08
103761	RHO1	268.9	0.04
103761	Q1	267.8	0.22
103761	T2	23.8	0.17
103761	R2	26.3	0.02
103761	2Q1	259.8	0.03
103761	P1	290.6	0.66
103761	L2	27	0.22
103761	K2	27.5	0.79
103762	M2	8.9	8.15
103762	S2	40.6	3.14
103762	N2	339.9	1.79
103762	K1	297.2	1.9
103762	M4	260.8	0.28
103762	O1	280.8	1.25
103762	M6	108.6	0.15
103762	S4	345.6	0.03
103762	NU2	343.8	0.35
103762	S6	316.9	0.01
103762	MU2	337.1	0.2
103762	2N2	310.9	0.24
103762	OO1	313.6	0.05
103762	LDA2	23.6	0.06
103762	M1	289.1	0.09
103762	J1	305.3	0.1
103762	SA	243.7	0.39
103762	MF	163	0.09
103762	RHO1	273.8	0.05
103762	Q1	272.7	0.24
103762	T2	39.3	0.18
103762	R2	41.9	0.03
103762	2Q1	264.5	0.03
103762	P1	296	0.63
103762	L2	37.8	0.23
103762	K2	43.2	0.85
103762	M8	293.5	0.02
103763	M2	15.2	7.45
103763	S2	47.2	2.9
103763	N2	346.5	1.67
103763	K1	301.9	1.92
103763	M4	232.4	0.18
103763	O1	284.3	1.25
103763	M6	95.3	0.09
103763	S4	313.2	0.02
103763	NU2	350.3	0.32
103763	S6	244.9	0.01
103763	MU2	343.3	0.18
103763	2N2	317.7	0.22
103763	OO1	319.5	0.05
103763	LDA2	30.1	0.05
103763	M1	293.2	0.09
103763	J1	310.6	0.1
103763	SA	243.7	0.04
103763	RHO1	276.7	0.05
103763	Q1	275.6	0.24
103763	T2	45.9	0.17
103763	R2	48.5	0.02
103763	2Q1	266.8	0.03
103763	P1	300.6	0.64
103763	L2	44	0.21
103763	K2	49.8	0.79
103764	M2	16.6	8.21
103764	S2	52.4	3.02
103764	N2	351.6	1.69
103764	K1	301.7	1.89
103764	M4	277.3	0.4
103764	O1	288.4	1.23
103764	M6	117.3	0.23
103764	S4	64.2	0.01
103764	NU2	354.9	0.33
103764	S6	198.9	0.01
103764	MU2	340.9	0.2
103764	2N2	326.6	0.23
103764	OO1	315.2	0.05
103764	LDA2	33.2	0.06
103764	M1	295.1	0.09
103764	J1	308.4	0.1
103764	SA	243.7	0.39
103764	MF	163	0.09
103764	RHO1	282.7	0.05
103764	Q1	281.7	0.24
103764	T2	51	0.18
103764	R2	53.8	0.02
103764	2Q1	275.1	0.03
103764	P1	300.7	0.63
103764	L2	41.7	0.23
103764	K2	55.3	0.82
103764	M8	349.4	0.04
103765	M2	32.3	8.21
103765	S2	63.1	2.82
103765	N2	1.6	1.62
103765	K1	307.9	2.11
103765	M4	279.1	0.29
103765	O1	291.1	1.26
103765	M6	141.2	0.23
103765	MK3	253.3	0.14
103765	S4	17.8	0.03
103765	MN4	259.9	0.11
103765	NU2	22.7	0.29
103765	MU2	274.7	0.34
103765	2N2	332.3	0.18
103765	OO1	11.9	0.06
103765	LDA2	60.1	0.1
103765	S1	107.5	0.03
103765	M1	353.1	0.08
103765	J1	342.3	0.08
103765	SA	243.7	0.39
103765	MF	163	0.09
103765	RHO1	276.8	0.05
103765	Q1	290.2	0.21
103765	T2	59.5	0.16
103765	R2	97.4	0.05
103765	2Q1	288.4	0.02
103765	P1	308.2	0.61
103765	2SM2	282.7	0.05
103765	M3	103.9	0.03
103765	L2	79.9	0.24
103765	2MK3	244.9	0.15
103765	K2	55.8	0.8
103765	M8	14	0.03
103765	MS4	319.1	0.23
103766	M2	87.2	10.27
103766	S2	122.9	3.14
103766	N2	50.1	1.85
103766	K1	326.1	2.21
103766	M4	63.3	0.64
103766	O1	309.6	1.52
103766	M6	297.6	0.34
103766	S4	194.7	0.07
103766	NU2	55.1	0.36
103766	S6	235.3	0.03
103766	MU2	110.6	0.25
103766	2N2	13.1	0.25
103766	OO1	342.5	0.07
103766	LDA2	103.8	0.07
103766	M1	317.9	0.11
103766	J1	334.3	0.12
103766	RHO1	302.6	0.06
103766	Q1	301.5	0.3
103766	T2	121.5	0.18
103766	R2	124.3	0.03
103766	2Q1	293.3	0.04
103766	P1	324.9	0.73
103766	L2	124.2	0.29
103766	K2	125.8	0.85
103766	M8	295.4	0.05
103767	M2	75.1	8.14
103767	S2	108.9	2.43
103767	N2	39.7	1.47
103767	K1	327.3	1.94
103767	M4	15.7	0.26
103767	O1	313.4	1.19
103767	M6	229.5	0.21
103767	S4	132.4	0.03
103767	NU2	44.4	0.29
103767	MU2	98.9	0.19
103767	2N2	4.3	0.19
103767	OO1	340.7	0.05
103767	LDA2	90.8	0.06
103767	M1	320.3	0.09
103767	J1	333.8	0.1
103767	SA	243.7	0.39
103767	MF	163	0.09
103767	RHO1	307.5	0.05
103767	Q1	306.6	0.23
103767	T2	107.5	0.14
103767	R2	110.2	0.02
103767	2Q1	299.8	0.03
103767	P1	326.2	0.64
103767	L2	110.5	0.23
103767	K2	111.6	0.66
103767	M8	128.2	0.04
103768	M2	96.7	10.87
103768	S2	139.4	3.09
103768	N2	74	1.82
103768	K1	336.4	2.07
103768	M4	64.6	0.73
103768	O1	323.5	1.33
103768	M6	333.1	0.44
103768	S4	217.2	0.04
103768	NU2	77	0.35
103768	S6	304.2	0.01
103768	MU2	53.9	0.26
103768	2N2	51.3	0.24
103768	OO1	349.1	0.06
103768	LDA2	116.5	0.08
103768	M1	329.9	0.1
103768	J1	342.6	0.1
103768	SA	243.7	0.39
103768	MF	163	0.09
103768	RHO1	317.9	0.05
103768	Q1	317.1	0.26
103768	T2	137.7	0.18
103768	R2	141.1	0.03
103768	2Q1	310.9	0.03
103768	P1	335.5	0.69
103768	L2	119.4	0.31
103768	K2	142.9	0.84
103768	M8	293.8	0.08
103769	M2	105.2	11.5
103769	S2	147.4	3.21
103769	N2	79.2	1.96
103769	K1	342.1	2.2
103769	M4	80.7	0.89
103769	O1	325	1.22
103769	M6	18.2	0.51
103769	MK3	8.8	0.27
103769	S4	207	0.07
103769	MN4	60	0.31
103769	NU2	82.3	0.56
103769	S6	278.4	0.01
103769	MU2	234	0.7
103769	2N2	48.1	0.19
103769	OO1	79.3	0.06
103769	LDA2	111.1	0.31
103769	S1	74.2	0.01
103769	M1	40.2	0.1
103769	J1	65.2	0.08
103769	MM	36.1	0.17
103769	SSA	283	0.08
103769	SA	217.4	0.31
103769	MSF	39.6	0.44
103769	MF	94.7	0.08
103769	RHO1	296.2	0.05
103769	Q1	330.6	0.2
103769	T2	128.7	0.18
103769	R2	233.5	0.04
103769	2Q1	328.4	0.02
103769	P1	340.9	0.58
103769	2SM2	348.6	0.19
103769	M3	148	0.06
103769	L2	125.2	0.69
103769	2MK3	21.2	0.32
103769	K2	138.1	0.89
103769	M8	346.2	0.15
103769	MS4	128.2	0.57
103769	SIG1	24.4	0.15
103769	MP1	67.2	0.22
103769	CHI1	278.4	0.02
103769	2PO1	143	0.06
103769	SO1	151.1	0.24
103769	MSN2	335.1	0.16
103769	MNS2	201.8	0.19
103769	OP2	100.5	0.02
103769	MKS2	300.1	0.05
103769	2NS2	167.2	0.03
103769	MLN2S2	201.5	0.13
103769	2ML2S2	43.4	0.08
103769	SKM2	340.7	0.08
103769	2MS2K2	245	0.02
103769	MKL2S2	108.5	0.01
103769	M2(KS)2	126.9	0.02
103769	2KM(SN)2	167.5	0.01
103769	SO3	31.4	0.17
103769	SK3	67.6	0.14
103769	NO3	353.7	0.13
103769	MK4	122.2	0.14
103769	SN4	146.9	0.07
103769	2MLS4	220.8	0.09
103769	3MS4	161.2	0.12
103769	ML4	72.6	0.09
103769	N4	36.4	0.06
103769	SL4	117.4	0.07
103769	MNO5	249.7	0.06
103769	2MO5	268.3	0.11
103769	2MK5	256.3	0.2
103769	MSK5	324.6	0.1
103769	3KM5	305.5	0.03
103769	2MP5	285.1	0.09
103769	3MP5	357.4	0.07
103769	MNK5	239.1	0.07
103769	2SM6	114.6	0.09
103769	2MN6	352.7	0.27
103769	MSN6	48.1	0.09
103769	2MS6	59.4	0.47
103769	2NMLS6	297.7	0.08
103769	2NM6	325.4	0.07
103769	MSL6	70.2	0.11
103769	2ML6	34.3	0.08
103769	MSK6	91.8	0.06
103769	2MNLS6	325.1	0.1
103769	3MLS6	176.1	0.1
103769	2MK6	46.7	0.12
103769	2MNO7	245.7	0.05
103769	2NMK7	204.4	0.01
103769	2MSO7	293.2	0.08
103769	MSKO7	122.5	0.1
103769	2MSN8	14	0.08
103769	3MS8	26	0.21
103769	2(MS)8	80.3	0.08
103769	2(MN)8	292.9	0.04
103769	3MN8	319.3	0.11
103769	2MSL8	30.1	0.07
103769	4MLS8	128.4	0.05
103769	3ML8	350.6	0.03
103769	3MK8	16.8	0.05
103769	2MSK8	62.5	0.05
103769	2M2NK9	144.4	0.01
103769	3MNK9	171.4	0.02
103769	4MK9	201.2	0.03
103769	3MSK9	244.7	0.05
103769	4MN10	273.1	0.05
103769	M10	299.2	0.06
103769	3MNS10	315.2	0.07
103769	4MS10	336.3	0.11
103769	3MSL10	346.3	0.04
103769	3M2S10	22.5	0.06
103769	4MSK11	204	0.03
103769	4MNS12	276.2	0.05
103769	5MS12	298.3	0.06
103769	4MSL12	307	0.03
103769	4M2S12	343	0.05
103769	TK1	352.9	0.03
103769	PSI1	322.1	0.03
103769	KP1	324.7	0.01
103769	THE1	310.7	0.04
103769	KJ2-IHO	314.9	0.02
103769	OQ2-HORN	31	0.08
103770	M2	105.9	11.85
103770	S2	151.3	3.31
103770	N2	83.4	1.92
103770	K1	340.9	2.08
103770	M4	77.5	0.78
103770	O1	328.5	1.28
103770	M6	23.9	0.65
103770	S4	248.6	0.04
103770	NU2	86.4	0.37
103770	MU2	60.6	0.29
103770	2N2	60.9	0.26
103770	OO1	352.9	0.06
103770	LDA2	127	0.08
103770	M1	334.6	0.09
103770	J1	346.8	0.1
103770	RHO1	323.2	0.05
103770	Q1	322.4	0.25
103770	T2	149.4	0.19
103770	R2	153	0.03
103770	2Q1	316.1	0.03
103770	P1	340	0.69
103770	L2	128.5	0.33
103770	K2	154.9	0.9
103770	M8	350.9	0.17
103771	M2	116.4	12.22
103771	S2	161.3	3.65
103771	N2	93.1	2.22
103771	K1	345.3	2.05
103771	M4	114.5	1.12
103771	O1	336.9	1.49
103771	M6	73.6	0.8
103771	S4	306.8	0.08
103771	NU2	96.3	0.43
103771	S6	252.6	0.01
103771	MU2	71.5	0.29
103771	2N2	69.9	0.3
103771	OO1	353.7	0.07
103771	LDA2	137.3	0.09
103771	M1	341.2	0.1
103771	J1	349.5	0.12
103771	MM	39.7	0.2
103771	SSA	45.6	0.24
103771	SA	230.2	0.18
103771	MSF	50.4	0.47
103771	RHO1	333.3	0.06
103771	Q1	332.8	0.29
103771	T2	159.5	0.22
103771	R2	163.1	0.03
103771	2Q1	328.6	0.04
103771	P1	344.7	0.68
103771	L2	139.7	0.34
103771	K2	165	0.99
103771	M8	73.9	0.26
103772	M2	329	5.62
103772	S2	8.3	2.19
103772	N2	307.3	1.22
103772	K1	289.9	1.6
103772	M4	53.6	0.05
103772	O1	272	1.03
103772	M6	270.2	0.09
103772	NU2	310.2	0.24
103772	S6	23.9	0.01
103772	MU2	289.7	0.13
103772	2N2	285.7	0.16
103772	OO1	307.9	0.05
103772	LDA2	347.2	0.04
103772	M1	281	0.07
103772	J1	298.8	0.08
103772	SA	249.9	0.45
103772	MF	176.3	0.11
103772	RHO1	264.3	0.04
103772	Q1	263.1	0.2
103772	T2	6.7	0.13
103772	R2	9.9	0.02
103772	2Q1	254.2	0.03
103772	P1	288.6	0.53
103772	L2	350.6	0.16
103772	K2	11.4	0.6
103772	M8	22.8	0.01
103773	M2	323.5	5.32
103773	S2	1.9	1.9
103773	N2	293.9	1.1
103773	K1	288.1	1.57
103773	M4	194.9	0.03
103773	O1	268.6	1.07
103773	M6	7.7	0.03
103773	S4	319.4	0.02
103773	NU2	297.9	0.21
103773	MU2	337.3	0.13
103773	2N2	264.3	0.15
103773	OO1	307.6	0.05
103773	LDA2	341.3	0.04
103773	M1	278.4	0.08
103773	J1	297.8	0.09
103773	SSA	151.7	0.05
103773	SA	262.1	0.26
103773	RHO1	260.2	0.04
103773	Q1	258.9	0.21
103773	T2	0.3	0.11
103773	R2	3.4	0.02
103773	2Q1	249.3	0.03
103773	P1	286.6	0.52
103773	L2	353.2	0.15
103773	K2	5	0.52
103773	M8	89.7	0.01
103774	M2	322.7	5.33
103774	S2	358.7	1.91
103774	N2	298.1	1.16
103774	K1	287.2	1.56
103774	M4	213.2	0.05
103774	O1	269.3	1.06
103774	M6	35.8	0.02
103774	S4	312.7	0.02
103774	NU2	301.4	0.23
103774	S6	218.2	0.01
103774	MU2	338.1	0.13
103774	2N2	273.5	0.15
103774	OO1	305.2	0.05
103774	LDA2	339.4	0.04
103774	M1	278.3	0.08
103774	J1	296.1	0.09
103774	SSA	151.7	0.05
103774	SA	262.1	0.26
103774	RHO1	261.6	0.04
103774	Q1	260.4	0.21
103774	T2	357.2	0.11
103774	R2	0.1	0.02
103774	2Q1	251.5	0.03
103774	P1	285.9	0.52
103774	L2	347.3	0.15
103774	K2	1.6	0.52
103775	M2	308.3	3.17
103775	S2	341.6	1.15
103775	N2	283.6	0.62
103775	K1	284.6	1.32
103775	M4	54.9	0.06
103775	O1	273.8	0.8
103775	M6	83.3	0.04
103775	S4	141.1	0.02
103775	NU2	286.9	0.12
103775	S6	198.7	0.02
103775	MU2	330.1	0.08
103775	2N2	258.8	0.08
103775	OO1	295.3	0.04
103775	LDA2	323.8	0.02
103775	M1	279.2	0.06
103775	J1	289.9	0.06
103775	SA	151.7	0.05
103775	MSF	262.1	0.26
103775	RHO1	269.2	0.03
103775	Q1	268.5	0.15
103775	T2	340.3	0.07
103775	R2	343	0.01
103775	2Q1	263.2	0.02
103775	P1	283.8	0.44
103775	L2	333.1	0.09
103775	K2	344.3	0.31
103775	M8	202.7	0.01
103776	M2	307.4	3.17
103776	S2	340.9	1.06
103776	N2	283.4	0.66
103776	K1	288.5	1.3
103776	M4	24.7	0.03
103776	O1	272.7	0.84
103776	M6	85.9	0.03
103776	MK3	259.6	0.01
103776	MN4	357.6	0.01
103776	NU2	285.1	0.13
103776	MU2	277.8	0.08
103776	2N2	258.1	0.08
103776	OO1	311	0.04
103776	LDA2	306.3	0.02
103776	S1	49.9	0.04
103776	M1	292.9	0.05
103776	J1	297.2	0.08
103776	SA	246.1	0.26
103776	MSF	25.2	0.03
103776	MF	193.3	0.11
103776	RHO1	266.6	0.03
103776	Q1	264.6	0.15
103776	T2	331	0.07
103776	2Q1	266.6	0.02
103776	P1	284.2	0.41
103776	2SM2	130.9	0.01
103776	M3	286.8	0.01
103776	L2	314.9	0.08
103776	2MK3	240.8	0.01
103776	K2	332.1	0.29
103776	M8	211.5	0.01
103776	MS4	69.9	0.02
103777	M2	317.5	4.05
103777	S2	355.5	1.44
103777	N2	297.5	0.86
103777	K1	287.4	1.44
103777	M4	184.1	0.31
103777	O1	267.7	1.05
103777	M6	37.8	0.09
103777	S4	217.7	0.01
103777	NU2	300.2	0.17
103777	S6	206.7	0.02
103777	MU2	279.5	0.1
103777	2N2	277.6	0.11
103777	OO1	307.2	0.05
103777	LDA2	335.1	0.03
103777	M1	277.6	0.08
103777	J1	297.3	0.08
103777	SSA	151.7	0.05
103777	SA	262.1	0.26
103777	RHO1	259.2	0.04
103777	Q1	257.9	0.2
103777	T2	353.9	0.09
103777	R2	357	0.01
103777	2Q1	248	0.03
103777	P1	286	0.48
103777	L2	337.4	0.11
103777	K2	358.5	0.39
103777	M8	81.4	0.03
103778	M2	308.4	3.4
103778	S2	342.2	1.27
103778	N2	285.6	0.68
103778	K1	286.6	1.3
103778	M4	15.8	0.03
103778	O1	273.4	0.86
103778	M6	102.5	0.04
103778	S4	176.7	0.01
103778	NU2	288.6	0.13
103778	S6	225	0.01
103778	MU2	328.9	0.08
103778	2N2	262.7	0.09
103778	OO1	299.8	0.04
103778	LDA2	324.1	0.02
103778	M1	280.1	0.06
103778	J1	293.2	0.07
103778	SSA	151.7	0.05
103778	SA	262.1	0.26
103778	RHO1	267.8	0.03
103778	Q1	266.9	0.17
103778	T2	340.8	0.08
103778	R2	343.5	0.01
103778	2Q1	260.3	0.02
103778	P1	285.6	0.43
103778	L2	331.2	0.1
103778	K2	344.9	0.34
103778	M8	236.6	0.01
103779	M2	308.8	3.47
103779	S2	340.3	1.15
103779	N2	284.6	0.77
103779	K1	288.7	1.38
103779	M4	21.1	0.03
103779	O1	273.7	0.87
103779	M6	86.7	0.05
103779	S4	265.4	0.01
103779	NU2	287.9	0.15
103779	S6	123.5	0.02
103779	MU2	277.3	0.08
103779	2N2	260.5	0.1
103779	OO1	303.7	0.04
103779	LDA2	323.4	0.02
103779	M1	281.3	0.06
103779	J1	296.2	0.07
103779	MM	191.7	0.06
103779	SSA	151.7	0.05
103779	SA	262.1	0.26
103779	MSF	51.5	0.05
103779	MF	165.2	0.07
103779	RHO1	267.3	0.03
103779	Q1	266.3	0.17
103779	T2	339	0.07
103779	R2	341.6	0.01
103779	2Q1	258.9	0.02
103779	P1	287.6	0.46
103779	L2	332.9	0.1
103779	K2	342.9	0.31
103779	M8	260.8	0.01
103780	M2	323.9	5.2
103780	S2	2.4	1.93
103780	N2	303.6	1.13
103780	K1	286.6	1.59
103780	M4	191.4	0.06
103780	O1	267.8	1.07
103780	M6	16.2	0.1
103780	S4	317.8	0.02
103780	NU2	306.3	0.22
103780	MU2	285.3	0.12
103780	2N2	283.4	0.15
103780	OO1	305.4	0.05
103780	LDA2	341.8	0.04
103780	M1	277.3	0.08
103780	J1	295.9	0.09
103780	SSA	151.7	0.05
103780	SA	262.1	0.26
103780	RHO1	259.8	0.04
103780	Q1	258.5	0.21
103780	T2	0.9	0.11
103780	R2	4	0.02
103780	2Q1	249.2	0.03
103780	P1	285.2	0.53
103780	L2	344.1	0.14
103780	K2	5.6	0.52
103781	M2	323.4	5.5
103781	S2	357.6	2.01
103781	N2	302	1.1
103781	K1	285.8	1.73
103781	M4	225.7	0.06
103781	O1	269.4	1.01
103781	M6	15.9	0.03
103781	S4	337.5	0.01
103781	NU2	304.9	0.21
103781	S6	184.9	0.01
103781	MU2	289.2	0.13
103781	2N2	280.7	0.15
103781	OO1	302.1	0.04
103781	LDA2	339.3	0.04
103781	M1	277.6	0.07
103781	J1	293.9	0.08
103781	SA	250.2	0.41
103781	MF	171.7	0.08
103781	RHO1	262.3	0.04
103781	Q1	261.2	0.2
103781	T2	356.3	0.12
103781	R2	359	0.02
103781	2Q1	253.1	0.03
103781	P1	284.5	0.57
103781	L2	344.8	0.15
103781	K2	0.4	0.55
103782	M2	298.7	2.98
103782	S2	329.2	1.08
103782	N2	274.6	0.59
103782	K1	272.2	1.1
103782	M4	45.2	0.01
103782	O1	258.1	0.74
103782	M6	155.6	0.01
103782	S4	211.5	0.03
103782	NU2	277.8	0.11
103782	S6	352.2	0.01
103782	MU2	268.1	0.07
103782	2N2	250.5	0.08
103782	OO1	286.4	0.03
103782	LDA2	312.9	0.02
103782	M1	265.2	0.05
103782	J1	279.2	0.06
103782	RHO1	252.1	0.03
103782	Q1	251.1	0.14
103782	T2	328	0.06
103782	R2	330.5	0.01
103782	2Q1	244.1	0.02
103782	P1	271.2	0.36
103782	L2	322.8	0.08
103782	K2	331.7	0.29
103783	M2	298.9	3
103783	S2	327	1.02
103783	N2	276	0.66
103783	K1	270.9	1.2
103783	M4	169.1	0.01
103783	O1	262	0.72
103783	M6	158.5	0.02
103783	S4	214.6	0.01
103783	NU2	279.1	0.13
103783	MU2	324.2	0.07
103783	2N2	253.1	0.09
103783	OO1	279.7	0.03
103783	LDA2	311.9	0.02
103783	M1	266.5	0.05
103783	J1	275.3	0.06
103783	SSA	151.7	0.05
103783	SA	262.1	0.26
103783	RHO1	258.2	0.03
103783	Q1	257.6	0.14
103783	T2	325.8	0.06
103783	R2	328.1	0.01
103783	2Q1	253.2	0.02
103783	P1	270.2	0.4
103783	L2	321.8	0.09
103783	K2	329.2	0.28
103783	M8	91.7	0.01
103784	M2	322.7	5.44
103784	S2	359.3	2
103784	N2	300.6	1.15
103784	K1	286.1	1.63
103784	M4	217.7	0.05
103784	O1	268.3	1.06
103784	M6	20	0.03
103784	S4	315.5	0.01
103784	NU2	303.6	0.22
103784	MU2	286	0.13
103784	2N2	278.5	0.15
103784	OO1	304	0.05
103784	LDA2	339.7	0.04
103784	M1	277.3	0.08
103784	J1	295	0.08
103784	SA	250.2	0.41
103784	MF	171.7	0.08
103784	RHO1	260.7	0.04
103784	Q1	259.5	0.2
103784	T2	357.8	0.12
103784	R2	0.8	0.02
103784	2Q1	250.7	0.03
103784	P1	284.8	0.54
103784	L2	344.8	0.15
103784	K2	2.3	0.54
103785	M2	299.4	2.99
103785	S2	330.7	1
103785	N2	278	0.64
103785	K1	268.9	1.12
103785	M4	149.4	0.01
103785	O1	256.3	0.74
103785	M6	151.8	0.01
103785	S4	193.3	0.01
103785	NU2	280.9	0.12
103785	S6	224.2	0.01
103785	MU2	268.1	0.07
103785	2N2	256.7	0.09
103785	OO1	281.5	0.03
103785	LDA2	314	0.02
103785	M1	262.7	0.05
103785	J1	275.2	0.06
103785	MM	191.7	0.06
103785	SSA	151.7	0.05
103785	SA	262.1	0.26
103785	MSF	51.5	0.05
103785	MF	165.2	0.07
103785	RHO1	251	0.03
103785	Q1	250.1	0.14
103785	T2	329.5	0.06
103785	R2	332	0.01
103785	2Q1	243.9	0.02
103785	P1	268	0.37
103785	L2	320.8	0.08
103785	K2	333.3	0.27
103786	M2	322.6	5.32
103786	S2	355.6	1.95
103786	N2	303.1	1.07
103786	K1	285.1	1.77
103786	M4	221.8	0.1
103786	O1	268.9	1.02
103786	M6	169.4	0.02
103786	S4	318	0.03
103786	NU2	305.7	0.21
103786	MU2	341.6	0.13
103786	2N2	283.6	0.14
103786	OO1	301.4	0.04
103786	LDA2	337.9	0.04
103786	M1	277.1	0.07
103786	J1	293.2	0.08
103786	SSA	151.7	0.05
103786	SA	262.1	0.26
103786	RHO1	261.9	0.04
103786	Q1	260.8	0.2
103786	T2	354.2	0.11
103786	R2	356.9	0.02
103786	2Q1	252.7	0.03
103786	P1	283.9	0.58
103786	L2	342	0.15
103786	K2	358.2	0.53
103787	M2	302.1	3.17
103787	S2	332.3	1.14
103787	N2	277.2	0.66
103787	K1	269.8	1.17
103787	M4	201.7	0.06
103787	O1	255.5	0.75
103787	M6	175.6	0.03
103787	S4	218	0.02
103787	NU2	280.5	0.13
103787	MU2	271.8	0.08
103787	2N2	252.4	0.09
103787	OO1	284.2	0.03
103787	LDA2	316.1	0.02
103787	M1	262.7	0.05
103787	J1	276.9	0.06
103787	RHO1	249.4	0.03
103787	Q1	248.4	0.14
103787	T2	331.1	0.07
103787	R2	333.5	0.01
103787	2Q1	241.3	0.02
103787	P1	268.8	0.39
103787	L2	326.9	0.09
103787	K2	334.7	0.31
103787	M8	38.7	0.01
103788	M2	319.3	5.27
103788	S2	357.2	1.9
103788	N2	293.9	1.06
103788	K1	284.8	1.63
103788	M4	219.3	0.08
103788	O1	267.7	1.07
103788	M6	51.4	0.01
103788	S4	319.3	0.02
103788	NU2	297.3	0.21
103788	MU2	333.4	0.13
103788	2N2	268.5	0.14
103788	OO1	301.9	0.05
103788	LDA2	336.8	0.04
103788	M1	276.3	0.08
103788	J1	293.3	0.09
103788	SSA	151.7	0.05
103788	SA	262.1	0.26
103788	RHO1	260.3	0.04
103788	Q1	259.2	0.21
103788	T2	355.6	0.11
103788	R2	358.7	0.02
103788	2Q1	250.7	0.03
103788	P1	283.5	0.54
103788	L2	344.6	0.15
103788	K2	0.2	0.52
103789	M2	314.2	4.43
103789	S2	348.5	1.59
103789	N2	291.3	0.93
103789	K1	280.4	1.62
103789	M4	209.6	0.11
103789	O1	265.3	1.01
103789	M6	89.8	0.04
103789	MK3	103.4	0.06
103789	S4	299.7	0.01
103789	MN4	177.8	0.04
103789	NU2	291.3	0.17
103789	MU2	296	0.16
103789	2N2	266.4	0.11
103789	OO1	313.3	0.06
103789	LDA2	265.1	0.03
103789	S1	55.2	0.05
103789	M1	293.2	0.06
103789	J1	298.2	0.1
103789	SSA	328.3	0.02
103789	SA	243.6	0.23
103789	MF	184.1	0.11
103789	RHO1	254.2	0.03
103789	Q1	258.1	0.18
103789	T2	338.5	0.1
103789	2Q1	257.7	0.02
103789	P1	277.4	0.51
103789	2SM2	101	0.03
103789	L2	299.7	0.09
103789	2MK3	71.9	0.05
103789	K2	339.3	0.42
103789	M8	325	0.01
103789	MS4	258.7	0.07
103790	M2	321.8	4.68
103790	S2	357.6	1.6
103790	N2	297.7	1.04
103790	K1	286.4	1.53
103790	M4	215.3	0.1
103790	O1	268.1	1.05
103790	M6	154.1	0.02
103790	S4	303.2	0.02
103790	NU2	301	0.2
103790	MU2	286.1	0.11
103790	2N2	273.6	0.14
103790	OO1	304.6	0.05
103790	LDA2	338.4	0.03
103790	M1	277.3	0.08
103790	J1	295.4	0.08
103790	SSA	151.7	0.05
103790	SA	262.1	0.26
103790	RHO1	260.3	0.04
103790	Q1	259.1	0.2
103790	T2	356.1	0.1
103790	R2	359	0.01
103790	2Q1	250	0.03
103790	P1	285	0.51
103790	L2	345.9	0.13
103790	K2	0.5	0.44
103790	M8	91.9	0.01
103791	M2	302.9	2.96
103791	S2	335.4	1.02
103791	N2	280.5	0.59
103791	K1	277.2	1.44
103791	M4	246	0.07
103791	O1	260.4	0.98
103791	M6	254.2	0.01
103791	S4	258.2	0.01
103791	NU2	283.5	0.11
103791	MU2	318.9	0.07
103791	2N2	258.2	0.08
103791	OO1	294	0.04
103791	LDA2	318	0.02
103791	M1	268.9	0.07
103791	J1	285.5	0.08
103791	RHO1	253.2	0.04
103791	Q1	252.1	0.19
103791	T2	334.1	0.06
103791	R2	336.7	0.01
103791	2Q1	243.8	0.03
103791	P1	275.9	0.48
103791	L2	325.2	0.08
103791	K2	338	0.28
103792	M2	315.7	3.15
103792	S2	352.3	1.06
103792	N2	292.1	0.65
103792	K1	282	1.42
103792	M4	254.8	0.06
103792	O1	265.7	0.95
103792	M6	244.1	0.02
103792	S4	311.6	0.01
103792	NU2	295.2	0.12
103792	MU2	279.3	0.08
103792	2N2	268.4	0.09
103792	OO1	298.4	0.04
103792	LDA2	332.8	0.02
103792	M1	274	0.07
103792	J1	290.1	0.08
103792	SSA	54.2	0.05
103792	SA	267.8	0.18
103792	RHO1	258.7	0.04
103792	Q1	257.6	0.18
103792	T2	350.8	0.06
103792	R2	353.8	0.01
103792	2Q1	249.5	0.02
103792	P1	280.7	0.47
103792	L2	339.5	0.09
103792	K2	355.2	0.29
103793	M2	9	3.32
103793	S2	45.3	1.17
103793	N2	344.2	0.74
103793	K1	311	1.43
103793	M4	334	0.08
103793	O1	292.9	0.96
103793	M6	22.5	0.03
103793	S4	19.5	0.02
103793	NU2	347.5	0.14
103793	MU2	332.7	0.08
103793	2N2	319.5	0.1
103793	OO1	328.9	0.04
103793	LDA2	25.8	0.02
103793	M1	302	0.07
103793	J1	319.9	0.08
103793	RHO1	285.2	0.04
103793	Q1	284.1	0.19
103793	T2	43.7	0.07
103793	R2	46.7	0.01
103793	2Q1	275.2	0.03
103793	P1	309.6	0.47
103793	L2	33.7	0.1
103793	K2	48.1	0.32
103794	M2	324.5	3.04
103794	S2	356.2	0.98
103794	N2	301.3	0.65
103794	K1	289.5	1.48
103794	M4	259.7	0.06
103794	O1	271.9	0.94
103794	M6	266.1	0.04
103794	NU2	304.4	0.13
103794	S6	205.1	0.01
103794	MU2	292.8	0.07
103794	2N2	278	0.09
103794	OO1	307	0.04
103794	LDA2	339.2	0.02
103794	M1	280.8	0.07
103794	J1	298.2	0.08
103794	SA	272.3	0.4
103794	RHO1	264.4	0.04
103794	Q1	263.2	0.18
103794	T2	354.9	0.06
103794	R2	357.5	0.01
103794	2Q1	254.5	0.02
103794	P1	288.1	0.49
103794	L2	347.7	0.09
103794	K2	358.8	0.27
103795	M2	323.1	2.67
103795	S2	355.7	0.94
103795	N2	298.7	0.59
103795	K1	288.2	1.36
103795	M4	249.8	0.03
103795	O1	273	0.91
103795	M6	286.5	0.04
103795	NU2	302	0.11
103795	S6	238.8	0.01
103795	MU2	333.3	0.07
103795	2N2	274.2	0.08
103795	OO1	303.4	0.04
103795	LDA2	338.3	0.02
103795	M1	280.7	0.07
103795	J1	295.7	0.07
103795	SA	272.3	0.4
103795	RHO1	266.5	0.04
103795	Q1	265.5	0.18
103795	T2	354.4	0.06
103795	R2	357	0.01
103795	2Q1	257.9	0.02
103795	P1	287.1	0.45
103795	L2	347.6	0.08
103795	K2	358.4	0.26
103796	M2	322.2	2.59
103796	S2	351.2	0.9
103796	N2	300.2	0.58
103796	K1	286.2	1.41
103796	M4	271.7	0.03
103796	O1	271.4	0.88
103796	M6	290.6	0.04
103796	NU2	303.1	0.11
103796	S6	252.5	0.01
103796	MU2	335.6	0.06
103796	2N2	278.1	0.08
103796	OO1	301.1	0.04
103796	LDA2	335.7	0.02
103796	M1	278.9	0.06
103796	J1	293.6	0.07
103796	RHO1	265	0.03
103796	Q1	264	0.17
103796	T2	350	0.05
103796	R2	352.4	0.01
103796	2Q1	256.7	0.02
103796	P1	285.1	0.47
103796	L2	344.2	0.07
103796	K2	353.5	0.25
103797	M2	322.5	2.39
103797	S2	353	0.81
103797	N2	297.4	0.51
103797	K1	286.6	1.37
103797	M4	308.4	0.02
103797	O1	270.3	0.92
103797	M6	332.8	0.02
103797	S4	212.1	0.01
103797	NU2	300.7	0.1
103797	S6	250.4	0.01
103797	MU2	333.2	0.06
103797	2N2	272.2	0.07
103797	OO1	302.9	0.04
103797	LDA2	336.7	0.02
103797	M1	278.5	0.07
103797	J1	294.7	0.07
103797	SA	272.3	0.4
103797	RHO1	263.3	0.04
103797	Q1	262.2	0.18
103797	T2	351.8	0.05
103797	R2	354.3	0.01
103797	2Q1	254.1	0.02
103797	P1	285.4	0.45
103797	L2	347.7	0.07
103797	K2	355.5	0.22
103798	M2	318.4	2.26
103798	S2	344.7	0.77
103798	N2	295.9	0.49
103798	K1	282.2	1.35
103798	O1	266	0.9
103798	M6	353.8	0.01
103798	S4	227	0.01
103798	NU2	298.9	0.1
103798	MU2	292.2	0.06
103798	2N2	273.4	0.07
103798	OO1	298.3	0.04
103798	LDA2	330.6	0.02
103798	M1	274.2	0.06
103798	J1	290.2	0.07
103798	SA	272.3	0.4
103798	RHO1	259.1	0.03
103798	Q1	258	0.17
103798	T2	343.6	0.05
103798	R2	345.7	0.01
103798	2Q1	250	0.02
103798	P1	281	0.45
103798	L2	340.9	0.06
103798	K2	346.8	0.21
103799	M2	322.4	2.4
103799	S2	349.6	0.8
103799	N2	297.1	0.52
103799	K1	285.4	1.36
103799	M4	280.9	0.01
103799	O1	269.7	0.88
103799	M6	26.9	0.03
103799	NU2	302.6	0.1
103799	MU2	274	0.06
103799	2N2	271	0.07
103799	OO1	312.5	0.04
103799	LDA2	330.8	0.01
103799	S1	74	0.03
103799	M1	308.1	0.05
103799	J1	294	0.07
103799	MM	289.5	0.16
103799	SSA	136	0.24
103799	SA	275.5	0.5
103799	MSF	77.4	0.05
103799	MF	115.4	0.1
103799	RHO1	272.8	0.02
103799	Q1	265.5	0.16
103799	T2	343.1	0.05
103799	R2	23	0.01
103799	2Q1	258.6	0.02
103799	P1	284	0.43
103799	2SM2	153.2	0.01
103799	M3	237.6	0.01
103799	L2	329.2	0.06
103799	K2	342.8	0.22
103799	MS4	304.8	0.01
103800	M2	324.1	2.49
103800	S2	351.6	0.84
103800	N2	301.5	0.53
103800	K1	286.3	1.34
103800	M4	267.8	0.01
103800	O1	270.6	0.87
103800	M6	15.7	0.04
103800	NU2	304.5	0.1
103800	MU2	296.7	0.06
103800	2N2	279	0.07
103800	OO1	302	0.04
103800	LDA2	336.8	0.02
103800	M1	278.5	0.06
103800	J1	294.1	0.07
103800	SA	266.4	0.47
103800	RHO1	263.9	0.03
103800	Q1	262.8	0.17
103800	T2	350.4	0.05
103800	R2	352.7	0.01
103800	2Q1	255	0.02
103800	P1	285.1	0.44
103800	L2	346.7	0.07
103800	K2	353.8	0.23
103801	M2	326.3	2.24
103801	S2	356.2	0.72
103801	N2	300.4	0.51
103801	K1	285	1.28
103801	M4	87.1	0.01
103801	O1	270.1	0.84
103801	M6	109.5	0.06
103801	S4	187.1	0.01
103801	NU2	303.9	0.1
103801	S6	96.1	0.01
103801	MU2	332.8	0.05
103801	2N2	274.5	0.07
103801	OO1	299.9	0.04
103801	LDA2	340.2	0.02
103801	M1	277.6	0.06
103801	J1	292.4	0.07
103801	RHO1	263.7	0.03
103801	Q1	262.7	0.16
103801	T2	355	0.04
103801	R2	357.4	0.01
103801	2Q1	255.3	0.02
103801	P1	283.9	0.42
103801	L2	352.2	0.06
103801	K2	358.6	0.2
103802	M2	328.2	2.21
103802	S2	353.6	0.73
103802	N2	303.9	0.49
103802	K1	284.3	1.36
103802	M4	45.6	0.01
103802	O1	269.9	0.87
103802	M6	133.9	0.05
103802	MK3	47.7	0.01
103802	S4	207.2	0.01
103802	NU2	308.7	0.1
103802	MU2	277.3	0.06
103802	2N2	276.4	0.06
103802	OO1	311	0.04
103802	LDA2	343	0.01
103802	S1	69	0.04
103802	M1	300.5	0.05
103802	J1	294.7	0.08
103802	SA	258.6	0.35
103802	MF	170	0.1
103802	RHO1	256.6	0.03
103802	Q1	264.9	0.16
103802	T2	343.7	0.05
103802	R2	295.9	0.01
103802	2Q1	270.9	0.02
103802	P1	279.8	0.42
103802	M3	229	0.01
103802	L2	337.5	0.05
103802	2MK3	0.9	0.01
103802	K2	346.1	0.2
103803	M2	335.2	2.34
103803	S2	359.5	0.76
103803	N2	313.6	0.55
103803	K1	288.8	1.4
103803	M4	167.5	0.02
103803	O1	277.6	0.85
103803	M6	196.4	0.1
103803	S4	183.6	0.01
103803	NU2	316.5	0.11
103803	S6	217.2	0.02
103803	MU2	310.8	0.06
103803	2N2	291.9	0.07
103803	OO1	300.1	0.04
103803	LDA2	346.5	0.02
103803	M1	283.2	0.06
103803	J1	294.4	0.07
103803	SA	272.3	0.4
103803	RHO1	272.8	0.03
103803	Q1	272	0.16
103803	T2	358.6	0.05
103803	R2	0.5	0.01
103803	2Q1	266.4	0.02
103803	P1	288	0.47
103803	L2	356.8	0.07
103803	K2	1.5	0.21
103803	M8	195.7	0.01
103804	M2	96	0.74
103804	S2	192.4	0.11
103804	N2	40.1	0.2
103804	K1	334.8	1.12
103804	O1	319.6	0.78
103804	NU2	47.6	0.04
103804	2N2	344.2	0.03
103804	OO1	350	0.03
103804	S1	131.5	0.05
103804	M1	324.5	0.04
103804	J1	342.5	0.06
103804	SSA	199.1	0.26
103804	SA	265.4	0.3
103804	RHO1	313.1	0.03
103804	Q1	311.1	0.15
103804	2Q1	304.4	0.02
103804	P1	334.9	0.38
103804	L2	151.9	0.02
103804	K2	177.5	0.03
103805	M2	80.7	0.63
103805	S2	269.4	0.06
103805	N2	32.9	0.22
103805	K1	332.3	1.37
103805	O1	309.5	0.93
103805	NU2	44.6	0.04
103805	MU2	325.1	0.03
103805	2N2	348.3	0.04
103805	OO1	11	0.04
103805	LDA2	131.3	0.01
103805	S1	104.6	0.03
103805	M1	342.9	0.05
103805	J1	343.3	0.07
103805	SSA	213.8	0.08
103805	SA	269.6	0.22
103805	MF	189.9	0.07
103805	RHO1	298.3	0.03
103805	Q1	298.7	0.17
103805	T2	325.4	0.01
103805	2Q1	294.2	0.02
103805	P1	329.2	0.43
103805	M3	151.4	0.01
103805	L2	79.5	0.01
103805	K2	333.3	0.01
103806	M2	90.8	0.56
103806	S2	281.5	0.1
103806	N2	36	0.22
103806	K1	336	1.25
103806	M4	297.6	0.01
103806	O1	315.6	0.89
103806	MK3	123.4	0.01
103806	NU2	50.2	0.04
103806	MU2	335	0.04
103806	2N2	351.7	0.04
103806	OO1	7	0.03
103806	S1	113.6	0.05
103806	M1	344.5	0.04
103806	J1	351.4	0.07
103806	SSA	235.8	0.09
103806	SA	254.7	0.19
103806	RHO1	302.5	0.03
103806	Q1	305.5	0.16
103806	T2	313.4	0.01
103806	2Q1	306.7	0.02
103806	P1	331.1	0.4
103806	M3	155.2	0.01
103806	2MK3	69.9	0.01
103806	K2	306.5	0.03
103807	M2	66.4	0.86
103807	S2	327	0.05
103807	N2	21.9	0.31
103807	K1	318.1	1.32
103807	M4	341	0.01
103807	O1	302.6	0.88
103807	MK3	92	0.03
103807	NU2	32.6	0.06
103807	MU2	326.7	0.05
103807	2N2	339.9	0.05
103807	OO1	358.5	0.04
103807	LDA2	136.3	0.01
103807	S1	138.6	0.04
103807	M1	324.1	0.04
103807	J1	327.1	0.07
103807	SSA	202.1	0.07
103807	SA	265.5	0.27
103807	MF	176.2	0.13
103807	RHO1	294.1	0.03
103807	Q1	296.7	0.16
103807	T2	334.5	0.01
103807	R2	216.3	0.01
103807	2Q1	294.5	0.02
103807	P1	313.9	0.42
103807	M3	157	0.01
103807	2MK3	50.5	0.02
103807	K2	23.9	0.03
103808	M2	80.2	0.89
103808	S2	310	0.08
103808	N2	30.3	0.34
103808	K1	318.7	1.11
103808	O1	306.8	0.75
103808	NU2	42.5	0.07
103808	MU2	332.5	0.06
103808	2N2	346.5	0.06
103808	OO1	334.6	0.04
103808	LDA2	19.9	0.01
103808	S1	96.6	0.03
103808	M1	337.3	0.04
103808	J1	339.7	0.07
103808	SSA	216.2	0.13
103808	SA	277.7	0.31
103808	MF	208.4	0.08
103808	RHO1	292.3	0.03
103808	Q1	301	0.14
103808	T2	337.5	0.01
103808	2Q1	295.9	0.02
103808	P1	318.4	0.35
103808	M3	167.8	0.01
103808	L2	130.1	0.05
103808	K2	341	0.03
103809	M2	344.9	1.39
103809	S2	359.4	0.49
103809	N2	325	0.33
103809	K1	287.6	1.22
103809	M4	95.3	0.04
103809	O1	273.4	0.82
103809	M6	289	0.05
103809	NU2	327.7	0.07
103809	MU2	358	0.03
103809	2N2	305	0.05
103809	OO1	301.8	0.04
103809	LDA2	351.6	0.01
103809	M1	280.6	0.06
103809	J1	294.7	0.07
103809	RHO1	267.3	0.03
103809	Q1	266.4	0.16
103809	T2	358.8	0.03
103809	2Q1	259.3	0.02
103809	P1	286.6	0.4
103809	L2	4.9	0.04
103809	K2	0.6	0.13
103809	M8	286.5	0.02
103810	M2	69.7	0.85
103810	S2	318.5	0.07
103810	N2	30.1	0.31
103810	K1	311.6	1.11
103810	M4	182.4	0.04
103810	O1	300.2	0.79
103810	M6	86.9	0.02
103810	S4	19.9	0.01
103810	NU2	35.4	0.06
103810	MU2	208.6	0.02
103810	2N2	350.5	0.04
103810	OO1	323.1	0.03
103810	LDA2	18.1	0.01
103810	M1	305.9	0.06
103810	J1	317.3	0.06
103810	RHO1	295.2	0.03
103810	Q1	294.5	0.15
103810	2Q1	288.8	0.02
103810	P1	310.8	0.37
103810	L2	109.3	0.02
103810	K2	309.5	0.02
103810	M8	86.7	0.02
103811	M2	345.5	1.55
103811	S2	359.9	0.5
103811	N2	324.4	0.38
103811	K1	285.7	1.26
103811	M4	106.4	0.04
103811	O1	269.7	0.85
103811	M6	290.2	0.04
103811	S4	235.1	0.01
103811	NU2	327.2	0.07
103811	MU2	331	0.04
103811	2N2	303.3	0.05
103811	OO1	301.9	0.04
103811	LDA2	352.2	0.01
103811	M1	277.8	0.06
103811	J1	293.7	0.07
103811	SSA	216.2	0.13
103811	SA	277.7	0.31
103811	MF	208.4	0.08
103811	RHO1	262.7	0.03
103811	Q1	261.7	0.16
103811	T2	359.4	0.03
103811	2Q1	253.7	0.02
103811	P1	284.5	0.42
103811	L2	6.6	0.04
103811	K2	1.1	0.13
103811	M8	270.8	0.01
103812	M2	81.3	0.91
103812	S2	320	0.1
103812	N2	31	0.32
103812	K1	321.4	1.22
103812	M4	156.7	0.01
103812	O1	302.6	0.81
103812	NU2	37.8	0.06
103812	MU2	231	0.02
103812	2N2	340.7	0.04
103812	OO1	340.3	0.04
103812	LDA2	25	0.01
103812	M1	312.1	0.06
103812	J1	330.8	0.07
103812	RHO1	294.5	0.03
103812	Q1	293.2	0.16
103812	T2	324.9	0.01
103812	2Q1	283.9	0.02
103812	P1	320	0.4
103812	L2	131.5	0.03
103812	K2	310.2	0.03
103813	M2	344.4	1.33
103813	S2	356.6	0.52
103813	N2	328	0.35
103813	K1	289.3	1.21
103813	M4	209.6	0.02
103813	O1	272.3	0.84
103813	S4	211.9	0.01
103813	NU2	330.2	0.07
103813	MU2	332.1	0.03
103813	2N2	311.7	0.05
103813	OO1	306.3	0.04
103813	LDA2	350	0.01
103813	M1	280.9	0.06
103813	J1	297.7	0.07
103813	SSA	216.2	0.13
103813	SA	277.7	0.31
103813	MF	208.4	0.08
103813	RHO1	265	0.03
103813	Q1	263.8	0.16
103813	T2	356.2	0.03
103813	2Q1	255.4	0.02
103813	P1	288	0.4
103813	L2	0.7	0.04
103813	K2	357.6	0.14
103814	M2	83.8	0.87
103814	S2	300.8	0.1
103814	N2	32.1	0.35
103814	K1	318.3	1.21
103814	M4	130	0.01
103814	O1	301.6	0.79
103814	M6	348.2	0.01
103814	S4	266.1	0.01
103814	NU2	39	0.07
103814	MU2	226.7	0.02
103814	2N2	340.3	0.05
103814	OO1	334.9	0.03
103814	LDA2	17.5	0.01
103814	M1	310	0.06
103814	J1	326.5	0.06
103814	SSA	216.2	0.13
103814	SA	277.7	0.31
103814	MF	208.4	0.08
103814	RHO1	294.4	0.03
103814	Q1	293.3	0.15
103814	T2	306.7	0.01
103814	2Q1	285.1	0.02
103814	P1	317	0.4
103814	L2	135.5	0.02
103814	K2	289.4	0.03
103815	M2	69	0.51
103815	S2	325.1	0.21
103815	N2	26.7	0.26
103815	K1	316.2	1.03
103815	M4	248.7	0.03
103815	O1	301.4	0.74
103815	M6	180	0.01
103815	MK3	131.3	0.02
103815	MN4	185.4	0.01
103815	NU2	46.5	0.05
103815	MU2	338.1	0.04
103815	2N2	331.6	0.07
103815	OO1	318.9	0.03
103815	S1	318.3	0.05
103815	M1	327.1	0.05
103815	J1	324.4	0.07
103815	SSA	216.2	0.13
103815	SA	277.7	0.31
103815	RHO1	292.6	0.03
103815	Q1	293.5	0.15
103815	T2	7.8	0.01
103815	R2	308.5	0.02
103815	2Q1	301.5	0.03
103815	P1	316	0.29
103815	2SM2	270.6	0.01
103815	M3	163.4	0.01
103815	L2	38.6	0.03
103815	2MK3	192.8	0.01
103815	K2	325.1	0.06
103815	MS4	303.1	0.02
103816	M2	340.4	0.83
103816	S2	336.4	0.4
103816	N2	335.4	0.25
103816	K1	300.1	1.07
103816	M4	224.5	0.13
103816	O1	285.5	0.78
103816	M6	321.7	0.02
103816	NU2	336.2	0.05
103816	S6	260.2	0.01
103816	MU2	344.5	0.02
103816	2N2	330.1	0.03
103816	OO1	314.7	0.03
103816	LDA2	338.6	0.01
103816	M1	292.8	0.06
103816	J1	307.3	0.06
103816	SSA	216.2	0.13
103816	SA	277.7	0.31
103816	MF	208.4	0.08
103816	RHO1	279.3	0.03
103816	Q1	278.2	0.15
103816	T2	336.6	0.02
103816	2Q1	271.1	0.02
103816	P1	299	0.35
103816	L2	345.6	0.02
103816	K2	336.1	0.11
103817	M2	340.6	1.39
103817	S2	353.3	0.48
103817	N2	322.4	0.38
103817	K1	287.6	1.17
103817	M4	218.2	0.03
103817	O1	272.1	0.81
103817	M6	243	0.03
103817	S4	326.6	0.01
103817	NU2	324.9	0.08
103817	MU2	327.9	0.03
103817	2N2	304.3	0.05
103817	OO1	303.1	0.04
103817	LDA2	346.5	0.01
103817	M1	279.9	0.06
103817	J1	295.3	0.07
103817	SSA	216.2	0.13
103817	SA	277.7	0.31
103817	MF	208.4	0.08
103817	RHO1	265.4	0.03
103817	Q1	264.4	0.16
103817	T2	352.8	0.03
103817	2Q1	256.7	0.02
103817	P1	286.4	0.39
103817	L2	358.8	0.04
103817	K2	354.3	0.13
103817	M8	229.8	0.01
103818	M2	25.6	0.4
103818	S2	323.8	0.28
103818	N2	12.3	0.26
103818	K1	310.7	1.03
103818	M4	203.9	0.04
103818	O1	296.5	0.73
103818	M6	151.2	0.02
103818	NU2	14.2	0.05
103818	MU2	87.4	0.01
103818	2N2	359	0.04
103818	OO1	325.1	0.03
103818	M1	303.7	0.05
103818	J1	317.8	0.06
103818	SSA	216.2	0.13
103818	SA	277.7	0.31
103818	MF	208.4	0.08
103818	RHO1	290.4	0.03
103818	Q1	289.4	0.14
103818	T2	326.3	0.02
103818	2Q1	282.3	0.02
103818	P1	309.7	0.34
103818	L2	39	0.01
103818	K2	318.8	0.08
103818	M8	96	0.01
103819	M2	334.4	1.47
103819	S2	355	0.54
103819	N2	319	0.35
103819	K1	288.2	1.2
103819	M4	193.5	0.02
103819	O1	272.1	0.84
103819	M6	334.9	0.01
103819	S4	246.8	0.01
103819	NU2	321.1	0.07
103819	MU2	313.7	0.04
103819	2N2	303.6	0.05
103819	OO1	304.2	0.04
103819	LDA2	344	0.01
103819	M1	280.2	0.06
103819	J1	296.1	0.07
103819	SSA	216.2	0.13
103819	SA	277.7	0.31
103819	MF	208.4	0.08
103819	RHO1	265.2	0.03
103819	Q1	264.1	0.16
103819	T2	354.3	0.03
103819	2Q1	256.1	0.02
103819	P1	287	0.4
103819	L2	349.9	0.04
103819	K2	356.8	0.15
103820	M2	65.2	1.35
103820	S2	5.1	0.09
103820	N2	24.5	0.44
103820	K1	308.7	1.31
103820	M4	200.2	0.03
103820	O1	296.1	0.93
103820	M6	168.5	0.01
103820	NU2	30	0.09
103820	MU2	155.4	0.03
103820	2N2	343.9	0.06
103820	OO1	321.3	0.04
103820	LDA2	37.3	0.01
103820	M1	302.5	0.07
103820	J1	315	0.07
103820	RHO1	290.7	0.04
103820	Q1	289.8	0.18
103820	T2	7.5	0.01
103820	2Q1	283.6	0.02
103820	P1	307.8	0.43
103820	L2	105.8	0.04
103820	K2	0.2	0.02
103820	M8	102	0.01
103821	M2	356.3	1.67
103821	S2	6.3	0.52
103821	N2	329.4	0.43
103821	K1	292.5	1.48
103821	M4	208.6	0.08
103821	O1	274.9	1.01
103821	NU2	333	0.08
103821	MU2	16.8	0.04
103821	2N2	302.6	0.06
103821	OO1	310.2	0.04
103821	LDA2	0.9	0.01
103821	M1	283.8	0.07
103821	J1	301.3	0.08
103821	SSA	216.2	0.13
103821	SA	277.7	0.31
103821	MF	208.4	0.08
103821	RHO1	267.3	0.04
103821	Q1	266.1	0.2
103821	T2	5.9	0.03
103821	2Q1	257.3	0.03
103821	P1	291.2	0.49
103821	L2	23.1	0.05
103821	K2	7.1	0.14
103822	M2	117.2	2.32
103822	S2	294.3	0.07
103822	N2	67.9	0.82
103822	K1	321.9	1.59
103822	M4	106.2	0.06
103822	O1	305.7	1.08
103822	M6	71.8	0.03
103822	S4	76.7	0.01
103822	NU2	74.5	0.16
103822	S6	7.2	0.01
103822	MU2	300.2	0.06
103822	2N2	18.5	0.11
103822	OO1	338.1	0.05
103822	LDA2	199.4	0.02
103822	M1	313.9	0.08
103822	J1	329.9	0.09
103822	SSA	241.9	0.02
103822	SA	243.7	0.23
103822	RHO1	298.8	0.04
103822	Q1	297.7	0.21
103822	2Q1	289.6	0.03
103822	P1	320.7	0.52
103822	L2	166.6	0.07
103822	K2	308.6	0.02
103823	M2	51.8	0.77
103823	S2	18.5	0.42
103823	N2	46.2	0.35
103823	K1	312.4	1.34
103823	M4	276.7	0.07
103823	O1	292.3	0.85
103823	M6	238.6	0.04
103823	S4	230.9	0.01
103823	NU2	47	0.07
103823	MU2	85.1	0.02
103823	2N2	40.7	0.05
103823	OO1	332.6	0.04
103823	LDA2	36.4	0.01
103823	M1	302.5	0.06
103823	J1	322.4	0.07
103823	SSA	216.2	0.13
103823	SA	277.7	0.31
103823	RHO1	283.6	0.03
103823	Q1	282.3	0.16
103823	T2	19.9	0.03
103823	2Q1	272.3	0.02
103823	P1	310.9	0.45
103823	L2	57.3	0.02
103823	K2	15.8	0.11
103824	M2	17.3	0.76
103824	S2	12.8	0.47
103824	N2	29.7	0.27
103824	K1	307.7	1.3
103824	M4	299.7	0.1
103824	O1	287.2	0.8
103824	M6	173.5	0.01
103824	S4	236.8	0.01
103824	NU2	28.1	0.05
103824	MU2	21.6	0.02
103824	2N2	42.2	0.03
103824	OO1	328.2	0.04
103824	LDA2	15.2	0.01
103824	M1	297.5	0.06
103824	J1	317.8	0.06
103824	SSA	216.2	0.13
103824	SA	277.7	0.31
103824	RHO1	278.3	0.03
103824	Q1	277	0.15
103824	T2	13	0.03
103824	2Q1	266.8	0.02
103824	P1	306.1	0.43
103824	L2	4.8	0.02
103824	K2	12.5	0.13
103825	M2	334	2.07
103825	S2	357.4	0.7
103825	N2	311.8	0.48
103825	K1	285.1	1.32
103825	M4	86.2	0.02
103825	O1	269.8	0.87
103825	M6	173.3	0.04
103825	S4	208.8	0.01
103825	NU2	314.8	0.09
103825	MU2	310.5	0.05
103825	2N2	289.6	0.06
103825	OO1	300.5	0.04
103825	LDA2	344.8	0.01
103825	M1	277.5	0.06
103825	J1	292.7	0.07
103825	SA	258.6	0.35
103825	MF	170	0.1
103825	RHO1	263.2	0.03
103825	Q1	262.1	0.17
103825	T2	356.5	0.04
103825	R2	358.3	0.01
103825	2Q1	254.5	0.02
103825	P1	283.9	0.44
103825	L2	356.1	0.06
103825	K2	359.3	0.19
103826	M2	206.5	3.39
103826	S2	5.9	0.04
103826	N2	154.9	1.06
103826	K1	3.8	2.13
103826	M4	229.5	0.09
103826	O1	343.5	1.33
103826	M6	316.3	0.05
103826	MK3	174.6	0.03
103826	S4	217.3	0.01
103826	MN4	182.5	0.04
103826	NU2	167.5	0.21
103826	MU2	75.6	0.16
103826	2N2	108.2	0.14
103826	OO1	34.9	0.07
103826	LDA2	246.5	0.05
103826	S1	163.2	0.06
103826	M1	45	0.09
103826	J1	9.9	0.07
103826	SSA	241.9	0.02
103826	SA	243.7	0.23
103826	RHO1	341.4	0.05
103826	Q1	340.8	0.24
103826	T2	118	0.03
103826	R2	197.5	0.01
103826	2Q1	342.8	0.03
103826	P1	358.5	0.67
103826	2SM2	88.6	0.01
103826	M3	52.5	0.03
103826	L2	230.5	0.13
103826	2MK3	236.1	0.06
103826	K2	242.9	0.04
103826	M8	19.9	0.01
103826	MS4	253.9	0.02
103827	M2	88.2	0.77
103827	S2	251.8	0.03
103827	N2	41.4	0.3
103827	K1	325.8	1.05
103827	M4	358.9	0.01
103827	O1	310	0.72
103827	M6	300.5	0.01
103827	NU2	47.7	0.06
103827	MU2	284.2	0.01
103827	2N2	354.7	0.04
103827	OO1	341.7	0.03
103827	M1	318	0.05
103827	J1	333.7	0.06
103827	SSA	222.3	0.08
103827	SA	235.6	0.19
103827	MF	175.7	0.09
103827	RHO1	303.2	0.03
103827	Q1	302.2	0.14
103827	2Q1	294.3	0.02
103827	P1	324.6	0.34
103827	L2	135	0.02
103827	K2	266	0.01
103828	M2	262.7	3.82
103828	S2	321.3	0.07
103828	N2	208.9	1.22
103828	K1	26.8	2.43
103828	M4	53	0.21
103828	O1	3.6	1.41
103828	M6	149.2	0.1
103828	S4	266	0.02
103828	NU2	216.1	0.24
103828	S6	232.3	0.01
103828	MU2	204.1	0.09
103828	2N2	155.1	0.16
103828	OO1	50.1	0.06
103828	LDA2	289.9	0.03
103828	M1	15.3	0.1
103828	J1	38.4	0.11
103828	RHO1	353.6	0.05
103828	Q1	352.1	0.27
103828	2Q1	340.6	0.04
103828	P1	25.1	0.81
103828	L2	316.5	0.11
103828	K2	326.1	0.02
103828	M8	250.2	0.03
103829	M2	95	0.82
103829	S2	195.8	0.01
103829	N2	49.2	0.28
103829	K1	326.7	0.95
103829	M4	13	0.01
103829	O1	312.8	0.64
103829	MK3	300.9	0.01
103829	NU2	58.6	0.05
103829	MU2	350.1	0.04
103829	2N2	5.7	0.05
103829	OO1	353	0.03
103829	S1	97.9	0.03
103829	M1	329	0.04
103829	J1	342.7	0.06
103829	SSA	222.3	0.08
103829	SA	235.6	0.19
103829	MF	175.7	0.09
103829	RHO1	306.4	0.02
103829	Q1	303.1	0.12
103829	T2	344.4	0.01
103829	2Q1	300.5	0.02
103829	P1	323	0.3
103829	M3	171.7	0.01
103829	2MK3	325.9	0.01
103829	K2	48.1	0.01
103830	M2	295.9	4.68
103830	S2	339.6	0.08
103830	N2	239.7	1.26
103830	K1	32.7	2.38
103830	M4	143.2	0.47
103830	O1	5.9	1.36
103830	M6	261.3	0.14
103830	S4	7.1	0.05
103830	NU2	247.2	0.25
103830	S6	338	0.02
103830	MU2	261.8	0.11
103830	2N2	183.5	0.17
103830	OO1	59.6	0.06
103830	LDA2	311.6	0.03
103830	M1	19.4	0.1
103830	J1	46	0.1
103830	RHO1	354.3	0.05
103830	Q1	352.6	0.27
103830	2Q1	339.3	0.04
103830	P1	30.7	0.78
103830	L2	352.3	0.13
103830	K2	343.7	0.02
103830	M8	83.4	0.05
103831	M2	327.2	5.27
103831	S2	12.1	0.07
103831	N2	272.9	1.26
103831	K1	44.7	2.19
103831	M4	224.7	0.85
103831	O1	16.3	1.26
103831	M6	37.8	0.1
103831	S4	84.9	0.06
103831	NU2	280.2	0.24
103831	S6	101.3	0.02
103831	MU2	283.8	0.12
103831	2N2	218.5	0.17
103831	OO1	73.1	0.06
103831	LDA2	347.3	0.04
103831	M1	30.6	0.09
103831	J1	58.8	0.1
103831	RHO1	4.1	0.05
103831	Q1	2.2	0.24
103831	2Q1	348.2	0.03
103831	P1	42.6	0.73
103831	L2	21.7	0.15
103831	K2	15.3	0.02
103831	M8	208.9	0.07
103832	M2	228.2	3.15
103832	S2	21.2	0.1
103832	N2	158.7	1.18
103832	K1	182.3	2.54
103832	M4	258.8	0.05
103832	O1	148.5	1.61
103832	M6	288.3	0.03
103832	S4	310.7	0.02
103832	NU2	168	0.23
103832	S6	230.6	0.01
103832	MU2	70.5	0.07
103832	2N2	89.2	0.16
103832	OO1	216.1	0.07
103832	LDA2	301.4	0.02
103832	M1	165.5	0.11
103832	J1	199.1	0.13
103832	RHO1	134	0.06
103832	Q1	131.7	0.31
103832	T2	12.7	0.01
103832	2Q1	115	0.04
103832	P1	179.7	0.84
103832	L2	297.7	0.09
103832	K2	33.5	0.03
103832	M8	125.5	0.01
103833	M2	336.9	5.97
103833	S2	90.4	0.24
103833	N2	279.4	1.85
103833	K1	53.1	2.75
103833	M4	174.2	0.12
103833	O1	30.4	1.73
103833	M6	56.1	0.02
103833	NU2	287.1	0.36
103833	MU2	224.7	0.14
103833	2N2	221.9	0.25
103833	OO1	75.7	0.07
103833	LDA2	29	0.04
103833	M1	41.8	0.12
103833	J1	64.3	0.13
103833	RHO1	20.7	0.07
103833	Q1	19.2	0.33
103833	T2	85.9	0.01
103833	2Q1	7.9	0.05
103833	P1	51.4	0.91
103833	L2	34.4	0.17
103833	K2	99.7	0.07
103833	M8	119.6	0.01
103834	M2	315.5	1.25
103834	S2	125.9	0.05
103834	N2	221	0.27
103834	K1	201.3	2.12
103834	M4	129	0.19
103834	O1	166.5	1.37
103834	M6	45.1	0.04
103834	S4	330.1	0.02
103834	NU2	233.6	0.05
103834	S6	132.5	0.01
103834	MU2	145.2	0.03
103834	2N2	126.4	0.04
103834	OO1	236.2	0.06
103834	LDA2	34.6	0.01
103834	M1	184	0.1
103834	J1	218.6	0.11
103834	RHO1	151.5	0.05
103834	Q1	149.2	0.27
103834	2Q1	131.9	0.04
103834	P1	198.7	0.7
103834	L2	50.1	0.04
103834	K2	139.7	0.01
103834	M8	127.6	0.01
103835	M2	103.7	1.35
103835	S2	227.2	0.08
103835	N2	31	0.27
103835	K1	71.8	1.95
103835	M4	338.8	0.14
103835	O1	46.1	1.24
103835	M6	1.5	0.03
103835	S4	243.8	0.01
103835	NU2	40.7	0.05
103835	MU2	346.4	0.03
103835	2N2	318.2	0.04
103835	OO1	97.5	0.05
103835	LDA2	158.2	0.01
103835	M1	59.1	0.09
103835	J1	84.6	0.1
103835	RHO1	35	0.05
103835	Q1	33.3	0.24
103835	2Q1	20.6	0.03
103835	P1	69.9	0.65
103835	L2	176.5	0.04
103835	K2	236.7	0.02
103836	M2	254.3	2.39
103836	S2	45.3	0.07
103836	N2	183.3	0.85
103836	K1	192.7	2.43
103836	M4	89.3	0.11
103836	O1	159.8	1.57
103836	M6	245.3	0.02
103836	S4	2.4	0.02
103836	NU2	192.8	0.16
103836	MU2	106.3	0.04
103836	2N2	112.2	0.11
103836	OO1	225.5	0.07
103836	LDA2	294.9	0.01
103836	M1	176.4	0.11
103836	J1	208.9	0.12
103836	RHO1	145.7	0.06
103836	Q1	143.5	0.31
103836	2Q1	127.2	0.04
103836	P1	190.2	0.8
103836	L2	325.3	0.07
103836	K2	49.2	0.02
103836	M8	178.1	0.01
103837	M2	349	7.7
103837	S2	52.6	0.21
103837	N2	301.5	1.69
103837	K1	59	2.34
103837	M4	283.4	1.37
103837	O1	30.5	1.33
103837	M6	164.8	0.06
103837	S4	149.1	0.04
103837	NU2	307.9	0.33
103837	S6	351.4	0.01
103837	MU2	285.9	0.18
103837	2N2	254	0.22
103837	OO1	87.6	0.06
103837	LDA2	18.1	0.05
103837	M1	44.9	0.1
103837	J1	73.2	0.1
103837	RHO1	18.2	0.05
103837	Q1	16.3	0.26
103837	T2	49.8	0.01
103837	2Q1	2.2	0.03
103837	P1	56.9	0.77
103837	L2	36.5	0.21
103837	K2	58	0.06
103837	M8	309.1	0.05
103838	M2	269.6	2.34
103838	S2	41.1	0.07
103838	N2	194.6	0.87
103838	K1	198.3	2.63
103838	M4	113.3	0.2
103838	O1	163.2	1.6
103838	M6	241.2	0.04
103838	S4	245.4	0.01
103838	NU2	204.6	0.17
103838	S6	106.4	0.01
103838	MU2	176.5	0.06
103838	2N2	119.5	0.11
103838	OO1	233.4	0.07
103838	LDA2	330.6	0.02
103838	M1	180.9	0.11
103838	J1	215.7	0.13
103838	RHO1	148.1	0.06
103838	Q1	145.8	0.31
103838	2Q1	128.4	0.04
103838	P1	195.6	0.87
103838	L2	344.6	0.07
103838	K2	51.7	0.02
103838	M8	164.5	0.01
103839	M2	282.4	2
103839	S2	14.7	0.03
103839	N2	208.1	0.54
103839	K1	199.6	2.37
103839	M4	115.4	0.26
103839	O1	163.9	1.56
103839	M6	254.6	0.02
103839	S4	322.7	0.02
103839	NU2	218	0.1
103839	S6	146	0.01
103839	MU2	227.8	0.05
103839	2N2	133.8	0.07
103839	OO1	235.3	0.07
103839	LDA2	325.2	0.01
103839	M1	181.9	0.11
103839	J1	217.3	0.12
103839	RHO1	148.6	0.06
103839	Q1	146.2	0.31
103839	2Q1	128.5	0.04
103839	P1	196.9	0.78
103839	L2	356.6	0.06
103839	K2	22.2	0.01
103839	M8	161.4	0.01
103840	M2	346.6	7.13
103840	S2	96.5	0.24
103840	N2	292.8	2.03
103840	K1	59.1	2.74
103840	M4	218.4	0.41
103840	O1	34.4	1.66
103840	M6	357.8	0.11
103840	S4	200.1	0.01
103840	NU2	300	0.39
103840	MU2	239	0.17
103840	2N2	239	0.27
103840	OO1	83.7	0.07
103840	LDA2	36.5	0.05
103840	M1	46.8	0.11
103840	J1	71.3	0.13
103840	RHO1	23.8	0.06
103840	Q1	22.2	0.32
103840	T2	92.5	0.01
103840	2Q1	9.9	0.04
103840	P1	57.3	0.91
103840	L2	40.3	0.2
103840	K2	105.3	0.07
103840	M8	187.1	0.06
103841	M2	337.5	3.22
103841	S2	122.4	0.07
103841	N2	270.9	0.98
103841	K1	50.5	2.68
103841	M4	282.5	0.01
103841	O1	27.1	1.63
103841	M6	259.5	0.03
103841	S4	358	0.01
103841	NU2	279.8	0.19
103841	MU2	204.8	0.07
103841	2N2	204.3	0.13
103841	OO1	73.8	0.07
103841	LDA2	39	0.02
103841	M1	38.9	0.11
103841	J1	62	0.13
103841	RHO1	17	0.06
103841	Q1	15.5	0.31
103841	2Q1	3.9	0.04
103841	P1	48.7	0.89
103841	L2	44.1	0.09
103841	K2	133.9	0.02
103842	M2	251.4	2.87
103842	S2	43	0.09
103842	N2	181.1	1.06
103842	K1	190.7	2.63
103842	M4	94.1	0.07
103842	O1	156.2	1.66
103842	M6	271.5	0.02
103842	S4	329	0.01
103842	NU2	190.5	0.21
103842	MU2	103.2	0.07
103842	2N2	110.7	0.14
103842	OO1	225.2	0.07
103842	LDA2	320.3	0.02
103842	M1	173.6	0.12
103842	J1	207.8	0.13
103842	RHO1	141.4	0.06
103842	Q1	139.1	0.32
103842	T2	34.7	0.01
103842	2Q1	122	0.04
103842	P1	188.1	0.87
103842	L2	321.7	0.08
103842	K2	54.8	0.02
103842	M8	228.6	0.01
103843	M2	7	7.16
103843	S2	105.7	0.26
103843	N2	314.3	1.89
103843	K1	69.4	2.6
103843	M4	278.2	0.62
103843	O1	41.1	1.51
103843	M6	94.4	0.21
103843	S4	334.5	0.01
103843	NU2	321.3	0.37
103843	S6	100	0.01
103843	MU2	272.6	0.17
103843	2N2	261.4	0.25
103843	OO1	97.7	0.07
103843	LDA2	50.9	0.05
103843	M1	55.4	0.11
103843	J1	83.5	0.12
103843	RHO1	29	0.06
103843	Q1	27.1	0.3
103843	T2	100.8	0.02
103843	2Q1	13	0.04
103843	P1	67.4	0.86
103843	L2	60	0.2
103843	K2	113.6	0.07
103843	M8	321.7	0.07
103844	M2	164.8	2.72
103844	S2	301.8	0.2
103844	N2	101	0.61
103844	K1	98.6	1.88
103844	M4	16.6	0.12
103844	O1	67.5	1.29
103844	M6	170.7	0.06
103844	S4	97.6	0.01
103844	NU2	109.5	0.12
103844	MU2	62.9	0.06
103844	2N2	37.3	0.08
103844	OO1	129.7	0.06
103844	LDA2	229	0.02
103844	M1	83.2	0.09
103844	J1	114	0.1
103844	RHO1	54.1	0.05
103844	Q1	52.1	0.25
103844	T2	296.4	0.01
103844	2Q1	36.6	0.03
103844	P1	96.3	0.62
103844	L2	228.6	0.08
103844	K2	312.8	0.05
103844	M8	13.5	0.01
103845	M2	51.4	3.56
103845	S2	93	0.09
103845	N2	353.6	0.79
103845	K1	82.4	1.2
103845	M4	46.2	1.32
103845	O1	33.1	0.68
103845	M6	32.2	0.44
103845	S4	252.3	0.05
103845	NU2	1.4	0.15
103845	S6	226.8	0.02
103845	MU2	8	0.09
103845	2N2	295.7	0.1
103845	OO1	132	0.03
103845	LDA2	71.3	0.02
103845	M1	58	0.05
103845	J1	106.8	0.05
103845	RHO1	11.7	0.03
103845	Q1	8.7	0.13
103845	2Q1	345	0.02
103845	P1	78.7	0.4
103845	L2	109.3	0.1
103845	K2	96.5	0.02
103845	M8	1.7	0.1
103846	M2	185.3	2.85
103846	S2	301.4	0.08
103846	N2	125.4	0.61
103846	K1	109.4	1.89
103846	M4	308.3	0.28
103846	O1	74.6	1.27
103846	M6	244	0.08
103846	S4	339.4	0.02
103846	NU2	133.5	0.12
103846	S6	10.1	0.01
103846	MU2	97.7	0.05
103846	2N2	65.2	0.08
103846	OO1	144.2	0.06
103846	LDA2	226.1	0.02
103846	M1	92.1	0.09
103846	J1	126.7	0.1
103846	SSA	241.9	0.02
103846	SA	243.7	0.23
103846	RHO1	59.7	0.05
103846	Q1	57.2	0.25
103846	T2	296.8	0.01
103846	2Q1	40	0.03
103846	P1	106.8	0.63
103846	L2	245.1	0.08
103846	K2	312.2	0.02
103846	M8	31.5	0.04
103847	M2	182.6	3.61
103847	S2	8.2	0.34
103847	N2	110.8	0.83
103847	K1	107.8	2.14
103847	M4	125.1	0.12
103847	O1	72.7	1.35
103847	M6	226.2	0.06
103847	MK3	156.7	0.07
103847	S4	128.4	0.01
103847	MN4	67.6	0.07
103847	NU2	146.5	0.18
103847	MU2	343.4	0.11
103847	2N2	124.2	0.1
103847	OO1	150.5	0.06
103847	LDA2	258.2	0.1
103847	S1	287.7	0.18
103847	M1	150.7	0.08
103847	J1	69.8	0.05
103847	RHO1	60.9	0.1
103847	Q1	62.5	0.26
103847	T2	13.3	0.13
103847	R2	218.9	0.36
103847	2Q1	154	0.03
103847	P1	96.6	0.72
103847	2SM2	90.1	0.02
103847	M3	87.1	0.04
103847	L2	248.9	0.35
103847	2MK3	103.8	0.03
103847	K2	242.4	0.21
103847	M8	142.4	0.01
103847	MS4	307.5	0.01
103848	M2	211	4.16
103848	S2	88	0.32
103848	N2	140.6	0.87
103848	K1	121	2.18
103848	M4	284	0.08
103848	O1	85.2	1.43
103848	M6	323.3	0.1
103848	MK3	220	0.21
103848	S4	192.3	0.01
103848	MN4	191.3	0.05
103848	NU2	172.3	0.23
103848	MU2	1.3	0.1
103848	2N2	115.3	0.17
103848	OO1	181.2	0.06
103848	LDA2	277.1	0.11
103848	S1	255.3	0.09
103848	M1	159.4	0.09
103848	J1	57.1	0.05
103848	RHO1	76.7	0.07
103848	Q1	82.7	0.27
103848	T2	78.9	0.2
103848	R2	298.9	0.33
103848	2Q1	119.6	0.06
103848	P1	110.4	0.67
103848	2SM2	108.5	0.02
103848	M3	109.7	0.09
103848	L2	275.8	0.42
103848	2MK3	154.5	0.16
103848	K2	292.2	0.13
103848	M8	333.2	0.01
103848	MS4	76	0.03
103849	M2	242.4	3.39
103849	S2	44	0.14
103849	N2	177.3	0.66
103849	K1	143.5	1.95
103849	M4	33	0.33
103849	O1	107.5	1.42
103849	M6	97.9	0.06
103849	S4	271.6	0.01
103849	NU2	186	0.13
103849	MU2	85.2	0.08
103849	2N2	112.3	0.09
103849	OO1	179.6	0.06
103849	LDA2	315.5	0.02
103849	M1	125.7	0.1
103849	J1	161.4	0.11
103849	RHO1	92	0.05
103849	Q1	89.6	0.27
103849	T2	37.1	0.01
103849	2Q1	71.7	0.04
103849	P1	140.8	0.64
103849	L2	307.6	0.1
103849	K2	56.7	0.04
103849	M8	218.3	0.02
103850	M2	256.9	2.57
103850	S2	353.7	0.14
103850	N2	195.3	0.68
103850	K1	177.3	1.38
103850	M4	60.3	0.21
103850	O1	135.1	0.98
103850	M6	75.9	0.07
103850	S4	177.8	0.01
103850	NU2	203.5	0.13
103850	MU2	160.4	0.06
103850	2N2	133.9	0.09
103850	OO1	219.5	0.04
103850	LDA2	301.4	0.02
103850	M1	156.4	0.07
103850	J1	198.2	0.08
103850	RHO1	117.1	0.04
103850	Q1	114.2	0.19
103850	T2	351.2	0.01
103850	2Q1	93.2	0.03
103850	P1	174.1	0.46
103850	L2	318.4	0.07
103850	K2	1.7	0.04
103850	M8	190	0.02
103851	M2	232	2.94
103851	S2	323.7	0.14
103851	N2	174.3	0.79
103851	K1	164.5	1.57
103851	M4	322.2	0.11
103851	O1	125.3	0.97
103851	M6	333.7	0.09
103851	S4	146.6	0.01
103851	NU2	182	0.15
103851	S6	70.2	0.01
103851	MU2	141.9	0.07
103851	2N2	116.7	0.1
103851	OO1	204	0.04
103851	LDA2	273.8	0.02
103851	M1	145.1	0.07
103851	J1	184.1	0.08
103851	RHO1	108.4	0.04
103851	Q1	105.8	0.19
103851	T2	320.5	0.01
103851	2Q1	86.3	0.03
103851	P1	161.6	0.52
103851	L2	289.5	0.08
103851	K2	331	0.04
103852	M2	242.3	2.85
103852	S2	334	0.25
103852	N2	184.6	0.7
103852	K1	187.5	0.75
103852	M4	349.6	0.03
103852	O1	148.2	0.5
103852	M6	97.3	0.02
103852	S4	44.9	0.03
103852	NU2	192.3	0.13
103852	MU2	150.7	0.07
103852	2N2	126.8	0.09
103852	OO1	226.8	0.02
103852	LDA2	284.8	0.02
103852	M1	168	0.04
103852	J1	207	0.04
103852	RHO1	131.3	0.02
103852	Q1	128.7	0.1
103852	T2	330.3	0.02
103852	2Q1	109.2	0.01
103852	P1	184.6	0.25
103852	L2	300.1	0.08
103852	K2	341.4	0.07
103852	M8	61.7	0.01
103853	M2	241.9	2.89
103853	S2	336.1	0.22
103853	N2	188.6	0.76
103853	K1	189.9	0.7
103853	M4	323	0.05
103853	O1	149.8	0.45
103853	M6	106.2	0.02
103853	S4	24.5	0.01
103853	NU2	195.8	0.15
103853	MU2	148.4	0.07
103853	2N2	135.4	0.1
103853	OO1	230	0.02
103853	LDA2	285.4	0.02
103853	M1	170	0.03
103853	J1	209.8	0.03
103853	RHO1	132.6	0.02
103853	Q1	129.9	0.09
103853	T2	331.8	0.01
103853	2Q1	109.5	0.01
103853	P1	186.9	0.23
103853	L2	295.2	0.08
103853	K2	343.7	0.06
103854	M2	260.3	3.62
103854	S2	18	0.21
103854	N2	192	0.71
103854	K1	148.3	1.96
103854	M4	71.1	0.26
103854	O1	110.9	1.44
103854	M6	112.1	0.11
103854	S4	293.4	0.01
103854	NU2	201.2	0.14
103854	MU2	144.3	0.08
103854	2N2	123.8	0.09
103854	OO1	185.6	0.06
103854	LDA2	314.3	0.03
103854	M1	129.8	0.1
103854	J1	166.8	0.11
103854	RHO1	94.9	0.06
103854	Q1	92.4	0.28
103854	T2	12.9	0.01
103854	2Q1	73.9	0.04
103854	P1	145.4	0.65
103854	L2	328.5	0.1
103854	K2	27.5	0.06
103854	M8	285	0.03
103855	M2	290.1	1.55
103855	S2	22.3	0.11
103855	N2	230.2	0.41
103855	K1	197.6	0.87
103855	M4	122.4	0.16
103855	O1	150.7	0.63
103855	M6	211.4	0.07
103855	NU2	238.3	0.08
103855	MU2	199.2	0.04
103855	2N2	170.4	0.05
103855	OO1	244.4	0.03
103855	LDA2	332.4	0.01
103855	M1	174.3	0.05
103855	J1	220.8	0.05
103855	RHO1	130.6	0.03
103855	Q1	127.4	0.12
103855	T2	17.5	0.01
103855	2Q1	104.2	0.02
103855	P1	194.1	0.29
103855	L2	349.2	0.04
103855	K2	30.1	0.03
103855	M8	10.8	0.02
103856	M2	283.9	3.33
103856	S2	46.4	0.15
103856	N2	217	0.6
103856	K1	163	1.87
103856	M4	115.8	0.28
103856	O1	124.2	1.38
103856	M6	191.3	0.1
103856	S4	328.8	0.02
103856	NU2	225.9	0.12
103856	MU2	149.2	0.06
103856	2N2	150	0.08
103856	OO1	201.7	0.06
103856	LDA2	306.1	0.01
103856	M1	143.7	0.1
103856	J1	182.1	0.11
103856	RHO1	107.5	0.05
103856	Q1	105	0.27
103856	T2	47.3	0.01
103856	2Q1	85.6	0.04
103856	P1	160.1	0.62
103856	L2	350.8	0.1
103856	K2	52.6	0.04
103856	M8	14	0.02
103857	M2	316.8	2.23
103857	S2	131	0.1
103857	N2	248.3	0.54
103857	K1	186	1.4
103857	M4	183.1	0.23
103857	O1	149.5	1.1
103857	M6	260.7	0.07
103857	S4	143.2	0.01
103857	NU2	257.5	0.1
103857	MU2	144.9	0.03
103857	2N2	179.8	0.07
103857	OO1	222.6	0.05
103857	LDA2	353.1	0.01
103857	M1	167.9	0.08
103857	J1	204.2	0.09
103857	RHO1	133.8	0.04
103857	Q1	131.4	0.21
103857	T2	135.1	0.01
103857	2Q1	113.2	0.03
103857	P1	183.2	0.47
103857	L2	25.5	0.06
103857	K2	138.9	0.03
103857	M8	26.1	0.01
103858	M2	233.6	3.07
103858	S2	315.3	0.32
103858	N2	181.7	0.79
103858	K1	262.5	0.9
103858	M4	25.4	0.04
103858	O1	221.3	0.46
103858	M6	314.5	0.05
103858	NU2	188.7	0.15
103858	S6	74.5	0.01
103858	MU2	180.4	0.07
103858	2N2	129.9	0.1
103858	OO1	303.2	0.02
103858	LDA2	271.2	0.02
103858	M1	241.9	0.03
103858	J1	282.6	0.04
103858	RHO1	203.7	0.02
103858	Q1	200.9	0.09
103858	T2	312	0.02
103858	2Q1	180.6	0.01
103858	P1	259.4	0.3
103858	L2	285.4	0.09
103858	K2	321.9	0.09
103858	M8	59.5	0.01
103859	M2	251.6	3.74
103859	S2	337.6	0.33
103859	N2	200.1	0.95
103859	K1	215.4	1.03
103859	M4	13.6	0.09
103859	O1	170	0.62
103859	M6	45	0.06
103859	S4	77.3	0.01
103859	NU2	207	0.18
103859	MU2	184.6	0.09
103859	2N2	148.6	0.13
103859	OO1	260.8	0.03
103859	LDA2	291.1	0.03
103859	M1	192.9	0.04
103859	J1	237.8	0.05
103859	RHO1	150.7	0.02
103859	Q1	147.6	0.12
103859	T2	334.3	0.02
103859	2Q1	125.4	0.02
103859	P1	212	0.34
103859	L2	303.3	0.1
103859	K2	344.5	0.09
103859	M8	271.3	0.01
103860	M2	348.4	2.31
103860	S2	173.4	0.07
103860	N2	277.5	0.42
103860	K1	201.2	1.54
103860	M4	238.8	0.25
103860	O1	161	1.25
103860	M6	343	0.05
103860	S4	33.7	0.01
103860	NU2	287	0.08
103860	MU2	176.6	0.02
103860	2N2	206.6	0.06
103860	OO1	241.1	0.06
103860	LDA2	21.2	0.01
103860	M1	181.2	0.09
103860	J1	220.9	0.1
103860	RHO1	143.9	0.05
103860	Q1	141.2	0.24
103860	2Q1	121.4	0.03
103860	P1	198.1	0.51
103860	L2	59.2	0.07
103860	K2	179.9	0.02
103860	M8	237.1	0.02
103861	M2	62.7	0.9
103861	S2	21.2	0.12
103861	N2	0.3	0.2
103861	K1	248.6	0.79
103861	M4	38.4	0.17
103861	O1	205.2	0.72
103861	M6	97.3	0.01
103861	MK3	217	0.21
103861	S4	273.4	0.01
103861	MN4	328.1	0.07
103861	NU2	81.3	0.04
103861	MU2	196.1	0.04
103861	2N2	7.3	0.09
103861	OO1	281.5	0.02
103861	LDA2	159.3	0.06
103861	S1	185.5	0.11
103861	M1	271.7	0.06
103861	J1	206.5	0.08
103861	RHO1	222.7	0.02
103861	Q1	187.3	0.13
103861	2Q1	169.4	0.03
103861	P1	258.1	0.31
103861	2SM2	279.1	0.02
103861	M3	97.9	0.07
103861	L2	149.6	0.11
103861	2MK3	162.2	0.15
103861	K2	181	0.04
103861	M8	163.2	0.01
103861	MS4	241.2	0.02
103862	M2	302.8	2.57
103862	S2	38.1	0.3
103862	N2	247.3	0.65
103862	K1	261.3	0.69
103862	M4	168.4	0.35
103862	O1	221.8	0.38
103862	M6	343.8	0.16
103862	S4	308	0.01
103862	NU2	254.8	0.12
103862	S6	313.9	0.01
103862	MU2	207.8	0.06
103862	2N2	191.9	0.09
103862	OO1	300.8	0.02
103862	LDA2	346.2	0.02
103862	M1	241.7	0.03
103862	J1	280.9	0.03
103862	RHO1	204.9	0.01
103862	Q1	202.2	0.07
103862	T2	35.2	0.02
103862	2Q1	182.7	0.01
103862	P1	258.4	0.23
103862	L2	358.2	0.07
103862	K2	45.7	0.08
103862	M8	213	0.04
103863	M2	285.1	1.65
103863	S2	46.8	0.2
103863	N2	228.5	0.47
103863	K1	285.7	0.82
103863	M4	196.3	0.22
103863	O1	265.4	0.45
103863	M6	66.7	0.02
103863	S4	64.9	0.03
103863	NU2	236.1	0.09
103863	S6	99.9	0.01
103863	MU2	168.4	0.03
103863	2N2	172	0.06
103863	OO1	305.3	0.02
103863	LDA2	298.8	0.01
103863	M1	275.5	0.03
103863	J1	295.4	0.04
103863	RHO1	256.8	0.02
103863	Q1	255.5	0.09
103863	T2	43.8	0.01
103863	2Q1	245.5	0.01
103863	P1	284.2	0.27
103863	L2	341.3	0.05
103863	K2	52.2	0.06
103863	M8	335.6	0.01
103864	M2	329.5	1.95
103864	S2	56	0.28
103864	N2	281.1	0.54
103864	K1	313.9	1.18
103864	M4	236	0.29
103864	O1	267.4	0.63
103864	M6	56.9	0.02
103864	S4	60	0.03
103864	NU2	287.5	0.1
103864	MU2	245.2	0.05
103864	2N2	232.7	0.07
103864	OO1	0.3	0.03
103864	LDA2	8.6	0.01
103864	M1	290.7	0.04
103864	J1	336.6	0.05
103864	SSA	245.7	0.39
103864	SA	128.7	0.18
103864	RHO1	247.4	0.02
103864	Q1	244.4	0.12
103864	T2	53	0.02
103864	2Q1	221.2	0.02
103864	P1	310.4	0.39
103864	L2	18	0.05
103864	K2	63.2	0.08
103864	M8	228.6	0.01
103865	M2	54.1	0.65
103865	S2	182.5	0.12
103865	N2	8.4	0.24
103865	K1	23.9	0.62
103865	M4	37.4	0.11
103865	O1	0.7	0.46
103865	M6	113	0.01
103865	S4	278	0.01
103865	NU2	14.5	0.05
103865	MU2	283.7	0.02
103865	2N2	322.8	0.03
103865	OO1	47	0.02
103865	M1	12.3	0.03
103865	J1	35.1	0.04
103865	RHO1	351	0.02
103865	Q1	349.2	0.09
103865	T2	176.8	0.01
103865	2Q1	338.6	0.01
103865	P1	22.1	0.2
103865	L2	99.6	0.02
103865	K2	193	0.03
103866	M2	71.4	0.53
103866	S2	215.2	0.06
103866	N2	14	0.17
103866	K1	32.3	0.52
103866	M4	61	0.09
103866	O1	2.5	0.38
103866	M6	25.4	0.02
103866	NU2	21.8	0.03
103866	MU2	228.5	0.01
103866	2N2	316.5	0.02
103866	OO1	62.1	0.02
103866	M1	17.5	0.03
103866	J1	47	0.03
103866	SSA	194.3	0.06
103866	SA	126	0.24
103866	RHO1	349.6	0.01
103866	Q1	347.8	0.07
103866	2Q1	333.4	0.01
103866	P1	30	0.17
103866	L2	127.3	0.01
103866	K2	229.2	0.02
103867	M2	90.1	0.41
103867	S2	312.1	0.04
103867	N2	34.2	0.12
103867	K1	47.7	0.46
103867	M4	97.7	0.06
103867	O1	16.6	0.36
103867	M6	114.7	0.01
103867	S4	102.9	0.01
103867	NU2	41.9	0.02
103867	MU2	237.9	0.01
103867	2N2	335.6	0.02
103867	OO1	78.7	0.02
103867	M1	32.2	0.03
103867	J1	63	0.03
103867	SSA	245.7	0.39
103867	SA	128.7	0.18
103867	RHO1	3.3	0.01
103867	Q1	1.2	0.07
103867	2Q1	345.8	0.01
103867	P1	45.4	0.15
103867	L2	139.7	0.01
103867	K2	298.9	0.01
103868	M2	172	0.6
103868	S2	303.4	0.12
103868	N2	137.4	0.17
103868	K1	101.4	1.07
103868	M4	269	0.08
103868	O1	47.2	0.65
103868	M6	29.4	0.01
103868	S4	288.7	0.01
103868	NU2	141.7	0.03
103868	S6	183.1	0.01
103868	MU2	30	0.01
103868	2N2	103.2	0.02
103868	OO1	155	0.03
103868	M1	74.4	0.05
103868	J1	128	0.05
103868	SSA	245.7	0.39
103868	SA	128.7	0.18
103868	RHO1	24.4	0.02
103868	Q1	20.4	0.12
103868	T2	295.4	0.01
103868	2Q1	353.4	0.02
103868	P1	97.3	0.35
103868	L2	206.8	0.02
103868	K2	312	0.03
103869	M2	284.5	0.96
103869	S2	22.1	0.22
103869	N2	235.4	0.17
103869	K1	6.6	0.3
103869	M4	30.8	0.03
103869	O1	341.3	0.19
103869	M6	223.9	0.02
103869	NU2	242.1	0.03
103869	MU2	186.9	0.02
103869	2N2	186.4	0.02
103869	OO1	32	0.01
103869	LDA2	329.8	0.01
103869	M1	354	0.01
103869	J1	19.3	0.01
103869	RHO1	330.3	0.01
103869	Q1	328.7	0.04
103869	T2	18.1	0.01
103869	P1	4.8	0.1
103869	L2	331.8	0.03
103869	K2	30	0.06
103870	M2	257.4	0.55
103870	S2	2.2	0.12
103870	N2	199.3	0.18
103870	K1	129.4	1.35
103870	M4	194.3	0.04
103870	O1	77.1	0.76
103870	NU2	207.1	0.04
103870	2N2	141.2	0.02
103870	OO1	181.7	0.03
103870	M1	103.2	0.05
103870	J1	155.6	0.06
103870	SSA	195.3	0.02
103870	RHO1	54.6	0.03
103870	Q1	50.9	0.15
103870	R2	164.8	0.02
103870	2Q1	24.8	0.02
103870	P1	129.2	0.45
103870	L2	315.5	0.02
103870	K2	2.3	0.03
103871	M2	170.2	0.61
103871	S2	297.7	0.12
103871	N2	111.9	0.22
103871	K1	86.1	1.37
103871	M4	36.2	0.03
103871	O1	36.5	0.77
103871	S4	124.8	0.01
103871	NU2	119.7	0.04
103871	MU2	39	0.01
103871	2N2	53.7	0.03
103871	OO1	135.8	0.03
103871	M1	61.5	0.05
103871	J1	110.8	0.06
103871	SSA	330.9	0.06
103871	SA	126	0.24
103871	RHO1	15.3	0.03
103871	Q1	11.8	0.15
103871	T2	293.9	0.01
103871	2Q1	347.3	0.02
103871	P1	82.3	0.45
103871	L2	228.7	0.02
103871	K2	308.9	0.03
103872	M2	222.5	0.98
103872	S2	324.4	0.2
103872	N2	167.2	0.17
103872	K1	345.3	0.34
103872	M4	22.6	0.02
103872	O1	317.4	0.2
103872	M6	68.2	0.01
103872	NU2	174.7	0.03
103872	MU2	120.8	0.02
103872	2N2	111.8	0.02
103872	OO1	13.3	0.01
103872	LDA2	269.8	0.01
103872	M1	331.5	0.01
103872	J1	359.2	0.02
103872	RHO1	305.2	0.01
103872	Q1	303.4	0.04
103872	T2	320.4	0.01
103872	2Q1	289.5	0.01
103872	P1	343.2	0.11
103872	L2	277.3	0.03
103872	K2	332.7	0.05
103872	M8	57.5	0.01
103873	M2	65.4	1.04
103873	S2	175.9	0.19
103873	N2	9	0.26
103873	K1	95.4	0.37
103873	M4	150.5	0.04
103873	O1	53.6	0.2
103873	M6	0.9	0.01
103873	NU2	16.5	0.05
103873	MU2	314.9	0.03
103873	2N2	312.6	0.03
103873	OO1	136.8	0.01
103873	LDA2	116.7	0.01
103873	M1	74.8	0.01
103873	J1	116.2	0.02
103873	RHO1	35.8	0.01
103873	Q1	32.8	0.04
103873	T2	171.5	0.01
103873	P1	92.3	0.12
103873	L2	121.8	0.03
103873	K2	184.9	0.05
103874	M2	196.4	1.05
103874	S2	294.3	0.21
103874	N2	142.5	0.2
103874	K1	335.9	0.37
103874	M4	339.5	0.02
103874	O1	303	0.23
103874	M6	26.7	0.02
103874	NU2	149.7	0.04
103874	MU2	98.6	0.03
103874	2N2	88.8	0.03
103874	OO1	8.9	0.01
103874	LDA2	241.9	0.01
103874	M1	319.5	0.02
103874	J1	352	0.02
103874	RHO1	288.8	0.01
103874	Q1	286.8	0.04
103874	T2	290.4	0.01
103874	2Q1	270.2	0.01
103874	P1	333.4	0.12
103874	L2	250.4	0.03
103874	K2	302.2	0.06
103875	M2	216	0.45
103875	S2	280.9	0.06
103875	N2	163.2	0.15
103875	K1	112.2	1.02
103875	M4	83.8	0.02
103875	O1	63.9	0.57
103875	MK3	295.6	0.05
103875	MN4	25	0.01
103875	NU2	189.7	0.02
103875	MU2	52	0.02
103875	2N2	68.8	0.04
103875	OO1	167.2	0.06
103875	LDA2	195	0.01
103875	S1	70.7	0.15
103875	M1	211.6	0.06
103875	J1	317.6	0.03
103875	SSA	260	0.19
103875	SA	117.6	0.42
103875	RHO1	20.3	0.02
103875	Q1	51.5	0.1
103875	R2	22.3	0.02
103875	2Q1	40.7	0.02
103875	P1	106	0.31
103875	L2	173.6	0.01
103875	2MK3	236.7	0.03
103875	K2	321.5	0.08
103875	MS4	162.5	0.01
103876	M2	232.5	0.59
103876	S2	348.5	0.12
103876	N2	177.2	0.18
103876	K1	112.2	1.46
103876	M4	158.3	0.01
103876	O1	58.6	0.86
103876	M6	324.4	0.01
103876	NU2	184.6	0.04
103876	MU2	116.5	0.01
103876	2N2	121.8	0.02
103876	OO1	165.8	0.04
103876	M1	85.6	0.06
103876	J1	138.8	0.07
103876	RHO1	35.7	0.03
103876	Q1	32.1	0.17
103876	T2	343.9	0.01
103876	2Q1	5.5	0.02
103876	P1	108.2	0.48
103876	L2	287.8	0.02
103876	K2	357.9	0.03
103877	M2	37.7	0.36
103877	S2	106.9	0.05
103877	N2	340.2	0.12
103877	K1	146.9	0.29
103877	M4	181.2	0.02
103877	O1	79	0.2
103877	M6	64.4	0.01
103877	MK3	66.5	0.03
103877	MN4	145.5	0.01
103877	NU2	343.8	0.02
103877	MU2	245.2	0.02
103877	2N2	283.4	0.02
103877	OO1	239.6	0.02
103877	S1	130.3	0.08
103877	SSA	245.7	0.39
103877	SA	128.7	0.18
103877	Q1	67.5	0.04
103877	T2	166.8	0.01
103877	P1	137.6	0.08
103877	2MK3	33.4	0.01
103877	K2	88.8	0.06
103877	MS4	238.7	0.01
103878	M2	311.5	0.2
103878	S2	96.1	0.04
103878	N2	259.1	0.06
103878	K1	136	1.17
103878	M4	274	0.01
103878	O1	83.4	0.65
103878	NU2	266.5	0.01
103878	2N2	207.9	0.01
103878	OO1	188.6	0.03
103878	M1	109.9	0.05
103878	J1	162.1	0.05
103878	SSA	245.7	0.39
103878	SA	128.7	0.18
103878	RHO1	60.7	0.02
103878	Q1	57.3	0.12
103878	2Q1	31.2	0.02
103878	P1	132	0.39
103878	L2	4	0.01
103878	K2	105.6	0.01
103879	M2	304.4	0.13
103879	S2	161.7	0.09
103879	N2	277.7	0.05
103879	K1	152.7	1.1
103879	M4	278.2	0.01
103879	O1	97.8	0.57
103879	NU2	281.9	0.01
103879	2N2	252.2	0.01
103879	OO1	207.4	0.03
103879	M1	125.4	0.04
103879	J1	179.8	0.05
103879	SSA	245.7	0.39
103879	SA	128.7	0.18
103879	RHO1	74.3	0.02
103879	Q1	70.6	0.11
103879	2Q1	43.4	0.02
103879	P1	148.6	0.36
103879	K2	153.4	0.03
103880	M2	270.2	0.48
103880	S2	6.3	0.13
103880	N2	211.7	0.17
103880	K1	128.8	1.42
103880	M4	272.5	0.02
103880	O1	72.4	0.76
103880	M6	359.7	0.01
103880	S4	39.3	0.01
103880	NU2	219.5	0.03
103880	MU2	171.4	0.01
103880	2N2	153.4	0.02
103880	OO1	185.8	0.03
103880	M1	101.1	0.05
103880	J1	157.4	0.06
103880	SSA	245.7	0.39
103880	SA	128.7	0.18
103880	RHO1	47.8	0.03
103880	Q1	44.1	0.15
103880	T2	2.6	0.01
103880	2Q1	15.9	0.02
103880	P1	124.5	0.47
103880	L2	328.8	0.01
103880	K2	13.9	0.03
103881	M2	321	0.61
103881	S2	94.8	0.22
103881	N2	259.6	0.29
103881	K1	157.3	1.5
103881	M4	219.1	0.04
103881	O1	86.3	0.88
103881	S4	175	0.01
103881	NU2	267.8	0.06
103881	MU2	187.1	0.01
103881	2N2	198.2	0.04
103881	OO1	228.3	0.04
103881	M1	122.1	0.06
103881	J1	192.5	0.07
103881	SSA	194.3	0.06
103881	SA	126	0.24
103881	RHO1	55.9	0.03
103881	Q1	51.1	0.17
103881	T2	89.5	0.01
103881	2Q1	15.9	0.02
103881	P1	152	0.5
103881	L2	22.3	0.02
103881	K2	105.7	0.06
103882	M2	315.5	0.09
103882	S2	71.2	0.02
103882	N2	228.4	0.02
103882	K1	342.6	0.05
103882	M4	73.7	0.01
103882	O1	215.6	0.01
103882	P1	333	0.02
103882	K2	80.2	0.01
103883	M2	186.9	0.43
103883	S2	293.9	0.09
103883	N2	116.3	0.11
103883	K1	254.6	0.14
103883	M4	219.1	0.08
103883	O1	121.8	0.06
103883	S4	235.5	0.01
103883	NU2	125.7	0.02
103883	MU2	81	0.01
103883	2N2	46.2	0.01
103883	Q1	55.8	0.01
103883	P1	244.6	0.05
103883	L2	258.4	0.01
103883	K2	302.8	0.02
103884	M2	206	0.36
103884	S2	321.7	0.11
103884	N2	130.1	0.1
103884	K1	262.9	0.11
103884	M4	270.3	0.09
103884	O1	118.5	0.03
103884	S4	318.1	0.01
103884	NU2	140.2	0.02
103884	MU2	117.5	0.01
103884	2N2	54.2	0.01
103884	Q1	47	0.01
103884	T2	317.1	0.01
103884	P1	252.1	0.04
103884	L2	281.9	0.01
103884	K2	331.1	0.03
103885	M2	188.5	0.36
103885	S2	313.2	0.09
103885	N2	123.9	0.12
103885	K1	265.2	0.14
103885	M4	213.8	0.03
103885	O1	130.3	0.06
103885	M6	194.5	0.01
103885	S4	74.6	0.01
103885	NU2	132.5	0.02
103885	S6	38.3	0.01
103885	MU2	89.5	0.01
103885	2N2	59.2	0.02
103885	Q1	63.3	0.01
103885	T2	308.2	0.01
103885	P1	255.1	0.05
103885	L2	253.2	0.01
103885	K2	323.3	0.02
103886	M2	199.4	0.41
103886	S2	296.9	0.1
103886	N2	124.4	0.1
103886	K1	266.3	0.12
103886	M4	182.8	0.01
103886	O1	108.2	0.06
103886	NU2	134.5	0.02
103886	MU2	125.9	0.01
103886	2N2	49.5	0.01
103886	Q1	29.8	0.01
103886	T2	293	0.01
103886	P1	254.5	0.04
103886	L2	274.4	0.01
103886	K2	304.8	0.03
103887	M2	213.6	0.45
103887	S2	317.4	0.12
103887	N2	140.4	0.09
103887	K1	284.1	0.1
103887	M4	150.4	0.01
103887	O1	92.2	0.03
103887	M6	283.6	0.01
103887	S4	219.2	0.01
103887	NU2	150.2	0.02
103887	MU2	109.7	0.01
103887	2N2	67.2	0.01
103887	T2	313.3	0.01
103887	P1	296.7	0.03
103887	L2	286.7	0.01
103887	K2	325.9	0.03
103888	M2	202.1	0.89
103888	S2	266.1	0.15
103888	N2	145.3	0.2
103888	K1	95.2	0.17
103888	M4	320.7	0.14
103888	O1	186.8	0.09
103888	M6	308.2	0.02
103888	S4	314.3	0.03
103888	NU2	153	0.04
103888	MU2	138.1	0.02
103888	2N2	88.6	0.03
103888	LDA2	231.8	0.01
103888	M1	140.6	0.01
103888	J1	49.7	0.01
103888	Q1	232.2	0.02
103888	T2	263.6	0.01
103888	P1	102	0.06
103888	L2	258.9	0.03
103888	K2	271.3	0.04
103888	M8	46.6	0.02
103889	M2	64.2	0.7
103889	S2	132.8	0.17
103889	N2	355.9	0.15
103889	K1	4.5	0.23
103889	M4	309.6	0.01
103889	O1	159.7	0.11
103889	S4	239.8	0.01
103889	NU2	5.1	0.03
103889	MU2	354.1	0.02
103889	2N2	287.9	0.02
103889	Q1	192	0.02
103889	T2	129.9	0.01
103889	P1	5.4	0.08
103889	L2	132.6	0.02
103889	K2	138.3	0.05
103890	M2	62.5	0.71
103890	S2	135.3	0.15
103890	N2	3.4	0.19
103890	K1	1.7	0.17
103890	M4	20.8	0.03
103890	O1	33.2	0.02
103890	M6	224.1	0.02
103890	NU2	11.4	0.04
103890	MU2	349.6	0.02
103890	2N2	304	0.02
103890	LDA2	96.4	0.01
103890	Q1	93.7	0.01
103890	T2	132.6	0.01
103890	P1	359.2	0.06
103890	L2	121.6	0.02
103890	K2	141.2	0.04
103891	M2	265.3	0.4
103891	S2	332.3	0.12
103891	N2	208.4	0.11
103891	K1	334	0.13
103891	M4	294.1	0.02
103891	O1	66.4	0.05
103891	M6	113.5	0.01
103891	NU2	216	0.02
103891	MU2	226.2	0.01
103891	2N2	151.5	0.02
103891	Q1	112.3	0.01
103891	T2	329.6	0.01
103891	P1	340.9	0.04
103891	L2	322.2	0.01
103891	K2	337.8	0.03
103891	M8	231	0.01
103892	M2	312	0.37
103892	S2	22	0.09
103892	N2	252	0.1
103892	K1	335.4	0.13
103892	M4	111.6	0.02
103892	O1	182.2	0.04
103892	M6	278.2	0.01
103892	NU2	260	0.02
103892	MU2	241.9	0.01
103892	2N2	192	0.01
103892	Q1	106.2	0.01
103892	T2	19.2	0.01
103892	P1	323.9	0.04
103892	L2	11.9	0.01
103892	K2	27.7	0.02
103893	M2	133.3	0.19
103893	S2	210.9	0.05
103893	N2	66.6	0.05
103893	K1	56.8	0.16
103893	M4	184.1	0.02
103893	O1	33.9	0.04
103893	M6	103.8	0.01
103893	S4	352.9	0.01
103893	NU2	76.3	0.01
103893	2N2	1.6	0.01
103893	Q1	38.9	0.01
103893	P1	52.4	0.05
103893	L2	195.6	0.01
103893	K2	216.6	0.01
103894	M2	194.4	0.12
103894	S2	280.7	0.03
103894	N2	110.2	0.02
103894	K1	25.3	0.17
103894	M4	139.3	0.01
103894	O1	196.1	0.06
103894	M6	11.3	0.01
103894	Q1	198.9	0.01
103894	P1	21.2	0.06
103894	K2	287	0.01
103895	M2	280.8	0.24
103895	S2	335	0.05
103895	N2	225.9	0.06
103895	K1	84.6	0.07
103895	O1	127.3	0.03
103895	MK3	75.2	0.01
103895	NU2	236.2	0.01
103895	MU2	77.7	0.01
103895	2N2	143.1	0.01
103895	OO1	108.5	0.01
103895	S1	297.8	0.04
103895	SSA	239.6	0.29
103895	SA	144.5	0.53
103895	Q1	132	0.01
103895	T2	46.2	0.02
103895	R2	9.4	0.03
103895	P1	95.4	0.02
103895	L2	324.9	0.01
103895	2MK3	335.9	0.01
103895	K2	314.6	0.03
103896	M2	268.7	0.34
103896	S2	334.8	0.12
103896	N2	210.8	0.1
103896	K1	30.4	0.12
103896	M4	79.3	0.01
103896	O1	129.3	0.04
103896	NU2	218.6	0.02
103896	MU2	233.4	0.01
103896	2N2	152.9	0.01
103896	Q1	178.3	0.01
103896	T2	332.1	0.01
103896	P1	37.9	0.04
103896	L2	326.6	0.01
103896	K2	340.1	0.03
103897	M2	298.8	0.25
103897	S2	3	0.03
103897	N2	245.2	0.08
103897	K1	50.6	0.06
103897	O1	162.4	0.03
103897	NU2	252.4	0.02
103897	MU2	234.5	0.01
103897	2N2	191.6	0.01
103897	SSA	239.6	0.29
103897	SA	144.5	0.53
103897	P1	59	0.02
103897	L2	352.3	0.01
103897	K2	8.3	0.01
103898	M2	230.2	0.2
103898	S2	318.8	0.12
103898	N2	86.9	0.02
103898	K1	123.4	0.09
103898	M4	292.1	0.01
103898	O1	67.3	0.06
103898	J1	151.2	0.01
103898	SSA	239.6	0.29
103898	SA	144.5	0.53
103898	Q1	39.4	0.01
103898	T2	315.2	0.01
103898	P1	119.2	0.03
103898	L2	13.6	0.01
103898	K2	325.9	0.03
103899	M2	270	0.18
103899	S2	320	0.08
103899	N2	248.3	0.02
103899	K1	150.3	0.07
103899	O1	153.2	0.06
103899	S1	91.8	0.01
103899	J1	141.3	0.01
103899	SSA	252.4	0.22
103899	SA	155.5	0.39
103899	RHO1	109.6	0.01
103899	Q1	130.9	0.01
103899	T2	7.3	0.01
103899	R2	353.6	0.01
103899	2Q1	127.1	0.01
103899	P1	147	0.03
103899	K2	306	0.02
103900	M2	275.7	0.21
103900	S2	314.9	0.1
103900	N2	258.2	0.03
103900	K1	158.4	0.08
103900	O1	186.8	0.11
103900	NU2	234.3	0.01
103900	MU2	273.3	0.01
103900	S1	290.6	0.01
103900	J1	159.7	0.01
103900	SSA	249	0.2
103900	SA	145.3	0.38
103900	RHO1	169.2	0.01
103900	Q1	173.6	0.04
103900	T2	337.8	0.01
103900	R2	343.4	0.01
103900	2Q1	94.1	0.01
103900	P1	177.2	0.03
103900	L2	299	0.01
103900	K2	318.4	0.03
103901	M2	287.7	0.23
103901	S2	334.6	0.11
103901	N2	268.5	0.03
103901	K1	156.3	0.05
103901	O1	195.9	0.15
103901	NU2	271.2	0.01
103901	2N2	249.3	0.01
103901	OO1	116.8	0.01
103901	M1	176.1	0.01
103901	J1	136.5	0.01
103901	RHO1	213	0.01
103901	Q1	215.7	0.03
103901	T2	334.6	0.01
103901	P1	156.4	0.02
103901	L2	306.9	0.01
103901	K2	334.6	0.03
103902	M2	308.2	0.21
103902	S2	349.5	0.1
103902	N2	289.2	0.04
103902	K1	172	0.08
103902	O1	198	0.1
103902	NU2	291.9	0.01
103902	2N2	270.3	0.01
103902	M1	185	0.01
103902	J1	158.9	0.01
103902	Q1	190	0.03
103902	T2	349.4	0.01
103902	P1	171.8	0.03
103902	L2	327.1	0.01
103902	K2	349.6	0.03
103903	M2	281	0.19
103903	S2	328.3	0.08
103903	N2	253.5	0.02
103903	K1	144.4	0.09
103903	O1	189.9	0.06
103903	J1	121.8	0.01
103903	Q1	212.5	0.01
103903	T2	326.4	0.01
103903	P1	147.8	0.03
103903	L2	308.4	0.01
103903	K2	332.1	0.02
103904	M2	9.1	0.04
103904	S2	8.4	0.02
103904	N2	76.5	0.01
103904	K1	232.8	0.27
103904	M4	253.9	0.01
103904	O1	225.4	0.2
103904	OO1	240.1	0.01
103904	M1	229	0.01
103904	J1	236.4	0.02
103904	MM	349	0.03
103904	SA	173.7	0.21
103904	MF	356.9	0.05
103904	RHO1	222.1	0.01
103904	Q1	221.6	0.04
103904	2Q1	218	0.01
103904	P1	232.2	0.09
103904	K2	6.4	0.01
103905	M2	1.2	0.08
103905	S2	30.2	0.02
103905	N2	33.7	0.01
103905	K1	228.1	0.25
103905	M4	290.5	0.01
103905	O1	221.6	0.19
103905	OO1	233.3	0.01
103905	M1	224.8	0.01
103905	J1	230.9	0.01
103905	MM	322.1	0.02
103905	SA	179.8	0.18
103905	MF	0.1	0.05
103905	RHO1	218.6	0.01
103905	Q1	218.2	0.04
103905	P1	227.7	0.08
103905	K2	29.9	0.01
103906	M2	357.3	0.03
103906	S2	15.4	0.02
103906	K1	234.6	0.27
103906	M4	257.1	0.01
103906	O1	226.7	0.21
103906	OO1	242.4	0.01
103906	M1	230.8	0.01
103906	J1	238.4	0.02
103906	MM	349	0.03
103906	SA	173.7	0.21
103906	MF	356.9	0.05
103906	RHO1	223.3	0.01
103906	Q1	222.8	0.04
103906	2Q1	218.9	0.01
103906	P1	234	0.09
103907	M2	18.4	0.17
103907	S2	30.5	0.03
103907	N2	1	0.03
103907	K1	226.7	0.27
103907	O1	220.6	0.19
103907	NU2	3.4	0.01
103907	OO1	231.6	0.01
103907	M1	223.6	0.01
103907	J1	229.8	0.02
103907	MM	324.3	0.02
103907	SSA	53.2	0.05
103907	SA	191.6	0.2
103907	MF	358.6	0.05
103907	RHO1	217.9	0.01
103907	Q1	217.7	0.04
103907	2Q1	215.9	0.01
103907	P1	226.3	0.09
103907	K2	31.5	0.01
103908	M2	15.3	0.33
103908	S2	42.5	0.06
103908	N2	356.3	0.07
103908	K1	217.1	0.26
103908	M4	278	0.01
103908	O1	215.2	0.19
103908	NU2	359	0.01
103908	MU2	348.2	0.01
103908	2N2	336.1	0.01
103908	OO1	219.6	0.01
103908	M1	216.2	0.01
103908	J1	218.2	0.01
103908	SSA	47.2	0.06
103908	SA	181.8	0.2
103908	RHO1	214.4	0.01
103908	Q1	214.3	0.04
103908	P1	216.9	0.09
103908	L2	35	0.01
103908	K2	44.6	0.02
103909	M2	344.6	0.1
103909	S2	19.7	0.03
103909	N2	310.6	0.01
103909	K1	228.5	0.27
103909	M4	263.1	0.01
103909	O1	222.2	0.2
103909	OO1	234.1	0.01
103909	S1	242.5	0.01
103909	M1	239.5	0.01
103909	J1	229.9	0.02
103909	MM	322.1	0.02
103909	SA	179.8	0.18
103909	MF	0.1	0.05
103909	RHO1	219.7	0.01
103909	Q1	209.3	0.03
103909	P1	229	0.08
103909	L2	359.8	0.01
103909	K2	16	0.01
103910	M2	16	0.18
103910	S2	26.4	0.03
103910	N2	2	0.03
103910	K1	226.2	0.28
103910	M4	298.4	0.01
103910	O1	222.7	0.19
103910	S4	225.5	0.01
103910	NU2	3.9	0.01
103910	OO1	229.8	0.01
103910	M1	224.5	0.01
103910	J1	228	0.02
103910	MM	333.6	0.02
103910	SSA	47.2	0.06
103910	SA	181.8	0.2
103910	MF	352.4	0.04
103910	RHO1	221.2	0.01
103910	Q1	220.9	0.04
103910	2Q1	219.2	0.01
103910	P1	226	0.09
103910	K2	27.3	0.01
103911	M2	23.8	0.15
103911	S2	22.8	0.03
103911	N2	11.4	0.03
103911	K1	228.9	0.27
103911	O1	222	0.19
103911	NU2	5.2	0.01
103911	2N2	4.5	0.01
103911	OO1	235.5	0.01
103911	S1	165.5	0.01
103911	M1	242.1	0.01
103911	J1	230.4	0.02
103911	MM	324.3	0.02
103911	SSA	53.2	0.05
103911	SA	191.6	0.2
103911	MF	358.6	0.05
103911	RHO1	216.6	0.01
103911	Q1	210.4	0.03
103911	P1	230.8	0.09
103911	L2	38.3	0.01
103911	K2	16.7	0.01
103912	M2	19.2	0.14
103912	S2	18.4	0.03
103912	N2	8.6	0.03
103912	K1	228.8	0.26
103912	M4	249.7	0.01
103912	O1	220.1	0.19
103912	NU2	10	0.01
103912	OO1	236	0.01
103912	M1	224.4	0.01
103912	J1	233.1	0.02
103912	MM	191.6	0.02
103912	SSA	53.2	0.05
103912	SA	191.6	0.2
103912	MF	358.6	0.05
103912	RHO1	216.2	0.01
103912	Q1	215.9	0.04
103912	2Q1	211.2	0.01
103912	P1	228.2	0.09
103912	K2	17.9	0.01
103913	M2	351.5	0.09
103913	S2	18.2	0.03
103913	N2	350.3	0.01
103913	K1	227.5	0.26
103913	M4	254	0.01
103913	O1	220.7	0.19
103913	OO1	232.8	0.01
103913	M1	224.1	0.01
103913	J1	230.9	0.02
103913	MM	322.1	0.02
103913	SA	179.8	0.18
103913	MF	0.1	0.05
103913	RHO1	217.7	0.01
103913	Q1	217.2	0.04
103913	2Q1	215.5	0.01
103913	P1	227	0.09
103913	K2	21.2	0.01
103914	M2	328.9	0.05
103914	S2	11.7	0.03
103914	N2	232.2	0.01
103914	K1	237	0.28
103914	M4	290.7	0.01
103914	O1	228.6	0.21
103914	OO1	248.4	0.01
103914	S1	240.7	0.02
103914	M1	273.5	0.01
103914	J1	234.3	0.02
103914	MM	349	0.03
103914	SA	173.7	0.21
103914	MF	356.9	0.05
103914	RHO1	213.6	0.01
103914	Q1	210.6	0.03
103914	T2	192.5	0.01
103914	P1	236.1	0.09
103914	K2	355.4	0.01
103914	MS4	355.2	0.01
103915	M2	16	0.4
103915	S2	46.3	0.07
103915	N2	0.5	0.1
103915	K1	211.8	0.25
103915	M4	257.6	0.01
103915	O1	211.5	0.19
103915	NU2	2.5	0.02
103915	MU2	345.6	0.01
103915	2N2	345.4	0.01
103915	OO1	213.5	0.01
103915	M1	211.7	0.01
103915	J1	211.9	0.02
103915	MM	324.3	0.02
103915	SSA	53.2	0.05
103915	SA	191.6	0.2
103915	MF	358.6	0.05
103915	RHO1	211.4	0.01
103915	Q1	211.3	0.04
103915	2Q1	212.5	0.01
103915	P1	211.8	0.08
103915	L2	31.3	0.01
103915	K2	48.9	0.02
103916	M2	14.9	0.22
103916	S2	34.8	0.03
103916	N2	350.8	0.05
103916	K1	223.4	0.26
103916	M4	317	0.01
103916	O1	219.9	0.19
103916	NU2	354.2	0.01
103916	MU2	351	0.01
103916	2N2	326.2	0.01
103916	OO1	225.7	0.01
103916	M1	221.6	0.01
103916	J1	224.8	0.01
103916	MM	230.4	0.02
103916	SSA	53.2	0.05
103916	SA	191.6	0.2
103916	MF	358.6	0.05
103916	RHO1	218.2	0.01
103916	Q1	218.4	0.04
103916	P1	223.2	0.09
103916	L2	39.5	0.01
103916	K2	37.1	0.01
103917	M2	11.3	0.3
103917	S2	70.5	0.06
103917	N2	354.9	0.06
103917	K1	224.5	0.23
103917	M4	308.6	0.02
103917	O1	215.9	0.19
103917	M6	325.6	0.01
103917	MK3	57.9	0.01
103917	MN4	257.8	0.01
103917	NU2	353.9	0.02
103917	MU2	53.6	0.01
103917	2N2	26.6	0.01
103917	OO1	231.4	0.01
103917	LDA2	319.1	0.01
103917	S1	191.3	0.04
103917	M1	207.7	0.01
103917	J1	226.2	0.02
103917	Q1	192.1	0.03
103917	T2	111.3	0.01
103917	R2	318	0.04
103917	P1	231.6	0.06
103917	2SM2	154.4	0.01
103917	L2	342.3	0.01
103917	2MK3	73.5	0.01
103917	K2	21.4	0.03
103917	MS4	17.3	0.01
103918	M2	9.5	0.26
103918	S2	28.7	0.05
103918	N2	352.5	0.06
103918	K1	221.5	0.25
103918	M4	280.6	0.01
103918	O1	215	0.18
103918	M6	342.7	0.01
103918	NU2	354.8	0.01
103918	MU2	350.1	0.01
103918	2N2	335.3	0.01
103918	OO1	227.9	0.01
103918	M1	218.3	0.01
103918	J1	224.5	0.01
103918	MM	324.3	0.02
103918	SSA	53.2	0.05
103918	SA	191.6	0.2
103918	MF	358.6	0.05
103918	RHO1	212.2	0.01
103918	Q1	211.7	0.03
103918	P1	221	0.08
103918	L2	26.5	0.01
103918	K2	30.3	0.01
103919	M2	23.8	0.15
103919	S2	136.3	0.02
103919	N2	22.9	0.03
103919	K1	230.9	0.25
103919	M4	283.8	0.01
103919	O1	221.7	0.2
103919	MN4	205.2	0.01
103919	NU2	30.2	0.01
103919	MU2	99	0.01
103919	OO1	224.9	0.01
103919	S1	197.3	0.03
103919	M1	215.2	0.01
103919	J1	225.7	0.02
103919	SSA	47.2	0.06
103919	SA	181.8	0.2
103919	RHO1	245.2	0.01
103919	Q1	196.8	0.03
103919	T2	172.2	0.02
103919	R2	344	0.05
103919	2Q1	168	0.01
103919	P1	233.9	0.06
103919	L2	32.3	0.01
103919	K2	26	0.03
103920	M2	14.8	0.33
103920	S2	37.9	0.06
103920	N2	358.8	0.08
103920	K1	221.7	0.24
103920	O1	215.2	0.18
103920	M6	326.2	0.01
103920	NU2	0.9	0.01
103920	MU2	351.7	0.01
103920	2N2	343	0.01
103920	OO1	228.1	0.01
103920	M1	218.5	0.01
103920	J1	225.1	0.01
103920	SSA	60.7	0.07
103920	SA	191	0.19
103920	RHO1	212.5	0.01
103920	Q1	212.1	0.04
103920	P1	221.2	0.08
103920	L2	30.7	0.01
103920	K2	39.8	0.02
103921	M2	28.1	0.14
103921	S2	18.8	0.02
103921	N2	6.2	0.03
103921	K1	228.4	0.27
103921	O1	222.9	0.2
103921	NU2	9.1	0.01
103921	OO1	233.9	0.01
103921	M1	225.6	0.01
103921	J1	231.1	0.02
103921	RHO1	220.5	0.01
103921	Q1	220.2	0.04
103921	2Q1	217.5	0.01
103921	P1	228	0.09
103921	K2	18	0.01
103922	M2	25.9	0.12
103922	S2	7.9	0.03
103922	N2	18.6	0.03
103922	K1	228.5	0.26
103922	M4	272.3	0.01
103922	O1	220.1	0.19
103922	NU2	20.1	0.01
103922	OO1	236.4	0.01
103922	M1	224.3	0.01
103922	J1	232.6	0.02
103922	SSA	46	0.05
103922	SA	181.2	0.21
103922	MF	358.7	0.05
103922	RHO1	216.4	0.01
103922	Q1	216.1	0.04
103922	2Q1	213.5	0.01
103922	P1	227.9	0.09
103922	K2	6.5	0.01
103923	M2	12.8	0.35
103923	S2	38	0.06
103923	N2	351.6	0.08
103923	K1	218.2	0.25
103923	O1	217.1	0.19
103923	M6	319	0.01
103923	NU2	354.3	0.02
103923	MU2	347.6	0.01
103923	2N2	330.4	0.01
103923	OO1	220.2	0.01
103923	M1	217.6	0.01
103923	J1	218.9	0.02
103923	SSA	47.2	0.06
103923	SA	181.8	0.2
103923	RHO1	216.5	0.01
103923	Q1	216.5	0.04
103923	2Q1	215.8	0.01
103923	P1	218.1	0.08
103923	L2	34.3	0.01
103923	K2	39.9	0.02
103924	M2	43.9	0.07
103924	S2	51.9	0.05
103924	N2	44	0.02
103924	K1	237.3	0.24
103924	M4	282.4	0.01
103924	O1	229	0.2
103924	S4	191.2	0.01
103924	MU2	136.9	0.01
103924	OO1	247.4	0.01
103924	LDA2	227.4	0.01
103924	S1	199.2	0.06
103924	M1	219.5	0.01
103924	J1	226.4	0.02
103924	SSA	60	0.05
103924	SA	184.9	0.19
103924	Q1	208.3	0.03
103924	R2	263.4	0.04
103924	P1	248	0.06
103924	2SM2	175	0.01
103924	M3	51.1	0.01
103924	L2	150.4	0.01
103924	K2	325.5	0.02
103925	M2	23.1	0.13
103925	S2	9.9	0.03
103925	N2	13.7	0.03
103925	K1	229.5	0.26
103925	M4	302	0.01
103925	O1	221.6	0.2
103925	NU2	6.6	0.01
103925	MU2	80.8	0.01
103925	OO1	236.2	0.01
103925	S1	201.1	0.01
103925	M1	240.8	0.01
103925	J1	235.1	0.02
103925	SSA	46	0.05
103925	SA	181.2	0.21
103925	MF	358.7	0.05
103925	RHO1	214.8	0.01
103925	Q1	208.8	0.04
103925	P1	231.2	0.08
103925	L2	41.6	0.01
103925	K2	5	0.01
103926	M2	15.7	0.43
103926	S2	45.2	0.08
103926	N2	359.9	0.1
103926	K1	216	0.23
103926	O1	213.5	0.18
103926	NU2	2	0.02
103926	MU2	346.2	0.01
103926	2N2	344.4	0.01
103926	OO1	218.7	0.01
103926	M1	214.9	0.01
103926	J1	217.4	0.01
103926	SSA	46	0.05
103926	SA	181.2	0.21
103926	MF	358.7	0.05
103926	RHO1	212.5	0.01
103926	Q1	212.2	0.04
103926	P1	215.9	0.08
103926	L2	31.3	0.01
103926	K2	47.7	0.02
103927	M2	19	0.14
103927	S2	5.8	0.04
103927	N2	11	0.03
103927	K1	230.4	0.25
103927	M4	296.7	0.01
103927	O1	220.9	0.19
103927	NU2	12.2	0.01
103927	OO1	239.7	0.01
103927	M1	225.6	0.01
103927	J1	234.9	0.02
103927	SSA	46	0.05
103927	SA	181.2	0.21
103927	MF	358.7	0.05
103927	RHO1	216.9	0.01
103927	Q1	216.2	0.04
103927	2Q1	211.6	0.01
103927	P1	229.7	0.08
103927	K2	5.8	0.01
103928	M2	16.1	0.42
103928	S2	44.2	0.07
103928	N2	354	0.1
103928	K1	210.2	0.22
103928	O1	213.2	0.17
103928	NU2	356.9	0.02
103928	MU2	348	0.01
103928	2N2	331.4	0.01
103928	OO1	207.3	0.01
103928	M1	211.7	0.01
103928	J1	208.8	0.01
103928	SSA	47.2	0.06
103928	SA	181.9	0.2
103928	RHO1	214.5	0.01
103928	Q1	214.7	0.03
103928	P1	210.4	0.08
103928	L2	38.2	0.01
103928	K2	46.6	0.02
103929	M2	15.9	0.41
103929	S2	73.2	0.15
103929	N2	359.7	0.1
103929	K1	216.1	0.22
103929	M4	358.9	0.01
103929	O1	216	0.19
103929	NU2	5.9	0.02
103929	MU2	35.5	0.01
103929	2N2	3.8	0.01
103929	OO1	234.4	0.01
103929	LDA2	333.5	0.01
103929	S1	207.5	0.04
103929	M1	212.7	0.01
103929	J1	218	0.02
103929	SSA	47.2	0.06
103929	SA	181.8	0.2
103929	RHO1	186.2	0.01
103929	Q1	198.5	0.03
103929	T2	96.8	0.05
103929	R2	256.4	0.08
103929	P1	220.2	0.06
103929	L2	328.7	0.02
103929	K2	329.6	0.02
103930	M2	18.9	0.37
103930	S2	43.1	0.07
103930	N2	0.6	0.1
103930	K1	217	0.24
103930	M4	293	0.02
103930	O1	217.1	0.18
103930	NU2	3	0.02
103930	MU2	354.6	0.01
103930	2N2	342.3	0.01
103930	OO1	219	0.01
103930	M1	217.1	0.01
103930	J1	217.9	0.01
103930	SSA	60.7	0.07
103930	SA	191	0.19
103930	MF	0.1	0.05
103930	RHO1	217.1	0.01
103930	Q1	217.1	0.04
103930	P1	217.1	0.08
103930	L2	37.1	0.01
103930	K2	45	0.02
103931	M2	11.7	0.33
103931	S2	34.9	0.06
103931	N2	349.8	0.07
103931	K1	225.7	0.25
103931	M4	326	0.01
103931	O1	223.6	0.19
103931	NU2	345.8	0.01
103931	MU2	22.4	0.01
103931	2N2	336.8	0.01
103931	OO1	231	0.01
103931	S1	200.8	0.01
103931	M1	247.9	0.01
103931	J1	221.7	0.02
103931	SSA	73.5	0.05
103931	SA	188	0.19
103931	MF	356.4	0.04
103931	RHO1	204	0.01
103931	Q1	208.7	0.04
103931	P1	227.9	0.08
103931	L2	25.1	0.01
103931	K2	39.3	0.02
103932	M2	334.7	0.08
103932	S2	17.7	0.03
103932	N2	313.7	0.01
103932	K1	230.4	0.25
103932	M4	260.1	0.01
103932	O1	224.1	0.19
103932	OO1	237.7	0.01
103932	M1	227.3	0.01
103932	J1	233.5	0.02
103932	MM	340.2	0.25
103932	SA	179	0.18
103932	MF	0.2	0.05
103932	RHO1	221.4	0.01
103932	Q1	220.9	0.04
103932	P1	229.9	0.08
103932	K2	23.6	0.01
103933	M2	17.8	0.37
103933	S2	37.1	0.06
103933	N2	353.2	0.08
103933	K1	222.5	0.25
103933	O1	223.3	0.2
103933	NU2	353.6	0.01
103933	MU2	26.7	0.01
103933	2N2	346.5	0.01
103933	OO1	234.5	0.01
103933	S1	250.7	0.02
103933	M1	248.4	0.01
103933	J1	220.2	0.02
103933	MM	332.1	0.03
103933	SA	197.7	0.14
103933	MF	350.5	0.06
103933	RHO1	215.1	0.01
103933	Q1	208.6	0.04
103933	T2	11.7	0.01
103933	P1	223.6	0.08
103933	L2	33.3	0.01
103933	K2	33.6	0.02
103934	M2	343	0.09
103934	S2	9.2	0.03
103934	N2	307.6	0.01
103934	K1	232.8	0.27
103934	M4	250	0.01
103934	O1	226.1	0.21
103934	MN4	151.1	0.01
103934	OO1	244.5	0.01
103934	S1	234.9	0.02
103934	M1	255.1	0.01
103934	J1	233.6	0.02
103934	MM	340.2	0.02
103934	SA	179	0.18
103934	MF	0.2	0.05
103934	RHO1	221.6	0.01
103934	Q1	212.1	0.04
103934	2Q1	203	0.01
103934	P1	232.6	0.08
103934	L2	5.9	0.01
103934	K2	5.7	0.01
103935	M2	15.4	0.32
103935	S2	37.1	0.05
103935	N2	356.4	0.08
103935	K1	222.8	0.25
103935	M4	313.6	0.01
103935	O1	224.1	0.19
103935	NU2	359	0.02
103935	MU2	353.7	0.01
103935	2N2	337	0.01
103935	OO1	222.9	0.01
103935	M1	223.5	0.01
103935	J1	222.9	0.02
103935	MM	332.1	0.03
103935	SA	197.7	0.14
103935	MF	350.5	0.06
103935	RHO1	224.6	0.01
103935	Q1	224.6	0.04
103935	2Q1	223.8	0.01
103935	P1	222.9	0.08
103935	L2	34.3	0.01
103935	K2	38.8	0.01
103936	M2	14.7	0.5
103936	S2	359.3	0.12
103936	N2	350.1	0.12
103936	K1	220.6	0.23
103936	O1	224.2	0.19
103936	NU2	356.2	0.02
103936	MU2	11.6	0.01
103936	2N2	322.4	0.01
103936	OO1	221.1	0.01
103936	LDA2	44.5	0.01
103936	S1	205.6	0.03
103936	M1	213.6	0.01
103936	J1	230.2	0.02
103936	SSA	37.1	0.07
103936	SA	186.9	0.18
103936	Q1	205.5	0.03
103936	T2	337.5	0.04
103936	R2	140.8	0.1
103936	P1	223.3	0.08
103936	L2	6.4	0.03
103936	K2	156.2	0.03
103937	M2	5.2	0.11
103937	S2	5.5	0.02
103937	N2	358.7	0.02
103937	K1	230.4	0.26
103937	M4	291.3	0.02
103937	O1	227.3	0.19
103937	OO1	234.1	0.01
103937	M1	228.9	0.01
103937	J1	232.5	0.02
103937	MM	332.1	0.03
103937	SA	197.7	0.14
103937	MF	350.5	0.06
103937	RHO1	225.9	0.01
103937	Q1	225.7	0.04
103937	P1	230.1	0.09
103937	K2	5.9	0.01
103938	M2	22.7	0.27
103938	S2	40.9	0.04
103938	N2	4.7	0.07
103938	K1	223.3	0.26
103938	M4	322.3	0.01
103938	O1	223.8	0.19
103938	NU2	6.9	0.01
103938	MU2	4.8	0.01
103938	2N2	346.3	0.01
103938	OO1	224.5	0.01
103938	M1	223.6	0.01
103938	J1	223.9	0.02
103938	MM	332.1	0.03
103938	SA	197.7	0.14
103938	MF	359.5	0.06
103938	RHO1	223.9	0.01
103938	Q1	224	0.04
103938	2Q1	222.8	0.01
103938	P1	223.3	0.09
103938	L2	40.6	0.01
103938	K2	42	0.01
103939	M2	12.5	0.52
103939	S2	41.2	0.08
103939	N2	345.2	0.12
103939	K1	219.2	0.24
103939	O1	222.8	0.19
103939	NU2	342.6	0.02
103939	MU2	10.9	0.02
103939	2N2	338	0.02
103939	OO1	223.5	0.01
103939	LDA2	46.9	0.01
103939	S1	224.4	0.02
103939	M1	230.8	0.01
103939	J1	226.1	0.02
103939	MM	318.4	0.03
103939	SSA	258.8	0.01
103939	SA	197.4	0.11
103939	MSF	298.4	0.01
103939	MF	357.2	0.06
103939	RHO1	208.4	0.01
103939	Q1	212.9	0.04
103939	T2	18.3	0.01
103939	P1	220.1	0.08
103939	L2	38.5	0.02
103939	K2	39.4	0.02
103940	M2	29.6	0.14
103940	S2	307.1	0.03
103940	N2	16.2	0.03
103940	K1	230.4	0.25
103940	M4	298.3	0.01
103940	O1	230	0.2
103940	NU2	14.1	0.02
103940	MU2	148.3	0.02
103940	2N2	168.5	0.01
103940	OO1	238.3	0.02
103940	LDA2	57	0.01
103940	S1	227.8	0.03
103940	M1	231.9	0.01
103940	J1	236.5	0.02
103940	SSA	37.1	0.07
103940	SA	186.9	0.18
103940	RHO1	149.3	0.01
103940	Q1	205	0.04
103940	R2	85.9	0.03
103940	P1	229	0.07
103940	M3	38.4	0.01
103940	L2	51.9	0.02
103940	K2	93.9	0.01
103941	M2	4.3	0.52
103941	S2	35.3	0.09
103941	N2	339	0.12
103941	K1	225	0.23
103941	M4	157.7	0.01
103941	O1	227.7	0.2
103941	NU2	342.4	0.02
103941	MU2	333.4	0.01
103941	2N2	314	0.02
103941	OO1	222.6	0.01
103941	M1	226.4	0.01
103941	J1	223.9	0.02
103941	MM	354.5	0.02
103941	SSA	38.3	0.05
103941	SA	181.4	0.18
103941	RHO1	228.7	0.01
103941	Q1	228.9	0.04
103941	T2	34	0.01
103941	2Q1	230.2	0.01
103941	P1	225.2	0.08
103941	L2	29.9	0.02
103941	K2	37.8	0.02
103942	M2	17.9	0.07
103942	S2	349.4	0.01
103942	N2	23.1	0.02
103942	K1	230.8	0.27
103942	M4	294.2	0.01
103942	O1	227.3	0.19
103942	OO1	235.4	0.01
103942	M1	229.1	0.01
103942	J1	232.6	0.02
103942	MM	332.1	0.03
103942	SA	197.7	0.14
103942	MF	350.5	0.06
103942	RHO1	225.8	0.01
103942	Q1	225.6	0.04
103942	2Q1	222.5	0.01
103942	P1	230.6	0.09
103943	M2	18.1	0.05
103943	S2	0.5	0.02
103943	N2	85	0.01
103943	K1	231.8	0.27
103943	M4	281.3	0.01
103943	O1	227.8	0.2
103943	NU2	51.7	0.01
103943	MU2	132.7	0.01
103943	OO1	240.3	0.01
103943	S1	215.8	0.01
103943	M1	257	0.01
103943	J1	230.5	0.02
103943	MM	318	0.02
103943	SA	184.5	0.18
103943	MF	352.9	0.05
103943	RHO1	216.4	0.01
103943	Q1	211.7	0.04
103943	2Q1	204	0.01
103943	P1	231.3	0.09
103943	K2	336.6	0.01
103944	M2	14.2	0.06
103944	S2	344.5	0.02
103944	N2	10.1	0.02
103944	K1	231.4	0.27
103944	M4	267.8	0.01
103944	O1	228.2	0.19
103944	OO1	234.8	0.01
103944	M1	229.8	0.01
103944	J1	233	0.02
103944	MM	332.1	0.03
103944	SA	197.7	0.14
103944	MF	359.5	0.06
103944	RHO1	226.9	0.01
103944	Q1	226.7	0.04
103944	P1	231.2	0.09
103944	K2	344.3	0.01
103945	M2	26.4	0.42
103945	S2	57.9	0.07
103945	N2	6.8	0.1
103945	K1	228.6	0.25
103945	O1	232.9	0.21
103945	NU2	9.5	0.02
103945	MU2	354.7	0.01
103945	2N2	347.4	0.01
103945	OO1	225.3	0.01
103945	M1	230.8	0.02
103945	J1	226.1	0.02
103945	MM	354.5	0.02
103945	SSA	38.3	0.05
103945	SA	181.4	0.18
103945	MF	350.5	0.06
103945	RHO1	234.6	0.01
103945	Q1	235	0.04
103945	2Q1	236.3	0.01
103945	P1	228.9	0.08
103945	L2	45.8	0.01
103945	K2	60.6	0.02
103946	M2	20.3	0.51
103946	S2	49.4	0.07
103946	N2	358.3	0.12
103946	K1	227.7	0.29
103946	M4	250.9	0.01
103946	O1	226.4	0.25
103946	MK3	35.4	0.01
103946	NU2	1.5	0.02
103946	MU2	18.8	0.02
103946	2N2	337.3	0.02
103946	OO1	252.2	0.01
103946	LDA2	41.8	0.01
103946	S1	153	0.02
103946	M1	266.1	0.01
103946	J1	214	0.02
103946	MM	354.5	0.02
103946	SSA	38.3	0.05
103946	SA	181.4	0.18
103946	RHO1	214.9	0.01
103946	Q1	211.2	0.05
103946	T2	24.9	0.01
103946	2Q1	218.6	0.01
103946	P1	228.9	0.09
103946	L2	21.3	0.01
103946	2MK3	24.5	0.01
103946	K2	49.6	0.02
103947	M2	65.9	0.04
103947	S2	5	0.04
103947	N2	137.7	0.02
103947	K1	231.1	0.27
103947	M4	266.8	0.01
103947	O1	229.7	0.19
103947	OO1	231.5	0.01
103947	M1	229.9	0.01
103947	J1	231.3	0.02
103947	RHO1	229.8	0.01
103947	Q1	229.5	0.04
103947	2Q1	228.4	0.01
103947	P1	230.8	0.09
103947	K2	0.3	0.01
103948	M2	137.8	0.03
103948	S2	13.9	0.02
103948	N2	77.6	0.03
103948	K1	230.5	0.26
103948	M4	285.2	0.01
103948	O1	230.1	0.18
103948	NU2	82.5	0.01
103948	OO1	231.5	0.01
103948	M1	230.3	0.01
103948	J1	231	0.01
103948	SA	179.9	0.18
103948	MF	357.4	0.05
103948	RHO1	229.8	0.01
103948	Q1	229.8	0.04
103948	P1	230.5	0.09
103948	K2	3.9	0.01
103949	M2	17.2	0.57
103949	S2	50.3	0.08
103949	N2	356.4	0.15
103949	K1	220	0.33
103949	M4	98.6	0.01
103949	O1	218.5	0.26
103949	NU2	359.2	0.03
103949	MU2	344.2	0.01
103949	2N2	335.6	0.02
103949	OO1	222.2	0.01
103949	M1	219.3	0.02
103949	J1	221	0.02
103949	MM	354.5	0.02
103949	SSA	38.3	0.05
103949	SA	181.4	0.18
103949	RHO1	217.9	0.01
103949	Q1	217.7	0.05
103949	2Q1	217.1	0.01
103949	P1	219.9	0.11
103949	L2	38	0.02
103949	K2	53	0.02
103950	M2	11.2	0.03
103950	S2	280.5	0.08
103950	N2	82.9	0.02
103950	K1	238	0.25
103950	M4	282.9	0.01
103950	O1	231.2	0.19
103950	MN4	164.9	0.01
103950	NU2	5	0.02
103950	MU2	97.5	0.01
103950	OO1	235.8	0.02
103950	LDA2	197.6	0.01
103950	S1	184.5	0.06
103950	M1	228.9	0.01
103950	J1	249.6	0.02
103950	SSA	42.6	0.05
103950	SA	184.2	0.2
103950	RHO1	239.6	0.01
103950	Q1	217.1	0.03
103950	R2	87.9	0.09
103950	P1	250.4	0.07
103950	L2	227.2	0.01
103950	K2	124.1	0.04
103951	M2	107.2	0.03
103951	S2	354.2	0.04
103951	N2	112.6	0.05
103951	K1	238.7	0.27
103951	M4	346.5	0.01
103951	O1	228.2	0.16
103951	NU2	112.3	0.01
103951	2N2	109.1	0.01
103951	OO1	249.1	0.01
103951	M1	233.6	0.01
103951	J1	243.9	0.01
103951	MM	341.3	0.02
103951	SA	179.9	0.18
103951	MF	357.4	0.05
103951	RHO1	223.7	0.01
103951	Q1	223	0.03
103951	P1	238	0.09
103951	K2	355.2	0.01
103952	M2	3.3	0.57
103952	S2	39.2	0.09
103952	N2	337.5	0.13
103952	K1	209.3	0.32
103952	O1	211.2	0.26
103952	MK3	77.8	0.01
103952	NU2	341.8	0.03
103952	MU2	356.5	0.02
103952	2N2	318.9	0.02
103952	OO1	215.3	0.01
103952	S1	230.3	0.02
103952	M1	233.1	0.01
103952	J1	212.7	0.02
103952	MM	319.4	0.02
103952	SA	187.7	0.16
103952	MF	350.5	0.05
103952	RHO1	200	0.01
103952	Q1	199.4	0.05
103952	T2	24.2	0.01
103952	P1	208.8	0.1
103952	L2	10.3	0.02
103952	K2	42	0.03
103953	M2	39.1	0.03
103953	S2	7.1	0.03
103953	N2	102.9	0.02
103953	K1	233.8	0.27
103953	M4	312.2	0.01
103953	O1	232.8	0.17
103953	MN4	209.2	0.01
103953	MU2	205.6	0.01
103953	2N2	123.9	0.01
103953	OO1	241.1	0.02
103953	S1	133.5	0.02
103953	M1	250.5	0.01
103953	J1	232.7	0.02
103953	MM	344.2	0.02
103953	SSA	42.6	0.05
103953	SA	184.2	0.2
103953	MF	353	0.05
103953	RHO1	250	0.01
103953	Q1	224.4	0.03
103953	T2	50	0.01
103953	R2	104	0.01
103953	P1	240.3	0.08
103953	L2	276.7	0.01
103953	K2	40.4	0.02
103954	M2	342.1	0.03
103954	S2	13.3	0.05
103954	N2	127.8	0.05
103954	K1	232.3	0.25
103954	M4	272.6	0.02
103954	O1	224.8	0.17
103954	NU2	122.5	0.01
103954	OO1	239.7	0.01
103954	M1	228.5	0.01
103954	J1	236	0.01
103954	MM	341.3	0.02
103954	SA	179.9	0.18
103954	MF	357.4	0.05
103954	RHO1	221.6	0.01
103954	Q1	221.1	0.03
103954	P1	231.8	0.08
103954	K2	12.1	0.01
103955	M2	9.9	0.02
103955	S2	9.8	0.03
103955	K1	233.4	0.26
103955	M4	295.2	0.01
103955	O1	227.8	0.18
103955	OO1	251.2	0.01
103955	S1	203.7	0.02
103955	M1	280.1	0.01
103955	J1	233	0.02
103955	MM	341.3	0.02
103955	SA	179.9	0.18
103955	MF	357.4	0.05
103955	RHO1	204	0.01
103955	Q1	215.3	0.03
103955	P1	233.6	0.08
103955	L2	340.2	0.01
103955	K2	2.8	0.01
103956	M2	9.2	0.16
103956	S2	28.3	0.05
103956	N2	336.2	0.04
103956	K1	226.2	0.22
103956	M4	287.9	0.02
103956	O1	220.4	0.17
103956	NU2	340.4	0.01
103956	2N2	302.6	0.01
103956	OO1	232.1	0.01
103956	M1	223.3	0.01
103956	J1	229.1	0.01
103956	MM	341.3	0.02
103956	SA	179.9	0.18
103956	MF	357.4	0.05
103956	RHO1	217.9	0.01
103956	Q1	217.5	0.03
103956	P1	225.8	0.07
103956	K2	29.9	0.01
103957	M2	2.7	0.27
103957	S2	37.3	0.06
103957	N2	332	0.06
103957	K1	226.7	0.21
103957	M4	296.2	0.02
103957	O1	218.5	0.16
103957	M6	317.1	0.01
103957	NU2	336.5	0.01
103957	MU2	328.1	0.01
103957	2N2	302.4	0.01
103957	OO1	234.9	0.01
103957	M1	223	0.01
103957	J1	230.8	0.01
103957	MM	317	0.03
103957	SSA	99.8	0.02
103957	SA	187.7	0.16
103957	MSF	351.2	0.01
103957	MF	356.7	0.05
103957	RHO1	215	0.01
103957	Q1	214.4	0.03
103957	P1	226.1	0.07
103957	L2	33.3	0.01
103957	K2	40	0.02
103958	M2	7.3	0.2
103958	S2	332.1	0.01
103958	N2	3.2	0.04
103958	K1	231.5	0.2
103958	M4	276.4	0.02
103958	O1	224.9	0.16
103958	M6	351.9	0.01
103958	MN4	229.6	0.01
103958	MU2	110.3	0.01
103958	OO1	237.3	0.01
103958	LDA2	230	0.01
103958	S1	192.1	0.05
103958	M1	212.1	0.01
103958	J1	231.7	0.02
103958	SSA	42.6	0.05
103958	SA	184.2	0.2
103958	RHO1	189.7	0.01
103958	Q1	199.2	0.03
103958	T2	241.3	0.02
103958	R2	38.1	0.04
103958	P1	239.9	0.06
103958	M3	93.9	0.01
103958	L2	145.2	0.01
103958	K2	51.4	0.03
103958	MS4	345.8	0.01
103959	M2	55	0.03
103959	S2	311.1	0.06
103959	N2	50.6	0.03
103959	K1	231.8	0.22
103959	M4	304.3	0.01
103959	O1	226.8	0.18
103959	NU2	185.7	0.01
103959	MU2	98.3	0.02
103959	OO1	241.9	0.01
103959	LDA2	201.5	0.02
103959	S1	205.3	0.06
103959	M1	221.6	0.01
103959	J1	223.2	0.02
103959	SSA	42.6	0.05
103959	SA	184.2	0.2
103959	RHO1	207.6	0.01
103959	Q1	206.1	0.03
103959	T2	280.7	0.04
103959	R2	98.3	0.03
103959	P1	242.2	0.06
103959	M3	84.5	0.01
103959	L2	143.9	0.02
103959	K2	19	0.01
103960	M2	14.5	0.48
103960	S2	41	0.07
103960	N2	350.7	0.11
103960	K1	213.8	0.19
103960	M4	321.3	0.01
103960	O1	210.8	0.15
103960	MK3	331.9	0.01
103960	NU2	350.3	0.02
103960	MU2	11.4	0.01
103960	2N2	334.9	0.02
103960	OO1	223	0.01
103960	LDA2	35.5	0.01
103960	S1	209.6	0.02
103960	M1	219	0.01
103960	J1	218.2	0.02
103960	MM	317	0.03
103960	SSA	99.8	0.02
103960	SA	187.7	0.16
103960	MSF	351.2	0.01
103960	MF	356.7	0.05
103960	RHO1	200.1	0.01
103960	Q1	194.3	0.03
103960	T2	17.7	0.01
103960	P1	217.6	0.06
103960	L2	46.7	0.02
103960	2MK3	351.8	0.01
103960	K2	39.5	0.02
103961	M2	0.6	0.48
103961	S2	29.9	0.1
103961	N2	340.1	0.11
103961	K1	208.5	0.24
103961	M4	278	0.01
103961	O1	205.4	0.19
103961	M6	358.5	0.01
103961	NU2	334.1	0.02
103961	MU2	349.6	0.02
103961	2N2	323.5	0.02
103961	OO1	221.5	0.01
103961	LDA2	6.8	0.01
103961	S1	317.9	0.01
103961	M1	220.8	0.01
103961	J1	217.6	0.01
103961	MM	330.3	0.02
103961	SA	180	0.28
103961	MF	355.4	0.05
103961	RHO1	206.2	0.01
103961	Q1	193.3	0.04
103961	T2	12.2	0.01
103961	P1	211	0.07
103961	L2	20.8	0.02
103961	K2	26.4	0.02
103962	M2	5.6	0.35
103962	S2	34.8	0.06
103962	N2	341.9	0.07
103962	K1	220.5	0.19
103962	M4	315.7	0.02
103962	O1	218.5	0.16
103962	M6	321.4	0.01
103962	NU2	345.1	0.01
103962	MU2	201.9	0.01
103962	2N2	318	0.01
103962	OO1	222.3	0.01
103962	M1	219.5	0.01
103962	J1	221.3	0.01
103962	SSA	42.6	0.05
103962	SA	184.2	0.2
103962	RHO1	217.7	0.01
103962	Q1	217.6	0.03
103962	P1	220.4	0.07
103962	L2	29.4	0.01
103962	K2	37.2	0.02
103963	M2	71.2	0.06
103963	S2	9.9	0.04
103963	N2	75.6	0.02
103963	K1	223	0.25
103963	O1	223.8	0.19
103963	M6	14.1	0.01
103963	NU2	76	0.01
103963	OO1	221.5	0.01
103963	M1	223.5	0.01
103963	J1	222.8	0.02
103963	MM	348	0.02
103963	SA	180.9	0.14
103963	MF	359.3	0.07
103963	RHO1	224.1	0.01
103963	Q1	224.2	0.04
103963	2Q1	226	0.01
103963	P1	223.1	0.08
103963	K2	4.1	0.01
103964	M2	7.6	0.08
103964	S2	17.2	0.04
103964	N2	27.1	0.01
103964	K1	233.1	0.27
103964	M4	0.6	0.04
103964	O1	231.5	0.2
103964	MK3	355.6	0.01
103964	MN4	322.6	0.01
103964	OO1	235	0.01
103964	S1	204.6	0.01
103964	M1	264.9	0.01
103964	J1	229.2	0.02
103964	MM	348	0.02
103964	SA	180.9	0.14
103964	MF	359.3	0.07
103964	RHO1	226	0.01
103964	Q1	219.9	0.04
103964	P1	232.5	0.08
103964	2MK3	11.3	0.01
103964	K2	12.9	0.01
103964	MS4	54.5	0.01
106032	M2	322.3	1.818
106032	S2	356.3	0.27
106032	N2	282.4	0.292
106032	K1	25.8	0.102
106032	M4	36.2	0.08
106032	O1	324.6	0.074
106032	M6	81.6	0.046
106032	NU2	287.7	0.057
106032	MU2	122.9	0.07
106032	2N2	242.5	0.039
106032	LDA2	338	0.013
106032	Q1	293.9	0.014
106032	T2	356.2	0.016
106032	P1	25.7	0.034
106032	L2	14.1	0.198
106032	K2	355.4	0.094
106033	M2	294.1	0.753
106033	S2	315.3	0.107
106033	N2	243.8	0.107
106033	K1	290.2	0.25
106033	O1	304.3	0.146
106033	NU2	250.6	0.02
106033	2N2	193.7	0.014
106033	J1	283	0.012
106033	Q1	311.4	0.028
106033	P1	290.1	0.082
106033	L2	344.3	0.021
106033	K2	315.3	0.029
106034	M2	297.3	1.843
106034	S2	325.2	0.325
106034	N2	285.3	0.396
106034	K1	119.7	0.144
106034	M4	92.7	0.19
106034	O1	122.7	0.103
106034	M6	63.4	0.056
106034	MK3	214.1	0.054
106034	MN4	53.6	0.071
106034	NU2	277.7	0.069
106034	MU2	316.6	0.063
106034	2N2	270.1	0.071
106034	OO1	116.6	0.004
106034	LDA2	278.9	0.031
106034	S1	66.5	0.031
106034	M1	210.5	0.01
106034	J1	127.7	0.013
106034	MM	196.4	0.023
106034	SA	325.9	0.02
106034	MSF	166.2	0.014
106034	RHO1	123.9	0.004
106034	Q1	122.5	0.026
106034	T2	308	0.031
106034	R2	227.7	0.017
106034	2Q1	125.6	0.003
106034	P1	125.1	0.049
106034	2SM2	350.3	0.014
106034	M3	36.7	0.053
106034	L2	285.3	0.064
106034	2MK3	222.3	0.051
106034	K2	327.8	0.088
106034	M8	353	0.038
106034	MS4	92.6	0.06
106035	M2	318.9	1.983
106035	S2	345.6	0.27
106035	N2	300	0.405
106035	K1	119.6	0.142
106035	M4	183.5	0.136
106035	O1	138.4	0.133
106035	M6	89.8	0.106
106035	MK3	297.7	0.023
106035	S4	6.3	0.016
106035	MN4	116.8	0.036
106035	NU2	253.2	0.113
106035	2N2	252.1	0.015
106035	OO1	32.9	0.019
106035	LDA2	181.7	0.039
106035	M1	173.4	0.017
106035	J1	172.5	0.01
106035	RHO1	146.4	0.005
106035	Q1	125.5	0.045
106035	T2	344.4	0.016
106035	R2	346.7	0.002
106035	2Q1	156.9	0.003
106035	P1	103.5	0.047
106035	2SM2	96.2	0.023
106035	M3	99.6	0.066
106035	L2	303.7	0.103
106035	K2	324.7	0.097
106035	M8	171.6	0.021
106035	MS4	204.8	0.036
106036	M2	122.5	1.045
106036	S2	133.9	0.368
106036	N2	116	0.187
106036	K1	325.9	0.611
106036	M4	304.2	0.043
106036	O1	316.8	0.515
106036	MK3	121.3	0.042
106036	S4	221	0.02
106036	MN4	308.5	0.015
106036	NU2	133.9	0.036
106036	MU2	345	0.04
106036	2N2	109.6	0.025
106036	OO1	334.8	0.022
106036	LDA2	189.5	0.03
106036	S1	44	0.078
106036	M1	321.3	0.037
106036	J1	326.8	0.03
106036	RHO1	312.9	0.02
106036	Q1	313.3	0.102
106036	T2	133.8	0.022
106036	R2	133.9	0.003
106036	2Q1	307.8	0.013
106036	P1	326.1	0.19
106036	2SM2	51	0.03
106036	M3	337.4	0.013
106036	L2	150.8	0.051
106036	2MK3	131.8	0.039
106036	K2	136.3	0.146
106036	MS4	295.3	0.027
106037	M2	302.7	0.607
106037	S2	284	0.171
106037	N2	272.6	0.134
106037	K1	16.3	0.883
106037	M4	224.6	0.077
106037	O1	6.4	0.853
106037	M6	77.7	0.012
106037	MK3	270.4	0.035
106037	S4	303.8	0.017
106037	MN4	190	0.037
106037	S6	180.7	0.007
106037	2N2	268.3	0.116
106037	OO1	23.1	0.064
106037	M1	57.8	0.05
106037	J1	302.2	0.068
106037	Q1	340.1	0.198
106037	2Q1	301	0.061
106037	P1	25.9	0.153
106037	2SM2	24.8	0.028
106037	M3	67.7	0.024
106037	L2	351.4	0.053
106037	2MK3	274.7	0.07
106037	K2	324	0.138
106037	M8	24.2	0.014
106037	MS4	210.9	0.033
106038	M2	310.9	0.685
106038	S2	305.1	0.184
106038	N2	276.4	0.169
106038	K1	16.3	0.995
106038	M4	229.4	0.069
106038	O1	4	0.917
106038	M6	73	0.008
106038	MK3	237.1	0.053
106038	MN4	202.3	0.028
106038	NU2	277.4	0.038
106038	MU2	196.5	0.042
106038	2N2	325.2	0.086
106038	OO1	29.5	0.174
106038	LDA2	342	0.034
106038	S1	109.8	0.007
106038	M1	100.2	0.016
106038	J1	158.9	0.041
106038	RHO1	16.2	0.051
106038	Q1	348.4	0.21
106038	T2	322	0.01
106038	R2	149.6	0.006
106038	2Q1	339.9	0.052
106038	P1	12.9	0.242
106038	2SM2	297.6	0.005
106038	M3	255.7	0.012
106038	L2	29.9	0.037
106038	2MK3	214.7	0.046
106038	K2	0.1	0.165
106038	M8	5.9	0.005
106038	MS4	226.2	0.04
106039	M2	81.9	0.607
106039	S2	129.6	0.064
106039	N2	56.3	0.117
106039	K1	160.9	0.199
106039	O1	179.6	0.108
106039	NU2	59.7	0.023
106039	2N2	30.7	0.016
106039	Q1	189	0.021
106039	P1	160.9	0.066
106039	L2	107.5	0.017
106039	K2	129.6	0.018
106040	M2	7.5	0.254
106040	S2	36.6	0.076
106040	N2	319.1	0.054
106040	K1	49.8	0.024
106040	M4	273.8	0.043
106040	O1	198.2	0.009
106040	M6	203.8	0.018
106040	MK3	107.9	0.009
106040	S4	354.7	0.005
106040	MN4	224.2	0.021
106040	S6	265.8	0.003
106040	2N2	113.1	0.026
106040	OO1	121.7	0.023
106040	M1	10	0.01
106040	J1	335.2	0.006
106040	Q1	42.6	0.013
106040	2Q1	349.3	0.014
106040	2SM2	95.4	0.014
106040	M3	331.1	0.004
106040	L2	75.6	0.055
106040	2MK3	210.1	0.005
106040	K2	19.7	0.03
106040	M8	184.7	0.002
106040	MS4	327.1	0.022
106041	M2	14.2	0.395
106041	S2	55.5	0.069
106041	N2	320	0.096
106041	K1	340.7	0.014
106041	M4	299.9	0.028
106041	O1	26.8	0.022
106041	M6	197.8	0.025
106041	MK3	278.1	0.007
106041	S4	336.1	0.002
106041	MN4	270.6	0.02
106041	S6	25.6	0.002
106041	2N2	343.2	0.025
106041	OO1	258.3	0.031
106041	M1	90.4	0.009
106041	J1	227.3	0.006
106041	Q1	122.9	0.017
106041	2Q1	160.6	0.025
106041	2SM2	143.4	0.015
106041	M3	121.7	0.006
106041	L2	103.7	0.027
106041	2MK3	107.4	0.002
106041	K2	82.2	0.013
106041	M8	253.4	0.004
106041	MS4	223	0.005
106042	M2	6.5	0.417
106042	S2	96.6	0.096
106042	N2	336.4	0.092
106042	K1	70.8	0.005
106042	M4	285	0.018
106042	O1	67.3	0.029
106042	M6	185.6	0.023
106042	MK3	72.7	0.01
106042	S4	62.6	0.011
106042	MN4	311.7	0.009
106042	S6	169.8	0.003
106042	2N2	333.5	0.03
106042	OO1	260.5	0.036
106042	M1	141.7	0.018
106042	J1	221.3	0.023
106042	Q1	151.2	0.015
106042	2Q1	178.5	0.027
106042	2SM2	188.3	0.02
106042	M3	302.4	0.008
106042	L2	59.2	0.007
106042	2MK3	98	0.012
106042	K2	92.5	0.064
106042	M8	330.8	0.011
106042	MS4	102.4	0.009
106043	M2	23.2	0.293
106043	S2	0.9	0.045
106043	N2	359.9	0.043
106043	K1	154.4	0.046
106043	M4	286.9	0.043
106043	O1	39.4	0.009
106043	M6	242.3	0.024
106043	S4	257.8	0.008
106043	MN4	217.3	0.01
106043	S6	267	0.004
106043	2N2	342.3	0.024
106043	OO1	267.7	0.008
106043	M1	202.9	0.003
106043	J1	268.7	0.013
106043	Q1	214.4	0.006
106043	2Q1	287.1	0.013
106043	P1	2.2	0.036
106043	2SM2	311.6	0.004
106043	M3	203.9	0.008
106043	L2	58	0.033
106043	2MK3	78	0.003
106043	K2	325.8	0.035
106043	M8	151.1	0.005
106043	MS4	350.2	0.013
106044	M2	40.8	0.296
106044	S2	101.1	0.091
106044	N2	356.7	0.09
106044	K1	117.1	0.048
106044	M4	344	0.035
106044	O1	162.3	0.02
106044	M6	206.1	0.008
106044	MK3	56.7	0.021
106044	S4	30.2	0.005
106044	MN4	313.7	0.027
106044	S6	170.2	0.005
106044	2N2	205.4	0.01
106044	OO1	335.8	0.002
106044	M1	329.2	0.006
106044	J1	94.3	0.011
106044	Q1	146	0.002
106044	2Q1	144.4	0.011
106044	P1	282.2	0.019
106044	2SM2	108.4	0.014
106044	M3	324.6	0.003
106044	L2	256.4	0.023
106044	2MK3	75.4	0.014
106044	K2	124.7	0.045
106044	M8	110.6	0.004
106044	MS4	81.3	0.008
106045	M2	352.8	0.103
106045	S2	22.8	0.032
106045	N2	320.7	0.039
106045	K1	90.1	0.015
106045	M4	239.4	0.042
106045	O1	78.6	0.013
106045	M6	177.2	0.014
106045	MK3	330.2	0.004
106045	S4	124.5	0.014
106045	MN4	220.7	0.016
106045	S6	309.4	0.002
106045	2N2	243.8	0.02
106045	OO1	36.9	0.01
106045	M1	273.6	0.003
106045	J1	30.5	0.007
106045	Q1	200.6	0.007
106045	2Q1	189.6	0.01
106045	2SM2	101.2	0.024
106045	M3	246.5	0.005
106045	L2	263.4	0.025
106045	2MK3	339.6	0.006
106045	M8	133.6	0.001
106045	MS4	12.3	0.019
106046	M2	18.5	0.209
106046	S2	46.7	0.033
106046	N2	329.5	0.053
106046	K1	135.2	0.017
106046	M4	284	0.035
106046	O1	69.6	0.01
106046	M6	213	0.01
106046	MK3	318.2	0.004
106046	S4	218.5	0.01
106046	MN4	252.5	0.013
106046	S6	310.4	0.005
106046	2N2	301.5	0.004
106046	OO1	280.5	0.003
106046	M1	267.6	0.005
106046	J1	46.3	0.004
106046	Q1	287.9	0.001
106046	2Q1	324.9	0.006
106046	2SM2	117.6	0.009
106046	M3	143.9	0.003
106046	L2	94.5	0.008
106046	2MK3	12.1	0.006
106046	M8	55.3	0.001
106046	MS4	11.4	0.012
106047	M2	30.7	0.261
106047	S2	90.4	0.025
106047	N2	342.5	0.043
106047	K1	140.7	0.013
106047	M4	330.4	0.027
106047	O1	57.2	0.005
106047	M6	94.2	0.001
106047	MK3	30.6	0.007
106047	S4	357	0.006
106047	MN4	247	0.008
106047	S6	101.5	0.003
106047	2N2	296.5	0.007
106047	OO1	184.7	0.005
106047	M1	130.6	0.003
106047	J1	169.9	0.007
106047	Q1	42	0.006
106047	2Q1	112.1	0.005
106047	2SM2	112.9	0.004
106047	M3	49	0.003
106047	L2	104.7	0.03
106047	2MK3	97.8	0.007
106047	M8	13.6	0.002
106047	MS4	170.8	0.002
106048	M2	35.6	0.064
106048	S2	76.9	0.011
106048	N2	347.9	0.023
106048	K1	134	0.011
106048	M4	297.9	0.01
106048	O1	158.3	0.011
106048	M6	312	0.003
106048	MK3	195	0.006
106048	S4	105.2	0.007
106048	MN4	320.9	0.011
106048	S6	301.9	0.007
106048	2N2	357.8	0.005
106048	OO1	42.3	0.013
106048	J1	10.2	0.009
106048	Q1	160.6	0.008
106048	2Q1	327.3	0.015
106048	2SM2	33.2	0.012
106048	M3	132	0.007
106048	L2	53.5	0.02
106048	2MK3	146.7	0.004
106048	M8	273.2	0.002
106048	MS4	138.7	0.003
106049	M2	65.5	0.115
106049	S2	102.4	0.015
106049	N2	351.9	0.013
106049	K1	134	0.008
106049	M4	342.3	0.017
106049	O1	126.4	0.011
106049	M6	325.8	0.006
106049	MK3	302.9	0.002
106049	S4	239.9	0.006
106049	MN4	198.3	0.007
106049	S6	13.2	0.004
106049	2N2	309.1	0.022
106049	OO1	119.9	0.015
106049	M1	345.1	0.008
106049	J1	20.2	0.007
106049	Q1	112.4	0.01
106049	2Q1	312.3	0.01
106049	2SM2	163.5	0.017
106049	M3	167	0.003
106049	L2	356.4	0.008
106049	2MK3	178	0.009
106049	M8	138.2	0.003
106049	MS4	352.6	0.009
106050	M2	71.4	0.145
106050	S2	116.2	0.013
106050	N2	60.6	0.034
106050	K1	137.8	0.056
106050	M4	339.2	0.022
106050	O1	146.9	0.032
106050	M6	325.9	0.005
106050	MK3	50.2	0.03
106050	S4	311.4	0.005
106050	MN4	318.7	0.009
106050	S6	160.4	0.005
106050	2N2	299.9	0.024
106050	OO1	137.4	0.017
106050	M1	322.3	0.01
106050	J1	39.1	0.016
106050	Q1	22.2	0.007
106050	2Q1	342.2	0.007
106050	2SM2	124.1	0.011
106050	M3	62.9	0.005
106050	L2	24.2	0.019
106050	2MK3	80.8	0.011
106050	M8	22.4	0.004
106050	MS4	288.4	0.006
106051	M2	343.1	0.383
106051	S2	102.7	0.054
106051	N2	352	0.019
106051	K1	118.7	0.009
106051	M4	163.1	0.044
106051	O1	22.6	0.017
106051	M6	138.2	0.022
106051	MK3	168.6	0.004
106051	S4	47.3	0.009
106051	MN4	327.4	0.016
106051	S6	27.1	0.004
106051	2N2	347	0.067
106051	OO1	299.6	0.013
106051	M1	113.1	0.006
106051	J1	102.5	0.01
106051	Q1	93.1	0.007
106051	2Q1	335.7	0.009
106051	2SM2	314.1	0.014
106051	M3	175	0.007
106051	L2	358.8	0.104
106051	2MK3	85	0.005
106051	M8	263.6	0.012
106051	MS4	252.7	0.017
106052	M2	23.4	0.265
106052	S2	13.8	0.018
106052	N2	7.1	0.052
106052	K1	173.4	0.035
106052	M4	56.9	0.025
106052	O1	61.6	0.028
106052	M6	249.5	0.02
106052	MK3	56.3	0.015
106052	S4	117.9	0.006
106052	MN4	258.6	0.019
106052	S6	353.9	0.007
106052	2N2	272.4	0.054
106052	OO1	250.7	0.009
106052	M1	12.7	0.007
106052	J1	122.3	0.006
106052	Q1	84.5	0.023
106052	2Q1	37.4	0.01
106052	2SM2	315.4	0.01
106052	M3	48.6	0.006
106052	L2	328	0.021
106052	2MK3	54.2	0.008
106052	M8	122	0.009
106052	MS4	283.6	0.007
106053	M2	55.2	0.27
106053	S2	26.9	0.057
106053	N2	332.4	0.092
106053	K1	98.5	0.071
106053	M4	14.5	0.035
106053	O1	177.7	0.036
106053	M6	247.6	0.018
106053	MK3	69.2	0.025
106053	S4	342.6	0.006
106053	MN4	332.1	0.007
106053	S6	172.1	0.003
106053	2N2	181.5	0.023
106053	OO1	84.7	0.035
106053	M1	347.7	0.007
106053	J1	341.7	0.011
106053	Q1	38	0.021
106053	2Q1	259.4	0.013
106053	2SM2	255	0.008
106053	M3	176.8	0.006
106053	L2	176.1	0.077
106053	2MK3	137.9	0.023
106053	M8	128.2	0.004
106053	MS4	287.4	0.02
106054	M2	23.1	0.468
106054	S2	72.8	0.103
106054	N2	351	0.108
106054	K1	155.3	0.04
106054	M4	306.7	0.06
106054	O1	89.9	0.02
106054	M6	214.4	0.051
106054	MK3	41.8	0.009
106054	S4	85.7	0.003
106054	MN4	290.8	0.027
106054	S6	280.1	0.004
106054	2N2	268.3	0.017
106054	OO1	203.8	0.006
106054	M1	57.7	0.005
106054	J1	104.3	0.005
106054	Q1	100.9	0.004
106054	2Q1	19.1	0.009
106054	P1	73.9	0.02
106054	2SM2	153.2	0.01
106054	M3	141.9	0.005
106054	L2	69	0.008
106054	2MK3	73.2	0.002
106054	K2	54.5	0.055
106054	M8	160.1	0.019
106054	MS4	32.8	0.017
106055	M2	35.1	0.71
106055	S2	69.3	0.105
106055	N2	336.6	0.132
106055	K1	138.3	0.05
106055	M4	302.7	0.071
106055	O1	119.3	0.016
106055	M6	203.6	0.044
106055	MK3	14.8	0.005
106055	S4	145.4	0.002
106055	MN4	271.8	0.03
106055	S6	177.3	0.003
106055	2N2	118.8	0.023
106055	OO1	237	0.005
106055	M1	47.9	0.007
106055	J1	62.1	0.006
106055	Q1	99.7	0.007
106055	2Q1	316.5	0.008
106055	P1	72.5	0.017
106055	2SM2	134.7	0.024
106055	M3	114.3	0.003
106055	L2	117.5	0.104
106055	2MK3	129.4	0.01
106055	K2	61.1	0.046
106055	M8	173.8	0.015
106055	MS4	23.2	0.017
106056	M2	20.9	0.719
106056	S2	65.6	0.153
106056	N2	350.6	0.217
106056	K1	146.5	0.043
106056	M4	297.9	0.147
106056	O1	72.4	0.036
106056	M6	193.7	0.098
106056	MK3	31.8	0.021
106056	S4	141.9	0.008
106056	MN4	263.7	0.066
106056	S6	355.9	0.005
106056	2N2	258.2	0.058
106056	OO1	263.7	0.009
106056	M1	65.9	0.003
106056	J1	87.4	0.009
106056	Q1	211.5	0.004
106056	2Q1	352.9	0.014
106056	P1	96	0.025
106056	2SM2	280.6	0.019
106056	M3	243.8	0.003
106056	L2	272	0.049
106056	2MK3	21.4	0.015
106056	K2	61.3	0.044
106056	M8	118.2	0.034
106056	MS4	359.4	0.022
106057	M2	23.1	0.924
106057	S2	67.4	0.157
106057	N2	349.4	0.238
106057	K1	138.2	0.055
106057	M4	296.2	0.191
106057	O1	78	0.041
106057	M6	196.8	0.099
106057	MK3	34.8	0.026
106057	S4	83.7	0.003
106057	MN4	258.7	0.069
106057	S6	344	0.003
106057	2N2	268.5	0.042
106057	OO1	248.6	0.009
106057	M1	19.7	0.001
106057	J1	61.4	0.008
106057	Q1	260.3	0.006
106057	2Q1	0.8	0.017
106057	P1	92	0.027
106057	2SM2	304.5	0.009
106057	M3	85.9	0.002
106057	L2	332.9	0.013
106057	2MK3	53.5	0.015
106057	K2	60.8	0.047
106057	M8	140.9	0.036
106057	MS4	349.7	0.02
106058	M2	27.5	1.133
106058	S2	63.6	0.167
106058	N2	342.7	0.209
106058	K1	92.8	0.04
106058	M4	296.9	0.203
106058	O1	90.5	0.042
106058	M6	199.8	0.086
106058	MK3	10.4	0.016
106058	S4	56.4	0.008
106058	MN4	233.4	0.059
106058	S6	272	0.006
106058	2N2	317	0.051
106058	OO1	251.7	0.01
106058	M1	192.5	0.001
106058	J1	244.9	0.008
106058	Q1	208.7	0.011
106058	2Q1	353.7	0.018
106058	P1	133.3	0.018
106058	2SM2	73.4	0.005
106058	M3	69.7	0.009
106058	L2	66.6	0.1
106058	2MK3	121.1	0.011
106058	K2	61	0.063
106058	M8	174.8	0.033
106058	MS4	287.9	0.039
106059	M2	32.4	0.509
106059	S2	78.4	0.114
106059	N2	356	0.163
106059	K1	133.4	0.051
106059	M4	311.7	0.082
106059	O1	79.5	0.027
106059	M6	209.4	0.053
106059	MK3	88.4	0.004
106059	S4	237.7	0.002
106059	MN4	293	0.033
106059	S6	347.2	0.003
106059	2N2	268.1	0.045
106059	OO1	42.7	0.003
106059	M1	106.6	0.007
106059	J1	128.7	0.015
106059	Q1	33.7	0.006
106059	2Q1	348	0.008
106059	2SM2	303.1	0.008
106059	M3	201.9	0.01
106059	L2	260.7	0.047
106059	2MK3	19.4	0.005
106059	K2	89.3	0.054
106059	M8	166.7	0.018
106059	MS4	23.8	0.01
106060	M2	34.6	0.701
106060	S2	74.5	0.138
106060	N2	352.9	0.184
106060	K1	131.3	0.06
106060	M4	316.9	0.105
106060	O1	84	0.029
106060	M6	209.1	0.052
106060	MK3	71.8	0.007
106060	S4	108.9	0.004
106060	MN4	271.6	0.041
106060	S6	307.5	0.005
106060	2N2	285.8	0.027
106060	OO1	131.6	0.003
106060	M1	91.1	0.007
106060	J1	136.2	0.011
106060	Q1	24.9	0.006
106060	2Q1	339.9	0.008
106060	2SM2	263.6	0.005
106060	M3	179.8	0.011
106060	L2	200.3	0.009
106060	2MK3	116.3	0.004
106060	K2	78.9	0.061
106060	M8	174.7	0.02
106060	MS4	334.3	0.022
106061	M2	37.8	0.944
106061	S2	70.2	0.15
106061	N2	340.1	0.182
106061	K1	110	0.065
106061	M4	287.7	0.098
106061	O1	100.3	0.017
106061	M6	168.2	0.075
106061	MK3	190	0.008
106061	S4	340	0.012
106061	MN4	248	0.038
106061	S6	320.4	0.005
106061	2N2	47.9	0.034
106061	OO1	302.4	0.007
106061	M1	26.2	0.006
106061	J1	322.2	0.006
106061	Q1	95.7	0.012
106061	2Q1	242.3	0.01
106061	2SM2	103.7	0.022
106061	M3	57.2	0.005
106061	L2	111.1	0.122
106061	2MK3	149.2	0.01
106061	K2	59.7	0.063
106061	M8	83.9	0.006
106061	MS4	309.9	0.028
106062	M2	24.6	0.955
106062	S2	68.7	0.199
106062	N2	3.5	0.166
106062	K1	134.5	0.054
106062	M4	291.3	0.165
106062	O1	101.6	0.043
106062	M6	203.4	0.105
106062	MK3	69.3	0.009
106062	S4	172.3	0.009
106062	MN4	268.9	0.051
106062	S6	145.7	0.004
106062	2N2	313.4	0.023
106062	OO1	269.8	0.003
106062	M1	113.4	0.004
106062	J1	67	0.007
106062	Q1	155.6	0.01
106062	2Q1	4.1	0.013
106062	P1	124.2	0.014
106062	2SM2	157.1	0.005
106062	M3	334.5	0.007
106062	L2	13.9	0.037
106062	2MK3	48.6	0.021
106062	K2	115.4	0.074
106062	M8	72.8	0.037
106062	MS4	357.8	0.046
106063	M2	27.1	1.385
106063	S2	75.1	0.187
106063	N2	357.8	0.262
106063	K1	106.9	0.074
106063	M4	316.7	0.187
106063	O1	87.6	0.039
106063	M6	176.1	0.036
106063	MK3	127.4	0.029
106063	S4	226.5	0.006
106063	MN4	299.5	0.059
106063	S6	152.3	0.008
106063	2N2	17.9	0.017
106063	OO1	232.5	0.01
106063	M1	109.4	0.008
106063	J1	73.7	0.003
106063	Q1	98.4	0.012
106063	2Q1	238.4	0.004
106063	P1	135.6	0.033
106063	2SM2	2.5	0.009
106063	M3	348.9	0.006
106063	L2	72.5	0.04
106063	2MK3	76.1	0.021
106063	M8	193.3	0.028
106063	MS4	11.4	0.05
106064	M2	29.2	1.446
106064	S2	78.8	0.206
106064	N2	359	0.29
106064	K1	84	0.093
106064	M4	323	0.159
106064	O1	72.9	0.036
106064	M6	87.2	0.007
106064	MK3	128.2	0.033
106064	S4	204.4	0.003
106064	MN4	307.4	0.061
106064	S6	180.8	0.015
106064	2N2	33.7	0.011
106064	OO1	174.4	0.015
106064	M1	73.8	0.007
106064	J1	110.7	0.008
106064	Q1	100.6	0.018
106064	2Q1	232.1	0.01
106064	P1	151.5	0.047
106064	2SM2	302.2	0.008
106064	M3	307.8	0.002
106064	L2	88.1	0.043
106064	2MK3	93.7	0.03
106064	M8	189.6	0.023
106064	MS4	11.9	0.039
106065	M2	21.8	1.072
106065	S2	64.7	0.153
106065	N2	340.1	0.23
106065	K1	104.2	0.057
106065	M4	278.5	0.115
106065	O1	100.3	0.048
106065	M6	218.1	0.095
106065	MK3	82.5	0.011
106065	S4	289.3	0.01
106065	MN4	255.9	0.026
106065	S6	100.5	0.001
106065	2N2	289.3	0.06
106065	OO1	139.5	0.007
106065	M1	97.8	0.003
106065	J1	199.7	0.007
106065	Q1	191.4	0.005
106065	2Q1	303.6	0.008
106065	2SM2	319.1	0.007
106065	M3	322.3	0.008
106065	L2	18.7	0.03
106065	2MK3	146	0.02
106065	K2	72.3	0.044
106065	M8	149.9	0.046
106065	MS4	308.4	0.017
106066	M2	19.1	1.245
106066	S2	71.8	0.163
106066	N2	338.8	0.253
106066	K1	110.1	0.065
106066	M4	311.6	0.131
106066	O1	98.7	0.059
106066	M6	213.2	0.116
106066	MK3	78.9	0.023
106066	S4	14.4	0.004
106066	MN4	279	0.047
106066	S6	295.8	0.007
106066	2N2	292.2	0.048
106066	OO1	280.1	0.005
106066	M1	134.4	0.003
106066	J1	209.3	0.009
106066	Q1	139	0.01
106066	2Q1	249.3	0.008
106066	2SM2	200.9	0.009
106066	M3	329.2	0.007
106066	L2	63.1	0.032
106066	2MK3	93.8	0.013
106066	K2	80.2	0.054
106066	M8	174.5	0.031
106066	MS4	333.1	0.024
106067	M2	17.6	1.201
106067	S2	61.6	0.182
106067	N2	337.4	0.245
106067	K1	116.2	0.083
106067	M4	347.1	0.167
106067	O1	105	0.044
106067	M6	219	0.068
106067	MK3	89.5	0.024
106067	S4	178.9	0.01
106067	MN4	297.1	0.08
106067	S6	283.8	0.016
106067	2N2	287	0.028
106067	OO1	353.6	0.004
106067	M1	117.9	0.004
106067	J1	165.6	0.005
106067	Q1	45.5	0.024
106067	2Q1	94.6	0.005
106067	2SM2	191.3	0.015
106067	M3	341.6	0.004
106067	L2	70.1	0.077
106067	2MK3	63.1	0.034
106067	K2	46.4	0.041
106067	M8	215.3	0.03
106067	MS4	38.8	0.037
106068	M2	27.1	0.43
106068	S2	84.3	0.106
106068	N2	11.2	0.107
106068	K1	100	0.042
106068	M4	270.8	0.04
106068	O1	53.1	0.011
106068	M6	197.1	0.064
106068	MK3	124.3	0.01
106068	S4	228.5	0.006
106068	MN4	109.5	0.009
106068	S6	165.5	0.002
106068	2N2	221.7	0.009
106068	OO1	218.5	0.008
106068	M1	53.6	0.005
106068	J1	42.2	0.008
106068	Q1	97.7	0.009
106068	2Q1	139.6	0.002
106068	P1	179.5	0.024
106068	2SM2	147.4	0.011
106068	M3	43.3	0.009
106068	L2	254.3	0.02
106068	2MK3	56.6	0.011
106068	K2	141.5	0.025
106068	M8	188.8	0.018
106068	MS4	204.3	0.009
106069	M2	41.4	0.705
106069	S2	91.8	0.153
106069	N2	16.3	0.152
106069	K1	109.4	0.064
106069	M4	309	0.07
106069	O1	76.5	0.021
106069	M6	176.3	0.035
106069	MK3	143.3	0.02
106069	S4	280.2	0.008
106069	MN4	243.7	0.014
106069	S6	289.5	0.005
106069	2N2	209.2	0.01
106069	OO1	166.5	0.005
106069	M1	92.3	0.007
106069	J1	88.7	0.002
106069	Q1	88.8	0.012
106069	2Q1	330.1	0.003
106069	P1	183	0.035
106069	2SM2	312.4	0.001
106069	M3	67.2	0.009
106069	L2	117.1	0.011
106069	2MK3	89.3	0.018
106069	K2	140.1	0.047
106069	M8	179.4	0.006
106069	MS4	322	0.005
106070	M2	51	0.794
106070	S2	106	0.104
106070	N2	18.5	0.164
106070	K1	125.3	0.05
106070	M4	195.4	0.06
106070	O1	153.3	0.026
106070	M6	159.7	0.03
106070	MK3	207.5	0.014
106070	S4	111.8	0.005
106070	MN4	117.3	0.007
106070	S6	266.1	0.009
106070	2N2	31.3	0.014
106070	OO1	260.3	0.009
106070	M1	79.6	0.002
106070	J1	42	0.007
106070	Q1	157.4	0.009
106070	2Q1	190.9	0.008
106070	2SM2	4.3	0.012
106070	M3	41.9	0.006
106070	L2	105.7	0.025
106070	2MK3	113.4	0.016
106070	K2	332.7	0.017
106070	M8	129.9	0.023
106070	MS4	182.8	0.007
106071	M2	43.6	0.195
106071	S2	90.6	0.042
106071	N2	18.8	0.056
106071	K1	144.2	0.012
106071	M4	315.9	0.023
106071	O1	56.9	0.004
106071	M6	198.7	0.067
106071	MK3	102.3	0.005
106071	S4	234.7	0.006
106071	MN4	69.5	0.005
106071	S6	55.5	0.003
106071	2N2	186.7	0.008
106071	OO1	183.5	0.003
106071	M1	80.6	0.004
106071	J1	55.5	0.001
106071	Q1	120.2	0.014
106071	2Q1	139.1	0.004
106071	2SM2	113.2	0.018
106071	M3	325.2	0.003
106071	L2	224.5	0.012
106071	2MK3	324.3	0.001
106071	M8	38.9	0.01
106071	MS4	189.9	0.003
106072	M2	40.3	0.422
106072	S2	88.6	0.057
106072	N2	356.8	0.065
106072	K1	105.6	0.011
106072	M4	306.9	0.039
106072	O1	144.3	0.009
106072	M6	106.2	0.01
106072	MK3	122.4	0.011
106072	S4	203.1	0.012
106072	MN4	238.5	0.016
106072	S6	34	0.003
106072	2N2	29.8	0.01
106072	OO1	202.2	0.007
106072	M1	2.7	0.001
106072	J1	8.8	0.009
106072	Q1	124.8	0.012
106072	2Q1	154	0.006
106072	2SM2	77.7	0.004
106072	M3	64.4	0.008
106072	L2	107.8	0.02
106072	2MK3	161.4	0.012
106072	M8	287.2	0.007
106072	MS4	6.3	0.015
106073	M2	48.1	0.5
106073	S2	112	0.073
106073	N2	23.1	0.09
106073	K1	172.3	0.024
106073	M4	221.1	0.038
106073	O1	126.3	0.021
106073	M6	358	0.002
106073	MK3	140.2	0.024
106073	S4	30.2	0.005
106073	MN4	270.7	0.018
106073	S6	54.3	0.005
106073	2N2	19.2	0.006
106073	OO1	80.2	0.003
106073	M1	50.6	0.005
106073	J1	277.8	0.004
106073	Q1	41.6	0.006
106073	2Q1	212.3	0.001
106073	2SM2	353.8	0.003
106073	M3	323.8	0.006
106073	L2	120.4	0.009
106073	2MK3	316.9	0.005
106073	M8	169.4	0.016
106073	MS4	338.7	0.021
106074	M2	49.6	0.335
106074	S2	108.4	0.026
106074	N2	24.2	0.063
106074	K1	169.4	0.059
106074	M4	280.4	0.047
106074	O1	156.4	0.018
106074	M6	161.2	0.017
106074	MK3	229.2	0.001
106074	S4	121.4	0.001
106074	MN4	260	0.031
106074	S6	169.4	0.003
106074	2N2	272.5	0.016
106074	OO1	273.2	0.01
106074	M1	138.6	0.005
106074	J1	119.7	0.002
106074	Q1	167.9	0.018
106074	2Q1	170	0.013
106074	P1	302.6	0.045
106074	2SM2	11	0.004
106074	M3	228.4	0.002
106074	L2	89.7	0.012
106074	2MK3	262.2	0.009
106074	M8	119	0.019
106074	MS4	343.2	0.022
106075	M2	47	0.429
106075	S2	103.4	0.054
106075	N2	13.3	0.082
106075	K1	133.4	0.062
106075	M4	274.3	0.063
106075	O1	141.5	0.013
106075	M6	228.4	0.023
106075	MK3	152.5	0.007
106075	S4	278.2	0.002
106075	MN4	242.9	0.019
106075	S6	128.9	0.002
106075	2N2	35.4	0.009
106075	OO1	288.7	0.011
106075	M1	112.7	0.003
106075	J1	136.1	0.003
106075	Q1	166.3	0.008
106075	2Q1	155.7	0.01
106075	P1	254.6	0.037
106075	2SM2	20.7	0.01
106075	M3	325.9	0.002
106075	L2	113.8	0.022
106075	2MK3	282.2	0.009
106075	M8	117.4	0.014
106075	MS4	337.5	0.014
106076	M2	40.7	0.484
106076	S2	95.4	0.07
106076	N2	4.7	0.09
106076	K1	89.7	0.036
106076	M4	282.8	0.03
106076	O1	122.5	0.008
106076	M6	262.8	0.025
106076	MK3	125.5	0.008
106076	S4	287	0.005
106076	MN4	356.9	0.003
106076	S6	222.1	0.001
106076	2N2	48.6	0.022
106076	OO1	306.9	0.003
106076	M1	335.5	0.003
106076	J1	53.3	0.003
106076	Q1	352.2	0.008
106076	2Q1	81	0.002
106076	P1	178.2	0.021
106076	2SM2	42.8	0.007
106076	M3	38.4	0.004
106076	L2	103	0.018
106076	2MK3	41.4	0.008
106076	M8	83.4	0.006
106076	MS4	150.1	0.007
106077	M2	23.1	0.271
106077	S2	97.6	0.032
106077	N2	358.1	0.05
106077	K1	108.2	0.013
106077	M4	305.5	0.046
106077	O1	333.1	0.011
106077	M6	198.9	0.011
106077	MK3	72.9	0.006
106077	S4	347.3	0.004
106077	MN4	279.6	0.023
106077	S6	115.2	0.001
106077	2N2	255.9	0.009
106077	OO1	249.8	0.008
106077	M1	113.8	0.003
106077	J1	120.5	0.006
106077	Q1	179.9	0.012
106077	2Q1	170.9	0.01
106077	2SM2	30.3	0.008
106077	M3	10.6	0.005
106077	L2	8.7	0.013
106077	2MK3	70.1	0.01
106077	K2	255.9	0.012
106077	M8	81.8	0.003
106077	MS4	2.7	0.011
106078	M2	36.1	0.349
106078	S2	89.5	0.038
106078	N2	2.5	0.07
106078	K1	106.1	0.027
106078	M4	335.9	0.02
106078	O1	52.5	0.009
106078	M6	174.5	0.015
106078	MK3	112.8	0.009
106078	S4	10.2	0.003
106078	MN4	333.9	0.013
106078	S6	111	0.001
106078	2N2	77.5	0.009
106078	OO1	272.4	0.011
106078	M1	127	0.004
106078	J1	128.4	0.007
106078	Q1	174.2	0.009
106078	2Q1	161.1	0.006
106078	2SM2	35.2	0.011
106078	M3	269.7	0.006
106078	L2	78.8	0.009
106078	2MK3	88	0.008
106078	K2	352.3	0.008
106078	M8	104.3	0.012
106078	MS4	52.9	0.01
106079	M2	41.8	0.348
106079	S2	114.9	0.053
106079	N2	14	0.062
106079	K1	152.9	0.019
106079	M4	317.7	0.007
106079	O1	125.9	0.03
106079	M6	178.6	0.024
106079	MK3	252.8	0.007
106079	S4	101	0.003
106079	MN4	330.1	0.01
106079	S6	172.9	0.005
106079	2N2	18.4	0.022
106079	OO1	123.3	0.005
106079	M1	126.7	0.005
106079	J1	278	0.005
106079	Q1	65.9	0.009
106079	2Q1	343.7	0.006
106079	2SM2	111	0.006
106079	M3	81.3	0.004
106079	L2	83	0.017
106079	2MK3	187.7	0.007
106079	K2	234.8	0.028
106079	M8	126.5	0.011
106079	MS4	17	0.006
106080	M2	19.9	0.104
106080	S2	147.2	0.026
106080	N2	5.4	0.018
106080	K1	89.6	0.01
106080	M4	27.4	0.029
106080	O1	214.7	0.002
106080	M6	305.4	0.006
106080	MK3	79.8	0.005
106080	S4	326.8	0.006
106080	MN4	354.6	0.006
106080	2N2	51.6	0.022
106080	OO1	245	0.011
106080	M1	129.7	0.005
106080	J1	166.5	0.019
106080	Q1	228.7	0.015
106080	2Q1	196.5	0.013
106080	2SM2	287.3	0.009
106080	M3	32.6	0.005
106080	L2	69.1	0.006
106080	2MK3	159	0.003
106080	M8	256.1	0.003
106080	MS4	203.8	0.007
106081	M2	39.8	0.162
106081	S2	58.9	0.024
106081	N2	10.8	0.045
106081	K1	81.2	0.021
106081	M4	143.5	0.018
106081	O1	69.3	0.016
106081	M6	158.6	0.027
106081	MK3	122	0.006
106081	S4	160.5	0.003
106081	MN4	84.7	0.011
106081	S6	321.4	0.003
106081	2N2	268.3	0.006
106081	OO1	93.5	0.003
106081	M1	316.7	0.007
106081	J1	37.4	0.002
106081	Q1	104.1	0.002
106081	2Q1	3.3	0.009
106081	2SM2	133.6	0.005
106081	M3	224.7	0.009
106081	L2	173.5	0.007
106081	2MK3	90.2	0.006
106081	M8	153.2	0.006
106081	MS4	118.2	0.013
106082	M2	33.2	0.214
106082	S2	75.5	0.033
106082	N2	8.4	0.037
106082	K1	119.2	0.013
106082	M4	245.1	0.03
106082	O1	201.2	0.009
106082	M6	204.9	0.02
106082	MK3	217.9	0.006
106082	S4	247.2	0.004
106082	MN4	225.6	0.013
106082	S6	277.3	0.005
106082	2N2	262	0.004
106082	OO1	65.9	0.005
106082	M1	99.7	0.002
106082	J1	286.5	0.006
106082	Q1	323.6	0.002
106082	2Q1	154.6	0.003
106082	2SM2	89.5	0.007
106082	M3	100.2	0.01
106082	L2	12.7	0.015
106082	2MK3	193.3	0.007
106082	M8	73.5	0.007
106082	MS4	274.3	0.008
106083	M2	31	0.455
106083	S2	69.3	0.113
106083	N2	354.6	0.07
106083	K1	148.8	0.019
106083	M4	127	0.046
106083	O1	195.1	0.002
106083	M6	353.2	0.034
106083	MK3	161.9	0.016
106083	S4	59.2	0.006
106083	MN4	94.5	0.03
106083	S6	83.1	0.009
106083	2N2	7.1	0.018
106083	OO1	24	0.003
106083	M1	53.6	0.005
106083	J1	102.3	0.005
106083	Q1	172.9	0.005
106083	2Q1	246.7	0.004
106083	2SM2	33.3	0.003
106083	M3	78.2	0.007
106083	L2	96	0.038
106083	2MK3	138	0.019
106083	K2	129.8	0.059
106083	M8	320.5	0.028
106083	MS4	202.1	0.016
106084	M2	25.9	0.49
106084	S2	71.8	0.084
106084	N2	351.9	0.077
106084	K1	149.1	0.024
106084	M4	272.1	0.021
106084	O1	155.4	0.012
106084	M6	46.8	0.007
106084	MK3	191.5	0.006
106084	S4	44.9	0.003
106084	MN4	190.9	0.003
106084	S6	70.2	0.007
106084	2N2	13.6	0.016
106084	OO1	175.9	0.002
106084	M1	144.8	0.002
106084	J1	163	0.004
106084	Q1	135.7	0.006
106084	2Q1	13.4	0.001
106084	2SM2	235	0.003
106084	M3	189.6	0.003
106084	L2	81.7	0.031
106084	2MK3	152.2	0.006
106084	K2	136.2	0.022
106084	M8	283.2	0.033
106084	MS4	254.5	0.018
106085	M2	23.9	0.456
106085	S2	64.4	0.058
106085	N2	357.5	0.081
106085	K1	97.5	0.021
106085	M4	300	0.037
106085	O1	141.5	0.019
106085	M6	139.5	0.03
106085	MK3	191.4	0.008
106085	S4	322.2	0.001
106085	MN4	263.6	0.018
106085	S6	321.6	0.001
106085	2N2	349.7	0.009
106085	OO1	194.7	0.004
106085	M1	228.8	0.005
106085	J1	120.8	0.003
106085	Q1	155.7	0.006
106085	2Q1	65.3	0.005
106085	2SM2	206.3	0.013
106085	M3	242.8	0.012
106085	L2	51.8	0.017
106085	2MK3	136.5	0.001
106085	K2	18.6	0.015
106085	M8	317.6	0.026
106085	MS4	296.8	0.011
106086	M2	39.8	0.557
106086	S2	94	0.087
106086	N2	5.6	0.11
106086	K1	142.4	0.032
106086	M4	279.6	0.215
106086	O1	33	0.002
106086	M6	137.9	0.059
106086	MK3	48.9	0.014
106086	S4	36.8	0.006
106086	MN4	240.9	0.079
106086	S6	137	0.006
106086	2N2	35.7	0.009
106086	OO1	285.2	0.003
106086	M1	67	0.003
106086	J1	126	0.006
106086	Q1	102.8	0.007
106086	2Q1	219.9	0.002
106086	P1	199.8	0.016
106086	2SM2	316.1	0.007
106086	M3	157.4	0.003
106086	L2	103.8	0.023
106086	2MK3	106.3	0.011
106086	K2	213.1	0.012
106086	M8	90.7	0.007
106086	MS4	313.3	0.058
106087	M2	41.6	0.677
106087	S2	95.7	0.105
106087	N2	11.4	0.128
106087	K1	153.3	0.055
106087	M4	283.4	0.194
106087	O1	115.2	0.017
106087	M6	124.3	0.023
106087	MK3	49.3	0.02
106087	S4	26.8	0.011
106087	MN4	255.1	0.079
106087	S6	104.2	0.006
106087	2N2	354.9	0.012
106087	OO1	31.1	0.004
106087	M1	144.2	0.002
106087	J1	137.2	0.01
106087	Q1	117.8	0.007
106087	2Q1	122.1	0.003
106087	P1	271.9	0.012
106087	2SM2	195.6	0.008
106087	M3	252.5	0.011
106087	L2	102.1	0.025
106087	2MK3	37.4	0.017
106087	K2	195.1	0.023
106087	M8	219.5	0.018
106087	MS4	328.2	0.049
106088	M2	37.3	0.575
106088	S2	79.6	0.129
106088	N2	18.3	0.119
106088	K1	135.1	0.052
106088	M4	297.4	0.139
106088	O1	96.3	0.042
106088	M6	309	0.021
106088	MK3	54.6	0.024
106088	S4	14.6	0.008
106088	MN4	261.9	0.069
106088	S6	61.3	0.006
106088	2N2	298.8	0.013
106088	OO1	327.9	0.007
106088	M1	98.5	0.004
106088	J1	53.6	0.007
106088	Q1	100.4	0.016
106088	2Q1	241.6	0.014
106088	P1	315.7	0.013
106088	2SM2	129.7	0.014
106088	M3	279.7	0.025
106088	L2	344.4	0.012
106088	2MK3	1.4	0.019
106088	K2	121	0.045
106088	M8	257.6	0.035
106088	MS4	315.1	0.031
106089	M2	29.8	1.002
106089	S2	73.4	0.185
106089	N2	4.8	0.248
106089	K1	134.8	0.077
106089	M4	303.7	0.179
106089	O1	91.1	0.041
106089	M6	155.8	0.081
106089	MK3	72.6	0.023
106089	S4	186.4	0.04
106089	MN4	275.8	0.088
106089	S6	341.1	0.001
106089	2N2	181.4	0.046
106089	OO1	245.4	0.008
106089	M1	117.4	0.004
106089	J1	59.5	0.023
106089	Q1	142.2	0.016
106089	2Q1	352.2	0.01
106089	2SM2	263.3	0.027
106089	M3	5.8	0.009
106089	L2	234.9	0.051
106089	2MK3	12	0.018
106089	M8	178.2	0.02
106089	MS4	351	0.071
106090	M2	29.4	1.347
106090	S2	79.5	0.19
106090	N2	1.4	0.284
106090	K1	123.4	0.092
106090	M4	313.3	0.175
106090	O1	94.6	0.057
106090	M6	191	0.073
106090	MK3	121.3	0.032
106090	S4	195.8	0.022
106090	MN4	324.7	0.054
106090	S6	192.8	0.005
106090	2N2	296.1	0.007
106090	OO1	306.9	0.004
106090	M1	49.5	0.003
106090	J1	83.1	0.021
106090	Q1	102.2	0.012
106090	2Q1	103.1	0.003
106090	2SM2	275.7	0.011
106090	M3	6.3	0.021
106090	L2	135.1	0.005
106090	2MK3	77.5	0.022
106090	M8	141.3	0.064
106090	MS4	32.7	0.055
106091	M2	29.3	1.527
106091	S2	85.1	0.194
106091	N2	359.6	0.289
106091	K1	106.8	0.082
106091	M4	330	0.055
106091	O1	104.5	0.048
106091	M6	225.6	0.118
106091	MK3	175.6	0.034
106091	S4	137.7	0.006
106091	MN4	296.5	0.038
106091	S6	155.2	0.014
106091	2N2	343.4	0.027
106091	OO1	261.9	0.006
106091	M1	103.6	0.002
106091	J1	88	0.026
106091	Q1	99.9	0.02
106091	2Q1	67.5	0.008
106091	2SM2	66	0.016
106091	M3	30.2	0.018
106091	L2	52.7	0.039
106091	2MK3	116	0.035
106091	M8	122.9	0.058
106091	MS4	19.5	0.031
106092	M2	11.9	2.023
106092	S2	64.2	0.333
106092	N2	350.8	0.379
106092	K1	96.6	0.119
106092	M4	284.8	0.254
106092	O1	86.5	0.083
106092	M6	197.2	0.275
106092	MK3	83.4	0.039
106092	S4	151.2	0.012
106092	MN4	278.6	0.094
106092	S6	174	0.009
106092	2N2	284.8	0.039
106092	OO1	99.4	0.004
106092	M1	167	0.006
106092	J1	90.1	0.011
106092	Q1	124.8	0.015
106092	2Q1	54	0.002
106092	P1	141.6	0.051
106092	2SM2	237.7	0.002
106092	M3	324	0.013
106092	L2	41.4	0.065
106092	2MK3	50	0.044
106092	K2	107	0.075
106092	M8	100.9	0.102
106092	MS4	352.2	0.079
106093	M2	11	2.218
106093	S2	63.8	0.335
106093	N2	349.9	0.397
106093	K1	100.6	0.129
106093	M4	287.2	0.27
106093	O1	87.4	0.089
106093	M6	196.9	0.316
106093	MK3	75.5	0.045
106093	S4	136.9	0.011
106093	MN4	279.1	0.095
106093	S6	172.1	0.01
106093	2N2	280.7	0.054
106093	M1	121.7	0.005
106093	J1	120.6	0.004
106093	Q1	105.6	0.014
106093	P1	146.3	0.049
106093	2SM2	40.4	0.003
106093	M3	335.6	0.01
106093	L2	23.4	0.089
106093	2MK3	50.1	0.041
106093	K2	97.4	0.06
106093	M8	105.9	0.097
106093	MS4	350.6	0.077
106094	M2	9.8	2.21
106094	S2	67.2	0.319
106094	N2	349.4	0.397
106094	K1	99.6	0.145
106094	M4	298.9	0.268
106094	O1	87.5	0.086
106094	M6	191.2	0.303
106094	MK3	80.4	0.041
106094	S4	103.8	0.006
106094	MN4	285.7	0.089
106094	S6	189.5	0.006
106094	2N2	280	0.055
106094	OO1	238.1	0.009
106094	M1	53.1	0.006
106094	Q1	85.9	0.016
106094	2Q1	206.6	0.003
106094	P1	169.9	0.056
106094	2SM2	251.5	0.006
106094	M3	359.4	0.009
106094	L2	9.9	0.091
106094	2MK3	44.9	0.043
106094	K2	115.6	0.045
106094	M8	123.8	0.083
106094	MS4	4.9	0.063
106095	M2	249.6	0.444
106095	S2	298.5	0.071
106095	N2	209.4	0.075
106095	K1	312.9	0.04
106095	M4	272.6	0.074
106095	O1	317.7	0.02
106095	M6	168	0.024
106095	MK3	2.5	0.037
106095	S4	255.9	0.007
106095	MN4	221	0.034
106095	S6	118.2	0.001
106095	2N2	218	0.034
106095	OO1	228.9	0.011
106095	M1	54.9	0.006
106095	J1	329.2	0.005
106095	Q1	70.2	0.005
106095	2Q1	340.2	0.011
106095	2SM2	240.3	0.002
106095	M3	289.6	0.008
106095	L2	298.1	0.032
106095	2MK3	283.2	0.006
106095	K2	49.2	0.023
106095	M8	46.7	0.01
106095	MS4	310.7	0.026
106096	M2	253.9	0.376
106096	S2	305.4	0.051
106096	N2	205.5	0.06
106096	K1	297.5	0.027
106096	M4	268.6	0.094
106096	O1	5.5	0.007
106096	M6	209	0.056
106096	MK3	6.4	0.04
106096	S4	270.3	0.008
106096	MN4	217.6	0.042
106096	S6	1.4	0.001
106096	2N2	204.5	0.031
106096	OO1	193	0.009
106096	M1	81.8	0.003
106096	J1	295.4	0.009
106096	Q1	68.2	0.008
106096	2Q1	292.1	0.011
106096	2SM2	251.6	0.003
106096	M3	294.1	0.013
106096	L2	303.2	0.031
106096	2MK3	351.2	0.015
106096	K2	56.2	0.024
106096	M8	126.9	0.02
106096	MS4	300.5	0.031
106097	M2	249.4	0.276
106097	S2	284.7	0.037
106097	N2	194.3	0.05
106097	K1	284.1	0.019
106097	M4	280.1	0.085
106097	O1	110.9	0.012
106097	M6	216.4	0.087
106097	MK3	15.1	0.024
106097	S4	37.5	0.001
106097	MN4	228.2	0.033
106097	S6	148.6	0.001
106097	2N2	178.5	0.027
106097	OO1	198.6	0.009
106097	M1	103.3	0.002
106097	J1	333.6	0.007
106097	Q1	102.2	0.01
106097	2Q1	269.7	0.014
106097	2SM2	263.2	0.007
106097	M3	286.2	0.016
106097	L2	309.5	0.026
106097	2MK3	0.5	0.021
106097	K2	45.6	0.018
106097	M8	148.1	0.027
106097	MS4	301.4	0.026
106098	M2	14.6	0.404
106098	S2	97.7	0.083
106098	K1	229.5	0.004
106098	M4	269.2	0.057
106098	O1	158.1	0.019
106098	M6	187.2	0.055
106098	MK3	100.5	0.013
106098	S4	65.9	0.011
106098	S6	15.3	0.005
106098	2N2	121.3	0.029
106098	OO1	208.3	0.011
106098	Q1	97.9	0.026
106098	2SM2	304.4	0.028
106098	2MK3	357.6	0.011
106098	M8	55.5	0.036
106098	MS4	334.9	0.03
106099	M2	30.4	0.451
106099	S2	84.8	0.083
106099	K1	168.2	0.02
106099	M4	301.5	0.091
106099	O1	168.1	0.016
106099	M6	217.6	0.066
106099	MK3	84.5	0.008
106099	S4	51.3	0.003
106099	S6	213.5	0.001
106099	2N2	78.1	0.055
106099	OO1	223.6	0.01
106099	Q1	118.3	0.024
106099	2SM2	256.8	0.007
106099	2MK3	105.1	0.005
106099	M8	98.7	0.022
106099	MS4	4.9	0.02
106100	M2	29.4	0.446
106100	S2	85.8	0.085
106100	K1	143.1	0.02
106100	M4	307	0.061
106100	O1	127.9	0.014
106100	M6	196.5	0.037
106100	MK3	186	0.008
106100	S4	116.5	0.005
106100	S6	19.7	0.004
106100	2N2	66.5	0.061
106100	OO1	193.1	0.004
106100	Q1	340.1	0.002
106100	2SM2	231.5	0.012
106100	2MK3	97.7	0.012
106100	M8	171.9	0.006
106100	MS4	20	0.015
106101	M2	26.1	0.531
106101	S2	86.9	0.074
106101	N2	9.7	0.096
106101	K1	157	0.036
106101	M4	341.7	0.069
106101	O1	84.1	0.031
106101	M6	196.9	0.048
106101	MK3	143.6	0.002
106101	S4	11.2	0.003
106101	MN4	295.2	0.024
106101	S6	89.7	0.003
106101	2N2	195.2	0.016
106101	OO1	131.3	0.01
106101	M1	107.4	0.007
106101	J1	324.7	0.005
106101	Q1	116.7	0.021
106101	2Q1	328.7	0.003
106101	2SM2	316	0.006
106101	M3	0.6	0.003
106101	L2	320.8	0.029
106101	2MK3	93.9	0.01
106101	M8	113.8	0.009
106101	MS4	27.4	0.018
106102	M2	31.3	0.603
106102	S2	86.4	0.075
106102	N2	6.3	0.101
106102	K1	136.8	0.036
106102	M4	354.4	0.04
106102	O1	92.1	0.025
106102	M6	220.6	0.012
106102	MK3	165.9	0.009
106102	S4	153.4	0.003
106102	MN4	342.6	0.009
106102	S6	74	0.005
106102	2N2	310.6	0.008
106102	OO1	185.5	0.006
106102	M1	66.1	0.007
106102	J1	293.2	0.006
106102	Q1	98.3	0.014
106102	2Q1	41.4	0.002
106102	2SM2	96.3	0.006
106102	M3	30.6	0.006
106102	L2	60.2	0.023
106102	2MK3	126.9	0.008
106102	M8	180.7	0.001
106102	MS4	58.3	0.013
106103	M2	33.4	0.539
106103	S2	88.7	0.07
106103	N2	9.6	0.112
106103	K1	133	0.03
106103	M4	264.1	0.014
106103	O1	130.7	0.014
106103	M6	268.2	0.014
106103	MK3	158.5	0.016
106103	S4	94.4	0.004
106103	MN4	40	0.025
106103	S6	234.8	0.003
106103	2N2	339.9	0.02
106103	OO1	283.5	0.005
106103	M1	1.7	0.005
106103	J1	116.7	0.01
106103	Q1	248.7	0.002
106103	2Q1	44.3	0.006
106103	2SM2	134.3	0.004
106103	M3	111.5	0.007
106103	L2	110.6	0.043
106103	2MK3	128.2	0.007
106103	M8	84.9	0.011
106103	MS4	54.3	0.012
106104	M2	20.2	0.946
106104	S2	81.5	0.122
106104	K1	131.5	0.073
106104	M4	335.2	0.173
106104	O1	98.2	0.06
106104	M6	216.7	0.114
106104	MK3	76.5	0.045
106104	S4	54	0.01
106104	S6	144.7	0.013
106104	2N2	334.3	0.041
106104	OO1	184.5	0.011
106104	2Q1	99.6	0.005
106104	2SM2	323.8	0.006
106104	2MK3	62	0.03
106104	M8	117.3	0.024
106104	MS4	49	0.034
106105	M2	25.3	1.264
106105	S2	86	0.178
106105	K1	128.3	0.092
106105	M4	314.1	0.19
106105	O1	95.7	0.066
106105	M6	213.5	0.072
106105	MK3	84.4	0.028
106105	S4	202.3	0.005
106105	S6	111.8	0.003
106105	2N2	338.9	0.064
106105	OO1	189	0.008
106105	2Q1	304.4	0.011
106105	2SM2	300.2	0.016
106105	2MK3	112.8	0.016
106105	M8	128.5	0.012
106105	MS4	20.3	0.044
106106	M2	27.2	1.365
106106	S2	90	0.198
106106	K1	126.1	0.102
106106	M4	292	0.198
106106	O1	84.7	0.063
106106	M6	120.4	0.032
106106	MK3	219.5	0.021
106106	S4	175.7	0.021
106106	S6	298.7	0.008
106106	2N2	332.5	0.083
106106	OO1	145.4	0.003
106106	2Q1	289.1	0.017
106106	2SM2	318.2	0.028
106106	2MK3	166.6	0.036
106106	M8	288.6	0.032
106106	MS4	337.5	0.06
106107	M2	4.3	0.232
106107	S2	33.6	0.02
106107	N2	286.3	0.043
106107	K1	80.3	0.021
106107	M4	281	0.012
106107	O1	41.4	0.017
106107	M6	208.6	0.004
106107	MK3	114.5	0.004
106107	S4	198.1	0.004
106107	MN4	196.9	0.004
106107	S6	186	0.001
106107	2N2	14.6	0.017
106107	OO1	86.3	0.008
106107	M1	126.6	0.005
106107	J1	39.1	0.006
106107	Q1	150.1	0.006
106107	2Q1	273.5	0.004
106107	2SM2	217.8	0.008
106107	M3	109.7	0.003
106107	L2	219.6	0.021
106107	2MK3	319.7	0.002
106107	M8	343	0.001
106107	MS4	79.4	0.004
106108	M2	14	0.216
106108	S2	89.3	0.02
106108	N2	322.7	0.042
106108	K1	130.5	0.013
106108	M4	207.2	0.008
106108	O1	60.6	0.017
106108	M6	175.5	0.003
106108	MK3	167.5	0.003
106108	S4	117.1	0.003
106108	MN4	197.9	0.007
106108	S6	309.8	0.003
106108	2N2	13.3	0.012
106108	OO1	265.7	0.008
106108	M1	174	0.002
106108	J1	65.9	0.003
106108	Q1	181.7	0.007
106108	2Q1	292.3	0.004
106108	2SM2	262.5	0.002
106108	M3	234.2	0.003
106108	L2	322.1	0.016
106108	2MK3	97.9	0.006
106108	M8	102.3	0.004
106108	MS4	298.5	0.006
106109	M2	282.2	0.254
106109	S2	6.5	0.026
106109	N2	188.7	0.077
106109	K1	331.5	0.027
106109	M4	247.1	0.009
106109	O1	46.2	0.019
106109	M6	20.8	0.017
106109	MK3	66.4	0.024
106109	S4	117.1	0.012
106109	MN4	106.2	0.019
106109	S6	78.6	0.004
106109	2N2	236.2	0.034
106109	OO1	191.7	0.005
106109	M1	220.8	0.018
106109	J1	220.2	0.012
106109	Q1	37	0.019
106109	2Q1	341	0.007
106109	2SM2	235.1	0.001
106109	M3	328.7	0.001
106109	L2	151.7	0.089
106109	2MK3	323.9	0.012
106109	M8	109.4	0.005
106109	MS4	54.6	0.011
106110	M2	4.6	0.458
106110	S2	28.7	0.057
106110	N2	314.9	0.074
106110	K1	185.2	0.024
106110	M4	246.1	0.047
106110	O1	88	0.009
106110	M6	227.2	0.026
106110	MK3	337.3	0.008
106110	S4	267.8	0.007
106110	MN4	278.2	0.015
106110	S6	313	0.005
106110	2N2	184.2	0.008
106110	OO1	183.5	0.01
106110	M1	247.5	0.009
106110	J1	166.4	0.008
106110	Q1	223.9	0.009
106110	2Q1	21.3	0.005
106110	P1	112.2	0.012
106110	2SM2	34.3	0.008
106110	M3	214	0.004
106110	L2	60.7	0.044
106110	2MK3	152.6	0.007
106110	M8	102.5	0.006
106110	MS4	274.9	0.012
106111	M2	19.9	0.85
106111	S2	33.2	0.113
106111	N2	330.8	0.166
106111	K1	179.1	0.092
106111	M4	244.1	0.011
106111	O1	80.6	0.056
106111	M6	262.8	0.017
106111	MK3	205.6	0.015
106111	S4	268.6	0.013
106111	MN4	223.2	0.017
106111	S6	148.3	0.006
106111	2N2	17.4	0.028
106111	OO1	204.2	0.043
106111	M1	241.2	0.027
106111	J1	118.2	0.03
106111	Q1	135.5	0.013
106111	2Q1	112.2	0.022
106111	P1	83.6	0.06
106111	2SM2	324	0.026
106111	M3	148.1	0.012
106111	L2	73.3	0.102
106111	2MK3	164.7	0.016
106111	M8	55.4	0.018
106111	MS4	116.7	0.007
106112	M2	5.3	0.766
106112	S2	61.6	0.073
106112	N2	331.1	0.18
106112	K1	48.5	0.131
106112	M4	293	0.05
106112	O1	175.1	0.023
106112	M6	160.2	0.065
106112	MK3	157.5	0.005
106112	S4	52.3	0.01
106112	MN4	54.5	0.008
106112	S6	136.5	0.005
106112	2N2	285	0.046
106112	OO1	16.2	0.069
106112	M1	91.1	0.045
106112	J1	350	0.038
106112	Q1	45.4	0.027
106112	2Q1	255.6	0.033
106112	P1	7.1	0.022
106112	2SM2	346.9	0.017
106112	M3	17.6	0.021
106112	L2	205.2	0.013
106112	2MK3	92.6	0.008
106112	M8	289.1	0.016
106112	MS4	319.8	0.013
106113	M2	7.1	0.561
106113	S2	40.7	0.08
106113	N2	325.8	0.124
106113	K1	89.2	0.054
106113	M4	207	0.052
106113	O1	66.6	0.028
106113	M6	210	0.014
106113	MK3	88.5	0.006
106113	S4	282	0.005
106113	MN4	149.3	0.022
106113	S6	183.1	0.005
106113	2N2	325	0.03
106113	OO1	224.2	0.002
106113	M1	333.3	0.003
106113	J1	189.7	0.004
106113	Q1	324.9	0.007
106113	2Q1	319.8	0.003
106113	P1	265.7	0.019
106113	2SM2	49.3	0.015
106113	M3	342.4	0.003
106113	L2	63.4	0.032
106113	2MK3	184.9	0.014
106113	M8	0.9	0.005
106113	MS4	273.3	0.014
106114	M2	12.9	0.545
106114	S2	53.1	0.073
106114	N2	329.9	0.121
106114	K1	125.8	0.043
106114	M4	167.1	0.029
106114	O1	82.4	0.023
106114	M6	61	0.006
106114	MK3	79	0.005
106114	S4	125.7	0.004
106114	MN4	41.3	0.01
106114	S6	7.2	0.004
106114	2N2	315.7	0.028
106114	OO1	237	0.015
106114	M1	290.4	0.004
106114	J1	273.5	0.007
106114	Q1	238.2	0.016
106114	2Q1	311	0.007
106114	P1	23.5	0.021
106114	2SM2	14	0.005
106114	M3	94.8	0.006
106114	L2	51.3	0.04
106114	2MK3	110.1	0.013
106114	M8	262.1	0.004
106114	MS4	55.3	0.001
106115	M2	30.1	0.429
106115	S2	162.4	0.03
106115	N2	6.1	0.049
106115	K1	32.6	0.068
106115	M4	9.7	0.08
106115	O1	339.7	0.015
106115	M6	232.8	0.025
106115	MK3	264.1	0.005
106115	S4	39.9	0.01
106115	MN4	313.6	0.027
106115	S6	24.8	0.001
106115	2N2	144	0.023
106115	OO1	95.8	0.026
106115	M1	79.7	0.007
106115	J1	119.8	0.007
106115	Q1	107	0.025
106115	2Q1	0.4	0.004
106115	P1	216.1	0.042
106115	2SM2	251.4	0.012
106115	M3	189.3	0.013
106115	L2	159.6	0.022
106115	2MK3	332.2	0.013
106115	M8	168.3	0.01
106115	MS4	86.2	0.024
106116	M2	40.1	0.426
106116	S2	93.3	0.078
106116	K1	152.1	0.072
106116	M4	281.5	0.049
106116	O1	107	0.051
106116	M6	174.4	0.049
106116	MK3	13.7	0.023
106116	S4	72.7	0.01
106116	S6	245.6	0.004
106116	2N2	355	0.054
106116	OO1	214.8	0.008
106116	2Q1	105.7	0.017
106116	2SM2	216.1	0.019
106116	2MK3	242.4	0.004
106116	M8	123.5	0.009
106116	MS4	314.9	0.024
106117	M2	26.7	0.386
106117	S2	13.3	0.023
106117	K1	160	0.081
106117	M4	180.8	0.046
106117	O1	122.2	0.027
106117	M6	249.1	0.008
106117	MK3	151.4	0.015
106117	S4	303	0.016
106117	S6	64.4	0.006
106117	2N2	350.9	0.044
106117	OO1	237.3	0.018
106117	2Q1	192.3	0.035
106117	2SM2	103.5	0.041
106117	2MK3	175.7	0.003
106117	M8	288.3	0.003
106117	MS4	201.1	0.006
106118	M2	17.6	0.265
106118	S2	10.3	0.068
106118	K1	346.6	0.063
106118	M4	318	0.026
106118	O1	297.6	0.044
106118	M6	178.6	0.014
106118	MK3	137.7	0.006
106118	S4	210.9	0.014
106118	S6	287.3	0.009
106118	2N2	56.1	0.01
106118	OO1	25.5	0.036
106118	2Q1	211.7	0.013
106118	2SM2	126.6	0.022
106118	2MK3	190.7	0.007
106118	M8	315.1	0.014
106118	MS4	205.4	0.008
106119	M2	356	0.231
106119	S2	15.4	0.014
106119	K1	60.7	0.035
106119	M4	128.6	0.008
106119	O1	37.2	0.034
106119	M6	172.4	0.009
106119	MK3	137.9	0.006
106119	S4	74.1	0.005
106119	S6	160.6	0.002
106119	2N2	326.4	0.018
106119	OO1	196	0.002
106119	2Q1	282.9	0.005
106119	2SM2	286.9	0.011
106119	2MK3	109.1	0.005
106119	M8	237.9	0.002
106119	MS4	98.3	0.004
106120	M2	10.8	0.175
106120	S2	285.8	0.018
106120	K1	162.8	0.006
106120	M4	296	0.02
106120	O1	131.1	0.011
106120	M6	299.9	0.008
106120	MK3	203.6	0.002
106120	S6	54.2	0.005
106120	2N2	111.1	0.002
106120	OO1	328.1	0.007
106120	2Q1	290.3	0.008
106120	2SM2	295.3	0.017
106120	2MK3	358.2	0.004
106120	M8	290.4	0.003
106120	MS4	308.7	0.01
106121	M2	237.3	0.234
106121	S2	232.6	0.036
106121	K1	287.2	0.038
106121	M4	175.8	0.016
106121	O1	285.9	0.018
106121	M6	53.7	0.021
106121	MK3	49.2	0.008
106121	S4	35.8	0.006
106121	S6	295.3	0.004
106121	2N2	216.6	0.031
106121	OO1	176.3	0.017
106121	2Q1	28.6	0.009
106121	2SM2	224.2	0.028
106121	2MK3	1.3	0.013
106121	M8	40.4	0.005
106121	MS4	18.1	0.005
106122	M2	354.4	0.286
106122	S2	25.9	0.04
106122	N2	306.2	0.055
106122	K1	70.9	0.015
106122	M4	290.9	0.015
106122	O1	318.1	0.006
106122	M6	151.2	0.005
106122	MK3	216.8	0.006
106122	S4	242.1	0.003
106122	MN4	234.9	0.009
106122	S6	37.2	0.002
106122	2N2	195.4	0.01
106122	OO1	56.2	0.004
106122	M1	307.1	0.001
106122	J1	157.3	0.009
106122	Q1	239.8	0.006
106122	2SM2	310.6	0.006
106122	M3	282.5	0.002
106122	L2	96.8	0.029
106122	2MK3	147.6	0.003
106122	M8	327.9	0.002
106122	MS4	281.6	0.004
106123	M2	18.3	0.206
106123	S2	78.9	0.037
106123	N2	309.5	0.045
106123	K1	160.1	0.005
106123	M4	137.5	0.016
106123	O1	101.2	0.007
106123	M6	179.3	0.003
106123	MK3	136.9	0.006
106123	S4	208.4	0.004
106123	MN4	80.4	0.009
106123	S6	237	0.002
106123	2N2	298	0.016
106123	OO1	245.7	0.005
106123	M1	223.2	0.006
106123	J1	25.9	0.005
106123	Q1	162.3	0.006
106123	2Q1	76.4	0.005
106123	2SM2	7.6	0.007
106123	M3	69.8	0.002
106123	L2	78.3	0.017
106123	2MK3	15.3	0.001
106123	M8	141.6	0.002
106123	MS4	196.2	0.009
106124	M2	30	0.383
106124	S2	83.2	0.03
106124	N2	1.3	0.085
106124	K1	139.5	0.014
106124	M4	331	0.021
106124	O1	144.4	0.014
106124	M6	249.8	0.017
106124	MK3	131.7	0.002
106124	S4	209.3	0.003
106124	MN4	286.5	0.005
106124	S6	47.3	0.002
106124	2N2	341	0.012
106124	OO1	192.8	0.003
106124	M1	192.9	0.006
106124	J1	76.5	0.01
106124	Q1	160.4	0.006
106124	2Q1	336.7	0.004
106124	2SM2	14.7	0.006
106124	M3	49.6	0.005
106124	L2	113.5	0.012
106124	2MK3	318.8	0.007
106124	M8	218.7	0.006
106124	MS4	10.6	0.009
106125	M2	17.5	0.632
106125	S2	55.3	0.122
106125	N2	352.6	0.182
106125	K1	136.2	0.035
106125	M4	244.9	0.076
106125	O1	103.9	0.04
106125	M6	94.1	0.102
106125	MK3	280.6	0.009
106125	S4	175.7	0.006
106125	MN4	240.7	0.027
106125	S6	214.4	0.003
106125	2N2	33.4	0.026
106125	OO1	103.1	0.009
106125	M1	115.2	0.005
106125	J1	300.6	0.003
106125	Q1	83.1	0.007
106125	2Q1	28.9	0.008
106125	P1	106.7	0.021
106125	2SM2	148.4	0.006
106125	M3	330.5	0.01
106125	L2	250.7	0.013
106125	2MK3	248	0.013
106125	K2	89.4	0.032
106125	M8	47.4	0.011
106125	MS4	308.9	0.02
106126	M2	25.6	0.794
106126	S2	58.8	0.113
106126	N2	357.2	0.185
106126	K1	117	0.042
106126	M4	269.9	0.069
106126	O1	90.7	0.046
106126	M6	65.1	0.061
106126	MK3	240.7	0.005
106126	S4	314.8	0.004
106126	MN4	240.9	0.018
106126	S6	312.6	0.002
106126	2N2	350.2	0.031
106126	OO1	71.9	0.019
106126	M1	359.4	0.004
106126	J1	322.8	0.004
106126	Q1	91.1	0.004
106126	2Q1	26	0.007
106126	P1	129.5	0.019
106126	2SM2	4	0.008
106126	M3	309.7	0.004
106126	L2	102.1	0.037
106126	2MK3	248.6	0.006
106126	K2	82.2	0.032
106126	M8	85	0.008
106126	MS4	302.6	0.016
106127	M2	29.6	0.821
106127	S2	60.3	0.106
106127	N2	2.9	0.17
106127	K1	123.7	0.05
106127	M4	268	0.046
106127	O1	87.8	0.048
106127	M6	37.8	0.055
106127	MK3	118.8	0.01
106127	S4	43.1	0.007
106127	MN4	191.1	0.016
106127	2N2	330	0.032
106127	OO1	92.2	0.018
106127	M1	21.2	0.004
106127	J1	6	0.009
106127	Q1	88.9	0.012
106127	2Q1	91.3	0.006
106127	P1	112.5	0.021
106127	2SM2	24.1	0.017
106127	M3	210	0.007
106127	L2	102.8	0.057
106127	2MK3	96.9	0.008
106127	K2	74.1	0.043
106127	M8	283.5	0.004
106127	MS4	269.2	0.02
106128	M2	13.5	0.718
106128	S2	58.5	0.096
106128	N2	352.1	0.157
106128	K1	148	0.053
106128	M4	54.4	0.058
106128	O1	95.4	0.035
106128	M6	66.8	0.009
106128	MK3	122.8	0.024
106128	S4	323.6	0.022
106128	MN4	53.8	0.029
106128	S6	246.6	0.011
106128	2N2	355.7	0.011
106128	OO1	79.1	0.003
106128	M1	36.7	0.008
106128	J1	348.6	0.021
106128	Q1	327	0.015
106128	2Q1	166	0.005
106128	P1	46.6	0.023
106128	2SM2	300.7	0.011
106128	M3	41.3	0.002
106128	L2	350	0.023
106128	2MK3	110.2	0.01
106128	M8	49.3	0.01
106128	MS4	148.1	0.017
106129	M2	14.2	0.84
106129	S2	43.9	0.096
106129	N2	352.1	0.159
106129	K1	117.1	0.065
106129	M4	22.2	0.099
106129	O1	129.2	0.026
106129	M6	45.4	0.04
106129	MK3	138.9	0.014
106129	S4	327.5	0.019
106129	MN4	11.7	0.028
106129	S6	228.7	0.007
106129	2N2	323.7	0.011
106129	OO1	105.6	0.014
106129	M1	27.7	0.011
106129	J1	297.5	0.01
106129	Q1	202.2	0.005
106129	2Q1	120.5	0.009
106129	P1	330.9	0.022
106129	2SM2	2.8	0.01
106129	M3	57.7	0.004
106129	L2	53.6	0.026
106129	2MK3	137.7	0.007
106129	M8	128	0.028
106129	MS4	29.1	0.007
106130	M2	12.5	0.784
106130	S2	31.4	0.101
106130	N2	345.7	0.129
106130	K1	87.4	0.074
106130	M4	353.5	0.099
106130	O1	125.5	0.011
106130	M6	13.9	0.069
106130	MK3	114.7	0.008
106130	S4	274.1	0.011
106130	MN4	285.8	0.036
106130	S6	215.2	0.004
106130	2N2	281.4	0.025
106130	OO1	171.2	0.019
106130	M1	105.6	0.001
106130	J1	165.6	0.018
106130	Q1	217.8	0.021
106130	2Q1	96.4	0.021
106130	P1	275.7	0.025
106130	2SM2	359.8	0.01
106130	M3	107.2	0.005
106130	L2	89.2	0.029
106130	2MK3	243.4	0.009
106130	M8	45.9	0.031
106130	MS4	5.9	0.038
106131	M2	336.1	0.175
106131	S2	354.8	0.038
106131	K1	89.7	0.025
106131	M4	225.5	0.078
106131	O1	78.2	0.018
106131	M6	94.8	0.009
106131	MK3	217.6	0.008
106131	S4	109.4	0.011
106131	S6	81.7	0.008
106131	2N2	48.2	0.005
106131	OO1	18.4	0.025
106131	2Q1	60.1	0.007
106131	2SM2	30.6	0.026
106131	2MK3	145.8	0.011
106131	M8	164.4	0.009
106131	MS4	275.5	0.028
106132	M2	343.4	0.246
106132	S2	351	0.025
106132	K1	37.3	0.022
106132	M4	215.9	0.077
106132	O1	177.5	0.007
106132	M6	79	0.019
106132	MK3	259.4	0.012
106132	S4	107.9	0.008
106132	S6	74.6	0.002
106132	2N2	309.5	0.018
106132	OO1	25.8	0.014
106132	2Q1	87.8	0.011
106132	2SM2	358.6	0.02
106132	2MK3	180.5	0.003
106132	M8	271.6	0.005
106132	MS4	265.3	0.021
106133	M2	342	0.316
106133	S2	17	0.02
106133	K1	37.3	0.019
106133	M4	261.3	0.06
106133	O1	134.3	0.009
106133	M6	358.9	0.008
106133	MK3	336.3	0.016
106133	S4	291.5	0.011
106133	S6	26.5	0.007
106133	2N2	290	0.048
106133	OO1	282.4	0.006
106133	2Q1	82.2	0.004
106133	2SM2	283.5	0.02
106133	2MK3	336	0.007
106133	M8	325.2	0.005
106133	MS4	262.6	0.019
106134	M2	15.4	0.335
106134	S2	55.1	0.092
106134	N2	355.2	0.137
106134	K1	111.8	0.023
106134	M4	228.3	0.062
106134	O1	128.4	0.037
106134	M6	62.7	0.063
106134	MK3	266.5	0.007
106134	S4	318.8	0.01
106134	MN4	210.2	0.044
106134	S6	32.6	0.002
106134	2N2	27.5	0.046
106134	OO1	263.7	0.019
106134	M1	183.8	0.022
106134	J1	195.5	0.008
106134	Q1	131.2	0.006
106134	2Q1	210.9	0.018
106134	2SM2	165.5	0.018
106134	M3	94	0.021
106134	L2	251.3	0.053
106134	2MK3	311	0.016
106134	M8	277.1	0.012
106134	MS4	254.7	0.029
106135	M2	14.6	0.488
106135	S2	58.7	0.078
106135	N2	352.4	0.124
106135	K1	159.3	0.026
106135	M4	253.5	0.123
106135	O1	144.6	0.029
106135	M6	21.1	0.057
106135	MK3	19.7	0.009
106135	S4	333.6	0.012
106135	MN4	223.3	0.062
106135	S6	138	0.004
106135	2N2	30.7	0.015
106135	OO1	267.3	0.005
106135	M1	158.3	0.01
106135	Q1	172.7	0.004
106135	2Q1	47.3	0.004
106135	2SM2	146.1	0.013
106135	M3	93.8	0.017
106135	L2	34.6	0.026
106135	2MK3	33.8	0.013
106135	M8	232.9	0.01
106135	MS4	283.8	0.035
106136	M2	10	0.541
106136	S2	63.3	0.058
106136	N2	356.6	0.111
106136	K1	161	0.039
106136	M4	255.2	0.144
106136	O1	160.5	0.025
106136	M6	357.9	0.049
106136	MK3	22	0.02
106136	S4	332.7	0.012
106136	MN4	229.3	0.059
106136	S6	187.3	0.004
106136	2N2	162.5	0.006
106136	OO1	278.8	0.019
106136	M1	97.5	0.004
106136	J1	47.9	0.007
106136	Q1	78.1	0.009
106136	2Q1	95.6	0.012
106136	2SM2	78.5	0.018
106136	M3	55.9	0.012
106136	L2	47.3	0.058
106136	2MK3	50.8	0.023
106136	M8	153.6	0.022
106136	MS4	293.4	0.032
106137	M2	40	0.194
106137	S2	65.5	0.018
106137	N2	27	0.033
106137	K1	127.9	0.008
106137	M4	158.1	0.05
106137	O1	215.3	0.019
106137	M6	35.8	0.009
106137	MK3	251.6	0.029
106137	S4	341.8	0.003
106137	MN4	121.7	0.034
106137	S6	27.1	0.001
106137	2N2	208.3	0.013
106137	OO1	170.1	0.018
106137	M1	297.9	0.008
106137	J1	330.1	0.011
106137	Q1	198.7	0.008
106137	2Q1	316.6	0.007
106137	2SM2	28.3	0.012
106137	M3	332.7	0.009
106137	L2	91.4	0.025
106137	2MK3	253.2	0.01
106137	M8	158.8	0.012
106137	MS4	186.9	0.016
106138	M2	32.5	0.186
106138	S2	66.9	0.042
106138	N2	7.8	0.052
106138	K1	246.3	0.025
106138	M4	162.1	0.08
106138	O1	264.7	0.025
106138	M6	91.4	0.047
106138	MK3	232.9	0.025
106138	S4	343.3	0.003
106138	MN4	120.2	0.045
106138	S6	167	0.006
106138	2N2	12.2	0.014
106138	OO1	88.2	0.006
106138	M1	226.5	0.007
106138	J1	102.9	0.019
106138	Q1	158.4	0.017
106138	2Q1	120.3	0.015
106138	2SM2	214.5	0.015
106138	M3	312.9	0.007
106138	L2	199.5	0.018
106138	2MK3	234.9	0.011
106138	M8	316.8	0.009
106138	MS4	175.4	0.017
106139	M2	4.2	0.188
106139	S2	89.5	0.032
106139	N2	344.8	0.037
106139	K1	193.3	0.019
106139	M4	93.4	0.049
106139	O1	181.2	0.019
106139	M6	44.2	0.035
106139	MK3	241	0.008
106139	S4	11.5	0.004
106139	MN4	100.9	0.018
106139	S6	191.6	0.001
106139	2N2	188.8	0.005
106139	OO1	133.7	0.015
106139	M1	195.1	0.005
106139	J1	300.5	0.008
106139	Q1	165.8	0.006
106139	2Q1	344.2	0.004
106139	P1	39.5	0.01
106139	2SM2	41.5	0.012
106139	M3	18.8	0.005
106139	L2	50.3	0.003
106139	2MK3	168.3	0.006
106139	K2	163.8	0.027
106139	M8	272	0.005
106139	MS4	160.7	0.012
106140	M2	26.3	0.335
106140	S2	44.5	0.031
106140	N2	6.1	0.073
106140	K1	166	0.023
106140	M4	89.1	0.013
106140	O1	137.5	0.023
106140	M6	87.3	0.021
106140	MK3	225.9	0.01
106140	S4	60.6	0.007
106140	MN4	108.8	0.003
106140	S6	75.5	0.003
106140	2N2	325	0.005
106140	OO1	143.9	0.016
106140	M1	257.7	0.005
106140	J1	319.2	0.016
106140	Q1	319.2	0.006
106140	2Q1	26.1	0.018
106140	P1	99.4	0.007
106140	2SM2	71.8	0.011
106140	M3	265.7	0.004
106140	L2	68	0.033
106140	K2	347.3	0.026
106140	M8	23.6	0.008
106140	MS4	7.9	0.004
106141	M2	29.2	0.456
106141	S2	53.5	0.075
106141	N2	1.8	0.108
106141	K1	111	0.025
106141	M4	306.1	0.037
106141	O1	86.4	0.025
106141	M6	114.5	0.024
106141	MK3	228.8	0.006
106141	S4	168.2	0.009
106141	MN4	319.6	0.01
106141	S6	328.8	0.001
106141	2N2	334.2	0.019
106141	OO1	308.1	0.032
106141	M1	50.8	0.009
106141	J1	119	0.024
106141	Q1	133.2	0.013
106141	2Q1	215.8	0.012
106141	P1	18.8	0.004
106141	2SM2	245.5	0.014
106141	M3	132.4	0.003
106141	L2	106.2	0.037
106141	2MK3	156.6	0.009
106141	K2	55.1	0.047
106141	M8	355	0.014
106141	MS4	50.8	0.02
106142	M2	6.7	0.405
106142	S2	41.5	0.066
106142	N2	341.7	0.083
106142	K1	76.8	0.031
106142	M4	148.3	0.06
106142	O1	87.8	0.019
106142	M6	29.3	0.073
106142	MK3	201.1	0.009
106142	S4	4.8	0.004
106142	MN4	120.6	0.017
106142	S6	318.5	0.004
106142	2N2	321.9	0.017
106142	OO1	95	0.007
106142	M1	134.2	0.005
106142	J1	328.8	0.006
106142	Q1	162.1	0.004
106142	2Q1	11.4	0.007
106142	P1	214.5	0.016
106142	2SM2	347.9	0.003
106142	M3	352.3	0.003
106142	L2	298.6	0.009
106142	2MK3	199.2	0.002
106142	M8	326.6	0.004
106142	MS4	197.1	0.013
106143	M2	22.7	0.447
106143	S2	84.4	0.011
106143	N2	32.2	0.052
106143	K1	177.3	0.027
106143	M4	35.7	0.071
106143	O1	185.1	0.026
106143	M6	287.7	0.025
106143	MK3	164.7	0.03
106143	S4	140	0.008
106143	MN4	11.2	0.048
106143	S6	111.1	0.005
106143	2N2	329.7	0.018
106143	OO1	244.6	0.012
106143	M1	104.5	0.004
106143	J1	83.7	0.011
106143	Q1	147	0.01
106143	2Q1	205.1	0.011
106143	P1	50.3	0.021
106143	2SM2	213.6	0.019
106143	M3	254	0.01
106143	L2	80.5	0.049
106143	2MK3	116.2	0.026
106143	M8	25.1	0.026
106143	MS4	83.8	0.034
106144	M2	3.3	0.539
106144	S2	30.7	0.095
106144	N2	340.6	0.135
106144	K1	97.6	0.02
106144	M4	229	0.108
106144	O1	63.8	0.015
106144	M6	347.1	0.05
106144	MK3	329.4	0.013
106144	S4	34.2	0.009
106144	MN4	190.4	0.047
106144	S6	187.5	0.012
106144	2N2	13.5	0.017
106144	OO1	106.6	0.014
106144	M1	101.6	0.005
106144	J1	193	0.009
106144	Q1	119.3	0.005
106144	2Q1	264.7	0.01
106144	2SM2	353.4	0.002
106144	M3	339.4	0.005
106144	L2	80	0.022
106144	2MK3	128.9	0.005
106144	K2	33.6	0.07
106144	M8	114	0.014
106144	MS4	284.7	0.019
106145	M2	2.8	0.658
106145	S2	32	0.117
106145	N2	338.9	0.135
106145	K1	96.4	0.026
106145	M4	156.7	0.073
106145	O1	100.6	0.02
106145	M6	342.3	0.037
106145	MK3	83.3	0.004
106145	S4	38.2	0.006
106145	MN4	144.5	0.012
106145	S6	216.9	0.003
106145	2N2	302.9	0.026
106145	OO1	333.4	0.009
106145	M1	100.4	0.008
106145	J1	275.4	0.003
106145	Q1	148	0.007
106145	2Q1	187	0.014
106145	2SM2	41.9	0.012
106145	M3	317.3	0.002
106145	L2	89.2	0.025
106145	2MK3	86.7	0.012
106145	K2	59.6	0.062
106145	M8	46.5	0.025
106145	MS4	171.6	0.019
106146	M2	2.3	0.659
106146	S2	19.7	0.079
106146	N2	334.5	0.13
106146	K1	136.1	0.041
106146	M4	111.8	0.151
106146	O1	156	0.024
106146	M6	9.7	0.044
106146	MK3	165.9	0.019
106146	S4	347.7	0.008
106146	MN4	76.9	0.032
106146	S6	289.7	0.003
106146	2N2	253.6	0.022
106146	OO1	125.1	0.002
106146	M1	293.1	0.01
106146	J1	56.9	0.012
106146	Q1	168	0.001
106146	2Q1	165	0.025
106146	2SM2	78.2	0.011
106146	M3	176.5	0.002
106146	L2	71	0.059
106146	2MK3	128.2	0.009
106146	K2	25.2	0.035
106146	M8	19.2	0.007
106146	MS4	150.9	0.047
106147	M2	17.9	0.814
106147	S2	71	0.122
106147	N2	10.9	0.2
106147	K1	121.8	0.052
106147	M4	62.1	0.013
106147	O1	106.7	0.044
106147	M6	145.3	0.03
106147	MK3	77.5	0.009
106147	S4	0.1	0.002
106147	MN4	303.2	0.028
106147	S6	193.8	0.008
106147	2N2	13.8	0.02
106147	OO1	133.3	0.003
106147	M1	153.5	0.006
106147	J1	163	0.008
106147	Q1	209.7	0.002
106147	2Q1	266.6	0.004
106147	2SM2	13.5	0.007
106147	M3	77.5	0.009
106147	L2	122.5	0.029
106147	2MK3	63.7	0.011
106147	K2	120.3	0.035
106147	M8	93.5	0.031
106147	MS4	168.1	0.007
106148	M2	23.6	0.905
106148	S2	65.2	0.121
106148	N2	353.8	0.237
106148	K1	133.2	0.063
106148	M4	306.2	0.046
106148	O1	85	0.017
106148	M6	40.8	0.086
106148	MK3	171.4	0.025
106148	S4	136.6	0.002
106148	MN4	293.4	0.011
106148	S6	176.7	0.007
106148	2N2	333.8	0.041
106148	OO1	339.2	0.003
106148	M1	297.3	0.01
106148	J1	125.5	0.006
106148	Q1	31.6	0.01
106148	2Q1	85.2	0.013
106148	2SM2	159.5	0.017
106148	M3	263.4	0.002
106148	L2	77.7	0.043
106148	2MK3	118	0.008
106148	K2	164.4	0.01
106148	M8	45.5	0.012
106148	MS4	17.8	0.015
106149	M2	25.7	0.994
106149	S2	42.4	0.131
106149	N2	356.9	0.228
106149	K1	133.8	0.066
106149	M4	277.9	0.076
106149	O1	54.3	0.027
106149	M6	32.4	0.073
106149	MK3	205.8	0.02
106149	S4	338.4	0.005
106149	MN4	131	0.012
106149	S6	220	0.005
106149	2N2	350.7	0.045
106149	OO1	85	0.01
106149	M1	296.9	0.008
106149	J1	149.2	0.006
106149	Q1	77.3	0.013
106149	2Q1	102.5	0.006
106149	2SM2	130.3	0.006
106149	M3	317.9	0.019
106149	L2	73.2	0.084
106149	2MK3	207.2	0.018
106149	K2	32.1	0.089
106149	M8	219.3	0.009
106149	MS4	301	0.015
106150	M2	24.2	0.16
106150	S2	30.9	0.027
106150	K1	196	0.021
106150	M4	294.3	0.082
106150	O1	94.7	0.033
106150	M6	27	0.042
106150	MK3	332.1	0.013
106150	S4	119.3	0.032
106150	S6	70.3	0.004
106150	2N2	341.9	0.031
106150	OO1	247.1	0.033
106150	2Q1	219.5	0.005
106150	2SM2	234.7	0.021
106150	2MK3	32.4	0.011
106150	M8	106.6	0.012
106150	MS4	302.4	0.011
106151	M2	26.2	0.166
106151	S2	1.1	0.008
106151	K1	244.9	0.009
106151	M4	307.2	0.117
106151	O1	87.3	0.059
106151	M6	108.8	0.022
106151	MK3	33.4	0.021
106151	S4	102.5	0.016
106151	S6	79.3	0.021
106151	2N2	13.8	0.009
106151	OO1	204.8	0.03
106151	2Q1	280.8	0.02
106151	2SM2	359.4	0.012
106151	2MK3	295.7	0.018
106151	M8	113.9	0.011
106151	MS4	34	0.016
106152	M2	18.6	0.786
106152	S2	71.8	0.153
106152	N2	355.2	0.136
106152	K1	122.5	0.04
106152	M4	255.6	0.145
106152	O1	77.7	0.026
106152	M6	24.7	0.064
106152	MK3	20.9	0.005
106152	S4	302.3	0.007
106152	MN4	230.7	0.046
106152	S6	352	0.009
106152	2N2	286.7	0.014
106152	OO1	48.8	0.016
106152	M1	152.7	0.004
106152	J1	47.2	0.013
106152	Q1	34.1	0.013
106152	2Q1	57.8	0.009
106152	2SM2	259.9	0.019
106152	M3	227.3	0.008
106152	L2	71.2	0.029
106152	2MK3	197.3	0.007
106152	K2	62.1	0.101
106152	M8	207.4	0.011
106152	MS4	283.5	0.016
106153	M2	20.8	0.796
106153	S2	83.6	0.209
106153	N2	353.6	0.183
106153	K1	119.1	0.063
106153	M4	186	0.088
106153	O1	97.7	0.033
106153	M6	45.9	0.043
106153	MK3	291.1	0.015
106153	S4	273.4	0.012
106153	MN4	208	0.035
106153	S6	75.3	0.002
106153	2N2	58.6	0.03
106153	OO1	66	0.03
106153	M1	5.1	0.011
106153	J1	81.7	0.022
106153	Q1	50.3	0.027
106153	2Q1	53.4	0.017
106153	2SM2	150.2	0.012
106153	M3	319.4	0.005
106153	L2	250.4	0.01
106153	2MK3	337.6	0.012
106153	K2	64	0.16
106153	M8	285.4	0.012
106153	MS4	257.1	0.018
106154	M2	20.6	0.851
106154	S2	88	0.177
106154	N2	359.8	0.206
106154	K1	118.1	0.108
106154	M4	144.9	0.108
106154	O1	93.9	0.062
106154	M6	62.4	0.068
106154	MK3	63.7	0.003
106154	S4	292.5	0.023
106154	MN4	149.3	0.039
106154	S6	181.8	0.005
106154	2N2	48.3	0.041
106154	OO1	64.9	0.036
106154	M1	343.1	0.014
106154	J1	347.1	0.002
106154	Q1	36	0.017
106154	2Q1	96	0.016
106154	2SM2	124.2	0.034
106154	M3	54.1	0.012
106154	L2	276.7	0.032
106154	2MK3	12.8	0.012
106154	K2	87.5	0.118
106154	M8	289.4	0.009
106154	MS4	188.7	0.015
106155	M2	4.1	0.514
106155	S2	33.7	0.091
106155	N2	339.5	0.148
106155	K1	62.4	0.057
106155	M4	241.7	0.235
106155	O1	98.8	0.012
106155	M6	7.7	0.027
106155	MK3	283.7	0.046
106155	S4	10.6	0.019
106155	MN4	191.2	0.119
106155	S6	167.7	0.003
106155	2N2	6.9	0.028
106155	OO1	154.2	0.021
106155	M1	158.5	0.004
106155	J1	21.5	0.012
106155	Q1	354.7	0.012
106155	2Q1	221.8	0.007
106155	P1	191.2	0.043
106155	2SM2	272.7	0.008
106155	M3	198.6	0.007
106155	L2	21	0.022
106155	2MK3	223.1	0.015
106155	K2	14.7	0.064
106155	M8	269.2	0.049
106155	MS4	282.5	0.047
106156	M2	3.8	0.48
106156	S2	6.3	0.081
106156	N2	331.7	0.11
106156	K1	85.2	0.061
106156	M4	225.8	0.187
106156	O1	86	0.026
106156	M6	47.9	0.047
106156	MK3	6	0.012
106156	S4	105.1	0.009
106156	MN4	204.4	0.108
106156	S6	136.9	0.013
106156	2N2	316.3	0.011
106156	OO1	215.2	0.015
106156	M1	265.1	0.01
106156	J1	200	0.008
106156	Q1	89.5	0.01
106156	2Q1	65.7	0.006
106156	P1	199.6	0.04
106156	2SM2	91.2	0.01
106156	M3	274.2	0.019
106156	L2	43.2	0.068
106156	2MK3	182.8	0.019
106156	K2	5.2	0.06
106156	M8	173.9	0.041
106156	MS4	277.6	0.053
106157	M2	47.2	0.484
106157	S2	102.1	0.051
106157	N2	25.7	0.116
106157	K1	103.7	0.056
106157	M4	351.3	0.037
106157	O1	127.6	0.025
106157	M6	348	0.014
106157	MK3	41.4	0.01
106157	S4	78.2	0.006
106157	MN4	328.5	0.015
106157	S6	211	0.004
106157	2N2	63.5	0.012
106157	OO1	331.8	0.009
106157	M1	184.1	0.008
106157	J1	197.4	0.01
106157	Q1	141.6	0.016
106157	2Q1	295.8	0.022
106157	2SM2	271.2	0.015
106157	M3	355.8	0.006
106157	L2	73.7	0.044
106157	2MK3	358.1	0.007
106157	M8	272	0.004
106157	MS4	24.2	0.013
106158	M2	58.3	0.45
106158	S2	102.6	0.06
106158	N2	50.2	0.135
106158	K1	143.8	0.059
106158	M4	24.3	0.031
106158	O1	107.3	0.052
106158	M6	72.1	0.014
106158	MK3	114.7	0.01
106158	S4	81.6	0.008
106158	MN4	345.6	0.018
106158	S6	290.1	0.003
106158	2N2	76.8	0.023
106158	OO1	337.8	0.019
106158	M1	86.6	0.01
106158	J1	51.6	0.006
106158	Q1	181.1	0.006
106158	2Q1	238.1	0.015
106158	2SM2	11.3	0.003
106158	M3	92.5	0.008
106158	L2	213.3	0.034
106158	2MK3	18.1	0.011
106158	M8	338.3	0.002
106158	MS4	24.1	0.004
106159	M2	59.9	0.409
106159	S2	114.9	0.077
106159	N2	47.5	0.138
106159	K1	178.4	0.074
106159	M4	35.8	0.034
106159	O1	106.4	0.056
106159	M6	96.5	0.03
106159	MK3	156.3	0.02
106159	S4	324.8	0.006
106159	MN4	302.7	0.015
106159	S6	103.3	0.006
106159	2N2	61.6	0.049
106159	OO1	0	0.024
106159	M1	36.7	0.012
106159	J1	40.9	0.017
106159	Q1	272	0.012
106159	2Q1	179.5	0.011
106159	2SM2	41.5	0.017
106159	M3	147.7	0.007
106159	L2	242.2	0.037
106159	2MK3	71.7	0.014
106159	M8	50.4	0.007
106159	MS4	53.2	0.008
106160	M2	2.5	0.376
106160	S2	67.1	0.054
106160	N2	353.5	0.078
106160	K1	111.6	0.037
106160	M4	330.9	0.05
106160	O1	64.6	0.004
106160	M6	152	0.024
106160	MK3	89.4	0.005
106160	S4	280.5	0.005
106160	MN4	344.6	0.03
106160	S6	39.7	0.008
106160	2N2	172.7	0.018
106160	OO1	353.4	0.013
106160	M1	163.2	0.005
106160	J1	77.1	0.011
106160	Q1	111.8	0.007
106160	2Q1	100.8	0.016
106160	P1	332	0.028
106160	2SM2	332	0.003
106160	M3	284.7	0.005
106160	L2	7.6	0.023
106160	2MK3	59.5	0.01
106160	M8	303.3	0.005
106160	MS4	79	0.007
106161	M2	29.7	0.588
106161	S2	56.7	0.072
106161	N2	3.7	0.09
106161	K1	100.7	0.054
106161	M4	217	0.031
106161	O1	103.4	0.016
106161	M6	31.5	0.057
106161	MK3	174.8	0.02
106161	S4	125.4	0.012
106161	MN4	218.1	0.014
106161	S6	307.6	0.007
106161	2N2	351.1	0.016
106161	OO1	16.8	0.024
106161	M1	101	0.011
106161	J1	13.6	0.015
106161	Q1	72.6	0.024
106161	2Q1	128.1	0.006
106161	P1	288	0.007
106161	2SM2	149.9	0.003
106161	M3	261.7	0.009
106161	L2	103.9	0.025
106161	2MK3	174.1	0.007
106161	M8	30.9	0.006
106161	MS4	276.5	0.007
106162	M2	30.8	0.598
106162	S2	53.6	0.072
106162	N2	3.8	0.117
106162	K1	128.9	0.065
106162	M4	172.6	0.015
106162	O1	104.2	0.032
106162	M6	9.1	0.058
106162	MK3	250.4	0.015
106162	S4	110	0.008
106162	MN4	240.8	0.023
106162	S6	232.3	0.009
106162	2N2	357.4	0.028
106162	OO1	296.7	0.002
106162	M1	45.9	0.016
106162	J1	268.1	0.014
106162	Q1	261.8	0.019
106162	2Q1	158	0.001
106162	2SM2	256.4	0.009
106162	M3	245.8	0.011
106162	L2	126.9	0.014
106162	2MK3	259.4	0.011
106162	M8	210.1	0.007
106162	MS4	338.1	0.005
106163	M2	9.3	0.858
106163	S2	39.4	0.112
106163	N2	348.8	0.161
106163	K1	87.1	0.039
106163	M4	342.4	0.059
106163	O1	98.4	0.017
106163	M6	34.1	0.041
106163	MK3	87.7	0.009
106163	S4	95	0.021
106163	MN4	305.8	0.046
106163	S6	37.5	0.015
106163	2N2	305.4	0.02
106163	OO1	11	0.033
106163	M1	356.2	0.002
106163	J1	66.5	0.004
106163	Q1	47.8	0.015
106163	2Q1	248	0.009
106163	2SM2	138.5	0.006
106163	M3	3.2	0.008
106163	L2	38	0.012
106163	2MK3	82.7	0.017
106163	M8	20.6	0.022
106163	MS4	12.8	0.034
106164	M2	18.9	0.9
106164	S2	48.9	0.137
106164	N2	356.5	0.176
106164	K1	100	0.049
106164	M4	321.8	0.088
106164	O1	105.3	0.027
106164	M6	33.5	0.07
106164	MK3	333.8	0.004
106164	S4	274.5	0.02
106164	MN4	306.9	0.033
106164	S6	197.1	0.01
106164	2N2	1.8	0.033
106164	OO1	243.4	0.023
106164	J1	76.1	0.011
106164	Q1	55.7	0.016
106164	2Q1	232.8	0.013
106164	2SM2	72.9	0.015
106164	M3	164.1	0.016
106164	L2	28.9	0.017
106164	2MK3	71.1	0.013
106164	M8	242.3	0.016
106164	MS4	340.2	0.034
106165	M2	15.2	0.971
106165	S2	53.4	0.12
106165	N2	348.8	0.164
106165	K1	99.6	0.071
106165	M4	319.2	0.086
106165	O1	83.9	0.04
106165	M6	5.4	0.053
106165	MK3	20.8	0.008
106165	S4	263.9	0.018
106165	MN4	281.9	0.024
106165	S6	263.2	0.006
106165	2N2	358.1	0.029
106165	OO1	71.2	0.01
106165	M1	3	0.012
106165	J1	50.4	0.019
106165	Q1	97.7	0.013
106165	2Q1	213.1	0.018
106165	2SM2	350	0.024
106165	M3	112.5	0.008
106165	L2	48	0.043
106165	2MK3	136.9	0.016
106165	M8	260.4	0.029
106165	MS4	270.4	0.023
106166	M2	349	0.175
106166	S2	11.1	0.014
106166	N2	303.6	0.031
106166	K1	38.1	0.049
106166	M4	166.1	0.043
106166	O1	25.5	0.017
106166	M6	344.8	0.033
106166	MK3	183.6	0.015
106166	S4	234.4	0.008
106166	MN4	158.4	0.017
106166	S6	310.7	0.006
106166	2N2	355.2	0.017
106166	OO1	145.6	0.01
106166	M1	341.7	0.011
106166	J1	254.3	0.014
106166	Q1	219.2	0.01
106166	2Q1	351.9	0.005
106166	P1	253.4	0.025
106166	2SM2	71.9	0.015
106166	M3	330.7	0.003
106166	L2	68.2	0.021
106166	2MK3	160.3	0.015
106166	M8	196.7	0.008
106166	MS4	17.4	0.007
106167	M2	358.6	0.228
106167	S2	2.7	0.027
106167	N2	301	0.035
106167	K1	47	0.052
106167	M4	189	0.044
106167	O1	357	0.015
106167	M6	3.1	0.032
106167	MK3	189.4	0.018
106167	S4	241.5	0.008
106167	MN4	157.7	0.02
106167	S6	332.2	0.003
106167	2N2	322.3	0.012
106167	OO1	169.8	0.011
106167	M1	5	0.008
106167	J1	291.6	0.014
106167	Q1	267.7	0.01
106167	2Q1	75.7	0.005
106167	P1	276.3	0.033
106167	2SM2	101.5	0.015
106167	M3	74.3	0.003
106167	L2	69.7	0.027
106167	2MK3	167.5	0.018
106167	M8	202.8	0.005
106167	MS4	223.3	0.004
106168	M2	0.5	0.239
106168	S2	22.5	0.038
106168	N2	302.6	0.042
106168	K1	48.1	0.076
106168	M4	184.5	0.03
106168	O1	335.3	0.015
106168	M6	355.2	0.028
106168	MK3	184.1	0.01
106168	S4	227.2	0.006
106168	MN4	158.7	0.024
106168	S6	351.6	0.001
106168	2N2	300.2	0.019
106168	OO1	141.3	0.021
106168	M1	355.8	0.011
106168	J1	329.9	0.033
106168	Q1	276.9	0.024
106168	2Q1	84.2	0.016
106168	P1	272.3	0.073
106168	2SM2	60.7	0.023
106168	M3	359.5	0.005
106168	L2	88.5	0.01
106168	2MK3	176	0.008
106168	M8	332	0.003
106168	MS4	203.9	0.013
106169	M2	121.3	1.082
106169	S2	168.1	0.115
106169	N2	88.7	0.211
106169	K1	191.2	0.088
106169	M4	228.2	0.225
106169	O1	186.2	0.057
106169	M6	188	0.084
106169	MK3	290.4	0.046
106169	S4	61.2	0.011
106169	MN4	215.8	0.081
106169	S6	355.1	0.004
106169	2N2	61	0.025
106169	OO1	37.4	0.022
106169	M1	41.8	0.001
106169	J1	296.1	0.01
106169	Q1	148.9	0.022
106169	2Q1	15.8	0.006
106169	P1	263.9	0.017
106169	2SM2	5.4	0.027
106169	M3	31	0.005
106169	L2	122.4	0.097
106169	2MK3	248.5	0.039
106169	K2	41.5	0.039
106169	M8	298.5	0.036
106169	MS4	302.4	0.049
106170	M2	121.4	1.344
106170	S2	160	0.149
106170	N2	88.3	0.268
106170	K1	187.6	0.102
106170	M4	226.4	0.275
106170	O1	190	0.065
106170	M6	192.2	0.106
106170	MK3	284.8	0.06
106170	S4	47.7	0.012
106170	MN4	215	0.095
106170	S6	359	0.005
106170	2N2	60.1	0.034
106170	OO1	37	0.027
106170	M1	15.5	0.001
106170	J1	306.8	0.012
106170	Q1	148.3	0.029
106170	2Q1	44.9	0.009
106170	P1	241	0.024
106170	2SM2	357.9	0.033
106170	M3	16.7	0.007
106170	L2	120.4	0.119
106170	2MK3	247.1	0.05
106170	K2	74.4	0.05
106170	M8	301.4	0.047
106170	MS4	301.5	0.06
106171	M2	98.1	2.289
106171	S2	142.4	0.263
106171	N2	76.6	0.471
106171	K1	168.6	0.175
106171	M4	196.3	0.071
106171	O1	159.9	0.146
106171	M6	146.5	0.152
106171	MK3	241.8	0.054
106171	S4	243.1	0.009
106171	MN4	226.3	0.037
106171	S6	82.2	0.008
106171	2N2	319.3	0.016
106171	M1	247.2	0.008
106171	J1	86.8	0.016
106171	Q1	152.2	0.027
106171	P1	174.2	0.06
106171	2SM2	77.8	0.005
106171	M3	289.4	0.016
106171	L2	130.1	0.209
106171	2MK3	201.1	0.049
106171	K2	150.1	0.104
106171	M8	205.2	0.007
106171	MS4	317.8	0.016
106172	M2	97.9	2.647
106172	S2	141.2	0.309
106172	N2	75.8	0.542
106172	K1	168.7	0.203
106172	M4	189.6	0.107
106172	O1	157.5	0.176
106172	M6	146.8	0.159
106172	MK3	245.3	0.064
106172	S4	235.3	0.01
106172	MN4	209.2	0.04
106172	S6	89.7	0.01
106172	2N2	320.6	0.019
106172	OO1	343.1	0.007
106172	M1	234.9	0.008
106172	J1	90	0.018
106172	Q1	144.2	0.034
106172	2Q1	223	0.005
106172	P1	170.7	0.07
106172	2SM2	96.5	0.009
106172	M3	290.7	0.016
106172	L2	129.8	0.241
106172	2MK3	205.9	0.059
106172	K2	151.6	0.127
106172	M8	204	0.023
106172	MS4	285.5	0.019
106173	M2	97.5	2.701
106173	S2	139.3	0.312
106173	N2	74.8	0.546
106173	K1	167.7	0.198
106173	M4	189.4	0.141
106173	O1	156	0.184
106173	M6	145.3	0.159
106173	MK3	248.3	0.068
106173	S4	248	0.008
106173	MN4	197.9	0.049
106173	S6	99.7	0.008
106173	2N2	322.5	0.027
106173	OO1	332.5	0.011
106173	M1	209.3	0.007
106173	J1	81.8	0.016
106173	Q1	144	0.036
106173	2Q1	213.7	0.008
106173	P1	160.6	0.081
106173	2SM2	108.7	0.014
106173	M3	287.2	0.014
106173	L2	129.3	0.248
106173	2MK3	208.3	0.057
106173	K2	150.2	0.136
106173	M8	202.5	0.036
106173	MS4	269.6	0.026
106174	M2	88.1	1.297
106174	S2	129.2	0.135
106174	N2	66.1	0.293
106174	K1	168.1	0.106
106174	M4	163.3	0.079
106174	O1	159.4	0.079
106174	M6	98.2	0.086
106174	MK3	207.4	0.03
106174	S4	310.7	0.004
106174	MN4	161.6	0.025
106174	2N2	34.1	0.01
106174	OO1	227.1	0.007
106174	M1	42.1	0.001
106174	J1	137.4	0.006
106174	Q1	129.6	0.005
106174	P1	182.6	0.022
106174	2SM2	72.7	0.004
106174	M3	306	0.007
106174	L2	126.9	0.092
106174	2MK3	188.6	0.026
106174	K2	139.9	0.034
106174	M8	231.7	0.036
106174	MS4	243.9	0.013
106175	M2	87.1	1.956
106175	S2	121.4	0.224
106175	N2	62.5	0.413
106175	K1	168.7	0.147
106175	M4	233.9	0.095
106175	O1	162.7	0.121
106175	M6	133.2	0.139
106175	MK3	250	0.037
106175	S4	251.4	0.004
106175	MN4	223	0.056
106175	S6	315.3	0.003
106175	2N2	28.6	0.018
106175	OO1	263	0.006
106175	M1	258.5	0.003
106175	J1	91	0.011
106175	Q1	137.1	0.016
106175	2Q1	99	0.007
106175	P1	171.7	0.035
106175	2SM2	14.3	0.008
106175	M3	305.8	0.007
106175	L2	116.9	0.17
106175	2MK3	197.9	0.029
106175	K2	111.2	0.095
106175	M8	212.9	0.017
106175	MS4	316	0.037
106176	M2	83.6	2.104
106176	S2	113.3	0.237
106176	N2	56.5	0.433
106176	K1	160.3	0.161
106176	M4	249.1	0.162
106176	O1	154.8	0.123
106176	M6	135.8	0.163
106176	MK3	282.4	0.038
106176	S4	235.2	0.01
106176	MN4	226.8	0.098
106176	S6	321.2	0.006
106176	2N2	341	0.02
106176	OO1	224.9	0.008
106176	M1	249.2	0.003
106176	J1	60.3	0.015
106176	Q1	140.6	0.021
106176	2Q1	66.4	0.008
106176	P1	168.6	0.043
106176	2SM2	347.8	0.019
106176	M3	330.2	0.007
106176	L2	111.2	0.19
106176	2MK3	212	0.036
106176	K2	94.5	0.118
106176	M8	191.9	0.02
106176	MS4	317.7	0.064
106177	M2	102.6	1.13
106177	S2	150.3	0.11
106177	K1	193.7	0.115
106177	M4	232.7	0.193
106177	O1	205.8	0.08
106177	M6	111.6	0.066
106177	MK3	313.2	0.043
106177	S4	248	0.019
106177	2N2	264.6	0.066
106177	OO1	201	0.038
106177	2Q1	303.5	0.024
106177	2SM2	301.5	0.032
106177	2MK3	264.8	0.023
106177	M8	290.4	0.028
106177	MS4	298.5	0.042
106178	M2	102.2	1.304
106178	S2	144.2	0.129
106178	K1	197.3	0.139
106178	M4	225.3	0.288
106178	O1	208.7	0.093
106178	M6	101.3	0.059
106178	MK3	307.2	0.06
106178	S4	265.2	0.015
106178	S6	311.7	0.004
106178	2N2	262.5	0.076
106178	OO1	181.3	0.031
106178	2Q1	294.2	0.026
106178	2SM2	295.9	0.038
106178	2MK3	279.5	0.028
106178	M8	262.3	0.027
106178	MS4	288.5	0.064
106179	M2	100.9	1.394
106179	S2	143.1	0.133
106179	K1	197.1	0.144
106179	M4	219.9	0.349
106179	O1	206.8	0.097
106179	M6	75.8	0.046
106179	MK3	300.6	0.071
106179	S4	303.6	0.013
106179	S6	280.6	0.004
106179	2N2	260	0.08
106179	OO1	180.9	0.025
106179	2Q1	299	0.023
106179	2SM2	292.5	0.048
106179	2MK3	286.3	0.028
106179	M8	246.2	0.034
106179	MS4	282.8	0.079
106180	M2	341.1	0.072
106180	S2	70.6	0.017
106180	N2	327.2	0.019
106180	K1	256.5	0.032
106180	M4	5.6	0.01
106180	O1	60.9	0.009
106180	M6	335	0.003
106180	MK3	290.9	0.009
106180	S4	340.3	0.001
106180	MN4	312.6	0.007
106180	S6	178.7	0.004
106180	2N2	192.3	0.011
106180	OO1	103	0.008
106180	M1	197.9	0.006
106180	J1	313.4	0.012
106180	Q1	340.9	0.018
106180	2Q1	204.5	0.003
106180	P1	153.7	0.022
106180	2SM2	251.5	0.005
106180	M3	279.8	0.005
106180	L2	32.4	0.022
106180	2MK3	18.7	0.002
106180	M8	301.8	0.002
106180	MS4	26.4	0.008
106181	M2	4	0.116
106181	S2	37.1	0.015
106181	N2	13.7	0.03
106181	K1	170.4	0.093
106181	M4	35.4	0.016
106181	O1	269.4	0.004
106181	M6	23.6	0.009
106181	MK3	328.4	0.017
106181	S4	341.5	0.003
106181	MN4	355.7	0.006
106181	S6	261.2	0.004
106181	2N2	210.9	0.006
106181	OO1	217	0.014
106181	M1	170.5	0.01
106181	J1	260.3	0.006
106181	Q1	3.2	0.025
106181	2Q1	242.5	0.005
106181	P1	6	0.059
106181	2SM2	60.3	0.013
106181	M3	27.9	0.013
106181	L2	95.5	0.023
106181	2MK3	268	0.008
106181	M8	240.9	0.003
106181	MS4	118.1	0.004
106182	M2	82.2	0.121
106182	S2	80.8	0.019
106182	N2	77	0.025
106182	K1	117.8	0.198
106182	M4	276.1	0.015
106182	O1	204.6	0.019
106182	M6	154.7	0.003
106182	MK3	28.9	0.003
106182	S4	286.3	0.01
106182	MN4	154.9	0.009
106182	S6	136.1	0.006
106182	2N2	54	0.023
106182	OO1	32.3	0.023
106182	M1	12.7	0.03
106182	J1	138.4	0.037
106182	Q1	146.9	0.014
106182	2Q1	161.5	0.012
106182	P1	345.1	0.174
106182	2SM2	125	0.019
106182	M3	125.8	0.007
106182	L2	222.6	0.053
106182	2MK3	63.6	0.014
106182	M8	14.6	0.002
106182	MS4	210.1	0.005
106183	M2	338.9	0.12
106183	S2	13.3	0.027
106183	N2	338.5	0.031
106183	K1	109.7	0.018
106183	M4	67.5	0.016
106183	O1	84.7	0.013
106183	M6	315.2	0.014
106183	MK3	131.6	0.002
106183	S4	251	0.01
106183	MN4	60.2	0.005
106183	S6	72.3	0.003
106183	2N2	109.4	0.006
106183	OO1	346.3	0.003
106183	M1	327.5	0.002
106183	J1	264.4	0.011
106183	Q1	242.8	0.003
106183	2Q1	38.9	0.008
106183	2SM2	119.7	0.013
106183	M3	280.3	0.004
106183	L2	90	0.009
106183	2MK3	118.8	0.001
106183	M8	88.6	0.005
106183	MS4	92.6	0.006
106184	M2	43.9	0.339
106184	S2	101.1	0.069
106184	N2	30.9	0.136
106184	K1	135.9	0.069
106184	M4	325.4	0.131
106184	O1	108.1	0.054
106184	M6	240.9	0.05
106184	MK3	58.7	0.046
106184	S4	191.7	0.001
106184	MN4	300.7	0.073
106184	S6	82.8	0.003
106184	2N2	134.3	0.024
106184	OO1	283.4	0.024
106184	M1	158.6	0.003
106184	J1	194	0.006
106184	Q1	76.2	0.015
106184	2Q1	115.3	0.016
106184	2SM2	158.1	0.007
106184	M3	219	0.006
106184	L2	311	0.027
106184	2MK3	32	0.036
106184	M8	154	0.028
106184	MS4	6.6	0.037
106185	M2	293.5	1.319
106185	S2	321.8	0.227
106185	N2	276.5	0.289
106185	K1	111.9	0.147
106185	M4	8.6	0.089
106185	O1	87.2	0.091
106185	M6	329.6	0.065
106185	S4	159.6	0.027
106185	NU2	278.8	0.056
106185	S6	111	0.014
106185	2N2	259.6	0.038
106185	OO1	136.4	0.004
106185	LDA2	306.6	0.009
106185	M1	99.5	0.006
106185	J1	124.1	0.007
106185	RHO1	76.6	0.003
106185	Q1	74.9	0.018
106185	T2	320.6	0.013
106185	R2	323	0.002
106185	2Q1	62.7	0.002
106185	P1	109.9	0.049
106185	L2	276.6	0.041
106185	K2	324.1	0.062
106185	M8	55	0.029
106186	M2	294.1	1.594
106186	S2	323	0.278
106186	N2	275.5	0.347
106186	K1	113.9	0.174
106186	M4	2.3	0.096
106186	O1	89.9	0.112
106186	M6	340.7	0.075
106186	S4	166.8	0.029
106186	NU2	278	0.067
106186	S6	112.1	0.016
106186	2N2	256.9	0.046
106186	OO1	137.8	0.005
106186	LDA2	307.4	0.011
106186	M1	101.8	0.008
106186	J1	125.8	0.009
106186	RHO1	79.6	0.004
106186	Q1	77.9	0.022
106186	T2	321.7	0.016
106186	R2	324.1	0.002
106186	2Q1	66	0.003
106186	P1	112	0.058
106186	L2	275.5	0.05
106186	K2	325.3	0.076
106186	M8	58	0.029
106187	M2	294.4	1.64
106187	S2	325.1	0.289
106187	N2	272.9	0.375
106187	K1	112.4	0.183
106187	M4	344.6	0.102
106187	O1	96.9	0.116
106187	M6	344.8	0.07
106187	S4	177.8	0.029
106187	NU2	275.8	0.073
106187	S6	120.9	0.013
106187	2N2	251.5	0.05
106187	OO1	127.8	0.005
106187	LDA2	308.6	0.011
106187	M1	104.6	0.008
106187	J1	120	0.009
106187	RHO1	90.2	0.004
106187	Q1	89.1	0.022
106187	T2	323.8	0.017
106187	R2	326.4	0.002
106187	2Q1	81.5	0.003
106187	P1	111.1	0.061
106187	L2	272.9	0.054
106187	K2	327.6	0.079
106187	M8	44	0.027
106188	M2	23.7	0.81
106188	S2	68.3	0.108
106188	N2	12.8	0.198
106188	K1	173.7	0.068
106188	M4	226.2	0.051
106188	O1	174.4	0.052
106188	M6	253.1	0.066
106188	MK3	347.3	0.026
106188	S4	358.4	0.008
106188	MN4	193.5	0.023
106188	S6	291.1	0.004
106188	2N2	113.6	0.023
106188	OO1	293.6	0.004
106188	M1	276.2	0.012
106188	J1	282.5	0.008
106188	Q1	161.3	0.015
106188	2Q1	19	0.007
106188	P1	221.3	0.027
106188	2SM2	262.8	0.008
106188	M3	138.9	0.02
106188	L2	11.5	0.105
106188	2MK3	26.9	0.019
106188	K2	36.7	0.028
106188	M8	85.4	0.022
106188	MS4	268.5	0.028
106189	M2	25.6	0.783
106189	S2	52.1	0.094
106189	N2	11.9	0.169
106189	K1	184.1	0.059
106189	M4	214.6	0.086
106189	O1	155.3	0.042
106189	M6	263.7	0.07
106189	MK3	359.6	0.027
106189	S4	101.7	0.006
106189	MN4	220.5	0.034
106189	S6	117.6	0.002
106189	2N2	165.8	0.025
106189	OO1	58.2	0.004
106189	M1	280.6	0.009
106189	J1	350.5	0.004
106189	Q1	168.7	0.008
106189	2Q1	31.6	0.007
106189	P1	222.5	0.039
106189	2SM2	244	0.01
106189	M3	128.5	0.015
106189	L2	21.3	0.121
106189	2MK3	50.2	0.018
106189	M8	108.2	0.018
106189	MS4	265.4	0.031
106190	M2	29.6	1.059
106190	S2	62.3	0.104
106190	N2	1	0.246
106190	K1	205.1	0.121
106190	M4	341.6	0.087
106190	O1	185.5	0.08
106190	M6	254.7	0.079
106190	MK3	25.8	0.018
106190	S4	88	0.009
106190	MN4	342.1	0.019
106190	S6	227.8	0.004
106190	2N2	42.2	0.041
106190	OO1	355.8	0.032
106190	M1	288.4	0.003
106190	J1	245.2	0.017
106190	Q1	169	0.05
106190	2Q1	117.2	0.01
106190	P1	171.3	0.088
106190	2SM2	153.2	0.007
106190	M3	125.6	0.033
106190	L2	17.8	0.117
106190	2MK3	63.1	0.028
106190	M8	265.1	0.017
106190	MS4	332.8	0.027
106191	M2	28.5	1.445
106191	S2	52.5	0.134
106191	N2	5.7	0.317
106191	K1	211.1	0.145
106191	M4	77.3	0.113
106191	O1	196.4	0.13
106191	M6	262.6	0.111
106191	MK3	188.2	0.014
106191	S4	176.4	0.003
106191	MN4	48.8	0.04
106191	S6	238.7	0.006
106191	2N2	48.2	0.065
106191	OO1	25.3	0.028
106191	M1	340	0.018
106191	J1	233.5	0.025
106191	Q1	165.9	0.068
106191	2Q1	116.6	0.008
106191	P1	181.8	0.134
106191	2SM2	123.6	0.018
106191	M3	143.4	0.033
106191	L2	26.2	0.165
106191	2MK3	76.3	0.027
106191	M8	182.4	0.003
106191	MS4	52.7	0.037
106192	M2	23.8	0.692
106192	S2	69.9	0.11
106192	N2	11.3	0.177
106192	K1	190	0.075
106192	M4	28.2	0.038
106192	O1	181.2	0.06
106192	M6	248	0.073
106192	MK3	357.1	0.016
106192	S4	62.5	0.008
106192	MN4	11.8	0.018
106192	S6	273.7	0.005
106192	2N2	79	0.029
106192	OO1	351	0.005
106192	M1	294.4	0.014
106192	J1	215.2	0.004
106192	Q1	198.6	0.017
106192	2Q1	0.1	0.006
106192	P1	227.1	0.039
106192	2SM2	202.6	0.008
106192	M3	144.6	0.018
106192	L2	355.4	0.08
106192	2MK3	73.6	0.017
106192	K2	17.6	0.019
106192	M8	326.7	0.009
106192	MS4	16.6	0.019
106193	M2	23.9	1.277
106193	S2	57.1	0.162
106193	N2	14.5	0.295
106193	K1	174	0.126
106193	M4	48.3	0.085
106193	O1	184.7	0.078
106193	M6	265.6	0.087
106193	MK3	39.7	0.013
106193	S4	83.3	0.004
106193	MN4	44.3	0.036
106193	S6	352	0.007
106193	2N2	121.6	0.028
106193	OO1	293.2	0.007
106193	M1	279	0.016
106193	J1	278.4	0.016
106193	Q1	168.8	0.031
106193	2Q1	300.1	0.002
106193	P1	211.4	0.045
106193	2SM2	241.6	0.007
106193	M3	154.6	0.026
106193	L2	16.1	0.156
106193	2MK3	66.5	0.031
106193	K2	113.5	0.019
106193	M8	294.2	0.021
106193	MS4	38.3	0.013
106194	M2	23.1	1.332
106194	S2	45	0.176
106194	N2	10	0.305
106194	K1	181	0.12
106194	M4	68.6	0.074
106194	O1	177.3	0.089
106194	M6	244.2	0.059
106194	MK3	220.1	0.009
106194	S4	107.1	0.014
106194	MN4	43.3	0.038
106194	S6	343.3	0.009
106194	2N2	106.4	0.01
106194	OO1	36.2	0.005
106194	M1	298.1	0.019
106194	J1	261.2	0.011
106194	Q1	154.9	0.015
106194	2Q1	61.6	0.009
106194	P1	219.4	0.061
106194	2SM2	226.5	0.013
106194	M3	114	0.022
106194	L2	17.5	0.165
106194	2MK3	127.8	0.019
106194	K2	130.7	0.02
106194	M8	191.8	0.018
106194	MS4	45.5	0.026
106195	M2	15.8	1.011
106195	S2	65.1	0.127
106195	N2	7.6	0.237
106195	K1	167.3	0.088
106195	M4	335.8	0.03
106195	O1	155.8	0.058
106195	M6	230	0.13
106195	MK3	338.7	0.02
106195	S4	53.3	0.014
106195	MN4	332.5	0.009
106195	S6	282.3	0.002
106195	2N2	79.7	0.027
106195	OO1	292.1	0.024
106195	M1	220.2	0.018
106195	J1	245	0.018
106195	Q1	139.8	0.017
106195	2Q1	182.5	0.002
106195	P1	202.2	0.051
106195	2SM2	216.9	0.015
106195	M3	141.5	0.03
106195	L2	355.4	0.13
106195	2MK3	9.9	0.025
106195	K2	7.9	0.04
106195	M8	249.5	0.014
106195	MS4	336.8	0.013
106196	M2	21.1	1.454
106196	S2	54.7	0.234
106196	N2	3.2	0.355
106196	K1	195.2	0.184
106196	M4	82.4	0.242
106196	O1	188	0.131
106196	M6	221.3	0.073
106196	MK3	209.5	0.057
106196	S4	104.9	0.019
106196	MN4	54.7	0.12
106196	S6	61.3	0.009
106196	2N2	50.7	0.04
106196	OO1	105.5	0.04
106196	M1	305.7	0.044
106196	J1	295.1	0.013
106196	Q1	185.4	0.036
106196	2Q1	346.2	0.039
106196	P1	226.1	0.095
106196	2SM2	211.9	0.03
106196	M3	76.2	0.03
106196	L2	8.1	0.17
106196	2MK3	172	0.043
106196	K2	13.1	0.062
106196	M8	293	0.019
106196	MS4	85.2	0.071
106197	M2	16.8	1.773
106197	S2	40	0.175
106197	N2	353.9	0.392
106197	K1	196.7	0.166
106197	M4	32.1	0.074
106197	O1	186.8	0.162
106197	M6	230.9	0.146
106197	MK3	189	0.006
106197	S4	186.5	0.007
106197	MN4	35.9	0.047
106197	S6	167.5	0.006
106197	2N2	25.3	0.096
106197	OO1	36.5	0.037
106197	M1	305.4	0.02
106197	J1	237.8	0.026
106197	Q1	156.3	0.075
106197	2Q1	82.2	0.009
106197	P1	179.3	0.153
106197	2SM2	98.3	0.019
106197	M3	130.9	0.039
106197	L2	18.1	0.171
106197	2MK3	49.9	0.04
106197	M8	204.9	0.021
106197	MS4	346.3	0.028
106198	M2	16.3	1.833
106198	S2	41.8	0.177
106198	N2	351.2	0.407
106198	K1	194.8	0.165
106198	M4	73.1	0.154
106198	O1	184.7	0.174
106198	M6	233.6	0.134
106198	MK3	223.3	0.035
106198	S4	187.1	0.01
106198	MN4	45.1	0.062
106198	S6	224.6	0.008
106198	2N2	30.9	0.083
106198	OO1	34.6	0.055
106198	M1	329.2	0.018
106198	J1	221.1	0.039
106198	Q1	147.1	0.08
106198	2Q1	102.1	0.016
106198	P1	180	0.149
106198	2SM2	107.8	0.017
106198	M3	117	0.036
106198	L2	9.7	0.169
106198	2MK3	62.3	0.029
106198	M8	333.6	0.016
106198	MS4	36.2	0.04
106199	M2	344.6	0.305
106199	S2	243.7	0.023
106199	K1	86.8	0.007
106199	M4	67.1	0.088
106199	O1	192.1	0.023
106199	M6	234.7	0.094
106199	MK3	235.2	0.006
106199	S4	351.4	0.011
106199	S6	325.9	0.01
106199	2N2	163.4	0.003
106199	OO1	252.8	0.02
106199	2Q1	52.3	0.008
106199	2SM2	306.3	0.005
106199	2MK3	6.5	0.009
106199	M8	82.1	0.018
106199	MS4	354.3	0.028
106200	M2	10.9	0.533
106200	S2	342.7	0.032
106200	K1	144.9	0.042
106200	M4	125.4	0.109
106200	O1	240.3	0.032
106200	M6	253.7	0.065
106200	MK3	234.5	0.016
106200	S4	281.5	0.007
106200	S6	327.1	0.005
106200	2N2	234.7	0.023
106200	OO1	309.5	0.03
106200	2Q1	55.9	0.022
106200	2SM2	25.1	0.013
106200	2MK3	25.4	0.016
106200	M8	74.9	0.021
106200	MS4	328.5	0.013
106201	M2	22.1	0.728
106201	S2	327.5	0.067
106201	K1	160.7	0.097
106201	M4	226.2	0.038
106201	O1	232	0.014
106201	M6	224.3	0.013
106201	MK3	313.8	0.014
106201	S4	268.8	0.026
106201	S6	259.9	0.003
106201	2N2	232.4	0.043
106201	OO1	36.8	0.058
106201	2Q1	25.1	0.012
106201	2SM2	358.8	0.021
106201	2MK3	94.2	0.037
106201	M8	209.2	0.019
106201	MS4	242	0.053
106202	M2	16.7	1.118
106202	S2	53.5	0.102
106202	N2	356.5	0.266
106202	K1	164.6	0.161
106202	M4	303.6	0.018
106202	O1	180.5	0.085
106202	M6	266.2	0.087
106202	MK3	14.8	0.013
106202	S4	148.4	0.024
106202	MN4	258.1	0.008
106202	S6	100.3	0.005
106202	2N2	10	0.05
106202	OO1	354.5	0.007
106202	M1	291.2	0.019
106202	J1	270.4	0.014
106202	Q1	164.2	0.044
106202	2Q1	129.4	0.003
106202	2SM2	359.8	0.009
106202	M3	115.8	0.033
106202	L2	10.1	0.101
106202	2MK3	54.7	0.034
106202	M8	90	0.018
106202	MS4	307.9	0.011
106203	M2	11.4	1.031
106203	S2	34.1	0.094
106203	N2	346.5	0.214
106203	K1	167.8	0.188
106203	M4	71.1	0.11
106203	O1	202.5	0.116
106203	M6	224.3	0.111
106203	MK3	232.4	0.038
106203	S4	354.4	0.006
106203	MN4	52.1	0.059
106203	S6	220.1	0.01
106203	2N2	37	0.06
106203	OO1	37.9	0.032
106203	M1	24.2	0.008
106203	J1	217.3	0.03
106203	Q1	165.3	0.064
106203	2Q1	80.7	0.022
106203	2SM2	113.6	0.02
106203	M3	141.6	0.031
106203	L2	2.9	0.117
106203	2MK3	19.3	0.021
106203	M8	254.6	0.022
106203	MS4	60.2	0.024
106204	M2	6	0.906
106204	S2	33.4	0.12
106204	N2	344.6	0.188
106204	K1	159.5	0.093
106204	M4	159	0.147
106204	O1	116.3	0.038
106204	M6	215.7	0.106
106204	S4	50.5	0.011
106204	NU2	347.5	0.036
106204	S6	70.2	0.001
106204	2N2	323.4	0.025
106204	OO1	202.6	0.002
106204	LDA2	18.6	0.006
106204	M1	137.8	0.003
106204	J1	180.9	0.003
106204	RHO1	97.7	0.001
106204	Q1	94.8	0.007
106204	T2	32.2	0.007
106204	R2	34.4	0.001
106204	2Q1	73.4	0.001
106204	P1	156.2	0.031
106204	L2	344.7	0.027
106204	K2	35.6	0.033
106204	M8	344.4	0.007
106205	M2	1.3	1.113
106205	S2	35.1	0.123
106205	N2	339.4	0.212
106205	K1	140	0.143
106205	M4	121.3	0.092
106205	O1	157.6	0.019
106205	M6	223.1	0.138
106205	S4	80.6	0.012
106205	NU2	342.4	0.041
106205	S6	282.1	0.012
106205	2N2	317.6	0.028
106205	OO1	122.4	0.001
106205	LDA2	16.9	0.008
106205	M1	148.7	0.001
106205	J1	131.3	0.001
106205	RHO1	165.1	0.001
106205	Q1	166.2	0.004
106205	T2	33.7	0.007
106205	R2	36.5	0.001
106205	P1	141.3	0.047
106205	L2	339.4	0.03
106205	K2	37.9	0.033
106205	M8	322.9	0.032
106206	M2	359.5	0.922
106206	S2	34	0.162
106206	N2	357.2	0.207
106206	K1	177	0.074
106206	M4	34.4	0.111
106206	O1	203.3	0.121
106206	M6	217.8	0.128
106206	S4	47.1	0.009
106206	NU2	357.5	0.04
106206	S6	261.1	0.014
106206	2N2	355.1	0.027
106206	OO1	150.6	0.005
106206	LDA2	15.4	0.006
106206	M1	190.1	0.009
106206	J1	164	0.01
106206	RHO1	214.6	0.005
106206	Q1	216.3	0.023
106206	T2	32.5	0.01
106206	R2	35.3	0.001
106206	2Q1	229.4	0.003
106206	P1	178.9	0.025
106206	L2	357.3	0.03
106206	K2	36.7	0.044
106206	M8	316.7	0.051
106207	M2	4.8	1.021
106207	S2	54.6	0.146
106207	N2	353.5	0.247
106207	K1	177.4	0.074
106207	M4	233.8	0.097
106207	O1	171.6	0.064
106207	M6	195.3	0.112
106207	MK3	354.4	0.016
106207	S4	61.6	0.015
106207	MN4	226.6	0.035
106207	S6	37.8	0.005
106207	2N2	87.3	0.054
106207	OO1	302.1	0.003
106207	M1	271.3	0.004
106207	J1	339.4	0.003
106207	Q1	145.7	0.026
106207	2Q1	355.5	0.004
106207	P1	216.5	0.037
106207	2SM2	174.6	0.015
106207	M3	103.9	0.023
106207	L2	343.5	0.155
106207	2MK3	67	0.018
106207	K2	7.2	0.041
106207	M8	183.8	0.022
106207	MS4	296.6	0.045
106208	M2	17.7	1.623
106208	S2	48.4	0.26
106208	N2	3	0.375
106208	K1	167.2	0.159
106208	M4	333.4	0.105
106208	O1	165.7	0.118
106208	M6	245.3	0.102
106208	MK3	25	0.032
106208	S4	36	0.018
106208	MN4	291.7	0.046
106208	S6	256.2	0.003
106208	2N2	322.1	0.025
106208	OO1	71	0.018
106208	M1	279.3	0.019
106208	J1	160.4	0.011
106208	Q1	169.8	0.035
106208	2Q1	4.4	0.016
106208	P1	197.1	0.046
106208	2SM2	223.1	0.028
106208	M3	118.6	0.035
106208	L2	20	0.168
106208	2MK3	93.3	0.041
106208	K2	345.1	0.068
106208	M8	232.6	0.015
106208	MS4	322.4	0.063
106209	M2	15.3	1.632
106209	S2	44	0.263
106209	N2	1.5	0.389
106209	K1	172.6	0.166
106209	M4	10.3	0.071
106209	O1	171	0.132
106209	M6	225.1	0.122
106209	MK3	324.3	0.02
106209	S4	67.1	0.01
106209	MN4	325.7	0.024
106209	S6	114.2	0.002
106209	2N2	5.6	0.035
106209	OO1	64.9	0.024
106209	M1	281.2	0.021
106209	J1	200.9	0.012
106209	Q1	165.8	0.037
106209	2Q1	12	0.028
106209	P1	204.3	0.057
106209	2SM2	205.3	0.032
106209	M3	119.6	0.042
106209	L2	8.4	0.16
106209	2MK3	99.1	0.036
106209	K2	3.1	0.038
106209	M8	60.4	0.016
106209	MS4	323.2	0.05
106210	M2	1.5	1.075
106210	S2	47.3	0.207
106210	N2	350.3	0.259
106210	K1	174.1	0.079
106210	M4	266.3	0.105
106210	O1	161.8	0.073
106210	M6	182.2	0.116
106210	MK3	353.5	0.029
106210	S4	78.4	0.018
106210	MN4	269.8	0.039
106210	S6	323.7	0.006
106210	2N2	69.8	0.071
106210	OO1	220.2	0.01
106210	M1	233.6	0.009
106210	J1	351.1	0.009
106210	Q1	138.1	0.034
106210	2Q1	330.7	0.006
106210	P1	216.9	0.045
106210	2SM2	188.4	0.015
106210	M3	92.8	0.031
106210	L2	336.8	0.131
106210	2MK3	56.9	0.009
106210	K2	314	0.045
106210	M8	160.7	0.022
106210	MS4	305.9	0.048
106211	M2	13.9	1.666
106211	S2	54.5	0.26
106211	N2	357.8	0.364
106211	K1	180	0.137
106211	M4	300	0.104
106211	O1	168.8	0.103
106211	M6	222.8	0.092
106211	MK3	14.8	0.032
106211	S4	36.5	0.015
106211	MN4	286.1	0.058
106211	S6	273.4	0.007
106211	2N2	292.9	0.003
106211	OO1	105.9	0.014
106211	M1	308.7	0.011
106211	J1	10	0.007
106211	Q1	148.7	0.037
106211	2Q1	10.9	0.017
106211	P1	219.7	0.059
106211	2SM2	207.1	0.026
106211	M3	105.8	0.03
106211	L2	9.8	0.199
106211	2MK3	96.1	0.044
106211	K2	338.8	0.123
106211	M8	211.5	0.019
106211	MS4	320.1	0.058
106212	M2	7.4	1.57
106212	S2	38.5	0.221
106212	N2	354.2	0.377
106212	K1	165	0.146
106212	M4	14.1	0.074
106212	O1	171.8	0.123
106212	M6	237	0.122
106212	MK3	320.1	0.008
106212	S4	25.9	0.025
106212	MN4	344.6	0.017
106212	S6	245.4	0.003
106212	2N2	5	0.062
106212	OO1	122.1	0.014
106212	M1	289.5	0.021
106212	J1	232.6	0.02
106212	Q1	137.2	0.018
106212	2Q1	12.9	0.021
106212	P1	210.5	0.058
106212	2SM2	197.1	0.022
106212	M3	102.3	0.048
106212	L2	1.6	0.14
106212	2MK3	97.4	0.027
106212	K2	34.4	0.087
106212	M8	359.4	0.015
106212	MS4	324.4	0.057
106213	M2	356.7	1.204
106213	S2	45.2	0.179
106213	N2	342	0.276
106213	K1	175.3	0.089
106213	M4	239.2	0.08
106213	O1	165	0.074
106213	M6	194.1	0.127
106213	MK3	350.7	0.027
106213	S4	66.6	0.016
106213	MN4	235	0.04
106213	2N2	75.1	0.048
106213	OO1	172.2	0.014
106213	M1	260	0.011
106213	J1	322.8	0.007
106213	Q1	148.2	0.038
106213	2Q1	269.5	0.004
106213	P1	203.4	0.063
106213	2SM2	212.6	0.012
106213	M3	100.1	0.039
106213	L2	344.8	0.139
106213	2MK3	39.1	0.019
106213	K2	8.3	0.086
106213	M8	63.1	0.013
106213	MS4	289	0.048
106214	M2	4.2	1.846
106214	S2	37.1	0.268
106214	N2	347	0.42
106214	K1	171.4	0.16
106214	M4	266.8	0.127
106214	O1	166.1	0.116
106214	M6	208.9	0.119
106214	MK3	2.1	0.039
106214	S4	49.2	0.028
106214	MN4	258.3	0.066
106214	2N2	347.8	0.015
106214	OO1	137.2	0.014
106214	M1	290.7	0.012
106214	J1	208.6	0.007
106214	Q1	155.1	0.039
106214	2Q1	352.8	0.004
106214	P1	197.4	0.07
106214	2SM2	191.3	0.012
106214	M3	94	0.043
106214	L2	2.3	0.201
106214	2MK3	77.4	0.045
106214	K2	4.2	0.073
106214	M8	166.8	0.03
106214	MS4	291.8	0.068
106215	M2	6.8	1.917
106215	S2	40.4	0.291
106215	N2	351.7	0.427
106215	K1	173.9	0.185
106215	M4	286	0.09
106215	O1	178.5	0.128
106215	M6	215	0.116
106215	MK3	347.3	0.029
106215	S4	38.9	0.021
106215	MN4	284	0.052
106215	S6	182	0.007
106215	2N2	15.7	0.027
106215	OO1	135.6	0.012
106215	M1	296.6	0.018
106215	J1	202	0.011
106215	Q1	158.4	0.038
106215	2Q1	15.9	0.014
106215	P1	190.1	0.068
106215	2SM2	197.4	0.025
106215	M3	104.9	0.047
106215	L2	6.1	0.2
106215	2MK3	82.2	0.045
106215	K2	352	0.073
106215	M8	188	0.027
106215	MS4	305.6	0.069
106216	M2	350.6	1.173
106216	S2	27.3	0.141
106216	N2	329.5	0.254
106216	K1	173.7	0.121
106216	M4	223.1	0.141
106216	O1	157	0.077
106216	M6	191.3	0.119
106216	MK3	22.9	0.025
106216	MN4	185.8	0.031
106216	S6	171.6	0.006
106216	2N2	340.1	0.071
106216	OO1	151.1	0.006
106216	M1	268.5	0.019
106216	J1	208.5	0.035
106216	Q1	117	0.038
106216	2Q1	301.1	0.015
106216	P1	124.2	0.075
106216	2SM2	269.7	0.006
106216	M3	89.4	0.036
106216	L2	334.8	0.126
106216	2MK3	23.5	0.036
106216	M8	99.1	0.038
106216	MS4	312.5	0.016
106217	M2	2.2	1.857
106217	S2	21.9	0.198
106217	N2	334.7	0.373
106217	K1	163.4	0.149
106217	M4	236.6	0.131
106217	O1	177.1	0.115
106217	M6	191.3	0.144
106217	MK3	18	0.048
106217	S4	46.1	0.01
106217	MN4	213.1	0.056
106217	S6	196.8	0.009
106217	2N2	19.9	0.078
106217	OO1	31.6	0.024
106217	M1	324.3	0.008
106217	J1	225.9	0.025
106217	Q1	153.2	0.06
106217	2Q1	69.5	0.02
106217	P1	182.2	0.095
106217	2SM2	88.2	0.013
106217	M3	107.3	0.048
106217	L2	8.4	0.187
106217	2MK3	44.1	0.036
106217	M8	181.1	0.014
106217	MS4	296.1	0.052
106218	M2	348.2	1.183
106218	S2	34.8	0.161
106218	N2	329.7	0.283
106218	K1	175.5	0.149
106218	M4	230.1	0.166
106218	O1	144	0.112
106218	M6	185.7	0.107
106218	MK3	13.9	0.048
106218	S4	71.7	0.007
106218	MN4	227.1	0.037
106218	2N2	318	0.079
106218	OO1	305.4	0.034
106218	M1	257.9	0.012
106218	J1	157.6	0.02
106218	Q1	101.7	0.023
106218	2Q1	320.6	0.014
106218	P1	117.6	0.073
106218	2SM2	206.7	0.01
106218	M3	90.2	0.038
106218	L2	324.5	0.073
106218	2MK3	53	0.017
106218	K2	76	0.048
106218	M8	82.2	0.013
106218	MS4	320.8	0.03
106219	M2	357.3	1.719
106219	S2	25.2	0.186
106219	N2	330	0.366
106219	K1	177.6	0.152
106219	M4	249.4	0.173
106219	O1	166.9	0.109
106219	M6	208	0.133
106219	MK3	37	0.069
106219	MN4	244.8	0.053
106219	S6	181.8	0.006
106219	2N2	352.8	0.023
106219	OO1	1.1	0.019
106219	M1	291.7	0.013
106219	J1	207.7	0.014
106219	Q1	143.9	0.028
106219	2Q1	327.4	0.008
106219	P1	141.1	0.092
106219	2SM2	179.1	0.017
106219	M3	103.8	0.045
106219	L2	9	0.184
106219	2MK3	65.8	0.043
106219	K2	145.6	0.027
106219	M8	166	0.013
106219	MS4	310.3	0.037
106220	M2	358.8	1.956
106220	S2	28.5	0.198
106220	N2	331.2	0.369
106220	K1	169.7	0.176
106220	M4	229.8	0.15
106220	O1	176.2	0.12
106220	M6	187.8	0.114
106220	MK3	14.7	0.058
106220	S4	331.8	0.004
106220	MN4	184.4	0.056
106220	S6	119.8	0.009
106220	2N2	23.9	0.06
106220	OO1	17.1	0.033
106220	M1	300	0.021
106220	J1	262	0.017
106220	Q1	147.5	0.058
106220	2Q1	89.4	0.014
106220	P1	158.4	0.085
106220	2SM2	141.4	0.009
106220	M3	90.7	0.05
106220	L2	5.8	0.23
106220	2MK3	42.1	0.04
106220	K2	88.2	0.05
106220	M8	118	0.052
106220	MS4	268.9	0.043
106221	M2	116.4	0.449
106221	S2	252.3	0.07
106221	N2	80	0.065
106221	K1	336.5	0.054
106221	M4	303.8	0.115
106221	O1	271.8	0.033
106221	M6	182.1	0.042
106221	MK3	97.7	0.038
106221	S4	6.7	0.01
106221	MN4	283.2	0.033
106221	S6	211.3	0.014
106221	2N2	188.1	0.038
106221	OO1	107.4	0.022
106221	M1	341.6	0.01
106221	J1	40	0.015
106221	Q1	18.6	0.004
106221	2Q1	69	0.019
106221	P1	253.3	0.046
106221	2SM2	278.7	0.018
106221	M3	216.4	0.024
106221	L2	81.8	0.089
106221	2MK3	85	0.034
106221	K2	229.3	0.116
106221	M8	210.9	0.023
106221	MS4	344.9	0.036
106222	M2	114.2	1.541
106222	S2	206.9	0.071
106222	N2	64.4	0.299
106222	K1	281.9	0.139
106222	M4	67.3	0.278
106222	O1	5.9	0.171
106222	M6	236.9	0.172
106222	S4	213.3	0.04
106222	NU2	71.1	0.058
106222	S6	140.2	0.017
106222	2N2	14.7	0.04
106222	OO1	197.9	0.007
106222	LDA2	157.1	0.011
106222	M1	323.8	0.012
106222	J1	239.9	0.014
106222	RHO1	41.9	0.006
106222	Q1	47.7	0.033
106222	T2	206.8	0.004
106222	R2	206.9	0.001
106222	2Q1	89.7	0.004
106222	P1	281.8	0.046
106222	L2	163.8	0.043
106222	K2	206.9	0.019
106222	M8	152.8	0.112
106223	M2	310.8	0.944
106223	S2	332.2	0.137
106223	N2	288.3	0.191
106223	K1	145.2	0.074
106223	M4	173.4	0.12
106223	O1	154.5	0.078
106223	M6	77.4	0.112
106223	MK3	304.5	0.014
106223	S4	351.9	0.007
106223	MN4	156.4	0.022
106223	S6	68.5	0.009
106223	2N2	319.8	0.053
106223	OO1	164.1	0.011
106223	M1	205.5	0.014
106223	J1	199.5	0.022
106223	Q1	143.9	0.029
106223	P1	122.4	0.031
106223	2SM2	57.2	0.01
106223	M3	7.4	0.023
106223	L2	311.2	0.11
106223	2MK3	321	0.04
106223	K2	256	0.039
106223	M8	257.3	0.019
106223	MS4	241.4	0.028
106224	M2	331.6	1.675
106224	S2	354.9	0.23
106224	N2	304	0.341
106224	K1	151.8	0.159
106224	M4	217.7	0.173
106224	O1	144.2	0.084
106224	M6	108.4	0.114
106224	MK3	17.9	0.066
106224	S4	32.9	0.012
106224	MN4	195.6	0.051
106224	S6	37.3	0.004
106224	2N2	349	0.048
106224	OO1	358.4	0.008
106224	M1	268.8	0.012
106224	J1	222.2	0.024
106224	Q1	128	0.048
106224	2Q1	347.1	0.01
106224	P1	134.4	0.06
106224	2SM2	35.8	0.004
106224	M3	51.8	0.047
106224	L2	344.1	0.185
106224	2MK3	21.9	0.049
106224	K2	310.8	0.063
106224	M8	32.4	0.032
106224	MS4	231.3	0.05
106225	M2	334.8	1.814
106225	S2	2	0.243
106225	N2	303.6	0.351
106225	K1	149	0.172
106225	M4	178.3	0.15
106225	O1	152.6	0.111
106225	M6	88.9	0.057
106225	MK3	350.1	0.06
106225	MN4	167.9	0.033
106225	S6	70.9	0.006
106225	2N2	10.5	0.053
106225	OO1	53.7	0.041
106225	M1	288.5	0.018
106225	J1	213.5	0.011
106225	Q1	134.5	0.054
106225	2Q1	23.9	0.018
106225	P1	161.6	0.045
106225	2SM2	84.1	0.011
106225	M3	58.7	0.054
106225	L2	352.6	0.199
106225	2MK3	40.8	0.056
106225	K2	345.1	0.083
106225	M8	107.4	0.024
106225	MS4	216.8	0.04
106226	M2	342.8	1.209
106226	S2	32	0.203
106226	N2	334.3	0.293
106226	K1	160.2	0.089
106226	M4	184.7	0.174
106226	O1	162.3	0.049
106226	M6	124.9	0.101
106226	MK3	304.6	0.052
106226	S4	31.5	0.02
106226	MN4	177.7	0.086
106226	S6	230.8	0.004
106226	2N2	47.2	0.097
106226	OO1	281.9	0.016
106226	M1	220.1	0.005
106226	J1	189.8	0.018
106226	Q1	123.1	0.025
106226	2Q1	198.2	0.003
106226	P1	196.6	0.051
106226	2SM2	130	0.017
106226	M3	70.4	0.036
106226	L2	315	0.13
106226	2MK3	351.5	0.034
106226	K2	27.9	0.042
106226	M8	347.7	0.015
106226	MS4	235	0.081
106227	M2	348.8	1.324
106227	S2	32.6	0.232
106227	N2	339.4	0.309
106227	K1	167.6	0.104
106227	M4	191.6	0.17
106227	O1	166.4	0.062
106227	M6	147.5	0.087
106227	MK3	316.6	0.05
106227	S4	57	0.017
106227	MN4	179.6	0.088
106227	S6	162.3	0.003
106227	2N2	47.5	0.058
106227	OO1	274	0.024
106227	M1	194	0.009
106227	J1	232.6	0.008
106227	Q1	132.3	0.029
106227	2Q1	232.4	0.005
106227	P1	205.8	0.055
106227	2SM2	154.4	0.02
106227	M3	68.3	0.029
106227	L2	337.3	0.137
106227	2MK3	2.7	0.033
106227	K2	329.1	0.055
106227	M8	51.4	0.02
106227	MS4	243.7	0.074
106228	M2	351.1	1.544
106228	S2	25.5	0.241
106228	N2	339.1	0.352
106228	K1	154.6	0.104
106228	M4	209.5	0.195
106228	O1	153.4	0.074
106228	M6	166.4	0.128
106228	MK3	337.1	0.044
106228	S4	58	0.008
106228	MN4	204.1	0.083
106228	S6	317.5	0.005
106228	2N2	319.3	0.018
106228	OO1	235.5	0.01
106228	M1	233	0.011
106228	J1	247.9	0.003
106228	Q1	124.4	0.024
106228	2Q1	352	0.01
106228	P1	206.9	0.036
106228	2SM2	183.3	0.022
106228	M3	86	0.042
106228	L2	355.5	0.161
106228	2MK3	25.3	0.04
106228	K2	326.8	0.076
106228	M8	99.5	0.037
106228	MS4	246.8	0.085
106229	M2	345	0.956
106229	S2	19.2	0.13
106229	K1	161.6	0.115
106229	M4	176.7	0.17
106229	O1	200.4	0.057
106229	M6	98.2	0.056
106229	MK3	323.2	0.048
106229	S4	14.5	0.011
106229	S6	252.2	0.009
106229	2N2	325.3	0.042
106229	OO1	95	0.008
106229	2Q1	245.1	0.007
106229	2SM2	36.9	0.019
106229	2MK3	325.3	0.039
106229	M8	68	0.012
106229	MS4	244.9	0.038
106230	M2	345.6	1.238
106230	S2	13.1	0.142
106230	K1	149	0.099
106230	M4	209.1	0.125
106230	O1	191.2	0.061
106230	M6	180.6	0.041
106230	MK3	349.1	0.03
106230	S4	22.4	0.014
106230	S6	237.6	0.011
106230	2N2	56.4	0.037
106230	OO1	216.7	0.011
106230	2Q1	109.1	0.012
106230	2SM2	112.4	0.026
106230	2MK3	9.2	0.023
106230	M8	128.4	0.025
106230	MS4	277.3	0.031
106231	M2	346.2	1.294
106231	S2	16.8	0.126
106231	K1	135.2	0.139
106231	M4	343.5	0.082
106231	O1	147	0.065
106231	M6	195.4	0.095
106231	MK3	67.1	0.041
106231	S4	349.3	0.011
106231	S6	164.4	0.009
106231	2N2	25.6	0.06
106231	OO1	359.5	0.023
106231	2Q1	310.2	0.006
106231	2SM2	122.2	0.028
106231	2MK3	34.6	0.047
106231	M8	143.9	0.009
106231	MS4	320.1	0.03
106232	M2	336.2	1.499
106232	S2	24.8	0.243
106232	K1	117.6	0.1
106232	M4	289.4	0.204
106232	O1	146.2	0.085
106232	M6	164.8	0.137
106232	MK3	317	0.019
106232	S4	328.8	0.025
106232	S6	84	0.01
106232	2N2	38.9	0.06
106232	OO1	302.3	0.027
106232	2Q1	356.8	0.045
106232	2SM2	314.8	0.037
106232	2MK3	42.6	0.048
106232	M8	203	0.053
106232	MS4	292	0.051
106233	M2	334.5	1.259
106233	S2	21.2	0.215
106233	K1	131.6	0.071
106233	M4	281.5	0.132
106233	O1	163.2	0.072
106233	M6	139.5	0.138
106233	MK3	271.9	0.033
106233	S4	17.6	0.024
106233	S6	314	0.008
106233	2N2	45	0.077
106233	OO1	132.2	0.04
106233	2Q1	14.7	0.016
106233	2SM2	267.2	0.046
106233	2MK3	1.1	0.041
106233	M8	167.6	0.042
106233	MS4	269.9	0.051
106234	M2	331.5	0.947
106234	S2	14.4	0.228
106234	K1	130	0.065
106234	M4	218	0.025
106234	O1	161.2	0.052
106234	M6	145.3	0.042
106234	MK3	259.1	0.041
106234	S4	102	0.014
106234	S6	136.5	0.01
106234	2N2	9.5	0.092
106234	OO1	249.9	0.023
106234	2Q1	279.7	0.028
106234	2SM2	297.6	0.025
106234	2MK3	180.6	0.006
106234	M8	254.7	0.026
106234	MS4	262.7	0.044
106235	M2	330.7	2.022
106235	S2	5.7	0.263
106235	N2	307.9	0.406
106235	K1	150.8	0.184
106235	M4	234	0.094
106235	O1	160.5	0.129
106235	M6	150.4	0.083
106235	MK3	335.2	0.041
106235	S4	118.6	0.01
106235	MN4	287.5	0.034
106235	S6	251.9	0.017
106235	2N2	336.8	0.062
106235	OO1	43.2	0.05
106235	M1	315.3	0.01
106235	J1	248.2	0.011
106235	Q1	127.6	0.054
106235	2Q1	105.5	0.031
106235	P1	152.1	0.095
106235	2SM2	109	0.016
106235	M3	94.3	0.051
106235	L2	337	0.186
106235	2MK3	28.6	0.045
106235	K2	6.1	0.085
106235	M8	178.8	0.013
106235	MS4	26.7	0.021
106236	M2	332.5	1.728
106236	S2	25	0.185
106236	N2	311.5	0.402
106236	K1	160.8	0.17
106236	M4	232.3	0.145
106236	O1	155.6	0.107
106236	M6	130.5	0.015
106236	MK3	17.4	0.062
106236	S4	208.1	0.015
106236	MN4	250.4	0.053
106236	S6	167.2	0.008
106236	2N2	326.4	0.065
106236	OO1	5.8	0.036
106236	M1	255.7	0.013
106236	J1	223.5	0.014
106236	Q1	106.8	0.045
106236	2Q1	89.1	0.013
106236	P1	136.3	0.093
106236	2SM2	192.2	0.026
106236	M3	84.2	0.042
106236	L2	323.7	0.102
106236	2MK3	64.1	0.052
106236	K2	57.7	0.121
106236	M8	246.9	0.021
106236	MS4	276.1	0.023
106237	M2	332	1.434
106237	S2	31	0.186
106237	N2	306.6	0.321
106237	K1	155.7	0.186
106237	M4	263.5	0.044
106237	O1	152.5	0.099
106237	M6	309	0.008
106237	MK3	25.3	0.048
106237	S4	140.9	0.004
106237	MN4	276.7	0.052
106237	S6	205.5	0.007
106237	2N2	312.4	0.061
106237	OO1	320.3	0.012
106237	M1	272.9	0.008
106237	J1	165.3	0.012
106237	Q1	100.4	0.033
106237	2Q1	65	0.011
106237	P1	96.5	0.06
106237	2SM2	164.5	0.01
106237	M3	82.6	0.037
106237	L2	330.8	0.082
106237	2MK3	53.3	0.047
106237	K2	42.4	0.132
106237	M8	272.5	0.039
106237	MS4	333.2	0.021
106238	M2	300.6	0.607
106238	S2	322	0.1
106238	N2	280.4	0.162
106238	K1	118	0.056
106238	M4	345.3	0.099
106238	O1	134.1	0.051
106238	M6	357.7	0.061
106238	MK3	147.3	0.031
106238	S4	289.2	0.006
106238	MN4	313.6	0.044
106238	S6	75.4	0.005
106238	2N2	271.5	0.029
106238	OO1	144.2	0.005
106238	M1	240.2	0.009
106238	J1	59.2	0.005
106238	Q1	100.4	0.009
106238	2Q1	295.2	0.009
106238	P1	164.7	0.015
106238	2SM2	188.8	0.014
106238	M3	342.9	0.023
106238	L2	294.2	0.021
106238	2MK3	124.9	0.012
106238	K2	338.1	0.035
106238	M8	122.3	0.007
106238	MS4	354.1	0.007
106239	M2	296.5	0.784
106239	S2	313.2	0.132
106239	N2	277	0.209
106239	K1	115.3	0.072
106239	M4	329.8	0.121
106239	O1	122.8	0.055
106239	M6	357.1	0.083
106239	MK3	139.2	0.028
106239	S4	286.7	0.011
106239	MN4	299.1	0.053
106239	S6	102.5	0.005
106239	2N2	278.6	0.036
106239	OO1	163.6	0.009
106239	M1	198.5	0.009
106239	J1	186.8	0.007
106239	Q1	104	0.014
106239	2Q1	293.2	0.006
106239	P1	149.5	0.031
106239	2SM2	186	0.011
106239	M3	345.3	0.023
106239	L2	278.1	0.04
106239	2MK3	111.4	0.015
106239	K2	359	0.027
106239	M8	79.3	0.007
106239	MS4	324	0.008
106240	M2	279.4	0.626
106240	S2	305.9	0.069
106240	N2	259.1	0.154
106240	K1	114.8	0.043
106240	M4	349.7	0.071
106240	O1	112.6	0.035
106240	M6	302.9	0.072
106240	MK3	175.5	0.025
106240	S4	15	0.003
106240	MN4	313.7	0.022
106240	S6	317.7	0.01
106240	2N2	272.1	0.048
106240	OO1	304.5	0.005
106240	M1	206.9	0.011
106240	J1	127.8	0.01
106240	Q1	57.1	0.024
106240	2Q1	39.8	0.008
106240	P1	112.2	0.03
106240	2SM2	351.3	0.008
106240	M3	351.2	0.022
106240	L2	228.3	0.046
106240	2MK3	242.2	0.02
106240	K2	84.3	0.011
106240	M8	26.5	0.02
106240	MS4	137.2	0.013
106241	M2	322.3	1.627
106241	S2	353.6	0.303
106241	N2	308.2	0.404
106241	K1	123.1	0.145
106241	M4	200	0.057
106241	O1	116.7	0.089
106241	M6	77.1	0.05
106241	MK3	265.9	0.033
106241	S4	350.9	0.006
106241	MN4	200.5	0.025
106241	S6	321.9	0.003
106241	2N2	318.5	0.08
106241	OO1	255.1	0.016
106241	M1	206.2	0.022
106241	J1	173.1	0.015
106241	Q1	90.5	0.031
106241	2Q1	342.2	0.008
106241	P1	157.7	0.061
106241	2SM2	157.7	0.014
106241	M3	31.5	0.049
106241	L2	321.8	0.102
106241	2MK3	32.2	0.034
106241	K2	332.5	0.056
106241	M8	119.7	0.008
106241	MS4	200.7	0.044
106242	M2	326.7	2.17
106242	S2	355.8	0.361
106242	N2	311.1	0.526
106242	K1	127.3	0.178
106242	M4	168	0.11
106242	O1	121.1	0.12
106242	M6	106.9	0.089
106242	MK3	291.3	0.044
106242	S4	52.4	0.01
106242	MN4	168.9	0.052
106242	S6	349.6	0.006
106242	2N2	314.8	0.051
106242	M1	215.3	0.018
106242	J1	171.3	0.016
106242	Q1	87.9	0.034
106242	2Q1	44.6	0.007
106242	P1	171.8	0.063
106242	2SM2	178.6	0.014
106242	M3	36.8	0.058
106242	L2	331.7	0.185
106242	2MK3	15.2	0.05
106242	K2	338.1	0.083
106242	M8	261.9	0.005
106242	MS4	198.6	0.067
106243	M2	329.9	2.467
106243	S2	3.6	0.366
106243	N2	311.6	0.566
106243	K1	128.7	0.168
106243	M4	152.1	0.251
106243	O1	130.9	0.133
106243	M6	119.8	0.126
106243	MK3	292.8	0.076
106243	S4	12.7	0.015
106243	MN4	146.3	0.091
106243	S6	343.7	0.006
106243	2N2	299.1	0.031
106243	OO1	273.6	0.008
106243	M1	218.2	0.018
106243	J1	150.5	0.008
106243	Q1	101.2	0.048
106243	2Q1	11.9	0.013
106243	P1	188.2	0.058
106243	2SM2	197.8	0.024
106243	M3	51.4	0.061
106243	L2	337.7	0.216
106243	2MK3	355.7	0.061
106243	K2	339.5	0.14
106243	M8	291.1	0.02
106243	MS4	195.7	0.113
106244	M2	316.9	1.394
106244	S2	311.5	0.446
106244	N2	289.9	0.258
106244	K1	158.9	0.19
106244	M4	260	0.058
106244	O1	162.3	0.051
106244	M6	73.3	0.161
106244	MK3	43.5	0.033
106244	S4	74.6	0.02
106244	MN4	253	0.037
106244	S6	289.3	0.002
106244	2N2	332.1	0.094
106244	OO1	19.9	0.024
106244	M1	345.4	0.026
106244	J1	205	0.023
106244	Q1	122.6	0.05
106244	P1	73.4	0.115
106244	2SM2	283.5	0.018
106244	M3	77.5	0.013
106244	L2	0.3	0.122
106244	2MK3	3.2	0.044
106244	K2	245.4	0.363
106244	M8	230.3	0.038
106244	MS4	41.8	0.013
106245	M2	315.8	1.183
106245	S2	316.6	0.366
106245	N2	288.4	0.23
106245	K1	158.3	0.204
106245	M4	275.5	0.027
106245	O1	151	0.054
106245	M6	71.6	0.13
106245	MK3	42.9	0.028
106245	S4	51.1	0.009
106245	MN4	260.9	0.026
106245	S6	338.9	0.002
106245	2N2	329.7	0.081
106245	OO1	42.5	0.023
106245	M1	337.5	0.024
106245	J1	217.5	0.041
106245	Q1	119	0.041
106245	2Q1	124.6	0.006
106245	P1	68.5	0.145
106245	2SM2	292.4	0.015
106245	M3	122.6	0.013
106245	L2	357.9	0.078
106245	2MK3	354.3	0.041
106245	K2	253.6	0.28
106245	M8	216.9	0.035
106245	MS4	348.7	0.008
106246	M2	318	1.11
106246	S2	313.3	0.217
106246	N2	288.6	0.224
106246	K1	152.5	0.177
106246	M4	321.4	0.141
106246	O1	157	0.067
106246	M6	66.3	0.098
106246	MK3	65.1	0.042
106246	S4	72.2	0.004
106246	MN4	275.5	0.033
106246	S6	286.3	0.013
106246	2N2	334	0.056
106246	OO1	31.3	0.023
106246	M1	301.7	0.032
106246	J1	221.6	0.039
106246	Q1	102.3	0.048
106246	2Q1	236.2	0.003
106246	P1	75.6	0.122
106246	2SM2	15.4	0.015
106246	M3	309.9	0.01
106246	L2	354.6	0.082
106246	2MK3	14.2	0.026
106246	K2	240.4	0.119
106246	M8	185.8	0.034
106246	MS4	301.8	0.012
106247	M2	309.2	1.075
106247	S2	354.4	0.245
106247	K1	74.6	0.105
106247	M4	97.9	0.191
106247	O1	95	0.072
106247	M6	122.3	0.024
106247	MK3	194.3	0.032
106247	S4	1.5	0.023
106247	S6	272.6	0.009
106247	2N2	39.7	0.127
106247	OO1	256.3	0.041
106247	2Q1	305.6	0.025
106247	2SM2	185	0.042
106247	2MK3	349.8	0.015
106247	M8	275.8	0.025
106247	MS4	178.7	0.069
106248	M2	290.5	0.635
106248	S2	331.6	0.188
106248	K1	29	0.074
106248	M4	76.8	0.183
106248	O1	99.9	0.043
106248	M6	227.9	0.065
106248	MK3	181.8	0.066
106248	S4	315.5	0.032
106248	S6	112.5	0.008
106248	2N2	359.5	0.126
106248	OO1	228.6	0.021
106248	2Q1	253.1	0.017
106248	2SM2	126.3	0.047
106248	2MK3	164.7	0.01
106248	M8	21.2	0.031
106248	MS4	122.3	0.082
106249	M2	182.2	0.43
106249	S2	200.4	0.062
106249	N2	155.5	0.101
106249	K1	250.1	0.145
106249	M4	255.6	0.007
106249	O1	241	0.108
106249	M6	28.8	0.005
106249	MK3	350.5	0.009
106249	S4	156.8	0.006
106249	MN4	215.7	0.003
106249	S6	161.9	0.003
106249	2N2	138.2	0.004
106249	OO1	152.4	0.019
106249	M1	325.1	0.022
106249	J1	82.8	0.003
106249	Q1	104.2	0.027
106249	2Q1	0.4	0.028
106249	P1	269.7	0.03
106249	2SM2	115.7	0.01
106249	M3	296	0.012
106249	L2	216.3	0.052
106249	2MK3	346.5	0.015
106249	K2	286.8	0.019
106249	M8	3.1	0.002
106249	MS4	244.9	0.01
106250	M2	188.9	0.477
106250	S2	211.9	0.068
106250	N2	159.3	0.109
106250	K1	256.7	0.164
106250	M4	317.4	0.008
106250	O1	243.9	0.139
106250	M6	199.2	0.002
106250	MK3	33.1	0.008
106250	S4	176.3	0.003
106250	MN4	281	0.002
106250	S6	115.1	0.005
106250	2N2	231.6	0.006
106250	OO1	168.1	0.016
106250	M1	328.9	0.025
106250	J1	33.4	0.006
106250	Q1	102.8	0.013
106250	2Q1	1.6	0.037
106250	P1	276.6	0.056
106250	2SM2	148.6	0.016
106250	M3	324.2	0.011
106250	L2	227.3	0.055
106250	2MK3	348.8	0.018
106250	K2	270.5	0.024
106250	M8	17.4	0.002
106250	MS4	285	0.003
106251	M2	281.7	0.501
106251	S2	322.3	0.073
106251	N2	259.6	0.12
106251	K1	271.8	0.096
106251	M4	243.6	0.025
106251	O1	304.6	0.056
106251	M6	171.1	0.012
106251	MK3	166.2	0.015
106251	S4	111.1	0.005
106251	MN4	217.3	0.012
106251	NU2	296.9	0.022
106251	S6	342.3	0.003
106251	MU2	118.1	0.024
106251	2N2	331.7	0.012
106251	OO1	338.8	0.016
106251	LDA2	328.2	0.013
106251	M1	154.9	0.011
106251	J1	336.4	0.02
106251	RHO1	308.7	0.009
106251	Q1	271.6	0.027
106251	2Q1	95.9	0.009
106251	P1	286.9	0.027
106251	2SM2	106.6	0.018
106251	M3	4.7	0.019
106251	L2	341.2	0.041
106251	2MK3	231.1	0.01
106251	K2	282.3	0.035
106251	M8	105.7	0.009
106251	MS4	282.2	0.014
106252	M2	276.2	0.402
106252	S2	308.2	0.066
106252	N2	249.3	0.106
106252	K1	262	0.076
106252	M4	56.7	0.004
106252	O1	288.9	0.059
106252	M6	335.8	0.004
106252	MK3	114.6	0.004
106252	S4	51.3	0.003
106252	MN4	295.2	0.003
106252	NU2	284.5	0.03
106252	S6	175.6	0.001
106252	MU2	311.8	0.006
106252	2N2	223.9	0.021
106252	OO1	116.8	0.014
106252	LDA2	239.9	0.018
106252	M1	259.9	0.009
106252	J1	106.9	0.006
106252	RHO1	171.2	0.025
106252	Q1	60.7	0.005
106252	2Q1	171.6	0.008
106252	P1	263.6	0.039
106252	2SM2	215.6	0.008
106252	M3	180	0.003
106252	L2	287.4	0.037
106252	2MK3	117.3	0.002
106252	K2	294.7	0.022
106252	M8	241.5	0.003
106252	MS4	318.8	0.006
106253	M2	132.5	0.604
106253	S2	150.3	0.103
106253	N2	117.9	0.128
106253	K1	236.6	0.127
106253	M4	247.2	0.014
106253	O1	260.4	0.081
106253	M6	182.7	0.013
106253	MK3	24.2	0.01
106253	S4	222.8	0.002
106253	MN4	183.6	0.008
106253	NU2	136.7	0.029
106253	S6	190.2	0.006
106253	MU2	4.1	0.006
106253	2N2	85	0.016
106253	OO1	299.3	0.011
106253	LDA2	179.1	0.009
106253	M1	356.8	0.004
106253	J1	120.8	0.013
106253	RHO1	272.2	0.015
106253	Q1	249.8	0.003
106253	2Q1	49.8	0.026
106253	P1	220.1	0.062
106253	2SM2	245.2	0.005
106253	M3	154.7	0.006
106253	L2	132.6	0.036
106253	2MK3	305.7	0.009
106253	K2	172.9	0.026
106253	M8	255.5	0.001
106253	MS4	335.4	0.011
106254	M2	130	0.621
106254	S2	154.4	0.078
106254	N2	110.4	0.167
106254	K1	213.4	0.155
106254	M4	238	0.019
106254	O1	238.6	0.073
106254	M6	187.5	0.011
106254	MK3	337.2	0.029
106254	S4	236.9	0.003
106254	MN4	220.9	0.009
106254	NU2	86.4	0.026
106254	S6	101.1	0.002
106254	MU2	313.3	0.01
106254	2N2	49.4	0.024
106254	OO1	285.7	0.013
106254	LDA2	147.7	0.014
106254	M1	305.5	0.002
106254	J1	28.7	0.007
106254	RHO1	257.5	0.009
106254	Q1	220.2	0.029
106254	2Q1	65.1	0.011
106254	P1	217	0.021
106254	2SM2	121.8	0.019
106254	M3	199.4	0.011
106254	L2	107.2	0.044
106254	2MK3	1.7	0.022
106254	K2	165.5	0.026
106254	M8	247.1	0.002
106254	MS4	230	0.006
106255	M2	192.6	0.5
106255	S2	189.3	0.13
106255	N2	179.2	0.078
106255	K1	236.8	0.041
106255	M4	258.4	0.013
106255	O1	276.8	0.088
106255	M6	40.2	0.01
106255	MK3	24.3	0.01
106255	S4	178.8	0.003
106255	MN4	141.9	0.016
106255	S6	176.1	0.003
106255	2N2	160.7	0.007
106255	OO1	11.6	0.001
106255	M1	96.1	0.023
106255	J1	180.9	0.02
106255	Q1	70.6	0.01
106255	2Q1	284.3	0.024
106255	P1	169.7	0.078
106255	2SM2	126.9	0.008
106255	M3	155.6	0.01
106255	L2	236.4	0.025
106255	2MK3	8.8	0.014
106255	K2	252.2	0.065
106255	M8	244.7	0.003
106255	MS4	355.3	0.004
106256	M2	190	0.55
106256	S2	208	0.097
106256	N2	183.4	0.102
106256	K1	202.3	0.019
106256	M4	177.6	0.004
106256	O1	277	0.098
106256	M6	50.4	0.013
106256	MK3	350	0.015
106256	S4	194.4	0.014
106256	MN4	155.8	0.02
106256	S6	46.3	0.008
106256	2N2	314.3	0.033
106256	OO1	330	0.015
106256	M1	70.5	0.03
106256	J1	246.1	0.025
106256	Q1	110	0.026
106256	2Q1	284.7	0.043
106256	P1	162.1	0.125
106256	2SM2	333.5	0.005
106256	M3	184.7	0.013
106256	L2	204.3	0.03
106256	2MK3	333.2	0.006
106256	K2	270.9	0.032
106256	M8	258.1	0.003
106256	MS4	85.5	0.003
106257	M2	32.6	0.53
106257	S2	61.5	0.135
106257	N2	31.8	0.141
106257	K1	224.6	0.11
106257	M4	260.3	0.04
106257	O1	231	0.087
106257	M6	253	0.038
106257	MK3	356.6	0.018
106257	S4	337.2	0.011
106257	MN4	239.3	0.023
106257	NU2	344.9	0.055
106257	S6	278.8	0.008
106257	MU2	2	0.073
106257	2N2	81.2	0.009
106257	OO1	323.4	0.014
106257	LDA2	270.3	0.012
106257	M1	150.7	0.019
106257	J1	270.5	0.012
106257	RHO1	137.8	0.051
106257	Q1	218.4	0.047
106257	2Q1	82.1	0.023
106257	P1	226.4	0.067
106257	2SM2	142.2	0.011
106257	M3	146.3	0.007
106257	L2	147.2	0.01
106257	2MK3	310.9	0.012
106257	K2	93.4	0.04
106257	M8	242	0.011
106257	MS4	74	0.018
106258	M2	34.5	0.68
106258	S2	56.8	0.188
106258	N2	32.7	0.192
106258	K1	221.5	0.131
106258	M4	292.7	0.049
106258	O1	234.8	0.089
106258	M6	269.5	0.036
106258	MK3	162	0.003
106258	S4	356.2	0.015
106258	MN4	264.9	0.028
106258	NU2	349.6	0.082
106258	S6	284.8	0.011
106258	MU2	17.8	0.083
106258	2N2	269.6	0.016
106258	OO1	4.5	0.028
106258	LDA2	278.6	0.026
106258	M1	143.6	0.024
106258	J1	219.6	0.007
106258	RHO1	119	0.059
106258	Q1	202	0.064
106258	2Q1	42.3	0.031
106258	P1	227	0.077
106258	2SM2	131.7	0.016
106258	M3	177.2	0.011
106258	L2	156.8	0.008
106258	2MK3	312.7	0.015
106258	K2	56.3	0.077
106258	M8	266.3	0.012
106258	MS4	32.3	0.016
106259	M2	32.5	0.928
106259	S2	58.4	0.209
106259	N2	13.3	0.246
106259	K1	210.9	0.172
106259	M4	19	0.024
106259	O1	231.6	0.087
106259	M6	1.1	0.004
106259	MK3	246.8	0.035
106259	S4	354.5	0.015
106259	MN4	310.8	0.009
106259	NU2	328.3	0.059
106259	S6	225.6	0.009
106259	MU2	336.6	0.049
106259	2N2	359.2	0.035
106259	OO1	329	0.03
106259	LDA2	332.5	0.041
106259	M1	67.8	0.029
106259	J1	185.9	0.037
106259	RHO1	122.9	0.072
106259	Q1	178.3	0.07
106259	2Q1	24.9	0.028
106259	P1	233.1	0.09
106259	2SM2	268.6	0.02
106259	M3	70.9	0.012
106259	L2	159.4	0.029
106259	2MK3	12.3	0.011
106259	K2	55.8	0.077
106259	M8	1	0.01
106259	MS4	84.5	0.014
106260	M2	30.8	1.05
106260	S2	68.8	0.199
106260	N2	9.4	0.215
106260	K1	178.8	0.231
106260	M4	30.5	0.063
106260	O1	209.7	0.126
106260	M6	98.2	0.048
106260	MK3	195.1	0.027
106260	S4	273.4	0.008
106260	MN4	6	0.018
106260	NU2	22.4	0.049
106260	S6	166.4	0.005
106260	MU2	304.6	0.044
106260	2N2	35.9	0.044
106260	OO1	288.4	0.03
106260	LDA2	292.4	0.061
106260	M1	169.3	0.002
106260	J1	284.3	0.025
106260	RHO1	127.5	0.107
106260	Q1	219.6	0.093
106260	2Q1	37.2	0.027
106260	P1	230.2	0.055
106260	2SM2	316.5	0.013
106260	M3	70	0.005
106260	L2	133.9	0.11
106260	2MK3	194	0.015
106260	K2	103.3	0.075
106260	M8	79.3	0.013
106260	MS4	67.6	0.012
106261	M2	345	1.088
106261	S2	49.8	0.28
106261	N2	343.4	0.35
106261	K1	127.7	0.119
106261	M4	155.4	0.129
106261	O1	156.4	0.119
106261	M6	1.9	0.073
106261	MK3	260.9	0.038
106261	S4	240.2	0.018
106261	MN4	118.4	0.016
106261	NU2	324.7	0.04
106261	S6	68	0.01
106261	MU2	0.4	0.212
106261	2N2	143.9	0.014
106261	OO1	97.2	0.049
106261	LDA2	270.2	0.121
106261	M1	183.2	0.026
106261	J1	209.3	0.016
106261	RHO1	97.6	0.038
106261	Q1	209	0.082
106261	2Q1	106.9	0.029
106261	P1	92.9	0.027
106261	2SM2	281.6	0.013
106261	M3	98.1	0.03
106261	L2	223.8	0.083
106261	2MK3	293.4	0.025
106261	K2	41.6	0.153
106261	M8	295.3	0.018
106261	MS4	141.8	0.024
106262	M2	354.8	1.514
106262	S2	56.5	0.254
106262	N2	348.7	0.362
106262	K1	121.8	0.162
106262	M4	189	0.057
106262	O1	167.2	0.119
106262	M6	14.2	0.078
106262	MK3	209.1	0.012
106262	S4	292.1	0.024
106262	MN4	64.4	0.005
106262	NU2	318.5	0.066
106262	S6	294.7	0.008
106262	MU2	18.2	0.134
106262	2N2	275.2	0.016
106262	OO1	134.1	0.031
106262	LDA2	320.9	0.122
106262	M1	279.7	0.014
106262	J1	302.6	0.036
106262	RHO1	175.9	0.041
106262	Q1	229.8	0.031
106262	2Q1	95.2	0.019
106262	P1	148.1	0.036
106262	2SM2	292.6	0.026
106262	M3	74.8	0.02
106262	L2	275.3	0.056
106262	2MK3	4.1	0.033
106262	K2	69.1	0.144
106262	M8	36.2	0.035
106262	MS4	149.9	0.025
106263	M2	3.3	1.652
106263	S2	41.7	0.211
106263	N2	343.7	0.326
106263	K1	130.2	0.142
106263	M4	227.3	0.045
106263	O1	159.7	0.104
106263	M6	346.2	0.021
106263	MK3	54	0.035
106263	S4	307.2	0.023
106263	MN4	2.2	0.009
106263	NU2	350.8	0.061
106263	S6	337.6	0.01
106263	MU2	89.3	0.037
106263	2N2	285.9	0.066
106263	OO1	230.1	0.018
106263	LDA2	355.9	0.049
106263	M1	248.9	0.012
106263	J1	309.1	0.03
106263	RHO1	197.4	0.038
106263	Q1	205.8	0.023
106263	2Q1	137.7	0.008
106263	P1	126.6	0.063
106263	2SM2	346.2	0.008
106263	M3	346.6	0.005
106263	L2	26.4	0.065
106263	2MK3	84.9	0.041
106263	K2	79.5	0.066
106263	M8	51.9	0.012
106263	MS4	178.3	0.015
106264	M2	7.2	1.749
106264	S2	37	0.229
106264	N2	342.7	0.353
106264	K1	144.5	0.19
106264	M4	270.9	0.04
106264	O1	168.2	0.107
106264	M6	294.7	0.041
106264	MK3	33.3	0.016
106264	S4	325.7	0.01
106264	MN4	213.4	0.013
106264	NU2	335.1	0.048
106264	S6	33.4	0.009
106264	MU2	136.6	0.022
106264	2N2	306.6	0.089
106264	OO1	206.9	0.023
106264	LDA2	35.6	0.042
106264	M1	243	0.018
106264	J1	14	0.029
106264	RHO1	214.8	0.054
106264	Q1	322.2	0.028
106264	2Q1	191.2	0.012
106264	P1	113.8	0.067
106264	2SM2	31.7	0.004
106264	M3	98.5	0.015
106264	L2	41.8	0.083
106264	2MK3	99.3	0.022
106264	K2	65.3	0.053
106264	M8	182.7	0.014
106264	MS4	222.6	0.017
106265	M2	8.8	1.797
106265	S2	36.5	0.234
106265	N2	346	0.368
106265	K1	145.9	0.205
106265	M4	258.2	0.031
106265	O1	169.8	0.115
106265	M6	297.8	0.055
106265	MK3	339.9	0.004
106265	S4	275.8	0.006
106265	MN4	205.2	0.02
106265	NU2	323.4	0.063
106265	S6	14.7	0.008
106265	MU2	182.8	0.026
106265	2N2	313.2	0.094
106265	OO1	199.4	0.023
106265	LDA2	48.6	0.046
106265	M1	253.7	0.022
106265	J1	15.8	0.029
106265	RHO1	215.9	0.054
106265	Q1	325.5	0.029
106265	2Q1	194.3	0.015
106265	P1	117.1	0.064
106265	2SM2	355.2	0.006
106265	M3	84.1	0.018
106265	L2	49.7	0.095
106265	2MK3	103	0.019
106265	K2	63.7	0.057
106265	M8	184.2	0.019
106265	MS4	218.6	0.017
106266	M2	20.4	0.957
106266	S2	50.8	0.19
106266	N2	355.4	0.235
106266	K1	134.1	0.113
106266	M4	264.2	0.097
106266	O1	171.2	0.086
106266	M6	246.2	0.021
106266	MK3	72.8	0.035
106266	S4	346	0.02
106266	MN4	331.7	0.019
106266	NU2	325.3	0.095
106266	S6	164	0.003
106266	MU2	71.2	0.066
106266	2N2	88.4	0.026
106266	OO1	73	0.024
106266	LDA2	53.8	0.086
106266	M1	154	0.009
106266	J1	210.6	0.025
106266	RHO1	123.7	0.015
106266	Q1	186.1	0.035
106266	2Q1	30.9	0.01
106266	P1	116.9	0.036
106266	2SM2	31.6	0.023
106266	M3	196.6	0.007
106266	L2	15.5	0.108
106266	2MK3	48.3	0.038
106266	K2	132.9	0.072
106266	M8	152.8	0.015
106266	MS4	248.8	0.022
106267	M2	25.4	1.171
106267	S2	43.1	0.205
106267	N2	359.5	0.27
106267	K1	138.4	0.16
106267	M4	287.6	0.098
106267	O1	169.9	0.096
106267	M6	319.4	0.035
106267	MK3	89.4	0.038
106267	S4	352.7	0.017
106267	MN4	265.3	0.014
106267	NU2	341.7	0.107
106267	S6	240.2	0.005
106267	MU2	100.1	0.044
106267	2N2	121.9	0.007
106267	OO1	65.9	0.022
106267	LDA2	44.2	0.057
106267	M1	202.7	0.011
106267	J1	247.6	0.021
106267	RHO1	99.6	0.029
106267	Q1	173.1	0.043
106267	2Q1	65.9	0.01
106267	P1	140.4	0.04
106267	2SM2	45.7	0.018
106267	M3	270.7	0.004
106267	L2	23.5	0.106
106267	2MK3	82.2	0.045
106267	K2	109.8	0.076
106267	M8	209.8	0.017
106267	MS4	285.8	0.034
106268	M2	30.5	1.274
106268	S2	41.9	0.234
106268	N2	5.4	0.289
106268	K1	143.7	0.163
106268	M4	296.8	0.074
106268	O1	168.8	0.114
106268	M6	18.8	0.038
106268	MK3	96.1	0.033
106268	S4	355.1	0.022
106268	MN4	280.2	0.017
106268	NU2	353	0.095
106268	S6	318.8	0.002
106268	MU2	118.9	0.019
106268	2N2	302.7	0.015
106268	OO1	75.5	0.009
106268	LDA2	20.4	0.058
106268	M1	195.9	0.014
106268	J1	259.6	0.024
106268	RHO1	144	0.022
106268	Q1	186.4	0.055
106268	2Q1	82.9	0.022
106268	P1	126.1	0.042
106268	2SM2	46.2	0.01
106268	M3	128.7	0.004
106268	L2	22.3	0.102
106268	2MK3	95.2	0.031
106268	K2	93.5	0.089
106268	M8	295.8	0.006
106268	MS4	302.8	0.022
106269	M2	33.9	1.258
106269	S2	46.3	0.233
106269	N2	9.4	0.295
106269	K1	151.6	0.134
106269	M4	300.2	0.058
106269	O1	179.1	0.12
106269	M6	38.5	0.036
106269	MK3	104.3	0.036
106269	S4	353.3	0.024
106269	MN4	285.3	0.017
106269	NU2	8.7	0.102
106269	S6	194.5	0.002
106269	MU2	186.1	0.019
106269	2N2	278.9	0.04
106269	OO1	66.2	0.035
106269	LDA2	11.5	0.081
106269	M1	142.1	0.011
106269	J1	207.9	0.015
106269	RHO1	163	0.026
106269	Q1	190.5	0.054
106269	2Q1	97.9	0.021
106269	P1	100.5	0.054
106269	2SM2	53.5	0.013
106269	M3	46.9	0.004
106269	L2	15.9	0.106
106269	2MK3	128.6	0.025
106269	K2	103.2	0.089
106269	M8	224.9	0.004
106269	MS4	287.1	0.009
106270	M2	318.5	0.472
106270	S2	345.4	0.141
106270	N2	199.9	0.05
106270	K1	343.5	0.036
106270	M4	196.2	0.048
106270	O1	129.8	0.05
106270	M6	54.3	0.018
106270	MK3	342.2	0.028
106270	S4	294.2	0.018
106270	MN4	263.1	0.022
106270	NU2	145.5	0.182
106270	S6	86.1	0.005
106270	MU2	324.9	0.134
106270	2N2	335.3	0.098
106270	OO1	114.9	0.023
106270	LDA2	283.7	0.078
106270	M1	37.2	0.002
106270	J1	145.3	0.01
106270	RHO1	255.7	0.036
106270	Q1	280.5	0.032
106270	2Q1	64.5	0.01
106270	P1	22.1	0.019
106270	2SM2	237	0.025
106270	M3	122	0.011
106270	L2	261.1	0.119
106270	2MK3	334.1	0.01
106270	K2	46.5	0.124
106270	M8	290.6	0.006
106270	MS4	88.1	0.014
106271	M2	330.2	0.534
106271	S2	345.1	0.141
106271	N2	251	0.044
106271	K1	13.1	0.024
106271	M4	238.1	0.032
106271	O1	136.5	0.066
106271	M6	34.5	0.015
106271	MK3	356.1	0.023
106271	S4	292	0.021
106271	MN4	282.1	0.013
106271	NU2	149.8	0.113
106271	S6	167.6	0.003
106271	MU2	333	0.1
106271	2N2	340.7	0.077
106271	OO1	123.7	0.028
106271	LDA2	304.3	0.075
106271	M1	252.5	0.004
106271	J1	168	0.01
106271	RHO1	241.6	0.025
106271	Q1	263.8	0.025
106271	2Q1	47.4	0.023
106271	P1	29.1	0.016
106271	2SM2	223.2	0.02
106271	M3	137.6	0.011
106271	L2	276.3	0.098
106271	2MK3	5.9	0.013
106271	K2	47.9	0.117
106271	M8	179.6	0.003
106271	MS4	102.1	0.016
106272	M2	340.1	0.56
106272	S2	9.1	0.1
106272	N2	320.3	0.153
106272	K1	88.9	0.056
106272	M4	270.3	0.021
106272	O1	135.9	0.043
106272	M6	330.1	0.006
106272	MK3	56.7	0.019
106272	S4	261.8	0.014
106272	MN4	339	0.007
106272	NU2	324.8	0.062
106272	S6	124.5	0.007
106272	MU2	75.1	0.029
106272	2N2	135.8	0.022
106272	OO1	185.3	0.015
106272	LDA2	22.5	0.034
106272	M1	178.9	0.013
106272	J1	179.5	0.011
106272	RHO1	301.9	0.018
106272	Q1	275.6	0.01
106272	2Q1	4.4	0.01
106272	P1	127.1	0.016
106272	2SM2	191	0.002
106272	M3	214.2	0.001
106272	L2	355.1	0.034
106272	2MK3	89.5	0.004
106272	K2	67.7	0.015
106272	M8	125.1	0.004
106272	MS4	167.9	0.019
106273	M2	342	0.602
106273	S2	16.7	0.082
106273	N2	330.9	0.192
106273	K1	114.6	0.085
106273	M4	334	0.025
106273	O1	153.1	0.033
106273	M6	326.2	0.023
106273	MK3	82.4	0.027
106273	S4	282.3	0.014
106273	MN4	40.4	0.016
106273	NU2	336.8	0.116
106273	S6	87.7	0.003
106273	MU2	143.7	0.037
106273	2N2	189.4	0.042
106273	OO1	315.6	0.013
106273	LDA2	85.9	0.046
106273	M1	247.9	0.003
106273	J1	296.3	0.006
106273	RHO1	25.4	0.006
106273	Q1	137	0.012
106273	2Q1	335.6	0.009
106273	P1	175.4	0.017
106273	2SM2	33.6	0.006
106273	M3	292.2	0.01
106273	L2	50.7	0.058
106273	2MK3	96.8	0.016
106273	K2	255.1	0.02
106273	M8	115.1	0.001
106273	MS4	178.7	0.012
106274	M2	325.1	2.354
106274	S2	14.1	0.361
106274	N2	289.4	0.456
106274	K1	50.7	0.132
106274	M4	81.6	0.186
106274	O1	356.9	0.081
106274	M6	103	0.247
106274	MK3	90.1	0.061
106274	S4	256.6	0.027
106274	MN4	63.3	0.092
106274	S6	104.3	0.008
106274	2N2	292.7	0.024
106274	OO1	359.2	0.004
106274	M1	293.9	0.025
106274	Q1	316.1	0.019
106274	2Q1	226.9	0.01
106274	P1	41.7	0.032
106274	2SM2	192	0.013
106274	M3	262.3	0.01
106274	L2	357.9	0.225
106274	2MK3	50.3	0.045
106274	K2	64.2	0.132
106274	M8	164.2	0.025
106274	MS4	207	0.078
106275	M2	324.9	3.352
106275	S2	2.9	0.398
106275	N2	296.9	0.712
106275	K1	53.3	0.142
106275	M4	102.1	0.09
106275	O1	2.8	0.102
106275	M6	106.9	0.333
106275	MK3	80.2	0.069
106275	S4	5	0.019
106275	MN4	340.5	0.034
106275	S6	134.3	0.007
106275	2N2	267.2	0.044
106275	OO1	161.8	0.012
106275	M1	298.7	0.02
106275	J1	328.6	0.016
106275	Q1	342.2	0.021
106275	2Q1	268.7	0.009
106275	P1	42.8	0.064
106275	2SM2	121.7	0.021
106275	M3	332.2	0.036
106275	L2	4	0.32
106275	2MK3	33.7	0.076
106275	K2	354.3	0.127
106275	M8	250.6	0.022
106275	MS4	247.1	0.056
106276	M2	325.3	3.397
106276	S2	3.6	0.411
106276	N2	297.1	0.72
106276	K1	53.3	0.141
106276	M4	97.2	0.096
106276	O1	3.8	0.102
106276	M6	107	0.341
106276	MK3	80.2	0.071
106276	S4	16.8	0.02
106276	MN4	342.5	0.038
106276	S6	136.6	0.008
106276	2N2	264.8	0.041
106276	OO1	174.8	0.011
106276	M1	301.4	0.02
106276	J1	328.1	0.017
106276	Q1	342.8	0.02
106276	2Q1	261.9	0.008
106276	P1	46	0.067
106276	2SM2	134.2	0.018
106276	M3	331.6	0.037
106276	L2	5.5	0.323
106276	2MK3	33.7	0.076
106276	K2	356.9	0.134
106276	M8	267.2	0.026
106276	MS4	244.5	0.054
106277	M2	328.9	2.77
106277	S2	13.2	0.38
106277	N2	302.2	0.609
106277	K1	56.8	0.117
106277	M4	86.1	0.1
106277	O1	6.6	0.082
106277	M6	109.5	0.305
106277	MK3	92.6	0.053
106277	S4	332	0.009
106277	MN4	359.8	0.029
106277	S6	258.8	0.005
106277	2N2	266.1	0.033
106277	OO1	181.7	0.012
106277	M1	302.1	0.015
106277	J1	330.9	0.016
106277	Q1	335.9	0.016
106277	2Q1	287.9	0.004
106277	P1	56.6	0.051
106277	2SM2	102.5	0.008
106277	M3	344.4	0.023
106277	L2	8.1	0.264
106277	2MK3	34.9	0.061
106277	K2	25.8	0.125
106277	M8	276.9	0.019
106277	MS4	242.9	0.053
106278	M2	328.9	3.225
106278	S2	13.3	0.443
106278	N2	302	0.708
106278	K1	54.8	0.142
106278	M4	82.3	0.124
106278	O1	4.4	0.097
106278	M6	110.6	0.35
106278	MK3	89.1	0.06
106278	S4	340.7	0.012
106278	MN4	359.8	0.038
106278	S6	256.6	0.007
106278	2N2	268.4	0.037
106278	OO1	177.2	0.013
106278	M1	313.1	0.018
106278	J1	335.7	0.02
106278	Q1	329.2	0.018
106278	2Q1	253.3	0.005
106278	P1	61.5	0.058
106278	2SM2	97.5	0.01
106278	M3	339.7	0.028
106278	L2	8.8	0.31
106278	2MK3	35.8	0.071
106278	K2	26.5	0.141
106278	M8	259.6	0.03
106278	MS4	239.2	0.059
106279	M2	329.3	3.64
106279	S2	12	0.494
106279	N2	302.2	0.778
106279	K1	61.6	0.148
106279	M4	74.9	0.157
106279	O1	12.4	0.11
106279	M6	111.2	0.367
106279	MK3	92.1	0.082
106279	S4	358.3	0.011
106279	MN4	355	0.061
106279	S6	235.5	0.005
106279	2N2	277.7	0.021
106279	OO1	147.1	0.02
106279	M1	276.2	0.023
106279	J1	307.8	0.014
106279	Q1	20.5	0.02
106279	2Q1	88.1	0.007
106279	P1	57.4	0.067
106279	2SM2	139.5	0.011
106279	M3	4.2	0.036
106279	L2	5.9	0.36
106279	2MK3	36.9	0.095
106279	K2	22	0.168
106279	M8	247.8	0.047
106279	MS4	239.6	0.05
106280	M2	329.4	2.624
106280	S2	6.7	0.329
106280	N2	302.2	0.574
106280	K1	61.6	0.107
106280	M4	90.9	0.154
106280	O1	9.4	0.08
106280	M6	120.5	0.25
106280	MK3	103.1	0.045
106280	S4	351.3	0.012
106280	MN4	35	0.039
106280	S6	93.9	0.005
106280	2N2	274.7	0.046
106280	OO1	162.4	0.008
106280	M1	292.4	0.014
106280	J1	337.3	0.012
106280	Q1	335.6	0.017
106280	2Q1	226.3	0.003
106280	P1	51.1	0.047
106280	2SM2	121.5	0.014
106280	M3	355.6	0.022
106280	L2	8.8	0.241
106280	2MK3	47.2	0.059
106280	K2	4.7	0.115
106280	M8	289.9	0.038
106280	MS4	225.5	0.053
106281	M2	329.5	3.192
106281	S2	7.4	0.4
106281	N2	302.4	0.697
106281	K1	62	0.134
106281	M4	93.4	0.188
106281	O1	8.7	0.098
106281	M6	120.8	0.31
106281	MK3	103.6	0.053
106281	S4	0.5	0.016
106281	MN4	37	0.047
106281	S6	102.6	0.005
106281	2N2	274.9	0.056
106281	OO1	162.7	0.01
106281	M1	299.1	0.016
106281	J1	336.3	0.013
106281	Q1	340.7	0.02
106281	P1	51.9	0.055
106281	2SM2	122.6	0.016
106281	M3	352.4	0.029
106281	L2	9.4	0.294
106281	2MK3	46.7	0.072
106281	K2	6.4	0.138
106281	M8	288.6	0.043
106281	MS4	225.8	0.064
106282	M2	329.6	3.466
106282	S2	7.1	0.431
106282	N2	302.3	0.758
106282	K1	60.7	0.145
106282	M4	94.6	0.178
106282	O1	8.1	0.106
106282	M6	120.1	0.339
106282	MK3	99	0.057
106282	S4	8.9	0.019
106282	MN4	28	0.044
106282	S6	108.4	0.004
106282	2N2	272.7	0.06
106282	OO1	173.5	0.01
106282	M1	301.1	0.018
106282	J1	344.1	0.016
106282	Q1	344.1	0.02
106282	P1	52.6	0.062
106282	2SM2	115.3	0.016
106282	M3	348.3	0.032
106282	L2	9.9	0.318
106282	2MK3	46	0.077
106282	K2	4.1	0.148
106282	M8	284.5	0.033
106282	MS4	228.1	0.064
106283	M2	330.4	3.63
106283	S2	7.4	0.504
106283	N2	295.3	0.789
106283	K1	61.1	0.173
106283	M4	79.4	0.279
106283	O1	20.8	0.087
106283	M6	128.5	0.345
106283	MK3	127.2	0.07
106283	S4	4.5	0.02
106283	MN4	31.4	0.126
106283	S6	170.4	0.008
106283	2N2	345.6	0.109
106283	OO1	169.8	0.014
106283	M1	337.1	0.011
106283	Q1	356.9	0.031
106283	2Q1	273.4	0.013
106283	P1	60.5	0.04
106283	2SM2	3.8	0.007
106283	M3	0.9	0.03
106283	L2	20.8	0.302
106283	2MK3	51.9	0.086
106283	K2	7.8	0.157
106283	M8	262.2	0.033
106283	MS4	171.8	0.07
106284	M2	331	4.584
106284	S2	5	0.575
106284	N2	293.8	0.982
106284	K1	67.4	0.216
106284	M4	97.2	0.259
106284	O1	21.4	0.133
106284	M6	135.8	0.445
106284	MK3	117.2	0.065
106284	S4	26.4	0.02
106284	MN4	40	0.122
106284	S6	212.6	0.008
106284	2N2	5.6	0.136
106284	OO1	178.1	0.025
106284	M1	318.8	0.015
106284	J1	108.1	0.01
106284	Q1	3.3	0.033
106284	2Q1	321.1	0.006
106284	P1	66	0.053
106284	2SM2	304.4	0.009
106284	M3	1.1	0.041
106284	L2	23	0.422
106284	2MK3	54.5	0.097
106284	K2	1.4	0.191
106284	M8	244.4	0.013
106284	MS4	179.7	0.072
106285	M2	331.6	3.482
106285	S2	357.6	0.426
106285	N2	291.4	0.756
106285	K1	102.7	0.26
106285	M4	65.8	0.493
106285	O1	15.5	0.21
106285	M6	143.9	0.302
106285	MK3	244.7	0.063
106285	S4	128.3	0.013
106285	MN4	18.1	0.235
106285	2N2	349.4	0.105
106285	OO1	212	0.016
106285	M1	356	0.024
106285	J1	64.2	0.038
106285	Q1	27.8	0.05
106285	2Q1	303.2	0.049
106285	P1	147.5	0.036
106285	2SM2	227	0.046
106285	M3	26	0.041
106285	L2	20.8	0.311
106285	2MK3	104.4	0.126
106285	K2	350.9	0.202
106285	M8	265.9	0.064
106285	MS4	136.5	0.208
106286	M2	328.7	2.454
106286	S2	4.5	0.318
106286	N2	302.1	0.559
106286	K1	70.4	0.107
106286	M4	344.6	0.079
106286	O1	12.2	0.061
106286	M6	134.1	0.181
106286	MK3	95.9	0.028
106286	S4	356	0.022
106286	MN4	294.1	0.059
106286	S6	98.9	0.004
106286	2N2	278.7	0.059
106286	OO1	147.6	0.011
106286	M1	279.5	0.011
106286	J1	342.5	0.007
106286	Q1	351.6	0.009
106286	2Q1	163.8	0.003
106286	P1	40.1	0.044
106286	2SM2	89.2	0.004
106286	M3	338.5	0.024
106286	L2	16.5	0.2
106286	2MK3	43.5	0.036
106286	K2	5.7	0.101
106286	M8	102.4	0.02
106286	MS4	212.7	0.004
106287	M2	328.7	3.025
106287	S2	4.6	0.387
106287	N2	302.4	0.678
106287	K1	69.7	0.131
106287	M4	323.2	0.093
106287	O1	14.4	0.075
106287	M6	132.8	0.245
106287	MK3	82.4	0.034
106287	S4	355.8	0.03
106287	MN4	286.6	0.075
106287	S6	58.2	0.004
106287	2N2	280.8	0.065
106287	OO1	151.1	0.014
106287	M1	286.9	0.013
106287	J1	330.3	0.011
106287	Q1	356.9	0.012
106287	2Q1	165.9	0.005
106287	P1	42.4	0.053
106287	2SM2	116.9	0.006
106287	M3	335.2	0.033
106287	L2	14.5	0.258
106287	2MK3	37.4	0.05
106287	K2	5.1	0.123
106287	M8	87	0.021
106287	MS4	284.3	0.009
106288	M2	328.2	3.162
106288	S2	3.2	0.398
106288	N2	300.7	0.718
106288	K1	73.4	0.128
106288	M4	353.1	0.129
106288	O1	20.3	0.078
106288	M6	137.5	0.262
106288	MK3	96.3	0.044
106288	S4	353.7	0.035
106288	MN4	306.7	0.073
106288	S6	31.5	0.008
106288	2N2	272.9	0.076
106288	OO1	139.9	0.009
106288	M1	274.2	0.011
106288	J1	310.8	0.011
106288	Q1	7.8	0.014
106288	P1	36.6	0.069
106288	2SM2	113.6	0.009
106288	M3	328.3	0.034
106288	L2	10.6	0.273
106288	2MK3	43.4	0.055
106288	K2	359.2	0.135
106288	M8	33.6	0.008
106288	MS4	356.2	0.005
106289	M2	330.9	1.153
106289	S2	358.1	0.161
106289	N2	304.3	0.259
106289	K1	76.9	0.073
106289	M4	115.1	0.043
106289	O1	52.9	0.046
106289	M6	150.4	0.105
106289	MK3	282.8	0.003
106289	S4	295	0.009
106289	MN4	128.5	0.006
106289	S6	33.4	0.007
106289	2N2	260.3	0.032
106289	OO1	125.8	0.009
106289	M1	296.5	0.008
106289	J1	13.6	0.004
106289	Q1	82	0.004
106289	2Q1	199.9	0.007
106289	P1	68.1	0.009
106289	2SM2	298.8	0.007
106289	M3	321.3	0.012
106289	L2	27	0.096
106289	2MK3	59.5	0.015
106289	K2	356.7	0.058
106289	M8	351.2	0.01
106289	MS4	146	0.019
106290	M2	329.3	1.468
106290	S2	0.7	0.199
106290	N2	304.3	0.336
106290	K1	75.9	0.088
106290	M4	142.2	0.023
106290	O1	46.8	0.056
106290	M6	148.4	0.128
106290	MK3	312.3	0.016
106290	S4	318	0.015
106290	MN4	222.9	0.016
106290	S6	41	0.008
106290	2N2	277.5	0.035
106290	OO1	128.7	0.012
106290	M1	291.8	0.009
106290	J1	332	0.004
106290	Q1	78.3	0.007
106290	2Q1	191	0.004
106290	P1	24.2	0.015
106290	2SM2	276.8	0.012
106290	M3	315.8	0.013
106290	L2	24	0.117
106290	2MK3	20.7	0.011
106290	K2	359.8	0.061
106290	M8	323.6	0.011
106290	MS4	160.7	0.019
106291	M2	327.8	1.52
106291	S2	4.3	0.215
106291	N2	302.4	0.363
106291	K1	84.5	0.091
106291	M4	122	0.061
106291	O1	52	0.052
106291	M6	141.9	0.102
106291	MK3	280.6	0.006
106291	S4	346.3	0.022
106291	MN4	179.4	0.023
106291	S6	76.4	0.004
106291	2N2	297.1	0.04
106291	OO1	125.6	0.008
106291	M1	348.2	0.004
106291	J1	277.3	0.003
106291	Q1	58.1	0.005
106291	2Q1	228.1	0.005
106291	P1	16.3	0.023
106291	2SM2	150.8	0.008
106291	M3	325.5	0.015
106291	L2	16.5	0.105
106291	2MK3	332.6	0.009
106291	K2	14.7	0.06
106291	M8	286.8	0.025
106291	MS4	179.3	0.024
106292	M2	282.4	0.218
106292	S2	337.8	0.039
106292	N2	267.6	0.051
106292	K1	65.5	0.063
106292	M4	302.2	0.04
106292	O1	74.6	0.013
106292	M6	137.5	0.012
106292	MK3	258.8	0.008
106292	S4	283	0.004
106292	MN4	255.3	0.019
106292	S6	12.1	0.002
106292	2N2	268.3	0.006
106292	OO1	92.8	0.007
106292	M1	212.3	0.006
106292	J1	147.7	0.008
106292	Q1	172.5	0.008
106292	2Q1	104.1	0.005
106292	P1	245	0.048
106292	2SM2	25.8	0.009
106292	M3	219.9	0.005
106292	L2	158.3	0.005
106292	2MK3	257.3	0.005
106292	K2	49.1	0.013
106292	M8	48.1	0.001
106292	MS4	62.3	0.012
106293	M2	305.2	0.316
106293	S2	328.4	0.047
106293	N2	286.2	0.088
106293	K1	88	0.037
106293	M4	318.8	0.057
106293	O1	100.2	0.026
106293	M6	166.2	0.024
106293	MK3	318.3	0.021
106293	S4	327.5	0.005
106293	MN4	265.2	0.031
106293	S6	122.1	0.002
106293	2N2	277.3	0.023
106293	OO1	109.2	0.005
106293	M1	200.2	0.002
106293	J1	222.5	0.008
106293	Q1	289.6	0.005
106293	2Q1	22.8	0.008
106293	P1	289.7	0.008
106293	2SM2	293.3	0.005
106293	M3	257	0.01
106293	L2	338.6	0.019
106293	2MK3	272.8	0.009
106293	K2	321.1	0.014
106293	M8	142.2	0.001
106293	MS4	79.3	0.019
106294	M2	310.6	0.331
106294	S2	335.6	0.042
106294	N2	289.1	0.097
106294	K1	103.5	0.033
106294	M4	319.6	0.057
106294	O1	94.5	0.025
106294	M6	168.8	0.02
106294	MK3	314.7	0.016
106294	S4	341.6	0.008
106294	MN4	260.7	0.024
106294	S6	119.8	0.003
106294	2N2	274.6	0.031
106294	OO1	175.2	0.004
106294	M1	127.3	0.001
106294	J1	324	0.009
106294	2Q1	235.3	0.004
106294	P1	50.7	0.008
106294	2SM2	246.8	0.008
106294	M3	257.2	0.009
106294	L2	333.5	0.016
106294	2MK3	297.3	0.009
106294	K2	323.7	0.015
106294	M8	119.7	0.004
106294	MS4	68.1	0.019
106295	M2	276.6	0.319
106295	S2	288.7	0.068
106295	N2	253.3	0.094
106295	K1	85.8	0.018
106295	M4	303.9	0.077
106295	O1	55.6	0.014
106295	M6	149.6	0.019
106295	MK3	287.3	0.004
106295	S4	276.2	0.005
106295	MN4	245.1	0.03
106295	S6	206.2	0.002
106295	2N2	197.2	0.021
106295	OO1	87.7	0.005
106295	M1	268.6	0.005
106295	J1	225.8	0.005
106295	Q1	1.2	0.005
106295	2Q1	352.8	0.005
106295	P1	251.1	0.012
106295	2SM2	272	0.003
106295	M3	267.1	0.009
106295	L2	300.6	0.012
106295	2MK3	247.2	0.013
106295	K2	312.4	0.025
106295	M8	228.2	0.002
106295	MS4	31.6	0.031
106296	M2	288.5	0.532
106296	S2	294.4	0.083
106296	N2	255.6	0.14
106296	K1	114.9	0.026
106296	M4	308.1	0.119
106296	O1	75.5	0.02
106296	M6	119.4	0.017
106296	MK3	329.4	0.011
106296	S4	273.4	0.015
106296	MN4	253.2	0.059
106296	S6	215.4	0.005
106296	2N2	186.1	0.028
106296	OO1	137.6	0.006
106296	M1	247.3	0.005
106296	J1	230.5	0.002
106296	Q1	66.1	0.007
106296	2Q1	350.3	0.005
106296	P1	214.4	0.02
106296	2SM2	335.6	0.003
106296	M3	298.8	0.011
106296	L2	355.7	0.032
106296	2MK3	295.4	0.017
106296	K2	294.1	0.053
106296	M8	103.8	0.009
106296	MS4	30.2	0.046
106297	M2	290.4	0.632
106297	S2	284.4	0.131
106297	N2	255.9	0.172
106297	K1	87.7	0.055
106297	M4	320.1	0.15
106297	O1	124.3	0.018
106297	M6	130.9	0.015
106297	MK3	303.4	0.026
106297	S4	281.8	0.016
106297	MN4	266	0.081
106297	S6	167.5	0.008
106297	2N2	200.7	0.045
106297	OO1	81.7	0.007
106297	M1	220.6	0.015
106297	J1	248.7	0.009
106297	Q1	120.3	0.009
106297	2Q1	36.6	0.004
106297	P1	136.2	0.054
106297	2SM2	247	0.008
106297	M3	325.1	0.01
106297	L2	77.5	0.021
106297	2MK3	259.2	0.019
106297	K2	313.7	0.065
106297	M8	74.8	0.012
106297	MS4	28.1	0.057
106298	M2	283.8	0.479
106298	S2	300.3	0.139
106298	N2	263.6	0.149
106298	K1	72.7	0.045
106298	M4	6.8	0.203
106298	O1	59.7	0.039
106298	M6	99.4	0.086
106298	MK3	180.7	0.025
106298	S4	255.2	0.013
106298	MN4	345	0.077
106298	S6	306.7	0.005
106298	2N2	198.7	0.046
106298	OO1	62.6	0.009
106298	M1	356.1	0.01
106298	J1	78.6	0.011
106298	Q1	45.6	0.011
106298	2Q1	31.7	0.01
106298	P1	218.7	0.007
106298	2SM2	183.8	0.018
106298	M3	347.7	0.014
106298	L2	160.8	0.031
106298	2MK3	185.3	0.013
106298	K2	345	0.056
106298	M8	157.8	0.037
106298	MS4	69.3	0.092
106299	M2	281.8	0.521
106299	S2	302.5	0.13
106299	N2	255.8	0.144
106299	K1	81.6	0.041
106299	M4	359.5	0.209
106299	O1	61.9	0.029
106299	M6	87.5	0.075
106299	MK3	157.7	0.007
106299	S4	238.3	0.008
106299	MN4	324.5	0.079
106299	S6	248.9	0.003
106299	2N2	209.2	0.054
106299	OO1	66.3	0.003
106299	M1	335.2	0.007
106299	J1	126.8	0.007
106299	Q1	41.3	0.005
106299	2Q1	18.9	0.007
106299	P1	250.1	0.012
106299	2SM2	147.1	0.008
106299	M3	340.5	0.013
106299	L2	137.8	0.015
106299	2MK3	224.9	0.011
106299	K2	323.2	0.042
106299	M8	132.8	0.032
106299	MS4	58.2	0.102
106300	M2	278.1	0.609
106300	S2	298.5	0.122
106300	N2	248.6	0.15
106300	K1	82.1	0.043
106300	M4	349.4	0.231
106300	O1	89.1	0.028
106300	M6	69.9	0.066
106300	MK3	216.7	0.005
106300	S4	269	0.012
106300	MN4	305.1	0.087
106300	S6	207.7	0.005
106300	2N2	213.7	0.042
106300	OO1	303.8	0.006
106300	M1	259.3	0.004
106300	J1	184.7	0.005
106300	Q1	75.3	0.005
106300	2Q1	116.3	0.004
106300	P1	209.5	0.004
106300	2SM2	140.8	0.008
106300	M3	348	0.012
106300	L2	319.1	0.012
106300	2MK3	251.9	0.016
106300	K2	296.2	0.045
106300	M8	111.5	0.025
106300	MS4	49.2	0.115
106301	M2	350.9	0.965
106301	S2	19.9	0.119
106301	N2	310.8	0.213
106301	K1	94.6	0.068
106301	M4	123.1	0.119
106301	O1	76.3	0.041
106301	M6	208.7	0.087
106301	MK3	217	0.005
106301	S4	357.2	0.013
106301	MN4	63.3	0.058
106301	S6	303.9	0.004
106301	2N2	2.4	0.036
106301	OO1	171.2	0.006
106301	M1	151.7	0.007
106301	J1	163.8	0.006
106301	Q1	63.1	0.015
106301	2Q1	343.5	0.007
106301	P1	93.6	0.024
106301	2SM2	19.3	0.01
106301	M3	8.6	0.013
106301	L2	45.3	0.078
106301	2MK3	10.6	0.016
106301	K2	15.6	0.041
106301	M8	344.4	0.031
106301	MS4	166	0.055
106302	M2	352.7	1.223
106302	S2	20.4	0.145
106302	N2	312.5	0.265
106302	K1	98.9	0.081
106302	M4	115.5	0.146
106302	O1	82.5	0.047
106302	M6	211.5	0.112
106302	MK3	282.2	0.002
106302	S4	2.8	0.013
106302	MN4	51.2	0.072
106302	S6	296.8	0.006
106302	2N2	9.4	0.044
106302	OO1	156.4	0.01
106302	M1	135.6	0.01
106302	J1	153.9	0.012
106302	Q1	63.7	0.017
106302	2Q1	337.4	0.008
106302	P1	102.5	0.021
106302	2SM2	17.2	0.005
106302	M3	43.7	0.012
106302	L2	44.9	0.101
106302	2MK3	23.3	0.019
106302	K2	22.5	0.05
106302	M8	341.4	0.034
106302	MS4	157.5	0.073
106303	M2	352.8	1.479
106303	S2	25.5	0.205
106303	N2	322.5	0.335
106303	K1	108.3	0.091
106303	M4	139.4	0.337
106303	O1	68.5	0.063
106303	M6	207.2	0.168
106303	MK3	210	0.004
106303	S4	34.3	0.014
106303	MN4	109.1	0.115
106303	S6	101.9	0.005
106303	2N2	334	0.03
106303	OO1	183.2	0.004
106303	J1	91	0.006
106303	Q1	63.6	0.011
106303	2Q1	133.5	0.002
106303	P1	85.4	0.023
106303	2SM2	30.9	0.005
106303	M3	3.7	0.021
106303	L2	28.2	0.124
106303	2MK3	41.7	0.035
106303	K2	16.6	0.059
106303	M8	341.5	0.079
106303	MS4	200.9	0.101
106304	M2	354.9	2.506
106304	S2	28.7	0.316
106304	N2	324.4	0.556
106304	K1	103	0.137
106304	M4	114.6	0.29
106304	O1	67.8	0.081
106304	M6	202.9	0.278
106304	MK3	113.7	0.021
106304	S4	40.9	0.026
106304	MN4	68.4	0.097
106304	S6	96.1	0.008
106304	2N2	329.3	0.042
106304	OO1	188.8	0.009
106304	M1	158.9	0.004
106304	J1	84.9	0.008
106304	Q1	53.6	0.013
106304	2Q1	105.9	0.004
106304	P1	85.7	0.048
106304	2SM2	22.5	0.003
106304	M3	5.4	0.029
106304	L2	32	0.224
106304	2MK3	47.4	0.061
106304	K2	20.6	0.095
106304	M8	324.8	0.054
106304	MS4	186.7	0.095
106305	M2	355.7	3.377
106305	S2	30.4	0.39
106305	N2	326.9	0.741
106305	K1	100.9	0.177
106305	M4	92.3	0.29
106305	O1	65.6	0.096
106305	M6	201.5	0.381
106305	MK3	106.5	0.04
106305	S4	42.3	0.039
106305	MN4	40.3	0.13
106305	S6	100.4	0.01
106305	2N2	350.5	0.055
106305	OO1	196.6	0.012
106305	M1	178.2	0.007
106305	J1	65.5	0.011
106305	Q1	49.8	0.015
106305	2Q1	77.4	0.004
106305	P1	81.2	0.064
106305	2SM2	257.4	0.006
106305	M3	6.4	0.034
106305	L2	37.3	0.31
106305	2MK3	49.5	0.082
106305	K2	22.5	0.111
106305	M8	300.5	0.038
106305	MS4	174.5	0.095
106306	M2	359.6	1.344
106306	S2	39.1	0.16
106306	N2	336.2	0.309
106306	K1	120.9	0.057
106306	M4	47.9	0.195
106306	O1	80.2	0.032
106306	M6	190.6	0.178
106306	MK3	85.3	0.024
106306	S4	49.5	0.023
106306	MN4	2.3	0.093
106306	S6	126.2	0.006
106306	2N2	340.2	0.029
106306	OO1	239.9	0.005
106306	M1	152.8	0.003
106306	J1	16.1	0.005
106306	Q1	70.3	0.006
106306	P1	63.9	0.042
106306	2SM2	294.1	0.003
106306	M3	336.1	0.009
106306	L2	31.7	0.113
106306	2MK3	42.8	0.033
106306	K2	41.1	0.045
106306	M8	300.9	0.027
106306	MS4	139.5	0.024
106307	M2	0.8	1.408
106307	S2	41.2	0.164
106307	N2	337.3	0.321
106307	K1	119.7	0.061
106307	M4	41.4	0.187
106307	O1	80.9	0.037
106307	M6	188	0.198
106307	MK3	71.7	0.026
106307	S4	53.2	0.024
106307	MN4	354.3	0.092
106307	S6	117.5	0.006
106307	2N2	336.5	0.027
106307	OO1	236	0.006
106307	M1	146.1	0.002
106307	J1	14.9	0.007
106307	Q1	65.6	0.006
106307	2Q1	98.8	0.004
106307	P1	70.8	0.044
106307	2SM2	178.1	0.003
106307	M3	339.1	0.008
106307	L2	33.2	0.118
106307	2MK3	37.2	0.035
106307	K2	39.2	0.044
106307	M8	308.4	0.031
106307	MS4	132.2	0.02
106308	M2	0.3	1.411
106308	S2	43.3	0.157
106308	N2	336.8	0.317
106308	K1	114.1	0.062
106308	M4	42.6	0.203
106308	O1	78.2	0.035
106308	M6	190.6	0.206
106308	MK3	74.8	0.031
106308	S4	69.8	0.025
106308	MN4	355.8	0.1
106308	S6	112.3	0.006
106308	2N2	329.7	0.022
106308	OO1	227	0.005
106308	J1	8.4	0.006
106308	Q1	55.6	0.006
106308	2Q1	73.3	0.003
106308	P1	74.7	0.039
106308	2SM2	241.3	0.006
106308	M3	346.2	0.008
106308	L2	34	0.121
106308	2MK3	42.6	0.038
106308	K2	43.7	0.04
106308	M8	305.6	0.027
106308	MS4	118.8	0.025
106309	M2	9.5	2.298
106309	S2	23.3	0.383
106309	N2	2	0.446
106309	K1	128.2	0.049
106309	M4	113	0.44
106309	O1	312.8	0.028
106309	M6	288.8	0.346
106309	S4	121.8	0.056
106309	NU2	3	0.087
106309	S6	9	0.03
106309	2N2	354.6	0.059
106309	OO1	303.6	0.001
106309	LDA2	15.8	0.016
106309	M1	40.4	0.002
106309	J1	216	0.002
106309	RHO1	237.3	0.001
106309	Q1	225	0.005
106309	T2	23.2	0.023
106309	R2	23.3	0.003
106309	2Q1	137.3	0.001
106309	P1	128.2	0.016
106309	L2	16.8	0.064
106309	K2	23.3	0.104
106309	M8	24.1	0.045
106310	M2	11.2	2.682
106310	S2	26.3	0.437
106310	N2	3	0.52
106310	K1	121.1	0.093
106310	M4	106.6	0.451
106310	O1	14.1	0.023
106310	M6	283.4	0.379
106310	S4	107.9	0.057
106310	NU2	4.1	0.101
106310	S6	6.6	0.032
106310	2N2	354.9	0.069
106310	OO1	228	0.001
106310	LDA2	18.2	0.019
106310	M1	67.5	0.002
106310	J1	174.6	0.002
106310	RHO1	328.1	0.001
106310	Q1	320.5	0.004
106310	T2	26.3	0.026
106310	R2	26.3	0.003
106310	2Q1	267.1	0.001
106310	P1	121	0.031
106310	L2	19.3	0.075
106310	K2	26.3	0.119
106310	M8	350.3	0.063
106311	M2	12.3	2.814
106311	S2	29.8	0.449
106311	N2	2.9	0.546
106311	K1	119.8	0.109
106311	M4	101	0.421
106311	O1	43.7	0.032
106311	M6	280.1	0.385
106311	S4	106.2	0.054
106311	NU2	4.2	0.106
106311	S6	358.4	0.026
106311	2N2	353.6	0.073
106311	OO1	195.8	0.001
106311	LDA2	20.3	0.02
106311	M1	81.7	0.002
106311	J1	157.8	0.003
106311	RHO1	11	0.001
106311	Q1	5.6	0.006
106311	T2	29.7	0.026
106311	R2	29.7	0.004
106311	2Q1	327.6	0.001
106311	P1	119.7	0.036
106311	L2	21.6	0.079
106311	K2	29.7	0.122
106311	M8	333.8	0.068
106312	M2	26.8	1.325
106312	S2	52.8	0.17
106312	N2	349	0.279
106312	K1	98.3	0.068
106312	M4	97.2	0.284
106312	O1	59	0.023
106312	M6	296.3	0.144
106312	MK3	128.5	0.011
106312	S4	59.3	0.02
106312	MN4	50	0.148
106312	S6	311	0.005
106312	2N2	41.9	0.05
106312	OO1	175.5	0.003
106312	M1	162.4	0.005
106312	J1	161.6	0.01
106312	Q1	64.6	0.012
106312	2Q1	346.6	0.01
106312	P1	118.8	0.041
106312	2SM2	47.5	0.007
106312	M3	76.7	0.02
106312	L2	79.4	0.108
106312	2MK3	67.6	0.026
106312	K2	50.5	0.07
106312	M8	23.9	0.039
106312	MS4	159.8	0.106
106313	M2	28.6	1.847
106313	S2	52.9	0.243
106313	N2	349.7	0.381
106313	K1	103.7	0.095
106313	M4	101	0.372
106313	O1	71.6	0.032
106313	M6	299.7	0.212
106313	MK3	136	0.016
106313	S4	57.6	0.029
106313	MN4	52.2	0.196
106313	S6	315.5	0.006
106313	2N2	45.8	0.07
106313	OO1	189.8	0.005
106313	M1	154.3	0.006
106313	J1	159.6	0.016
106313	Q1	67.5	0.017
106313	2Q1	339.8	0.013
106313	P1	126.2	0.056
106313	2SM2	44.8	0.008
106313	M3	65	0.028
106313	L2	79.8	0.155
106313	2MK3	78.3	0.036
106313	K2	54.8	0.088
106313	M8	18.2	0.056
106313	MS4	165.4	0.148
106314	M2	29.2	1.968
106314	S2	52.9	0.264
106314	N2	349.9	0.406
106314	K1	104.1	0.101
106314	M4	101	0.407
106314	O1	73.4	0.034
106314	M6	299.8	0.225
106314	MK3	143	0.018
106314	S4	53.8	0.033
106314	MN4	51.8	0.214
106314	S6	330.9	0.006
106314	2N2	48.6	0.074
106314	OO1	201.4	0.007
106314	M1	156.6	0.006
106314	J1	160.9	0.018
106314	Q1	68	0.016
106314	2Q1	339.2	0.012
106314	P1	128	0.057
106314	2SM2	25.2	0.006
106314	M3	59.9	0.03
106314	L2	79.2	0.168
106314	2MK3	77.6	0.037
106314	K2	57.1	0.09
106314	M8	13.1	0.065
106314	MS4	165.3	0.16
106315	M2	24	1.606
106315	S2	48	0.216
106315	N2	357.4	0.31
106315	K1	128.6	0.059
106315	M4	83.4	0.403
106315	O1	67.2	0.021
106315	M6	268.4	0.197
106315	MK3	73.5	0.006
106315	S4	30.2	0.036
106315	MN4	36.4	0.205
106315	S6	265.5	0.011
106315	2N2	41.9	0.098
106315	OO1	220.4	0.004
106315	M1	163.1	0.012
106315	J1	243.3	0.007
106315	Q1	19.9	0.016
106315	2Q1	294.9	0.016
106315	P1	148.8	0.023
106315	2SM2	316.2	0.015
106315	M3	63.4	0.033
106315	L2	70.7	0.144
106315	2MK3	32.2	0.034
106315	K2	47.5	0.098
106315	M8	322.4	0.039
106315	MS4	150	0.167
106316	M2	22.4	0.953
106316	S2	63.5	0.295
106316	N2	2.8	0.173
106316	K1	234.2	0.044
106316	M4	105.2	0.194
106316	O1	269.1	0.023
106316	M6	295.2	0.134
106316	S4	200.9	0.004
106316	NU2	5.4	0.034
106316	S6	5.9	0.002
106316	2N2	343.1	0.023
106316	OO1	199.3	0.001
106316	LDA2	41.5	0.007
106316	M1	251.6	0.002
106316	J1	216.9	0.002
106316	RHO1	284.1	0.001
106316	Q1	286.4	0.005
106316	T2	61.8	0.017
106316	R2	65	0.002
106316	2Q1	303.7	0.001
106316	P1	236.9	0.015
106316	L2	2.8	0.025
106316	K2	66.8	0.08
106316	M8	273.7	0.052
106317	M2	24.8	1.191
106317	S2	69.7	0.343
106317	N2	4.9	0.206
106317	K1	248.7	0.056
106317	M4	97	0.129
106317	O1	280.6	0.029
106317	M6	315.5	0.189
106317	S4	197.7	0.013
106317	NU2	7.6	0.04
106317	S6	353.4	0.008
106317	2N2	345.1	0.027
106317	OO1	216.9	0.001
106317	LDA2	45.7	0.008
106317	M1	264.7	0.002
106317	J1	232.9	0.002
106317	RHO1	294.3	0.001
106317	Q1	296.4	0.006
106317	T2	67.9	0.02
106317	R2	71.4	0.003
106317	2Q1	312.2	0.001
106317	P1	251.1	0.019
106317	L2	4.9	0.029
106317	K2	73.3	0.093
106317	M8	256.1	0.072
106318	M2	29.4	1.681
106318	S2	77.7	0.458
106318	N2	13.6	0.282
106318	K1	264.8	0.106
106318	M4	85.4	0.047
106318	O1	290.1	0.056
106318	M6	325.4	0.262
106318	S4	218.3	0.031
106318	NU2	15.7	0.055
106318	S6	353.8	0.011
106318	2N2	357.7	0.038
106318	OO1	239.5	0.002
106318	LDA2	51.9	0.012
106318	M1	277.4	0.004
106318	J1	252.3	0.004
106318	RHO1	300.9	0.002
106318	Q1	302.6	0.011
106318	T2	75.8	0.027
106318	R2	79.6	0.004
106318	2Q1	315.1	0.001
106318	P1	266.7	0.035
106318	L2	13.6	0.04
106318	K2	81.6	0.125
106318	M8	235.5	0.127
106319	M2	14.7	1.342
106319	S2	55.4	0.393
106319	N2	358.6	0.271
106319	K1	266	0.125
106319	M4	11.8	0.197
106319	O1	244.3	0.064
106319	M6	271.9	0.126
106319	MK3	329.8	0.021
106319	S4	164.3	0.014
106319	MN4	357.5	0.078
106319	S6	189.3	0.009
106319	2N2	192.2	0.089
106319	OO1	18	0.017
106319	M1	293.1	0.008
106319	J1	350.5	0.008
106319	Q1	208.4	0.012
106319	2Q1	322.7	0.014
106319	P1	270.7	0.04
106319	2SM2	272.8	0.031
106319	M3	199.3	0.022
106319	L2	0.5	0.123
106319	2MK3	288.3	0.081
106319	K2	52.5	0.137
106319	M8	247.4	0.054
106319	MS4	66.3	0.149
106320	M2	17.6	1.727
106320	S2	58.3	0.5
106320	N2	1.4	0.347
106320	K1	269.1	0.169
106320	M4	5.6	0.213
106320	O1	248.1	0.086
106320	M6	279.9	0.173
106320	MK3	342.4	0.017
106320	S4	144.1	0.012
106320	MN4	0.2	0.077
106320	S6	186.4	0.011
106320	2N2	198.6	0.117
106320	OO1	25.7	0.025
106320	M1	276.7	0.007
106320	J1	333.5	0.007
106320	Q1	217.5	0.014
106320	2Q1	308.1	0.008
106320	P1	276	0.052
106320	2SM2	275.2	0.031
106320	M3	206.4	0.028
106320	L2	6.4	0.159
106320	2MK3	291.9	0.1
106320	K2	57.7	0.182
106320	M8	250	0.064
106320	MS4	62	0.149
106321	M2	21.4	1.893
106321	S2	60.5	0.523
106321	N2	7.3	0.371
106321	K1	272.3	0.188
106321	M4	5.6	0.21
106321	O1	253.4	0.091
106321	M6	283.1	0.188
106321	MK3	10	0.015
106321	S4	137.2	0.023
106321	MN4	5	0.076
106321	S6	197.9	0.005
106321	2N2	208.8	0.137
106321	OO1	34.2	0.022
106321	M1	266.6	0.008
106321	J1	268.2	0.007
106321	Q1	226.5	0.012
106321	2Q1	334.2	0.013
106321	P1	281.2	0.052
106321	2SM2	272.1	0.036
106321	M3	201.1	0.026
106321	L2	18.6	0.182
106321	2MK3	303.8	0.105
106321	K2	63.2	0.194
106321	M8	260.2	0.049
106321	MS4	62.3	0.145
106322	M2	20.5	2.797
106322	S2	66.7	0.767
106322	N2	3.9	0.447
106322	K1	254.5	0.216
106322	M4	327.9	0.226
106322	O1	245.1	0.174
106322	M6	292.2	0.309
106322	S4	170.2	0.026
106322	NU2	6.2	0.087
106322	S6	316	0.01
106322	2N2	347.3	0.059
106322	OO1	263.9	0.007
106322	LDA2	41.9	0.02
106322	M1	249.8	0.012
106322	J1	259.2	0.014
106322	RHO1	241.1	0.007
106322	Q1	240.4	0.034
106322	T2	64.8	0.045
106322	R2	68.4	0.006
106322	2Q1	235.8	0.005
106322	P1	253.9	0.072
106322	L2	3.9	0.064
106322	K2	70.4	0.209
106322	M8	242.4	0.09
106323	M2	22.4	3.05
106323	S2	67	0.836
106323	N2	3.9	0.485
106323	K1	254.3	0.237
106323	M4	345.1	0.271
106323	O1	248.1	0.193
106323	M6	305.4	0.365
106323	S4	181.4	0.029
106323	NU2	6.5	0.094
106323	S6	333.3	0.012
106323	2N2	345.5	0.065
106323	OO1	260.5	0.008
106323	LDA2	43.1	0.021
106323	M1	251.2	0.014
106323	J1	257.4	0.015
106323	RHO1	245.5	0.007
106323	Q1	245.1	0.037
106323	T2	65.2	0.049
106323	R2	68.7	0.007
106323	2Q1	242	0.005
106323	P1	253.9	0.078
106323	L2	3.9	0.069
106323	K2	70.5	0.227
106323	M8	259.6	0.101
106324	M2	24.7	3.263
106324	S2	67.7	0.902
106324	N2	4.1	0.518
106324	K1	255	0.262
106324	M4	4.2	0.319
106324	O1	250.3	0.208
106324	M6	318	0.412
106324	S4	184.4	0.032
106324	NU2	6.9	0.1
106324	S6	323.7	0.014
106324	2N2	343.4	0.069
106324	OO1	259.8	0.009
106324	LDA2	44.7	0.023
106324	M1	252.7	0.015
106324	J1	257.4	0.016
106324	RHO1	248.3	0.008
106324	Q1	247.9	0.04
106324	T2	66	0.053
106324	R2	69.4	0.007
106324	2Q1	245.6	0.005
106324	P1	254.7	0.087
106324	L2	4.1	0.074
106324	K2	71.1	0.245
106324	M8	271.7	0.092
106325	M2	36.5	4.825
106325	S2	81	1.403
106325	N2	356.9	0.75
106325	K1	260.5	0.392
106325	M4	54.8	0.222
106325	O1	255.8	0.283
106325	M6	342.7	0.579
106325	S4	206.8	0.026
106325	NU2	2.3	0.146
106325	S6	327.6	0.033
106325	2N2	317.3	0.1
106325	OO1	265.1	0.012
106325	LDA2	57.2	0.034
106325	M1	258.2	0.02
106325	J1	262.7	0.022
106325	RHO1	253.9	0.011
106325	Q1	253.6	0.055
106325	T2	79.2	0.083
106325	R2	82.7	0.011
106325	2Q1	251.3	0.007
106325	P1	260.2	0.13
106325	L2	356.9	0.107
106325	K2	84.6	0.382
106325	M8	318	0.123
106326	M2	36.8	4.882
106326	S2	81	1.422
106326	N2	357.1	0.761
106326	K1	262.3	0.401
106326	M4	60.4	0.203
106326	O1	258.7	0.292
106326	M6	345.8	0.575
106326	S4	202.1	0.025
106326	NU2	2.4	0.148
106326	S6	328.2	0.03
106326	2N2	317.4	0.101
106326	OO1	266	0.013
106326	LDA2	57.3	0.034
106326	M1	260.5	0.021
106326	J1	264.1	0.023
106326	RHO1	257.2	0.011
106326	Q1	256.9	0.057
106326	T2	79.2	0.084
106326	R2	82.7	0.011
106326	2Q1	255.1	0.008
106326	P1	262.1	0.133
106326	L2	357.1	0.109
106326	K2	84.5	0.387
106326	M8	321.4	0.116
106327	M2	36.6	4.932
106327	S2	80.1	1.438
106327	N2	356.7	0.775
106327	K1	259.8	0.416
106327	M4	59.3	0.146
106327	O1	257.7	0.276
106327	M6	346.9	0.551
106327	S4	201.3	0.014
106327	NU2	2.1	0.15
106327	S6	335.3	0.026
106327	2N2	316.9	0.103
106327	OO1	261.9	0.012
106327	LDA2	56.8	0.035
106327	M1	258.7	0.02
106327	J1	260.8	0.022
106327	RHO1	256.8	0.01
106327	Q1	256.6	0.054
106327	T2	78.3	0.085
106327	R2	81.7	0.012
106327	2Q1	255.6	0.007
106327	P1	259.7	0.138
106327	L2	356.7	0.111
106327	K2	83.5	0.391
106327	M8	319.8	0.093
106328	M2	18.6	3.178
106328	S2	56.9	0.945
106328	N2	342.1	0.396
106328	K1	231.9	0.239
106328	M4	119.5	0.476
106328	O1	219.6	0.108
106328	M6	327.2	0.182
106328	MK3	24.3	0.302
106328	S4	265.8	0.04
106328	MN4	84	0.158
106328	S6	210.2	0.011
106328	2N2	324.6	0.276
106328	OO1	334.1	0.037
106328	M1	309.9	0.014
106328	J1	353.7	0.021
106328	Q1	279.5	0.013
106328	2Q1	106.7	0.029
106328	P1	248.7	0.1
106328	2SM2	318.8	0.057
106328	M3	285.3	0.033
106328	L2	37.6	0.111
106328	2MK3	335.6	0.271
106328	K2	59.9	0.302
106328	M8	12.6	0.089
106328	MS4	179.6	0.275
106329	M2	17.9	3.382
106329	S2	53.9	1.016
106329	N2	338.9	0.433
106329	K1	231.2	0.259
106329	M4	130.7	0.546
106329	O1	214	0.108
106329	M6	340.1	0.239
106329	MK3	25.6	0.332
106329	S4	275.5	0.034
106329	MN4	90.8	0.153
106329	S6	204.5	0.009
106329	2N2	329.2	0.303
106329	OO1	330.4	0.034
106329	M1	306.6	0.013
106329	J1	339.9	0.014
106329	Q1	233.3	0.013
106329	2Q1	107.2	0.024
106329	P1	248	0.097
106329	2SM2	319.9	0.06
106329	M3	279.5	0.039
106329	L2	41.7	0.12
106329	2MK3	337.1	0.301
106329	K2	56.8	0.348
106329	M8	9.3	0.083
106329	MS4	188.9	0.269
106330	M2	18	3.441
106330	S2	56.7	1.039
106330	N2	341	0.437
106330	K1	239.9	0.254
106330	M4	131.5	0.607
106330	O1	221	0.1
106330	M6	346.7	0.308
106330	MK3	23.6	0.342
106330	S4	264.8	0.033
106330	MN4	91.2	0.164
106330	S6	255	0.008
106330	2N2	328.5	0.297
106330	OO1	331.6	0.034
106330	M1	309.5	0.018
106330	J1	339.8	0.016
106330	Q1	244.6	0.011
106330	2Q1	91.8	0.021
106330	P1	241.6	0.074
106330	2SM2	316.7	0.062
106330	M3	264.1	0.039
106330	L2	32.7	0.129
106330	2MK3	336	0.323
106330	K2	60.8	0.331
106330	M8	353.1	0.085
106330	MS4	190.1	0.288
106331	M2	17.9	2.749
106331	S2	64.4	0.829
106331	N2	355.5	0.347
106331	K1	266.7	0.221
106331	M4	252.6	0.345
106331	O1	293.3	0.149
106331	M6	313.1	0.447
106331	MK3	52.2	0.242
106331	S4	215.8	0.026
106331	MN4	185.3	0.076
106331	S6	279.5	0.052
106331	2N2	293.8	0.188
106331	OO1	347.2	0.021
106331	M1	211.1	0.003
106331	J1	346.7	0.019
106331	Q1	309.9	0.036
106331	2Q1	0.9	0.015
106331	P1	277.4	0.034
106331	2SM2	322.1	0.073
106331	M3	279.8	0.021
106331	L2	332.4	0.091
106331	2MK3	336.4	0.164
106331	K2	59.3	0.266
106331	M8	295	0.21
106331	MS4	311.6	0.144
106332	M2	20.8	3.077
106332	S2	67	0.888
106332	N2	355.5	0.406
106332	K1	264.8	0.163
106332	M4	273.9	0.39
106332	O1	290.2	0.155
106332	M6	324	0.528
106332	MK3	62	0.254
106332	S4	217.4	0.029
106332	MN4	212.2	0.077
106332	S6	289.4	0.046
106332	2N2	296.1	0.179
106332	OO1	308.1	0.024
106332	M1	140.2	0.004
106332	J1	344.8	0.026
106332	Q1	322	0.027
106332	2Q1	20.7	0.015
106332	P1	210	0.081
106332	2SM2	318.4	0.055
106332	M3	295.7	0.023
106332	L2	350.2	0.094
106332	2MK3	351.1	0.195
106332	K2	57.7	0.278
106332	M8	281.8	0.216
106332	MS4	329	0.152
106333	M2	23.6	3.232
106333	S2	69.6	0.943
106333	N2	355.2	0.448
106333	K1	266.8	0.169
106333	M4	297.6	0.41
106333	O1	285	0.182
106333	M6	331.2	0.543
106333	MK3	64.3	0.239
106333	S4	208.9	0.037
106333	MN4	252.6	0.06
106333	S6	296.6	0.042
106333	2N2	310.1	0.174
106333	OO1	300.6	0.035
106333	J1	342.6	0.033
106333	Q1	315.3	0.027
106333	2Q1	13.4	0.01
106333	P1	213.2	0.102
106333	2SM2	321.4	0.061
106333	M3	269.6	0.025
106333	L2	358.5	0.092
106333	2MK3	346.9	0.197
106333	K2	62.4	0.285
106333	M8	282	0.217
106333	MS4	6.4	0.146
106334	M2	24.5	3.287
106334	S2	69.9	0.969
106334	N2	354.9	0.465
106334	K1	268.5	0.166
106334	M4	305.3	0.425
106334	O1	283.7	0.192
106334	M6	332.9	0.549
106334	MK3	65	0.235
106334	S4	205.1	0.04
106334	MN4	271.2	0.06
106334	S6	299	0.042
106334	2N2	317.2	0.171
106334	OO1	300.7	0.039
106334	J1	340	0.034
106334	Q1	311.3	0.027
106334	2Q1	11.2	0.008
106334	P1	212.7	0.115
106334	2SM2	320.5	0.065
106334	M3	261.3	0.027
106334	L2	1	0.092
106334	2MK3	345.5	0.195
106334	K2	65.3	0.293
106334	M8	283.5	0.214
106334	MS4	18.7	0.158
106335	M2	30.6	3.305
106335	S2	65.4	0.991
106335	N2	343	0.588
106335	K1	251.6	0.364
106335	M4	333.1	0.294
106335	O1	253.9	0.231
106335	M6	281.7	0.094
106335	S4	315.6	0.02
106335	NU2	349.4	0.114
106335	S6	7.8	0.026
106335	2N2	295.5	0.078
106335	OO1	249.3	0.01
106335	LDA2	46.8	0.023
106335	M1	252.7	0.016
106335	J1	250.5	0.018
106335	RHO1	254.9	0.009
106335	Q1	255	0.045
106335	T2	64	0.058
106335	R2	66.7	0.008
106335	2Q1	256.1	0.006
106335	P1	251.8	0.121
106335	L2	343	0.084
106335	K2	68.2	0.269
106335	M8	268.9	0.039
106336	M2	31.9	3.466
106336	S2	67.7	1.044
106336	N2	345.7	0.628
106336	K1	253.7	0.373
106336	M4	330.3	0.29
106336	O1	252	0.246
106336	M6	288.6	0.065
106336	S4	309.3	0.025
106336	NU2	351.9	0.122
106336	S6	12.6	0.029
106336	2N2	299.5	0.083
106336	OO1	255.5	0.011
106336	LDA2	48.5	0.024
106336	M1	252.9	0.017
106336	J1	254.6	0.019
106336	RHO1	251.3	0.009
106336	Q1	251.2	0.048
106336	T2	66.2	0.062
106336	R2	69	0.008
106336	2Q1	250.3	0.006
106336	P1	253.7	0.123
106336	L2	345.7	0.09
106336	K2	70.5	0.284
106336	M8	274	0.032
106337	M2	32.8	3.59
106337	S2	70	1.073
106337	N2	348.7	0.655
106337	K1	252.7	0.378
106337	M4	322.6	0.265
106337	O1	246.6	0.243
106337	M6	263.6	0.028
106337	S4	300.8	0.032
106337	NU2	354.7	0.127
106337	S6	354.2	0.024
106337	2N2	304.7	0.087
106337	OO1	258.8	0.01
106337	LDA2	50.1	0.025
106337	M1	249.6	0.017
106337	J1	255.7	0.019
106337	RHO1	244	0.009
106337	Q1	243.5	0.047
106337	T2	68.5	0.063
106337	R2	71.5	0.009
106337	2Q1	240.5	0.006
106337	P1	252.3	0.125
106337	L2	348.7	0.094
106337	K2	73	0.292
106337	M8	277.9	0.01
106338	M2	12.4	2.733
106338	S2	51.9	0.791
106338	N2	330	0.448
106338	K1	241.1	0.241
106338	M4	340.6	0.195
106338	O1	240.2	0.163
106338	M6	261.1	0.215
106338	S4	139.8	0.012
106338	NU2	335.7	0.087
106338	S6	235.5	0.011
106338	2N2	287.5	0.06
106338	OO1	242	0.007
106338	LDA2	30.7	0.019
106338	M1	240.7	0.012
106338	J1	241.5	0.013
106338	RHO1	239.9	0.006
106338	Q1	239.8	0.032
106338	T2	50.3	0.047
106338	R2	53.4	0.006
106338	2Q1	239.4	0.004
106338	P1	241.1	0.08
106338	L2	330	0.064
106338	K2	55	0.215
106338	M8	243.2	0.061
106339	M2	12.7	2.9
106339	S2	52.6	0.818
106339	N2	330	0.465
106339	K1	242.6	0.256
106339	M4	333.5	0.187
106339	O1	239.3	0.168
106339	M6	267.8	0.21
106339	S4	144.5	0.014
106339	NU2	335.7	0.09
106339	S6	224.1	0.013
106339	2N2	287.2	0.062
106339	OO1	245.8	0.007
106339	LDA2	31.2	0.02
106339	M1	241	0.012
106339	J1	244.1	0.013
106339	RHO1	238	0.006
106339	Q1	237.8	0.033
106339	T2	50.9	0.048
106339	R2	54.1	0.007
106339	2Q1	236.2	0.004
106339	P1	242.4	0.085
106339	L2	330	0.066
106339	K2	55.7	0.223
106339	M8	240.6	0.058
106340	M2	13	2.998
106340	S2	53.5	0.831
106340	N2	330.4	0.472
106340	K1	244	0.263
106340	M4	327.7	0.182
106340	O1	238.8	0.167
106340	M6	272.2	0.204
106340	S4	147.6	0.018
106340	NU2	336.1	0.092
106340	S6	224.6	0.013
106340	2N2	287.8	0.063
106340	OO1	249.2	0.007
106340	LDA2	31.8	0.021
106340	M1	241.4	0.012
106340	J1	246.6	0.013
106340	RHO1	236.6	0.006
106340	Q1	236.2	0.032
106340	T2	51.8	0.049
106340	R2	55	0.007
106340	2Q1	233.6	0.004
106340	P1	243.6	0.087
106340	L2	330.4	0.068
106340	K2	56.7	0.226
106340	M8	234.6	0.055
106341	M2	274.3	1.545
106341	S2	306.7	0.592
106341	N2	246.3	0.328
106341	K1	194.8	0.277
106341	M4	196.3	0.033
106341	O1	178.8	0.182
106341	M6	121.2	0.037
106341	S4	248.5	0.04
106341	NU2	250.1	0.064
106341	S6	254.5	0.009
106341	2N2	218.3	0.044
106341	OO1	210.9	0.008
106341	LDA2	289.3	0.011
106341	M1	186.8	0.013
106341	J1	202.8	0.014
106341	RHO1	172	0.007
106341	Q1	170.9	0.035
106341	T2	305.3	0.035
106341	R2	307.9	0.005
106341	2Q1	162.9	0.005
106341	P1	193.7	0.092
106341	L2	246.3	0.047
106341	K2	309.2	0.161
106341	M8	38.2	0.026
106342	M2	276.9	1.634
106342	S2	302.6	0.603
106342	N2	251.6	0.336
106342	K1	193.7	0.278
106342	M4	226.3	0.075
106342	O1	174.3	0.184
106342	M6	135.9	0.044
106342	S4	242.4	0.04
106342	NU2	255	0.065
106342	S6	238.2	0.01
106342	2N2	226.3	0.045
106342	OO1	213.1	0.008
106342	LDA2	288.8	0.011
106342	M1	184	0.013
106342	J1	203.3	0.015
106342	RHO1	166	0.007
106342	Q1	164.7	0.036
106342	T2	301.6	0.036
106342	R2	303.6	0.005
106342	2Q1	155.1	0.005
106342	P1	192.3	0.092
106342	L2	251.6	0.048
106342	K2	304.7	0.164
106342	M8	54.3	0.024
106343	M2	277.4	1.664
106343	S2	299.6	0.592
106343	N2	254.3	0.335
106343	K1	190.3	0.276
106343	M4	238.8	0.096
106343	O1	168.8	0.176
106343	M6	140.8	0.06
106343	S4	238.2	0.037
106343	NU2	257.4	0.065
106343	S6	255.9	0.015
106343	2N2	231.1	0.045
106343	OO1	211.8	0.008
106343	LDA2	287.7	0.012
106343	M1	179.6	0.013
106343	J1	201	0.014
106343	RHO1	159.6	0.007
106343	Q1	158.1	0.034
106343	T2	298.7	0.035
106343	R2	300.4	0.005
106343	2Q1	147.4	0.005
106343	P1	188.7	0.091
106343	L2	254.3	0.048
106343	K2	301.4	0.161
106343	M8	49.8	0.011
106344	M2	312.9	2.117
106344	S2	338.3	0.856
106344	N2	278.4	0.535
106344	K1	227.9	0.406
106344	M4	129.1	0.091
106344	O1	213	0.229
106344	M6	224.7	0.019
106344	S4	249.6	0.044
106344	NU2	283	0.104
106344	S6	318	0.004
106344	2N2	243.9	0.071
106344	OO1	242.8	0.01
106344	LDA2	324.7	0.015
106344	M1	220.5	0.016
106344	J1	235.3	0.018
106344	RHO1	206.6	0.009
106344	Q1	205.6	0.044
106344	T2	337.2	0.05
106344	R2	339.2	0.007
106344	2Q1	198.2	0.006
106344	P1	226.8	0.134
106344	L2	278.4	0.076
106344	K2	340.3	0.233
106344	M8	18.8	0.013
106345	M2	315.6	2.226
106345	S2	339.6	0.889
106345	N2	280.9	0.558
106345	K1	226	0.45
106345	M4	109.3	0.072
106345	O1	214.2	0.224
106345	M6	210.2	0.038
106345	S4	204.4	0.029
106345	NU2	285.6	0.108
106345	S6	359.6	0.01
106345	2N2	246.1	0.074
106345	OO1	237.8	0.01
106345	LDA2	326.8	0.016
106345	M1	220.1	0.016
106345	J1	231.9	0.018
106345	RHO1	209.1	0.009
106345	Q1	208.3	0.043
106345	T2	338.6	0.052
106345	R2	340.5	0.007
106345	2Q1	202.5	0.006
106345	P1	225.2	0.149
106345	L2	280.9	0.08
106345	K2	341.5	0.242
106345	M8	14.6	0.022
106346	M2	317.1	2.262
106346	S2	340.7	0.877
106346	N2	281.3	0.543
106346	K1	222.8	0.46
106346	M4	84	0.078
106346	O1	214.5	0.199
106346	M6	190.9	0.056
106346	S4	160	0.032
106346	NU2	286.1	0.105
106346	S6	329.2	0.016
106346	2N2	245.4	0.072
106346	OO1	231.2	0.009
106346	LDA2	328.1	0.016
106346	M1	218.6	0.014
106346	J1	227	0.016
106346	RHO1	210.9	0.008
106346	Q1	210.3	0.039
106346	T2	339.7	0.052
106346	R2	341.6	0.007
106346	2Q1	206.2	0.005
106346	P1	222.2	0.152
106346	L2	281.3	0.078
106346	K2	342.6	0.238
106346	M8	343.1	0.033
106347	M2	307.2	2.091
106347	S2	331.6	0.766
106347	N2	263.8	0.452
106347	K1	210.3	0.298
106347	M4	125.1	0.078
106347	O1	194.6	0.199
106347	M6	91.9	0.027
106347	MK3	46.9	0.025
106347	S4	164.6	0.013
106347	MN4	78.1	0.025
106347	S6	67.8	0.002
106347	2N2	49.5	0.168
106347	OO1	320.1	0.007
106347	M1	83.9	0.02
106347	J1	141.9	0.003
106347	Q1	160.5	0.03
106347	2Q1	215.8	0.018
106347	P1	174.2	0.081
106347	2SM2	288.6	0.042
106347	M3	99.1	0.006
106347	L2	49.4	0.062
106347	2MK3	25.4	0.016
106347	K2	326.2	0.18
106347	M8	251.1	0.007
106347	MS4	166.2	0.078
106348	M2	307.9	2.168
106348	S2	332.7	0.795
106348	N2	262.6	0.472
106348	K1	215.6	0.319
106348	M4	132.3	0.085
106348	O1	198	0.204
106348	M6	99.5	0.033
106348	MK3	64.4	0.027
106348	S4	173.9	0.021
106348	MN4	84.1	0.028
106348	S6	72.7	0.004
106348	2N2	46.2	0.173
106348	OO1	325	0.007
106348	M1	84.7	0.018
106348	J1	223.2	0.005
106348	Q1	161.2	0.027
106348	2Q1	221.2	0.02
106348	P1	185.5	0.062
106348	2SM2	289.8	0.052
106348	M3	112.3	0.011
106348	L2	42	0.071
106348	2MK3	44.1	0.018
106348	K2	325.1	0.168
106348	M8	267.5	0.009
106348	MS4	169.8	0.083
106349	M2	308.5	2.139
106349	S2	330.9	0.773
106349	N2	256.9	0.463
106349	K1	210.4	0.293
106349	M4	205.8	0.062
106349	O1	195.2	0.162
106349	M6	91.5	0.065
106349	MK3	21	0.016
106349	S4	132.3	0.021
106349	MN4	137.2	0.006
106349	2N2	36.8	0.223
106349	OO1	52.9	0.021
106349	M1	82.3	0.044
106349	J1	228.5	0.024
106349	Q1	179.9	0.009
106349	2Q1	236.5	0.043
106349	P1	143.3	0.065
106349	2SM2	273.8	0.072
106349	M3	87.4	0.037
106349	L2	35.8	0.117
106349	2MK3	157.5	0.032
106349	K2	325.9	0.142
106349	M8	255.4	0.011
106349	MS4	222.2	0.046
106350	M2	220.4	0.43
106350	S2	252.8	0.201
106350	N2	186.9	0.085
106350	K1	186.6	0.066
106350	M4	102.6	0.019
106350	O1	196.3	0.015
106350	M6	182.1	0.011
106350	MK3	159.2	0.01
106350	S4	223.8	0.006
106350	MN4	97.5	0.006
106350	S6	55.9	0.005
106350	2N2	64.3	0.042
106350	OO1	103.8	0.003
106350	M1	319.1	0.006
106350	J1	344.2	0.002
106350	Q1	79.1	0.009
106350	2Q1	57.7	0.003
106350	P1	246.3	0.048
106350	2SM2	107.1	0.01
106350	M3	342.8	0.001
106350	L2	7.1	0.021
106350	2MK3	106.1	0.009
106350	K2	351.6	0.061
106350	M8	55.3	0.003
106350	MS4	169.5	0.02
106351	M2	231.5	0.316
106351	S2	283.8	0.099
106351	N2	203.4	0.059
106351	K1	176	0.048
106351	M4	316.9	0.012
106351	O1	156.7	0.023
106351	M6	75.9	0.01
106351	MK3	174	0.006
106351	S4	34.2	0.003
106351	MN4	140.5	0.005
106351	S6	182.7	0.003
106351	2N2	73.2	0.051
106351	OO1	179.3	0.001
106351	M1	305.9	0.005
106351	J1	53.7	0.007
106351	Q1	126.9	0.01
106351	2Q1	76.7	0.01
106351	P1	210.8	0.024
106351	2SM2	172.1	0.017
106351	M3	114.4	0.003
106351	L2	149.7	0.012
106351	2MK3	79	0.006
106351	K2	161.6	0.048
106351	MS4	292.9	0.016
106352	M2	262.6	0.287
106352	S2	304.1	0.101
106352	N2	238.1	0.05
106352	K1	180.1	0.037
106352	M4	262	0.023
106352	O1	132.5	0.029
106352	M6	108.9	0.01
106352	MK3	253.7	0.009
106352	S4	85	0.007
106352	MN4	209	0.024
106352	2N2	247.4	0.044
106352	OO1	85	0.007
106352	M1	304.1	0.005
106352	J1	135	0.006
106352	Q1	31.5	0.001
106352	2Q1	185.7	0.01
106352	P1	194.1	0.021
106352	2SM2	280.1	0.037
106352	M3	97.4	0.009
106352	L2	73.1	0.011
106352	2MK3	175.7	0.006
106352	K2	206.5	0.082
106352	M8	243.8	0.004
106352	MS4	17.2	0.023
106353	M2	238.8	0.427
106353	S2	275	0.161
106353	N2	207.3	0.096
106353	K1	171	0.059
106353	M4	269.9	0.016
106353	O1	163.1	0.025
106353	M6	124.7	0.009
106353	MK3	256.8	0.02
106353	S4	328.5	0.017
106353	MN4	141.2	0.013
106353	S6	134	0.008
106353	2N2	62.8	0.032
106353	OO1	290.5	0.003
106353	M1	256.9	0.002
106353	J1	180	0.002
106353	Q1	286.1	0.004
106353	2Q1	71.8	0.003
106353	P1	265.4	0.014
106353	2SM2	84.5	0.013
106353	M3	0.3	0.011
106353	L2	273.9	0.015
106353	2MK3	166.5	0.021
106353	K2	282.4	0.034
106353	M8	257.2	0.004
106353	MS4	313.1	0.037
106354	M2	231.9	0.388
106354	S2	266.4	0.175
106354	N2	200.2	0.083
106354	K1	182.7	0.052
106354	M4	255.8	0.034
106354	O1	137.4	0.021
106354	M6	75.1	0.008
106354	MK3	174.9	0.018
106354	S4	70.7	0.007
106354	MN4	271	0.015
106354	S6	230.3	0.001
106354	2N2	76	0.02
106354	OO1	3.2	0.003
106354	M1	244.6	0.003
106354	J1	236	0.004
106354	Q1	47.3	0.001
106354	2Q1	17.4	0.008
106354	P1	301.8	0.007
106354	2SM2	181.9	0.006
106354	M3	342.7	0.01
106354	L2	233.7	0.008
106354	2MK3	120.1	0.014
106354	K2	278.4	0.032
106354	M8	334.3	0.002
106354	MS4	318.8	0.018
106355	M2	244.9	0.264
106355	S2	275	0.144
106355	N2	207.2	0.038
106355	K1	245.2	0.019
106355	M4	188.8	0.038
106355	O1	197.4	0.054
106355	M6	61.8	0.013
106355	MK3	136.2	0.042
106355	S4	249.2	0.018
106355	MN4	221.8	0.017
106355	S6	90.1	0.005
106355	2N2	198.8	0.049
106355	OO1	218.2	0.01
106355	M1	272.2	0.016
106355	J1	228.3	0.006
106355	Q1	194	0.007
106355	2Q1	134.1	0.016
106355	P1	149.9	0.022
106355	2SM2	328.7	0.037
106355	M3	269.4	0.018
106355	L2	263.5	0.006
106355	2MK3	68	0.029
106355	K2	273.2	0.025
106355	M8	173.5	0.005
106355	MS4	208.6	0.036
106356	M2	351.2	3.361
106356	S2	27.5	0.957
106356	N2	332	0.614
106356	K1	233.5	0.415
106356	M4	184.6	0.075
106356	O1	215.8	0.208
106356	M6	176.9	0.147
106356	MK3	317.5	0.115
106356	S4	40.7	0.008
106356	MN4	174.6	0.024
106356	S6	112.5	0.009
106356	2N2	257.3	0.141
106356	OO1	230.3	0.027
106356	M1	28.2	0.005
106356	J1	315.9	0.02
106356	Q1	233.9	0.033
106356	2Q1	315	0.018
106356	P1	239.8	0.058
106356	2SM2	250.4	0.024
106356	M3	40.9	0.051
106356	L2	14.3	0.143
106356	2MK3	290.9	0.108
106356	K2	17.9	0.263
106356	M8	52.3	0.019
106356	MS4	274	0.031
106357	M2	351.3	3.924
106357	S2	24.9	1.044
106357	N2	332.7	0.677
106357	K1	238.1	0.436
106357	M4	178.7	0.082
106357	O1	222.7	0.225
106357	M6	188.9	0.186
106357	MK3	313.2	0.163
106357	MN4	182.8	0.057
106357	S6	108.6	0.013
106357	2N2	250.5	0.191
106357	OO1	245.1	0.028
106357	M1	15	0.003
106357	J1	300.5	0.017
106357	Q1	237.9	0.038
106357	2Q1	298.9	0.014
106357	P1	238.5	0.101
106357	2SM2	252.6	0.03
106357	M3	25.8	0.061
106357	L2	23.7	0.185
106357	2MK3	292.7	0.154
106357	K2	14.4	0.279
106357	M8	39.8	0.044
106357	MS4	285.7	0.057
106358	M2	351.8	4.124
106358	S2	22.2	1.088
106358	N2	331	0.694
106358	K1	238	0.439
106358	M4	123.2	0.105
106358	O1	217.9	0.216
106358	M6	200.3	0.191
106358	MK3	316.1	0.217
106358	MN4	184.5	0.065
106358	S6	117.3	0.013
106358	2N2	252.9	0.241
106358	OO1	263.2	0.037
106358	M1	135.8	0.008
106358	J1	249.9	0.005
106358	Q1	232.9	0.031
106358	2Q1	322.1	0.015
106358	P1	228.9	0.112
106358	2SM2	260.4	0.039
106358	M3	33.5	0.069
106358	L2	32.3	0.214
106358	2MK3	297	0.19
106358	K2	11.9	0.303
106358	M8	36.3	0.065
106358	MS4	309.7	0.045
106359	M2	346	4.218
106359	S2	27.5	1.096
106359	N2	330.2	0.665
106359	K1	233.1	0.416
106359	M4	194.7	0.078
106359	O1	217.1	0.201
106359	M6	171	0.294
106359	MK3	285.3	0.166
106359	S4	63.4	0.011
106359	MN4	306	0.035
106359	S6	110.2	0.007
106359	2N2	260.3	0.246
106359	OO1	192.1	0.023
106359	M1	315.2	0.021
106359	J1	270.6	0.024
106359	Q1	240.6	0.049
106359	2Q1	354.9	0.009
106359	P1	235.8	0.132
106359	2SM2	237.4	0.052
106359	M3	23.4	0.068
106359	L2	10	0.204
106359	2MK3	271.4	0.193
106359	K2	25.2	0.346
106359	M8	18.5	0.085
106359	MS4	338.9	0.027
106360	M2	345.8	4.942
106360	S2	26.7	1.274
106360	N2	329.2	0.794
106360	K1	233.6	0.493
106360	M4	204.5	0.049
106360	O1	214	0.24
106360	M6	179	0.365
106360	MK3	283.8	0.203
106360	S4	80.3	0.01
106360	MN4	296.5	0.042
106360	S6	134.9	0.014
106360	2N2	264.3	0.278
106360	OO1	198.7	0.028
106360	M1	317.1	0.018
106360	J1	276.4	0.025
106360	Q1	239.5	0.062
106360	2Q1	2.1	0.016
106360	P1	235.2	0.154
106360	2SM2	230.2	0.056
106360	M3	23.3	0.09
106360	L2	7.9	0.23
106360	2MK3	272.7	0.235
106360	K2	24.3	0.387
106360	M8	11.2	0.09
106360	MS4	335.2	0.041
106361	M2	343.1	5.297
106361	S2	27.2	1.329
106361	N2	327.8	0.844
106361	K1	233.4	0.54
106361	M4	52.3	0.04
106361	O1	217.7	0.259
106361	M6	174.5	0.374
106361	MK3	276.9	0.25
106361	S4	105.2	0.006
106361	MN4	298.9	0.024
106361	S6	128.8	0.007
106361	2N2	255.6	0.293
106361	OO1	192.3	0.031
106361	M1	301	0.02
106361	J1	322.7	0.028
106361	Q1	237.3	0.069
106361	2Q1	279.9	0.007
106361	P1	234.2	0.125
106361	2SM2	225.3	0.064
106361	M3	20	0.091
106361	L2	0.1	0.237
106361	2MK3	264.5	0.267
106361	K2	30.5	0.397
106361	M8	309.1	0.046
106361	MS4	349.6	0.054
106362	M2	343.7	3.289
106362	S2	28.9	0.897
106362	N2	329.4	0.515
106362	K1	241.6	0.338
106362	M4	249.2	0.064
106362	O1	225.2	0.171
106362	M6	157.7	0.247
106362	MK3	277.3	0.12
106362	S4	84.2	0.01
106362	S6	65.1	0.007
106362	2N2	256.6	0.186
106362	OO1	184.8	0.01
106362	M1	280.4	0.017
106362	J1	223.3	0.02
106362	Q1	226	0.017
106362	2Q1	142.7	0.018
106362	P1	218.6	0.097
106362	2SM2	219.1	0.047
106362	M3	20.8	0.053
106362	L2	8.4	0.147
106362	2MK3	274.6	0.137
106362	K2	30.6	0.296
106362	M8	20.6	0.023
106362	MS4	302.8	0.047
106363	M2	345.3	3.816
106363	S2	27.5	1.023
106363	N2	328.4	0.598
106363	K1	237.5	0.4
106363	M4	284.4	0.045
106363	O1	217.2	0.189
106363	M6	175.5	0.268
106363	MK3	281.6	0.122
106363	S4	172.2	0.007
106363	MN4	269.6	0.014
106363	S6	98.5	0.013
106363	2N2	262.3	0.221
106363	OO1	192.8	0.019
106363	M1	319	0.014
106363	J1	264.3	0.009
106363	Q1	234.2	0.037
106363	2Q1	36.7	0.008
106363	P1	228.8	0.09
106363	2SM2	226.3	0.054
106363	M3	25.9	0.066
106363	L2	14.1	0.162
106363	2MK3	278.4	0.153
106363	K2	30.3	0.328
106363	M8	0.2	0.012
106363	MS4	304.3	0.045
106364	M2	345.6	3.972
106364	S2	26.9	1.037
106364	N2	326.5	0.63
106364	K1	234.5	0.431
106364	M4	177.2	0.033
106364	O1	209.8	0.195
106364	M6	189.3	0.301
106364	MK3	295.6	0.144
106364	S4	152.7	0.012
106364	MN4	42.2	0.012
106364	S6	92	0.013
106364	2N2	266.3	0.243
106364	OO1	212.9	0.026
106364	M1	285.2	0.006
106364	J1	35.1	0.007
106364	Q1	222	0.031
106364	2Q1	21.1	0.005
106364	P1	217.3	0.091
106364	2SM2	244.1	0.052
106364	M3	45.2	0.066
106364	L2	19.2	0.173
106364	2MK3	284.6	0.176
106364	K2	32.2	0.332
106364	MS4	241.9	0.007
106365	M2	346.5	2.776
106365	S2	21.6	0.703
106365	N2	329.5	0.485
106365	K1	232.2	0.336
106365	M4	208	0.241
106365	O1	224.9	0.173
106365	M6	184.7	0.111
106365	MK3	336.5	0.042
106365	S4	173.8	0.005
106365	MN4	195.7	0.083
106365	S6	148.8	0.006
106365	2N2	250.5	0.124
106365	OO1	238.3	0.02
106365	M1	335.7	0.004
106365	J1	277.7	0.012
106365	Q1	238.7	0.032
106365	2Q1	346.9	0.005
106365	P1	210.7	0.032
106365	2SM2	257.8	0.022
106365	M3	14	0.038
106365	L2	20.9	0.15
106365	2MK3	293.1	0.08
106365	K2	16.4	0.181
106365	M8	8.6	0.01
106365	MS4	246.2	0.092
106366	M2	345.4	3.144
106366	S2	19.1	0.75
106366	N2	329.3	0.517
106366	K1	227.9	0.356
106366	M4	200	0.141
106366	O1	217.7	0.188
106366	M6	187.9	0.183
106366	MK3	307.3	0.077
106366	S4	235.4	0.008
106366	MN4	184.7	0.052
106366	S6	111.7	0.006
106366	2N2	238.7	0.17
106366	OO1	225.4	0.019
106366	M1	283.1	0.004
106366	J1	286	0.019
106366	Q1	240.1	0.041
106366	2Q1	320.4	0.017
106366	P1	276.6	0.02
106366	2SM2	243.3	0.025
106366	M3	14.6	0.037
106366	L2	22.6	0.176
106366	2MK3	289	0.11
106366	K2	13	0.177
106366	M8	297.3	0.013
106366	MS4	236.2	0.082
106367	M2	344.3	3.23
106367	S2	16.2	0.749
106367	N2	327.1	0.514
106367	K1	223.7	0.358
106367	M4	174.5	0.1
106367	O1	207.1	0.183
106367	M6	194.2	0.18
106367	MK3	315	0.115
106367	S4	194.4	0.011
106367	MN4	147.9	0.04
106367	S6	79.1	0.005
106367	2N2	238	0.202
106367	OO1	231.5	0.02
106367	M1	213.5	0.011
106367	J1	283.2	0.014
106367	Q1	231.6	0.035
106367	2Q1	318.6	0.015
106367	2SM2	242.1	0.031
106367	M3	44.7	0.033
106367	L2	24.5	0.191
106367	2MK3	293.9	0.139
106367	K2	11.7	0.174
106367	M8	249.1	0.026
106367	MS4	210.8	0.075
106368	M2	341.2	2.417
106368	S2	24.2	0.648
106368	N2	326.5	0.399
106368	K1	231.3	0.263
106368	M4	162.1	0.023
106368	O1	217	0.132
106368	M6	162.8	0.12
106368	MK3	266.3	0.083
106368	MN4	205.9	0.015
106368	S6	106.2	0.005
106368	2N2	259.6	0.133
106368	OO1	189.9	0.015
106368	M1	334.7	0.01
106368	J1	326.8	0.011
106368	Q1	228.8	0.02
106368	2Q1	347.3	0.005
106368	P1	232	0.057
106368	2SM2	217.8	0.023
106368	M3	29.1	0.029
106368	L2	8.5	0.11
106368	2MK3	270.9	0.087
106368	K2	23.7	0.218
106368	M8	349	0.039
106368	MS4	284.9	0.029
106369	M2	342.5	2.674
106369	S2	25.5	0.692
106369	N2	328.2	0.438
106369	K1	233.8	0.291
106369	M4	206.3	0.058
106369	O1	218.6	0.145
106369	M6	173.2	0.155
106369	MK3	270.4	0.081
106369	S4	170.7	0.006
106369	MN4	211.1	0.016
106369	S6	109.9	0.005
106369	2N2	259.5	0.161
106369	OO1	198.7	0.016
106369	M1	333.7	0.014
106369	J1	337.9	0.011
106369	Q1	219.2	0.018
106369	P1	218.3	0.068
106369	2SM2	225.6	0.025
106369	M3	31.5	0.04
106369	L2	12.1	0.136
106369	2MK3	275.6	0.102
106369	K2	26.1	0.23
106369	M8	8.3	0.043
106369	MS4	280.7	0.036
106370	M2	343.2	2.8
106370	S2	24.9	0.686
106370	N2	327.7	0.448
106370	K1	232.9	0.307
106370	M4	208.5	0.078
106370	O1	213.5	0.148
106370	M6	184.4	0.169
106370	MK3	284.2	0.086
106370	S4	152.1	0.011
106370	MN4	141.1	0.014
106370	S6	90.6	0.006
106370	2N2	262.4	0.192
106370	OO1	208.5	0.018
106370	M1	311.9	0.01
106370	J1	6.2	0.013
106370	Q1	191.4	0.014
106370	2Q1	197.8	0.007
106370	P1	202.2	0.073
106370	2SM2	234.7	0.026
106370	M3	45.5	0.042
106370	L2	16.4	0.156
106370	2MK3	286.2	0.12
106370	K2	28.3	0.226
106370	M8	37.6	0.033
106370	MS4	255.2	0.028
106371	M2	335.1	1.897
106371	S2	7	0.53
106371	N2	307	0.329
106371	K1	214.5	0.212
106371	M4	143.4	0.153
106371	O1	196.9	0.132
106371	M6	203	0.029
106371	S4	99.8	0.02
106371	NU2	310.8	0.064
106371	S6	94.1	0.014
106371	2N2	278.8	0.044
106371	OO1	232	0.006
106371	LDA2	350	0.013
106371	M1	205.7	0.009
106371	J1	223.2	0.01
106371	RHO1	189.5	0.005
106371	Q1	188.2	0.026
106371	T2	5.7	0.031
106371	R2	8.2	0.004
106371	2Q1	179.5	0.003
106371	P1	213.2	0.07
106371	L2	307	0.047
106371	K2	9.6	0.144
106371	M8	340.5	0.017
106372	M2	337.9	2.038
106372	S2	9.6	0.562
106372	N2	308.7	0.356
106372	K1	216.9	0.212
106372	M4	135.4	0.164
106372	O1	195.3	0.137
106372	M6	228.9	0.05
106372	S4	102.8	0.022
106372	NU2	312.7	0.069
106372	S6	95.3	0.018
106372	2N2	279.5	0.047
106372	OO1	238.6	0.006
106372	LDA2	352.6	0.014
106372	M1	206.1	0.01
106372	J1	227.7	0.011
106372	RHO1	186	0.005
106372	Q1	184.5	0.027
106372	T2	8.3	0.033
106372	R2	10.8	0.004
106372	2Q1	173.8	0.004
106372	P1	215.3	0.07
106372	L2	308.7	0.051
106372	K2	12.2	0.153
106372	M8	349.5	0.024
106373	M2	340.3	2.16
106373	S2	11.5	0.594
106373	N2	309.3	0.383
106373	K1	218	0.213
106373	M4	124.5	0.183
106373	O1	190.1	0.146
106373	M6	237.2	0.079
106373	S4	128	0.019
106373	NU2	313.5	0.074
106373	S6	91.9	0.018
106373	2N2	278.3	0.051
106373	OO1	246	0.006
106373	LDA2	354.8	0.015
106373	M1	204.1	0.01
106373	J1	231.9	0.012
106373	RHO1	178.1	0.006
106373	Q1	176.2	0.028
106373	T2	10.2	0.035
106373	R2	12.7	0.005
106373	2Q1	162.3	0.004
106373	P1	216	0.07
106373	L2	309.3	0.055
106373	K2	14	0.162
106373	M8	0.9	0.051
106374	M2	356.5	2.939
106374	S2	35.9	0.878
106374	N2	336.5	0.543
106374	K1	251.6	0.476
106374	M4	261.7	0.226
106374	O1	243.4	0.24
106374	M6	205.6	0.075
106374	MK3	154.6	0.099
106374	S4	184.8	0.019
106374	MN4	224.5	0.088
106374	S6	28	0.008
106374	2N2	309.1	0.138
106374	OO1	230.3	0.022
106374	M1	260.3	0.024
106374	J1	260.4	0.013
106374	Q1	271.8	0.033
106374	2Q1	234.3	0.03
106374	P1	241.3	0.118
106374	2SM2	242.7	0.008
106374	M3	155.1	0.007
106374	L2	16.9	0.073
106374	2MK3	185.6	0.016
106374	K2	41.2	0.268
106374	M8	267.5	0.016
106374	MS4	277.3	0.101
106375	M2	2	3.622
106375	S2	34.6	1.043
106375	N2	337.6	0.648
106375	K1	252	0.568
106375	M4	287.6	0.219
106375	O1	226.3	0.27
106375	M6	309.9	0.091
106375	MK3	133.4	0.064
106375	S4	256.4	0.017
106375	MN4	245.3	0.069
106375	S6	233.6	0.014
106375	2N2	310.2	0.249
106375	OO1	262	0.041
106375	M1	203.7	0.016
106375	J1	200.5	0.047
106375	Q1	308.7	0.009
106375	2Q1	221.7	0.027
106375	P1	215.6	0.174
106375	2SM2	272.7	0.027
106375	M3	100.3	0.027
106375	L2	42.8	0.115
106375	2MK3	20.8	0.052
106375	K2	38	0.303
106375	M8	271.5	0.037
106375	MS4	297.8	0.078
106376	M2	3.6	3.831
106376	S2	35.7	1.053
106376	N2	340.4	0.675
106376	K1	256.1	0.605
106376	M4	298.2	0.246
106376	O1	224.2	0.285
106376	M6	348.8	0.108
106376	MK3	67.3	0.025
106376	S4	275.2	0.013
106376	MN4	247.1	0.043
106376	S6	253.5	0.015
106376	2N2	306.1	0.284
106376	OO1	279.3	0.056
106376	M1	194	0.03
106376	J1	198.7	0.084
106376	Q1	94	0.037
106376	2Q1	207.3	0.05
106376	P1	204.5	0.246
106376	2SM2	259.1	0.04
106376	M3	68.9	0.046
106376	L2	44.3	0.159
106376	2MK3	1.4	0.113
106376	K2	39.6	0.312
106376	M8	295.4	0.035
106376	MS4	280.1	0.046
106377	M2	341.7	3.141
106377	S2	9	0.948
106377	N2	315.5	0.549
106377	K1	230.4	0.405
106377	M4	180.1	0.274
106377	O1	213.9	0.219
106377	M6	170	0.081
106377	MK3	31.1	0.103
106377	S4	195.5	0.012
106377	MN4	167.8	0.113
106377	S6	123.9	0.013
106377	2N2	297	0.201
106377	OO1	223.8	0.024
106377	M1	273.5	0.01
106377	J1	280.6	0.004
106377	Q1	242.6	0.039
106377	2Q1	338	0.007
106377	P1	211.9	0.124
106377	2SM2	275.1	0.026
106377	M3	26.4	0.035
106377	L2	40.8	0.123
106377	2MK3	342.9	0.094
106377	K2	358.5	0.279
106377	M8	273.3	0.082
106377	MS4	208.7	0.105
106378	M2	340.4	3.686
106378	S2	9	1.124
106378	N2	313.5	0.659
106378	K1	226.7	0.501
106378	M4	175.3	0.25
106378	O1	210.6	0.267
106378	M6	204.6	0.1
106378	MK3	22.1	0.09
106378	S4	158	0.028
106378	MN4	139.1	0.108
106378	S6	54	0.005
106378	2N2	292.1	0.261
106378	OO1	227.6	0.028
106378	M1	246.5	0.015
106378	J1	313.5	0.011
106378	Q1	232.2	0.043
106378	2Q1	118	0.006
106378	P1	228.5	0.125
106378	2SM2	274.5	0.03
106378	M3	40.3	0.042
106378	L2	38.5	0.129
106378	2MK3	328.2	0.099
106378	K2	2.9	0.342
106378	M8	245.9	0.093
106378	MS4	183.9	0.122
106379	M2	335.4	3.81
106379	S2	11.3	1.006
106379	N2	312.3	0.687
106379	K1	222.9	0.544
106379	M4	151.3	0.087
106379	O1	201.8	0.267
106379	M6	51.8	0.065
106379	MK3	305.7	0.05
106379	S4	155.8	0.033
106379	MN4	108.9	0.109
106379	S6	29	0.004
106379	2N2	279.5	0.266
106379	OO1	213.3	0.025
106379	M1	224.3	0.004
106379	J1	299.9	0.031
106379	Q1	215	0.035
106379	2Q1	146.2	0.012
106379	P1	199.6	0.074
106379	2SM2	202	0.022
106379	M3	7.7	0.04
106379	L2	11.4	0.113
106379	2MK3	299.6	0.107
106379	K2	22.2	0.279
106379	M8	220.8	0.121
106379	MS4	171.5	0.093
106380	M2	333.1	2.275
106380	S2	8.4	0.725
106380	N2	311	0.411
106380	K1	233	0.365
106380	M4	161.9	0.114
106380	O1	222.4	0.189
106380	M6	114.1	0.056
106380	MK3	191.5	0.056
106380	S4	330	0.007
106380	MN4	172.3	0.063
106380	S6	16.4	0.015
106380	2N2	294.7	0.137
106380	OO1	207.4	0.016
106380	M1	299	0.01
106380	J1	292.3	0.012
106380	Q1	227.7	0.046
106380	2Q1	349.1	0.011
106380	P1	255.7	0.085
106380	2SM2	264.9	0.027
106380	M3	310.2	0.016
106380	L2	331.7	0.012
106380	2MK3	210.3	0.049
106380	K2	6.3	0.229
106380	M8	252.6	0.016
106380	MS4	221.3	0.07
106381	M2	335.6	2.657
106381	S2	10	0.747
106381	N2	314.3	0.407
106381	K1	232.7	0.386
106381	M4	171	0.089
106381	O1	222	0.172
106381	M6	172.4	0.024
106381	MK3	228.8	0.051
106381	S4	314.3	0.006
106381	MN4	183.5	0.045
106381	S6	58.6	0.012
106381	2N2	287.7	0.221
106381	OO1	214	0.019
106381	M1	278.7	0.017
106381	J1	237.2	0.014
106381	Q1	222.4	0.038
106381	2Q1	343.4	0.013
106381	P1	234.6	0.094
106381	2SM2	225.2	0.031
106381	M3	318.8	0.011
106381	L2	70.6	0.048
106381	2MK3	255.4	0.053
106381	K2	10.5	0.269
106381	M8	197.6	0.01
106381	MS4	245.7	0.055
106382	M2	336.4	2.855
106382	S2	12.2	0.711
106382	N2	322.1	0.408
106382	K1	230.6	0.38
106382	M4	171.2	0.059
106382	O1	221.2	0.155
106382	M6	225	0.025
106382	MK3	243.7	0.052
106382	S4	257.8	0.01
106382	MN4	176.3	0.04
106382	S6	113.4	0.011
106382	2N2	277.9	0.244
106382	OO1	214.6	0.022
106382	M1	282.2	0.021
106382	J1	200.1	0.014
106382	Q1	217.9	0.036
106382	2Q1	339.2	0.009
106382	P1	232.1	0.104
106382	2SM2	189.2	0.033
106382	M3	39.1	0.005
106382	L2	57.2	0.106
106382	2MK3	270.7	0.061
106382	K2	13.8	0.283
106382	M8	198.4	0.007
106382	MS4	266.1	0.049
106383	M2	327.5	1.672
106383	S2	359.4	0.547
106383	N2	305.5	0.413
106383	K1	245.7	0.378
106383	M4	224.3	0.051
106383	O1	243.5	0.226
106383	M6	6.8	0.041
106383	MK3	172	0.078
106383	S4	2.5	0.008
106383	MN4	179	0.028
106383	S6	106.8	0.003
106383	2N2	266	0.134
106383	OO1	293.4	0.014
106383	M1	250.8	0.035
106383	J1	231.4	0.019
106383	Q1	242.3	0.039
106383	2Q1	134.1	0.014
106383	P1	245.8	0.131
106383	2SM2	154.4	0.015
106383	M3	249.4	0.021
106383	L2	58.9	0.039
106383	2MK3	154.6	0.034
106383	K2	344.8	0.127
106383	M8	176.7	0.007
106383	MS4	248.9	0.035
106384	M2	334.3	2.324
106384	S2	7.8	0.781
106384	N2	308	0.559
106384	K1	242.8	0.469
106384	M4	203.5	0.084
106384	O1	243.1	0.29
106384	M6	333.8	0.031
106384	MK3	138.5	0.066
106384	S4	322.2	0.011
106384	MN4	204.7	0.029
106384	S6	161.4	0.006
106384	2N2	249.1	0.208
106384	OO1	265.4	0.017
106384	M1	250	0.027
106384	J1	243.8	0.035
106384	Q1	244.1	0.048
106384	2Q1	28.6	0.004
106384	P1	248	0.196
106384	2SM2	89.1	0.014
106384	M3	309.2	0.014
106384	L2	66.1	0.054
106384	2MK3	133	0.04
106384	K2	358.8	0.171
106384	M8	52.3	0.007
106384	MS4	263.1	0.075
106385	M2	336.5	2.992
106385	S2	5.5	0.971
106385	N2	311.9	0.656
106385	K1	240.3	0.478
106385	M4	185.6	0.216
106385	O1	231.9	0.285
106385	M6	117	0.007
106385	MK3	66.5	0.083
106385	S4	279.7	0.01
106385	MN4	166.2	0.087
106385	S6	220.8	0.006
106385	2N2	216.2	0.127
106385	OO1	270.9	0.021
106385	M1	311	0.016
106385	J1	248.8	0.046
106385	Q1	226.2	0.049
106385	2Q1	13.3	0.023
106385	P1	232.7	0.179
106385	2SM2	354.8	0.058
106385	M3	322.3	0.009
106385	L2	50.9	0.142
106385	2MK3	78.6	0.009
106385	K2	0.8	0.257
106385	M8	290.3	0.016
106385	MS4	240.5	0.129
106386	M2	260.3	0.924
106386	S2	288	0.303
106386	N2	233.4	0.227
106386	K1	170.7	0.107
106386	M4	86.4	0.044
106386	O1	195.8	0.103
106386	M6	82.3	0.015
106386	MK3	72	0.013
106386	S4	322	0.01
106386	MN4	94.1	0.023
106386	S6	237.2	0.004
106386	2N2	191.1	0.095
106386	OO1	296.5	0.003
106386	M1	150.3	0.011
106386	J1	140.6	0.009
106386	Q1	200.5	0.016
106386	2Q1	335.9	0.012
106386	P1	177.1	0.105
106386	2SM2	280.6	0.018
106386	M3	279.4	0.01
106386	L2	28.9	0.043
106386	2MK3	12.3	0.017
106386	K2	260.1	0.092
106386	M8	71.5	0.009
106386	MS4	124.3	0.036
106387	M2	262.6	0.997
106387	S2	289.7	0.362
106387	N2	235.5	0.238
106387	K1	171.5	0.118
106387	M4	113	0.044
106387	O1	192.6	0.102
106387	M6	75.9	0.026
106387	MK3	101.4	0.015
106387	S4	291.7	0.005
106387	MN4	104.1	0.023
106387	S6	124.9	0.002
106387	2N2	184.7	0.093
106387	OO1	255.8	0.004
106387	M1	141	0.013
106387	J1	116.9	0.011
106387	Q1	186.8	0.018
106387	2Q1	338.5	0.008
106387	P1	177.4	0.101
106387	2SM2	292.9	0.021
106387	M3	265.8	0.011
106387	L2	28.8	0.054
106387	2MK3	38.7	0.009
106387	K2	274.9	0.095
106387	M8	4.1	0.007
106387	MS4	135.8	0.035
106388	M2	263	1.042
106388	S2	291.4	0.47
106388	N2	234.6	0.245
106388	K1	180	0.123
106388	M4	135.4	0.047
106388	O1	184.8	0.095
106388	M6	80.8	0.028
106388	MK3	90.6	0.017
106388	S4	269.3	0.016
106388	MN4	78.1	0.013
106388	S6	152.3	0.007
106388	2N2	175.6	0.097
106388	OO1	296.1	0.005
106388	M1	135.4	0.015
106388	J1	105.1	0.018
106388	Q1	156.4	0.023
106388	2Q1	354.2	0.002
106388	P1	163.9	0.083
106388	2SM2	299.9	0.034
106388	M3	251.8	0.014
106388	L2	22.8	0.056
106388	2MK3	91.2	0.008
106388	K2	309	0.123
106388	M8	285.8	0.006
106388	MS4	150.1	0.028
106389	M2	282.6	0.585
106389	S2	305	0.258
106389	N2	260.3	0.152
106389	K1	242.5	0.161
106389	M4	293.2	0.041
106389	O1	234.7	0.113
106389	M6	88.6	0.008
106389	MK3	176.4	0.025
106389	S4	24	0.013
106389	MN4	201	0.012
106389	S6	274.5	0.005
106389	2N2	131.8	0.037
106389	OO1	252.4	0.008
106389	M1	227.8	0.008
106389	J1	216.2	0.014
106389	Q1	206.2	0.021
106389	2Q1	266	0.008
106389	P1	236.6	0.063
106389	2SM2	80.6	0.029
106389	M3	265.7	0.014
106389	L2	107.9	0.022
106389	2MK3	125.7	0.033
106389	K2	311.4	0.112
106389	M8	55.7	0.004
106389	MS4	326	0.022
106390	M2	299.4	0.853
106390	S2	337.4	0.41
106390	N2	266.7	0.175
106390	K1	241.8	0.21
106390	M4	168.9	0.011
106390	O1	227	0.129
106390	M6	148	0.01
106390	MK3	139.1	0.029
106390	S4	145.6	0.007
106390	MN4	311.3	0.007
106390	S6	264	0.01
106390	2N2	187.2	0.107
106390	OO1	256.5	0.006
106390	M1	254.5	0.013
106390	J1	332	0.006
106390	Q1	197.3	0.024
106390	2Q1	260.1	0.011
106390	P1	237.6	0.056
106390	2SM2	78.9	0.014
106390	M3	276.2	0.008
106390	L2	28.1	0.047
106390	2MK3	97.7	0.012
106390	K2	11.4	0.09
106390	M8	182.2	0.004
106390	MS4	226.2	0.021
106391	M2	303.9	0.963
106391	S2	317.9	0.249
106391	N2	278.5	0.275
106391	K1	221.3	0.175
106391	M4	26.2	0.005
106391	O1	212.6	0.059
106391	M6	73.7	0.032
106391	MK3	230.1	0.014
106391	S4	305.8	0.021
106391	MN4	94	0.013
106391	S6	148.6	0.01
106391	2N2	230.2	0.115
106391	OO1	69.9	0.017
106391	M1	190.9	0.017
106391	J1	159.8	0.033
106391	Q1	88.9	0.012
106391	2Q1	34.3	0.036
106391	P1	195.2	0.055
106391	2SM2	273.4	0.058
106391	M3	287.1	0.004
106391	L2	77.8	0.047
106391	2MK3	178.6	0.025
106391	K2	251.2	0.107
106391	M8	147	0.003
106391	MS4	21.7	0.024
106392	M2	266	0.883
106392	S2	301.6	0.436
106392	N2	235.9	0.201
106392	K1	203.5	0.199
106392	M4	332.2	0.024
106392	O1	197.5	0.113
106392	M6	312.5	0.008
106392	S4	264.3	0.008
106392	NU2	240	0.039
106392	S6	345	0.008
106392	2N2	205.9	0.027
106392	OO1	209.6	0.005
106392	LDA2	282.5	0.006
106392	M1	200.5	0.008
106392	J1	206.5	0.009
106392	RHO1	195	0.004
106392	Q1	194.5	0.022
106392	T2	300.1	0.026
106392	R2	302.9	0.003
106392	2Q1	191.6	0.003
106392	P1	203.1	0.066
106392	L2	235.9	0.029
106392	K2	304.4	0.119
106392	M8	325	0.003
106393	M2	275.9	1.3
106393	S2	302.8	0.567
106393	N2	251	0.286
106393	K1	198.3	0.244
106393	M4	52.9	0.022
106393	O1	186.3	0.165
106393	M6	65.9	0.024
106393	S4	280.7	0.004
106393	NU2	254.4	0.056
106393	S6	245.1	0.002
106393	2N2	226.2	0.038
106393	OO1	210.4	0.007
106393	LDA2	288.4	0.009
106393	M1	192.3	0.012
106393	J1	204.3	0.013
106393	RHO1	181.2	0.006
106393	Q1	180.3	0.032
106393	T2	301.7	0.033
106393	R2	303.8	0.005
106393	2Q1	174.4	0.004
106393	P1	197.5	0.081
106393	L2	251	0.041
106393	K2	305	0.154
106393	M8	246.6	0.007
106394	M2	285.6	1.584
106394	S2	312.1	0.68
106394	N2	248.9	0.249
106394	K1	192.4	0.272
106394	M4	113.7	0.031
106394	O1	185.1	0.17
106394	M6	137.1	0.044
106394	S4	73.2	0.021
106394	NU2	253.9	0.048
106394	S6	247.4	0.015
106394	2N2	212.2	0.033
106394	OO1	199.7	0.007
106394	LDA2	298	0.011
106394	M1	188.8	0.012
106394	J1	196	0.013
106394	RHO1	182	0.006
106394	Q1	181.5	0.033
106394	T2	311	0.04
106394	R2	313.1	0.005
106394	2Q1	177.9	0.004
106394	P1	191.9	0.09
106394	L2	248.9	0.036
106394	K2	314.2	0.185
106394	M8	255.8	0.006
106395	M2	286.8	1.647
106395	S2	319.3	0.723
106395	N2	244.2	0.246
106395	K1	187.3	0.294
106395	M4	172.8	0.032
106395	O1	175.8	0.158
106395	M6	146.1	0.036
106395	S4	0.1	0.024
106395	NU2	249.9	0.048
106395	S6	196.3	0.015
106395	2N2	201.6	0.033
106395	OO1	198.9	0.007
106395	LDA2	301.9	0.012
106395	M1	181.6	0.011
106395	J1	193.1	0.012
106395	RHO1	170.9	0.006
106395	Q1	170.1	0.031
106395	T2	318	0.043
106395	R2	320.5	0.006
106395	2Q1	164.3	0.004
106395	P1	186.5	0.097
106395	L2	244.2	0.035
106395	K2	321.9	0.197
106395	M8	330.4	0.004
106396	M2	258.4	1.693
106396	S2	286.1	0.527
106396	N2	232.5	0.398
106396	K1	155	0.245
106396	M4	138.2	0.106
106396	O1	188.7	0.087
106396	M6	96.7	0.038
106396	MK3	43.9	0.075
106396	S4	187	0.02
106396	MN4	138.3	0.029
106396	S6	237.2	0.007
106396	2N2	178.2	0.142
106396	OO1	250.5	0.022
106396	M1	309.6	0.004
106396	J1	236.5	0.015
106396	Q1	165.5	0.026
106396	2Q1	155.3	0.002
106396	P1	214	0.099
106396	2SM2	284.4	0.021
106396	L2	12.5	0.049
106396	2MK3	33.7	0.036
106396	K2	255.6	0.152
106396	M8	267.4	0.018
106396	MS4	184.9	0.077
106397	M2	262.2	1.915
106397	S2	284.1	0.678
106397	N2	233	0.435
106397	K1	156.7	0.263
106397	M4	129.6	0.113
106397	O1	191.2	0.108
106397	M6	57.5	0.036
106397	MK3	44.8	0.069
106397	S4	220.3	0.018
106397	MN4	113.7	0.031
106397	S6	292.1	0.007
106397	2N2	167.3	0.137
106397	OO1	262.4	0.024
106397	M1	242.7	0.006
106397	J1	210.6	0.016
106397	Q1	174.7	0.037
106397	2Q1	304.2	0.013
106397	P1	203.8	0.109
106397	2SM2	272.5	0.02
106397	M3	42.7	0.01
106397	L2	10.5	0.087
106397	2MK3	43.5	0.03
106397	K2	272.6	0.2
106397	M8	271.9	0.024
106397	MS4	165.5	0.066
106398	M2	267.6	2.042
106398	S2	292.1	0.983
106398	N2	233.3	0.431
106398	K1	160.7	0.283
106398	M4	141	0.081
106398	O1	187.9	0.153
106398	M6	26.4	0.059
106398	MK3	69	0.046
106398	S4	233.5	0.009
106398	MN4	108.1	0.025
106398	S6	137	0.009
106398	2N2	155.8	0.174
106398	OO1	277	0.04
106398	M1	156.8	0.013
106398	J1	147.2	0.026
106398	Q1	199.8	0.046
106398	2Q1	294.6	0.046
106398	P1	169.5	0.093
106398	2SM2	224.1	0.022
106398	M3	348.1	0.028
106398	L2	7.4	0.176
106398	2MK3	90.8	0.048
106398	K2	318.2	0.287
106398	M8	50.3	0.003
106398	MS4	175.8	0.047
106399	M2	284.7	0.285
106399	S2	309.1	0.171
106399	N2	266.5	0.073
106399	K1	225.6	0.075
106399	M4	327	0.015
106399	O1	223.6	0.045
106399	M6	162.5	0.005
106399	S4	354.7	0.003
106399	NU2	269	0.014
106399	S6	101.6	0.001
106399	2N2	248.2	0.01
106399	OO1	227.5	0.002
106399	LDA2	296.1	0.002
106399	M1	224.6	0.003
106399	J1	226.5	0.004
106399	RHO1	222.9	0.002
106399	Q1	222.7	0.009
106399	T2	308.1	0.01
106399	R2	310	0.001
106399	2Q1	221.8	0.001
106399	P1	225.5	0.025
106399	L2	266.5	0.01
106399	K2	311	0.047
106399	M8	157.1	0.003
106400	M2	286.6	0.283
106400	S2	316	0.133
106400	N2	251.3	0.06
106400	K1	223.8	0.086
106400	M4	283.7	0.015
106400	O1	240	0.041
106400	M6	186	0.01
106400	S4	41.6	0.002
106400	NU2	256.1	0.012
106400	S6	145.8	0.002
106400	2N2	216	0.008
106400	OO1	207.6	0.002
106400	LDA2	300.3	0.002
106400	M1	231.9	0.003
106400	J1	215.7	0.003
106400	RHO1	247	0.002
106400	Q1	248	0.008
106400	T2	314.8	0.008
106400	R2	317.1	0.001
106400	2Q1	256.1	0.001
106400	P1	225	0.029
106400	L2	251.3	0.009
106400	K2	318.3	0.036
106401	M2	292.2	0.273
106401	S2	348	0.139
106401	N2	252.2	0.068
106401	K1	241.6	0.066
106401	M4	295.2	0.036
106401	O1	246.3	0.046
106401	M6	180.1	0.007
106401	S4	81.6	0.011
106401	NU2	257.6	0.013
106401	S6	227.2	0.004
106401	2N2	212.3	0.009
106401	OO1	236.9	0.002
106401	LDA2	318.1	0.002
106401	M1	243.9	0.003
106401	J1	239.3	0.004
106401	RHO1	248.3	0.002
106401	Q1	248.6	0.009
106401	T2	345.7	0.008
106401	R2	350.1	0.001
106401	2Q1	250.9	0.001
106401	P1	242	0.022
106401	L2	252.2	0.01
106401	K2	352.5	0.038
106401	M8	125.7	0.001
106402	M2	275.2	0.823
106402	S2	320.6	0.528
106402	N2	258.6	0.212
106402	K1	205.1	0.28
106402	M4	38	0.053
106402	O1	201.1	0.175
106402	M6	121.9	0.029
106402	MK3	290.7	0.019
106402	S4	152.3	0.011
106402	MN4	334.9	0.034
106402	S6	110.1	0.004
106402	2N2	219.5	0.066
106402	OO1	186.2	0.006
106402	M1	222.2	0.017
106402	J1	231.1	0.028
106402	Q1	196.2	0.034
106402	2Q1	58.6	0.008
106402	P1	204.7	0.205
106402	2SM2	118.6	0.029
106402	M3	218.6	0.005
106402	L2	116	0.029
106402	2MK3	179.1	0.028
106402	K2	1.5	0.146
106402	M8	224.4	0.013
106402	MS4	52.7	0.029
106403	M2	273.1	1.338
106403	S2	300.8	0.505
106403	N2	251.3	0.34
106403	K1	213.5	0.349
106403	M4	284.1	0.048
106403	O1	191.7	0.172
106403	M6	234.8	0.004
106403	MK3	151.5	0.051
106403	S4	354.4	0.028
106403	MN4	255.6	0.022
106403	S6	61.2	0.007
106403	2N2	227.4	0.117
106403	OO1	153.8	0.016
106403	M1	144.8	0.007
106403	J1	194.2	0.021
106403	Q1	206.8	0.037
106403	2Q1	60.1	0.012
106403	P1	268.8	0.084
106403	2SM2	253.1	0.016
106403	M3	211.2	0.041
106403	L2	34.6	0.029
106403	2MK3	191.8	0.011
106403	K2	300.1	0.166
106403	M8	50.5	0.016
106403	MS4	312.6	0.08
106404	M2	267.4	1.399
106404	S2	279.7	0.385
106404	N2	241.8	0.39
106404	K1	218.7	0.274
106404	M4	165.6	0.041
106404	O1	184.5	0.161
106404	M6	5.1	0.009
106404	MK3	107.8	0.03
106404	S4	306.5	0.021
106404	MN4	129.1	0.05
106404	S6	288.9	0.017
106404	2N2	228.3	0.135
106404	OO1	248.4	0.012
106404	M1	242.2	0.032
106404	J1	224.1	0.047
106404	Q1	136.2	0.05
106404	2Q1	173.9	0.011
106404	P1	161.6	0.051
106404	2SM2	70.2	0.03
106404	M3	277.9	0.039
106404	L2	234.4	0.028
106404	2MK3	48.5	0.047
106404	K2	248	0.203
106404	M8	344.4	0.014
106404	MS4	200.5	0.03
106405	M2	281.1	1.151
106405	S2	299	0.53
106405	N2	248.9	0.288
106405	K1	228.6	0.213
106405	M4	266.2	0.024
106405	O1	187.9	0.131
106405	M6	149.8	0.016
106405	MK3	342.3	0.013
106405	S4	193.8	0.004
106405	MN4	298.2	0.011
106405	S6	337.2	0.01
106405	2N2	191.8	0.065
106405	OO1	220.6	0.022
106405	M1	321.3	0.02
106405	J1	229.9	0.02
106405	Q1	277.6	0.025
106405	2Q1	219.1	0.029
106405	P1	171.5	0.04
106405	2SM2	64.6	0.033
106405	M3	35	0.009
106405	L2	200.7	0.038
106405	2MK3	104.5	0.027
106405	K2	319.4	0.219
106405	MS4	60.1	0.027
106406	M2	278.4	1.486
106406	S2	263.3	0.541
106406	N2	265.7	0.34
106406	K1	233.2	0.264
106406	M4	157.9	0.07
106406	O1	177.4	0.114
106406	M6	26.8	0.017
106406	MK3	269.3	0.028
106406	S4	170	0.023
106406	MN4	205.3	0.04
106406	S6	340.1	0.006
106406	2N2	279	0.095
106406	OO1	223.1	0.015
106406	M1	263	0.027
106406	J1	302.9	0.012
106406	Q1	205.6	0.03
106406	2Q1	108.6	0.015
106406	P1	81.6	0.067
106406	2SM2	231.7	0.017
106406	M3	242.9	0.004
106406	L2	181.1	0.059
106406	2MK3	246.7	0.029
106406	K2	281.8	0.452
106406	M8	236.9	0.019
106406	MS4	69.3	0.048
106407	M2	239	1.552
106407	S2	275	0.339
106407	N2	218.3	0.383
106407	K1	171.5	0.359
106407	M4	256.8	0.006
106407	O1	135.4	0.109
106407	M6	158.9	0.038
106407	MK3	152.2	0.042
106407	S4	133.7	0.018
106407	MN4	164.3	0.035
106407	S6	280.5	0.015
106407	2N2	213.7	0.111
106407	OO1	71.9	0.033
106407	M1	148.8	0.025
106407	J1	155.4	0.046
106407	Q1	284.6	0.005
106407	2Q1	168.5	0.007
106407	P1	282.4	0.113
106407	2SM2	69.9	0.046
106407	M3	314.1	0.007
106407	L2	139.9	0.072
106407	2MK3	121.6	0.075
106407	K2	201.2	0.186
106407	M8	124.4	0.014
106407	MS4	73.1	0.038
106408	M2	252.4	1.863
106408	S2	279.5	0.725
106408	N2	226.3	0.432
106408	K1	173.6	0.484
106408	M4	307.2	0.025
106408	O1	148	0.153
106408	M6	152.5	0.039
106408	MK3	178.8	0.043
106408	S4	134.5	0.003
106408	MN4	232.1	0.018
106408	S6	297.2	0.015
106408	2N2	191.4	0.158
106408	OO1	10.5	0.038
106408	M1	126.7	0.042
106408	J1	150.7	0.067
106408	Q1	188.8	0.029
106408	2Q1	256	0.005
106408	P1	257.7	0.122
106408	2SM2	328.8	0.03
106408	M3	281.5	0.02
106408	L2	61.4	0.089
106408	2MK3	110.4	0.029
106408	K2	266.5	0.22
106408	M8	144.5	0.037
106408	MS4	80.4	0.028
106409	M2	267.9	1.744
106409	S2	293.4	0.848
106409	N2	235.1	0.459
106409	K1	174	0.318
106409	M4	280.9	0.09
106409	O1	192.9	0.161
106409	M6	94	0.048
106409	MK3	177.9	0.076
106409	S4	51.8	0.019
106409	MN4	272.1	0.038
106409	S6	138.4	0.005
106409	2N2	188.6	0.253
106409	OO1	355.6	0.056
106409	M1	139	0.061
106409	J1	137.7	0.055
106409	Q1	165.7	0.073
106409	2Q1	29.6	0.049
106409	P1	173.3	0.228
106409	2SM2	339.1	0.068
106409	M3	342.9	0.037
106409	L2	46.6	0.16
106409	2MK3	59.7	0.05
106409	K2	315.6	0.213
106409	M8	346.6	0.015
106409	MS4	307.1	0.067
106410	M2	218.9	0.214
106410	S2	216.5	0.085
106410	N2	173.1	0.05
106410	K1	61.7	0.011
106410	M4	98	0.023
106410	O1	223.3	0.016
106410	M6	334.4	0.007
106410	MK3	332.1	0.012
106410	S4	173	0.007
106410	MN4	25.8	0.022
106410	S6	67.5	0.006
106410	2N2	112.2	0.042
106410	OO1	215.9	0.008
106410	M1	274.8	0.004
106410	J1	234.9	0.01
106410	Q1	84.5	0.002
106410	2Q1	274.6	0.008
106410	P1	348.8	0.018
106410	2SM2	265.7	0.01
106410	M3	296.5	0.002
106410	L2	334.4	0.025
106410	2MK3	176.2	0.011
106410	K2	215.6	0.052
106410	M8	14.5	0.003
106410	MS4	133.2	0.019
106411	M2	221.3	0.175
106411	S2	231.4	0.073
106411	N2	160.9	0.042
106411	K1	218	0.002
106411	M4	162.9	0.029
106411	O1	275.3	0.02
106411	M6	310.7	0.012
106411	MK3	37.5	0.012
106411	S4	193.5	0.005
106411	MN4	52.1	0.011
106411	S6	61.9	0.006
106411	2N2	101.7	0.038
106411	OO1	156.3	0.005
106411	M1	346.2	0.001
106411	J1	265.1	0.01
106411	Q1	73	0.003
106411	2Q1	199.3	0.009
106411	P1	342.5	0.029
106411	2SM2	266.1	0.017
106411	M3	181.1	0.002
106411	L2	9.3	0.037
106411	2MK3	180.8	0.013
106411	K2	209.4	0.036
106411	M8	331.1	0.003
106411	MS4	197.2	0.019
106412	M2	221.6	0.121
106412	S2	262.7	0.069
106412	N2	152.1	0.029
106412	K1	275.1	0.013
106412	M4	179.8	0.037
106412	O1	270.6	0.022
106412	M6	322.6	0.015
106412	MK3	43.1	0.015
106412	S4	305.3	0.005
106412	MN4	100.9	0.007
106412	S6	38.7	0.004
106412	2N2	103.6	0.034
106412	OO1	113	0.002
106412	M1	37.9	0.004
106412	J1	268.5	0.007
106412	Q1	166.5	0.004
106412	2Q1	183.5	0.01
106412	P1	3.2	0.023
106412	2SM2	277.2	0.014
106412	M3	348.3	0.001
106412	L2	17.7	0.038
106412	2MK3	206.1	0.008
106412	K2	242.5	0.002
106412	M8	277.7	0.005
106412	MS4	214.4	0.025
106413	M2	230	1.927
106413	S2	265.5	0.758
106413	N2	196.2	0.384
106413	K1	168.6	0.181
106413	M4	115.3	0.209
106413	O1	129.8	0.16
106413	M6	290.2	0.05
106413	MK3	119.3	0.041
106413	S4	111.6	0.017
106413	MN4	55.1	0.071
106413	S6	71.3	0.007
106413	2N2	127.1	0.164
106413	OO1	254.7	0.019
106413	M1	42.3	0.025
106413	J1	46.5	0.013
106413	Q1	195.7	0.009
106413	2Q1	288.6	0.056
106413	P1	63.3	0.153
106413	2SM2	192.4	0.073
106413	M3	315.2	0.012
106413	L2	355.4	0.155
106413	2MK3	123.9	0.079
106413	K2	258.2	0.142
106413	M8	98.3	0.029
106413	MS4	172.1	0.11
106414	M2	232.4	2.227
106414	S2	264	0.83
106414	N2	197.7	0.483
106414	K1	159.6	0.252
106414	M4	115.3	0.25
106414	O1	130	0.16
106414	M6	276.3	0.062
106414	MK3	111.5	0.015
106414	S4	115.9	0.013
106414	MN4	79	0.097
106414	S6	282	0.006
106414	2N2	126.5	0.208
106414	OO1	273.6	0.017
106414	M1	62.2	0.027
106414	J1	113.1	0.015
106414	Q1	127.7	0.017
106414	2Q1	293.4	0.038
106414	P1	78.4	0.094
106414	2SM2	197.9	0.028
106414	M3	296.6	0.018
106414	L2	345.3	0.166
106414	2MK3	123.3	0.06
106414	K2	262.8	0.165
106414	M8	62.7	0.029
106414	MS4	153	0.125
106415	M2	234.1	2.186
106415	S2	264.2	0.787
106415	N2	201.8	0.507
106415	K1	154.9	0.303
106415	M4	106.5	0.202
106415	O1	134.5	0.135
106415	M6	261.9	0.098
106415	MK3	239	0.007
106415	S4	37.4	0.003
106415	MN4	85.9	0.078
106415	S6	274.7	0.014
106415	2N2	131.2	0.236
106415	OO1	265.8	0.016
106415	M1	84.1	0.024
106415	J1	152.4	0.016
106415	Q1	108.2	0.019
106415	2Q1	355.6	0.012
106415	P1	155.1	0.039
106415	2SM2	329.2	0.016
106415	M3	311.2	0.038
106415	L2	337.6	0.138
106415	2MK3	101	0.042
106415	K2	267.1	0.143
106415	M8	66.5	0.019
106415	MS4	130.4	0.122
106416	M2	230.4	3.091
106416	S2	255.1	1.251
106416	N2	202.5	0.687
106416	K1	155.5	0.356
106416	M4	310.9	0.215
106416	O1	153.2	0.196
106416	M6	160.9	0.165
106416	MK3	197.4	0.1
106416	S4	12	0.049
106416	MN4	281.9	0.057
106416	S6	247.6	0.028
106416	2N2	117.9	0.269
106416	OO1	262.5	0.037
106416	M1	125.9	0.022
106416	J1	122.2	0.02
106416	Q1	151	0.038
106416	2Q1	312.3	0.007
106416	P1	148.4	0.125
106416	2SM2	230.7	0.016
106416	M3	289.3	0.051
106416	L2	314	0.188
106416	2MK3	127	0.056
106416	K2	273.6	0.333
106416	M8	291.2	0.035
106416	MS4	2.2	0.152
106417	M2	231.2	3.313
106417	S2	255.5	1.33
106417	N2	203.4	0.74
106417	K1	155.7	0.398
106417	M4	309.8	0.246
106417	O1	151.9	0.218
106417	M6	159.8	0.162
106417	MK3	194.4	0.108
106417	S4	14.4	0.053
106417	MN4	272	0.064
106417	S6	250.5	0.032
106417	2N2	118.4	0.288
106417	OO1	265	0.041
106417	M1	112.4	0.029
106417	J1	119.6	0.024
106417	Q1	152.7	0.045
106417	2Q1	269.2	0.011
106417	P1	154.2	0.122
106417	2SM2	258.2	0.027
106417	M3	280.2	0.052
106417	L2	314.9	0.202
106417	2MK3	132.6	0.059
106417	K2	273.2	0.355
106417	M8	284.4	0.045
106417	MS4	1.7	0.172
106418	M2	232.7	3.169
106418	S2	254.2	1.241
106418	N2	206.1	0.643
106418	K1	153.9	0.369
106418	M4	276.3	0.188
106418	O1	159.3	0.201
106418	M6	166.4	0.132
106418	MK3	178.5	0.178
106418	S4	339.6	0.06
106418	MN4	201	0.09
106418	S6	260.8	0.033
106418	2N2	98.9	0.259
106418	OO1	264.2	0.052
106418	M1	80.3	0.037
106418	J1	79.6	0.024
106418	Q1	178.1	0.038
106418	2Q1	263.8	0.03
106418	P1	155.8	0.101
106418	2SM2	206.4	0.027
106418	M3	269.6	0.081
106418	L2	297	0.256
106418	2MK3	109.6	0.089
106418	K2	274.9	0.37
106418	M8	265.2	0.048
106418	MS4	337	0.106
106419	M2	334	2.389
106419	S2	6.7	0.71
106419	N2	291.1	0.337
106419	K1	223.3	0.258
106419	M4	345.1	0.243
106419	O1	193.9	0.168
106419	M6	143.1	0.166
106419	MK3	281.9	0.07
106419	S4	33	0.021
106419	MN4	297.7	0.083
106419	S6	195	0.009
106419	2N2	324	0.212
106419	OO1	328.2	0.022
106419	J1	223.8	0.006
106419	Q1	186.7	0.014
106419	2Q1	146.2	0.03
106419	P1	224.5	0.055
106419	2SM2	212.4	0.049
106419	M3	193.3	0.019
106419	L2	16.2	0.111
106419	2MK3	238.9	0.116
106419	K2	8.9	0.182
106419	M8	173	0.008
106419	MS4	25.3	0.155
106420	M2	335.9	2.836
106420	S2	6.7	0.833
106420	N2	290.2	0.387
106420	K1	224	0.307
106420	M4	349	0.264
106420	O1	194	0.199
106420	M6	152.5	0.227
106420	MK3	295.7	0.078
106420	S4	49.7	0.02
106420	MN4	304.9	0.087
106420	S6	227.8	0.014
106420	2N2	329.1	0.285
106420	OO1	336.4	0.028
106420	M1	8.5	0.006
106420	J1	203.8	0.006
106420	Q1	197.4	0.017
106420	2Q1	142.1	0.037
106420	P1	229.4	0.062
106420	2SM2	222.5	0.07
106420	M3	211.6	0.03
106420	L2	23.6	0.143
106420	2MK3	246.8	0.133
106420	K2	10.7	0.213
106420	MS4	29.8	0.16
106421	M2	337.4	3.044
106421	S2	7.3	0.897
106421	N2	290.3	0.413
106421	K1	224.8	0.325
106421	M4	346	0.271
106421	O1	192.7	0.212
106421	M6	161	0.298
106421	MK3	307.2	0.074
106421	S4	54.4	0.015
106421	MN4	304.1	0.091
106421	S6	228.8	0.017
106421	2N2	333.1	0.328
106421	OO1	345	0.035
106421	M1	2.9	0.016
106421	J1	168.4	0.004
106421	Q1	205.4	0.015
106421	2Q1	138.7	0.047
106421	P1	237.2	0.056
106421	2SM2	231.5	0.087
106421	M3	214.2	0.032
106421	L2	29.7	0.157
106421	2MK3	252	0.143
106421	K2	13.5	0.227
106421	M8	120.1	0.016
106421	MS4	28.5	0.158
106422	M2	334.3	2.265
106422	S2	8.8	0.654
106422	N2	295	0.319
106422	K1	225.3	0.25
106422	M4	14.4	0.097
106422	O1	203.3	0.154
106422	M6	147	0.135
106422	MK3	292.3	0.065
106422	S4	18	0.011
106422	MN4	324.1	0.035
106422	S6	224.4	0.003
106422	2N2	323.5	0.179
106422	OO1	329	0.017
106422	J1	204.8	0.008
106422	Q1	174.7	0.02
106422	2Q1	156.7	0.015
106422	P1	228.3	0.068
106422	2SM2	224.5	0.046
106422	M3	214.4	0.011
106422	L2	17.2	0.091
106422	2MK3	247.3	0.092
106422	K2	359.6	0.186
106422	M8	315.9	0.015
106422	MS4	39.8	0.055
106423	M2	338.6	2.667
106423	S2	10.3	0.781
106423	N2	294.5	0.374
106423	K1	227.1	0.294
106423	M4	345.6	0.094
106423	O1	204.2	0.183
106423	M6	164.3	0.182
106423	MK3	314.8	0.058
106423	MN4	310.1	0.025
106423	S6	284.5	0.004
106423	2N2	334.7	0.245
106423	OO1	341.8	0.022
106423	M1	356.2	0.008
106423	J1	193.2	0.006
106423	Q1	180	0.017
106423	2Q1	153.3	0.021
106423	P1	230.4	0.074
106423	2SM2	233.5	0.061
106423	M3	244.2	0.021
106423	L2	31.3	0.122
106423	2MK3	257.3	0.09
106423	K2	5	0.209
106423	M8	29.3	0.014
106423	MS4	9	0.039
106424	M2	341.4	2.955
106424	S2	11.6	0.869
106424	N2	294.5	0.417
106424	K1	227.9	0.333
106424	M4	342.6	0.108
106424	O1	200.6	0.204
106424	M6	175.1	0.215
106424	MK3	339.8	0.062
106424	S4	216.3	0.004
106424	MN4	296.4	0.027
106424	S6	309.3	0.009
106424	2N2	341.1	0.297
106424	OO1	340.6	0.029
106424	M1	1.7	0.011
106424	J1	242.9	0.006
106424	Q1	190.9	0.015
106424	2Q1	137.4	0.027
106424	P1	238.9	0.079
106424	2SM2	235.1	0.072
106424	M3	257.4	0.028
106424	L2	38.2	0.145
106424	2MK3	265.2	0.096
106424	K2	7.8	0.229
106424	M8	21.3	0.022
106424	MS4	352.6	0.037
106425	M2	237.4	0.646
106425	S2	274.9	0.24
106425	N2	197.3	0.121
106425	K1	182.2	0.101
106425	M4	221.9	0.034
106425	O1	195.7	0.048
106425	M6	129.5	0.002
106425	MK3	188.4	0.03
106425	S4	343.7	0.013
106425	MN4	179.5	0.017
106425	S6	304.5	0.003
106425	2N2	86.2	0.02
106425	OO1	273.3	0.001
106425	M1	177.3	0.009
106425	J1	96.4	0.008
106425	Q1	211.3	0.013
106425	2Q1	286.6	0.005
106425	P1	148.6	0.013
106425	2SM2	52.2	0.009
106425	M3	352.7	0.011
106425	L2	41.5	0.01
106425	2MK3	105.8	0.024
106425	K2	261.2	0.071
106425	M8	349.5	0.009
106425	MS4	280.7	0.024
106426	M2	235.8	0.594
106426	S2	270.6	0.226
106426	N2	196.8	0.121
106426	K1	198	0.08
106426	M4	244.1	0.022
106426	O1	200.6	0.041
106426	M6	115.5	0.011
106426	MK3	192.8	0.03
106426	S4	334.6	0.014
106426	MN4	216.2	0.014
106426	S6	272.1	0.007
106426	2N2	75.3	0.032
106426	OO1	300	0.001
106426	M1	134.5	0.003
106426	J1	169.9	0.012
106426	Q1	217.2	0.01
106426	2Q1	129.6	0.002
106426	P1	159.7	0.032
106426	2SM2	182.6	0.009
106426	M3	38.9	0.005
106426	L2	248.3	0.008
106426	2MK3	99.8	0.02
106426	K2	259.9	0.052
106426	M8	80.2	0.009
106426	MS4	299.8	0.023
106427	M2	254.1	0.579
106427	S2	287.4	0.199
106427	N2	228.8	0.119
106427	K1	211.8	0.061
106427	M4	354.7	0.092
106427	O1	155.2	0.034
106427	M6	92.4	0.041
106427	MK3	351.2	0.023
106427	S4	54	0.012
106427	MN4	328.2	0.046
106427	S6	168.9	0.005
106427	2N2	66.4	0.042
106427	OO1	79.7	0.026
106427	M1	12.6	0.022
106427	J1	229.5	0.016
106427	Q1	34.3	0.008
106427	2Q1	206.6	0.017
106427	P1	237.2	0.055
106427	2SM2	237.4	0.001
106427	M3	248.2	0.017
106427	L2	21.5	0.012
106427	2MK3	152.9	0.048
106427	K2	285.2	0.07
106427	M8	176	0.014
106427	MS4	58.1	0.058
106428	M2	249.1	1.846
106428	S2	274.2	0.663
106428	N2	203.8	0.378
106428	K1	166.3	0.145
106428	M4	82.9	0.041
106428	O1	180.7	0.089
106428	M6	246.7	0.08
106428	MK3	346.8	0.029
106428	S4	95.7	0.012
106428	MN4	14.4	0.023
106428	S6	264	0.009
106428	2N2	357.9	0.125
106428	OO1	287.4	0.029
106428	M1	335.8	0.021
106428	J1	106.2	0.011
106428	Q1	55	0.006
106428	2Q1	177.4	0.014
106428	P1	111.9	0.058
106428	2SM2	220.7	0.033
106428	M3	199.6	0.013
106428	L2	10.5	0.087
106428	2MK3	261.4	0.015
106428	K2	264.7	0.144
106428	M8	281.2	0.026
106428	MS4	102.6	0.038
106429	M2	249.1	2.163
106429	S2	272.6	0.78
106429	N2	203.8	0.446
106429	K1	165.4	0.175
106429	M4	53.5	0.051
106429	O1	178	0.1
106429	M6	243.2	0.094
106429	MK3	337.3	0.046
106429	S4	108.2	0.015
106429	MN4	2.6	0.027
106429	S6	260.8	0.012
106429	2N2	355.8	0.154
106429	OO1	296.5	0.033
106429	M1	328.3	0.023
106429	J1	94.4	0.01
106429	Q1	54.8	0.004
106429	2Q1	196.6	0.012
106429	P1	110.5	0.062
106429	2SM2	214.6	0.046
106429	M3	242.8	0.008
106429	L2	7.5	0.112
106429	2MK3	279.7	0.031
106429	K2	260.6	0.181
106429	M8	274.9	0.035
106429	MS4	86.2	0.042
106430	M2	246.6	2.242
106430	S2	267.8	0.803
106430	N2	202.4	0.439
106430	K1	150.6	0.166
106430	M4	204.4	0.046
106430	O1	178.3	0.059
106430	M6	269	0.102
106430	MK3	234	0.037
106430	S4	292.3	0.027
106430	MN4	172.3	0.028
106430	S6	249.9	0.01
106430	2N2	336.9	0.215
106430	OO1	328.2	0.055
106430	M1	323.7	0.041
106430	J1	74.3	0.028
106430	Q1	315.4	0.005
106430	2Q1	189	0.022
106430	P1	98.5	0.09
106430	2SM2	200.4	0.073
106430	M3	330.8	0.038
106430	L2	356.4	0.154
106430	2MK3	106.5	0.02
106430	K2	260.9	0.202
106430	M8	275.3	0.023
106430	MS4	265.9	0.046
106431	M2	300.3	2.156
106431	S2	324.6	0.72
106431	N2	257.9	0.43
106431	K1	199.7	0.31
106431	M4	41.4	0.026
106431	O1	180.1	0.209
106431	M6	64.4	0.032
106431	MK3	1.1	0.019
106431	S4	193.2	0.013
106431	MN4	227.8	0.006
106431	S6	62.2	0.005
106431	2N2	33.4	0.112
106431	OO1	323.3	0.027
106431	M1	343	0.014
106431	J1	131.6	0.011
106431	Q1	141.6	0.026
106431	2Q1	140.7	0.019
106431	P1	186.4	0.081
106431	2SM2	282.9	0.029
106431	M3	355.6	0.008
106431	L2	34	0.096
106431	2MK3	321.7	0.015
106431	K2	313.4	0.186
106431	M8	92.3	0.018
106431	MS4	135.9	0.029
106432	M2	299.9	2.506
106432	S2	324.2	0.832
106432	N2	255.9	0.502
106432	K1	198.8	0.36
106432	M4	92.9	0.065
106432	O1	179.9	0.24
106432	M6	67.5	0.051
106432	MK3	1	0.041
106432	S4	188.5	0.013
106432	MN4	65.1	0.019
106432	S6	40.2	0.008
106432	2N2	31.1	0.134
106432	OO1	307.3	0.029
106432	M1	331.5	0.015
106432	J1	145.6	0.007
106432	Q1	149.7	0.025
106432	2Q1	146.7	0.026
106432	P1	188.6	0.088
106432	2SM2	269.8	0.027
106432	M3	28.7	0.013
106432	L2	34.2	0.108
106432	2MK3	344.7	0.016
106432	K2	309.3	0.218
106432	M8	156.8	0.007
106432	MS4	147.5	0.062
106433	M2	298.7	2.635
106433	S2	320.9	0.838
106433	N2	251	0.514
106433	K1	185.7	0.37
106433	M4	152.5	0.086
106433	O1	170.5	0.193
106433	M6	58.2	0.104
106433	MK3	297.5	0.074
106433	S4	99.7	0.028
106433	MN4	98.4	0.036
106433	S6	347.2	0.013
106433	2N2	10.5	0.177
106433	OO1	340.4	0.025
106433	M1	328.1	0.016
106433	J1	96.1	0.018
106433	Q1	121	0.025
106433	2Q1	159.1	0.03
106433	P1	189	0.106
106433	2SM2	268.3	0.035
106433	M3	41.4	0.033
106433	L2	28.9	0.135
106433	2MK3	195.7	0.032
106433	K2	307.8	0.216
106433	M8	258.7	0.014
106433	MS4	181.1	0.035
106434	M2	11.6	2.896
106434	S2	49.9	0.858
106434	N2	336.3	0.477
106434	K1	258.1	0.324
106434	M4	306.7	0.325
106434	O1	246.3	0.201
106434	M6	221.6	0.141
106434	MK3	338.7	0.034
106434	S4	67.7	0.019
106434	MN4	272.4	0.071
106434	S6	202.1	0.006
106434	2N2	2.5	0.128
106434	OO1	336	0.031
106434	M1	354.1	0.018
106434	J1	76.4	0.004
106434	Q1	227.1	0.022
106434	2Q1	248.1	0.01
106434	P1	232.5	0.065
106434	2SM2	326.7	0.041
106434	M3	112.7	0.02
106434	L2	59.9	0.131
106434	2MK3	293.2	0.093
106434	K2	42.9	0.258
106434	M8	179.9	0.02
106434	MS4	4.1	0.176
106435	M2	11.5	3.53
106435	S2	47.6	0.979
106435	N2	332.1	0.565
106435	K1	252.7	0.361
106435	M4	307.5	0.377
106435	O1	242.4	0.222
106435	M6	234.5	0.17
106435	MK3	352.9	0.054
106435	S4	87.4	0.022
106435	MN4	260.4	0.093
106435	S6	223.1	0.009
106435	2N2	10.2	0.206
106435	OO1	328.6	0.042
106435	M1	332.8	0.025
106435	J1	53.2	0.018
106435	Q1	216.6	0.027
106435	2Q1	211.7	0.011
106435	P1	236.6	0.079
106435	2SM2	305.1	0.049
106435	M3	111.8	0.039
106435	L2	59.5	0.184
106435	2MK3	295.7	0.097
106435	K2	35.1	0.304
106435	M8	208.7	0.038
106435	MS4	355.4	0.202
106436	M2	10	4.078
106436	S2	47.7	1.079
106436	N2	330.2	0.615
106436	K1	248.7	0.391
106436	M4	305.7	0.354
106436	O1	239.7	0.218
106436	M6	237.8	0.164
106436	MK3	13.4	0.071
106436	S4	129.5	0.017
106436	MN4	252.4	0.113
106436	S6	213.2	0.022
106436	2N2	4.2	0.247
106436	OO1	359.1	0.051
106436	M1	25.3	0.023
106436	J1	76.7	0.009
106436	Q1	207.2	0.018
106436	2Q1	272.4	0.018
106436	P1	217.6	0.091
106436	2SM2	291.5	0.059
106436	M3	127.9	0.032
106436	L2	55.6	0.203
106436	2MK3	308.9	0.126
106436	K2	37.6	0.311
106436	M8	232.6	0.064
106436	MS4	347.6	0.207
106437	M2	351.5	2.478
106437	S2	31.1	0.72
106437	N2	315.5	0.401
106437	K1	251.7	0.376
106437	M4	194.5	0.199
106437	O1	223.3	0.238
106437	M6	157.4	0.108
106437	MK3	60	0.044
106437	S4	30.6	0.009
106437	MN4	160.4	0.074
106437	S6	118.8	0.014
106437	2N2	351	0.086
106437	OO1	295.6	0.029
106437	M1	299.9	0.015
106437	J1	339.3	0.016
106437	Q1	217.6	0.047
106437	2Q1	175.6	0.03
106437	P1	242	0.104
106437	2SM2	156.9	0.019
106437	M3	86.1	0.003
106437	L2	27.2	0.089
106437	2MK3	134.2	0.037
106437	K2	5.3	0.119
106437	M8	75.5	0.017
106437	MS4	242.3	0.133
106438	M2	355.1	3.123
106438	S2	24	0.962
106438	N2	309.7	0.569
106438	K1	250.2	0.443
106438	M4	211.6	0.258
106438	O1	232.3	0.278
106438	M6	200.9	0.108
106438	MK3	101.4	0.073
106438	S4	149.5	0.01
106438	MN4	180	0.108
106438	S6	156.1	0.009
106438	2N2	39.3	0.143
106438	OO1	14.1	0.038
106438	M1	19.7	0.008
106438	J1	136.2	0.016
106438	Q1	207.1	0.06
106438	2Q1	160.8	0.02
106438	P1	215.6	0.132
106438	2SM2	267.4	0.012
106438	M3	87.8	0.008
106438	L2	65.9	0.141
106438	2MK3	108.4	0.032
106438	K2	9	0.259
106438	M8	168.1	0.021
106438	MS4	261.3	0.174
106439	M2	357.2	3.49
106439	S2	21	1.038
106439	N2	310.5	0.63
106439	K1	246.1	0.433
106439	M4	267.3	0.254
106439	O1	243.1	0.262
106439	M6	333.1	0.083
106439	MK3	117.2	0.082
106439	S4	314.8	0.026
106439	MN4	216.2	0.11
106439	S6	12.6	0.006
106439	2N2	44.7	0.169
106439	OO1	75.2	0.057
106439	M1	122.8	0.07
106439	J1	172.5	0.067
106439	Q1	187.4	0.113
106439	2Q1	322.3	0.066
106439	P1	212.9	0.265
106439	2SM2	335.5	0.071
106439	M3	237.9	0.025
106439	L2	71.4	0.182
106439	2MK3	307.8	0.037
106439	K2	10.5	0.305
106439	M8	202.4	0.039
106439	MS4	300.6	0.177
106440	M2	13.4	3.37
106440	S2	51.8	0.928
106440	N2	335.3	0.514
106440	K1	249.9	0.312
106440	M4	338.2	0.253
106440	O1	241.4	0.201
106440	M6	255.2	0.237
106440	MK3	9.6	0.114
106440	S4	168.9	0.011
106440	MN4	329.8	0.069
106440	S6	245.1	0.009
106440	2N2	359	0.238
106440	OO1	338.9	0.051
106440	M1	4.3	0.005
106440	J1	82.2	0.016
106440	Q1	218.8	0.036
106440	2Q1	180.3	0.016
106440	P1	236.2	0.069
106440	2SM2	282	0.066
106440	M3	129.3	0.042
106440	L2	50.3	0.19
106440	2MK3	314.2	0.161
106440	K2	40.9	0.31
106440	M8	231.5	0.059
106440	MS4	40	0.159
106441	M2	15	3.937
106441	S2	53.2	1.084
106441	N2	335.5	0.607
106441	K1	255	0.374
106441	M4	345.1	0.329
106441	O1	246	0.236
106441	M6	275.6	0.277
106441	MK3	359.4	0.14
106441	S4	183	0.023
106441	MN4	319.9	0.077
106441	S6	279.5	0.016
106441	2N2	2.4	0.244
106441	OO1	330.8	0.055
106441	M1	319.5	0.014
106441	J1	22.8	0.013
106441	Q1	236.7	0.038
106441	2Q1	175	0.019
106441	P1	243.3	0.069
106441	2SM2	283.6	0.061
106441	M3	127.7	0.053
106441	L2	54.5	0.201
106441	2MK3	309.3	0.199
106441	K2	39.7	0.359
106441	M8	246.6	0.078
106441	MS4	47.6	0.188
106442	M2	12.7	4.063
106442	S2	50.9	1.085
106442	N2	333.8	0.617
106442	K1	255.2	0.368
106442	M4	13.4	0.254
106442	O1	243.7	0.195
106442	M6	289.7	0.304
106442	MK3	359.1	0.228
106442	S4	168.8	0.032
106442	MN4	333.2	0.046
106442	S6	287	0.017
106442	2N2	3.8	0.263
106442	OO1	337	0.057
106442	M1	308.5	0.022
106442	J1	31.1	0.015
106442	Q1	245.6	0.021
106442	2Q1	177.8	0.005
106442	P1	236.1	0.065
106442	2SM2	283.5	0.051
106442	M3	133.5	0.04
106442	L2	52.5	0.216
106442	2MK3	313.7	0.286
106442	K2	39.8	0.383
106442	M8	263.2	0.093
106442	MS4	80.4	0.17
106443	M2	17.5	2.32
106443	S2	53.1	0.675
106443	N2	337.4	0.358
106443	K1	253.2	0.238
106443	M4	19	0.266
106443	O1	224.2	0.125
106443	M6	292.5	0.091
106443	MK3	352.4	0.087
106443	S4	71.1	0.012
106443	MN4	332.8	0.08
106443	S6	267	0.015
106443	2N2	7.4	0.146
106443	OO1	356.6	0.038
106443	M1	349.2	0.015
106443	J1	129.9	0.009
106443	Q1	234.9	0.023
106443	2Q1	200.6	0.024
106443	P1	241.4	0.036
106443	2SM2	300.1	0.038
106443	M3	131.3	0.029
106443	L2	69.2	0.129
106443	2MK3	312.4	0.117
106443	K2	49	0.205
106443	M8	292.8	0.056
106443	MS4	66.1	0.14
106444	M2	20.7	2.883
106444	S2	55.8	0.817
106444	N2	339.5	0.441
106444	K1	252.5	0.276
106444	M4	20.9	0.269
106444	O1	231.1	0.16
106444	M6	294.5	0.172
106444	MK3	356.7	0.114
106444	S4	117.8	0.014
106444	MN4	342.6	0.09
106444	S6	278.6	0.02
106444	2N2	21.7	0.179
106444	OO1	11.4	0.046
106444	M1	9.1	0.024
106444	J1	145.7	0.006
106444	Q1	234.8	0.031
106444	2Q1	212.9	0.023
106444	P1	235.9	0.065
106444	2SM2	297.3	0.045
106444	M3	126.7	0.029
106444	L2	70.1	0.151
106444	2MK3	319.7	0.156
106444	K2	47.1	0.278
106444	M8	308.9	0.036
106444	MS4	73.1	0.152
106445	M2	23.2	3.359
106445	S2	56.9	0.932
106445	N2	341.8	0.516
106445	K1	253.4	0.327
106445	M4	32.1	0.302
106445	O1	235.3	0.172
106445	M6	289.1	0.201
106445	MK3	352.7	0.126
106445	S4	66.3	0.009
106445	MN4	355.7	0.106
106445	S6	315.2	0.019
106445	2N2	33.2	0.209
106445	OO1	8	0.05
106445	M1	354.4	0.019
106445	J1	47.9	0.005
106445	Q1	251.4	0.019
106445	2Q1	243.1	0.027
106445	P1	235.9	0.067
106445	2SM2	300	0.051
106445	M3	126.9	0.031
106445	L2	74.8	0.179
106445	2MK3	324	0.205
106445	K2	50.5	0.331
106445	M8	8.1	0.017
106445	MS4	83.5	0.184
106446	M2	21.3	3.134
106446	S2	63.6	0.831
106446	N2	343.2	0.459
106446	K1	257.9	0.31
106446	M4	357.4	0.276
106446	O1	242.6	0.194
106446	M6	289.7	0.339
106446	MK3	344.8	0.106
106446	S4	146.1	0.021
106446	MN4	351.9	0.072
106446	S6	261.1	0.023
106446	2N2	4.7	0.234
106446	OO1	327.3	0.054
106446	M1	326.6	0.021
106446	J1	341.1	0.011
106446	Q1	253.6	0.034
106446	2Q1	165.4	0.019
106446	P1	281.6	0.076
106446	2SM2	274.4	0.043
106446	M3	113.3	0.037
106446	L2	57.3	0.164
106446	2MK3	311.5	0.147
106446	K2	48.6	0.267
106446	M8	252.2	0.055
106446	MS4	62.7	0.184
106447	M2	25.5	3.841
106447	S2	64.1	0.987
106447	N2	345.2	0.562
106447	K1	261.9	0.383
106447	M4	10.8	0.389
106447	O1	251	0.239
106447	M6	305	0.413
106447	MK3	350.5	0.117
106447	S4	171.9	0.02
106447	MN4	352.8	0.104
106447	S6	292.1	0.027
106447	2N2	18.8	0.289
106447	OO1	333.2	0.069
106447	M1	345	0.027
106447	J1	348.6	0.019
106447	Q1	266.8	0.029
106447	2Q1	178.2	0.021
106447	P1	268.5	0.066
106447	2SM2	282.6	0.051
106447	M3	127.8	0.054
106447	L2	64.1	0.196
106447	2MK3	314.5	0.178
106447	K2	47.3	0.35
106447	M8	279.5	0.071
106447	MS4	72.4	0.237
106448	M2	25.6	3.959
106448	S2	61.1	1.014
106448	N2	344.9	0.591
106448	K1	257.4	0.363
106448	M4	16.4	0.346
106448	O1	245.2	0.213
106448	M6	310.5	0.373
106448	MK3	12.4	0.116
106448	S4	198.7	0.017
106448	MN4	355.6	0.103
106448	S6	302.2	0.023
106448	2N2	24.3	0.303
106448	OO1	333.8	0.061
106448	M1	337.4	0.042
106448	J1	33.5	0.021
106448	Q1	247	0.03
106448	2Q1	183.2	0.03
106448	P1	235.8	0.073
106448	2SM2	284.5	0.051
106448	M3	124.5	0.059
106448	L2	63.7	0.217
106448	2MK3	325.5	0.195
106448	K2	47.1	0.394
106448	M8	296.7	0.062
106448	MS4	78.5	0.201
106449	M2	1.4	3.007
106449	S2	38.6	0.822
106449	N2	325.3	0.478
106449	K1	247	0.369
106449	M4	292.4	0.231
106449	O1	236.3	0.221
106449	M6	193.7	0.121
106449	MK3	298.9	0.013
106449	S4	47.8	0.019
106449	MN4	262.5	0.074
106449	S6	145.8	0.007
106449	2N2	334.8	0.165
106449	OO1	295.6	0.063
106449	M1	279.8	0.02
106449	J1	321.4	0.022
106449	Q1	244	0.038
106449	2Q1	163.8	0.004
106449	P1	259.7	0.074
106449	2SM2	260.2	0.042
106449	M3	67	0.024
106449	L2	44.8	0.152
106449	2MK3	269.4	0.067
106449	K2	23.2	0.25
106449	M8	117.7	0.026
106449	MS4	347.9	0.157
106450	M2	2.5	3.739
106450	S2	40.8	0.97
106450	N2	322.6	0.59
106450	K1	248.8	0.416
106450	M4	296.3	0.279
106450	O1	236.2	0.261
106450	M6	225.3	0.155
106450	MK3	303.7	0.063
106450	S4	76.9	0.029
106450	MN4	259.5	0.081
106450	S6	166.6	0.012
106450	2N2	353.7	0.233
106450	OO1	291.4	0.072
106450	M1	290.2	0.02
106450	J1	315.2	0.029
106450	Q1	241.6	0.04
106450	2Q1	163.5	0.02
106450	P1	260.5	0.078
106450	2SM2	262.9	0.048
106450	M3	85.5	0.043
106450	L2	43.7	0.193
106450	2MK3	282.8	0.111
106450	K2	22.9	0.284
106450	M8	138.7	0.037
106450	MS4	346	0.185
106451	M2	3	3.903
106451	S2	41.5	0.984
106451	N2	322	0.615
106451	K1	249.1	0.428
106451	M4	295.8	0.239
106451	O1	231.9	0.235
106451	M6	246.6	0.165
106451	MK3	323.5	0.094
106451	S4	99.5	0.024
106451	MN4	245.4	0.065
106451	S6	196.8	0.014
106451	2N2	0.3	0.239
106451	OO1	322.1	0.061
106451	M1	323.8	0.025
106451	J1	311.3	0.025
106451	Q1	250	0.027
106451	2Q1	217.2	0.018
106451	P1	253.7	0.06
106451	2SM2	258.6	0.051
106451	M3	80.4	0.042
106451	L2	44.1	0.201
106451	2MK3	290.6	0.152
106451	K2	26	0.284
106451	M8	159.7	0.032
106451	MS4	340.5	0.138
106452	M2	347	1.403
106452	S2	45.1	0.298
106452	N2	308.5	0.3
106452	K1	143.3	0.159
106452	M4	288.1	0.054
106452	O1	119.1	0.089
106452	M6	313.6	0.052
106452	MK3	115.9	0.038
106452	S4	282.5	0.006
106452	MN4	288	0.016
106452	S6	303.2	0.006
106452	2N2	234.2	0.033
106452	OO1	77.4	0.017
106452	M1	324.9	0.019
106452	J1	36.5	0.032
106452	Q1	108.6	0.016
106452	2Q1	139.2	0.025
106452	2SM2	257.6	0.011
106452	M3	67.2	0.02
106452	L2	35.2	0.091
106452	2MK3	94.1	0.034
106452	K2	121.1	0.178
106452	M8	159.7	0.006
106452	MS4	305.3	0.015
106453	M2	350.9	1.485
106453	S2	25.5	0.254
106453	N2	318.7	0.369
106453	K1	146.1	0.209
106453	M4	304.8	0.071
106453	O1	133.4	0.106
106453	M6	309.4	0.082
106453	MK3	117.5	0.065
106453	S4	328.3	0.013
106453	MN4	288.5	0.046
106453	S6	75	0.007
106453	2N2	260.1	0.055
106453	OO1	242.6	0.006
106453	M1	4.4	0.047
106453	J1	344.1	0.02
106453	Q1	105.8	0.02
106453	2Q1	157	0.019
106453	2SM2	68.6	0.009
106453	M3	3.2	0.017
106453	L2	42.4	0.113
106453	2MK3	73.9	0.057
106453	K2	92.4	0.094
106453	M8	235.2	0.029
106453	MS4	325.4	0.017
106454	M2	350.9	1.561
106454	S2	21.4	0.334
106454	N2	319.6	0.394
106454	K1	155.7	0.181
106454	M4	350.4	0.051
106454	O1	134.6	0.096
106454	M6	323.3	0.071
106454	MK3	132.4	0.074
106454	S4	339.4	0.004
106454	MN4	280.8	0.046
106454	S6	109.4	0.016
106454	2N2	264.7	0.042
106454	OO1	132.5	0.003
106454	M1	32.7	0.024
106454	J1	233	0.011
106454	Q1	94.7	0.044
106454	2Q1	132.1	0.011
106454	2SM2	146.1	0.011
106454	M3	8.7	0.04
106454	L2	34.7	0.118
106454	2MK3	77.1	0.059
106454	K2	70.1	0.143
106454	M8	243.1	0.023
106454	MS4	275.9	0.01
106455	M2	352.1	1.635
106455	S2	28.4	0.374
106455	N2	317.2	0.429
106455	K1	166.3	0.188
106455	M4	78	0.056
106455	O1	146.3	0.095
106455	M6	346.8	0.029
106455	MK3	138.7	0.035
106455	S4	163.7	0.013
106455	MN4	219.1	0.015
106455	S6	157.3	0.016
106455	2N2	232.9	0.04
106455	OO1	46.7	0.025
106455	M1	111.9	0.029
106455	J1	235.2	0.01
106455	Q1	101.2	0.068
106455	2Q1	61.6	0.013
106455	2SM2	171.5	0.025
106455	M3	36.2	0.045
106455	L2	25.6	0.137
106455	2MK3	76.4	0.062
106455	K2	88.6	0.158
106455	M8	262.5	0.009
106455	MS4	165.5	0.019
106456	M2	339.2	1.215
106456	S2	18.4	0.188
106456	N2	330.5	0.241
106456	K1	132.1	0.13
106456	M4	239.2	0.111
106456	O1	111.2	0.105
106456	M6	90.2	0.007
106456	MK3	42.5	0.032
106456	S4	221.3	0.007
106456	MN4	215.8	0.055
106456	S6	217.5	0.007
106456	2N2	238.3	0.038
106456	OO1	354.6	0.006
106456	M1	244.7	0.01
106456	J1	353.4	0.008
106456	Q1	156.5	0.011
106456	2Q1	349.5	0.012
106456	P1	110.4	0.024
106456	2SM2	287.1	0.003
106456	M3	57.5	0.005
106456	L2	289.8	0.038
106456	2MK3	7	0.025
106456	K2	2.4	0.053
106456	M8	133	0.015
106456	MS4	291.7	0.03
106457	M2	352.7	1.861
106457	S2	15.2	0.275
106457	N2	332.4	0.345
106457	K1	144.4	0.185
106457	M4	234.1	0.091
106457	O1	128	0.147
106457	M6	283.9	0.093
106457	MK3	72.5	0.025
106457	S4	187.5	0.011
106457	MN4	221.4	0.039
106457	S6	263.9	0.009
106457	2N2	292.7	0.038
106457	OO1	22.9	0.009
106457	M1	282.5	0.021
106457	J1	57	0.022
106457	Q1	174.1	0.018
106457	2Q1	42.3	0.019
106457	P1	107.8	0.039
106457	2SM2	285.7	0.045
106457	M3	8.8	0.011
106457	L2	11.7	0.044
106457	2MK3	65.9	0.023
106457	K2	10.1	0.103
106457	M8	100.1	0.035
106457	MS4	271.8	0.016
106458	M2	354.9	1.908
106458	S2	21	0.269
106458	N2	332.6	0.36
106458	K1	145.3	0.19
106458	M4	239.1	0.046
106458	O1	126	0.151
106458	M6	279.9	0.091
106458	MK3	120.1	0.024
106458	S4	7.1	0.008
106458	MN4	220.1	0.016
106458	S6	283.2	0.012
106458	2N2	285.2	0.034
106458	OO1	45.7	0.006
106458	M1	286.5	0.016
106458	J1	78.6	0.034
106458	Q1	144.8	0.022
106458	2Q1	56.2	0.028
106458	P1	91	0.046
106458	2SM2	294.8	0.047
106458	M3	10.1	0.006
106458	L2	28.2	0.034
106458	2MK3	88.7	0.026
106458	K2	358	0.1
106458	M8	71.7	0.014
106458	MS4	287.7	0.012
106459	M2	335.2	1.279
106459	S2	359.8	0.167
106459	N2	330.1	0.272
106459	K1	120	0.147
106459	M4	263	0.105
106459	O1	103.4	0.098
106459	M6	351.5	0.033
106459	MK3	18.1	0.006
106459	S4	333.3	0.004
106459	MN4	295.3	0.043
106459	S6	259.5	0.003
106459	2N2	342.1	0.03
106459	OO1	40	0.011
106459	M1	224.8	0.015
106459	J1	70.4	0.007
106459	Q1	135.9	0.025
106459	2Q1	231.4	0.006
106459	P1	86.2	0.031
106459	2SM2	140.5	0.023
106459	M3	74.3	0.016
106459	L2	260.3	0.055
106459	2MK3	33.4	0.019
106459	K2	356.4	0.103
106459	M8	91.9	0.015
106459	MS4	295.4	0.021
106460	M2	347.4	1.843
106460	S2	354.2	0.273
106460	N2	337.8	0.359
106460	K1	134	0.188
106460	M4	244.5	0.13
106460	O1	112.3	0.142
106460	M6	270.1	0.07
106460	MK3	39	0.012
106460	S4	177.1	0.017
106460	MN4	205.4	0.059
106460	S6	45	0.003
106460	2N2	356	0.052
106460	OO1	21.1	0.012
106460	M1	277.6	0.025
106460	J1	34.9	0.014
106460	Q1	163.9	0.02
106460	2Q1	225.5	0.008
106460	P1	132.7	0.028
106460	2SM2	176.6	0.021
106460	L2	310	0.086
106460	2MK3	34.2	0.038
106460	K2	35.4	0.093
106460	M8	165.2	0.035
106460	MS4	209.1	0.045
106461	M2	351.3	1.921
106461	S2	348	0.278
106461	N2	340	0.361
106461	K1	147.4	0.214
106461	M4	228.5	0.09
106461	O1	121.6	0.127
106461	M6	283	0.073
106461	MK3	102.3	0.01
106461	S4	217.1	0.019
106461	MN4	178.6	0.075
106461	2N2	348.6	0.055
106461	OO1	19.6	0.018
106461	M1	287.8	0.036
106461	J1	85	0.01
106461	Q1	186.1	0.021
106461	2Q1	203.4	0.009
106461	P1	128.7	0.069
106461	2SM2	224.6	0.037
106461	M3	127.5	0.01
106461	L2	317.8	0.107
106461	2MK3	57.8	0.03
106461	K2	52.5	0.127
106461	M8	163	0.023
106461	MS4	191.6	0.051
106462	M2	330	1.105
106462	S2	10	0.185
106462	N2	315.5	0.209
106462	K1	128.8	0.111
106462	M4	99.5	0.049
106462	O1	113.1	0.066
106462	M6	335	0.01
106462	MK3	94.9	0.019
106462	S4	209.7	0.006
106462	MN4	121.7	0.011
106462	S6	201.6	0.006
106462	2N2	226	0.075
106462	OO1	254	0.007
106462	M1	203.1	0.012
106462	J1	253.1	0.018
106462	Q1	184.1	0.014
106462	2Q1	346.1	0.022
106462	P1	110.6	0.012
106462	2SM2	35.2	0.003
106462	M3	49.8	0.01
106462	L2	286.5	0.043
106462	2MK3	342.1	0.02
106462	K2	1.6	0.034
106462	M8	316	0.029
106462	MS4	183.9	0.01
106463	M2	351	1.683
106463	S2	6.5	0.304
106463	N2	319.3	0.329
106463	K1	130.4	0.167
106463	M4	280.9	0.159
106463	O1	101.3	0.11
106463	M6	323.2	0.119
106463	MK3	118	0.091
106463	S4	220.8	0.017
106463	MN4	246.2	0.054
106463	S6	17.9	0.006
106463	2N2	69.8	0.017
106463	OO1	350	0.008
106463	M1	310.9	0.006
106463	J1	75.9	0.005
106463	Q1	308.7	0.005
106463	2Q1	27.5	0.008
106463	P1	156.2	0.011
106463	2SM2	331	0.007
106463	M3	322.6	0.021
106463	L2	16.5	0.068
106463	2MK3	76.7	0.105
106463	K2	42.1	0.131
106463	M8	225.4	0.015
106463	MS4	328.9	0.028
106464	M2	352	1.713
106464	S2	1.8	0.303
106464	N2	321.6	0.299
106464	K1	138.4	0.17
106464	M4	276.6	0.174
106464	O1	98.7	0.11
106464	M6	326.1	0.076
106464	MK3	110.3	0.087
106464	S4	226.7	0.013
106464	MN4	245.7	0.06
106464	S6	338.4	0.01
106464	2N2	14.1	0.022
106464	OO1	336	0.013
106464	M1	355.7	0.016
106464	J1	70.5	0.013
106464	Q1	3.1	0.01
106464	2Q1	104.5	0.004
106464	P1	115.1	0.018
106464	2SM2	348.2	0.014
106464	M3	321.1	0.039
106464	L2	16.4	0.059
106464	2MK3	67.3	0.109
106464	K2	42.7	0.163
106464	M8	250.2	0.012
106464	MS4	320.9	0.035
106465	M2	304.3	1.36
106465	S2	323.1	0.14
106465	N2	287.9	0.179
106465	K1	110.9	0.087
106465	M4	187.6	0.092
106465	O1	90.5	0.076
106465	M6	39.4	0.109
106465	MK3	32.5	0.037
106465	S4	234	0.005
106465	MN4	178.2	0.031
106465	S6	88.9	0.004
106465	2N2	249.9	0.069
106465	OO1	340.1	0.002
106465	M1	180.8	0.009
106465	J1	298.6	0.003
106465	Q1	162.5	0.009
106465	2Q1	45.4	0.008
106465	P1	50.4	0.015
106465	2SM2	227.3	0.009
106465	M3	30.3	0.009
106465	L2	292.4	0.056
106465	2MK3	342.6	0.045
106465	K2	315.5	0.086
106465	M8	258.8	0.035
106465	MS4	243.8	0.022
106466	M2	308	1.729
106466	S2	332.2	0.163
106466	N2	287.9	0.21
106466	K1	115.3	0.102
106466	M4	173.4	0.063
106466	O1	104.5	0.102
106466	M6	76.1	0.14
106466	MK3	56.1	0.052
106466	S4	166.1	0.009
106466	MN4	191.9	0.017
106466	S6	314.4	0.002
106466	2N2	255.9	0.098
106466	OO1	252.5	0.003
106466	M1	166.7	0.008
106466	J1	335.8	0.011
106466	Q1	147.6	0.022
106466	2Q1	81.7	0.013
106466	P1	73.3	0.024
106466	2SM2	289.7	0.024
106466	M3	8.5	0.009
106466	L2	293.3	0.093
106466	2MK3	339.7	0.071
106466	K2	321.2	0.104
106466	M8	276.4	0.037
106466	MS4	246.2	0.019
106467	M2	306.9	1.737
106467	S2	326.7	0.179
106467	N2	280.7	0.199
106467	K1	116.2	0.094
106467	M4	85.4	0.043
106467	O1	108.1	0.104
106467	M6	104.1	0.109
106467	MK3	74	0.045
106467	S4	177.2	0.013
106467	MN4	343.4	0.021
106467	2N2	260.3	0.098
106467	OO1	313.1	0.003
106467	M1	194.3	0.012
106467	J1	326.1	0.011
106467	Q1	140.2	0.018
106467	2Q1	101.1	0.012
106467	P1	72.1	0.021
106467	2SM2	300.8	0.031
106467	M3	350.9	0.012
106467	L2	299.5	0.103
106467	2MK3	334.8	0.065
106467	K2	326.3	0.102
106467	M8	347.7	0.027
106467	MS4	102.8	0.012
106468	M2	334.4	0.873
106468	S2	357.5	0.101
106468	N2	330.7	0.189
106468	K1	132.8	0.073
106468	M4	158.8	0.029
106468	O1	122.1	0.056
106468	M6	83	0.05
106468	MK3	343.8	0.012
106468	S4	274.8	0.01
106468	MN4	162.9	0.013
106468	S6	222.4	0.007
106468	2N2	83.6	0.028
106468	OO1	107.9	0.006
106468	M1	226	0.009
106468	J1	88.6	0.008
106468	Q1	147.7	0.008
106468	2Q1	209.2	0.003
106468	P1	204.7	0.007
106468	2SM2	82.3	0.017
106468	M3	332.9	0.011
106468	L2	275.6	0.068
106468	2MK3	298.7	0.012
106468	K2	15.1	0.09
106468	M8	346.7	0.011
106468	MS4	196.6	0.019
106469	M2	338.2	1.377
106469	S2	329.5	0.188
106469	N2	329.7	0.249
106469	K1	135.2	0.101
106469	M4	156.4	0.006
106469	O1	122.7	0.087
106469	M6	226.6	0.031
106469	MK3	77.8	0.02
106469	S4	176.7	0.017
106469	MN4	297.4	0.003
106469	S6	128.3	0.005
106469	2N2	307	0.043
106469	OO1	334.6	0.011
106469	M1	249.7	0.016
106469	J1	296.9	0.003
106469	Q1	201.3	0.009
106469	2Q1	255.8	0.008
106469	2SM2	167.2	0.015
106469	M3	10.2	0.008
106469	L2	297.9	0.067
106469	2MK3	34.1	0.023
106469	K2	41.1	0.096
106469	M8	308.9	0.017
106469	MS4	206.6	0.019
106470	M2	336	1.434
106470	S2	303.2	0.173
106470	N2	326.8	0.228
106470	K1	138.8	0.151
106470	M4	4.2	0.071
106470	O1	114.7	0.077
106470	M6	247.9	0.037
106470	MK3	101.1	0.018
106470	S4	261.9	0.015
106470	MN4	296.9	0.03
106470	S6	148.5	0.006
106470	2N2	269.9	0.058
106470	OO1	336.9	0.017
106470	M1	258.7	0.01
106470	J1	192.3	0.009
106470	Q1	272.9	0.007
106470	2Q1	260.4	0.019
106470	P1	103.9	0.066
106470	2SM2	186.4	0.032
106470	M3	60.8	0.005
106470	L2	305.8	0.076
106470	2MK3	58	0.02
106470	K2	46.6	0.14
106470	M8	203.6	0.004
106470	MS4	351.3	0.022
106471	M2	344.6	1.112
106471	S2	24.7	0.147
106471	N2	335.6	0.225
106471	K1	143.9	0.12
106471	M4	162.8	0.06
106471	O1	120.4	0.082
106471	M6	117.8	0.035
106471	MK3	132.8	0.011
106471	S4	113.9	0.006
106471	MN4	128.1	0.004
106471	S6	104	0.008
106471	2N2	249.9	0.064
106471	OO1	103	0.003
106471	M1	173.8	0.017
106471	J1	254.9	0.018
106471	Q1	150.3	0.02
106471	2Q1	323.6	0.016
106471	2SM2	219.1	0.011
106471	M3	51	0.018
106471	L2	297.4	0.052
106471	2MK3	44.4	0.015
106471	K2	345.6	0.065
106471	M8	72.1	0.01
106471	MS4	320.7	0.001
106472	M2	351.4	1.446
106472	S2	14.2	0.243
106472	N2	323.6	0.279
106472	K1	149.2	0.153
106472	M4	45	0.033
106472	O1	135.4	0.1
106472	M6	359.3	0.058
106472	MK3	152.1	0.046
106472	S4	287.8	0.01
106472	MN4	77.3	0.006
106472	S6	291.9	0.003
106472	2N2	270.4	0.016
106472	OO1	28.4	0.012
106472	M1	277.4	0.021
106472	J1	332.2	0.014
106472	Q1	169.4	0.009
106472	2Q1	334.7	0.024
106472	2SM2	334.3	0.017
106472	M3	64.5	0.021
106472	L2	23.5	0.036
106472	2MK3	98	0.029
106472	K2	18.2	0.058
106472	M8	295.3	0.008
106472	MS4	203.6	0.008
106473	M2	352.8	1.47
106473	S2	14.9	0.267
106473	N2	321.9	0.274
106473	K1	157.9	0.177
106473	M4	35.2	0.084
106473	O1	140.1	0.106
106473	M6	342.3	0.058
106473	MK3	157	0.048
106473	S4	265.4	0.005
106473	MN4	23.8	0.012
106473	S6	272.7	0.003
106473	2N2	262.1	0.027
106473	OO1	34.8	0.013
106473	M1	325.7	0.015
106473	J1	19.8	0.011
106473	Q1	136.7	0.012
106473	2Q1	8.9	0.015
106473	2SM2	350.3	0.027
106473	M3	43.8	0.017
106473	L2	45.6	0.027
106473	2MK3	93.6	0.023
106473	K2	13.9	0.08
106473	M8	353.3	0.011
106473	MS4	99.1	0.011
106474	M2	352.2	0.804
106474	S2	25.7	0.119
106474	N2	341	0.163
106474	K1	133.4	0.1
106474	M4	217.7	0.099
106474	O1	102.3	0.069
106474	M6	127.5	0.067
106474	MK3	14.3	0.015
106474	S4	226.3	0.003
106474	MN4	223.7	0.031
106474	S6	93	0.002
106474	2N2	245	0.047
106474	OO1	286.8	0.007
106474	M1	191.9	0.004
106474	J1	310.1	0.004
106474	Q1	137.5	0.011
106474	2Q1	338	0.015
106474	P1	185.5	0.015
106474	2SM2	30.8	0.002
106474	M3	181	0.003
106474	L2	299.2	0.025
106474	2MK3	327	0.018
106474	K2	2	0.045
106474	M8	49.7	0.013
106474	MS4	292.5	0.035
106475	M2	0.8	1.258
106475	S2	26.4	0.201
106475	N2	344.1	0.249
106475	K1	148.1	0.143
106475	M4	254.3	0.191
106475	O1	113.3	0.102
106475	M6	176.3	0.075
106475	MK3	61.4	0.039
106475	S4	143.5	0.009
106475	MN4	232.4	0.065
106475	S6	114.3	0.005
106475	2N2	268.1	0.045
106475	OO1	320.3	0.016
106475	M1	253.1	0.009
106475	J1	336.2	0.011
106475	Q1	187.2	0.014
106475	2Q1	31.1	0.019
106475	P1	180	0.012
106475	2SM2	230.5	0.008
106475	M3	355.3	0.007
106475	L2	298.7	0.029
106475	2MK3	23.2	0.039
106475	K2	26.6	0.087
106475	M8	135.5	0.039
106475	MS4	324.9	0.057
106476	M2	1.8	1.43
106476	S2	5.8	0.227
106476	N2	342.3	0.212
106476	K1	154.5	0.147
106476	M4	270.8	0.198
106476	O1	123.5	0.107
106476	M6	249.5	0.026
106476	MK3	71.4	0.049
106476	S4	174.6	0.007
106476	MN4	230.7	0.061
106476	S6	142.1	0.005
106476	2N2	298.6	0.073
106476	OO1	340.5	0.013
106476	M1	218.6	0.011
106476	J1	346.9	0.005
106476	Q1	192.1	0.018
106476	2Q1	53.6	0.017
106476	2SM2	249.7	0.012
106476	M3	82.6	0.012
106476	L2	350.4	0.056
106476	2MK3	59.4	0.041
106476	K2	28.9	0.144
106476	M8	217.3	0.026
106476	MS4	312.7	0.042
106477	M2	8.8	0.938
106477	S2	48.8	0.121
106477	N2	2.3	0.182
106477	K1	149.6	0.1
106477	M4	271.8	0.129
106477	O1	115.3	0.088
106477	M6	161.9	0.062
106477	MK3	96.8	0.026
106477	S4	149.3	0.006
106477	MN4	297.8	0.043
106477	S6	72.7	0.002
106477	2N2	275.9	0.05
106477	OO1	273.7	0.006
106477	M1	201.6	0.019
106477	J1	259.8	0.014
106477	Q1	177.4	0.024
106477	2Q1	1.7	0.021
106477	P1	234.8	0.009
106477	2SM2	221.5	0.006
106477	M3	323.3	0.01
106477	L2	314.5	0.045
106477	2MK3	52.1	0.027
106477	K2	20.1	0.062
106477	M8	51.7	0.028
106477	MS4	355.6	0.047
106478	M2	19.5	1.63
106478	S2	58.7	0.225
106478	N2	5.7	0.318
106478	K1	153.1	0.171
106478	M4	278.1	0.252
106478	O1	119.6	0.135
106478	M6	168.6	0.028
106478	MK3	102.1	0.063
106478	S4	339	0.005
106478	MN4	286	0.082
106478	S6	194.1	0.005
106478	2N2	276.6	0.032
106478	OO1	306	0.009
106478	M1	230.8	0.022
106478	J1	290.9	0.006
106478	Q1	194.4	0.036
106478	2Q1	15.5	0.037
106478	P1	187.5	0.016
106478	2SM2	354.1	0.007
106478	M3	314.2	0.016
106478	L2	293.4	0.037
106478	2MK3	51.6	0.058
106478	K2	32.5	0.089
106478	M8	149.9	0.005
106478	MS4	346.4	0.075
106479	M2	21.8	1.814
106479	S2	43.4	0.229
106479	N2	1	0.289
106479	K1	159.5	0.192
106479	M4	294.4	0.22
106479	O1	134.4	0.155
106479	M6	197.9	0.027
106479	MK3	86	0.053
106479	S4	306.3	0.02
106479	MN4	257.6	0.068
106479	S6	93.1	0.003
106479	2N2	321.2	0.061
106479	OO1	5.8	0.02
106479	M1	259.9	0.02
106479	J1	14.7	0.017
106479	Q1	256.1	0.016
106479	2Q1	52.8	0.032
106479	P1	121.8	0.032
106479	2SM2	332.9	0.014
106479	M3	97.2	0.028
106479	L2	12.2	0.048
106479	2MK3	68.9	0.053
106479	K2	33.1	0.11
106479	M8	318.6	0.011
106479	MS4	321.8	0.051
106480	M2	31.8	1.798
106480	S2	49.8	0.285
106480	N2	31.4	0.358
106480	K1	165	0.204
106480	M4	325.1	0.18
106480	O1	137.2	0.124
106480	M6	299	0.015
106480	MK3	72.6	0.028
106480	S4	278.4	0.009
106480	MN4	311.2	0.086
106480	S6	50.6	0.003
106480	2N2	287.1	0.06
106480	OO1	4.6	0.011
106480	M1	224.5	0.029
106480	J1	280.5	0.023
106480	Q1	156.9	0.03
106480	2Q1	290.2	0.024
106480	P1	165.8	0.043
106480	2SM2	237.4	0.035
106480	M3	12.9	0.011
106480	L2	347.1	0.151
106480	2MK3	84.2	0.048
106480	M8	355.7	0.008
106480	MS4	343.4	0.062
106481	M2	38.2	1.814
106481	S2	46.9	0.33
106481	N2	34.7	0.349
106481	K1	182	0.236
106481	M4	336.4	0.168
106481	O1	142.3	0.148
106481	M6	141.2	0.049
106481	MK3	115.6	0.033
106481	S4	316.8	0.022
106481	MN4	318.5	0.051
106481	S6	312.3	0.009
106481	2N2	295.4	0.051
106481	OO1	45.9	0.031
106481	M1	267	0.039
106481	J1	298.8	0.023
106481	Q1	206.3	0.028
106481	2Q1	332.3	0.026
106481	P1	195.3	0.092
106481	2SM2	297.5	0.028
106481	M3	164.5	0.01
106481	L2	11.4	0.143
106481	2MK3	79.9	0.045
106481	M8	146.8	0.006
106481	MS4	24.3	0.045
106482	M2	43.9	1.889
106482	S2	51.9	0.348
106482	N2	33.2	0.371
106482	K1	182.3	0.251
106482	M4	346.7	0.162
106482	O1	149.8	0.16
106482	M6	171.8	0.023
106482	MK3	118.1	0.036
106482	S4	8.4	0.014
106482	MN4	322.8	0.058
106482	S6	322	0.012
106482	2N2	308.3	0.046
106482	OO1	68.4	0.029
106482	M1	290.2	0.029
106482	J1	156.7	0.009
106482	Q1	194.7	0.032
106482	2Q1	329.3	0.034
106482	P1	171.4	0.075
106482	2SM2	308	0.047
106482	M3	18.9	0.004
106482	L2	16.6	0.155
106482	2MK3	92.4	0.033
106482	M8	155.4	0.034
106482	MS4	14.1	0.041
106483	M2	40.3	1.349
106483	S2	73.4	0.158
106483	N2	32.2	0.22
106483	K1	173.9	0.161
106483	M4	5.9	0.095
106483	O1	146.3	0.105
106483	M6	291.6	0.066
106483	MK3	156.9	0.043
106483	S4	298.7	0.008
106483	MN4	54.2	0.038
106483	S6	316.3	0.005
106483	2N2	348.2	0.047
106483	OO1	276.3	0.008
106483	M1	258.3	0.023
106483	J1	321.4	0.023
106483	Q1	193.7	0.017
106483	2Q1	31.5	0.023
106483	P1	223.1	0.038
106483	2SM2	35.6	0.018
106483	M3	62.4	0.021
106483	L2	356.3	0.081
106483	2MK3	99.7	0.053
106483	K2	71.1	0.08
106483	M8	266.7	0.02
106483	MS4	100	0.023
106484	M2	52.5	1.926
106484	S2	60.4	0.189
106484	N2	16.9	0.237
106484	K1	183.1	0.188
106484	M4	37.5	0.132
106484	O1	154.8	0.156
106484	M6	38.8	0.003
106484	MK3	189.1	0.066
106484	S4	285	0.009
106484	MN4	51.8	0.044
106484	S6	180.5	0.009
106484	2N2	23.1	0.089
106484	OO1	292.9	0.006
106484	M1	297.4	0.012
106484	J1	3.5	0.021
106484	Q1	185.4	0.012
106484	2Q1	77.9	0.016
106484	P1	101.9	0.036
106484	2SM2	32.5	0.049
106484	M3	154	0.01
106484	L2	60.9	0.093
106484	2MK3	143.1	0.071
106484	K2	61.9	0.117
106484	M8	170.8	0.008
106484	MS4	116.9	0.024
106485	M2	58.6	2.112
106485	S2	63.8	0.22
106485	N2	20.3	0.247
106485	K1	190.2	0.22
106485	M4	80.3	0.083
106485	O1	172.3	0.192
106485	M6	228.4	0.064
106485	MK3	232	0.07
106485	S4	79.1	0.006
106485	MN4	113.6	0.032
106485	S6	189.5	0.012
106485	2N2	26.4	0.082
106485	OO1	351.5	0.02
106485	M1	334.5	0.038
106485	J1	35	0.039
106485	Q1	272	0.015
106485	2Q1	110	0.028
106485	P1	80.8	0.046
106485	2SM2	51	0.05
106485	M3	249.9	0.014
106485	L2	77.9	0.109
106485	2MK3	177.3	0.065
106485	K2	67.6	0.13
106485	M8	150.1	0.029
106485	MS4	203.8	0.01
106486	M2	60	1.846
106486	S2	103.7	0.261
106486	N2	36.5	0.358
106486	K1	189.3	0.197
106486	M4	72.9	0.099
106486	O1	177.3	0.118
106486	M6	18.1	0.154
106486	S4	235.3	0.011
106486	NU2	39.7	0.069
106486	S6	310.4	0.012
106486	2N2	13.1	0.048
106486	OO1	201.2	0.005
106486	LDA2	80.2	0.013
106486	M1	183.3	0.008
106486	J1	195.3	0.009
106486	RHO1	172.2	0.004
106486	Q1	171.3	0.023
106486	T2	103.6	0.015
106486	R2	103.7	0.002
106486	2Q1	165.3	0.003
106486	P1	189.2	0.065
106486	L2	83.4	0.052
106486	K2	103.7	0.071
106486	M8	293.9	0.016
106487	M2	57.8	1.173
106487	S2	106.1	0.195
106487	N2	31.8	0.228
106487	K1	170	0.089
106487	M4	35	0.118
106487	O1	157.9	0.041
106487	M6	9.4	0.125
106487	S4	259.9	0.013
106487	NU2	35.3	0.044
106487	S6	37.8	0.012
106487	2N2	6	0.03
106487	OO1	182	0.002
106487	LDA2	80.2	0.008
106487	M1	163.9	0.003
106487	J1	176	0.003
106487	RHO1	152.7	0.002
106487	Q1	151.8	0.008
106487	T2	106	0.012
106487	R2	106.1	0.002
106487	2Q1	145.8	0.001
106487	P1	169.9	0.03
106487	L2	83.7	0.033
106487	K2	106.1	0.053
106487	M8	45.8	0.033
106488	M2	74.3	1.307
106488	S2	94.6	0.223
106488	N2	75.7	0.235
106488	K1	201.5	0.125
106488	M4	59.6	0.18
106488	O1	167.3	0.081
106488	M6	24.1	0.067
106488	MK3	155.4	0.042
106488	MN4	62.3	0.07
106488	S6	89	0.002
106488	2N2	320.9	0.024
106488	OO1	45.7	0.014
106488	M1	272.9	0.021
106488	J1	332.2	0.016
106488	Q1	195.4	0.025
106488	2Q1	325.8	0.028
106488	P1	224.3	0.042
106488	2SM2	283.8	0.033
106488	M3	56.3	0.007
106488	L2	40.7	0.119
106488	2MK3	149.2	0.046
106488	M8	355.8	0.02
106488	MS4	89.2	0.051
106489	M2	73.8	1.963
106489	S2	87.5	0.258
106489	N2	84.4	0.312
106489	K1	197.5	0.192
106489	M4	60.3	0.194
106489	O1	165.3	0.131
106489	M6	58.6	0.117
106489	MK3	163.8	0.048
106489	S4	46.2	0.012
106489	MN4	66.9	0.087
106489	S6	49.1	0.005
106489	2N2	331	0.087
106489	OO1	65.7	0.017
106489	M1	304.1	0.029
106489	J1	78.5	0.008
106489	Q1	219.2	0.026
106489	2Q1	348.6	0.039
106489	P1	205.9	0.051
106489	2SM2	283.1	0.021
106489	M3	35.4	0.01
106489	L2	52.4	0.165
106489	2MK3	151.5	0.064
106489	M8	26.7	0.041
106489	MS4	113.1	0.057
106490	M2	72.8	1.98
106490	S2	85.6	0.242
106490	N2	85.8	0.283
106490	K1	196.4	0.201
106490	M4	99.1	0.278
106490	O1	162.5	0.143
106490	M6	37.3	0.164
106490	MK3	182.2	0.06
106490	S4	128.2	0.005
106490	MN4	96.8	0.11
106490	S6	108.5	0.005
106490	2N2	321	0.105
106490	OO1	85.9	0.025
106490	M1	331.1	0.027
106490	J1	111.1	0.016
106490	Q1	235.8	0.018
106490	2Q1	347.3	0.037
106490	P1	200.6	0.04
106490	2SM2	284.5	0.031
106490	M3	23.1	0.019
106490	L2	54.9	0.179
106490	2MK3	161.3	0.075
106490	M8	72.1	0.032
106490	MS4	118.1	0.089
106491	M2	62.4	1.809
106491	S2	118.9	0.31
106491	N2	73.6	0.132
106491	K1	201	0.136
106491	M4	119.9	0.267
106491	O1	160.1	0.078
106491	M6	67.7	0.241
106491	MK3	190.8	0.091
106491	S4	126.5	0.009
106491	MN4	102.1	0.159
106491	S6	244.5	0.013
106491	2N2	129.2	0.042
106491	OO1	181.6	0.035
106491	M1	274.1	0.026
106491	J1	214.7	0.007
106491	Q1	242.1	0.031
106491	2Q1	196.1	0.02
106491	2SM2	130.8	0.037
106491	M3	181.5	0.04
106491	L2	104.9	0.208
106491	2MK3	150.8	0.108
106491	K2	140.6	0.174
106491	M8	33.9	0.11
106491	MS4	125.2	0.073
106492	M2	63.1	1.705
106492	S2	112.2	0.237
106492	N2	65.8	0.124
106492	K1	204.6	0.143
106492	M4	129.2	0.224
106492	O1	166.4	0.082
106492	M6	61.4	0.242
106492	MK3	187.3	0.077
106492	S4	154.7	0.01
106492	MN4	105.6	0.132
106492	S6	249.9	0.013
106492	2N2	99.2	0.037
106492	OO1	187.7	0.033
106492	M1	281.2	0.028
106492	J1	238.9	0.007
106492	Q1	244.8	0.033
106492	2Q1	199.4	0.019
106492	2SM2	122.5	0.035
106492	M3	183	0.038
106492	L2	100.4	0.18
106492	2MK3	150.2	0.09
106492	K2	126	0.158
106492	M8	36.2	0.106
106492	MS4	131.5	0.065
106493	M2	64.2	1.609
106493	S2	136.8	0.203
106493	N2	56.4	0.109
106493	K1	208.1	0.153
106493	M4	141.9	0.163
106493	O1	171.6	0.081
106493	M6	56.9	0.218
106493	MK3	190.7	0.066
106493	S4	146.9	0.013
106493	MN4	110.2	0.107
106493	S6	244.1	0.007
106493	2N2	89.9	0.035
106493	OO1	191.2	0.032
106493	M1	290.3	0.042
106493	J1	339.9	0.008
106493	Q1	261.7	0.038
106493	2Q1	211.9	0.023
106493	2SM2	122.4	0.029
106493	M3	185.8	0.026
106493	L2	102.3	0.183
106493	2MK3	153.2	0.076
106493	K2	139.3	0.075
106493	M8	34.4	0.098
106493	MS4	130.6	0.067
106494	M2	65.7	1.436
106494	S2	140.6	0.367
106494	N2	72.8	0.075
106494	K1	202.2	0.155
106494	M4	185	0.083
106494	O1	175.2	0.096
106494	M6	36.2	0.172
106494	MK3	227.4	0.05
106494	S4	107.1	0.01
106494	MN4	95.1	0.062
106494	S6	276.6	0.012
106494	2N2	146.3	0.047
106494	OO1	210.8	0.026
106494	M1	298.3	0.034
106494	J1	297.2	0.008
106494	Q1	245.9	0.028
106494	2Q1	169.7	0.024
106494	2SM2	117.4	0.037
106494	M3	190.6	0.039
106494	L2	89.7	0.195
106494	2MK3	158.7	0.046
106494	K2	192.5	0.168
106494	M8	31.5	0.082
106494	MS4	138.5	0.045
106495	M2	57.5	1.722
106495	S2	83.4	0.239
106495	N2	68.4	0.312
106495	K1	189.1	0.141
106495	M4	111.1	0.078
106495	O1	158.9	0.106
106495	M6	2.8	0.197
106495	MK3	106	0.038
106495	S4	333.4	0.012
106495	MN4	92.5	0.022
106495	S6	144.9	0.013
106495	2N2	286.4	0.08
106495	OO1	78.9	0.014
106495	M1	284.7	0.027
106495	J1	127.1	0.01
106495	Q1	213.1	0.031
106495	2Q1	330.2	0.025
106495	P1	218.4	0.025
106495	2SM2	219.1	0.045
106495	M3	39.6	0.013
106495	L2	8.5	0.123
106495	2MK3	87.5	0.06
106495	M8	31.9	0.022
106495	MS4	122.5	0.033
106496	M2	57.8	1.947
106496	S2	84.6	0.272
106496	N2	69	0.36
106496	K1	189.1	0.165
106496	M4	111	0.076
106496	O1	158.8	0.126
106496	M6	2.9	0.223
106496	MK3	101.7	0.043
106496	S4	347.1	0.012
106496	MN4	83.3	0.026
106496	S6	150.7	0.013
106496	2N2	288.7	0.089
106496	OO1	82.7	0.015
106496	M1	281.1	0.03
106496	J1	140.3	0.009
106496	Q1	212.3	0.034
106496	2Q1	324.5	0.03
106496	P1	220.8	0.03
106496	2SM2	222	0.047
106496	M3	39	0.014
106496	L2	7.4	0.139
106496	2MK3	86.5	0.067
106496	M8	33.1	0.023
106496	MS4	124	0.034
106497	M2	58	2.042
106497	S2	83.5	0.28
106497	N2	69.6	0.381
106497	K1	185.3	0.172
106497	M4	119	0.038
106497	O1	155	0.133
106497	M6	2.5	0.239
106497	MK3	95.5	0.054
106497	S4	304.9	0.008
106497	MN4	68.1	0.019
106497	S6	157.5	0.014
106497	2N2	287.2	0.096
106497	OO1	89	0.016
106497	M1	284.1	0.03
106497	J1	176.7	0.009
106497	Q1	216.2	0.033
106497	2Q1	320.3	0.034
106497	P1	224.5	0.029
106497	2SM2	224.5	0.062
106497	M3	30.9	0.011
106497	L2	3.9	0.145
106497	2MK3	80.6	0.073
106497	M8	0.1	0.007
106497	MS4	107	0.024
106498	M2	77	1.669
106498	S2	84.4	0.155
106498	N2	78.3	0.285
106498	K1	189.1	0.148
106498	M4	57.5	0.158
106498	O1	154.4	0.091
106498	M6	58.9	0.086
106498	MK3	157.8	0.038
106498	S4	23.2	0.006
106498	MN4	71	0.086
106498	S6	84.8	0.004
106498	2N2	336.9	0.066
106498	OO1	60	0.016
106498	M1	284	0.027
106498	J1	6.2	0.009
106498	Q1	206.5	0.021
106498	2Q1	319.4	0.024
106498	P1	178.6	0.035
106498	2SM2	323.3	0.014
106498	M3	96.2	0.016
106498	L2	46.5	0.142
106498	2MK3	152.7	0.051
106498	K2	147.6	0.12
106498	M8	47	0.018
106498	MS4	104.4	0.061
106499	M2	77.3	2.209
106499	S2	77	0.189
106499	N2	81.9	0.366
106499	K1	188.9	0.182
106499	M4	79.6	0.172
106499	O1	155.4	0.122
106499	M6	91.9	0.119
106499	MK3	172.4	0.044
106499	S4	36	0.011
106499	MN4	79.1	0.095
106499	S6	32	0.005
106499	2N2	331.1	0.115
106499	OO1	67.5	0.019
106499	M1	289.8	0.034
106499	J1	37.5	0.011
106499	Q1	213.5	0.026
106499	2Q1	336.6	0.027
106499	P1	183.8	0.037
106499	2SM2	280.5	0.008
106499	M3	111.4	0.016
106499	L2	56.3	0.177
106499	2MK3	155.1	0.068
106499	K2	148.5	0.151
106499	M8	16.5	0.022
106499	MS4	127.6	0.069
106500	M2	76.9	2.281
106500	S2	71.3	0.19
106500	N2	81	0.376
106500	K1	187.9	0.19
106500	M4	88.5	0.154
106500	O1	155.6	0.131
106500	M6	100.3	0.118
106500	MK3	184.9	0.042
106500	S4	39.9	0.011
106500	MN4	76.3	0.08
106500	S6	32.1	0.007
106500	2N2	334	0.118
106500	OO1	69.9	0.02
106500	M1	291.7	0.034
106500	J1	52	0.007
106500	Q1	216.5	0.028
106500	2Q1	340	0.025
106500	P1	177.4	0.041
106500	2SM2	268.7	0.014
106500	M3	113.5	0.015
106500	L2	55.4	0.181
106500	2MK3	160.5	0.069
106500	K2	149.1	0.164
106500	M8	8.7	0.02
106500	MS4	131.2	0.072
106501	M2	90	2.026
106501	S2	124.7	0.196
106501	N2	78	0.239
106501	K1	200.8	0.186
106501	M4	122.4	0.163
106501	O1	171.4	0.143
106501	M6	146.7	0.096
106501	MK3	253.3	0.057
106501	S4	105.4	0.012
106501	MN4	117.8	0.053
106501	S6	114.2	0.004
106501	2N2	35.3	0.104
106501	OO1	34.8	0.006
106501	M1	314.2	0.024
106501	J1	42	0.02
106501	Q1	240.7	0.021
106501	2Q1	102.1	0.04
106501	P1	113.1	0.024
106501	2SM2	65.6	0.038
106501	M3	243.1	0.008
106501	L2	78.3	0.114
106501	2MK3	183.7	0.073
106501	K2	110.2	0.097
106501	M8	114.7	0.025
106501	MS4	193.2	0.056
106502	M2	91.3	1.9
106502	S2	129.3	0.191
106502	N2	76	0.222
106502	K1	201.1	0.168
106502	M4	125.7	0.149
106502	O1	178	0.131
106502	M6	118.7	0.093
106502	MK3	249.9	0.066
106502	S4	64.8	0.012
106502	MN4	114.8	0.057
106502	2N2	37.7	0.103
106502	OO1	43	0.01
106502	M1	324.2	0.022
106502	J1	40.7	0.017
106502	Q1	260.3	0.021
106502	2Q1	95.3	0.032
106502	P1	99.6	0.013
106502	2SM2	76.6	0.033
106502	M3	231.2	0.01
106502	L2	78.8	0.117
106502	2MK3	181.7	0.073
106502	K2	115.9	0.077
106502	M8	104.7	0.024
106502	MS4	192.5	0.046
106503	M2	90.5	1.496
106503	S2	136	0.154
106503	N2	69.8	0.183
106503	K1	196.6	0.12
106503	M4	122.7	0.163
106503	O1	173.5	0.11
106503	M6	74.7	0.058
106503	MK3	252.5	0.046
106503	S4	97.7	0.005
106503	MN4	111.1	0.044
106503	S6	315.4	0.004
106503	2N2	47.2	0.078
106503	OO1	27.3	0.006
106503	M1	335.8	0.013
106503	J1	56.5	0.021
106503	Q1	263.5	0.01
106503	2Q1	103.1	0.023
106503	P1	95.3	0.04
106503	2SM2	105	0.015
106503	M3	219.1	0.008
106503	L2	75.5	0.1
106503	2MK3	192.7	0.061
106503	K2	117.3	0.051
106503	M8	156.5	0.017
106503	MS4	192	0.042
106504	M2	86.2	1.741
106504	S2	119.8	0.182
106504	N2	71.6	0.279
106504	K1	191.6	0.147
106504	M4	161.8	0.142
106504	O1	176.6	0.112
106504	M6	103.7	0.112
106504	MK3	241.3	0.042
106504	S4	66.1	0.008
106504	MN4	142.2	0.046
106504	NU2	57.3	0.093
106504	S6	114.3	0.005
106504	MU2	211.7	0.061
106504	2N2	13	0.058
106504	OO1	56.6	0.008
106504	LDA2	61.9	0.047
106504	M1	303.8	0.022
106504	J1	64.9	0.011
106504	RHO1	210.8	0.009
106504	Q1	219.1	0.02
106504	2Q1	81.4	0.013
106504	P1	143.3	0.024
106504	2SM2	57.1	0.011
106504	M3	177	0.012
106504	L2	67.5	0.146
106504	2MK3	192.1	0.058
106504	K2	127.6	0.078
106504	M8	64	0.02
106504	MS4	192.1	0.053
106505	M2	86.2	2.287
106505	S2	117.5	0.241
106505	N2	71.2	0.366
106505	K1	191.5	0.2
106505	M4	166.8	0.241
106505	O1	173.4	0.148
106505	M6	110	0.132
106505	MK3	249.2	0.076
106505	S4	46.1	0.008
106505	MN4	151.4	0.085
106505	NU2	58.5	0.119
106505	S6	96.1	0.004
106505	MU2	210	0.079
106505	2N2	17.7	0.067
106505	OO1	63.2	0.016
106505	LDA2	38.8	0.038
106505	M1	295.1	0.026
106505	J1	64.3	0.015
106505	RHO1	185.3	0.01
106505	Q1	214	0.025
106505	2Q1	72.5	0.018
106505	P1	146	0.035
106505	2SM2	53.1	0.018
106505	M3	176.5	0.011
106505	L2	65.9	0.173
106505	2MK3	197.6	0.085
106505	K2	126.2	0.102
106505	M8	98.9	0.017
106505	MS4	203.4	0.078
106506	M2	86	2.316
106506	S2	116.1	0.246
106506	N2	70.8	0.37
106506	K1	190.8	0.204
106506	M4	167.1	0.261
106506	O1	172.6	0.152
106506	M6	105.2	0.122
106506	MK3	250.9	0.083
106506	S4	33.6	0.008
106506	MN4	151.3	0.096
106506	NU2	58.6	0.117
106506	S6	85.2	0.003
106506	MU2	211.9	0.079
106506	2N2	16	0.064
106506	OO1	63.4	0.017
106506	LDA2	22.2	0.037
106506	M1	292.2	0.025
106506	J1	64.4	0.015
106506	RHO1	183.5	0.008
106506	Q1	213.3	0.025
106506	2Q1	72.2	0.018
106506	P1	144.4	0.038
106506	2SM2	56.1	0.02
106506	M3	179.2	0.013
106506	L2	64.7	0.174
106506	2MK3	199.8	0.088
106506	K2	127.7	0.104
106506	M8	110.7	0.018
106506	MS4	203.7	0.082
106507	M2	97.6	1.768
106507	S2	82.1	0.197
106507	N2	99.4	0.27
106507	K1	190.5	0.124
106507	M4	174.3	0.135
106507	O1	167.3	0.102
106507	M6	141	0.102
106507	MK3	248.1	0.043
106507	S4	54.8	0.01
106507	MN4	152.3	0.047
106507	2N2	350.7	0.105
106507	OO1	65.2	0.021
106507	M1	318.2	0.026
106507	J1	117.5	0.008
106507	Q1	220.6	0.016
106507	2Q1	349	0.022
106507	2SM2	352.5	0.013
106507	M3	205.5	0.02
106507	L2	79.2	0.152
106507	2MK3	212.1	0.057
106507	K2	195.9	0.147
106507	M8	137.2	0.017
106507	MS4	192.6	0.052
106508	M2	97.9	1.743
106508	S2	85.5	0.189
106508	N2	99.8	0.273
106508	K1	197.6	0.131
106508	M4	168.2	0.124
106508	O1	166.6	0.101
106508	M6	137.1	0.104
106508	MK3	241.4	0.037
106508	S4	57.1	0.013
106508	MN4	146.7	0.04
106508	S6	279.6	0.003
106508	2N2	349.9	0.103
106508	OO1	68.2	0.02
106508	M1	321.8	0.026
106508	J1	102	0.004
106508	Q1	224.1	0.016
106508	2Q1	350.8	0.024
106508	P1	202.9	0.014
106508	2SM2	1.4	0.014
106508	M3	220.8	0.02
106508	L2	75.7	0.149
106508	2MK3	205.1	0.055
106508	K2	195.1	0.132
106508	M8	135.1	0.017
106508	MS4	186.5	0.045
106509	M2	97.6	1.451
106509	S2	105.3	0.139
106509	N2	103.1	0.24
106509	K1	203.7	0.117
106509	M4	146.6	0.105
106509	O1	169	0.088
106509	M6	123.9	0.071
106509	MK3	225.1	0.032
106509	S4	36.6	0.006
106509	MN4	129.9	0.039
106509	2N2	350.6	0.075
106509	OO1	67.3	0.018
106509	M1	314	0.022
106509	J1	164.6	0.005
106509	Q1	245.6	0.018
106509	2Q1	343.6	0.024
106509	P1	229.2	0.02
106509	2SM2	342.7	0.006
106509	M3	205.4	0.012
106509	L2	72.2	0.122
106509	2MK3	204.1	0.041
106509	K2	173.3	0.075
106509	M8	125.9	0.011
106509	MS4	170.4	0.044
106510	M2	96.7	1.43
106510	S2	132.1	0.142
106510	N2	84.9	0.222
106510	K1	198.4	0.114
106510	M4	145.3	0.144
106510	O1	175.1	0.091
106510	M6	138.7	0.128
106510	MK3	233.8	0.038
106510	S4	86.7	0.008
106510	MN4	142.7	0.044
106510	NU2	73.9	0.067
106510	S6	187.7	0.002
106510	MU2	222.1	0.063
106510	2N2	30.4	0.037
106510	OO1	63.3	0.013
106510	LDA2	76.1	0.037
106510	M1	300.6	0.019
106510	J1	60.3	0.01
106510	RHO1	188.6	0.006
106510	Q1	221.6	0.014
106510	2Q1	80.4	0.013
106510	P1	164	0.02
106510	2SM2	52.4	0.016
106510	M3	182.4	0.01
106510	L2	78.5	0.122
106510	2MK3	190.7	0.057
106510	K2	133.3	0.062
106510	M8	197.3	0.026
106510	MS4	193.9	0.046
106511	M2	97.4	1.667
106511	S2	134.4	0.167
106511	N2	85.3	0.26
106511	K1	198.1	0.131
106511	M4	148.7	0.161
106511	O1	175.3	0.104
106511	M6	137.7	0.157
106511	MK3	235.5	0.044
106511	S4	85.7	0.009
106511	MN4	144.3	0.048
106511	NU2	73.7	0.077
106511	MU2	223.2	0.072
106511	2N2	28.2	0.044
106511	OO1	65.4	0.015
106511	LDA2	74	0.045
106511	M1	300.6	0.022
106511	J1	65.9	0.011
106511	RHO1	186.7	0.007
106511	Q1	222	0.016
106511	2Q1	79.1	0.015
106511	P1	163.2	0.022
106511	2SM2	57.1	0.018
106511	M3	185.8	0.011
106511	L2	78.6	0.143
106511	2MK3	191.1	0.067
106511	K2	130.4	0.072
106511	M8	201.3	0.034
106511	MS4	198.7	0.052
106512	M2	98.3	1.885
106512	S2	136.2	0.191
106512	N2	85.7	0.295
106512	K1	197.5	0.148
106512	M4	149.6	0.177
106512	O1	174	0.115
106512	M6	140.2	0.176
106512	MK3	242.1	0.051
106512	S4	83.8	0.011
106512	MN4	145.8	0.053
106512	NU2	75	0.088
106512	MU2	223.9	0.08
106512	2N2	26.8	0.049
106512	OO1	65.5	0.017
106512	LDA2	73	0.055
106512	M1	301.3	0.024
106512	J1	68.2	0.012
106512	RHO1	197.4	0.009
106512	Q1	218.7	0.019
106512	2Q1	79.6	0.016
106512	P1	161	0.024
106512	2SM2	60.5	0.02
106512	M3	181.3	0.012
106512	L2	80.1	0.162
106512	2MK3	193.1	0.076
106512	K2	129.3	0.08
106512	M8	203.6	0.036
106512	MS4	203.9	0.058
106513	M2	102	1.162
106513	S2	133.5	0.227
106513	N2	88.8	0.136
106513	K1	238.2	0.078
106513	M4	189.6	0.144
106513	O1	195.2	0.078
106513	M6	149.3	0.123
106513	MK3	286	0.049
106513	S4	98.4	0.011
106513	MN4	159.7	0.035
106513	S6	149.9	0.004
106513	2N2	50.5	0.085
106513	OO1	30.3	0.014
106513	M1	298	0.015
106513	J1	62.6	0.014
106513	Q1	253.3	0.013
106513	2Q1	106.3	0.024
106513	P1	34.9	0.048
106513	2SM2	84.2	0.033
106513	M3	246.6	0.013
106513	L2	103.9	0.068
106513	2MK3	215.3	0.063
106513	K2	193.6	0.12
106513	M8	221.1	0.014
106513	MS4	242	0.046
106514	M2	102.9	1.585
106514	S2	133	0.304
106514	N2	91.7	0.186
106514	K1	232.6	0.108
106514	M4	196.7	0.156
106514	O1	190.9	0.104
106514	M6	155.8	0.202
106514	MK3	282.3	0.064
106514	S4	76.2	0.01
106514	MN4	166.3	0.034
106514	S6	152.5	0.007
106514	2N2	52.3	0.123
106514	OO1	32.6	0.016
106514	M1	301.1	0.018
106514	J1	65.3	0.016
106514	Q1	254.2	0.017
106514	2Q1	107.9	0.034
106514	P1	46.5	0.06
106514	2SM2	83.9	0.037
106514	M3	244	0.019
106514	L2	103.3	0.095
106514	2MK3	211.2	0.083
106514	K2	192	0.157
106514	M8	238.3	0.008
106514	MS4	243.5	0.058
106515	M2	101.8	1.657
106515	S2	132.3	0.321
106515	N2	91.6	0.196
106515	K1	223.1	0.125
106515	M4	212	0.126
106515	O1	183.5	0.114
106515	M6	160	0.191
106515	MK3	273	0.071
106515	S4	160.5	0.003
106515	MN4	180	0.027
106515	S6	192.5	0.008
106515	2N2	53.6	0.14
106515	OO1	33.5	0.014
106515	M1	303.2	0.022
106515	J1	69.8	0.018
106515	Q1	237	0.02
106515	2Q1	111.4	0.038
106515	P1	61.2	0.053
106515	2SM2	102.3	0.026
106515	M3	232.3	0.017
106515	L2	100	0.103
106515	2MK3	204.8	0.084
106515	K2	190.6	0.152
106515	M8	289.3	0.022
106515	MS4	244.7	0.048
106516	M2	111.8	1.05
106516	S2	127.2	0.09
106516	N2	117.7	0.176
106516	K1	201	0.082
106516	M4	206.6	0.128
106516	O1	181.7	0.058
106516	M6	174.8	0.093
106516	MK3	245.1	0.027
106516	S4	107.3	0.003
106516	MN4	208.8	0.034
106516	S6	305.3	0.001
106516	2N2	352.4	0.045
106516	OO1	77.4	0.007
106516	M1	316.2	0.014
106516	J1	158.3	0.005
106516	Q1	235.9	0.013
106516	2Q1	342.9	0.012
106516	P1	147.4	0.011
106516	2SM2	343.7	0.01
106516	M3	199.6	0.009
106516	L2	77.3	0.086
106516	2MK3	214.4	0.039
106516	K2	176.4	0.063
106516	M8	232.2	0.022
106516	MS4	222.3	0.032
106517	M2	114.8	1.646
106517	S2	134.4	0.127
106517	N2	119.8	0.271
106517	K1	201.4	0.128
106517	M4	208	0.215
106517	O1	182.6	0.088
106517	M6	191.6	0.156
106517	MK3	253.2	0.049
106517	S4	111.1	0.009
106517	MN4	204.8	0.051
106517	S6	347.1	0.003
106517	2N2	356.5	0.076
106517	OO1	71.9	0.013
106517	M1	317.2	0.023
106517	J1	131.8	0.008
106517	Q1	244.1	0.02
106517	2Q1	349	0.017
106517	P1	143.8	0.013
106517	2SM2	341.7	0.016
106517	M3	211.6	0.017
106517	L2	81.9	0.139
106517	2MK3	215.8	0.067
106517	K2	176.3	0.099
106517	M8	248.7	0.031
106517	MS4	228	0.05
106518	M2	115.2	1.718
106518	S2	135.7	0.134
106518	N2	120.3	0.283
106518	K1	200.9	0.132
106518	M4	207.7	0.227
106518	O1	182.3	0.089
106518	M6	195	0.163
106518	MK3	254.2	0.053
106518	S4	107.4	0.01
106518	MN4	204.8	0.054
106518	S6	345.9	0.003
106518	2N2	357.3	0.08
106518	OO1	70.8	0.013
106518	M1	315	0.024
106518	J1	128	0.009
106518	Q1	246.6	0.021
106518	2Q1	351.4	0.017
106518	P1	145.5	0.013
106518	2SM2	345.8	0.016
106518	M3	214.8	0.019
106518	L2	82.2	0.145
106518	2MK3	216.3	0.072
106518	K2	176.6	0.101
106518	M8	251.7	0.03
106518	MS4	229.6	0.053
106519	M2	110.9	2.311
106519	S2	135.2	0.256
106519	N2	127.1	0.425
106519	K1	200.2	0.205
106519	M4	267.6	0.095
106519	O1	180.1	0.155
106519	M6	155.7	0.255
106519	MK3	153.5	0.034
106519	MN4	225.7	0.041
106519	S6	335.9	0.005
106519	2N2	6.4	0.146
106519	OO1	75.2	0.028
106519	M1	327.3	0.046
106519	J1	169.5	0.029
106519	Q1	238.5	0.058
106519	2Q1	7.5	0.016
106519	2SM2	301.4	0.026
106519	M3	111.6	0.021
106519	L2	74.7	0.165
106519	2MK3	173.6	0.075
106519	M8	290.9	0.053
106519	MS4	278.6	0.054
106520	M2	108.5	1.367
106520	S2	135.3	0.115
106520	N2	114.7	0.228
106520	K1	200.8	0.095
106520	M4	202.5	0.218
106520	O1	173.1	0.073
106520	M6	164.4	0.14
106520	MK3	250.9	0.046
106520	S4	87.8	0.009
106520	MN4	215.8	0.064
106520	S6	333.9	0.007
106520	2N2	349.6	0.077
106520	OO1	57	0.01
106520	M1	311.1	0.018
106520	J1	90.2	0.007
106520	Q1	222.4	0.017
106520	2Q1	347.6	0.017
106520	P1	219.9	0.015
106520	2SM2	323.3	0.008
106520	M3	186.5	0.013
106520	L2	77.2	0.112
106520	2MK3	217.7	0.06
106520	K2	166.3	0.069
106520	M8	256.2	0.053
106520	MS4	229.9	0.052
106521	M2	109.8	1.824
106521	S2	134.6	0.17
106521	N2	113.8	0.306
106521	K1	201	0.125
106521	M4	197.2	0.258
106521	O1	171.4	0.098
106521	M6	171.1	0.177
106521	MK3	245.2	0.055
106521	S4	110.9	0.011
106521	MN4	208.3	0.064
106521	S6	321.1	0.008
106521	2N2	352.1	0.096
106521	OO1	61.8	0.015
106521	M1	304.3	0.025
106521	J1	121.8	0.006
106521	Q1	235.7	0.024
106521	2Q1	345.1	0.018
106521	P1	222.5	0.028
106521	2SM2	339.8	0.011
106521	M3	205.7	0.019
106521	L2	77.2	0.159
106521	2MK3	215	0.076
106521	K2	172.6	0.087
106521	M8	259.3	0.075
106521	MS4	224.2	0.067
106522	M2	110.1	1.849
106522	S2	133.7	0.164
106522	N2	114.2	0.308
106522	K1	200.7	0.124
106522	M4	191.8	0.264
106522	O1	169.1	0.099
106522	M6	172.6	0.18
106522	MK3	238.6	0.058
106522	S4	109.8	0.012
106522	MN4	198.2	0.064
106522	S6	317.3	0.007
106522	2N2	351.8	0.095
106522	OO1	64.2	0.016
106522	M1	300.5	0.026
106522	J1	150.3	0.006
106522	Q1	242.1	0.026
106522	2Q1	342.2	0.018
106522	P1	217.4	0.03
106522	2SM2	340.8	0.013
106522	M3	206.6	0.022
106522	L2	77.4	0.164
106522	2MK3	212.7	0.077
106522	K2	173.5	0.098
106522	M8	258.6	0.081
106522	MS4	220.3	0.07
106523	M2	85.3	0.147
106523	N2	117.2	0.04
106523	K1	213.6	0.014
106523	O1	190.7	0.022
106523	M6	104.4	0.035
106523	MK3	169.5	0.005
106523	S4	233.9	0.002
106523	MN4	42.8	0.015
106523	NU2	107	0.043
106523	2N2	123.1	0.027
106523	OO1	340.5	0.005
106523	LDA2	31.4	0.137
106523	M1	188.8	0.007
106523	J1	223.7	0.005
106523	Q1	158.4	0.013
106523	T2	298.1	0.075
106523	2Q1	128.7	0.012
106523	P1	50.4	0.02
106523	2SM2	70.6	0.013
106523	L2	1.9	0.131
106523	K2	246.4	0.053
106524	M2	122.4	1.326
106524	S2	161.5	0.144
106524	N2	111	0.222
106524	K1	207.2	0.099
106524	M4	245.1	0.226
106524	O1	194.9	0.078
106524	M6	229.6	0.08
106524	MK3	298.8	0.046
106524	S4	146.5	0.006
106524	MN4	246.2	0.067
106524	NU2	103.5	0.065
106524	S6	290.3	0.002
106524	MU2	233.2	0.048
106524	2N2	59.6	0.048
106524	OO1	65.8	0.011
106524	LDA2	114.8	0.044
106524	M1	323.6	0.017
106524	J1	102	0.007
106524	RHO1	246.6	0.006
106524	Q1	249.8	0.016
106524	2Q1	99	0.007
106524	P1	190.9	0.019
106524	2SM2	88.7	0.016
106524	M3	239.8	0.015
106524	L2	102.2	0.112
106524	2MK3	250.7	0.065
106524	K2	168.7	0.061
106524	M8	294.9	0.041
106524	MS4	288	0.059
106525	M2	123.7	1.766
106525	S2	163.4	0.195
106525	N2	112.7	0.29
106525	K1	207.8	0.133
106525	M4	247.8	0.27
106525	O1	191.3	0.099
106525	M6	231.6	0.137
106525	MK3	296.2	0.065
106525	S4	136.9	0.01
106525	MN4	249.9	0.081
106525	NU2	104.2	0.086
106525	S6	278.1	0.002
106525	MU2	238	0.071
106525	2N2	61.5	0.06
106525	OO1	64.8	0.015
106525	LDA2	122.4	0.057
106525	M1	322.5	0.022
106525	J1	112.2	0.008
106525	RHO1	246.5	0.008
106525	Q1	246.5	0.022
106525	2Q1	93.2	0.012
106525	P1	181.1	0.028
106525	2SM2	91.8	0.023
106525	M3	238.6	0.019
106525	L2	106.7	0.15
106525	2MK3	247.5	0.081
106525	K2	169.7	0.077
106525	M8	314.4	0.043
106525	MS4	289.3	0.078
106526	M2	123.6	1.815
106526	S2	162.9	0.2
106526	N2	112.3	0.298
106526	K1	208.4	0.138
106526	M4	247.4	0.276
106526	O1	190	0.102
106526	M6	232.7	0.139
106526	MK3	295.2	0.068
106526	S4	139.8	0.011
106526	MN4	248.8	0.082
106526	NU2	102.8	0.09
106526	MU2	239.8	0.074
106526	2N2	61.6	0.06
106526	OO1	64.5	0.015
106526	LDA2	124.1	0.059
106526	M1	322.5	0.024
106526	J1	120.3	0.008
106526	RHO1	250.3	0.01
106526	Q1	243.5	0.023
106526	2Q1	91.2	0.013
106526	P1	179.4	0.034
106526	2SM2	91.5	0.026
106526	M3	237.2	0.02
106526	L2	107.6	0.154
106526	2MK3	247.4	0.083
106526	K2	170.8	0.078
106526	M8	313.9	0.042
106526	MS4	287.6	0.08
106527	M2	120.5	1.353
106527	S2	158.7	0.143
106527	N2	108.2	0.162
106527	K1	218.9	0.094
106527	M4	254.5	0.229
106527	O1	193.3	0.086
106527	M6	223.2	0.104
106527	MK3	314.6	0.052
106527	MN4	244.1	0.053
106527	S6	224.4	0.006
106527	2N2	63.6	0.091
106527	OO1	61.7	0.009
106527	M1	331.8	0.014
106527	J1	56	0.013
106527	Q1	278.2	0.013
106527	2Q1	111.5	0.023
106527	P1	90.2	0.012
106527	2SM2	113.6	0.029
106527	M3	269.6	0.014
106527	L2	100.4	0.081
106527	2MK3	245.8	0.064
106527	K2	158.4	0.069
106527	M8	306.1	0.03
106527	MS4	309.8	0.065
106528	M2	121.2	1.745
106528	S2	158.2	0.18
106528	N2	110.8	0.205
106528	K1	219.9	0.118
106528	M4	251.1	0.293
106528	O1	192.8	0.11
106528	M6	226.2	0.167
106528	MK3	309.4	0.073
106528	S4	137.6	0.004
106528	MN4	243.8	0.069
106528	S6	214.8	0.008
106528	2N2	63.4	0.116
106528	OO1	64.6	0.011
106528	M1	334	0.018
106528	J1	65.5	0.018
106528	Q1	281.5	0.016
106528	2Q1	110.5	0.031
106528	P1	81.5	0.022
106528	2SM2	110.2	0.041
106528	M3	259.7	0.017
106528	L2	102.8	0.103
106528	2MK3	243.7	0.088
106528	K2	157	0.092
106528	M8	322.4	0.042
106528	MS4	306.1	0.087
106529	M2	121.2	1.797
106529	S2	158.2	0.185
106529	N2	111.2	0.212
106529	K1	219.1	0.123
106529	M4	251	0.291
106529	O1	191.6	0.113
106529	M6	227.7	0.172
106529	MK3	308	0.076
106529	S4	130.5	0.004
106529	MN4	243.2	0.07
106529	S6	224.9	0.007
106529	2N2	64.4	0.116
106529	OO1	65.2	0.011
106529	M1	331.4	0.019
106529	J1	66.8	0.018
106529	Q1	272.8	0.015
106529	2Q1	108.5	0.03
106529	P1	84.3	0.024
106529	2SM2	108	0.042
106529	M3	251.4	0.016
106529	L2	102.2	0.106
106529	2MK3	242.9	0.091
106529	K2	156.9	0.094
106529	M8	324.2	0.039
106529	MS4	306.1	0.088
106530	M2	129.8	2.11
106530	S2	168.3	0.323
106530	N2	117.4	0.228
106530	K1	223.8	0.15
106530	M4	262.7	0.298
106530	O1	196.3	0.121
106530	M6	245.4	0.262
106530	MK3	314.1	0.074
106530	S4	127.5	0.008
106530	MN4	266.8	0.055
106530	S6	252.5	0.011
106530	2N2	79.1	0.141
106530	OO1	65.4	0.015
106530	M1	326.9	0.023
106530	J1	68.4	0.019
106530	Q1	270.4	0.02
106530	2Q1	116.4	0.034
106530	P1	61.8	0.028
106530	2SM2	107.2	0.055
106530	M3	286.7	0.025
106530	L2	121.4	0.156
106530	2MK3	249.8	0.116
106530	K2	200	0.161
106530	M8	355.6	0.055
106530	MS4	319.3	0.1
106531	M2	129.4	1.557
106531	S2	163.2	0.262
106531	N2	115.7	0.169
106531	K1	232.2	0.095
106531	M4	261.8	0.225
106531	O1	201.2	0.092
106531	M6	248.5	0.183
106531	MK3	317.5	0.063
106531	S4	102.9	0.008
106531	MN4	257.7	0.043
106531	S6	273.5	0.007
106531	2N2	71.5	0.094
106531	OO1	84	0.01
106531	M1	345	0.012
106531	J1	77.8	0.017
106531	Q1	289.8	0.012
106531	2Q1	124.4	0.03
106531	P1	81.8	0.037
106531	2SM2	100.8	0.036
106531	M3	287.1	0.019
106531	L2	121.9	0.118
106531	2MK3	248.6	0.084
106531	K2	198.6	0.144
106531	M8	4.2	0.034
106531	MS4	316.5	0.078
106532	M2	125.9	1.174
106532	S2	158.5	0.19
106532	N2	109.9	0.115
106532	K1	227.4	0.073
106532	M4	269	0.196
106532	O1	196.3	0.079
106532	M6	245.6	0.102
106532	MK3	321.5	0.038
106532	S4	216.8	0.001
106532	MN4	265.7	0.026
106532	S6	254	0.003
106532	2N2	64.1	0.071
106532	OO1	78.7	0.008
106532	M1	350.5	0.009
106532	J1	78.8	0.015
106532	Q1	299.2	0.007
106532	2Q1	124.1	0.024
106532	P1	84.9	0.031
106532	2SM2	101.3	0.025
106532	M3	297.2	0.016
106532	L2	123.8	0.101
106532	2MK3	248.7	0.06
106532	K2	193	0.107
106532	M8	4.4	0.045
106532	MS4	333	0.055
106533	M2	127.9	1.378
106533	S2	147.4	0.138
106533	N2	135.6	0.232
106533	K1	205.6	0.097
106533	M4	254.3	0.252
106533	O1	181.5	0.057
106533	M6	271.9	0.147
106533	MK3	270.9	0.046
106533	S4	117.8	0.012
106533	MN4	263.9	0.09
106533	S6	61.6	0.01
106533	2N2	15.9	0.079
106533	OO1	79.2	0.015
106533	M1	332.2	0.018
106533	J1	164.9	0.012
106533	Q1	252	0.019
106533	2Q1	349.8	0.005
106533	P1	149.5	0.015
106533	2SM2	45	0.009
106533	M3	234.1	0.021
106533	L2	98	0.123
106533	2MK3	242.5	0.06
106533	K2	207.4	0.064
106533	M8	12	0.051
106533	MS4	279.2	0.072
106534	M2	128.8	1.258
106534	S2	146.4	0.129
106534	N2	136.3	0.215
106534	K1	211.5	0.083
106534	M4	254.4	0.228
106534	O1	189.9	0.059
106534	M6	268.6	0.121
106534	MK3	279	0.042
106534	S4	132	0.016
106534	MN4	266.3	0.086
106534	S6	74.5	0.011
106534	2N2	12.9	0.07
106534	OO1	82.8	0.009
106534	M1	320.5	0.015
106534	J1	162.3	0.008
106534	Q1	248	0.017
106534	2Q1	11.5	0.01
106534	P1	196.3	0.009
106534	2SM2	18.2	0.013
106534	M3	226.1	0.02
106534	L2	99.2	0.11
106534	2MK3	248.3	0.055
106534	K2	210.8	0.062
106534	M8	1.5	0.045
106534	MS4	282.3	0.07
106535	M2	128	1.123
106535	S2	148.1	0.119
106535	N2	135.6	0.194
106535	K1	216.5	0.069
106535	M4	258.1	0.216
106535	O1	187.7	0.056
106535	M6	269.9	0.093
106535	MK3	281.2	0.035
106535	S4	125.4	0.015
106535	MN4	269.1	0.083
106535	S6	73.5	0.01
106535	2N2	13.8	0.059
106535	OO1	82	0.006
106535	M1	314.6	0.012
106535	J1	140.1	0.005
106535	Q1	245.7	0.015
106535	2Q1	14.9	0.01
106535	P1	255.7	0.01
106535	2SM2	21.3	0.015
106535	M3	229.2	0.019
106535	L2	97.8	0.094
106535	2MK3	252.3	0.048
106535	K2	207.2	0.051
106535	M8	359.8	0.038
106535	MS4	287.6	0.068
106536	M2	136.1	1.038
106536	S2	145	0.1
106536	N2	142	0.172
106536	K1	210.1	0.059
106536	M4	264.4	0.245
106536	O1	191.5	0.047
106536	M6	304.9	0.153
106536	MK3	287.1	0.039
106536	S4	141.1	0.011
106536	MN4	275.9	0.085
106536	S6	89.9	0.006
106536	2N2	19.8	0.051
106536	OO1	70.8	0.009
106536	M1	329.3	0.01
106536	J1	197.9	0.01
106536	Q1	263.8	0.016
106536	2Q1	4.1	0.004
106536	2SM2	21.7	0.008
106536	M3	241.3	0.015
106536	L2	96.8	0.087
106536	2MK3	255.2	0.049
106536	K2	224.8	0.058
106536	M8	60.8	0.07
106536	MS4	292.6	0.069
106537	M2	136.7	1.265
106537	S2	144.6	0.122
106537	N2	142.4	0.204
106537	K1	209.7	0.072
106537	M4	267.4	0.296
106537	O1	191.5	0.056
106537	M6	303.6	0.19
106537	MK3	290.9	0.049
106537	S4	147.2	0.013
106537	MN4	279.2	0.101
106537	S6	95.5	0.009
106537	2N2	20.8	0.061
106537	OO1	69.3	0.01
106537	M1	333.1	0.012
106537	J1	191.3	0.011
106537	Q1	261.9	0.02
106537	2Q1	10.8	0.005
106537	2SM2	35.3	0.01
106537	M3	240	0.018
106537	L2	98.3	0.106
106537	2MK3	256.2	0.059
106537	K2	225.4	0.073
106537	M8	66.1	0.093
106537	MS4	296.1	0.084
106538	M2	136	1.336
106538	S2	146.9	0.139
106538	N2	137.7	0.211
106538	K1	209.1	0.078
106538	M4	271.2	0.287
106538	O1	189.4	0.057
106538	M6	307.4	0.187
106538	MK3	291.1	0.05
106538	S4	136.2	0.019
106538	MN4	289.2	0.093
106538	S6	101.3	0.013
106538	2N2	24.9	0.069
106538	OO1	64.1	0.01
106538	M1	342.5	0.014
106538	J1	180.4	0.013
106538	Q1	259.2	0.022
106538	2Q1	1	0.004
106538	2SM2	44.2	0.016
106538	M3	246.2	0.023
106538	L2	106.7	0.114
106538	2MK3	255.6	0.061
106538	K2	223.1	0.069
106538	M8	74.3	0.1
106538	MS4	298.4	0.082
106539	M2	135.1	0.996
106539	S2	155.7	0.132
106539	N2	138.8	0.156
106539	K1	214.9	0.057
106539	M4	266.6	0.204
106539	O1	174.6	0.04
106539	M6	308.8	0.205
106539	MK3	283.5	0.035
106539	S4	147.8	0.013
106539	MN4	280.4	0.069
106539	S6	102.1	0.009
106539	2N2	5.9	0.063
106539	OO1	68.3	0.009
106539	M1	331.6	0.01
106539	J1	141.6	0.01
106539	Q1	264.8	0.014
106539	2Q1	16.5	0.008
106539	P1	206.1	0.012
106539	2SM2	332.7	0.011
106539	M3	243.2	0.019
106539	L2	103	0.083
106539	2MK3	260.9	0.053
106539	M8	72.4	0.094
106539	MS4	295.3	0.053
106540	M2	135.2	0.975
106540	S2	155.9	0.128
106540	N2	138	0.155
106540	K1	216.8	0.058
106540	M4	266.3	0.202
106540	O1	178.3	0.038
106540	M6	309	0.197
106540	MK3	287	0.034
106540	S4	151.7	0.012
106540	MN4	281.4	0.069
106540	S6	97.6	0.008
106540	2N2	6	0.061
106540	OO1	69.8	0.008
106540	M1	333.7	0.008
106540	J1	149.9	0.01
106540	Q1	259.4	0.014
106540	2Q1	11.9	0.008
106540	P1	199.8	0.014
106540	2SM2	329.5	0.01
106540	M3	245.6	0.018
106540	L2	102.5	0.082
106540	2MK3	260.3	0.052
106540	M8	72.4	0.092
106540	MS4	295.2	0.055
106541	M2	122.9	0.779
106541	S2	154.5	0.102
106541	N2	129.1	0.128
106541	K1	181.1	0.058
106541	M4	279.5	0.094
106541	O1	178.4	0.034
106541	M6	319.1	0.095
106541	MK3	274.3	0.014
106541	S4	81.8	0.003
106541	MN4	273.6	0.032
106541	S6	17.8	0.004
106541	2N2	33.9	0.041
106541	OO1	42.4	0.009
106541	M1	310.7	0.006
106541	J1	185.1	0.012
106541	Q1	239.1	0.015
106541	2Q1	93.7	0.002
106541	P1	105.3	0.025
106541	2SM2	335.6	0.007
106541	M3	251.3	0.01
106541	L2	93.2	0.057
106541	2MK3	237.6	0.033
106541	M8	93.7	0.064
106541	MS4	303.4	0.031
106542	M2	133	0.748
106542	S2	193.5	0.11
106542	N2	130.8	0.086
106542	K1	264.7	0.058
106542	M4	269.7	0.206
106542	O1	202.5	0.074
106542	M6	293.1	0.141
106542	MK3	325.1	0.028
106542	S4	27.4	0.006
106542	MN4	254.4	0.044
106542	S6	274	0.006
106542	2N2	74.1	0.063
106542	OO1	162.3	0.013
106542	M1	357.8	0.008
106542	J1	92.6	0.021
106542	Q1	321.3	0.014
106542	2Q1	105.5	0.029
106542	P1	62.7	0.025
106542	2SM2	171.3	0.007
106542	M3	333.3	0.018
106542	L2	120.7	0.069
106542	2MK3	285.3	0.033
106542	K2	239.8	0.022
106542	M8	82.1	0.099
106542	MS4	0.9	0.067
106543	M2	133.4	0.678
106543	S2	191.9	0.092
106543	N2	127.2	0.077
106543	K1	261.8	0.06
106543	M4	273.6	0.185
106543	O1	200.4	0.057
106543	M6	289.9	0.117
106543	MK3	325.3	0.028
106543	S4	34.4	0.008
106543	MN4	263.9	0.037
106543	S6	259.2	0.007
106543	2N2	74.8	0.062
106543	OO1	131.9	0.005
106543	M1	350.3	0.009
106543	J1	75.5	0.017
106543	Q1	289.8	0.017
106543	2Q1	99.9	0.025
106543	P1	46.2	0.026
106543	2SM2	208.4	0.003
106543	M3	335.9	0.012
106543	L2	123.9	0.07
106543	2MK3	278.9	0.027
106543	K2	233.8	0.019
106543	M8	77.6	0.084
106543	MS4	6.4	0.063
106544	M2	131.9	0.629
106544	S2	182.1	0.069
106544	N2	124.3	0.064
106544	K1	304.3	0.073
106544	M4	276.5	0.158
106544	O1	203.1	0.059
106544	M6	283.8	0.102
106544	MK3	323.2	0.025
106544	S4	22.4	0.006
106544	MN4	273.7	0.033
106544	S6	232.7	0.006
106544	2N2	64.5	0.065
106544	OO1	156	0.006
106544	M1	26.6	0.014
106544	J1	87.5	0.015
106544	Q1	306.9	0.021
106544	2Q1	109.2	0.029
106544	P1	73.8	0.069
106544	2SM2	216.4	0.007
106544	M3	10.9	0.01
106544	L2	123.1	0.072
106544	2MK3	284	0.028
106544	K2	191.2	0.017
106544	M8	76.5	0.069
106544	MS4	12.1	0.062
106545	M2	27.6	2.011
106545	S2	68.3	0.29
106545	N2	357.5	0.397
106545	K1	125	0.071
106545	M4	314.9	0.073
106545	O1	108.1	0.051
106545	M6	231.8	0.178
106545	MK3	319.5	0.009
106545	S4	83.9	0.004
106545	MN4	263.8	0.028
106545	NU2	358.8	0.099
106545	S6	24.3	0.008
106545	MU2	99.2	0.03
106545	2N2	327.6	0.069
106545	LDA2	43.3	0.038
106545	J1	142.9	0.006
106545	Q1	70.1	0.008
106545	2Q1	64.7	0.009
106545	P1	125.6	0.023
106545	2SM2	24.7	0.005
106545	M3	195.4	0.004
106545	L2	64.6	0.111
106545	2MK3	308.7	0.005
106545	K2	66.1	0.084
106545	M8	293.5	0.039
106545	MS4	9	0.012
106546	M2	28.1	2.263
106546	S2	69.3	0.328
106546	N2	357.8	0.444
106546	K1	125	0.077
106546	M4	318.3	0.086
106546	O1	104.6	0.055
106546	M6	236	0.187
106546	MK3	322.8	0.011
106546	S4	70.8	0.003
106546	MN4	266.2	0.033
106546	NU2	359.4	0.112
106546	S6	33.7	0.007
106546	MU2	108.1	0.034
106546	2N2	329.6	0.085
106546	LDA2	37.7	0.043
106546	J1	142.8	0.007
106546	Q1	63.6	0.009
106546	2Q1	56.9	0.008
106546	P1	117.9	0.022
106546	2SM2	335.9	0.003
106546	M3	188.2	0.004
106546	L2	66.2	0.123
106546	2MK3	310	0.008
106546	K2	67.1	0.094
106546	M8	293.2	0.051
106546	MS4	6.4	0.013
106547	M2	28.5	2.376
106547	S2	69.5	0.344
106547	N2	358.5	0.465
106547	K1	123.4	0.082
106547	M4	317.9	0.081
106547	O1	101.6	0.055
106547	M6	238.1	0.191
106547	MK3	311.4	0.011
106547	MN4	260.4	0.033
106547	NU2	359.2	0.121
106547	S6	43.3	0.005
106547	MU2	108.7	0.038
106547	2N2	329.8	0.088
106547	LDA2	35.5	0.047
106547	J1	131.4	0.007
106547	Q1	61.5	0.01
106547	2Q1	64.6	0.007
106547	P1	113.4	0.023
106547	2SM2	268.9	0.003
106547	M3	189	0.005
106547	L2	66.5	0.129
106547	2MK3	303.2	0.008
106547	K2	67.3	0.097
106547	M8	293.4	0.058
106547	MS4	350.7	0.011
106548	M2	28.3	2.461
106548	S2	68.7	0.349
106548	N2	358.2	0.474
106548	K1	120.5	0.083
106548	M4	314.3	0.061
106548	O1	98.4	0.05
106548	M6	238.4	0.187
106548	MK3	290.5	0.019
106548	S4	252.7	0.003
106548	MN4	233	0.03
106548	NU2	358.8	0.129
106548	S6	45.8	0.004
106548	MU2	117.7	0.038
106548	2N2	327.7	0.089
106548	LDA2	39	0.053
106548	M1	343.5	0.006
106548	J1	84.5	0.007
106548	Q1	68.4	0.005
106548	P1	105.9	0.018
106548	2SM2	294.5	0.007
106548	M3	216.6	0.01
106548	L2	68	0.137
106548	2MK3	242	0.008
106548	K2	66.4	0.098
106548	M8	303.8	0.065
106548	MS4	263.8	0.011
106549	M2	10.5	0.791
106549	S2	50.5	0.124
106549	N2	346.5	0.173
106549	K1	122.1	0.036
106549	M4	65.4	0.043
106549	O1	80.5	0.026
106549	M6	195.6	0.067
106549	MK3	31.3	0.008
106549	S4	292.3	0.007
106549	MN4	18.4	0.022
106549	NU2	321.2	0.039
106549	S6	261.5	0.004
106549	MU2	55.1	0.025
106549	2N2	309.6	0.03
106549	LDA2	34.7	0.008
106549	J1	109.5	0.003
106549	Q1	16.1	0.007
106549	2Q1	268	0.002
106549	P1	141.9	0.007
106549	2SM2	91.1	0.011
106549	M3	82.2	0.002
106549	L2	43.8	0.043
106549	2MK3	346.8	0.011
106549	K2	45.4	0.038
106549	M8	178.9	0.008
106549	MS4	81.2	0.003
106550	M2	22.9	0.957
106550	S2	64.8	0.137
106550	N2	356.2	0.205
106550	K1	112.9	0.037
106550	M4	355.3	0.062
106550	O1	69.5	0.023
106550	M6	199.6	0.075
106550	MK3	312.2	0.006
106550	S4	195.7	0.006
106550	MN4	307.5	0.03
106550	NU2	329	0.048
106550	S6	269.2	0.003
106550	MU2	215.8	0.005
106550	2N2	348.4	0.048
106550	LDA2	34.2	0.011
106550	M1	291	0.005
106550	J1	87.3	0.006
106550	RHO1	340	0.008
106550	Q1	77.8	0.011
106550	P1	108.8	0.01
106550	2SM2	68.7	0.002
106550	M3	194.1	0.005
106550	L2	67.5	0.058
106550	2MK3	277	0.006
106550	K2	72.5	0.038
106550	M8	183.3	0.022
106550	MS4	71.9	0.015
106551	M2	25.3	1.001
106551	S2	61.8	0.121
106551	N2	355.4	0.189
106551	K1	84.3	0.02
106551	M4	296.9	0.039
106551	O1	71	0.018
106551	M6	160.3	0.07
106551	MK3	218.5	0.011
106551	S4	203.1	0.004
106551	MN4	226.7	0.017
106551	NU2	350.4	0.055
106551	S6	263.1	0.006
106551	MU2	204.3	0.031
106551	2N2	348.7	0.053
106551	LDA2	48	0.017
106551	M1	212.8	0.007
106551	J1	212.7	0.01
106551	RHO1	137.4	0.01
106551	Q1	342.2	0.004
106551	2Q1	80.2	0.004
106551	P1	108.5	0.017
106551	2SM2	283.6	0.007
106551	M3	127.4	0.01
106551	L2	66.9	0.081
106551	2MK3	174	0.008
106551	K2	62.6	0.039
106551	M8	320.1	0.009
106551	MS4	165.1	0.01
106552	M2	324.6	1.872
106552	S2	350.6	0.403
106552	N2	307.9	0.47
106552	K1	128.2	0.148
106552	M4	52.4	0.181
106552	O1	152.4	0.12
106552	M6	120.8	0.086
106552	S4	281	0.022
106552	NU2	310.1	0.091
106552	S6	41.6	0.011
106552	2N2	291.2	0.063
106552	OO1	103.8	0.005
106552	LDA2	336.6	0.013
106552	M1	140.2	0.009
106552	J1	116.1	0.009
106552	RHO1	162.8	0.005
106552	Q1	164.4	0.023
106552	T2	349.4	0.024
106552	R2	351.6	0.003
106552	2Q1	176.4	0.003
106552	P1	129.9	0.049
106552	L2	307.9	0.067
106552	K2	352.6	0.11
106552	M8	201.1	0.03
106553	M2	325.2	2.26
106553	S2	352.3	0.481
106553	N2	308.7	0.576
106553	K1	129.1	0.179
106553	M4	58.6	0.216
106553	O1	151.6	0.142
106553	M6	124.7	0.119
106553	S4	281.1	0.025
106553	NU2	311	0.112
106553	S6	39.6	0.017
106553	2N2	292.4	0.077
106553	OO1	106.4	0.006
106553	LDA2	337.7	0.016
106553	M1	140.2	0.01
106553	J1	117.9	0.011
106553	RHO1	161.2	0.005
106553	Q1	162.7	0.027
106553	T2	351.1	0.028
106553	R2	353.4	0.004
106553	2Q1	173.9	0.004
106553	P1	130.7	0.059
106553	L2	308.8	0.082
106553	K2	354.5	0.131
106553	M8	206.8	0.03
106554	M2	325.5	2.445
106554	S2	352.2	0.523
106554	N2	308.6	0.625
106554	K1	129.2	0.191
106554	M4	57.2	0.24
106554	O1	151.7	0.158
106554	M6	130.2	0.145
106554	S4	255	0.028
106554	NU2	310.9	0.121
106554	S6	48.7	0.021
106554	2N2	291.9	0.083
106554	OO1	106.6	0.007
106554	LDA2	337.8	0.017
106554	M1	140.4	0.011
106554	J1	118	0.013
106554	RHO1	161.3	0.006
106554	Q1	162.8	0.031
106554	T2	351.1	0.031
106554	R2	353.3	0.004
106554	2Q1	174	0.004
106554	P1	130.8	0.063
106554	L2	308.7	0.089
106554	K2	354.4	0.142
106554	M8	213.4	0.025
106555	M2	320.6	1.072
106555	S2	335.1	0.166
106555	N2	294.1	0.251
106555	K1	113.4	0.098
106555	M4	26.2	0.163
106555	O1	140.5	0.068
106555	M6	94.7	0.059
106555	MK3	195.6	0.03
106555	S4	309.8	0.02
106555	MN4	2.1	0.066
106555	S6	347.2	0.007
106555	2N2	286.8	0.034
106555	OO1	302.8	0.008
106555	M1	129.9	0.004
106555	J1	137.1	0.013
106555	Q1	103.9	0.015
106555	2Q1	48.8	0.001
106555	2SM2	45.4	0.006
106555	M3	90.8	0.022
106555	L2	323.6	0.084
106555	2MK3	232.4	0.022
106555	M8	157.1	0.02
106555	MS4	29.9	0.042
106556	M2	319.7	1.295
106556	S2	334.4	0.21
106556	N2	292.9	0.304
106556	K1	114.1	0.118
106556	M4	24.7	0.134
106556	O1	138.3	0.086
106556	M6	97.1	0.057
106556	MK3	208.6	0.034
106556	S4	299.6	0.021
106556	MN4	359.2	0.059
106556	S6	6.7	0.007
106556	2N2	275.2	0.044
106556	OO1	297.3	0.009
106556	M1	158.7	0.007
106556	J1	140.4	0.014
106556	Q1	107.5	0.019
106556	2Q1	105	0.005
106556	2SM2	45.6	0.013
106556	M3	96.9	0.024
106556	L2	324.1	0.1
106556	2MK3	235.4	0.026
106556	M8	114.3	0.005
106556	MS4	42.6	0.038
106557	M2	317.9	1.361
106557	S2	334.6	0.244
106557	N2	290.6	0.314
106557	K1	118.1	0.14
106557	M4	65.5	0.087
106557	O1	140.8	0.095
106557	M6	100.4	0.051
106557	MK3	225.8	0.047
106557	S4	308.7	0.015
106557	MN4	35.8	0.044
106557	S6	33.8	0.008
106557	2N2	269.8	0.055
106557	OO1	276.8	0.014
106557	M1	159.2	0.016
106557	J1	157.7	0.02
106557	Q1	139.6	0.018
106557	2Q1	155	0.013
106557	2SM2	59.9	0.02
106557	M3	97.8	0.027
106557	L2	322.5	0.109
106557	2MK3	241.1	0.038
106557	M8	358.2	0.013
106557	MS4	65.7	0.033
106558	M2	327.2	1.173
106558	S2	345	0.206
106558	N2	298.6	0.283
106558	K1	124.3	0.122
106558	M4	44.8	0.172
106558	O1	159	0.078
106558	M6	89.6	0.05
106558	MK3	192.1	0.045
106558	S4	268.8	0.019
106558	MN4	16.5	0.076
106558	S6	28.6	0.008
106558	2N2	269.9	0.063
106558	OO1	0.3	0.005
106558	M1	82	0.001
106558	J1	152.4	0.009
106558	Q1	123.9	0.012
106558	2Q1	132.2	0.007
106558	2SM2	47.7	0.008
106558	M3	124.9	0.017
106558	L2	325	0.085
106558	2MK3	235.1	0.031
106558	M8	191.1	0.026
106558	MS4	64.6	0.067
106559	M2	327.5	1.376
106559	S2	343.8	0.233
106559	N2	299.3	0.33
106559	K1	125.4	0.139
106559	M4	39	0.185
106559	O1	158.1	0.091
106559	M6	101.5	0.069
106559	MK3	194.5	0.048
106559	S4	269.9	0.018
106559	MN4	14.4	0.083
106559	S6	30.6	0.008
106559	2N2	273.9	0.063
106559	OO1	348.6	0.003
106559	M1	117.9	0.003
106559	J1	152.7	0.01
106559	Q1	125.8	0.014
106559	2Q1	131.1	0.01
106559	2SM2	37.5	0.005
106559	M3	124.3	0.019
106559	L2	329.2	0.093
106559	2MK3	234.5	0.032
106559	M8	183.5	0.028
106559	MS4	62.3	0.07
106560	M2	326.8	1.481
106560	S2	342.4	0.243
106560	N2	297.9	0.351
106560	K1	124.5	0.148
106560	M4	35.4	0.19
106560	O1	153.8	0.102
106560	M6	118.3	0.081
106560	MK3	202.9	0.053
106560	S4	259.4	0.019
106560	MN4	14.6	0.096
106560	S6	14.7	0.009
106560	2N2	276.4	0.053
106560	OO1	306.4	0.005
106560	M1	118.4	0.004
106560	J1	152.1	0.009
106560	Q1	123.5	0.018
106560	2Q1	121.7	0.012
106560	2SM2	151.3	0.002
106560	M3	115.8	0.022
106560	L2	330.6	0.102
106560	2MK3	246.2	0.033
106560	M8	174.5	0.028
106560	MS4	66.5	0.073
106561	M2	331.8	0.764
106561	S2	340.2	0.196
106561	K1	118.8	0.072
106561	M4	58.3	0.01
106561	O1	166	0.051
106561	M6	110.3	0.033
106561	MK3	8.6	0.002
106561	S4	265.1	0.013
106561	S6	330.1	0.006
106561	2N2	59.6	0.041
106561	OO1	275.6	0.01
106561	2Q1	52	0.009
106561	2SM2	39.3	0.01
106561	2MK3	359.7	0.006
106561	M8	172.2	0.005
106561	MS4	67.5	0.01
106562	M2	331.1	0.91
106562	S2	338.6	0.231
106562	K1	117.5	0.082
106562	M4	189.6	0.001
106562	O1	157.9	0.052
106562	M6	126.7	0.034
106562	MK3	7.1	0.006
106562	S4	270.1	0.011
106562	S6	348.3	0.009
106562	2N2	62	0.056
106562	OO1	289.6	0.012
106562	2Q1	48.2	0.009
106562	2SM2	35.6	0.013
106562	2MK3	16.7	0.01
106562	M8	204.4	0.01
106562	MS4	43.5	0.013
106563	M2	328.9	0.902
106563	S2	335.2	0.241
106563	K1	114.3	0.085
106563	M4	291.1	0.008
106563	O1	147.1	0.057
106563	M6	167.8	0.024
106563	MK3	344.4	0.007
106563	S4	278.6	0.012
106563	S6	347.2	0.015
106563	2N2	64.5	0.053
106563	OO1	272.7	0.015
106563	2Q1	50.6	0.01
106563	2SM2	27.1	0.016
106563	2MK3	0.9	0.016
106563	M8	196.6	0.023
106563	MS4	39.9	0.014
106564	M2	305.7	0.79
106564	S2	309.4	0.116
106564	N2	266.7	0.158
106564	K1	163.3	0.017
106564	M4	53.4	0.134
106564	O1	150.3	0.04
106564	M6	141.7	0.111
106564	MK3	235.2	0.015
106564	S4	135.4	0.011
106564	MN4	3.7	0.06
106564	S6	60	0.008
106564	2N2	160	0.02
106564	OO1	274.6	0.002
106564	M1	299.9	0.004
106564	J1	303.2	0.008
106564	Q1	140.4	0.004
106564	2Q1	17.1	0.013
106564	P1	107.6	0.053
106564	2SM2	36	0.024
106564	M3	90.3	0.011
106564	L2	336.5	0.103
106564	2MK3	305.4	0.02
106564	M8	263	0.045
106564	MS4	76.4	0.059
106565	M2	305.5	0.949
106565	S2	309.3	0.138
106565	N2	269	0.193
106565	K1	181.6	0.027
106565	M4	47	0.163
106565	O1	153.4	0.049
106565	M6	138	0.133
106565	MK3	240	0.019
106565	S4	158.7	0.017
106565	MN4	358.7	0.071
106565	S6	21.3	0.009
106565	2N2	145.1	0.017
106565	OO1	316.1	0.003
106565	M1	308.3	0.007
106565	J1	324.8	0.009
106565	Q1	105.5	0.014
106565	2Q1	12.5	0.016
106565	P1	108.2	0.074
106565	2SM2	22	0.035
106565	M3	94.4	0.013
106565	L2	334.2	0.121
106565	2MK3	310.4	0.025
106565	M8	251.2	0.057
106565	MS4	71.6	0.075
106566	M2	306.3	1.014
106566	S2	309.8	0.149
106566	N2	270	0.205
106566	K1	202.5	0.034
106566	M4	47	0.167
106566	O1	156.5	0.051
106566	M6	135.9	0.139
106566	MK3	245.5	0.02
106566	S4	167.4	0.026
106566	MN4	358.6	0.076
106566	S6	2.9	0.009
106566	2N2	143.5	0.017
106566	OO1	271.5	0.004
106566	M1	324.1	0.009
106566	J1	329.7	0.009
106566	Q1	100.8	0.018
106566	2Q1	16.8	0.02
106566	P1	109.3	0.09
106566	2SM2	18.3	0.048
106566	M3	93.3	0.015
106566	L2	334.5	0.13
106566	2MK3	309.9	0.029
106566	M8	249.4	0.061
106566	MS4	71.9	0.081
106567	M2	3.6	1.235
106567	S2	19.6	0.355
106567	N2	345.1	0.147
106567	K1	218.9	0.15
106567	M4	184.2	0.051
106567	O1	224.5	0.121
106567	M6	227.8	0.043
106567	MK3	15.2	0.029
106567	S4	243.7	0.006
106567	MN4	147.5	0.024
106567	S6	196.4	0.004
106567	2N2	350	0.086
106567	OO1	331.6	0.017
106567	M1	298.3	0.009
106567	J1	225.8	0.007
106567	Q1	198.8	0.043
106567	2Q1	155.2	0.019
106567	P1	177.4	0.033
106567	2SM2	267.7	0.029
106567	M3	191.1	0.011
106567	L2	29.9	0.045
106567	2MK3	355.4	0.05
106567	K2	13.5	0.084
106567	M8	95.8	0.004
106567	MS4	183.4	0.037
106568	M2	4.1	1.489
106568	S2	19.8	0.429
106568	N2	346.5	0.172
106568	K1	217.9	0.18
106568	M4	191.5	0.065
106568	O1	227.4	0.142
106568	M6	226.9	0.061
106568	MK3	21.5	0.039
106568	S4	258.9	0.008
106568	MN4	143.7	0.028
106568	S6	219.3	0.005
106568	2N2	350.2	0.11
106568	OO1	330	0.023
106568	M1	294.4	0.01
106568	J1	238.6	0.009
106568	Q1	199.4	0.052
106568	2Q1	163.5	0.022
106568	P1	174.7	0.039
106568	2SM2	264.4	0.032
106568	M3	177.8	0.011
106568	L2	33.2	0.054
106568	2MK3	355.9	0.063
106568	K2	13.9	0.093
106568	M8	104.6	0.009
106568	MS4	190.7	0.044
106569	M2	352.9	0.201
106569	S2	18.1	0.057
106569	N2	314.8	0.026
106569	K1	211.1	0.046
106569	M4	132.5	0.01
106569	O1	267.4	0.032
106569	M6	206	0.005
106569	MK3	356.8	0.007
106569	S4	303.8	0.003
106569	MN4	52.5	0.004
106569	S6	232.4	0.003
106569	2N2	45.3	0.007
106569	OO1	80.7	0.011
106569	M1	352.9	0.007
106569	J1	227.5	0.013
106569	Q1	240.6	0.019
106569	2Q1	334.8	0.003
106569	P1	260.8	0.031
106569	2SM2	74.3	0.001
106569	M3	198.1	0.002
106569	L2	56.9	0.014
106569	2MK3	357.3	0.009
106569	M8	124	0.001
106569	MS4	99.9	0.007
106570	M2	357.3	0.271
106570	S2	16.3	0.09
106570	N2	305.1	0.034
106570	K1	225.4	0.065
106570	M4	223.6	0.011
106570	O1	273.3	0.04
106570	M6	240.7	0.013
106570	MK3	79.9	0.004
106570	S4	196.1	0.007
106570	MN4	140.9	0.005
106570	S6	203.5	0.003
106570	2N2	3.5	0.012
106570	OO1	131.4	0.017
106570	M1	233.5	0.013
106570	J1	220.2	0.023
106570	Q1	225.4	0.021
106570	2Q1	274	0.016
106570	P1	280	0.056
106570	2SM2	156.4	0.002
106570	M3	266.5	0.004
106570	L2	34.9	0.012
106570	2MK3	12.7	0.006
106570	M8	163	0.002
106570	MS4	182.1	0.017
106571	M2	15.9	0.461
106571	S2	20.1	0.167
106571	N2	340.3	0.042
106571	K1	235.2	0.125
106571	M4	267.4	0.063
106571	O1	222.2	0.062
106571	M6	196.8	0.02
106571	MK3	328.9	0.009
106571	S4	280.8	0.009
106571	MN4	181.1	0.022
106571	S6	84.5	0.013
106571	2N2	22.5	0.028
106571	OO1	332.8	0.031
106571	M1	55.2	0.007
106571	J1	104.3	0.01
106571	Q1	202.2	0.032
106571	2Q1	208.6	0.041
106571	P1	218	0.061
106571	2SM2	192.8	0.005
106571	M3	221.5	0.014
106571	L2	317.2	0.02
106571	2MK3	63.7	0.015
106571	K2	86.4	0.053
106571	M8	27.7	0.002
106571	MS4	287.4	0.058
106572	M2	15.6	0.563
106572	S2	18.6	0.165
106572	N2	331.7	0.051
106572	K1	234.2	0.094
106572	M4	246.8	0.081
106572	O1	222.5	0.057
106572	M6	196.8	0.019
106572	MK3	29.5	0.023
106572	S4	248.7	0.011
106572	MN4	170.8	0.032
106572	S6	61.3	0.01
106572	2N2	23.1	0.068
106572	OO1	286.2	0.031
106572	M1	355.6	0.012
106572	J1	153.3	0.014
106572	Q1	191.4	0.048
106572	2Q1	221.6	0.031
106572	P1	216.3	0.034
106572	2SM2	324.2	0.019
106572	M3	174.8	0.016
106572	L2	292.4	0.022
106572	2MK3	61.3	0.037
106572	K2	64.4	0.083
106572	M8	65.5	0.003
106572	MS4	270.7	0.084
106573	M2	10.7	0.544
106573	S2	21.5	0.148
106573	N2	4.5	0.067
106573	K1	240.1	0.118
106573	M4	200.9	0.023
106573	O1	220.5	0.062
106573	M6	217.7	0.009
106573	MK3	10.8	0.01
106573	S4	200.8	0.004
106573	MN4	141.1	0.011
106573	S6	83.3	0.002
106573	2N2	330.9	0.044
106573	OO1	43.5	0.014
106573	M1	338.2	0.013
106573	J1	59.7	0.005
106573	Q1	235	0.006
106573	2Q1	184.1	0.008
106573	P1	236	0.062
106573	2SM2	249.8	0.014
106573	M3	188	0.005
106573	L2	26	0.028
106573	2MK3	8.9	0.021
106573	K2	59.8	0.037
106573	M8	120.9	0.001
106573	MS4	187.2	0.02
106574	M2	12.5	0.588
106574	S2	25.1	0.164
106574	N2	4	0.066
106574	K1	238.6	0.12
106574	M4	177.7	0.035
106574	O1	244.9	0.046
106574	M6	233.9	0.011
106574	MK3	34	0.022
106574	S4	254.8	0.003
106574	MN4	131.7	0.017
106574	S6	131.3	0.002
106574	2N2	342.4	0.039
106574	OO1	45.1	0.015
106574	M1	317.1	0.031
106574	J1	79.6	0.01
106574	Q1	203.9	0.012
106574	2Q1	295.3	0.008
106574	P1	244.1	0.061
106574	2SM2	289	0.017
106574	M3	170.8	0.007
106574	L2	16.7	0.027
106574	2MK3	18	0.032
106574	K2	39.9	0.04
106574	M8	67	0.003
106574	MS4	191.1	0.027
106575	M2	9.8	0.978
106575	S2	16.9	0.279
106575	N2	343.4	0.137
106575	K1	257.6	0.154
106575	M4	137	0.037
106575	O1	258.7	0.122
106575	M6	233.2	0.037
106575	MK3	4.4	0.032
106575	S4	271.3	0.007
106575	MN4	97.9	0.017
106575	S6	357.9	0.007
106575	2N2	24.7	0.042
106575	OO1	320.5	0.025
106575	M1	200	0.017
106575	J1	331.3	0.006
106575	Q1	213	0.047
106575	2Q1	124.6	0.023
106575	P1	300.7	0.015
106575	2SM2	288.3	0.015
106575	M3	217.4	0.006
106575	L2	50	0.029
106575	2MK3	340.4	0.054
106575	K2	27.3	0.124
106575	M8	310.5	0.007
106575	MS4	146.1	0.045
106576	M2	10.8	1.191
106576	S2	19.3	0.337
106576	N2	343.9	0.173
106576	K1	256.8	0.177
106576	M4	142.9	0.032
106576	O1	259.9	0.147
106576	M6	236.1	0.056
106576	MK3	13.7	0.039
106576	S4	264.3	0.012
106576	MN4	92.8	0.014
106576	S6	349.6	0.007
106576	2N2	18	0.06
106576	OO1	325.3	0.039
106576	M1	204	0.02
106576	J1	336.7	0.01
106576	Q1	214.5	0.06
106576	2Q1	124.8	0.031
106576	P1	288.9	0.012
106576	2SM2	290.9	0.018
106576	M3	241	0.005
106576	L2	60	0.042
106576	2MK3	345.2	0.063
106576	K2	29.4	0.134
106576	M8	262.3	0.006
106576	MS4	150.4	0.057
106577	M2	12.7	0.878
106577	S2	34.9	0.259
106577	N2	357.4	0.08
106577	K1	266.7	0.139
106577	M4	108.5	0.03
106577	O1	255.1	0.098
106577	M6	246.1	0.023
106577	MK3	332.9	0.031
106577	S4	164.6	0.008
106577	MN4	116	0.024
106577	S6	180.4	0.007
106577	2N2	327.9	0.086
106577	OO1	347.9	0.008
106577	M1	340.9	0.028
106577	J1	244	0.01
106577	Q1	214.1	0.02
106577	2Q1	213.6	0.025
106577	P1	278.4	0.032
106577	2SM2	284	0.027
106577	M3	150.2	0.017
106577	L2	5.2	0.041
106577	2MK3	351.5	0.051
106577	K2	352	0.045
106577	M8	4.5	0.006
106577	MS4	133.9	0.034
106578	M2	14.3	1.153
106578	S2	36.6	0.361
106578	N2	0	0.1
106578	K1	263.7	0.156
106578	M4	55.9	0.05
106578	O1	261.8	0.127
106578	M6	260.8	0.036
106578	MK3	328.6	0.037
106578	S4	126.6	0.006
106578	MN4	102.2	0.034
106578	S6	129.8	0.01
106578	2N2	333.6	0.108
106578	OO1	343.9	0.009
106578	M1	347.9	0.04
106578	J1	252.4	0.012
106578	Q1	230.8	0.025
106578	2Q1	225.7	0.03
106578	P1	265.1	0.015
106578	2SM2	271.3	0.032
106578	M3	158.1	0.023
106578	L2	9	0.054
106578	2MK3	345.6	0.062
106578	K2	323.1	0.031
106578	M8	299.8	0.015
106578	MS4	112.6	0.034
106579	M2	21.7	0.718
106579	S2	34.6	0.189
106579	N2	353.2	0.106
106579	K1	282.7	0.094
106579	M4	76.4	0.057
106579	O1	291.2	0.111
106579	M6	249.1	0.064
106579	MK3	341.2	0.034
106579	S4	97.6	0.006
106579	MN4	46.4	0.017
106579	S6	3.8	0.004
106579	2N2	45.2	0.03
106579	OO1	319.2	0.027
106579	M1	167.9	0.015
106579	J1	33.7	0.01
106579	Q1	220.6	0.035
106579	2Q1	131.1	0.013
106579	2SM2	307.7	0.004
106579	M3	259.2	0.005
106579	L2	84.5	0.022
106579	2MK3	330.7	0.054
106579	K2	26.6	0.081
106579	M8	177.5	0.006
106579	MS4	120.9	0.061
106580	M2	21.5	0.874
106580	S2	28.6	0.186
106580	N2	357	0.123
106580	K1	281.9	0.11
106580	M4	64.3	0.077
106580	O1	291.7	0.125
106580	M6	247.3	0.075
106580	MK3	339.6	0.05
106580	S4	92.4	0.004
106580	MN4	21.2	0.029
106580	S6	348.5	0.007
106580	2N2	48.2	0.046
106580	OO1	322	0.04
106580	M1	142.1	0.011
106580	J1	13	0.016
106580	Q1	223.2	0.041
106580	2Q1	130.9	0.019
106580	2SM2	9.3	0.006
106580	M3	2.3	0.007
106580	L2	77.6	0.024
106580	2MK3	330.6	0.064
106580	K2	19.4	0.133
106580	M8	166.4	0.005
106580	MS4	114.7	0.075
106581	M2	37.6	1.19
106581	S2	60.2	0.35
106581	N2	35.6	0.089
106581	K1	296.8	0.32
106581	M4	93.6	0.05
106581	O1	288.4	0.253
106581	M6	303.3	0.05
106581	MK3	330.8	0.05
106581	S4	119.9	0.017
106581	MN4	127.4	0.022
106581	S6	186	0.015
106581	2N2	343.2	0.104
106581	OO1	202.5	0.016
106581	M1	17.8	0.051
106581	J1	275.6	0.019
106581	Q1	274.4	0.045
106581	2Q1	282.6	0.039
106581	P1	295.8	0.115
106581	2SM2	315.7	0.037
106581	M3	171.5	0.019
106581	L2	24	0.042
106581	2MK3	340.5	0.117
106581	K2	61.1	0.032
106581	M8	334.7	0.01
106581	MS4	122.9	0.057
106582	M2	37.5	1.577
106582	S2	59.3	0.473
106582	N2	36.5	0.119
106582	K1	295.7	0.424
106582	M4	105.3	0.05
106582	O1	287.8	0.337
106582	M6	303.1	0.077
106582	MK3	329.7	0.067
106582	S4	124.9	0.023
106582	MN4	133	0.027
106582	S6	188.2	0.017
106582	2N2	340.7	0.131
106582	OO1	207.8	0.021
106582	M1	16.3	0.069
106582	J1	274.2	0.026
106582	Q1	275.6	0.061
106582	2Q1	277.6	0.048
106582	P1	294.1	0.148
106582	2SM2	312.2	0.043
106582	M3	172.7	0.024
106582	L2	25.3	0.056
106582	2MK3	341.3	0.148
106582	K2	84.1	0.039
106582	M8	345.7	0.014
106582	MS4	131.5	0.068
106583	M2	24.6	0.858
106583	S2	40.6	0.274
106583	N2	1.3	0.125
106583	K1	292.1	0.234
106583	M4	257.3	0.103
106583	O1	287.7	0.212
106583	M6	243.5	0.072
106583	MK3	55.4	0.011
106583	S4	300.9	0.026
106583	MN4	214.2	0.033
106583	S6	18.2	0.015
106583	2N2	17.3	0.034
106583	OO1	307.4	0.032
106583	M1	233.7	0.024
106583	J1	16.2	0.016
106583	Q1	236.5	0.07
106583	2Q1	167.6	0.022
106583	P1	3.6	0.031
106583	2SM2	297.4	0.013
106583	M3	238.5	0.006
106583	L2	51.1	0.032
106583	2MK3	346.2	0.031
106583	K2	92.1	0.117
106583	M8	184.6	0.021
106583	MS4	255.2	0.062
106584	M2	25.6	1.042
106584	S2	46	0.314
106584	N2	5.4	0.158
106584	K1	287.4	0.286
106584	M4	244.1	0.131
106584	O1	286.5	0.246
106584	M6	247.5	0.077
106584	MK3	63.9	0.031
106584	S4	305.2	0.033
106584	MN4	202.8	0.035
106584	S6	9.2	0.015
106584	2N2	38.2	0.058
106584	OO1	329.3	0.037
106584	M1	238.7	0.033
106584	J1	2.4	0.02
106584	Q1	233.8	0.086
106584	2Q1	162.6	0.017
106584	P1	10.2	0.047
106584	2SM2	293.1	0.028
106584	M3	226.4	0.005
106584	L2	77.4	0.03
106584	2MK3	356.2	0.045
106584	K2	99.2	0.104
106584	M8	202.1	0.016
106584	MS4	251.3	0.085
106585	M2	359	0.932
106585	S2	358.8	0.291
106585	N2	324.6	0.124
106585	K1	182.1	0.176
106585	M4	328.2	0.046
106585	O1	174.3	0.121
106585	M6	230.4	0.053
106585	MK3	131.2	0.01
106585	S4	341.2	0.011
106585	MN4	282.5	0.016
106585	S6	234	0.003
106585	2N2	32.1	0.056
106585	OO1	312.4	0.007
106585	M1	149.1	0.02
106585	J1	235.3	0.006
106585	Q1	169.1	0.037
106585	2Q1	114.4	0.025
106585	P1	180.4	0.049
106585	2SM2	290.8	0.026
106585	M3	247.5	0.015
106585	L2	43.3	0.033
106585	2MK3	15.5	0.024
106585	K2	24.3	0.109
106585	M8	184.7	0.005
106585	MS4	4.3	0.031
106586	M2	359.8	1.075
106586	S2	358.8	0.346
106586	N2	326.3	0.138
106586	K1	182.4	0.204
106586	M4	315.1	0.047
106586	O1	173.6	0.125
106586	M6	229.5	0.066
106586	MK3	76.6	0.012
106586	S4	338.2	0.016
106586	MN4	281.3	0.012
106586	S6	76	0.003
106586	2N2	32.5	0.068
106586	OO1	312.6	0.013
106586	M1	147.5	0.026
106586	Q1	169.4	0.039
106586	2Q1	112.9	0.025
106586	P1	188.3	0.059
106586	2SM2	286.3	0.026
106586	M3	243.7	0.013
106586	L2	43.6	0.039
106586	2MK3	17.3	0.031
106586	K2	33	0.125
106586	M8	181.5	0.005
106586	MS4	6.3	0.019
106587	M2	1.9	1.344
106587	S2	3.6	0.361
106587	N2	350.8	0.127
106587	K1	213.5	0.236
106587	M4	239.3	0.043
106587	O1	193.7	0.163
106587	M6	242.4	0.072
106587	MK3	35.3	0.012
106587	S4	348.7	0.011
106587	MN4	119.9	0.014
106587	S6	135.3	0.013
106587	2N2	335.6	0.144
106587	OO1	320.9	0.006
106587	M1	347.7	0.038
106587	J1	205.5	0.018
106587	Q1	178.8	0.041
106587	2Q1	207.2	0.034
106587	P1	217.6	0.098
106587	2SM2	252.7	0.041
106587	M3	138.9	0.021
106587	L2	2.9	0.056
106587	2MK3	0.5	0.028
106587	K2	67.3	0.117
106587	M8	102.5	0.005
106587	MS4	269.1	0.022
106588	M2	2	1.638
106588	S2	5	0.433
106588	N2	352.9	0.153
106588	K1	213.6	0.288
106588	M4	241.7	0.051
106588	O1	193.4	0.193
106588	M6	245.6	0.087
106588	MK3	23.1	0.021
106588	S4	11.3	0.01
106588	MN4	115	0.021
106588	S6	127.6	0.015
106588	2N2	334.8	0.176
106588	OO1	27.7	0.006
106588	M1	348.3	0.045
106588	J1	203.3	0.017
106588	Q1	176.7	0.045
106588	2Q1	204.5	0.041
106588	P1	217.4	0.117
106588	2SM2	250.7	0.053
106588	M3	141	0.024
106588	L2	2.5	0.07
106588	2MK3	358.4	0.039
106588	K2	63.7	0.14
106588	M8	121.5	0.008
106588	MS4	268.4	0.027
106589	M2	358.3	0.946
106589	S2	7.6	0.286
106589	N2	341.2	0.091
106589	K1	205.4	0.15
106589	M4	242	0.022
106589	O1	184.6	0.11
106589	M6	228	0.044
106589	MK3	36.8	0.007
106589	S4	25.2	0.002
106589	MN4	96.1	0.007
106589	S6	144.7	0.006
106589	2N2	335	0.098
106589	OO1	350	0.008
106589	M1	344.5	0.024
106589	J1	219.7	0.014
106589	Q1	182.1	0.032
106589	2Q1	215.8	0.02
106589	P1	214	0.058
106589	2SM2	251.7	0.03
106589	M3	148	0.012
106589	L2	357.2	0.043
106589	2MK3	12.5	0.023
106589	K2	27.6	0.034
106589	M8	81.8	0.003
106589	MS4	300.1	0.011
106590	M2	359	1.187
106590	S2	7.6	0.356
106590	N2	340.1	0.109
106590	K1	205	0.186
106590	M4	247.6	0.018
106590	O1	185.9	0.129
106590	M6	234.5	0.053
106590	MK3	356	0.013
106590	S4	50.4	0.005
106590	MN4	70.4	0.017
106590	S6	132.2	0.009
106590	2N2	335.3	0.128
106590	OO1	23.4	0.01
106590	M1	350.8	0.033
106590	J1	227.5	0.018
106590	Q1	171.7	0.039
106590	2Q1	213	0.021
106590	P1	211	0.067
106590	2SM2	251.5	0.04
106590	M3	138	0.019
106590	L2	356.2	0.058
106590	2MK3	353.3	0.035
106590	K2	24.4	0.042
106590	M8	107.2	0.004
106590	MS4	298.6	0.012
106591	M2	43.3	0.568
106591	S2	37.8	0.221
106591	N2	27	0.071
106591	K1	222.2	0.107
106591	M4	333.4	0.026
106591	O1	210.6	0.128
106591	M6	51.4	0.009
106591	MK3	148.7	0.012
106591	S4	301.4	0.009
106591	MN4	280.8	0.017
106591	S6	317.6	0.002
106591	2N2	64.9	0.031
106591	OO1	154	0.021
106591	M1	0	0.015
106591	J1	236.9	0.012
106591	Q1	198.1	0.031
106591	2Q1	207.3	0.03
106591	2SM2	294.1	0.03
106591	M3	250.8	0.009
106591	L2	46.4	0.011
106591	2MK3	140.5	0.019
106591	K2	125.8	0.076
106591	M8	23.9	0.004
106591	MS4	333.4	0.029
106592	M2	45.3	0.682
106592	S2	36	0.266
106592	N2	11.4	0.084
106592	K1	224.8	0.13
106592	M4	335.1	0.027
106592	O1	214.3	0.134
106592	M6	65.1	0.015
106592	MK3	151.9	0.028
106592	S4	304.2	0.011
106592	MN4	237.7	0.016
106592	S6	297.2	0.007
106592	2N2	58.6	0.064
106592	OO1	180.1	0.039
106592	M1	242.3	0.008
106592	J1	206.9	0.028
106592	Q1	192.2	0.038
106592	2Q1	226.9	0.029
106592	2SM2	310.5	0.034
106592	M3	212	0.025
106592	L2	85.3	0.026
106592	2MK3	144.6	0.036
106592	K2	126.7	0.096
106592	M8	13.6	0.005
106592	MS4	324.6	0.032
106593	M2	41.9	1.11
106593	S2	68	0.301
106593	N2	31.1	0.101
106593	K1	279.9	0.235
106593	M4	264.5	0.051
106593	O1	268.1	0.181
106593	M6	340	0.059
106593	MK3	42.9	0.031
106593	S4	285	0.005
106593	MN4	210.7	0.032
106593	S6	260.3	0.009
106593	2N2	353.3	0.117
106593	OO1	341.9	0.014
106593	M1	16.9	0.034
106593	J1	241.7	0.022
106593	Q1	239.7	0.048
106593	2Q1	229.9	0.031
106593	P1	287.8	0.06
106593	2SM2	301.2	0.028
106593	M3	168.9	0.011
106593	L2	39.7	0.046
106593	2MK3	28.7	0.047
106593	K2	147.2	0.028
106593	M8	321.2	0.003
106593	MS4	271	0.028
106594	M2	41.9	1.362
106594	S2	70.6	0.385
106594	N2	28	0.112
106594	K1	279	0.279
106594	M4	263.5	0.051
106594	O1	271	0.214
106594	M6	342.5	0.071
106594	MK3	41.4	0.052
106594	S4	271.5	0.006
106594	MN4	200.9	0.04
106594	S6	270.4	0.013
106594	2N2	351.5	0.148
106594	OO1	330.6	0.016
106594	M1	16.2	0.044
106594	J1	236	0.02
106594	Q1	231.1	0.051
106594	2Q1	218.6	0.037
106594	P1	289.1	0.066
106594	2SM2	294.1	0.032
106594	M3	183	0.012
106594	L2	38.1	0.064
106594	2MK3	27.8	0.066
106594	M8	288.2	0.005
106594	MS4	258.8	0.035
106595	M2	11.8	0.165
106595	S2	45.8	0.045
106595	N2	336.1	0.02
106595	K1	270.9	0.066
106595	M4	262.2	0.008
106595	O1	266	0.037
106595	M6	179	0.002
106595	MK3	54.8	0.002
106595	S4	154.8	0.003
106595	MN4	189.1	0.006
106595	S6	125.2	0.002
106595	2N2	336.2	0.004
106595	OO1	62	0.02
106595	M1	23.5	0.013
106595	J1	294.4	0.005
106595	Q1	312.8	0.005
106595	2Q1	175.2	0.012
106595	P1	261.6	0.027
106595	2SM2	285.7	0.004
106595	M3	20	0.001
106595	L2	46.2	0.005
106595	2MK3	123	0.003
106595	K2	8.6	0.026
106595	M8	146.2	0.001
106595	MS4	296.5	0.004
106596	M2	8.8	0.22
106596	S2	49.7	0.057
106596	N2	353.8	0.021
106596	K1	272.2	0.061
106596	M4	241.8	0.013
106596	O1	277.5	0.059
106596	M6	174	0.004
106596	MK3	57.2	0.009
106596	S4	40.9	0.002
106596	MN4	171.5	0.007
106596	S6	31.4	0.002
106596	2N2	341.1	0.022
106596	OO1	312.4	0.008
106596	M1	333.2	0.006
106596	J1	254.5	0.007
106596	Q1	266.8	0.009
106596	2Q1	198.1	0.008
106596	P1	260.9	0.015
106596	2SM2	235.7	0.008
106596	M3	110.9	0.005
106596	L2	15.5	0.002
106596	2MK3	69.8	0.008
106596	K2	18	0.016
106596	MS4	250.1	0.012
106597	M2	38.4	1.394
106597	S2	65.5	0.349
106597	N2	1.2	0.185
106597	K1	284.9	0.305
106597	M4	342.8	0.025
106597	O1	277.1	0.21
106597	M6	316.9	0.075
106597	MK3	65.4	0.032
106597	S4	345.5	0.02
106597	MN4	190.5	0.005
106597	S6	176.3	0.008
106597	2N2	25.3	0.095
106597	OO1	343.5	0.022
106597	M1	235	0.028
106597	J1	15.4	0.024
106597	Q1	253.5	0.081
106597	2Q1	146.9	0.054
106597	P1	332.8	0.068
106597	2SM2	353.4	0.01
106597	M3	28	0.01
106597	L2	109.1	0.044
106597	2MK3	26	0.074
106597	K2	54.6	0.102
106597	M8	334.1	0.012
106597	MS4	263	0.023
106598	M2	0.3	2.233
106598	S2	33.3	0.297
106598	N2	337.7	0.571
106598	K1	177.4	0.333
106598	M4	47	0.075
106598	O1	183.6	0.226
106598	M6	210.8	0.177
106598	MK3	349.1	0.051
106598	S4	253.4	0.02
106598	MN4	22.8	0.026
106598	S6	203.2	0.025
106598	2N2	288.6	0.073
106598	OO1	213.4	0.021
106598	M1	284.5	0.017
106598	Q1	198.6	0.05
106598	2Q1	259.3	0.012
106598	P1	164	0.06
106598	2SM2	259.4	0.018
106598	M3	270.8	0.022
106598	L2	359.1	0.185
106598	2MK3	349.7	0.087
106598	K2	28.3	0.088
106598	M8	212.4	0.017
106598	MS4	68.7	0.038
106599	M2	0.7	2.56
106599	S2	34.1	0.345
106599	N2	337.8	0.653
106599	K1	177.4	0.382
106599	M4	38.5	0.096
106599	O1	184.7	0.265
106599	M6	213.5	0.198
106599	MK3	352.8	0.052
106599	S4	254.4	0.02
106599	MN4	11.7	0.034
106599	S6	204	0.029
106599	2N2	283.8	0.083
106599	OO1	216.5	0.024
106599	M1	279.9	0.016
106599	J1	129.3	0.003
106599	Q1	194.8	0.057
106599	2Q1	263.8	0.015
106599	P1	170.2	0.071
106599	2SM2	256.2	0.026
106599	M3	279	0.029
106599	L2	0	0.215
106599	2MK3	351.2	0.093
106599	K2	31.2	0.107
106599	M8	222.1	0.019
106599	MS4	65.6	0.047
106600	M2	1	2.717
106600	S2	34.5	0.369
106600	N2	337.6	0.693
106600	K1	176.7	0.409
106600	M4	42	0.101
106600	O1	185.1	0.281
106600	M6	214.7	0.2
106600	MK3	352.8	0.057
106600	S4	253.3	0.019
106600	MN4	17.4	0.035
106600	S6	202.6	0.029
106600	2N2	281.3	0.089
106600	OO1	217.2	0.025
106600	M1	279.4	0.015
106600	J1	129.8	0.005
106600	Q1	194.2	0.06
106600	2Q1	267.8	0.016
106600	P1	176.4	0.072
106600	2SM2	253.1	0.03
106600	M3	280.6	0.032
106600	L2	359.7	0.227
106600	2MK3	351	0.096
106600	K2	33	0.116
106600	M8	236.3	0.021
106600	MS4	65.5	0.05
106601	M2	1.5	2.927
106601	S2	33.3	0.405
106601	N2	337.5	0.747
106601	K1	175.2	0.451
106601	M4	52.5	0.098
106601	O1	185.2	0.303
106601	M6	216.6	0.197
106601	MK3	352	0.069
106601	S4	250.6	0.019
106601	MN4	29.6	0.034
106601	S6	201	0.029
106601	2N2	281.1	0.099
106601	OO1	215	0.026
106601	M1	282.9	0.02
106601	J1	143.9	0.007
106601	Q1	194	0.063
106601	2Q1	267	0.017
106601	P1	188.1	0.071
106601	2SM2	251.5	0.03
106601	M3	271.3	0.037
106601	L2	359.6	0.243
106601	2MK3	352.4	0.105
106601	K2	30.4	0.133
106601	M8	248.7	0.02
106601	MS4	71.4	0.049
106602	M2	2.5	1.57
106602	S2	23.6	0.19
106602	N2	339.6	0.371
106602	K1	179.6	0.235
106602	M4	7.7	0.116
106602	O1	190.8	0.174
106602	M6	214	0.116
106602	MK3	50.8	0.017
106602	S4	254.7	0.01
106602	MN4	344.8	0.048
106602	S6	212.9	0.015
106602	2N2	258	0.032
106602	OO1	207.4	0.013
106602	M1	13.3	0.006
106602	J1	36.4	0.007
106602	Q1	205.8	0.04
106602	2Q1	277.2	0.01
106602	P1	194.8	0.056
106602	2SM2	303.6	0.018
106602	M3	240.9	0.017
106602	L2	9.2	0.143
106602	2MK3	2.9	0.044
106602	K2	10.8	0.062
106602	M8	231.7	0.021
106602	MS4	55.1	0.036
106603	M2	2.6	1.754
106603	S2	22.8	0.213
106603	N2	339.8	0.417
106603	K1	179.7	0.264
106603	M4	6.8	0.134
106603	O1	190.1	0.199
106603	M6	216.3	0.128
106603	MK3	53.9	0.017
106603	S4	251.8	0.013
106603	MN4	344.5	0.057
106603	S6	211.3	0.017
106603	2N2	256.8	0.04
106603	OO1	208.1	0.014
106603	M1	350.9	0.006
106603	J1	32	0.007
106603	Q1	203.9	0.044
106603	2Q1	272.3	0.01
106603	P1	190.7	0.064
106603	2SM2	309.7	0.021
106603	M3	241.5	0.018
106603	L2	8.9	0.157
106603	2MK3	4.4	0.048
106603	K2	7.2	0.072
106603	M8	224.8	0.024
106603	MS4	54	0.043
106604	M2	1	1.784
106604	S2	24.4	0.253
106604	N2	339	0.425
106604	K1	177.8	0.275
106604	M4	19.9	0.16
106604	O1	185.5	0.212
106604	M6	221.3	0.126
106604	MK3	335.2	0.017
106604	S4	264.1	0.014
106604	MN4	1.1	0.071
106604	S6	224.3	0.014
106604	2N2	282.2	0.018
106604	OO1	221.3	0.01
106604	M1	343.4	0.009
106604	J1	98.2	0.008
106604	Q1	196.8	0.035
106604	2Q1	288.8	0.007
106604	P1	173.4	0.072
106604	2SM2	320.9	0.007
106604	M3	245.5	0.015
106604	L2	8.2	0.14
106604	2MK3	354.8	0.051
106604	K2	17.5	0.082
106604	M8	227.8	0.035
106604	MS4	61.6	0.041
106605	M2	5.1	1.101
106605	S2	31.3	0.134
106605	N2	343.8	0.219
106605	K1	184.8	0.143
106605	M4	35	0.103
106605	O1	186.6	0.122
106605	M6	213	0.075
106605	S4	220.6	0.011
106605	NU2	346.7	0.043
106605	S6	276.5	0.008
106605	2N2	322.6	0.029
106605	OO1	182.8	0.005
106605	LDA2	17.2	0.008
106605	M1	185.6	0.009
106605	J1	183.8	0.01
106605	RHO1	187.3	0.005
106605	Q1	187.4	0.024
106605	T2	30.1	0.008
106605	R2	32.3	0.001
106605	2Q1	188.3	0.003
106605	P1	184.8	0.047
106605	L2	343.9	0.031
106605	K2	33.4	0.037
106605	M8	265.5	0.024
106606	M2	4.2	1.327
106606	S2	32.9	0.172
106606	N2	342.5	0.253
106606	K1	184	0.174
106606	M4	42.3	0.101
106606	O1	184.3	0.15
106606	M6	210.2	0.089
106606	S4	261.4	0.005
106606	NU2	345.5	0.049
106606	S6	261.4	0.013
106606	2N2	320.9	0.034
106606	OO1	183.6	0.006
106606	LDA2	17.5	0.009
106606	M1	184.1	0.011
106606	J1	183.8	0.012
106606	RHO1	184.3	0.006
106606	Q1	184.3	0.029
106606	T2	31.7	0.01
106606	R2	34	0.001
106606	2Q1	184.5	0.004
106606	P1	183.9	0.058
106606	L2	342.6	0.036
106606	K2	35.2	0.047
106606	M8	284.4	0.024
106607	M2	2.9	1.41
106607	S2	33.2	0.204
106607	N2	340.7	0.27
106607	K1	180.9	0.189
106607	M4	51.9	0.089
106607	O1	180.5	0.166
106607	M6	202.7	0.089
106607	S4	309	0.006
106607	NU2	343.7	0.052
106607	S6	230.7	0.013
106607	2N2	318.6	0.036
106607	OO1	181.2	0.007
106607	LDA2	16.9	0.01
106607	M1	180.6	0.012
106607	J1	181.1	0.013
106607	RHO1	180.3	0.006
106607	Q1	180.2	0.032
106607	T2	31.9	0.012
106607	R2	34.4	0.002
106607	2Q1	180	0.004
106607	P1	180.8	0.063
106607	L2	340.7	0.039
106607	K2	35.6	0.056
106607	M8	297.1	0.019
106608	M2	5.7	0.582
106608	S2	40.4	0.07
106608	N2	325.4	0.119
106608	K1	178.6	0.085
106608	M4	318.2	0.048
106608	O1	181.6	0.054
106608	M6	222.1	0.07
106608	MK3	70.1	0.01
106608	S4	190.4	0.006
106608	MN4	268	0.02
106608	S6	156.7	0.002
106608	2N2	343.9	0.019
106608	OO1	154.7	0.006
106608	M1	14.3	0.003
106608	J1	201.5	0.006
106608	Q1	148	0.014
106608	2Q1	38.4	0.002
106608	P1	175.8	0.028
106608	2SM2	44.4	0.008
106608	M3	260.6	0.008
106608	L2	45.6	0.045
106608	2MK3	25.5	0.015
106608	K2	338.2	0.019
106608	M8	220.1	0.004
106608	MS4	347.6	0.018
106609	M2	5.5	0.606
106609	S2	37.3	0.073
106609	N2	327.8	0.127
106609	K1	179	0.087
106609	M4	317.5	0.049
106609	O1	178.5	0.057
106609	M6	222.2	0.075
106609	MK3	45.4	0.011
106609	S4	185.5	0.007
106609	MN4	274.2	0.019
106609	S6	166.1	0.001
106609	2N2	330.7	0.022
106609	OO1	157.9	0.007
106609	M1	24.9	0.003
106609	J1	194.7	0.008
106609	Q1	148.2	0.015
106609	2Q1	61.9	0.002
106609	P1	175.6	0.03
106609	2SM2	54.9	0.009
106609	M3	257.2	0.009
106609	L2	47.7	0.043
106609	2MK3	22.4	0.016
106609	K2	356.9	0.023
106609	M8	203.6	0.006
106609	MS4	357.7	0.017
106610	M2	5.2	0.621
106610	S2	35.8	0.077
106610	N2	335	0.146
106610	K1	185.3	0.092
106610	M4	309.8	0.044
106610	O1	171.9	0.056
106610	M6	217.6	0.088
106610	MK3	357.4	0.023
106610	S4	171.7	0.014
106610	MN4	304	0.013
106610	S6	117.4	0.004
106610	2N2	290.4	0.042
106610	OO1	172.4	0.011
106610	M1	21.2	0.006
106610	J1	186.6	0.014
106610	Q1	154.1	0.019
106610	2Q1	164.4	0.004
106610	P1	199.2	0.028
106610	2SM2	79.1	0.014
106610	M3	251.7	0.007
106610	L2	50.1	0.031
106610	2MK3	359.6	0.02
106610	K2	11.6	0.043
106610	M8	171.4	0.012
106610	MS4	42.8	0.021
106611	M2	169.6	0.092
106611	S2	232.7	0.125
106611	N2	155.8	0.048
106611	K1	81.4	0.137
106611	M4	300.5	0.034
106611	O1	240.3	0.035
106611	M6	103.3	0.004
106611	MK3	197.1	0.009
106611	S4	93.3	0.019
106611	MN4	238.5	0.021
106611	S6	182.2	0.002
106611	2N2	47.9	0.015
106611	OO1	251.4	0.018
106611	M1	3.7	0.008
106611	J1	167.9	0.017
106611	Q1	226.6	0.009
106611	2Q1	268.6	0.013
106611	P1	213.6	0.091
106611	2SM2	121.9	0.036
106611	M3	18.9	0.01
106611	L2	91.9	0.075
106611	2MK3	166.8	0.033
106611	K2	326	0.116
106611	M8	64	0.003
106611	MS4	352.2	0.01
106612	M2	172.5	0.164
106612	S2	258.9	0.212
106612	N2	168.9	0.093
106612	K1	83.2	0.216
106612	M4	320.6	0.06
106612	O1	250.6	0.069
106612	M6	226.6	0.004
106612	MK3	287.7	0.023
106612	S4	88.5	0.025
106612	MN4	205.2	0.033
106612	S6	348.3	0.008
106612	2N2	90	0.031
106612	OO1	217.9	0.012
106612	M1	30.6	0.01
106612	J1	171.6	0.023
106612	Q1	242.8	0.022
106612	2Q1	254.5	0.054
106612	P1	231.1	0.098
106612	2SM2	158.8	0.043
106612	M3	316.7	0.004
106612	L2	115.4	0.125
106612	2MK3	161.3	0.062
106612	K2	359.3	0.208
106612	M8	80.6	0.006
106612	MS4	83.7	0.011
106613	M2	167.5	0.226
106613	S2	255	0.209
106613	N2	162.9	0.107
106613	K1	83.8	0.286
106613	M4	334.1	0.062
106613	O1	260.7	0.084
106613	M6	248.1	0.012
106613	MK3	296.5	0.056
106613	S4	100.7	0.016
106613	MN4	205.3	0.017
106613	S6	28.2	0.015
106613	2N2	75.6	0.055
106613	OO1	182.2	0.013
106613	M1	47.3	0.018
106613	J1	131.8	0.015
106613	Q1	279.4	0.043
106613	2Q1	241.3	0.081
106613	P1	223.3	0.133
106613	2SM2	182.9	0.044
106613	M3	154.9	0.007
106613	L2	118.2	0.125
106613	2MK3	164.4	0.067
106613	K2	5.9	0.209
106613	M8	83.8	0.004
106613	MS4	77	0.021
106614	M2	104.6	0.314
106614	S2	118	0.187
106614	N2	99.3	0.095
106614	K1	63.6	0.16
106614	M4	253	0.037
106614	O1	272.2	0.094
106614	M6	74.9	0.007
106614	MK3	169.3	0.025
106614	S4	236.4	0.005
106614	MN4	198.4	0.034
106614	S6	95.9	0.007
106614	2N2	11.9	0.033
106614	OO1	281.6	0.005
106614	M1	80.6	0.031
106614	J1	174.7	0.073
106614	Q1	215.2	0.066
106614	2Q1	237	0.044
106614	P1	268.2	0.086
106614	2SM2	119.4	0.062
106614	M3	40.1	0.036
106614	L2	72.8	0.111
106614	2MK3	56.2	0.014
106614	M8	70.2	0.005
106614	MS4	320.3	0.022
106615	M2	102.6	0.42
106615	S2	118.9	0.234
106615	N2	112.1	0.083
106615	K1	58.2	0.245
106615	M4	234.4	0.058
106615	O1	265.5	0.131
106615	M6	57.7	0.01
106615	MK3	201.9	0.052
106615	S4	286.4	0.023
106615	MN4	190.4	0.029
106615	S6	121.2	0.007
106615	2N2	28	0.081
106615	OO1	315.8	0.023
106615	M1	79.6	0.033
106615	J1	172.7	0.076
106615	Q1	208.5	0.085
106615	2Q1	227	0.065
106615	P1	252.4	0.115
106615	2SM2	142.1	0.076
106615	M3	61.1	0.042
106615	L2	78.9	0.171
106615	2MK3	56.5	0.036
106615	M8	228.4	0.002
106615	MS4	307.8	0.032
106616	M2	96.9	0.538
106616	S2	117.7	0.274
106616	N2	126.1	0.085
106616	K1	69	0.371
106616	M4	227.3	0.093
106616	O1	261.2	0.199
106616	M6	12.1	0.006
106616	MK3	182.4	0.071
106616	S4	253.6	0.032
106616	MN4	227.2	0.018
106616	S6	126.4	0.022
106616	2N2	34.2	0.128
106616	OO1	73.6	0.032
106616	M1	76.4	0.046
106616	J1	180.6	0.103
106616	Q1	211.9	0.085
106616	2Q1	228.3	0.133
106616	P1	231.9	0.236
106616	2SM2	173.8	0.068
106616	M3	70.1	0.032
106616	L2	79.9	0.163
106616	2MK3	21.9	0.09
106616	M8	313.4	0.01
106616	MS4	292.3	0.056
106617	M2	40.9	0.492
106617	S2	117.6	0.226
106617	N2	31.2	0.135
106617	K1	3.3	0.134
106617	M4	118.7	0.035
106617	O1	296.7	0.059
106617	M6	47.6	0.004
106617	MK3	335	0.019
106617	S4	297.6	0.01
106617	MN4	61	0.015
106617	S6	126.2	0.011
106617	2N2	350.7	0.05
106617	OO1	103.3	0.04
106617	M1	216.3	0.01
106617	J1	242.1	0.045
106617	Q1	255.4	0.035
106617	2Q1	359.1	0.033
106617	2SM2	151.5	0.02
106617	M3	249.5	0.022
106617	L2	48.7	0.064
106617	2MK3	69.8	0.018
106617	K2	282.2	0.128
106617	M8	126	0.012
106617	MS4	184.9	0.026
106618	M2	47.7	0.657
106618	S2	113.7	0.308
106618	N2	34.6	0.2
106618	K1	15.1	0.165
106618	M4	126.1	0.096
106618	O1	300.3	0.07
106618	M6	184	0.007
106618	MK3	353.8	0.02
106618	S4	242	0.016
106618	MN4	92.5	0.059
106618	S6	102.6	0.007
106618	2N2	15.5	0.062
106618	OO1	98.1	0.058
106618	M1	325.8	0.013
106618	J1	249.7	0.049
106618	Q1	265.5	0.059
106618	2Q1	10.2	0.038
106618	2SM2	187	0.024
106618	M3	296.4	0.038
106618	L2	70.4	0.065
106618	2MK3	35.4	0.03
106618	K2	277.7	0.122
106618	M8	49.4	0.007
106618	MS4	160.4	0.071
106619	M2	50.3	0.735
106619	S2	116	0.37
106619	N2	37.5	0.238
106619	K1	20.3	0.196
106619	M4	132.9	0.121
106619	O1	321.6	0.081
106619	M6	227.6	0.015
106619	MK3	96	0.019
106619	S4	226.9	0.017
106619	MN4	88.4	0.06
106619	S6	133.2	0.007
106619	2N2	3.1	0.06
106619	OO1	93.2	0.072
106619	M1	8.7	0.011
106619	J1	245	0.06
106619	Q1	267.6	0.078
106619	2Q1	8.1	0.04
106619	2SM2	208.5	0.03
106619	M3	318.5	0.043
106619	L2	53.6	0.096
106619	2MK3	49.6	0.032
106619	K2	276.2	0.158
106619	M8	25.8	0.005
106619	MS4	164.8	0.098
106620	M2	332.3	0.111
106620	S2	349.1	0.044
106620	N2	351	0.032
106620	K1	159	0.058
106620	M4	162.5	0.01
106620	O1	111.8	0.033
106620	M6	4.3	0.003
106620	MK3	61.7	0.005
106620	S4	35.5	0.003
106620	MN4	120.2	0.002
106620	S6	99	0.003
106620	2N2	66.8	0.005
106620	OO1	144.4	0.005
106620	M1	159.2	0.006
106620	J1	102.4	0.005
106620	Q1	142.3	0.014
106620	2Q1	265.9	0.008
106620	2SM2	208.5	0.002
106620	L2	200.1	0.001
106620	2MK3	7.8	0.004
106620	M8	318.6	0.001
106620	MS4	27.1	0.001
106621	M2	345.2	0.172
106621	S2	2.5	0.074
106621	N2	359.9	0.045
106621	K1	166.9	0.098
106621	M4	212.6	0.011
106621	O1	115.5	0.045
106621	M6	42.8	0.004
106621	MK3	109.3	0.009
106621	S4	55.5	0.003
106621	MN4	178.1	0.001
106621	S6	156.9	0.006
106621	2N2	41.6	0.016
106621	OO1	69.4	0.004
106621	M1	154	0.007
106621	J1	144.1	0.013
106621	Q1	139.7	0.014
106621	2Q1	284	0.004
106621	2SM2	230.9	0.008
106621	M3	50.1	0.004
106621	L2	108	0.006
106621	2MK3	57.7	0.008
106621	M8	198.5	0.002
106621	MS4	216.7	0.002
106622	M2	338.9	0.172
106622	S2	358.2	0.084
106622	N2	353.4	0.023
106622	K1	162.9	0.061
106622	M4	325.8	0.004
106622	O1	150.5	0.057
106622	M6	30.3	0.006
106622	MK3	240.7	0.008
106622	S4	316.8	0.007
106622	MN4	64.2	0.001
106622	S6	114.8	0.007
106622	2N2	358.2	0.004
106622	OO1	126.7	0.029
106622	M1	324.1	0.004
106622	J1	158.8	0.013
106622	Q1	235.7	0.017
106622	2Q1	79.7	0.01
106622	2SM2	60	0.005
106622	M3	120.3	0.013
106622	L2	258.8	0.005
106622	2MK3	168.3	0.003
106622	M8	238.2	0.003
106622	MS4	28.3	0.008
106623	M2	358.4	0.49
106623	S2	3.7	0.292
106623	N2	358.2	0.056
106623	K1	21.1	0.277
106623	M4	213.9	0.034
106623	O1	358.3	0.129
106623	M6	161	0.012
106623	MK3	207.8	0.024
106623	S4	257.3	0.024
106623	MN4	191.4	0.008
106623	S6	142.3	0.007
106623	2N2	15	0.023
106623	OO1	354.6	0.045
106623	M1	37.5	0.019
106623	J1	183.9	0.065
106623	Q1	187	0.004
106623	2Q1	344.5	0.063
106623	2SM2	53.8	0.025
106623	M3	104.1	0.019
106623	L2	179.7	0.051
106623	2MK3	159	0.015
106623	K2	52.2	0.139
106623	M8	339.6	0.005
106623	MS4	241.3	0.032
106624	M2	359.6	0.452
106624	S2	359.9	0.429
106624	N2	330.1	0.034
106624	K1	31	0.357
106624	M4	217.6	0.031
106624	O1	10.4	0.208
106624	M6	127.3	0.006
106624	MK3	61.9	0.011
106624	S4	90.8	0.007
106624	MN4	192.9	0.012
106624	S6	302	0.005
106624	2N2	347.4	0.012
106624	OO1	16	0.075
106624	M1	24.5	0.007
106624	J1	141.3	0.047
106624	Q1	156	0.054
106624	2Q1	339.2	0.03
106624	2SM2	4.7	0.033
106624	M3	12.2	0.006
106624	L2	172.4	0.057
106624	2MK3	42.9	0.015
106624	K2	70.9	0.241
106624	M8	14.9	0.005
106624	MS4	254.4	0.012
106625	M2	0.6	0.449
106625	S2	0.3	0.428
106625	N2	303.4	0.028
106625	K1	28.2	0.348
106625	M4	223	0.03
106625	O1	15	0.217
106625	M6	122.7	0.007
106625	MK3	47.7	0.011
106625	S4	137.9	0.001
106625	MN4	181.2	0.016
106625	S6	292.2	0.005
106625	2N2	347.1	0.016
106625	OO1	18.8	0.075
106625	M1	18.9	0.009
106625	J1	150.4	0.058
106625	Q1	161.7	0.061
106625	2Q1	320.2	0.038
106625	2SM2	351.6	0.038
106625	M3	309.6	0.003
106625	L2	167.9	0.049
106625	2MK3	50.6	0.015
106625	K2	69.4	0.23
106625	M8	5.7	0.007
106625	MS4	266.8	0.017
106626	M2	132.9	0.333
106626	S2	164.5	0.168
106626	N2	111.7	0.128
106626	K1	311.5	0.429
106626	M4	65.5	0.024
106626	O1	303.9	0.152
106626	M6	24.6	0.005
106626	MK3	250.2	0.024
106626	S4	144.1	0.006
106626	MN4	2	0.006
106626	S6	301.4	0.002
106626	2N2	142.3	0.037
106626	OO1	84.9	0.004
106626	M1	321.2	0.013
106626	J1	85.2	0.01
106626	Q1	197.7	0.031
106626	2Q1	99	0.024
106626	P1	285.4	0.215
106626	2SM2	259.7	0.014
106626	M3	80.8	0.015
106626	L2	222.1	0.008
106626	2MK3	145.9	0.017
106626	K2	146.5	0.062
106626	M8	6.1	0.003
106626	MS4	89.9	0.015
106627	M2	139	0.408
106627	S2	175.5	0.227
106627	N2	129.5	0.148
106627	K1	320.5	0.511
106627	M4	94.2	0.046
106627	O1	314.1	0.222
106627	M6	13.3	0.01
106627	MK3	264	0.033
106627	S4	156.3	0.016
106627	MN4	67.8	0.02
106627	S6	130.2	0.007
106627	2N2	147.5	0.058
106627	OO1	266.9	0.027
106627	M1	307.1	0.019
106627	J1	300.2	0.005
106627	Q1	198.1	0.046
106627	2Q1	116	0.053
106627	P1	289.6	0.222
106627	2SM2	222.4	0.018
106627	M3	210.4	0.007
106627	L2	247.5	0.029
106627	2MK3	148.4	0.005
106627	K2	159.4	0.063
106627	M8	241.4	0.002
106627	MS4	122.2	0.043
106628	M2	143.5	0.426
106628	S2	181.8	0.254
106628	N2	132.7	0.154
106628	K1	320	0.478
106628	M4	105.7	0.049
106628	O1	315.6	0.232
106628	M6	12.5	0.015
106628	MK3	274.1	0.042
106628	S4	144.5	0.025
106628	MN4	62.4	0.026
106628	S6	110.2	0.005
106628	2N2	136.9	0.073
106628	OO1	266.3	0.022
106628	M1	321	0.006
106628	J1	288.6	0.039
106628	Q1	214.4	0.071
106628	2Q1	129.6	0.031
106628	P1	273.5	0.191
106628	2SM2	183.1	0.017
106628	M3	200.3	0.017
106628	L2	242.1	0.039
106628	2MK3	144.6	0.008
106628	K2	144.6	0.064
106628	M8	232.6	0.008
106628	MS4	129.6	0.05
106629	M2	355.9	0.775
106629	S2	13.1	0.433
106629	N2	356.7	0.163
106629	K1	324	0.169
106629	M4	205.1	0.061
106629	O1	322.4	0.04
106629	M6	249.4	0.021
106629	MK3	100.5	0.035
106629	S4	83.2	0.005
106629	MN4	225.1	0.022
106629	S6	248	0.002
106629	2N2	309.9	0.016
106629	OO1	312.2	0.014
106629	M1	22.5	0.025
106629	J1	147.2	0.076
106629	Q1	45.3	0.028
106629	2Q1	348.8	0.026
106629	2SM2	318.2	0.013
106629	M3	75.6	0.013
106629	L2	106.1	0.021
106629	2MK3	201.5	0.011
106629	K2	45.7	0.188
106629	M8	57.2	0.014
106629	MS4	252.5	0.041
106630	M2	6.2	0.908
106630	S2	25.3	0.459
106630	N2	16.7	0.179
106630	K1	333.5	0.264
106630	M4	153	0.05
106630	O1	353.3	0.106
106630	M6	272.7	0.019
106630	MK3	90.6	0.024
106630	S4	131.9	0.01
106630	MN4	179.2	0.018
106630	S6	23.8	0.003
106630	2N2	67.9	0.025
106630	OO1	14.4	0.023
106630	M1	359.7	0.024
106630	J1	162.5	0.082
106630	Q1	88.3	0.034
106630	2Q1	324.2	0.07
106630	2SM2	290.5	0.025
106630	M3	29.4	0.009
106630	L2	127.2	0.045
106630	2MK3	108.7	0.009
106630	K2	36.5	0.2
106630	M8	56.1	0.012
106630	MS4	176.7	0.032
106631	M2	6	0.928
106631	S2	24.7	0.479
106631	N2	22.2	0.183
106631	K1	327.4	0.274
106631	M4	127.9	0.063
106631	O1	354.7	0.133
106631	M6	235.6	0.018
106631	MK3	78.4	0.032
106631	S4	71	0.005
106631	MN4	159.9	0.03
106631	S6	89.2	0.005
106631	2N2	63.3	0.022
106631	OO1	27.2	0.052
106631	M1	344.6	0.024
106631	J1	149.4	0.071
106631	Q1	82.7	0.055
106631	2Q1	308.2	0.076
106631	2SM2	290.3	0.034
106631	M3	321.4	0.011
106631	L2	128.6	0.068
106631	2MK3	93.2	0.017
106631	K2	36.8	0.2
106631	M8	347.7	0.003
106631	MS4	141.4	0.039
106632	M2	3.6	0.247
106632	S2	84.5	0.105
106632	N2	23.3	0.076
106632	K1	12	0.166
106632	M4	274.9	0.019
106632	O1	348.3	0.092
106632	M6	203.4	0.006
106632	MK3	281.8	0.004
106632	S4	160.2	0.006
106632	MN4	247.6	0.009
106632	S6	110.6	0.004
106632	2N2	119.2	0.018
106632	OO1	327	0.017
106632	M1	273.5	0.009
106632	J1	249.9	0.046
106632	Q1	272.1	0.026
106632	2Q1	118.1	0.018
106632	2SM2	340	0.009
106632	M3	181.3	0.007
106632	L2	182	0.007
106632	2MK3	169.4	0.012
106632	K2	289.4	0.073
106632	M8	180.3	0.003
106632	MS4	73.1	0.01
106633	M2	357.2	0.273
106633	S2	44	0.134
106633	N2	0.1	0.083
106633	K1	22.7	0.183
106633	M4	213.9	0.015
106633	O1	355.9	0.068
106633	M6	209.4	0.009
106633	MK3	172.7	0.02
106633	S4	156	0.006
106633	MN4	273.6	0.006
106633	S6	243.6	0.003
106633	2N2	192.1	0.01
106633	OO1	97.5	0.011
106633	M1	214	0.008
106633	J1	216.3	0.018
106633	Q1	315.8	0.02
106633	2Q1	86.7	0.009
106633	2SM2	80.1	0.021
106633	M3	177.1	0.006
106633	L2	97.5	0.016
106633	2MK3	140.5	0.013
106633	K2	12.1	0.03
106633	M8	38.2	0.003
106633	MS4	325.5	0.001
106634	M2	358.1	0.276
106634	S2	42.8	0.13
106634	N2	4.9	0.082
106634	K1	36.7	0.164
106634	M4	194.6	0.014
106634	O1	4.8	0.055
106634	M6	203.9	0.015
106634	MK3	184.5	0.017
106634	S4	158.3	0.017
106634	MN4	94.1	0.006
106634	S6	14.7	0.001
106634	2N2	166.1	0.014
106634	OO1	59.3	0.018
106634	M1	71.6	0.01
106634	J1	166.6	0.041
106634	Q1	57.7	0.02
106634	2Q1	51.5	0.03
106634	2SM2	121.9	0.02
106634	M3	175.9	0.006
106634	L2	325.3	0.022
106634	2MK3	223.8	0.006
106634	K2	35.3	0.052
106634	M8	167.6	0.002
106634	MS4	18.5	0.004
106635	M2	34.8	0.381
106635	S2	64.7	0.174
106635	N2	35.4	0.07
106635	K1	30.4	0.129
106635	M4	317.8	0.012
106635	O1	10.9	0.069
106635	M6	257.2	0.006
106635	MK3	307.3	0.008
106635	S4	31	0.016
106635	MN4	191.8	0.005
106635	NU2	322.2	0.035
106635	S6	177.5	0.008
106635	MU2	7.4	0.052
106635	2N2	328.6	0.031
106635	OO1	65.6	0.013
106635	LDA2	290.2	0.03
106635	M1	150.8	0.005
106635	J1	45.1	0.007
106635	RHO1	305.5	0.005
106635	Q1	29.3	0.013
106635	2Q1	163.4	0.008
106635	P1	339.4	0.027
106635	2SM2	173.1	0.013
106635	M3	44.7	0.003
106635	2MK3	186.7	0.008
106635	K2	51.1	0.064
106635	M8	233.2	0.005
106635	MS4	343.3	0.013
106636	M2	37.1	0.411
106636	S2	72.3	0.17
106636	N2	47.4	0.104
106636	K1	27.4	0.202
106636	M4	73.9	0.012
106636	O1	3.2	0.075
106636	MK3	282.8	0.005
106636	S4	229.7	0.004
106636	MN4	10.7	0.003
106636	NU2	282.4	0.028
106636	S6	163	0.001
106636	MU2	85.5	0.026
106636	2N2	296.2	0.019
106636	OO1	130.4	0.012
106636	LDA2	318.9	0.025
106636	M1	263.2	0.006
106636	J1	2.9	0.009
106636	RHO1	354.3	0.008
106636	Q1	300.4	0.019
106636	2Q1	253.4	0.006
106636	P1	31.3	0.054
106636	2SM2	315.5	0.01
106636	M3	193	0.006
106636	L2	331.1	0.042
106636	2MK3	226	0.009
106636	K2	32	0.077
106636	M8	12.6	0.002
106636	MS4	133.8	0.006
106637	M2	37.4	0.409
106637	S2	72.8	0.185
106637	N2	40.8	0.102
106637	K1	35.5	0.202
106637	M4	76	0.019
106637	O1	13.3	0.074
106637	M6	31.5	0.007
106637	MK3	326.1	0.01
106637	S4	174.3	0.01
106637	MN4	330.9	0.008
106637	NU2	287	0.023
106637	S6	28.4	0.006
106637	MU2	113.1	0.021
106637	2N2	314.2	0.017
106637	OO1	215	0.013
106637	LDA2	336.5	0.022
106637	M1	161	0.006
106637	J1	46.2	0.007
106637	RHO1	55.8	0.023
106637	Q1	298.9	0.05
106637	2Q1	112.6	0.018
106637	P1	10.2	0.04
106637	2SM2	296.7	0.01
106637	M3	201.3	0.009
106637	L2	5.7	0.03
106637	2MK3	282	0.01
106637	K2	22.6	0.066
106637	M8	131.8	0.002
106637	MS4	107	0.012
106638	M2	359	0.351
106638	S2	45.5	0.16
106638	N2	6.8	0.07
106638	K1	332.3	0.191
106638	M4	85.4	0.004
106638	O1	339.9	0.071
106638	M6	202.1	0.004
106638	MK3	79	0.004
106638	S4	130.5	0.004
106638	MN4	43.7	0.012
106638	S6	282.3	0.007
106638	2N2	13	0.018
106638	OO1	260.9	0.023
106638	M1	52.6	0.005
106638	J1	58	0.045
106638	Q1	226.6	0.007
106638	2Q1	64.1	0.014
106638	P1	341.2	0.09
106638	2SM2	236.8	0.007
106638	M3	313	0.014
106638	L2	239.3	0.026
106638	2MK3	324	0.004
106638	K2	334.4	0.035
106638	M8	53	0.003
106638	MS4	110.9	0.01
106639	M2	15.6	0.341
106639	S2	40.1	0.178
106639	N2	37.3	0.105
106639	K1	4	0.353
106639	M4	247.3	0.016
106639	O1	31.5	0.133
106639	M6	148.8	0.011
106639	MK3	194.1	0.015
106639	S4	5	0.01
106639	MN4	277.8	0.009
106639	S6	131	0.002
106639	2N2	82.5	0.027
106639	OO1	247.1	0.053
106639	M1	157.9	0.034
106639	J1	37.6	0.048
106639	Q1	219.3	0.029
106639	2Q1	282.6	0.043
106639	P1	351.9	0.21
106639	2SM2	263	0.02
106639	M3	158.2	0.007
106639	L2	293.8	0.038
106639	2MK3	242.5	0.009
106639	K2	68.6	0.06
106639	M8	81.6	0.002
106639	MS4	282.9	0.025
106640	M2	20.5	0.314
106640	S2	38.5	0.159
106640	N2	45.2	0.1
106640	K1	2.5	0.343
106640	M4	286.6	0.015
106640	O1	29.5	0.171
106640	M6	54	0.004
106640	MK3	200.1	0.011
106640	S4	50.4	0.008
106640	MN4	1.7	0.008
106640	S6	262.8	0.01
106640	2N2	69.7	0.042
106640	OO1	249.1	0.048
106640	M1	140.7	0.034
106640	J1	54.2	0.033
106640	Q1	240.4	0.029
106640	2Q1	260.1	0.052
106640	P1	342.5	0.231
106640	2SM2	262.7	0.033
106640	M3	181.4	0.016
106640	L2	274.1	0.05
106640	2MK3	291.9	0.016
106640	K2	68.5	0.086
106640	M8	192.7	0.008
106640	MS4	302.3	0.013
106641	M2	2.2	0.363
106641	S2	45.4	0.227
106641	N2	7.1	0.077
106641	K1	326.8	0.259
106641	M4	73	0.004
106641	O1	343.3	0.092
106641	M6	62.4	0.004
106641	MK3	230.3	0.002
106641	S4	79.4	0.009
106641	MN4	156.2	0.005
106641	S6	152.6	0.001
106641	2N2	27.5	0.037
106641	OO1	302.4	0.01
106641	M1	108.4	0.017
106641	J1	358.6	0.03
106641	Q1	224.2	0.013
106641	2Q1	329.7	0.013
106641	P1	327.7	0.134
106641	2SM2	35.5	0.005
106641	M3	344	0.005
106641	L2	321.8	0.028
106641	2MK3	290.6	0.008
106641	K2	256.4	0.022
106641	M8	358	0.002
106641	MS4	273.7	0.003
106642	M2	13.1	0.44
106642	S2	54.1	0.203
106642	N2	9.3	0.087
106642	K1	326.1	0.367
106642	M4	78	0.015
106642	O1	338.7	0.136
106642	M6	276.4	0.002
106642	MK3	98.6	0.007
106642	S4	133.2	0.003
106642	MN4	100.2	0.006
106642	S6	223.3	0.003
106642	2N2	15.5	0.037
106642	OO1	220.7	0.004
106642	M1	120.2	0.015
106642	J1	22.7	0.027
106642	Q1	218.2	0.023
106642	2Q1	85.6	0.011
106642	P1	316.4	0.188
106642	2SM2	101	0.003
106642	M3	90.5	0.008
106642	L2	77.9	0.029
106642	2MK3	91.1	0.007
106642	K2	32.8	0.067
106642	M8	104.7	0.003
106642	MS4	105.9	0.003
106643	M2	20.2	0.439
106643	S2	47.5	0.187
106643	N2	7.1	0.091
106643	K1	326.4	0.425
106643	M4	89.7	0.027
106643	O1	343.3	0.166
106643	M6	294.9	0.008
106643	MK3	10.8	0.004
106643	S4	200.2	0.004
106643	MN4	0.4	0.003
106643	S6	253.7	0.004
106643	2N2	22.1	0.048
106643	OO1	354.7	0.019
106643	M1	70.2	0.017
106643	J1	135.3	0.015
106643	Q1	247.6	0.057
106643	2Q1	120.7	0.018
106643	P1	321.5	0.245
106643	2SM2	142.8	0.007
106643	M3	146.5	0.005
106643	L2	49.1	0.016
106643	2MK3	124.5	0.004
106643	K2	63.2	0.092
106643	M8	116.2	0.002
106643	MS4	161.9	0.004
106644	M2	340.6	0.3
106644	S2	13.2	0.227
106644	N2	322.9	0.049
106644	K1	300.6	0.155
106644	M4	272	0.039
106644	O1	283.7	0.109
106644	M6	319.3	0.011
106644	MK3	229.4	0.023
106644	S4	342.7	0.019
106644	MN4	265.5	0.02
106644	S6	282.3	0.005
106644	2N2	206.2	0.023
106644	OO1	224.5	0.027
106644	M1	142.6	0.01
106644	J1	319.7	0.037
106644	Q1	187.6	0.021
106644	2Q1	216.6	0.021
106644	P1	277.9	0.068
106644	2SM2	320.3	0.02
106644	M3	246	0.002
106644	L2	30.2	0.034
106644	2MK3	250.5	0.028
106644	K2	185.3	0.053
106644	M8	43.4	0.004
106644	MS4	324.5	0.046
106645	M2	346.1	0.347
106645	S2	17.1	0.259
106645	N2	329.9	0.059
106645	K1	303.1	0.192
106645	M4	270.5	0.039
106645	O1	286	0.134
106645	M6	303.2	0.014
106645	MK3	228	0.023
106645	S4	337	0.019
106645	MN4	271.1	0.019
106645	S6	294	0.004
106645	2N2	202.5	0.024
106645	OO1	224.3	0.038
106645	M1	149.6	0.011
106645	J1	326.1	0.041
106645	Q1	191.4	0.025
106645	2Q1	212.5	0.021
106645	P1	275.8	0.09
106645	2SM2	318.2	0.023
106645	M3	246.8	0.003
106645	L2	45.3	0.041
106645	2MK3	260.8	0.031
106645	K2	182.7	0.054
106645	M8	56.2	0.005
106645	MS4	331.3	0.044
106646	M2	348.1	0.371
106646	S2	21.3	0.271
106646	N2	333.4	0.068
106646	K1	305.9	0.203
106646	M4	279.2	0.029
106646	O1	290.6	0.134
106646	M6	298.2	0.018
106646	MK3	233.5	0.028
106646	S4	351.9	0.017
106646	MN4	275.1	0.017
106646	S6	299.2	0.003
106646	2N2	214.1	0.026
106646	OO1	219.3	0.044
106646	M1	141.2	0.015
106646	J1	329.6	0.044
106646	Q1	191.8	0.026
106646	2Q1	191.8	0.025
106646	P1	275.7	0.096
106646	2SM2	319.7	0.022
106646	M3	222.8	0.003
106646	L2	50.5	0.051
106646	2MK3	257.1	0.035
106646	K2	187.7	0.056
106646	M8	40.2	0.005
106646	MS4	334.6	0.045
106647	M2	42.5	0.109
106647	S2	108	0.05
106647	N2	351.1	0.055
106647	K1	57.4	0.066
106647	M4	168.1	0.006
106647	O1	343	0.061
106647	M6	252.3	0.006
106647	MK3	39.9	0.006
106647	S4	55.9	0.009
106647	MN4	328.1	0.004
106647	S6	3.1	0.008
106647	2N2	206.1	0.016
106647	OO1	33.9	0.029
106647	M1	139.4	0.007
106647	J1	73	0.06
106647	Q1	322.8	0.021
106647	2Q1	265.3	0.006
106647	P1	50.2	0.037
106647	2SM2	107.2	0.01
106647	M3	121.9	0.008
106647	L2	119.9	0.034
106647	2MK3	0	0.014
106647	M8	261.2	0.005
106647	MS4	267.8	0.005
106648	M2	36.4	0.572
106648	S2	65.1	0.406
106648	N2	358.4	0.19
106648	K1	295.8	0.281
106648	M4	70	0.042
106648	O1	313.1	0.064
106648	M6	201.2	0.013
106648	MK3	341.4	0.012
106648	S4	284.8	0.001
106648	MN4	60.1	0.04
106648	S6	183.6	0.013
106648	2N2	336.9	0.041
106648	OO1	347.5	0.026
106648	M1	132.6	0.012
106648	J1	248.8	0.036
106648	Q1	253.1	0.035
106648	2Q1	103.9	0.017
106648	P1	304.3	0.208
106648	2SM2	268.1	0.043
106648	M3	28.2	0.012
106648	L2	261.1	0.073
106648	2MK3	355.3	0.016
106648	M8	301	0.002
106648	MS4	158.4	0.058
106649	M2	40.7	0.694
106649	S2	71.3	0.507
106649	N2	353.2	0.194
106649	K1	284.6	0.248
106649	M4	71.7	0.065
106649	O1	328.4	0.074
106649	M6	89.4	0.016
106649	MK3	346.3	0.02
106649	S4	285.7	0.022
106649	MN4	53.8	0.065
106649	S6	100.8	0.006
106649	2N2	338.3	0.089
106649	OO1	351.5	0.025
106649	M1	174.7	0.015
106649	J1	261.3	0.053
106649	Q1	266.9	0.047
106649	2Q1	122.8	0.013
106649	P1	289.1	0.184
106649	2SM2	280.7	0.07
106649	M3	339.6	0.01
106649	L2	216.9	0.134
106649	2MK3	346.9	0.039
106649	M8	18.7	0.004
106649	MS4	151.9	0.088
106650	M2	38.4	0.677
106650	S2	70.4	0.514
106650	N2	348.5	0.18
106650	K1	270.4	0.189
106650	M4	75.3	0.092
106650	O1	338.9	0.079
106650	M6	81	0.014
106650	MK3	334.4	0.022
106650	S4	278.3	0.024
106650	MN4	53.3	0.078
106650	S6	80.4	0.016
106650	2N2	333.5	0.103
106650	OO1	309	0.045
106650	M1	168.7	0.019
106650	J1	290.9	0.042
106650	Q1	274.2	0.05
106650	2Q1	43.6	0.007
106650	P1	274	0.181
106650	2SM2	279.3	0.071
106650	M3	307.2	0.012
106650	L2	206.7	0.13
106650	2MK3	338.1	0.03
106650	M8	358.9	0.002
106650	MS4	148.5	0.091
106651	M2	140	1.757
106651	S2	154.2	0.472
106651	N2	132.5	0.341
106651	K1	153.8	0.512
106651	M4	34.8	0.076
106651	O1	139.9	0.229
106651	M6	263.5	0.063
106651	S4	26.1	0.019
106651	NU2	133.5	0.066
106651	S6	26.7	0.025
106651	2N2	124.8	0.045
106651	OO1	167.7	0.01
106651	LDA2	146.6	0.012
106651	M1	146.8	0.016
106651	J1	160.7	0.018
106651	RHO1	133.9	0.009
106651	Q1	132.9	0.044
106651	T2	154.2	0.028
106651	R2	154.2	0.004
106651	2Q1	126.1	0.006
106651	P1	153.8	0.17
106651	L2	147.6	0.049
106651	K2	154.2	0.128
106651	M8	233.6	0.021
106652	M2	135.7	1.681
106652	S2	146.3	0.761
106652	N2	130.1	0.326
106652	K1	150.9	0.559
106652	M4	45.3	0.088
106652	O1	125.2	0.306
106652	M6	268.5	0.068
106652	S4	91.2	0.05
106652	NU2	130.9	0.063
106652	S6	60.3	0.029
106652	2N2	124.5	0.043
106652	OO1	176.5	0.013
106652	LDA2	140.6	0.012
106652	M1	138	0.022
106652	J1	163.6	0.024
106652	RHO1	114.1	0.012
106652	Q1	112.3	0.059
106652	T2	146.2	0.045
106652	R2	146.3	0.006
106652	2Q1	99.5	0.008
106652	P1	150.8	0.185
106652	L2	141.4	0.047
106652	K2	146.2	0.207
106652	M8	101.8	0.015
106653	M2	134.1	1.315
106653	S2	168.8	0.431
106653	N2	101.7	0.215
106653	K1	149.7	0.408
106653	M4	48.9	0.124
106653	O1	151.3	0.222
106653	M6	230.1	0.061
106653	MK3	13.8	0.127
106653	S4	39	0.028
106653	MN4	29.7	0.022
106653	S6	147.1	0.006
106653	2N2	139.5	0.036
106653	OO1	205	0.024
106653	M1	202.9	0.011
106653	J1	150.8	0.022
106653	Q1	147.3	0.032
106653	2Q1	70.1	0.011
106653	P1	173.6	0.097
106653	2SM2	50.7	0.012
106653	M3	269.3	0.03
106653	L2	166.6	0.053
106653	2MK3	301.7	0.1
106653	K2	185.6	0.185
106653	M8	201.4	0.013
106653	MS4	112.4	0.077
106654	M2	139.4	1.616
106654	S2	169.8	0.443
106654	N2	107.7	0.275
106654	K1	147.3	0.46
106654	M4	46.6	0.117
106654	O1	150.5	0.231
106654	M6	251.9	0.057
106654	MK3	22.3	0.188
106654	S4	38.4	0.034
106654	MN4	11.8	0.019
106654	S6	104.8	0.008
106654	2N2	143.5	0.062
106654	OO1	205.2	0.036
106654	M1	197.2	0.015
106654	J1	165.4	0.021
106654	Q1	147.2	0.025
106654	2Q1	83.7	0.011
106654	P1	169.8	0.132
106654	2SM2	357.6	0.014
106654	M3	267.9	0.04
106654	L2	154.3	0.042
106654	2MK3	329.4	0.126
106654	K2	194.3	0.152
106654	M8	158.9	0.016
106654	MS4	122	0.085
106655	M2	123.7	0.932
106655	S2	150.9	0.306
106655	N2	109.1	0.171
106655	K1	145.3	0.3
106655	M4	97	0.081
106655	O1	141.2	0.201
106655	M6	84.2	0.064
106655	MK3	145.8	0.021
106655	S4	44.7	0.007
106655	MN4	100.9	0.017
106655	S6	220	0.006
106655	2N2	193.2	0.02
106655	OO1	204.9	0.016
106655	M1	163.8	0.019
106655	J1	87.3	0.034
106655	Q1	116.7	0.042
106655	2Q1	167.5	0.03
106655	P1	140.9	0.133
106655	2SM2	317	0.021
106655	M3	175.4	0.027
106655	L2	101.6	0.052
106655	2MK3	152.8	0.008
106655	K2	182.3	0.06
106655	M8	147.3	0.01
106655	MS4	83.9	0.037
106656	M2	108.7	0.192
106656	S2	108.5	0.024
106656	N2	91.3	0.029
106656	K1	293.4	0.162
106656	M4	358.6	0.058
106656	O1	269.8	0.059
106656	M6	263.3	0.022
106656	MK3	309.9	0.038
106656	S4	63.1	0.007
106656	MN4	307.4	0.015
106656	S6	331.1	0.004
106656	2N2	183.3	0.036
106656	OO1	176	0.001
106656	M1	148	0.017
106656	J1	272.4	0.028
106656	Q1	266.6	0.022
106656	2Q1	29.5	0.024
106656	P1	300.9	0.081
106656	2SM2	187.4	0.012
106656	M3	278.3	0.003
106656	L2	201.8	0.015
106656	2MK3	279.5	0.017
106656	K2	64.5	0.022
106656	M8	166.4	0.01
106656	MS4	54.8	0.038
106657	M2	112.2	0.238
106657	S2	182.5	0.071
106657	N2	100.3	0.054
106657	K1	294.1	0.287
106657	M4	338.9	0.077
106657	O1	257	0.088
106657	M6	263.1	0.028
106657	MK3	293.4	0.043
106657	S4	81.2	0.016
106657	MN4	289	0.019
106657	S6	16.6	0.005
106657	2N2	199.6	0.045
106657	OO1	257.5	0.008
106657	M1	201.3	0.019
106657	J1	268.1	0.049
106657	Q1	247	0.067
106657	2Q1	11.4	0.033
106657	P1	324.1	0.171
106657	2SM2	55.9	0.005
106657	M3	326.5	0.011
106657	L2	272.8	0.01
106657	2MK3	245.8	0.033
106657	K2	343.5	0.041
106657	M8	155	0.01
106657	MS4	35	0.053
106658	M2	128.6	1.13
106658	S2	161.6	0.287
106658	N2	101.7	0.209
106658	K1	164.6	0.247
106658	M4	13.1	0.128
106658	O1	159.4	0.148
106658	M6	176.8	0.054
106658	MK3	35.3	0.104
106658	S4	48.2	0.006
106658	MN4	341	0.043
106658	S6	116.5	0.005
106658	2N2	55.6	0.063
106658	OO1	224.8	0.019
106658	LDA2	85.2	0.042
106658	M1	203.3	0.017
106658	J1	250.9	0.017
106658	RHO1	324.1	0.007
106658	Q1	164.3	0.025
106658	2Q1	31.3	0.019
106658	P1	187	0.078
106658	2SM2	170.3	0.013
106658	M3	230.6	0.025
106658	L2	97.9	0.032
106658	2MK3	351.8	0.097
106658	K2	139.8	0.058
106658	M8	119.6	0.011
106658	MS4	48.9	0.072
106659	M2	131.5	1.566
106659	S2	156.9	0.381
106659	N2	104.6	0.291
106659	K1	163.3	0.359
106659	M4	20.7	0.164
106659	O1	155.3	0.211
106659	M6	200.5	0.062
106659	MK3	38.4	0.132
106659	S4	67.1	0.014
106659	MN4	352	0.056
106659	S6	143.3	0.004
106659	2N2	56.7	0.076
106659	OO1	206.6	0.023
106659	LDA2	72.9	0.047
106659	M1	207.3	0.02
106659	J1	225.9	0.029
106659	Q1	165.1	0.046
106659	2Q1	24.3	0.021
106659	P1	189.5	0.114
106659	2SM2	158.4	0.016
106659	M3	218.6	0.03
106659	L2	109.8	0.035
106659	2MK3	347.7	0.118
106659	K2	149.4	0.106
106659	M8	96.2	0.009
106659	MS4	57.8	0.1
106660	M2	86.4	0.717
106660	S2	87.6	0.125
106660	N2	53.5	0.172
106660	K1	175.5	0.126
106660	M4	326.2	0.022
106660	O1	187.2	0.046
106660	M6	255	0.023
106660	MK3	217.3	0.036
106660	S4	166	0.004
106660	MN4	285.3	0.015
106660	S6	41.1	0.001
106660	2N2	344.6	0.018
106660	OO1	248	0.01
106660	M1	335.4	0.017
106660	J1	26.6	0.007
106660	Q1	240	0.011
106660	2Q1	19.1	0.006
106660	P1	208.7	0.045
106660	2SM2	101.2	0.005
106660	M3	239.4	0.018
106660	L2	124.4	0.049
106660	2MK3	216.6	0.024
106660	K2	84.1	0.054
106660	M8	200	0.012
106660	MS4	7.2	0.01
106661	M2	95.5	0.981
106661	S2	113.4	0.14
106661	N2	60.5	0.211
106661	K1	181.7	0.197
106661	M4	322	0.045
106661	O1	206.4	0.064
106661	M6	279.2	0.023
106661	MK3	269.1	0.018
106661	S4	137.3	0.004
106661	MN4	324.1	0.021
106661	2N2	17.5	0.023
106661	OO1	283.6	0.019
106661	M1	3	0.03
106661	J1	75.4	0.034
106661	Q1	226.8	0.01
106661	2Q1	331.7	0.019
106661	P1	200	0.08
106661	2SM2	327.6	0.004
106661	M3	186.7	0.003
106661	L2	148.9	0.063
106661	2MK3	209.2	0.02
106661	K2	110.3	0.038
106661	M8	224.6	0.008
106661	MS4	19.4	0.024
106662	M2	98.4	1.091
106662	S2	113	0.157
106662	N2	65.1	0.245
106662	K1	183.6	0.23
106662	M4	13.1	0.08
106662	O1	209.6	0.072
106662	M6	332.3	0.023
106662	MK3	62.8	0.016
106662	S4	169	0.009
106662	MN4	0.2	0.03
106662	S6	119.7	0.004
106662	2N2	25.7	0.028
106662	OO1	270.5	0.016
106662	M1	338.2	0.032
106662	J1	90.8	0.028
106662	Q1	209.7	0.015
106662	2Q1	325.9	0.011
106662	P1	199.7	0.095
106662	2SM2	26.8	0.01
106662	M3	143.9	0.026
106662	L2	168.7	0.056
106662	2MK3	100.8	0.006
106662	K2	94.9	0.039
106662	M8	298.4	0.009
106662	MS4	57.2	0.037
106663	M2	50	0.862
106663	S2	81	0.115
106663	N2	35.1	0.204
106663	K1	158.2	0.141
106663	M4	331.3	0.119
106663	O1	142.7	0.072
106663	M6	296.9	0.062
106663	S4	269.8	0.012
106663	NU2	37.1	0.04
106663	S6	119.2	0.001
106663	2N2	20.3	0.027
106663	OO1	173.5	0.003
106663	LDA2	64.3	0.006
106663	M1	150.4	0.005
106663	J1	165.8	0.006
106663	RHO1	136	0.003
106663	Q1	134.9	0.014
106663	T2	79.6	0.007
106663	R2	82.2	0.001
106663	2Q1	127.3	0.002
106663	P1	156.9	0.047
106663	L2	35.1	0.029
106663	K2	83.4	0.031
106663	M8	157	0.014
106664	M2	62.3	1.345
106664	S2	72.4	0.229
106664	N2	34.1	0.232
106664	K1	166.9	0.247
106664	M4	349.2	0.18
106664	O1	149.6	0.099
106664	M6	302	0.03
106664	S4	284.5	0.014
106664	NU2	37.9	0.045
106664	S6	267.9	0.011
106664	2N2	6	0.031
106664	OO1	184.1	0.004
106664	LDA2	66.9	0.009
106664	M1	158.2	0.007
106664	J1	175.5	0.008
106664	RHO1	142.1	0.004
106664	Q1	140.9	0.019
106664	T2	71.9	0.014
106664	R2	72.8	0.002
106664	2Q1	132.3	0.003
106664	P1	165.5	0.082
106664	L2	34.2	0.033
106664	K2	73.2	0.062
106664	M8	146.1	0.019
106665	M2	65.5	1.437
106665	S2	84.3	0.282
106665	N2	33	0.3
106665	K1	174.8	0.313
106665	M4	342.5	0.126
106665	O1	183.7	0.113
106665	M6	261.9	0.052
106665	S4	325.4	0.012
106665	NU2	37.4	0.058
106665	S6	205	0.006
106665	2N2	0.5	0.04
106665	OO1	165.9	0.005
106665	LDA2	74.2	0.01
106665	M1	179.2	0.008
106665	J1	170.4	0.009
106665	RHO1	187.4	0.004
106665	Q1	188	0.022
106665	T2	83.5	0.017
106665	R2	85	0.002
106665	2Q1	192.4	0.003
106665	P1	175.4	0.104
106665	L2	33	0.043
106665	K2	85.8	0.077
106665	M8	178.1	0.023
106666	M2	89.5	0.891
106666	S2	104.4	0.225
106666	N2	54.1	0.275
106666	K1	187.2	0.166
106666	M4	183.4	0.157
106666	O1	183.7	0.116
106666	M6	88.4	0.054
106666	MK3	274.6	0.095
106666	S4	194.6	0.007
106666	MN4	77.7	0.042
106666	S6	60.2	0.005
106666	2N2	9.3	0.06
106666	OO1	278.7	0.008
106666	M1	173.9	0.016
106666	J1	129.7	0.038
106666	Q1	131.7	0.018
106666	2Q1	64.6	0.011
106666	P1	146.4	0.035
106666	2SM2	76.6	0.026
106666	M3	331.5	0.029
106666	L2	329.2	0.049
106666	2MK3	295.6	0.071
106666	K2	125.1	0.126
106666	M8	190.5	0.015
106666	MS4	245	0.044
106667	M2	88.5	1.129
106667	S2	116.5	0.187
106667	N2	65.2	0.31
106667	K1	178.6	0.199
106667	M4	2.1	0.049
106667	O1	176	0.126
106667	M6	288.5	0.035
106667	MK3	154.4	0.049
106667	S4	127.8	0.01
106667	MN4	26.6	0.039
106667	S6	41.4	0.006
106667	2N2	36.1	0.042
106667	OO1	272.5	0.019
106667	M1	65.5	0.031
106667	J1	98.9	0.011
106667	Q1	171.4	0.029
106667	2Q1	205.7	0.016
106667	P1	159.9	0.063
106667	2SM2	64.5	0.009
106667	M3	136.1	0.019
106667	L2	110.9	0.043
106667	2MK3	98.3	0.03
106667	K2	116.4	0.067
106667	M8	161.7	0.009
106667	MS4	57.2	0.028
106668	M2	91.4	1.228
106668	S2	103.8	0.098
106668	N2	65.5	0.242
106668	K1	184.9	0.151
106668	M4	55.8	0.049
106668	O1	197.3	0.104
106668	M6	59.7	0.06
106668	MK3	219	0.035
106668	S4	240	0.002
106668	MN4	178	0.005
106668	S6	208.9	0.002
106668	2N2	155.3	0.009
106668	OO1	247.3	0.021
106668	M1	63.6	0.022
106668	J1	303.9	0.008
106668	Q1	184.1	0.031
106668	2Q1	123.3	0.004
106668	P1	133.5	0.067
106668	2SM2	286.6	0.004
106668	M3	239.8	0.02
106668	L2	151	0.117
106668	2MK3	184.7	0.043
106668	K2	32.2	0.059
106668	M8	164.1	0.004
106668	MS4	95.8	0.015
106669	M2	88.2	0.918
106669	S2	129.8	0.095
106669	N2	68.5	0.272
106669	K1	166.2	0.188
106669	M4	78.3	0.072
106669	O1	167.2	0.088
106669	M6	28.2	0.056
106669	MK3	181	0.057
106669	S4	255.5	0.007
106669	MN4	80.2	0.05
106669	S6	262.2	0.005
106669	2N2	44.8	0.043
106669	OO1	274.2	0.018
106669	M1	91.7	0.009
106669	J1	272.3	0.008
106669	Q1	154.7	0.036
106669	2Q1	158.7	0.008
106669	P1	192	0.053
106669	2SM2	117.3	0.002
106669	M3	194.9	0.035
106669	L2	89	0.063
106669	2MK3	143.7	0.044
106669	K2	61	0.034
106669	M8	25.3	0.027
106669	MS4	117.1	0.025
106670	M2	91.8	1.095
106670	S2	115.1	0.137
106670	N2	75.1	0.269
106670	K1	174.5	0.157
106670	M4	87.8	0.056
106670	O1	171.4	0.09
106670	M6	75.3	0.058
106670	MK3	197	0.057
106670	S4	2.3	0.009
106670	MN4	17.9	0.003
106670	S6	242.2	0.004
106670	2N2	39.5	0.025
106670	OO1	261.6	0.012
106670	M1	80	0.016
106670	J1	213.3	0.008
106670	Q1	163	0.034
106670	2Q1	206.5	0.01
106670	P1	167.6	0.039
106670	2SM2	271.7	0.007
106670	M3	227.3	0.022
106670	L2	122	0.076
106670	2MK3	181.4	0.052
106670	K2	96.2	0.042
106670	M8	332.9	0.029
106670	MS4	205.6	0.014
106671	M2	92.3	0.997
106671	S2	100.9	0.115
106671	N2	68.8	0.2
106671	K1	179.6	0.134
106671	M4	48.2	0.109
106671	O1	178.6	0.07
106671	M6	89.8	0.034
106671	MK3	178.9	0.035
106671	S4	257.9	0.002
106671	MN4	10.7	0.043
106671	S6	263.2	0.004
106671	2N2	180.8	0.009
106671	OO1	279.9	0.012
106671	M1	52.2	0.016
106671	J1	178.5	0.007
106671	Q1	155.4	0.022
106671	2Q1	353.4	0.003
106671	P1	157.3	0.038
106671	2SM2	83.1	0.003
106671	M3	293.4	0.018
106671	L2	145.8	0.081
106671	2MK3	193	0.037
106671	K2	87	0.05
106671	M8	41.3	0.009
106671	MS4	85.3	0.025
106672	M2	100.3	0.864
106672	S2	127.9	0.086
106672	N2	73	0.186
106672	K1	180.6	0.126
106672	M4	130	0.036
106672	O1	192.8	0.066
106672	M6	108.9	0.048
106672	MK3	236.6	0.03
106672	S4	266	0.005
106672	MN4	112.8	0.018
106672	S6	326.3	0.003
106672	2N2	293.4	0.006
106672	OO1	272.2	0.01
106672	M1	67.5	0.012
106672	J1	71	0.005
106672	Q1	154.9	0.016
106672	P1	181.5	0.032
106672	2SM2	127.7	0.004
106672	M3	255.7	0.012
106672	L2	146.5	0.08
106672	2MK3	204	0.022
106672	K2	70.1	0.037
106672	M8	93	0.006
106672	MS4	178.4	0.01
106673	M2	101.2	0.992
106673	S2	131.4	0.096
106673	N2	74	0.215
106673	K1	180.7	0.148
106673	M4	135.9	0.042
106673	O1	192.1	0.076
106673	M6	115.3	0.047
106673	MK3	239.8	0.041
106673	S4	272	0.007
106673	MN4	116.2	0.023
106673	S6	338.8	0.003
106673	2N2	300.7	0.005
106673	OO1	274.1	0.011
106673	M1	72.6	0.012
106673	J1	78.3	0.006
106673	Q1	156.8	0.02
106673	2Q1	236.1	0.001
106673	P1	180.6	0.037
106673	2SM2	120.9	0.005
106673	M3	261	0.011
106673	L2	149.7	0.086
106673	2MK3	206.6	0.028
106673	K2	69.8	0.039
106673	M8	84.6	0.009
106673	MS4	183.5	0.013
106674	M2	102.5	1.126
106674	S2	132.1	0.116
106674	N2	75.4	0.242
106674	K1	186.3	0.175
106674	M4	140.5	0.03
106674	O1	191.2	0.095
106674	M6	88.7	0.036
106674	MK3	248.1	0.052
106674	S4	265.5	0.01
106674	MN4	130	0.028
106674	S6	322.9	0.002
106674	2N2	39.2	0.005
106674	OO1	291.2	0.015
106674	M1	62	0.013
106674	J1	95.3	0.015
106674	Q1	150	0.019
106674	2Q1	44.7	0.002
106674	P1	142.3	0.038
106674	2SM2	79.7	0.006
106674	M3	260.4	0.009
106674	L2	149.7	0.093
106674	2MK3	213	0.039
106674	K2	87.9	0.047
106674	M8	95.6	0.011
106674	MS4	147	0.013
106675	M2	114.9	0.883
106675	S2	122.7	0.131
106675	N2	81.2	0.156
106675	K1	201.7	0.138
106675	M4	168.8	0.061
106675	O1	186.7	0.073
106675	M6	151.8	0.038
106675	MK3	258.4	0.016
106675	S4	187.2	0.013
106675	MN4	159.6	0.028
106675	S6	144.1	0.006
106675	2N2	179	0.028
106675	OO1	12.2	0.012
106675	M1	40.6	0.006
106675	J1	234.6	0.004
106675	Q1	169.5	0.021
106675	2Q1	276.4	0.017
106675	P1	182.9	0.035
106675	2SM2	52.2	0.005
106675	M3	268.5	0.021
106675	L2	177.7	0.054
106675	2MK3	209.6	0.027
106675	K2	156.1	0.056
106675	M8	60	0.012
106675	MS4	172.6	0.031
106676	M2	115.4	1.152
106676	S2	126.5	0.185
106676	N2	83.7	0.213
106676	K1	194.3	0.179
106676	M4	149.1	0.058
106676	O1	188.4	0.094
106676	M6	143.6	0.025
106676	MK3	257.5	0.018
106676	S4	212.9	0.022
106676	MN4	161.9	0.008
106676	S6	38.3	0.002
106676	2N2	183.9	0.035
106676	OO1	14.4	0.016
106676	M1	19	0.006
106676	J1	270.1	0.013
106676	Q1	176.4	0.024
106676	2Q1	271.6	0.023
106676	P1	172.4	0.05
106676	2SM2	62.9	0.008
106676	M3	251.9	0.015
106676	L2	176.8	0.062
106676	2MK3	240	0.02
106676	K2	155	0.062
106676	M8	337.2	0.002
106676	MS4	165.8	0.035
106677	M2	115.4	1.185
106677	S2	128.4	0.186
106677	N2	82.7	0.22
106677	K1	193.9	0.189
106677	M4	149.6	0.062
106677	O1	189.7	0.091
106677	M6	119.9	0.021
106677	MK3	257.4	0.018
106677	S4	223.1	0.022
106677	MN4	124.7	0.01
106677	S6	17.3	0.002
106677	2N2	189.6	0.032
106677	OO1	16.8	0.018
106677	M1	32.8	0.007
106677	J1	276.1	0.014
106677	Q1	172	0.024
106677	2Q1	263.2	0.023
106677	P1	171.2	0.051
106677	2SM2	77.7	0.009
106677	M3	253.6	0.013
106677	L2	176.5	0.062
106677	2MK3	233.1	0.015
106677	K2	151.1	0.067
106677	M8	7.2	0.005
106677	MS4	160.8	0.041
106678	M2	128.1	1.095
106678	S2	138.5	0.155
106678	N2	88.2	0.203
106678	K1	194.2	0.141
106678	M4	213.5	0.018
106678	O1	190.6	0.061
106678	M6	205.2	0.068
106678	MK3	340.7	0.02
106678	S4	255.8	0.015
106678	MN4	210.9	0.008
106678	2N2	183.5	0.032
106678	OO1	35.4	0.011
106678	M1	47.2	0.007
106678	J1	277	0.007
106678	Q1	150.8	0.017
106678	2Q1	275	0.01
106678	P1	172.3	0.058
106678	2SM2	91.2	0.013
106678	M3	289.5	0.012
106678	L2	198.4	0.07
106678	2MK3	274.7	0.026
106678	K2	176.3	0.06
106678	M8	147.1	0.008
106678	MS4	185.1	0.023
106679	M2	128.6	1.319
106679	S2	139.9	0.189
106679	N2	88.6	0.244
106679	K1	193.2	0.176
106679	M4	163.6	0.027
106679	O1	190.2	0.071
106679	M6	209.1	0.078
106679	MK3	330.9	0.029
106679	S4	250.8	0.017
106679	MN4	183.5	0.005
106679	2N2	182.5	0.035
106679	OO1	36.3	0.013
106679	M1	45.1	0.009
106679	J1	266.8	0.008
106679	Q1	149.8	0.022
106679	2Q1	280.6	0.013
106679	P1	170.5	0.072
106679	2SM2	96.8	0.014
106679	M3	288.7	0.015
106679	L2	200.3	0.084
106679	2MK3	268.6	0.031
106679	K2	176	0.072
106679	M8	156.1	0.011
106679	MS4	172.7	0.028
106680	M2	129	1.397
106680	S2	139.8	0.203
106680	N2	89.1	0.258
106680	K1	193.9	0.193
106680	M4	156.4	0.024
106680	O1	188.4	0.075
106680	M6	214.1	0.076
106680	MK3	331.6	0.036
106680	S4	254.6	0.02
106680	MN4	192.6	0.005
106680	S6	149.8	0.002
106680	2N2	185.2	0.035
106680	OO1	26.5	0.011
106680	M1	45.7	0.01
106680	J1	244.2	0.009
106680	Q1	143.5	0.028
106680	2Q1	293.3	0.013
106680	P1	168.8	0.071
106680	2SM2	90.9	0.012
106680	M3	282.4	0.017
106680	L2	201.7	0.089
106680	2MK3	260.3	0.031
106680	K2	176	0.077
106680	M8	153.9	0.009
106680	MS4	152.9	0.023
106681	M2	20.7	1.148
106681	S2	42.3	0.227
106681	N2	353.1	0.26
106681	K1	145.9	0.244
106681	M4	254.4	0.047
106681	O1	115.1	0.137
106681	M6	223.9	0.007
106681	MK3	245.6	0.009
106681	S4	19.8	0.025
106681	MN4	203.5	0.008
106681	S6	53.3	0.002
106681	2N2	8.9	0.085
106681	OO1	178.7	0.004
106681	M1	157.7	0.013
106681	J1	281.3	0.03
106681	Q1	116.6	0.019
106681	2Q1	229.1	0.019
106681	P1	146.4	0.081
106681	2SM2	242.7	0.019
106681	M3	49.8	0.04
106681	L2	358.8	0.082
106681	2MK3	294.1	0.019
106681	K2	50	0.074
106681	M8	62.9	0.034
106681	MS4	268.9	0.062
106682	M2	23.9	1.693
106682	S2	40.3	0.34
106682	N2	358.1	0.371
106682	K1	154.2	0.331
106682	M4	275.7	0.135
106682	O1	122.2	0.184
106682	M6	184.6	0.022
106682	MK3	83.9	0.02
106682	S4	23.3	0.037
106682	MN4	244.7	0.066
106682	S6	65.9	0.011
106682	2N2	8.3	0.074
106682	M1	164.1	0.016
106682	J1	295.8	0.035
106682	Q1	121.2	0.035
106682	2Q1	223	0.034
106682	P1	152.2	0.101
106682	2SM2	248.5	0.019
106682	M3	83.5	0.05
106682	L2	32.6	0.126
106682	2MK3	344	0.013
106682	K2	65.1	0.095
106682	M8	82.1	0.052
106682	MS4	286.9	0.094
106683	M2	33.6	2.057
106683	S2	48.4	0.349
106683	N2	9	0.489
106683	K1	168.8	0.363
106683	M4	262.6	0.126
106683	O1	150.4	0.21
106683	M6	220.1	0.092
106683	MK3	105.7	0.031
106683	S4	25.6	0.035
106683	MN4	285	0.044
106683	S6	67.4	0.005
106683	2N2	348.6	0.024
106683	OO1	113.3	0.005
106683	M1	199.6	0.007
106683	J1	317.3	0.024
106683	Q1	142.9	0.06
106683	2Q1	226.1	0.026
106683	P1	153.4	0.098
106683	2SM2	175.2	0.012
106683	M3	109.7	0.02
106683	L2	92.1	0.191
106683	2MK3	96.5	0.029
106683	K2	68.5	0.092
106683	M8	113.5	0.02
106683	MS4	274.3	0.068
106684	M2	138	0.987
106684	S2	154.1	0.146
106684	N2	106.2	0.197
106684	K1	207.4	0.125
106684	M4	208.1	0.058
106684	O1	182	0.068
106684	M6	253	0.048
106684	MK3	312.6	0.033
106684	S4	277.3	0.014
106684	MN4	174.8	0.023
106684	S6	340.9	0.001
106684	2N2	328.9	0.028
106684	OO1	96.5	0.001
106684	M1	255.1	0.004
106684	J1	334.5	0.009
106684	Q1	153.5	0.013
106684	2Q1	294	0.013
106684	P1	194.7	0.031
106684	2SM2	349.4	0.015
106684	M3	327.2	0.015
106684	L2	185.8	0.129
106684	2MK3	271.5	0.036
106684	K2	176.5	0.043
106684	M8	316	0.01
106684	MS4	207.3	0.027
106685	M2	138.8	1.163
106685	S2	156.9	0.173
106685	N2	107.2	0.235
106685	K1	207.7	0.15
106685	M4	213.4	0.067
106685	O1	181.7	0.079
106685	M6	263.9	0.055
106685	MK3	318.8	0.041
106685	S4	279.6	0.016
106685	MN4	178.7	0.026
106685	S6	327.1	0.003
106685	2N2	333.2	0.031
106685	OO1	78	0.001
106685	M1	257.9	0.004
106685	J1	332.9	0.012
106685	Q1	156.6	0.016
106685	2Q1	289.7	0.016
106685	P1	193.1	0.036
106685	2SM2	346.2	0.017
106685	M3	335.8	0.018
106685	L2	185.5	0.146
106685	2MK3	275.3	0.043
106685	K2	174.4	0.052
106685	M8	301.8	0.012
106685	MS4	210.6	0.028
106686	M2	138.9	1.229
106686	S2	158.6	0.183
106686	N2	107.6	0.248
106686	K1	206.7	0.162
106686	M4	212.8	0.07
106686	O1	180.2	0.085
106686	M6	272	0.056
106686	MK3	319.9	0.045
106686	S4	283.9	0.016
106686	MN4	174.7	0.029
106686	S6	309.5	0.004
106686	2N2	338.4	0.032
106686	OO1	47.3	0.003
106686	M1	258.4	0.004
106686	J1	324.9	0.015
106686	Q1	152.8	0.018
106686	2Q1	284.6	0.017
106686	P1	190	0.038
106686	2SM2	350	0.021
106686	M3	338.9	0.021
106686	L2	184.1	0.154
106686	2MK3	277.4	0.049
106686	K2	172.3	0.054
106686	M8	304.4	0.01
106686	MS4	210.6	0.029
106687	M2	156.6	1.037
106687	S2	180.9	0.155
106687	N2	120.6	0.22
106687	K1	217.7	0.154
106687	M4	316.8	0.069
106687	O1	193	0.078
106687	M6	287.8	0.064
106687	MK3	346.2	0.044
106687	S4	345	0.011
106687	MN4	296	0.027
106687	S6	288.4	0.002
106687	2N2	304.5	0.03
106687	OO1	329.2	0.003
106687	M1	200.1	0.002
106687	J1	355.1	0.023
106687	Q1	139.8	0.02
106687	2Q1	276.1	0.029
106687	P1	175.1	0.062
106687	2SM2	334.6	0.038
106687	M3	11.8	0.016
106687	L2	197.9	0.131
106687	2MK3	306.2	0.042
106687	K2	192.8	0.047
106687	M8	129.1	0.003
106687	MS4	306.8	0.017
106688	M2	157.5	1.366
106688	S2	181.1	0.214
106688	N2	122	0.285
106688	K1	216.5	0.201
106688	M4	312	0.077
106688	O1	195.1	0.102
106688	M6	295.4	0.082
106688	MK3	344.7	0.054
106688	S4	352.6	0.015
106688	MN4	299	0.03
106688	S6	262.6	0.003
106688	2N2	308.1	0.036
106688	OO1	332.2	0.004
106688	M1	163.2	0.003
106688	J1	354.1	0.029
106688	Q1	138.2	0.025
106688	2Q1	273.7	0.039
106688	P1	180.3	0.079
106688	2SM2	327.7	0.048
106688	M3	13.8	0.021
106688	L2	199.6	0.174
106688	2MK3	308	0.052
106688	K2	195.3	0.056
106688	M8	128.5	0.003
106688	MS4	303.1	0.02
106689	M2	157.7	1.457
106689	S2	182.4	0.237
106689	N2	122.6	0.304
106689	K1	214.9	0.212
106689	M4	314.6	0.076
106689	O1	195.6	0.108
106689	M6	297.7	0.083
106689	MK3	344.8	0.056
106689	S4	351.8	0.016
106689	MN4	299	0.031
106689	S6	257	0.005
106689	2N2	309.3	0.037
106689	OO1	340.7	0.004
106689	M1	147.4	0.005
106689	J1	349.4	0.031
106689	Q1	132.8	0.027
106689	2Q1	272.4	0.041
106689	P1	180.7	0.077
106689	2SM2	325.8	0.05
106689	M3	6.8	0.02
106689	L2	200.2	0.187
106689	2MK3	310.1	0.053
106689	K2	189.5	0.057
106689	M8	119.5	0.002
106689	MS4	300.3	0.017
106690	M2	168.3	1.223
106690	S2	191.1	0.208
106690	N2	131.9	0.248
106690	K1	224.4	0.158
106690	M4	331.4	0.138
106690	O1	198.4	0.089
106690	M6	340.3	0.062
106690	MK3	5.1	0.065
106690	S4	29.2	0.019
106690	MN4	309.7	0.049
106690	S6	117.4	0.004
106690	2N2	298.1	0.042
106690	OO1	303.8	0.002
106690	M1	113.8	0.001
106690	J1	357.8	0.027
106690	Q1	153.1	0.019
106690	2Q1	283	0.033
106690	P1	185.9	0.062
106690	2SM2	331.1	0.046
106690	M3	30.7	0.025
106690	L2	204.6	0.159
106690	2MK3	318.2	0.058
106690	K2	201.1	0.036
106690	M8	105.5	0.018
106690	MS4	335.2	0.045
106691	M2	169.1	1.566
106691	S2	192.6	0.26
106691	N2	132.8	0.319
106691	K1	224.8	0.2
106691	M4	337.4	0.174
106691	O1	199.2	0.113
106691	M6	345	0.083
106691	MK3	5.6	0.081
106691	S4	37.5	0.027
106691	MN4	319.6	0.062
106691	S6	122.2	0.005
106691	2N2	303.3	0.049
106691	OO1	303.8	0.003
106691	M1	122.5	0.001
106691	J1	356.9	0.033
106691	Q1	149.4	0.025
106691	2Q1	283.5	0.043
106691	P1	190.5	0.076
106691	2SM2	330.6	0.059
106691	M3	34.8	0.034
106691	L2	206	0.201
106691	2MK3	318.9	0.072
106691	K2	207.1	0.053
106691	M8	122.7	0.023
106691	MS4	341.6	0.059
106692	M2	169.6	1.664
106692	S2	193.5	0.271
106692	N2	133.2	0.339
106692	K1	224.9	0.21
106692	M4	338.9	0.184
106692	O1	198.5	0.12
106692	M6	346.7	0.088
106692	MK3	3.7	0.084
106692	S4	41.2	0.027
106692	MN4	320	0.066
106692	S6	119.8	0.006
106692	2N2	302.6	0.051
106692	OO1	310	0.003
106692	M1	87.8	0.002
106692	J1	359.1	0.033
106692	Q1	149.5	0.026
106692	2Q1	282.8	0.046
106692	P1	194.2	0.075
106692	2SM2	332.2	0.063
106692	M3	37	0.037
106692	L2	205.8	0.218
106692	2MK3	320	0.075
106692	K2	207.7	0.062
106692	M8	124.7	0.024
106692	MS4	341.4	0.063
106693	M2	172.9	1.034
106693	S2	203.8	0.286
106693	N2	147.1	0.204
106693	K1	217.8	0.064
106693	M4	342.3	0.175
106693	O1	197	0.06
106693	M6	36.4	0.08
106693	MK3	16.6	0.052
106693	S4	63.4	0.014
106693	MN4	316.6	0.082
106693	S6	175.6	0.005
106693	2N2	278.9	0.049
106693	OO1	357.4	0.004
106693	M1	106	0.006
106693	J1	345.8	0.011
106693	Q1	127.5	0.01
106693	2Q1	254.5	0.009
106693	P1	60.2	0.033
106693	2SM2	7.9	0.024
106693	M3	45.6	0.031
106693	L2	219.9	0.215
106693	2MK3	325.4	0.064
106693	K2	75.8	0.063
106693	M8	147.7	0.013
106693	MS4	342	0.062
106694	M2	173.8	1.317
106694	S2	202.9	0.349
106694	N2	147.3	0.262
106694	K1	216.8	0.081
106694	M4	343.7	0.202
106694	O1	195.4	0.075
106694	M6	38.2	0.113
106694	MK3	18.2	0.062
106694	S4	59	0.018
106694	MN4	316	0.096
106694	S6	173.5	0.005
106694	2N2	279.1	0.06
106694	OO1	353.1	0.005
106694	M1	112.9	0.007
106694	J1	348.3	0.017
106694	Q1	126.5	0.012
106694	2Q1	260.1	0.012
106694	P1	62	0.042
106694	2SM2	7.4	0.03
106694	M3	43.4	0.041
106694	L2	217.3	0.269
106694	2MK3	325.2	0.079
106694	K2	73.3	0.066
106694	M8	158.2	0.016
106694	MS4	341	0.071
106695	M2	174.3	1.4
106695	S2	201.4	0.363
106695	N2	147.6	0.283
106695	K1	222.3	0.094
106695	M4	344.4	0.208
106695	O1	194.5	0.083
106695	M6	40.4	0.121
106695	MK3	20.8	0.067
106695	S4	59.6	0.018
106695	MN4	316.7	0.1
106695	S6	166.7	0.004
106695	2N2	279.5	0.061
106695	OO1	347.6	0.006
106695	M1	110.7	0.007
106695	J1	350.5	0.019
106695	Q1	119.5	0.013
106695	2Q1	261.7	0.014
106695	P1	62.5	0.03
106695	2SM2	2.8	0.029
106695	M3	43.4	0.045
106695	L2	215.5	0.283
106695	2MK3	325.9	0.081
106695	K2	68	0.06
106695	M8	160.8	0.016
106695	MS4	341.3	0.073
106696	M2	177.2	0.882
106696	S2	189.5	0.098
106696	N2	157	0.171
106696	K1	220.1	0.073
106696	M4	344.1	0.154
106696	O1	216.4	0.048
106696	M6	65.7	0.111
106696	MK3	32.1	0.038
106696	S4	16.5	0.007
106696	MN4	323.5	0.065
106696	S6	278.9	0.006
106696	2N2	353.9	0.024
106696	OO1	99	0.003
106696	M1	253.4	0.006
106696	J1	222.6	0.004
106696	Q1	243	0.011
106696	2Q1	27.3	0.011
106696	P1	161.9	0.034
106696	2SM2	100.6	0.023
106696	M3	47.2	0.025
106696	L2	195.3	0.129
106696	2MK3	322.7	0.059
106696	K2	214.6	0.068
106696	M8	215.1	0.011
106696	MS4	5.6	0.06
106697	M2	178.1	1.063
106697	S2	192.8	0.119
106697	N2	156	0.213
106697	K1	225.2	0.097
106697	M4	346	0.183
106697	O1	215.3	0.054
106697	M6	69.2	0.135
106697	MK3	29.6	0.047
106697	S4	21.2	0.01
106697	MN4	327	0.078
106697	S6	283.2	0.008
106697	2N2	3.3	0.027
106697	OO1	78.7	0.003
106697	M1	258.4	0.007
106697	J1	278.6	0.003
106697	Q1	243.2	0.011
106697	2Q1	36.4	0.013
106697	P1	175.8	0.04
106697	2SM2	100.9	0.027
106697	M3	46.5	0.032
106697	L2	192.5	0.151
106697	2MK3	326.7	0.068
106697	K2	213.4	0.081
106697	M8	209.3	0.012
106697	MS4	9.9	0.073
106698	M2	178.2	1.129
106698	S2	192.5	0.119
106698	N2	155.4	0.227
106698	K1	227.6	0.108
106698	M4	346.6	0.188
106698	O1	213.2	0.055
106698	M6	72.3	0.138
106698	MK3	27.4	0.052
106698	S4	36.9	0.01
106698	MN4	329.6	0.08
106698	S6	289.8	0.01
106698	2N2	8.8	0.029
106698	OO1	70.7	0.004
106698	M1	264.9	0.007
106698	J1	294.4	0.006
106698	Q1	230.4	0.01
106698	2Q1	35.8	0.015
106698	P1	184.8	0.045
106698	2SM2	99.1	0.031
106698	M3	45.7	0.036
106698	L2	191.8	0.157
106698	2MK3	328.7	0.069
106698	K2	211.3	0.088
106698	M8	217.9	0.011
106698	MS4	13.6	0.076
106699	M2	177.3	0.732
106699	S2	187.7	0.094
106699	N2	155.5	0.146
106699	K1	222.5	0.078
106699	M4	345.2	0.155
106699	O1	218.9	0.031
106699	M6	78.9	0.123
106699	MK3	43	0.046
106699	S4	13.5	0.012
106699	MN4	327.2	0.071
106699	S6	273.6	0.006
106699	2N2	7.2	0.02
106699	OO1	71.2	0.003
106699	M1	253.8	0.005
106699	J1	289.9	0.008
106699	Q1	238.4	0.008
106699	2Q1	19	0.005
106699	P1	194.1	0.033
106699	2SM2	133.9	0.02
106699	M3	65.7	0.023
106699	L2	188.5	0.114
106699	2MK3	327.6	0.058
106699	K2	222.3	0.057
106699	M8	254.4	0.029
106699	MS4	9.9	0.063
106700	M2	178.5	0.861
106700	S2	184.4	0.115
106700	N2	155	0.173
106700	K1	229.4	0.089
106700	M4	345.8	0.176
106700	O1	219.5	0.035
106700	M6	82.1	0.15
106700	MK3	38.6	0.054
106700	S4	18.5	0.012
106700	MN4	327.1	0.079
106700	S6	268.2	0.007
106700	2N2	14.4	0.023
106700	OO1	63.7	0.003
106700	M1	265.4	0.005
106700	J1	300.2	0.009
106700	Q1	220.5	0.009
106700	2Q1	17.1	0.006
106700	P1	208.5	0.039
106700	2SM2	134	0.023
106700	M3	58.8	0.03
106700	L2	191	0.137
106700	2MK3	330.4	0.063
106700	K2	227.7	0.07
106700	M8	254.3	0.035
106700	MS4	14.1	0.073
106701	M2	178.5	0.895
106701	S2	180.5	0.115
106701	N2	154.6	0.18
106701	K1	232.4	0.092
106701	M4	345.3	0.18
106701	O1	212.4	0.04
106701	M6	85	0.161
106701	MK3	31.1	0.049
106701	S4	18.5	0.012
106701	MN4	325.2	0.079
106701	S6	267.4	0.007
106701	2N2	19.2	0.022
106701	OO1	66.5	0.004
106701	M1	273.1	0.006
106701	J1	302.9	0.01
106701	Q1	200.3	0.011
106701	2Q1	14.6	0.008
106701	P1	209.6	0.045
106701	2SM2	132.7	0.023
106701	M3	52.6	0.032
106701	L2	191	0.142
106701	2MK3	332.7	0.059
106701	K2	227	0.079
106701	M8	252.1	0.036
106701	MS4	11.5	0.077
106702	M2	191.2	0.411
106702	S2	222.7	0.06
106702	N2	156.3	0.066
106702	K1	237.4	0.052
106702	M4	353.1	0.084
106702	O1	227.6	0.02
106702	M6	85.5	0.08
106702	S4	171.3	0.002
106702	NU2	161	0.013
106702	S6	295.6	0.002
106702	2N2	121.5	0.009
106702	OO1	247.1	0.001
106702	LDA2	205.8	0.003
106702	M1	232.4	0.001
106702	J1	242.2	0.002
106702	RHO1	223.3	0.001
106702	Q1	222.6	0.004
106702	T2	221.4	0.004
106702	2Q1	217.8	0.001
106702	P1	236.6	0.017
106702	L2	156.4	0.009
106702	K2	225.3	0.016
106702	M8	264.7	0.041
106703	M2	190.2	0.443
106703	S2	223.1	0.062
106703	N2	156.1	0.072
106703	K1	252.3	0.058
106703	M4	353.5	0.092
106703	O1	211.2	0.018
106703	M6	90.4	0.095
106703	S4	81.2	0.002
106703	NU2	160.7	0.014
106703	S6	305.7	0.002
106703	2N2	122.1	0.01
106703	OO1	293.4	0.001
106703	LDA2	205.4	0.003
106703	M1	231.7	0.001
106703	J1	272.7	0.001
106703	RHO1	193.5	0.001
106703	Q1	190.7	0.003
106703	T2	221.7	0.004
106703	P1	249.1	0.019
106703	L2	156.1	0.01
106703	K2	225.8	0.017
106703	M8	262.7	0.043
106704	M2	183.9	0.448
106704	S2	219.6	0.057
106704	N2	148.9	0.067
106704	K1	255.9	0.061
106704	M4	359.2	0.062
106704	O1	198.8	0.019
106704	M6	91	0.084
106704	S4	136.2	0.006
106704	NU2	153.7	0.013
106704	S6	335.7	0.004
106704	2N2	114	0.009
106704	OO1	312.9	0.001
106704	LDA2	200.4	0.003
106704	M1	227.3	0.001
106704	J1	284.2	0.001
106704	RHO1	174.3	0.001
106704	Q1	170.5	0.004
106704	T2	218.1	0.003
106704	P1	251.5	0.02
106704	L2	149	0.01
106704	K2	222.4	0.016
106704	M8	281.8	0.036
106705	M2	121	0.96
106705	S2	138.9	0.165
106705	N2	87.5	0.209
106705	K1	205.2	0.182
106705	M4	163.2	0.073
106705	O1	170.1	0.102
106705	M6	147.7	0.034
106705	MK3	254.5	0.032
106705	S4	235.3	0.011
106705	MN4	139.5	0.029
106705	S6	270.7	0.001
106705	2N2	294.9	0.018
106705	OO1	311.2	0.001
106705	M1	180.5	0.005
106705	J1	333.9	0.026
106705	Q1	111.7	0.031
106705	2Q1	254.5	0.034
106705	P1	180.1	0.076
106705	2SM2	272.4	0.024
106705	M3	260.8	0.015
106705	L2	176.7	0.131
106705	2MK3	241.7	0.022
106705	K2	144.3	0.036
106705	M8	285.8	0.005
106705	MS4	156.3	0.034
106706	M2	122	1.166
106706	S2	141.4	0.199
106706	N2	87.4	0.257
106706	K1	204.8	0.219
106706	M4	174.8	0.081
106706	O1	173.1	0.121
106706	M6	167.4	0.032
106706	MK3	269.4	0.039
106706	S4	250.1	0.013
106706	MN4	149.4	0.033
106706	S6	260.6	0.002
106706	2N2	307.9	0.022
106706	OO1	314.8	0.002
106706	M1	180.2	0.006
106706	J1	334	0.029
106706	Q1	113.2	0.038
106706	2Q1	254.9	0.041
106706	P1	178.7	0.089
106706	2SM2	277.8	0.03
106706	M3	270.4	0.015
106706	L2	176.4	0.15
106706	2MK3	253.8	0.026
106706	K2	143.7	0.046
106706	MS4	165.6	0.033
106707	M2	122.9	1.256
106707	S2	143.6	0.212
106707	N2	87.9	0.276
106707	K1	204	0.238
106707	M4	176.8	0.088
106707	O1	172.9	0.128
106707	M6	169.1	0.025
106707	MK3	273.9	0.041
106707	S4	256.7	0.014
106707	MN4	146.7	0.034
106707	S6	280.1	0.002
106707	2N2	313.3	0.023
106707	OO1	341.4	0.003
106707	M1	176.8	0.006
106707	J1	332.9	0.031
106707	Q1	113.3	0.04
106707	2Q1	255.4	0.043
106707	P1	177.4	0.097
106707	2SM2	285.6	0.034
106707	M3	272.3	0.016
106707	L2	178.2	0.156
106707	2MK3	254.7	0.03
106707	K2	143.9	0.055
106707	M8	135.4	0.005
106707	MS4	169.9	0.035
106708	M2	67.5	0.503
106708	S2	75.1	0.14
106708	N2	59.7	0.09
106708	K1	289.1	0.305
106708	M4	358.5	0.073
106708	O1	304	0.246
106708	M6	48.4	0.019
106708	MK3	226.4	0.093
106708	S4	165.7	0.015
106708	MN4	320.3	0.029
106708	S6	163.8	0.006
106708	2N2	110.9	0.034
106708	OO1	60	0.011
106708	M1	349.7	0.012
106708	J1	318.9	0.015
106708	Q1	289.4	0.041
106708	2Q1	328.5	0.014
106708	2SM2	41.9	0.006
106708	M3	106.2	0.007
106708	L2	128.6	0.021
106708	2MK3	261.7	0.035
106708	M8	46.2	0.01
106708	MS4	345.8	0.027
106709	M2	67.6	0.606
106709	S2	74.3	0.166
106709	N2	59.5	0.113
106709	K1	291	0.371
106709	M4	358	0.082
106709	O1	303.5	0.304
106709	M6	51.6	0.022
106709	MK3	224.3	0.11
106709	S4	166.9	0.019
106709	MN4	317.8	0.034
106709	S6	145.1	0.003
106709	2N2	110.8	0.032
106709	OO1	58	0.011
106709	M1	324.9	0.016
106709	J1	339.1	0.014
106709	Q1	279.6	0.045
106709	2Q1	347.9	0.017
106709	2SM2	339.6	0.007
106709	M3	82	0.009
106709	L2	116.3	0.021
106709	2MK3	253.3	0.042
106709	M8	60.6	0.011
106709	MS4	346.9	0.036
106710	M2	57.7	1.015
106710	S2	67	0.271
106710	N2	48	0.205
106710	K1	286.5	0.51
106710	M4	22.5	0.071
106710	O1	298.7	0.414
106710	M6	44.4	0.043
106710	MK3	286.3	0.092
106710	S4	160.3	0.031
106710	MN4	13.7	0.009
106710	S6	146.1	0.002
106710	2N2	102.6	0.06
106710	OO1	165	0.016
106710	M1	341.1	0.031
106710	J1	347.2	0.014
106710	Q1	285.1	0.062
106710	2Q1	263.7	0.028
106710	2SM2	160.7	0.024
106710	M3	226.1	0.028
106710	L2	127.2	0.029
106710	2MK3	334.4	0.058
106710	M8	25.2	0.025
106710	MS4	27.4	0.034
106711	M2	58.6	1.066
106711	S2	66.9	0.271
106711	N2	49.1	0.213
106711	K1	287.3	0.582
106711	M4	348	0.087
106711	O1	300	0.47
106711	M6	43.2	0.047
106711	MK3	254.2	0.071
106711	S4	162	0.034
106711	MN4	278.9	0.025
106711	S6	236.7	0.003
106711	2N2	120.8	0.075
106711	OO1	309.2	0.005
106711	M1	343.6	0.034
106711	J1	1.3	0.006
106711	Q1	279.8	0.068
106711	2Q1	330	0.026
106711	2SM2	220.2	0.021
106711	M3	232.6	0.03
106711	L2	133.5	0.035
106711	2MK3	333.2	0.03
106711	M8	18.3	0.028
106711	MS4	352	0.024
106712	M2	61.4	0.789
106712	S2	68.8	0.209
106712	N2	49.7	0.155
106712	K1	277.3	0.321
106712	M4	114.5	0.064
106712	O1	288.6	0.257
106712	M6	74.2	0.039
106712	MK3	338.2	0.124
106712	S4	155.7	0.032
106712	MN4	130.2	0.03
106712	2N2	110.6	0.046
106712	OO1	233.1	0.026
106712	M1	337.1	0.029
106712	J1	64.2	0.01
106712	Q1	269.9	0.036
106712	2Q1	242	0.017
106712	2SM2	188.1	0.013
106712	M3	236.2	0.03
106712	L2	137.8	0.023
106712	2MK3	6.8	0.078
106712	M8	65.2	0.013
106712	MS4	108.1	0.034
106713	M2	62.5	0.931
106713	S2	69.9	0.242
106713	N2	49	0.18
106713	K1	277.9	0.391
106713	M4	115.2	0.076
106713	O1	289.8	0.309
106713	M6	81.1	0.044
106713	MK3	339.5	0.143
106713	S4	162.9	0.037
106713	MN4	125.1	0.035
106713	S6	264	0.002
106713	2N2	118.6	0.048
106713	OO1	221.3	0.025
106713	M1	338.6	0.039
106713	J1	47.1	0.009
106713	Q1	268.3	0.041
106713	2Q1	264.3	0.018
106713	2SM2	178.5	0.015
106713	M3	237.4	0.037
106713	L2	132.4	0.027
106713	2MK3	8.6	0.093
106713	M8	77	0.012
106713	MS4	111.1	0.037
106714	M2	239.8	0.194
106714	S2	248.8	0.048
106714	N2	215	0.03
106714	K1	85.1	0.028
106714	M4	112.6	0.053
106714	O1	356.9	0.016
106714	M6	0.1	0.006
106714	MK3	300.4	0.048
106714	S4	208.1	0.002
106714	MN4	108.5	0.027
106714	S6	137	0.003
106714	2N2	151.1	0.021
106714	OO1	190.7	0.004
106714	M1	298.2	0.007
106714	J1	340.2	0.003
106714	Q1	0.8	0.003
106714	2Q1	182.5	0.003
106714	2SM2	291.8	0.013
106714	M3	343.2	0.007
106714	L2	238.5	0.019
106714	2MK3	276.5	0.019
106714	M8	186.8	0.006
106714	MS4	135	0.008
106715	M2	190.3	0.114
106715	S2	234.2	0.024
106715	N2	179.5	0.028
106715	K1	359.4	0.036
106715	M4	261.5	0.026
106715	O1	201.8	0.033
106715	M6	213.6	0.008
106715	MK3	142.1	0.054
106715	S4	82.5	0.012
106715	MN4	250.7	0.023
106715	S6	76.6	0.005
106715	2N2	59.8	0.01
106715	OO1	113.3	0.01
106715	M1	155.3	0.018
106715	J1	253.3	0.018
106715	Q1	144.9	0.009
106715	2Q1	13.5	0.015
106715	2SM2	218.2	0.013
106715	M3	276.3	0.008
106715	L2	275.8	0.007
106715	2MK3	81.8	0.024
106715	M8	221.5	0.011
106715	MS4	64.2	0.006
106716	M2	226	0.632
106716	S2	260.4	0.219
106716	N2	200.2	0.146
106716	K1	146.4	0.273
106716	M4	187.7	0.015
106716	O1	114.5	0.153
106716	M6	356.7	0.003
106716	MK3	165.7	0.016
106716	S4	34.2	0.001
106716	MN4	175.7	0.005
106716	S6	224.2	0.004
106716	2N2	142.3	0.048
106716	OO1	253.8	0.02
106716	M1	66.7	0.01
106716	J1	97.7	0.011
106716	Q1	123.9	0.02
106716	2Q1	167.5	0.01
106716	P1	154.6	0.061
106716	2SM2	210.7	0.01
106716	M3	21.7	0.007
106716	L2	233.9	0.028
106716	2MK3	164.7	0.019
106716	K2	262.9	0.052
106716	MS4	297.3	0.011
106717	M2	227.4	0.812
106717	S2	262.2	0.287
106717	N2	202.7	0.189
106717	K1	146.3	0.351
106717	M4	133.9	0.021
106717	O1	113.7	0.193
106717	M6	178.4	0.006
106717	MK3	172.3	0.011
106717	MN4	128	0.004
106717	S6	177.6	0.002
106717	2N2	142.2	0.056
106717	OO1	256.1	0.027
106717	M1	22.1	0.017
106717	J1	108.9	0.012
106717	Q1	112.9	0.026
106717	2Q1	163.5	0.011
106717	P1	155.2	0.076
106717	2SM2	200.9	0.011
106717	M3	4.4	0.007
106717	L2	244.2	0.034
106717	2MK3	160.3	0.021
106717	K2	268.3	0.076
106717	MS4	206.1	0.009
106718	M2	228.3	0.832
106718	S2	263.5	0.292
106718	N2	202.8	0.195
106718	K1	146.9	0.365
106718	M4	108.8	0.024
106718	O1	114.7	0.186
106718	M6	199.5	0.006
106718	MK3	172.9	0.011
106718	S4	238.5	0.005
106718	MN4	114.1	0.004
106718	S6	224.8	0.003
106718	2N2	145.6	0.054
106718	OO1	257.5	0.03
106718	M1	11.5	0.017
106718	J1	152.7	0.01
106718	Q1	124.3	0.02
106718	2Q1	185	0.008
106718	P1	161.8	0.077
106718	2SM2	189.1	0.01
106718	M3	336.4	0.003
106718	L2	249.8	0.033
106718	2MK3	160	0.019
106718	K2	267.6	0.079
106718	M8	189.9	0.001
106718	MS4	150.1	0.014
106719	M2	242.9	0.538
106719	S2	278.2	0.197
106719	N2	218.5	0.139
106719	K1	158.6	0.249
106719	M4	120.7	0.018
106719	O1	126.3	0.133
106719	M6	247.9	0.004
106719	MK3	141.9	0.006
106719	S4	287.6	0.004
106719	MN4	190.4	0.01
106719	S6	57.2	0.003
106719	2N2	204	0.044
106719	OO1	225.9	0.026
106719	M1	129.7	0.009
106719	J1	61.8	0.006
106719	Q1	133.1	0.015
106719	2Q1	4.7	0.01
106719	P1	162.1	0.096
106719	2SM2	257.3	0.005
106719	M3	24.1	0.011
106719	L2	250.4	0.031
106719	2MK3	133.6	0.016
106719	K2	277.1	0.054
106719	M8	89.7	0.003
106719	MS4	178.2	0.011
106720	M2	243.8	0.562
106720	S2	272.4	0.204
106720	N2	222	0.146
106720	K1	162.4	0.278
106720	M4	208.2	0.02
106720	O1	117.5	0.142
106720	M6	262.9	0.006
106720	MK3	86.4	0.015
106720	S4	329.8	0.007
106720	MN4	242.3	0.006
106720	S6	55.6	0.004
106720	2N2	196	0.052
106720	OO1	244.9	0.037
106720	M1	44.9	0.012
106720	J1	59.9	0.007
106720	Q1	105.4	0.017
106720	2Q1	67	0.01
106720	P1	153.2	0.094
106720	2SM2	125.6	0.008
106720	M3	234.3	0.01
106720	L2	287.7	0.018
106720	2MK3	312.3	0.011
106720	K2	281	0.055
106720	M8	30.8	0.004
106720	MS4	196.8	0.011
106721	M2	242.9	0.594
106721	S2	273.1	0.226
106721	N2	217.1	0.15
106721	K1	166.3	0.314
106721	M4	204.3	0.044
106721	O1	121.2	0.133
106721	M6	309.9	0.017
106721	MK3	147.9	0.011
106721	S4	268.5	0.004
106721	MN4	182.5	0.02
106721	S6	55.5	0.004
106721	2N2	194.4	0.07
106721	OO1	258.3	0.03
106721	M1	16.2	0.024
106721	J1	191.5	0.016
106721	Q1	113.3	0.019
106721	2Q1	73.3	0.019
106721	P1	137.8	0.043
106721	2SM2	180.9	0.01
106721	L2	319.2	0.013
106721	2MK3	313.7	0.008
106721	K2	286.6	0.061
106721	M8	82.3	0.004
106721	MS4	251.2	0.015
106722	M2	234.8	0.847
106722	S2	267.4	0.321
106722	N2	212.3	0.204
106722	K1	163.8	0.384
106722	M4	312.1	0.059
106722	O1	135.3	0.157
106722	M6	301	0.015
106722	MK3	258.6	0.088
106722	S4	34.1	0.008
106722	MN4	286.8	0.03
106722	S6	147.6	0.005
106722	2N2	194.1	0.09
106722	OO1	244.2	0.039
106722	M1	39.1	0.022
106722	J1	140.2	0.014
106722	Q1	149.4	0.017
106722	2Q1	75.3	0.023
106722	P1	172.3	0.062
106722	2SM2	212	0.01
106722	M3	197.1	0.01
106722	L2	261.2	0.008
106722	2MK3	217.8	0.022
106722	K2	280.8	0.077
106722	M8	337.6	0.013
106722	MS4	31.6	0.032
106723	M2	236.2	0.928
106723	S2	267.4	0.35
106723	N2	212.7	0.216
106723	K1	163.5	0.389
106723	M4	297.9	0.053
106723	O1	133.7	0.154
106723	M6	311.8	0.022
106723	MK3	254.2	0.091
106723	S4	42.3	0.004
106723	MN4	293	0.035
106723	S6	89.4	0.008
106723	2N2	190.7	0.093
106723	OO1	249.3	0.039
106723	M1	17.1	0.019
106723	J1	138.6	0.012
106723	Q1	137.6	0.009
106723	2Q1	68.9	0.025
106723	P1	163.7	0.091
106723	2SM2	217.4	0.015
106723	M3	132.5	0.006
106723	L2	282.6	0.027
106723	2MK3	209	0.049
106723	K2	279.2	0.103
106723	M8	3.1	0.003
106723	MS4	0.3	0.019
106724	M2	235.6	0.952
106724	S2	270.1	0.35
106724	N2	212	0.228
106724	K1	166.6	0.364
106724	M4	303.9	0.051
106724	O1	141.1	0.155
106724	M6	313.7	0.024
106724	MK3	250.5	0.081
106724	S4	16.8	0.007
106724	MN4	306.4	0.03
106724	S6	168.8	0.003
106724	2N2	190.7	0.094
106724	OO1	251.6	0.037
106724	M1	36	0.009
106724	J1	155.3	0.013
106724	Q1	249	0.01
106724	2Q1	42.4	0.029
106724	P1	154.3	0.119
106724	2SM2	219.8	0.011
106724	M3	206.9	0.009
106724	L2	268.7	0.049
106724	2MK3	214.2	0.053
106724	K2	284.1	0.112
106724	M8	148.9	0.003
106724	MS4	346.2	0.021
106725	M2	236.6	0.421
106725	S2	268.6	0.118
106725	N2	215.2	0.093
106725	K1	172.3	0.375
106725	M4	79.7	0.015
106725	O1	127.8	0.189
106725	M6	125.7	0.005
106725	MK3	344.7	0.041
106725	S4	342.7	0.016
106725	MN4	83.6	0.011
106725	S6	153.4	0.008
106725	2N2	242.3	0.044
106725	OO1	131.8	0.012
106725	M1	171.8	0.014
106725	J1	171.5	0.033
106725	Q1	123.9	0.037
106725	2Q1	79.8	0.008
106725	P1	164.2	0.102
106725	2SM2	222.2	0.001
106725	M3	256.3	0.017
106725	L2	177.7	0.045
106725	2MK3	138.8	0.025
106725	K2	273.8	0.031
106725	M8	342.5	0.009
106725	MS4	291.1	0.014
106726	M2	253.9	0.499
106726	S2	288	0.187
106726	N2	238.8	0.14
106726	K1	180.9	0.369
106726	M4	250.4	0.022
106726	O1	132.4	0.181
106726	M6	87	0.009
106726	MK3	229.9	0.011
106726	S4	352.6	0.012
106726	MN4	51.1	0.007
106726	S6	211	0.013
106726	2N2	230.1	0.061
106726	OO1	307.5	0.005
106726	M1	167.8	0.021
106726	J1	169.5	0.031
106726	Q1	129.9	0.03
106726	2Q1	159.1	0.016
106726	P1	164.6	0.181
106726	2SM2	278.6	0.012
106726	M3	172.2	0.004
106726	L2	103.5	0.005
106726	2MK3	123.6	0.013
106726	K2	290.2	0.059
106726	M8	74.8	0.008
106726	MS4	237.7	0.044
106727	M2	258.6	0.456
106727	S2	311.7	0.17
106727	N2	235.7	0.097
106727	K1	169.1	0.297
106727	M4	242.7	0.044
106727	O1	123.3	0.208
106727	M6	358	0.024
106727	MK3	176.7	0.075
106727	S4	275.5	0.012
106727	MN4	296.7	0.006
106727	S6	100.8	0.009
106727	2N2	195.4	0.062
106727	OO1	327.5	0.009
106727	M1	137.1	0.024
106727	J1	78.7	0.009
106727	Q1	96.6	0.03
106727	2Q1	51.3	0.017
106727	P1	185	0.198
106727	2SM2	272.7	0.019
106727	M3	144.7	0.03
106727	L2	290.7	0.007
106727	2MK3	170.4	0.014
106727	K2	327.6	0.055
106727	M8	26.3	0.009
106727	MS4	241.3	0.042
106728	M2	72.4	0.023
106728	S2	70	0.006
106728	N2	266.5	0.01
106728	K1	146.5	0.083
106728	M4	4.9	0.01
106728	O1	142.5	0.058
106728	M6	262.1	0.006
106728	MK3	192.5	0.003
106728	S4	14.9	0.006
106728	MN4	157	0.007
106728	S6	208.2	0.006
106728	2N2	47.6	0.033
106728	OO1	115.6	0.009
106728	M1	59.5	0.012
106728	J1	43.5	0.01
106728	Q1	30.5	0.008
106728	2Q1	170.5	0.021
106728	2SM2	341.1	0.019
106728	M3	132.3	0.011
106728	L2	100.4	0.015
106728	2MK3	191.7	0.008
106728	M8	198.7	0.003
106728	MS4	356.1	0.011
106729	M2	219.4	0.102
106729	S2	277.7	0.044
106729	N2	185.8	0.04
106729	K1	157.8	0.088
106729	M4	172.1	0.013
106729	O1	129.5	0.045
106729	M6	19.1	0.005
106729	MK3	28.1	0.02
106729	S4	179.3	0.008
106729	MN4	39.6	0.004
106729	S6	345.8	0.001
106729	2N2	288.1	0.036
106729	OO1	288.7	0.002
106729	M1	74.6	0.025
106729	J1	18.8	0.013
106729	Q1	11.1	0.007
106729	2Q1	68.2	0.023
106729	2SM2	238.5	0.009
106729	M3	311.4	0.019
106729	L2	275.7	0.013
106729	2MK3	7.2	0.024
106729	M8	22.6	0.002
106729	MS4	200.9	0.016
106730	M2	177.7	0.646
106730	S2	225.6	0.242
106730	N2	146.6	0.151
106730	K1	132.6	0.09
106730	M4	196.2	0.121
106730	O1	113.5	0.094
106730	M6	263.5	0.068
106730	MK3	163.7	0.055
106730	S4	324.3	0.015
106730	MN4	129.3	0.053
106730	S6	84.9	0.011
106730	2N2	62.3	0.021
106730	OO1	157.8	0.018
106730	M1	97	0.023
106730	J1	45	0.039
106730	Q1	76.1	0.016
106730	2Q1	199.7	0.018
106730	2SM2	22.2	0.003
106730	M3	61.5	0.02
106730	L2	228.1	0.029
106730	2MK3	118.6	0.075
106730	M8	293.9	0.051
106730	MS4	249.1	0.075
106731	M2	185.6	0.664
106731	S2	236.9	0.255
106731	N2	152.6	0.135
106731	K1	156.7	0.111
106731	M4	187.3	0.144
106731	O1	127.5	0.11
106731	M6	236.5	0.086
106731	MK3	141.6	0.059
106731	S4	290.6	0.021
106731	MN4	142.6	0.065
106731	S6	92.2	0.013
106731	2N2	65.6	0.028
106731	OO1	79.7	0.006
106731	M1	79	0.023
106731	J1	30.5	0.036
106731	Q1	196.8	0.013
106731	2Q1	286.6	0.016
106731	2SM2	97.4	0.013
106731	M3	53.1	0.033
106731	L2	258	0.014
106731	2MK3	121.4	0.078
106731	M8	273.7	0.046
106731	MS4	247.7	0.078
106732	M2	188.3	0.689
106732	S2	241.8	0.279
106732	N2	157.2	0.137
106732	K1	164.5	0.13
106732	M4	191.2	0.168
106732	O1	129.1	0.123
106732	M6	231.4	0.089
106732	MK3	137.5	0.071
106732	S4	287	0.013
106732	MN4	147.6	0.077
106732	S6	74.5	0.01
106732	2N2	44.6	0.048
106732	OO1	52	0.006
106732	M1	40.5	0.016
106732	J1	36.3	0.018
106732	Q1	166.7	0.029
106732	2Q1	296.6	0.024
106732	2SM2	147.4	0.025
106732	M3	65.6	0.054
106732	L2	257.2	0.024
106732	2MK3	130.3	0.085
106732	M8	254.8	0.047
106732	MS4	252.4	0.089
106733	M2	214.4	0.409
106733	S2	224.6	0.167
106733	N2	168.2	0.133
106733	K1	246.9	0.273
106733	M4	335.5	0.015
106733	O1	216.7	0.165
106733	M6	3.8	0.01
106733	MK3	323.6	0.034
106733	S4	232.5	0.025
106733	MN4	208.8	0.019
106733	S6	66.9	0.009
106733	2N2	178.7	0.023
106733	OO1	256.8	0.016
106733	M1	131.4	0.018
106733	J1	51	0.029
106733	Q1	147.2	0.021
106733	2Q1	318.4	0.014
106733	P1	277.2	0.074
106733	2SM2	46	0.021
106733	M3	197.8	0.018
106733	L2	317.5	0.002
106733	2MK3	285.9	0.006
106733	K2	261.9	0.036
106733	M8	346.1	0.006
106733	MS4	180.4	0.018
106734	M2	230.2	0.428
106734	S2	250.9	0.183
106734	N2	192.4	0.128
106734	K1	250.7	0.353
106734	M4	113.6	0.036
106734	O1	228.3	0.256
106734	M6	196.3	0.004
106734	MK3	339.8	0.012
106734	S4	213.2	0.009
106734	MN4	146.7	0.006
106734	S6	126.1	0.006
106734	2N2	199.9	0.023
106734	OO1	332.2	0.009
106734	M1	248.2	0.021
106734	J1	94.3	0.01
106734	Q1	155.7	0.056
106734	2Q1	212.4	0.016
106734	P1	272.1	0.024
106734	2SM2	76.1	0.013
106734	M3	73.6	0.016
106734	L2	98.7	0.03
106734	2MK3	60.8	0.023
106734	K2	245.9	0.064
106734	M8	51.5	0.007
106734	MS4	192.5	0.022
106735	M2	236.5	0.409
106735	S2	300.2	0.171
106735	N2	230.7	0.096
106735	K1	253.1	0.381
106735	M4	93.4	0.066
106735	O1	225.2	0.256
106735	M6	169.3	0.016
106735	MK3	40.9	0.035
106735	S4	197.4	0.008
106735	MN4	64.1	0.049
106735	S6	47.3	0.006
106735	2N2	218.3	0.061
106735	OO1	6.3	0.027
106735	M1	302.1	0.032
106735	J1	281.4	0.043
106735	Q1	200.9	0.067
106735	2Q1	124.4	0.033
106735	P1	282.2	0.054
106735	2SM2	79.3	0.018
106735	M3	77.5	0.008
106735	L2	234.4	0.015
106735	2MK3	59.6	0.039
106735	K2	146.2	0.087
106735	M8	318.6	0.005
106735	MS4	107	0.009
106736	M2	194.3	1.213
106736	S2	223.2	0.385
106736	N2	166	0.247
106736	K1	153.5	0.344
106736	M4	295	0.044
106736	O1	157.2	0.201
106736	M6	79	0.108
106736	MK3	191	0.073
106736	S4	212.2	0.012
106736	MN4	237.2	0.013
106736	S6	200.3	0.004
106736	2N2	77	0.035
106736	OO1	299.8	0.031
106736	M1	117.1	0.015
106736	J1	96.6	0.018
106736	Q1	125.9	0.028
106736	2Q1	271.9	0.039
106736	P1	131.3	0.083
106736	2SM2	96.6	0.022
106736	M3	133.4	0.012
106736	L2	216.8	0.049
106736	2MK3	99.4	0.04
106736	K2	213	0.132
106736	M8	231.9	0.035
106736	MS4	272.3	0.052
106737	M2	195.1	1.306
106737	S2	222.9	0.412
106737	N2	165.4	0.266
106737	K1	152.2	0.363
106737	M4	304.8	0.053
106737	O1	155.3	0.208
106737	M6	79	0.118
106737	MK3	189.7	0.084
106737	S4	205.1	0.017
106737	MN4	272.8	0.01
106737	S6	192.2	0.006
106737	2N2	59.5	0.026
106737	OO1	303.9	0.031
106737	M1	119	0.017
106737	J1	113.9	0.013
106737	Q1	113.7	0.033
106737	2Q1	264.3	0.038
106737	P1	128.8	0.097
106737	2SM2	105.1	0.025
106737	M3	108.1	0.019
106737	L2	228.6	0.052
106737	2MK3	101.7	0.046
106737	K2	213.1	0.149
106737	M8	240.8	0.037
106737	MS4	264.6	0.058
106738	M2	195.7	1.358
106738	S2	222.1	0.428
106738	N2	165.7	0.278
106738	K1	151.1	0.366
106738	M4	308.1	0.054
106738	O1	153.2	0.211
106738	M6	77.8	0.124
106738	MK3	184.6	0.087
106738	S4	193.3	0.018
106738	MN4	298.1	0.007
106738	S6	198.7	0.006
106738	2N2	34.2	0.021
106738	OO1	308.2	0.029
106738	M1	111.9	0.02
106738	J1	143.7	0.011
106738	Q1	99.9	0.037
106738	2Q1	249.4	0.04
106738	P1	126	0.104
106738	2SM2	97.5	0.028
106738	M3	93.7	0.023
106738	L2	238.7	0.055
106738	2MK3	97.5	0.051
106738	K2	215	0.166
106738	M8	246.6	0.043
106738	MS4	252.6	0.062
106739	M2	196.2	0.452
106739	S2	247.7	0.142
106739	N2	167.1	0.114
106739	K1	193.5	0.183
106739	M4	112.8	0.046
106739	O1	135.2	0.135
106739	M6	72.5	0.055
106739	MK3	142.5	0.044
106739	S4	143	0.024
106739	MN4	72.6	0.026
106739	S6	300.7	0.002
106739	2N2	103.1	0.022
106739	OO1	344	0.015
106739	M1	26.5	0.044
106739	J1	64.2	0.02
106739	Q1	212.8	0.018
106739	2Q1	213.4	0.02
106739	P1	123.3	0.096
106739	2SM2	128.9	0.011
106739	M3	277	0.038
106739	L2	309	0.003
106739	2MK3	179.1	0.001
106739	K2	270.6	0.046
106739	M8	318.9	0.007
106739	MS4	157.3	0.013
106740	M2	207.2	0.586
106740	S2	238.9	0.227
106740	N2	175.2	0.136
106740	K1	175.4	0.247
106740	M4	101.8	0.074
106740	O1	134.2	0.123
106740	M6	61	0.025
106740	MK3	96.5	0.044
106740	S4	87.6	0.012
106740	MN4	74.4	0.046
106740	S6	61.1	0.004
106740	2N2	105.2	0.059
106740	OO1	293.4	0.016
106740	M1	23.6	0.049
106740	J1	59.4	0.034
106740	Q1	199.1	0.017
106740	2Q1	213.4	0.014
106740	P1	104.8	0.055
106740	2SM2	229.4	0.009
106740	M3	271	0.03
106740	L2	298.8	0.025
106740	2MK3	171.1	0.015
106740	K2	244.2	0.073
106740	M8	20.8	0.02
106740	MS4	122.8	0.035
106741	M2	209.3	0.723
106741	S2	236.7	0.276
106741	N2	170.5	0.138
106741	K1	165.7	0.226
106741	M4	103.1	0.098
106741	O1	146.1	0.122
106741	M6	359.2	0.014
106741	MK3	49.8	0.025
106741	S4	186.6	0.013
106741	MN4	78.4	0.056
106741	S6	8.1	0.009
106741	2N2	101.8	0.078
106741	OO1	271.2	0.035
106741	M1	37	0.032
106741	J1	86.1	0.037
106741	Q1	181.9	0.027
106741	2Q1	234.6	0.019
106741	P1	120.2	0.056
106741	2SM2	239.3	0.026
106741	M3	254.9	0.017
106741	L2	302.4	0.045
106741	2MK3	196.2	0.015
106741	K2	246.6	0.093
106741	M8	5.5	0.015
106741	MS4	123.4	0.054
106742	M2	196.8	1.828
106742	S2	228.4	0.632
106742	N2	171.5	0.374
106742	K1	151.2	0.56
106742	M4	134.9	0.137
106742	O1	134.3	0.312
106742	M6	86.5	0.086
106742	MK3	128.2	0.132
106742	S4	210.3	0.022
106742	MN4	121.2	0.064
106742	S6	189.4	0.002
106742	2N2	99.7	0.084
106742	OO1	243.1	0.034
106742	M1	64.4	0.017
106742	J1	79.5	0.024
106742	Q1	123.8	0.056
106742	2Q1	261.3	0.025
106742	P1	131.8	0.134
106742	2SM2	139.4	0.017
106742	M3	30.5	0.026
106742	L2	236.3	0.068
106742	2MK3	95.4	0.111
106742	K2	223.5	0.198
106742	M8	325.3	0.02
106742	MS4	216.7	0.101
106743	M2	195.9	2.015
106743	S2	226.8	0.691
106743	N2	170.7	0.414
106743	K1	149.1	0.591
106743	M4	104.6	0.148
106743	O1	128.9	0.32
106743	M6	89.6	0.09
106743	MK3	122.7	0.107
106743	S4	208.8	0.023
106743	MN4	91.8	0.065
106743	S6	15.9	0.004
106743	2N2	96.1	0.086
106743	OO1	236.2	0.036
106743	M1	54.3	0.02
106743	J1	75.7	0.022
106743	Q1	118.3	0.056
106743	2Q1	260.3	0.022
106743	P1	132.4	0.151
106743	2SM2	117.3	0.019
106743	M3	25.2	0.025
106743	L2	234.2	0.08
106743	2MK3	92.5	0.106
106743	K2	220.7	0.22
106743	M8	305.7	0.03
106743	MS4	191.7	0.082
106744	M2	194.9	2.111
106744	S2	225.2	0.709
106744	N2	169	0.436
106744	K1	148.1	0.579
106744	M4	89.1	0.18
106744	O1	129.6	0.303
106744	M6	82.5	0.07
106744	MK3	110	0.113
106744	S4	206.1	0.026
106744	MN4	76.8	0.078
106744	S6	2.7	0.005
106744	2N2	86.4	0.07
106744	OO1	232.9	0.039
106744	M1	30.9	0.019
106744	J1	82.5	0.015
106744	Q1	126.9	0.048
106744	2Q1	263.3	0.016
106744	P1	133.4	0.161
106744	2SM2	129.1	0.027
106744	M3	32.9	0.025
106744	L2	223.3	0.087
106744	2MK3	85.2	0.116
106744	K2	215.9	0.236
106744	M8	302.9	0.022
106744	MS4	160.6	0.1
106745	M2	265	0.203
106745	S2	314.1	0.08
106745	N2	241	0.055
106745	K1	298.8	0.076
106745	M4	35.1	0.012
106745	O1	267.9	0.048
106745	M6	309.1	0.011
106745	MK3	352.7	0.023
106745	S4	254.4	0.002
106745	MN4	9.1	0.006
106745	S6	262.4	0.001
106745	2N2	235.1	0.027
106745	OO1	37.1	0.013
106745	M1	220.1	0.008
106745	J1	235.3	0.005
106745	Q1	247.4	0.006
106745	2Q1	34.9	0.003
106745	P1	251.5	0.028
106745	2SM2	184.4	0.002
106745	M3	255.9	0.005
106745	L2	238.8	0.008
106745	2MK3	307.9	0.014
106745	K2	321.9	0.018
106745	M8	200.1	0.003
106745	MS4	83.3	0.007
106746	M2	279.9	0.281
106746	S2	315.7	0.103
106746	N2	247.3	0.071
106746	K1	273.7	0.067
106746	M4	15.2	0.004
106746	O1	263.2	0.049
106746	M6	342.1	0.01
106746	MK3	331.1	0.024
106746	S4	124.9	0.005
106746	MN4	187.5	0.001
106746	S6	306.9	0.001
106746	2N2	223.5	0.04
106746	OO1	343	0.008
106746	M1	235.6	0.008
106746	J1	209.9	0.005
106746	Q1	252.8	0.011
106746	2Q1	55.9	0.006
106746	P1	290	0.041
106746	2SM2	153.9	0.005
106746	M3	219.4	0.01
106746	L2	127.6	0.003
106746	2MK3	302.1	0.014
106746	K2	300.2	0.023
106746	M8	321.9	0.002
106746	MS4	114.4	0.002
106747	M2	286.9	0.313
106747	S2	320	0.099
106747	N2	266.9	0.069
106747	K1	240.2	0.074
106747	M4	287.6	0.014
106747	O1	260.3	0.037
106747	M6	259.8	0.002
106747	MK3	337.2	0.023
106747	S4	326.9	0.005
106747	MN4	286.4	0.003
106747	S6	26.8	0.003
106747	2N2	280.6	0.033
106747	OO1	351.1	0.009
106747	M1	163.2	0.009
106747	J1	154.4	0.014
106747	Q1	258.1	0.007
106747	2Q1	139	0.007
106747	P1	320.2	0.043
106747	2SM2	323.6	0.013
106747	M3	258.4	0.008
106747	L2	77.3	0.012
106747	2MK3	276	0.015
106747	K2	331.1	0.014
106747	M8	61.3	0.002
106747	MS4	324	0.01
106748	M2	250.9	0.589
106748	S2	292.7	0.159
106748	N2	226.5	0.156
106748	K1	265.5	0.07
106748	M4	55.3	0.076
106748	O1	225.4	0.063
106748	M6	289.3	0.034
106748	MK3	194.2	0.02
106748	S4	278.8	0.011
106748	MN4	33.7	0.034
106748	S6	284.8	0.005
106748	2N2	221.2	0.048
106748	OO1	206	0.002
106748	M1	202	0.027
106748	J1	290.1	0.026
106748	Q1	1.4	0.011
106748	2Q1	214.9	0.01
106748	2SM2	45.2	0.016
106748	M3	324.4	0.016
106748	L2	338.6	0.028
106748	2MK3	61	0.021
106748	M8	49.5	0.015
106748	MS4	90.9	0.041
106749	M2	247.1	0.61
106749	S2	283.6	0.172
106749	N2	223.2	0.177
106749	K1	258.6	0.101
106749	M4	20	0.051
106749	O1	211.3	0.075
106749	M6	240.2	0.017
106749	MK3	264.8	0.006
106749	S4	189.8	0.011
106749	MN4	340.5	0.03
106749	S6	179	0.003
106749	2N2	225.1	0.052
106749	OO1	281.8	0.008
106749	M1	229	0.026
106749	J1	262.1	0.016
106749	Q1	40.2	0.003
106749	2Q1	229.3	0.032
106749	2SM2	88.5	0.015
106749	M3	18.5	0.012
106749	L2	51.5	0.018
106749	2MK3	285.5	0.01
106749	M8	320.6	0.007
106749	MS4	59.9	0.03
106750	M2	245.4	0.564
106750	S2	274.3	0.135
106750	N2	213.5	0.143
106750	K1	256.3	0.111
106750	M4	315	0.015
106750	O1	213.6	0.076
106750	M6	299.8	0.006
106750	MK3	195.6	0.024
106750	S4	8.3	0.006
106750	MN4	280.7	0.012
106750	S6	334.4	0.008
106750	2N2	205.4	0.085
106750	OO1	127.4	0.003
106750	M1	229.5	0.015
106750	J1	270.2	0.017
106750	Q1	5	0.011
106750	2Q1	211.5	0.022
106750	2SM2	71.8	0.003
106750	M3	355	0.014
106750	L2	8.6	0.022
106750	2MK3	141.5	0.016
106750	M8	260.1	0.004
106750	MS4	354.8	0.02
106751	M2	234.4	0.369
106751	S2	265	0.186
106751	N2	238.7	0.087
106751	K1	198.5	0.098
106751	M4	344.6	0.043
106751	O1	191.2	0.044
106751	M6	273.7	0.017
106751	MK3	237.4	0.012
106751	S4	207.2	0.008
106751	MN4	332.2	0.018
106751	S6	298.8	0.001
106751	2N2	280.7	0.014
106751	OO1	341	0.009
106751	M1	48.6	0.015
106751	J1	120.4	0.017
106751	Q1	244.2	0.015
106751	2Q1	286.5	0.029
106751	P1	276.2	0.024
106751	2SM2	198.9	0.015
106751	M3	320.3	0.003
106751	L2	244.9	0.037
106751	2MK3	56.3	0.005
106751	K2	261.7	0.096
106751	M8	58.7	0.004
106751	MS4	71.8	0.01
106752	M2	237.1	0.376
106752	S2	277	0.165
106752	N2	216.8	0.086
106752	K1	189.9	0.091
106752	M4	354.5	0.031
106752	O1	188.8	0.048
106752	M6	215.2	0.01
106752	MK3	35	0.011
106752	S4	13.2	0.007
106752	MN4	310.7	0.014
106752	S6	115	0.005
106752	2N2	217.4	0.034
106752	OO1	112.8	0.006
106752	M1	92.1	0.017
106752	J1	162.2	0.011
106752	Q1	258.9	0.007
106752	2Q1	276.8	0.035
106752	P1	288.7	0.036
106752	2SM2	351.2	0.01
106752	M3	297.8	0.008
106752	L2	227.2	0.028
106752	2MK3	239.9	0.002
106752	K2	262.9	0.063
106752	M8	155.7	0.001
106752	MS4	56.8	0.024
106753	M2	242.1	0.342
106753	S2	285.1	0.15
106753	N2	218.6	0.102
106753	K1	168.3	0.092
106753	M4	328.5	0.028
106753	O1	179.6	0.027
106753	M6	214.3	0.004
106753	MK3	332.5	0.015
106753	S4	249.3	0.001
106753	MN4	57.2	0.003
106753	S6	200.8	0.003
106753	2N2	204.9	0.04
106753	OO1	250.4	0.012
106753	M1	109.5	0.018
106753	J1	182.5	0.008
106753	Q1	149	0.009
106753	2Q1	340	0.008
106753	P1	288.8	0.07
106753	2SM2	322.2	0.019
106753	M3	237	0.004
106753	L2	180.2	0.015
106753	2MK3	323.7	0.011
106753	K2	303.6	0.042
106753	M8	18.7	0.004
106753	MS4	5.6	0.012
106754	M2	229.7	0.094
106754	S2	258.6	0.077
106754	N2	217.2	0.007
106754	K1	36	0.079
106754	M4	92.8	0.028
106754	O1	95.8	0.032
106754	M6	132	0.008
106754	MK3	35.7	0.03
106754	S4	272.2	0.01
106754	MN4	6.8	0.008
106754	S6	352	0.007
106754	2N2	69.1	0.128
106754	OO1	28	0.024
106754	M1	219.7	0.012
106754	J1	219.9	0.023
106754	Q1	63.3	0.01
106754	2Q1	35.3	0.011
106754	2SM2	164.7	0.05
106754	M3	268.1	0.011
106754	L2	306.8	0.058
106754	2MK3	333.9	0.01
106754	M8	266.9	0.002
106754	MS4	156.2	0.029
106755	M2	173.4	0.105
106755	S2	240.1	0.099
106755	N2	140.7	0.029
106755	K1	45.2	0.084
106755	M4	77.6	0.044
106755	O1	81.2	0.036
106755	M6	322.8	0.002
106755	MK3	4.8	0.028
106755	S4	94.4	0.008
106755	MN4	91	0.025
106755	S6	51.4	0.007
106755	2N2	67.8	0.113
106755	OO1	1.5	0.026
106755	M1	267.1	0.009
106755	J1	218	0.012
106755	Q1	57.4	0.014
106755	2Q1	65.3	0.01
106755	2SM2	131.2	0.044
106755	M3	290	0.01
106755	L2	316	0.043
106755	2MK3	339.3	0.011
106755	M8	162.9	0.004
106755	MS4	160.2	0.031
106756	M2	151.6	0.133
106756	S2	234.5	0.111
106756	N2	130.2	0.042
106756	K1	51.2	0.096
106756	M4	73.8	0.044
106756	O1	70.7	0.043
106756	M6	249.2	0.004
106756	MK3	18.7	0.029
106756	S4	118.1	0.02
106756	MN4	89.4	0.018
106756	S6	117.9	0.003
106756	2N2	70.4	0.098
106756	OO1	352.6	0.025
106756	M1	325.4	0.018
106756	J1	181.6	0.004
106756	Q1	63.4	0.013
106756	2Q1	92.1	0.015
106756	2SM2	112.5	0.022
106756	M3	336.5	0.009
106756	L2	338.3	0.041
106756	2MK3	78.6	0.009
106756	M8	219.4	0.002
106756	MS4	165.5	0.03
106757	M2	233.8	1.383
106757	S2	272.1	0.541
106757	N2	209.7	0.316
106757	K1	186.5	0.235
106757	M4	82	0.204
106757	O1	153.3	0.137
106757	M6	326.1	0.034
106757	MK3	19.7	0.108
106757	S4	233.7	0.018
106757	MN4	59	0.085
106757	S6	312.4	0.005
106757	2N2	209.3	0.093
106757	OO1	86.8	0.005
106757	M1	221.8	0.007
106757	J1	209.9	0.02
106757	Q1	156.4	0.025
106757	2Q1	199.8	0.018
106757	P1	187	0.067
106757	2SM2	331.7	0.011
106757	M3	322.9	0.023
106757	L2	185.2	0.042
106757	2MK3	350.6	0.051
106757	K2	265.2	0.131
106757	M8	57.6	0.019
106757	MS4	126	0.091
106758	M2	232.3	1.344
106758	S2	267.3	0.433
106758	N2	213	0.315
106758	K1	188.9	0.221
106758	M4	70.1	0.175
106758	O1	157.8	0.121
106758	M6	281	0.018
106758	MK3	20.3	0.089
106758	S4	251.3	0.007
106758	MN4	63.6	0.069
106758	S6	201.9	0.003
106758	2N2	217	0.053
106758	OO1	167.5	0.003
106758	M1	207.5	0.007
106758	J1	213	0.023
106758	Q1	137.2	0.026
106758	2Q1	190	0.008
106758	P1	179.8	0.057
106758	2SM2	45.8	0.013
106758	M3	325.6	0.02
106758	L2	218.7	0.044
106758	2MK3	347.3	0.032
106758	K2	246.6	0.108
106758	M8	11.7	0.016
106758	MS4	114.2	0.06
106759	M2	232.1	1.291
106759	S2	266.2	0.386
106759	N2	214.4	0.296
106759	K1	190.5	0.201
106759	M4	64.3	0.148
106759	O1	165.3	0.109
106759	M6	285.4	0.015
106759	MK3	23.1	0.074
106759	S4	257.9	0.008
106759	MN4	64.8	0.057
106759	S6	186.7	0.005
106759	2N2	218.4	0.03
106759	OO1	192.2	0.006
106759	M1	185.9	0.002
106759	J1	212.6	0.022
106759	Q1	137.6	0.022
106759	2Q1	213.9	0.007
106759	P1	183.2	0.062
106759	2SM2	73.2	0.014
106759	M3	333.8	0.011
106759	L2	235.1	0.051
106759	2MK3	13.7	0.024
106759	K2	240.3	0.101
106759	M8	30.4	0.01
106759	MS4	104.7	0.047
106760	M2	259.1	0.341
106760	S2	314.2	0.104
106760	N2	235	0.095
106760	K1	220.4	0.044
106760	M4	293	0.01
106760	O1	188.7	0.018
106760	M6	326.2	0.01
106760	MK3	144.7	0.015
106760	S4	61.3	0.016
106760	MN4	303	0.011
106760	S6	164.2	0.009
106760	2N2	200.2	0.024
106760	OO1	295.3	0.002
106760	M1	137.1	0.006
106760	J1	88.8	0.005
106760	Q1	263.5	0.006
106760	2Q1	304.6	0.011
106760	2SM2	313.3	0.019
106760	M3	317.1	0.009
106760	L2	105.7	0.01
106760	2MK3	103	0.007
106760	M8	177.9	0.005
106760	MS4	97.4	0.014
106761	M2	252.6	0.379
106761	S2	282.4	0.142
106761	N2	248.2	0.114
106761	K1	212.1	0.049
106761	M4	287.2	0.007
106761	O1	191.7	0.02
106761	M6	269.7	0.01
106761	MK3	134.5	0.006
106761	S4	205.6	0.012
106761	MN4	29.5	0.005
106761	S6	5.2	0.002
106761	2N2	260.4	0.011
106761	OO1	235.2	0.008
106761	M1	151.7	0.004
106761	J1	64.6	0.003
106761	Q1	155	0.005
106761	2Q1	301.4	0.02
106761	2SM2	52.8	0.002
106761	M3	309.6	0.012
106761	L2	1.7	0.021
106761	2MK3	137.9	0.006
106761	M8	77.3	0.002
106761	MS4	98.7	0.009
106762	M2	221.8	0.312
106762	S2	262.1	0.107
106762	N2	165.8	0.113
106762	K1	216.2	0.032
106762	M4	209.9	0.011
106762	O1	195.2	0.026
106762	M6	251	0.006
106762	MK3	118	0.016
106762	S4	275.6	0.011
106762	MN4	240	0.007
106762	S6	354.8	0.005
106762	2N2	168	0.036
106762	OO1	304.7	0.008
106762	M1	160.8	0.002
106762	J1	171	0.004
106762	Q1	202	0.013
106762	2Q1	251	0.015
106762	2SM2	219.4	0.024
106762	M3	80.9	0.001
106762	L2	6.4	0.022
106762	2MK3	88.9	0.015
106762	M8	190	0.004
106762	MS4	174	0.005
106763	M2	256	0.111
106763	S2	324.1	0.059
106763	N2	217.4	0.019
106763	K1	284.9	0.081
106763	M4	313.3	0.013
106763	O1	249.3	0.036
106763	M6	153.6	0.004
106763	MK3	109.5	0.01
106763	S4	19.2	0.007
106763	MN4	247	0.007
106763	S6	126.3	0.002
106763	2N2	252.3	0.003
106763	OO1	43.6	0.007
106763	M1	16.5	0.003
106763	J1	309.4	0.01
106763	Q1	256.3	0.009
106763	2Q1	277.2	0.005
106763	P1	31.3	0.013
106763	2SM2	101.7	0.014
106763	M3	345.6	0.005
106763	L2	336.5	0.016
106763	2MK3	94.3	0.012
106763	K2	85.3	0.013
106763	M8	344.3	0.001
106763	MS4	28.6	0.009
106764	M2	293.5	0.101
106764	S2	346.5	0.061
106764	N2	251.7	0.021
106764	K1	286.1	0.059
106764	M4	282.8	0.019
106764	O1	253.6	0.036
106764	M6	258.5	0.006
106764	MK3	183	0.014
106764	S4	350.8	0.007
106764	MN4	236.8	0.008
106764	S6	129.6	0.001
106764	2N2	15.9	0.006
106764	OO1	25.9	0.007
106764	M1	269.2	0.005
106764	J1	1.7	0.002
106764	Q1	235.6	0.009
106764	2Q1	313.8	0.018
106764	P1	17.8	0.004
106764	2SM2	104	0.008
106764	M3	41.6	0.009
106764	L2	336	0.006
106764	2MK3	97.1	0.015
106764	K2	91	0.01
106764	M8	62.7	0.003
106764	MS4	9	0.015
106765	M2	175.8	0.331
106765	S2	197.9	0.126
106765	N2	127.5	0.072
106765	K1	74.7	0.063
106765	M4	357.6	0.005
106765	O1	64.2	0.03
106765	M6	83.6	0.029
106765	MK3	178.3	0.006
106765	S4	293.6	0.004
106765	MN4	227.6	0.001
106765	S6	316.5	0.005
106765	2N2	313.4	0.044
106765	OO1	243.5	0.006
106765	M1	284.2	0.009
106765	J1	281.3	0.008
106765	Q1	162.9	0.007
106765	2Q1	159.9	0.012
106765	2SM2	174.3	0.002
106765	M3	96.6	0.012
106765	L2	323	0.022
106765	2MK3	127.2	0.012
106765	M8	125.5	0.004
106765	MS4	24.1	0.006
106766	M2	169.2	0.351
106766	S2	211	0.139
106766	N2	138.9	0.06
106766	K1	93.6	0.053
106766	M4	187.6	0.019
106766	O1	52	0.028
106766	M6	93.4	0.035
106766	MK3	122.3	0.018
106766	S4	260.6	0.001
106766	MN4	144.4	0.013
106766	S6	247.4	0.003
106766	2N2	302.8	0.047
106766	OO1	110.3	0.005
106766	M1	4.2	0.007
106766	J1	257.6	0.005
106766	Q1	120	0.004
106766	2Q1	144.4	0.009
106766	2SM2	119.7	0.011
106766	M3	128.6	0.009
106766	L2	269.8	0.045
106766	2MK3	136	0.018
106766	M8	222.7	0.004
106766	MS4	210	0.021
106767	M2	169.6	0.291
106767	S2	206.4	0.133
106767	N2	132.8	0.088
106767	K1	106	0.065
106767	M4	161.5	0.025
106767	O1	85.7	0.035
106767	M6	93.4	0.026
106767	MK3	156.4	0.012
106767	S4	247.5	0.013
106767	MN4	81.7	0.016
106767	S6	19.9	0.006
106767	2N2	41.9	0.031
106767	OO1	312.4	0.009
106767	M1	126.2	0.013
106767	J1	51.8	0.015
106767	Q1	75.9	0.016
106767	2Q1	39	0.019
106767	2SM2	100.4	0.007
106767	M3	31.5	0.006
106767	L2	203.4	0.017
106767	2MK3	115.1	0.011
106767	M8	113.2	0.005
106767	MS4	205	0.029
106768	M2	179.2	1.18
106768	S2	201.9	0.398
106768	N2	146.2	0.26
106768	K1	101.5	0.16
106768	M4	329.9	0.089
106768	O1	82.2	0.072
106768	M6	26.7	0.044
106768	MK3	212.2	0.041
106768	S4	249	0.008
106768	MN4	311.3	0.035
106768	S6	292.6	0.005
106768	2N2	334	0.074
106768	OO1	242	0.013
106768	M1	347.9	0.009
106768	J1	190.3	0.005
106768	Q1	53	0.003
106768	2Q1	99.3	0.009
106768	P1	126.5	0.011
106768	2SM2	77.5	0.035
106768	M3	80.7	0.008
106768	L2	235.9	0.063
106768	2MK3	124.8	0.022
106768	K2	200	0.117
106768	M8	187.6	0.043
106768	MS4	9.7	0.059
106769	M2	182.2	1.358
106769	S2	206.2	0.451
106769	N2	149.4	0.31
106769	K1	99.5	0.203
106769	M4	321.7	0.105
106769	O1	91.4	0.082
106769	M6	47.1	0.055
106769	MK3	219.1	0.058
106769	S4	268.6	0.016
106769	MN4	285.3	0.04
106769	S6	326.1	0.004
106769	2N2	336.6	0.093
106769	OO1	244.5	0.017
106769	M1	320.5	0.006
106769	J1	132.7	0.006
106769	Q1	116.2	0.007
106769	2Q1	126.3	0.014
106769	P1	117	0.043
106769	2SM2	85.4	0.039
106769	M3	91.8	0.017
106769	L2	232.4	0.062
106769	2MK3	160.1	0.035
106769	K2	194.2	0.126
106769	M8	192.2	0.056
106769	MS4	5.7	0.07
106770	M2	184.5	1.393
106770	S2	215.2	0.495
106770	N2	152.3	0.315
106770	K1	98.8	0.214
106770	M4	335.9	0.091
106770	O1	100.7	0.082
106770	M6	64.2	0.061
106770	MK3	224.5	0.056
106770	S4	314.4	0.024
106770	MN4	294.2	0.033
106770	S6	343.1	0.01
106770	2N2	336	0.113
106770	OO1	253.7	0.019
106770	M1	88.7	0.001
106770	J1	42.2	0.007
106770	Q1	123.4	0.019
106770	2Q1	117.7	0.019
106770	P1	113.3	0.068
106770	2SM2	90.8	0.042
106770	M3	85	0.022
106770	L2	224.5	0.075
106770	2MK3	158.7	0.031
106770	K2	182.2	0.077
106770	M8	191.1	0.052
106770	MS4	21.1	0.067
106771	M2	193.2	2.848
106771	S2	217.6	0.896
106771	N2	160.3	0.629
106771	K1	108.7	0.433
106771	M4	46.6	0.242
106771	O1	92.5	0.269
106771	M6	87.5	0.144
106771	MK3	277.7	0.043
106771	S4	235.5	0.013
106771	MN4	21.1	0.125
106771	S6	236.4	0.016
106771	2N2	350.2	0.155
106771	OO1	271.3	0.042
106771	M1	42.1	0.017
106771	J1	115.8	0.004
106771	Q1	63.9	0.039
106771	2Q1	158.3	0.051
106771	P1	103.5	0.104
106771	2SM2	104.3	0.057
106771	M3	26.3	0.008
106771	L2	247.2	0.158
106771	2MK3	102.9	0.046
106771	K2	203.1	0.297
106771	M8	288.7	0.063
106771	MS4	94.2	0.167
106772	M2	192.5	3.378
106772	S2	217.9	1.065
106772	N2	160.1	0.749
106772	K1	108.8	0.526
106772	M4	39	0.321
106772	O1	91.6	0.327
106772	M6	88.2	0.18
106772	MK3	283.6	0.054
106772	S4	216.2	0.011
106772	MN4	12.6	0.158
106772	S6	244.1	0.013
106772	2N2	350.1	0.175
106772	OO1	269.5	0.045
106772	M1	62.5	0.021
106772	J1	131.2	0.009
106772	Q1	66.9	0.051
106772	2Q1	156.4	0.064
106772	P1	108.5	0.12
106772	2SM2	100.9	0.066
106772	M3	43.1	0.007
106772	L2	246.3	0.177
106772	2MK3	100.9	0.049
106772	K2	202.4	0.344
106772	M8	279.7	0.079
106772	MS4	84.8	0.225
106773	M2	193.2	3.641
106773	S2	219	1.172
106773	N2	161.9	0.812
106773	K1	112.5	0.542
106773	M4	37.7	0.364
106773	O1	95.2	0.35
106773	M6	85.2	0.187
106773	MK3	275.1	0.05
106773	S4	219.1	0.014
106773	MN4	10.7	0.175
106773	2N2	342.5	0.204
106773	OO1	274.9	0.054
106773	M1	68.9	0.022
106773	J1	122.7	0.015
106773	Q1	73.7	0.056
106773	2Q1	150.4	0.081
106773	P1	107.4	0.083
106773	2SM2	98.4	0.089
106773	M3	106	0.011
106773	L2	244.1	0.176
106773	2MK3	87.7	0.047
106773	K2	207.7	0.341
106773	M8	270.1	0.081
106773	MS4	84.2	0.272
106774	M2	190.5	3.242
106774	S2	214.3	1.027
106774	N2	158.4	0.695
106774	K1	111.5	0.443
106774	M4	45.5	0.133
106774	O1	96.3	0.279
106774	M6	90.7	0.172
106774	MK3	204	0.035
106774	S4	253.9	0.023
106774	MN4	20.4	0.061
106774	S6	329	0.009
106774	2N2	344.8	0.142
106774	OO1	255.6	0.046
106774	M1	50.1	0.015
106774	J1	94.7	0.008
106774	Q1	75.8	0.04
106774	2Q1	164.2	0.045
106774	P1	86.5	0.089
106774	2SM2	87.3	0.072
106774	M3	77.4	0.031
106774	L2	244.2	0.179
106774	2MK3	113.8	0.077
106774	K2	208.2	0.34
106774	M8	244.3	0.042
106774	MS4	97.2	0.074
106775	M2	191	3.758
106775	S2	215.1	1.187
106775	N2	158.3	0.807
106775	K1	109.8	0.517
106775	M4	60.3	0.101
106775	O1	97.1	0.315
106775	M6	92.9	0.201
106775	MK3	195.1	0.039
106775	S4	233.5	0.026
106775	MN4	36.5	0.045
106775	S6	324.6	0.011
106775	2N2	350.1	0.167
106775	OO1	257.4	0.048
106775	M1	54.2	0.015
106775	J1	129.1	0.011
106775	Q1	77.6	0.045
106775	2Q1	165.6	0.044
106775	P1	89.9	0.129
106775	2SM2	91	0.075
106775	M3	69.1	0.042
106775	L2	244.4	0.198
106775	2MK3	117.3	0.1
106775	K2	206.2	0.39
106775	M8	258.9	0.032
106775	MS4	121.5	0.062
106776	M2	191.7	3.867
106776	S2	218	1.183
106776	N2	157.5	0.834
106776	K1	110.4	0.537
106776	M4	77.7	0.093
106776	O1	98.5	0.318
106776	M6	92	0.217
106776	MK3	185.3	0.043
106776	S4	226.2	0.032
106776	MN4	59.1	0.033
106776	S6	333.4	0.013
106776	2N2	347.6	0.179
106776	OO1	260.2	0.048
106776	M1	52	0.012
106776	J1	140	0.016
106776	Q1	84.4	0.047
106776	2Q1	160.1	0.041
106776	P1	91.7	0.133
106776	2SM2	93.6	0.073
106776	M3	62.3	0.054
106776	L2	247.6	0.196
106776	2MK3	122.9	0.104
106776	K2	196.7	0.367
106776	M8	259.2	0.019
106776	MS4	146.3	0.067
106777	M2	189.8	0.976
106777	S2	223.1	0.319
106777	N2	161.8	0.224
106777	K1	129.5	0.192
106777	M4	210.2	0.219
106777	O1	172.8	0.072
106777	M6	230.6	0.07
106777	MK3	185.8	0.058
106777	S4	325.5	0.08
106777	MN4	180.1	0.106
106777	S6	150.3	0.018
106777	2N2	102.7	0.18
106777	OO1	177.3	0.041
106777	M1	118.2	0.022
106777	J1	202.1	0.004
106777	Q1	83.8	0.014
106777	2Q1	65.4	0.046
106777	P1	183.1	0.128
106777	2SM2	292.8	0.041
106777	M3	128.5	0.031
106777	L2	113.1	0.035
106777	2MK3	156.9	0.027
106777	K2	203.1	0.225
106777	M8	193.1	0.014
106777	MS4	267.4	0.222
106778	M2	199	1.309
106778	S2	217.9	0.48
106778	N2	165.3	0.3
106778	K1	135.3	0.253
106778	M4	222.3	0.309
106778	O1	165.4	0.097
106778	M6	222	0.087
106778	MK3	190.3	0.101
106778	S4	308.8	0.073
106778	MN4	182.4	0.15
106778	S6	110.4	0.017
106778	2N2	83.5	0.127
106778	OO1	184.6	0.044
106778	M1	134.9	0.009
106778	J1	84.9	0.007
106778	Q1	123.9	0.005
106778	2Q1	59.3	0.05
106778	P1	188.5	0.1
106778	2SM2	273.2	0.019
106778	M3	126.2	0.049
106778	L2	37.7	0.013
106778	2MK3	178.1	0.071
106778	K2	214.6	0.239
106778	M8	181.3	0.036
106778	MS4	262.6	0.303
106779	M2	205.6	1.386
106779	S2	211.1	0.558
106779	N2	168.3	0.313
106779	K1	136.6	0.253
106779	M4	236.6	0.327
106779	O1	161.9	0.108
106779	M6	214.3	0.076
106779	MK3	185.1	0.133
106779	S4	276.4	0.047
106779	MN4	193.6	0.147
106779	S6	55	0.012
106779	2N2	15.4	0.096
106779	OO1	226.7	0.019
106779	M1	223.1	0.004
106779	J1	159.1	0.016
106779	Q1	146.4	0.021
106779	2Q1	50.4	0.017
106779	P1	156.1	0.048
106779	2SM2	113.7	0.014
106779	M3	113.9	0.061
106779	L2	320.6	0.042
106779	2MK3	186.5	0.105
106779	K2	233.4	0.243
106779	M8	172.3	0.055
106779	MS4	262.9	0.297
106780	M2	158.4	0.954
106780	S2	183.7	0.326
106780	N2	122.9	0.204
106780	K1	108.4	0.056
106780	M4	1.3	0.041
106780	O1	120.5	0.059
106780	M6	2.4	0.091
106780	MK3	86.5	0.011
106780	S4	112.4	0.008
106780	MN4	21.7	0.029
106780	S6	237.2	0.006
106780	2N2	283.6	0.075
106780	OO1	232.7	0.005
106780	M1	45	0.005
106780	J1	359.5	0.003
106780	Q1	69	0.021
106780	2Q1	195	0.015
106780	P1	78.2	0.029
106780	2SM2	356.5	0.031
106780	M3	6.9	0.008
106780	L2	198.8	0.049
106780	2MK3	66.6	0.032
106780	K2	192.8	0.077
106780	M8	230.1	0.007
106780	MS4	81.4	0.035
106781	M2	157.5	1.103
106781	S2	182.6	0.357
106781	N2	124.1	0.237
106781	K1	117.9	0.054
106781	M4	350.9	0.048
106781	O1	119.3	0.068
106781	M6	4.2	0.096
106781	MK3	93.3	0.014
106781	S4	178.9	0.009
106781	MN4	4.3	0.024
106781	S6	230.9	0.003
106781	2N2	275.7	0.089
106781	OO1	221	0.011
106781	M1	48.2	0.011
106781	J1	104.8	0.007
106781	Q1	71.6	0.031
106781	2Q1	193.4	0.011
106781	P1	45.7	0.026
106781	2SM2	11.6	0.04
106781	M3	333.6	0.011
106781	L2	191.6	0.064
106781	2MK3	68.8	0.033
106781	K2	183.5	0.101
106781	M8	201.2	0.01
106781	MS4	62.6	0.037
106782	M2	158.1	1.097
106782	S2	184.4	0.325
106782	N2	123.4	0.239
106782	K1	140.1	0.057
106782	M4	31.5	0.066
106782	O1	135.2	0.059
106782	M6	359.3	0.086
106782	MK3	74.2	0.034
106782	S4	206.4	0.02
106782	MN4	34.9	0.035
106782	S6	326.5	0.003
106782	2N2	271.9	0.097
106782	OO1	234.6	0.011
106782	M1	89.3	0.01
106782	J1	106.3	0.004
106782	Q1	71.9	0.032
106782	2Q1	222.6	0.002
106782	P1	358	0.021
106782	2SM2	35.8	0.035
106782	M3	327.2	0.016
106782	L2	189.2	0.062
106782	2MK3	68.8	0.041
106782	K2	173.1	0.091
106782	M8	173.6	0.011
106782	MS4	84.6	0.054
106783	M2	214.1	0.493
106783	S2	269.3	0.255
106783	N2	178.3	0.081
106783	K1	162.9	0.061
106783	M4	277.9	0.131
106783	O1	211	0.035
106783	M6	298.2	0.033
106783	MK3	215.2	0.027
106783	S4	329.5	0.021
106783	MN4	257.1	0.04
106783	S6	94.1	0.004
106783	2N2	126.5	0.118
106783	OO1	195.1	0.01
106783	M1	249.4	0.008
106783	J1	146.1	0.003
106783	Q1	209.8	0.015
106783	2Q1	47.9	0.016
106783	2SM2	323.1	0.022
106783	M3	175.3	0.01
106783	L2	26.7	0.029
106783	2MK3	205.6	0.005
106783	M8	243.5	0.039
106783	MS4	317.1	0.097
106784	M2	215.4	0.563
106784	S2	261.9	0.283
106784	N2	181.4	0.126
106784	K1	159	0.063
106784	M4	265.4	0.16
106784	O1	213.5	0.038
106784	M6	279.4	0.044
106784	MK3	219.7	0.035
106784	S4	333.5	0.028
106784	MN4	250.3	0.059
106784	S6	218.2	0.007
106784	2N2	118.3	0.104
106784	OO1	135.7	0.005
106784	M1	264.2	0.01
106784	J1	157.4	0.004
106784	Q1	197.3	0.016
106784	2Q1	25.3	0.011
106784	2SM2	301.7	0.019
106784	M3	153.2	0.019
106784	L2	56.3	0.037
106784	2MK3	204.7	0.022
106784	M8	234.4	0.029
106784	MS4	304.5	0.132
106785	M2	214.3	0.58
106785	S2	256.4	0.285
106785	N2	187.3	0.135
106785	K1	144.8	0.051
106785	M4	250	0.162
106785	O1	218.6	0.037
106785	M6	272.1	0.076
106785	MK3	199.9	0.049
106785	S4	273.5	0.028
106785	MN4	218.3	0.066
106785	S6	250.5	0.012
106785	2N2	102	0.08
106785	OO1	100.8	0.002
106785	M1	298.2	0.004
106785	J1	279.7	0.009
106785	Q1	192.4	0.008
106785	2Q1	66.1	0.008
106785	2SM2	261.3	0.005
106785	M3	172.9	0.023
106785	L2	98	0.034
106785	2MK3	179.3	0.026
106785	M8	221.6	0.025
106785	MS4	290.4	0.153
106786	M2	229	0.244
106786	S2	271.4	0.085
106786	N2	180.4	0.041
106786	K1	191.2	0.052
106786	M4	355.2	0.02
106786	O1	151.6	0.03
106786	M6	283.4	0.008
106786	MK3	241.3	0.012
106786	S4	197.2	0.001
106786	MN4	306.5	0.01
106786	S6	81.9	0.003
106786	2N2	129.9	0.036
106786	OO1	293.7	0.007
106786	M1	189.4	0.021
106786	J1	89.9	0.015
106786	Q1	41	0.02
106786	2Q1	228.1	0.01
106786	2SM2	327.2	0.011
106786	M3	253.9	0.005
106786	L2	142.6	0.004
106786	2MK3	178.5	0.005
106786	M8	331.5	0.002
106786	MS4	27.7	0.009
106787	M2	248.6	0.201
106787	S2	305.3	0.081
106787	N2	233.4	0.056
106787	K1	219.2	0.064
106787	M4	238.9	0.003
106787	O1	169.3	0.033
106787	M6	276.8	0.013
106787	MK3	191	0.007
106787	S4	181.5	0.004
106787	MN4	233.3	0.006
106787	S6	235.4	0.004
106787	2N2	159.2	0.019
106787	OO1	44.5	0.002
106787	M1	246.2	0.007
106787	J1	193.4	0.006
106787	Q1	134.9	0.012
106787	2Q1	227	0.011
106787	2SM2	105.2	0.009
106787	M3	82.9	0.007
106787	L2	194.6	0.012
106787	2MK3	139	0.008
106787	M8	126.1	0.006
106787	MS4	334.1	0.008
106788	M2	256.2	0.179
106788	S2	298.1	0.09
106788	N2	228.5	0.062
106788	K1	296.9	0.016
106788	M4	280.4	0.008
106788	O1	252.6	0.02
106788	M6	21.1	0.006
106788	MK3	340.2	0.003
106788	S4	233.7	0.003
106788	MN4	240.3	0.006
106788	S6	158	0.001
106788	2N2	241	0.019
106788	OO1	164.9	0.009
106788	M1	40.4	0.005
106788	J1	295.9	0.009
106788	Q1	245.2	0.007
106788	2Q1	319.8	0.007
106788	2SM2	19.4	0.016
106788	M3	241.6	0.004
106788	L2	227	0.021
106788	2MK3	304.1	0.007
106788	M8	182	0.005
106788	MS4	33.3	0.004
106789	M2	191.5	0.15
106789	S2	200.9	0.055
106789	N2	130.6	0.029
106789	K1	125.7	0.031
106789	M4	112.9	0.024
106789	O1	80.1	0.029
106789	M6	51.8	0.004
106789	MK3	317	0.013
106789	S4	249.9	0.005
106789	MN4	104.5	0.004
106789	S6	313.2	0.001
106789	2N2	347.5	0.02
106789	OO1	149.2	0.004
106789	M1	194.3	0.004
106789	J1	357.4	0.01
106789	Q1	86.2	0.008
106789	2Q1	354.8	0.007
106789	2SM2	113.7	0.018
106789	M3	239.2	0.003
106789	L2	343.6	0.029
106789	2MK3	293.2	0.012
106789	M8	212.5	0.001
106789	MS4	168.6	0.013
106790	M2	199.9	0.233
106790	S2	228.5	0.072
106790	N2	159.6	0.031
106790	K1	131.4	0.043
106790	M4	145	0.011
106790	O1	92.1	0.047
106790	M6	5.4	0.003
106790	MK3	351.4	0.006
106790	S4	266.7	0.006
106790	MN4	11.7	0.005
106790	2N2	326.3	0.03
106790	OO1	109.6	0.009
106790	M1	281	0.008
106790	J1	164.4	0.012
106790	Q1	135.4	0.017
106790	2Q1	40.6	0.003
106790	2SM2	112.8	0.01
106790	M3	165.9	0.011
106790	L2	326	0.027
106790	2MK3	332.1	0.006
106790	M8	192.9	0.003
106790	MS4	169.2	0.008
106791	M2	200.1	0.208
106791	S2	211.5	0.062
106791	N2	162.9	0.048
106791	K1	148.8	0.084
106791	M4	91	0.022
106791	O1	99.5	0.053
106791	M6	322	0.005
106791	MK3	30.4	0.009
106791	S4	157	0.002
106791	MN4	69.6	0.008
106791	S6	201.2	0.003
106791	2N2	316.5	0.03
106791	OO1	177.2	0.011
106791	M1	201.6	0.014
106791	J1	172.2	0.022
106791	Q1	160.4	0.025
106791	2Q1	224.3	0.01
106791	2SM2	344.7	0.008
106791	M3	180.8	0.011
106791	L2	233.5	0.015
106791	2MK3	309.5	0.02
106791	M8	303.1	0.003
106791	MS4	170.2	0.013
106792	M2	188.8	0.104
106792	S2	235.1	0.079
106792	N2	166.6	0.019
106792	K1	145.3	0.036
106792	M4	97.4	0.011
106792	O1	105.7	0.026
106792	M6	5.4	0.004
106792	MK3	331.7	0.013
106792	S4	264.2	0.01
106792	MN4	45.3	0.012
106792	S6	322.2	0.003
106792	2N2	63.7	0.016
106792	OO1	123.9	0.013
106792	M1	174	0.007
106792	J1	54.5	0.01
106792	Q1	315.2	0.016
106792	2Q1	41.1	0.02
106792	2SM2	285.8	0.008
106792	M3	316.7	0.004
106792	L2	146.6	0.022
106792	2MK3	239.3	0.002
106792	M8	338.6	0.004
106792	MS4	209.3	0.013
106793	M2	194.1	0.129
106793	S2	219	0.08
106793	N2	167.6	0.045
106793	K1	180.3	0.043
106793	M4	93	0.013
106793	O1	92.3	0.037
106793	M6	279	0.006
106793	MK3	28.1	0.01
106793	S4	312.2	0.008
106793	MN4	97.8	0.011
106793	S6	51.2	0.003
106793	2N2	18	0.011
106793	OO1	87.3	0.008
106793	M1	149.6	0.012
106793	J1	306.9	0.011
106793	Q1	76.8	0.008
106793	2Q1	113.9	0.005
106793	2SM2	299.8	0.011
106793	M3	284.9	0.01
106793	L2	93.6	0.024
106793	2MK3	325.7	0.009
106793	M8	200.6	0.003
106793	MS4	210.1	0.016
106794	M2	149.7	0.124
106794	S2	202	0.05
106794	N2	90.7	0.039
106794	K1	106.2	0.008
106794	M4	70	0.024
106794	O1	109.7	0.006
106794	M6	93.5	0.008
106794	MK3	341	0.003
106794	S4	209.5	0.011
106794	MN4	2.4	0.02
106794	S6	208.6	0.002
106794	2N2	52.2	0.006
106794	OO1	14.4	0.007
106794	M1	115.9	0.005
106794	J1	152.5	0.008
106794	Q1	61.2	0.004
106794	2Q1	10.2	0.004
106794	2SM2	115.9	0.002
106794	M3	327.8	0.004
106794	L2	206.5	0.009
106794	2MK3	107.2	0.008
106794	M8	104.7	0.001
106794	MS4	144.7	0.021
106795	M2	218.9	0.265
106795	S2	248.7	0.098
106795	N2	213.3	0.062
106795	K1	117.6	0.048
106795	M4	100.8	0.033
106795	O1	110.3	0.028
106795	M6	52.2	0.005
106795	MK3	5.6	0.015
106795	S4	263.6	0.009
106795	MN4	137.8	0.011
106795	S6	311.5	0.004
106795	2N2	10.4	0.044
106795	OO1	223.2	0.016
106795	M1	159	0.006
106795	J1	40.7	0.029
106795	Q1	7.3	0.007
106795	2Q1	107	0.021
106795	2SM2	109.3	0.013
106795	M3	339.4	0.012
106795	L2	7.3	0.032
106795	2MK3	100.5	0.003
106795	M8	108.9	0.004
106795	MS4	133.8	0.023
106796	M2	181.2	2.757
106796	S2	211.8	0.847
106796	N2	148.4	0.611
106796	K1	113.3	0.314
106796	M4	2.1	0.144
106796	O1	96.3	0.184
106796	M6	50.3	0.227
106796	MK3	102.7	0.012
106796	S4	149.1	0.017
106796	MN4	337.4	0.07
106796	S6	171	0.013
106796	2N2	284.5	0.126
106796	OO1	245.6	0.023
106796	M1	0.6	0.006
106796	J1	168.1	0.009
106796	Q1	77.8	0.027
106796	2Q1	127.3	0.027
106796	P1	136.5	0.057
106796	2SM2	63.7	0.072
106796	M3	335.9	0.028
106796	L2	216.6	0.173
106796	2MK3	62.8	0.073
106796	K2	194.6	0.219
106796	M8	201.6	0.041
106796	MS4	44	0.087
106797	M2	181.6	3.678
106797	S2	213.3	1.145
106797	N2	149	0.794
106797	K1	110.7	0.4
106797	M4	20.5	0.119
106797	O1	100.1	0.235
106797	M6	56.3	0.289
106797	MK3	124.6	0.032
106797	S4	206.9	0.027
106797	MN4	0.1	0.067
106797	S6	155.3	0.013
106797	2N2	290	0.139
106797	OO1	243.7	0.033
106797	M1	343.8	0.005
106797	J1	144.1	0.014
106797	Q1	71.3	0.037
106797	2Q1	117.5	0.039
106797	P1	123.4	0.087
106797	2SM2	65.8	0.089
106797	M3	334.4	0.032
106797	L2	218.6	0.224
106797	2MK3	72.7	0.107
106797	K2	190.8	0.282
106797	M8	204.7	0.029
106797	MS4	56.8	0.059
106798	M2	183.1	4.198
106798	S2	214	1.329
106798	N2	150.4	0.901
106798	K1	110.7	0.497
106798	M4	31.2	0.136
106798	O1	103.8	0.28
106798	M6	59.4	0.336
106798	MK3	116.1	0.043
106798	S4	213.1	0.041
106798	MN4	2.9	0.07
106798	S6	160.8	0.012
106798	2N2	294.2	0.186
106798	OO1	253.5	0.052
106798	J1	150.7	0.018
106798	Q1	81.8	0.036
106798	2Q1	134.8	0.051
106798	P1	137.5	0.117
106798	2SM2	76.1	0.111
106798	M3	343.2	0.04
106798	L2	222.1	0.275
106798	2MK3	64.7	0.119
106798	K2	194.5	0.323
106798	M8	207.7	0.03
106798	MS4	74.9	0.083
106799	M2	279	0.086
106799	S2	305.5	0.053
106799	N2	186.3	0.026
106799	K1	126.3	0.008
106799	M4	349.7	0.028
106799	O1	179.1	0.011
106799	M6	358.8	0.01
106799	MK3	41.5	0.005
106799	S4	240.7	0.002
106799	MN4	307.9	0.011
106799	S6	62.2	0.005
106799	2N2	276.2	0.007
106799	OO1	271.8	0.011
106799	M1	135.9	0.003
106799	J1	77.8	0.009
106799	Q1	154.4	0.009
106799	2Q1	206.4	0.016
106799	2SM2	345.2	0.011
106799	M3	93.6	0.001
106799	L2	69.5	0.01
106799	2MK3	356.3	0.003
106799	M8	326.2	0.012
106799	MS4	38.2	0.011
106800	M2	25.5	0.217
106800	S2	24.4	0.084
106800	N2	356.7	0.089
106800	K1	344	0.028
106800	M4	319.6	0.043
106800	O1	295	0.011
106800	M6	312	0.062
106800	MK3	304.1	0.013
106800	S4	329.8	0.016
106800	MN4	313	0.021
106800	S6	325.9	0.004
106800	2N2	159.2	0.051
106800	OO1	113.2	0.006
106800	M1	269.4	0.011
106800	J1	66.8	0.003
106800	Q1	18.7	0.002
106800	2Q1	179.4	0.002
106800	2SM2	269.9	0.039
106800	M3	205	0.016
106800	L2	79.2	0.014
106800	2MK3	312.8	0.015
106800	M8	305.7	0.039
106800	MS4	17.4	0.057
106801	M2	230.1	1.047
106801	S2	260.8	0.394
106801	N2	200.6	0.238
106801	K1	149.1	0.288
106801	M4	272.4	0.074
106801	O1	113.2	0.179
106801	M6	201.4	0.058
106801	MK3	156.7	0.06
106801	S4	294	0.018
106801	MN4	237.2	0.028
106801	S6	310.3	0.011
106801	2N2	130.5	0.113
106801	OO1	235.4	0.003
106801	M1	106.7	0.015
106801	J1	130.1	0.026
106801	Q1	84.3	0.047
106801	2Q1	230.6	0.015
106801	P1	139.1	0.076
106801	2SM2	20.7	0.01
106801	M3	122.4	0.013
106801	L2	175.2	0.006
106801	2MK3	104.8	0.02
106801	K2	250.7	0.114
106801	M8	340.9	0.009
106801	MS4	319	0.067
106802	M2	233.2	1.187
106802	S2	258.2	0.422
106802	N2	200	0.278
106802	K1	147.8	0.271
106802	M4	254.6	0.066
106802	O1	115.6	0.19
106802	M6	209.9	0.067
106802	MK3	145.8	0.055
106802	S4	277.9	0.024
106802	MN4	212.6	0.019
106802	S6	313.8	0.008
106802	2N2	116.3	0.099
106802	OO1	141.5	0.006
106802	M1	120.1	0.017
106802	J1	134.7	0.028
106802	Q1	84.2	0.042
106802	2Q1	244.9	0.017
106802	P1	117.3	0.096
106802	2SM2	166.2	0.006
106802	M3	101.9	0.008
106802	L2	217.2	0.005
106802	2MK3	102.4	0.021
106802	K2	248.7	0.137
106802	M8	155.4	0.009
106802	MS4	305.3	0.049
106803	M2	236.9	1.231
106803	S2	265.2	0.414
106803	N2	201.4	0.295
106803	K1	139.5	0.283
106803	M4	220.9	0.106
106803	O1	118.8	0.182
106803	M6	223.6	0.06
106803	MK3	155.7	0.076
106803	S4	253.6	0.029
106803	MN4	163.5	0.052
106803	S6	286.6	0.008
106803	2N2	83.2	0.089
106803	OO1	64	0.013
106803	M1	94.3	0.026
106803	J1	105.7	0.03
106803	Q1	93.5	0.043
106803	2Q1	263.3	0.019
106803	P1	127	0.13
106803	2SM2	179.8	0.026
106803	M3	66.4	0.023
106803	L2	282.9	0.021
106803	2MK3	110.1	0.049
106803	K2	235.7	0.105
106803	M8	168.4	0.035
106803	MS4	251.6	0.091
106804	M2	256.3	1.523
106804	S2	282.6	0.53
106804	N2	221.4	0.363
106804	K1	158.9	0.537
106804	M4	77	0.035
106804	O1	148.7	0.271
106804	M6	242.6	0.029
106804	MK3	347.9	0.034
106804	S4	161.8	0.009
106804	MN4	40.9	0.023
106804	S6	324.1	0.003
106804	2N2	142.9	0.184
106804	OO1	47.9	0.024
106804	M1	131.9	0.031
106804	J1	149.3	0.038
106804	Q1	123.2	0.049
106804	2Q1	322.3	0.021
106804	P1	147.7	0.219
106804	2SM2	306.5	0.025
106804	M3	313.4	0.011
106804	L2	45.7	0.016
106804	2MK3	190.4	0.011
106804	K2	266.9	0.195
106804	M8	121.4	0.008
106804	MS4	100.9	0.028
106805	M2	257.7	1.918
106805	S2	284.3	0.705
106805	N2	221.4	0.462
106805	K1	162.7	0.667
106805	M4	96.6	0.031
106805	O1	150.2	0.33
106805	M6	283.4	0.041
106805	MK3	349.9	0.03
106805	S4	172	0.005
106805	MN4	62.6	0.014
106805	2N2	144	0.203
106805	OO1	50.1	0.03
106805	M1	117.2	0.047
106805	J1	138.9	0.059
106805	Q1	119.2	0.066
106805	2Q1	293.4	0.03
106805	P1	146.8	0.252
106805	2SM2	314.7	0.032
106805	M3	278.7	0.025
106805	L2	66.2	0.022
106805	2MK3	191.4	0.017
106805	K2	278.2	0.22
106805	M8	96.3	0.005
106805	MS4	112.1	0.03
106806	M2	257.2	2.071
106806	S2	285.4	0.777
106806	N2	220.4	0.469
106806	K1	163.5	0.658
106806	M4	14.9	0.027
106806	O1	150.3	0.343
106806	M6	299	0.03
106806	MK3	314.4	0.026
106806	S4	324.2	0.005
106806	MN4	346	0.016
106806	S6	294.9	0.01
106806	2N2	145.9	0.214
106806	OO1	47	0.04
106806	M1	98.7	0.042
106806	J1	137.5	0.063
106806	Q1	109.9	0.071
106806	2Q1	272.5	0.033
106806	P1	146.5	0.213
106806	2SM2	326.9	0.03
106806	M3	278	0.014
106806	L2	35.2	0.045
106806	2MK3	229	0.019
106806	K2	286.8	0.232
106806	M8	95.1	0.006
106806	MS4	72.9	0.003
106807	M2	252.2	0.656
106807	S2	285.6	0.264
106807	N2	225.4	0.167
106807	K1	183.2	0.288
106807	M4	115.8	0.062
106807	O1	162.2	0.124
106807	M6	227.3	0.041
106807	MK3	68.7	0.027
106807	S4	210.9	0.012
106807	MN4	102.7	0.04
106807	S6	271.6	0.008
106807	2N2	186.6	0.09
106807	OO1	169.1	0.02
106807	M1	165.9	0.022
106807	J1	193.8	0.015
106807	Q1	157	0.012
106807	2Q1	193.4	0.024
106807	P1	184.2	0.061
106807	2SM2	21.3	0.024
106807	M3	346.1	0.027
106807	L2	198.6	0.035
106807	2MK3	64.8	0.028
106807	K2	277	0.071
106807	M8	232	0.007
106807	MS4	143.4	0.041
106808	M2	260.1	0.874
106808	S2	282.9	0.393
106808	N2	230.4	0.219
106808	K1	173.9	0.32
106808	M4	86.5	0.052
106808	O1	155.4	0.148
106808	M6	270.8	0.024
106808	MK3	39.7	0.041
106808	S4	203.6	0.016
106808	MN4	73.6	0.018
106808	S6	229.5	0.007
106808	2N2	152.8	0.094
106808	OO1	244.5	0.02
106808	M1	182.3	0.012
106808	J1	199.8	0.03
106808	Q1	142.2	0.03
106808	2Q1	234.5	0.013
106808	P1	160.6	0.094
106808	2SM2	18.6	0.039
106808	M3	329.1	0.017
106808	L2	209.9	0.014
106808	2MK3	43.9	0.025
106808	K2	321.5	0.113
106808	M8	98.9	0.008
106808	MS4	105.3	0.035
106809	M2	260.4	0.916
106809	S2	273.8	0.428
106809	N2	227.9	0.2
106809	K1	157.9	0.328
106809	M4	74.1	0.077
106809	O1	155.3	0.147
106809	M6	310.7	0.011
106809	MK3	14.1	0.032
106809	S4	198.2	0.005
106809	MN4	39.6	0.029
106809	S6	171.1	0.005
106809	2N2	167.5	0.065
106809	OO1	251.5	0.012
106809	M1	141.6	0.005
106809	J1	224.3	0.027
106809	Q1	146.7	0.031
106809	2Q1	213.5	0.021
106809	P1	163.1	0.127
106809	2SM2	1.1	0.042
106809	M3	318	0.021
106809	L2	333.1	0.002
106809	2MK3	40.9	0.036
106809	K2	317.1	0.193
106809	M8	114.8	0.016
106809	MS4	94.8	0.031
106810	M2	199.5	0.87
106810	S2	196.7	0.231
106810	N2	166.9	0.197
106810	K1	85.3	0.048
106810	M4	8.5	0.152
106810	O1	115.7	0.049
106810	M6	76.5	0.02
106810	MK3	264.6	0.038
106810	S4	152.1	0.038
106810	MN4	342.6	0.092
106810	S6	167.8	0.01
106810	2N2	15.7	0.09
106810	OO1	298.5	0.02
106810	M1	32.9	0.02
106810	J1	282.9	0.007
106810	Q1	155.9	0.008
106810	2Q1	186.6	0.025
106810	P1	11.4	0.045
106810	2SM2	125.9	0.034
106810	M3	310.6	0.003
106810	L2	293.4	0.072
106810	2MK3	201.9	0.033
106810	K2	202.7	0.163
106810	M8	295.7	0.029
106810	MS4	63.6	0.101
106811	M2	211.9	1.01
106811	S2	228.2	0.3
106811	N2	178.5	0.215
106811	K1	99.9	0.085
106811	M4	42.9	0.132
106811	O1	135.5	0.047
106811	M6	250.1	0.022
106811	MK3	313.5	0.03
106811	S4	135.6	0.043
106811	MN4	9.5	0.07
106811	S6	164.5	0.004
106811	2N2	29.5	0.122
106811	OO1	309.5	0.017
106811	M1	19.3	0.021
106811	J1	260.5	0.013
106811	Q1	121.3	0.017
106811	2Q1	199.5	0.025
106811	P1	70.2	0.033
106811	2SM2	174.6	0.042
106811	M3	256.3	0.006
106811	L2	299.5	0.08
106811	2MK3	173.6	0.027
106811	K2	212.3	0.114
106811	M8	46.3	0.01
106811	MS4	94.2	0.142
106812	M2	220.6	1.182
106812	S2	240.5	0.44
106812	N2	182.7	0.242
106812	K1	136	0.14
106812	M4	78.3	0.101
106812	O1	117.3	0.037
106812	M6	224.5	0.051
106812	MK3	17.5	0.019
106812	S4	130.3	0.043
106812	MN4	64.2	0.028
106812	S6	79.9	0.009
106812	2N2	30.8	0.142
106812	OO1	351.8	0.02
106812	M1	348.9	0.026
106812	J1	223.4	0.01
106812	Q1	116.1	0.028
106812	2Q1	346.7	0.002
106812	P1	227.1	0.028
106812	2SM2	186.9	0.068
106812	M3	317.7	0.012
106812	L2	319.9	0.1
106812	2MK3	159.3	0.035
106812	K2	249.7	0.075
106812	M8	128.7	0.042
106812	MS4	127.3	0.12
106813	M2	28.5	2.287
106813	S2	55.9	0.369
106813	N2	5.7	0.523
106813	K1	102.2	0.148
106813	M4	53.2	0.256
106813	O1	149.2	0.071
106813	M6	87.1	0.024
106813	MK3	128.4	0.035
106813	S4	177.9	0.006
106813	MN4	29.3	0.116
106813	NU2	355.3	0.09
106813	MU2	351.9	0.037
106813	2N2	325.9	0.046
106813	OO1	91.2	0.009
106813	LDA2	73.8	0.048
106813	M1	169.9	0.011
106813	J1	172	0.013
106813	RHO1	33.1	0.016
106813	Q1	128.5	0.014
106813	2Q1	128.8	0.003
106813	P1	98.5	0.053
106813	2SM2	312.2	0.005
106813	M3	26.8	0.015
106813	L2	66.3	0.145
106813	2MK3	105.6	0.015
106813	K2	43.1	0.089
106813	M8	338.2	0.056
106813	MS4	82.9	0.061
106814	M2	30.8	3.149
106814	S2	56.6	0.486
106814	N2	8.6	0.69
106814	K1	101.4	0.208
106814	M4	57.9	0.057
106814	O1	145	0.125
106814	M6	326.5	0.034
106814	MK3	148.3	0.017
106814	S4	175.4	0.009
106814	MN4	12.1	0.043
106814	NU2	1.2	0.134
106814	MU2	4.6	0.023
106814	2N2	328.6	0.046
106814	OO1	94.3	0.013
106814	LDA2	87.5	0.062
106814	M1	181.5	0.014
106814	J1	172.4	0.016
106814	RHO1	43.7	0.017
106814	Q1	113.7	0.024
106814	2Q1	64.9	0.006
106814	P1	104.2	0.078
106814	2SM2	316.4	0.01
106814	M3	5.9	0.023
106814	L2	69.1	0.235
106814	2MK3	78.8	0.017
106814	K2	38.5	0.121
106814	M8	354.6	0.042
106814	MS4	84.1	0.013
106815	M2	33.7	3.632
106815	S2	60.2	0.539
106815	N2	11.2	0.813
106815	K1	97.1	0.228
106815	M4	205.1	0.06
106815	O1	152.9	0.138
106815	M6	337.8	0.058
106815	MK3	201.5	0.035
106815	S4	124.7	0.012
106815	MN4	202.9	0.039
106815	NU2	1.6	0.136
106815	MU2	337	0.031
106815	2N2	330	0.049
106815	OO1	98.3	0.009
106815	LDA2	80.6	0.083
106815	M1	166.6	0.011
106815	J1	187.2	0.017
106815	RHO1	359	0.008
106815	Q1	127.2	0.023
106815	P1	101.9	0.072
106815	M3	356.3	0.008
106815	L2	67.3	0.281
106815	2MK3	91.6	0.013
106815	K2	44.2	0.119
106815	M8	286.9	0.017
106815	MS4	216.8	0.018
106816	M2	357.2	1.26
106816	S2	34.4	0.199
106816	N2	331.7	0.221
106816	K1	92	0.057
106816	M4	148.4	0.085
106816	O1	119.6	0.049
106816	M6	264.6	0.03
106816	MK3	178.2	0.01
106816	S4	323.6	0.006
106816	MN4	163.3	0.03
106816	S6	197.7	0.006
106816	2N2	13.6	0.013
106816	OO1	0.6	0.009
106816	M1	157.2	0.011
106816	J1	166.7	0.018
106816	Q1	133.8	0.009
106816	2Q1	92.3	0.004
106816	P1	81.2	0.04
106816	2SM2	344.9	0.012
106816	M3	193.8	0.005
106816	L2	34.9	0.072
106816	2MK3	233.5	0.008
106816	K2	27.9	0.085
106816	M8	57.8	0.024
106816	MS4	166.6	0.019
106817	M2	359.9	1.705
106817	S2	33.3	0.249
106817	N2	332.5	0.271
106817	K1	95.6	0.075
106817	M4	148.7	0.059
106817	O1	114.2	0.054
106817	M6	250.9	0.095
106817	MK3	166.9	0.016
106817	S4	277.8	0.005
106817	MN4	165.4	0.035
106817	S6	173.2	0.003
106817	2N2	16.5	0.026
106817	OO1	355.7	0.012
106817	M1	154.9	0.014
106817	J1	169.2	0.023
106817	Q1	158.1	0.012
106817	2Q1	30.6	0.007
106817	P1	69.1	0.053
106817	2SM2	4.5	0.007
106817	M3	149.2	0.008
106817	L2	45.6	0.128
106817	2MK3	200.1	0.013
106817	K2	27.6	0.109
106817	M8	43.6	0.014
106817	MS4	186.5	0.021
106818	M2	3.6	1.954
106818	S2	37.2	0.269
106818	N2	334.8	0.273
106818	K1	92.6	0.083
106818	M4	172.3	0.073
106818	O1	117.9	0.047
106818	M6	256.6	0.132
106818	MK3	162.5	0.021
106818	S4	147.9	0.003
106818	MN4	193.3	0.028
106818	S6	205.5	0.004
106818	2N2	16.8	0.033
106818	OO1	1.5	0.014
106818	M1	165.3	0.015
106818	J1	174.3	0.025
106818	Q1	188.5	0.009
106818	2Q1	18.1	0.012
106818	P1	60.1	0.055
106818	2SM2	9.4	0.007
106818	M3	97.3	0.008
106818	L2	49.6	0.176
106818	2MK3	178.4	0.017
106818	K2	31.9	0.116
106818	M8	352.5	0.022
106818	MS4	223.8	0.018
106819	M2	340.3	0.499
106819	S2	347.9	0.047
106819	N2	310.4	0.075
106819	K1	15.8	0.036
106819	M4	199.9	0.033
106819	O1	56.7	0.019
106819	M6	276.5	0.024
106819	MK3	103.3	0.013
106819	S4	100.3	0.005
106819	MN4	245.6	0.01
106819	S6	137.8	0.001
106819	2N2	85.9	0.01
106819	OO1	25.7	0.007
106819	M1	170.9	0.006
106819	J1	9	0.006
106819	Q1	69.6	0.006
106819	2Q1	274.3	0.009
106819	2SM2	203.7	0.002
106819	M3	206.5	0.003
106819	L2	40	0.046
106819	2MK3	158.3	0.008
106819	M8	139.8	0.021
106819	MS4	56.8	0.008
106820	M2	345.9	0.651
106820	S2	342	0.075
106820	N2	291.2	0.103
106820	K1	5.3	0.033
106820	M4	62.3	0.076
106820	O1	10.5	0.015
106820	M6	288.7	0.092
106820	MK3	69.3	0.027
106820	S4	7.7	0.008
106820	MN4	72.2	0.033
106820	S6	325.2	0.003
106820	2N2	17.3	0.02
106820	OO1	287.3	0.003
106820	M1	186.9	0.001
106820	J1	201.3	0.01
106820	Q1	320.2	0.003
106820	2Q1	313.3	0.008
106820	2SM2	108.7	0.008
106820	M3	44.8	0.015
106820	L2	64	0.07
106820	2MK3	140.1	0.023
106820	M8	15.5	0.019
106820	MS4	131.3	0.012
106821	M2	340.3	0.676
106821	S2	353	0.056
106821	N2	289	0.124
106821	K1	334.4	0.04
106821	M4	68.6	0.101
106821	O1	322	0.017
106821	M6	286.6	0.109
106821	MK3	50.4	0.024
106821	S4	340.3	0.011
106821	MN4	58.4	0.043
106821	S6	25.7	0.001
106821	2N2	20.4	0.03
106821	OO1	263.8	0.006
106821	M1	68.5	0.006
106821	J1	201.8	0.02
106821	Q1	267.3	0.018
106821	2Q1	339.5	0.012
106821	2SM2	58.2	0.019
106821	M3	36.4	0.016
106821	L2	37.7	0.063
106821	2MK3	137.7	0.018
106821	M8	8.6	0.034
106821	MS4	106.2	0.015
106822	M2	328.8	0.164
106822	S2	349.6	0.034
106822	N2	314.9	0.018
106822	K1	28.5	0.051
106822	M4	269.7	0.044
106822	O1	104.1	0.046
106822	M6	145.6	0.038
106822	MK3	274	0.012
106822	S4	286.7	0.007
106822	MN4	284.9	0.013
106822	S6	203.4	0.004
106822	2N2	165.9	0.012
106822	OO1	316.6	0.003
106822	M1	64.1	0.008
106822	J1	78.9	0.009
106822	Q1	82.5	0.019
106822	2Q1	89	0.014
106822	2SM2	10.4	0.012
106822	M3	246.4	0.011
106822	L2	95.2	0.021
106822	2MK3	272.6	0.008
106822	M8	286.8	0.004
106822	MS4	71.8	0.013
106823	M2	338.1	0.19
106823	S2	4.7	0.036
106823	N2	326.8	0.033
106823	K1	64.2	0.039
106823	M4	256.5	0.048
106823	O1	150.5	0.032
106823	M6	165	0.032
106823	MK3	337.2	0.012
106823	S4	275.5	0.006
106823	MN4	218.3	0.023
106823	S6	168.7	0.008
106823	2N2	183.1	0.001
106823	OO1	180.8	0.005
106823	M1	164.4	0.01
106823	J1	269.1	0.006
106823	Q1	123.3	0.011
106823	2Q1	129.7	0.006
106823	2SM2	331	0.005
106823	M3	287.1	0.006
106823	L2	266.5	0.002
106823	2MK3	279.2	0.007
106823	M8	263.7	0.006
106823	MS4	300.5	0.005
106824	M2	355.6	0.256
106824	S2	1	0.045
106824	N2	322.1	0.062
106824	K1	122	0.023
106824	M4	288.4	0.059
106824	O1	204.6	0.018
106824	M6	195.6	0.026
106824	MK3	281.9	0.006
106824	S4	229.9	0.009
106824	MN4	248.6	0.029
106824	S6	173.3	0.007
106824	2N2	265.4	0.007
106824	OO1	51.6	0.024
106824	M1	234.7	0.009
106824	J1	171.5	0.008
106824	Q1	221.6	0.017
106824	2Q1	244.5	0.007
106824	2SM2	215.5	0.01
106824	M3	221.2	0.006
106824	L2	313	0.021
106824	2MK3	255.4	0.011
106824	M8	256.8	0.016
106824	MS4	219.1	0.007
106825	M2	340.3	0.29
106825	S2	357.9	0.043
106825	N2	307.8	0.07
106825	K1	48.3	0.034
106825	M4	291	0.043
106825	O1	118.4	0.033
106825	M6	192.7	0.034
106825	MK3	268.8	0.001
106825	S4	220.3	0.006
106825	MN4	248.3	0.022
106825	S6	208.4	0.001
106825	2N2	87	0.01
106825	OO1	255.9	0.003
106825	M1	158.4	0.009
106825	J1	109.3	0.006
106825	Q1	119.9	0.011
106825	2Q1	67	0.006
106825	2SM2	3.9	0.007
106825	L2	33.9	0.006
106825	2MK3	193.9	0.002
106825	M8	304.3	0.008
106825	MS4	257.2	0.006
106826	M2	358.2	0.267
106826	S2	355.6	0.037
106826	N2	339.4	0.043
106826	K1	70.9	0.035
106826	M4	285.9	0.048
106826	O1	157.1	0.031
106826	M6	183.1	0.033
106826	MK3	311.6	0.015
106826	S4	14.4	0.002
106826	MN4	257.6	0.021
106826	S6	227.7	0.001
106826	2N2	198.3	0.009
106826	OO1	139.1	0.001
106826	M1	196.3	0.007
106826	J1	206.1	0.005
106826	Q1	107.2	0.008
106826	2Q1	62.1	0.009
106826	2SM2	17.6	0.01
106826	M3	266.4	0.004
106826	L2	29.4	0.014
106826	2MK3	351	0.009
106826	M8	292.1	0.006
106826	MS4	282.9	0.007
106827	M2	358.4	0.315
106827	S2	2.2	0.049
106827	N2	335.2	0.054
106827	K1	66.8	0.012
106827	M4	300.2	0.072
106827	O1	178.6	0.015
106827	M6	171.2	0.056
106827	MK3	32.7	0.006
106827	S4	292.5	0.003
106827	MN4	254.2	0.024
106827	S6	296.8	0.001
106827	2N2	252.1	0.015
106827	OO1	340	0.01
106827	M1	228.6	0.007
106827	J1	250	0.004
106827	Q1	285.6	0.004
106827	2Q1	128	0.01
106827	2SM2	47.1	0.015
106827	M3	326	0.008
106827	L2	29.7	0.027
106827	2MK3	323.5	0.01
106827	M8	246	0.006
106827	MS4	331.3	0.009
106828	M2	314.9	0.313
106828	S2	349.4	0.04
106828	N2	297.1	0.065
106828	K1	40.1	0.019
106828	M4	326	0.054
106828	O1	114.2	0.025
106828	M6	155.4	0.052
106828	MK3	302.3	0.01
106828	S4	355.2	0.008
106828	MN4	192.8	0.013
106828	S6	241.1	0.005
106828	2N2	132.8	0.008
106828	OO1	232.8	0.004
106828	M1	162.4	0.006
106828	J1	133	0.006
106828	Q1	160.6	0.003
106828	2Q1	311.8	0.005
106828	2SM2	326.2	0.007
106828	M3	60.3	0.004
106828	L2	8.9	0.014
106828	2MK3	274.1	0.008
106828	M8	258.9	0.026
106828	MS4	218.2	0.016
106829	M2	342.5	0.362
106829	S2	348.4	0.05
106829	N2	316.1	0.065
106829	K1	50.9	0.043
106829	M4	268.9	0.055
106829	O1	124.3	0.035
106829	M6	176.6	0.046
106829	MK3	241	0.005
106829	S4	225.1	0.006
106829	MN4	242.8	0.031
106829	S6	292.2	0.003
106829	2N2	114.2	0.008
106829	OO1	186.7	0.005
106829	M1	172.3	0.007
106829	J1	85.3	0.004
106829	Q1	89.6	0.016
106829	2Q1	98.3	0.007
106829	2SM2	44.3	0.009
106829	M3	255.9	0.005
106829	L2	29.1	0.013
106829	2MK3	284.4	0.013
106829	M8	282.3	0.016
106829	MS4	288.9	0.008
106830	M2	351.1	0.354
106830	S2	359.4	0.053
106830	N2	325.7	0.063
106830	K1	50.5	0.044
106830	M4	265.6	0.052
106830	O1	136.2	0.031
106830	M6	175.2	0.047
106830	MK3	292	0.01
106830	S4	233.1	0.005
106830	MN4	241.7	0.025
106830	S6	328.6	0.003
106830	2N2	185.9	0.008
106830	OO1	54.5	0.002
106830	M1	179.3	0.009
106830	J1	267.7	0.003
106830	Q1	128.5	0.005
106830	2Q1	101.3	0.015
106830	2SM2	44.6	0.007
106830	M3	288.6	0.008
106830	L2	14	0.009
106830	2MK3	318	0.017
106830	M8	280.5	0.003
106830	MS4	294.8	0.005
106831	M2	329.6	0.276
106831	S2	341.7	0.053
106831	N2	308.4	0.043
106831	K1	16.6	0.033
106831	M4	263.8	0.059
106831	O1	108.4	0.026
106831	M6	176.8	0.056
106831	MK3	305.6	0.012
106831	S4	294.1	0.002
106831	MN4	241.6	0.027
106831	S6	164.9	0.003
106831	2N2	21.7	0.002
106831	M1	132.8	0.004
106831	J1	195.3	0.007
106831	Q1	55.5	0.005
106831	2Q1	97.5	0.003
106831	P1	212.1	0.01
106831	2SM2	12.3	0.006
106831	M3	251.6	0.008
106831	L2	8.1	0.019
106831	2MK3	308.3	0.011
106831	K2	314.7	0.016
106831	M8	10.2	0.009
106831	MS4	261.7	0.007
106832	M2	347.4	0.306
106832	S2	12.4	0.068
106832	N2	320.4	0.065
106832	K1	52.7	0.04
106832	M4	291.6	0.075
106832	O1	114.6	0.029
106832	M6	190	0.046
106832	MK3	326.8	0.019
106832	S4	272.7	0.006
106832	MN4	258.9	0.039
106832	S6	69.9	0.003
106832	2N2	87	0.003
106832	OO1	154.6	0.004
106832	M1	151	0.005
106832	J1	178	0.002
106832	Q1	55.3	0.002
106832	2Q1	71.2	0.005
106832	P1	269.4	0.005
106832	2SM2	19.9	0.012
106832	M3	261.1	0.007
106832	L2	72.5	0.002
106832	2MK3	324.8	0.012
106832	K2	354.2	0.022
106832	M8	313.3	0.01
106832	MS4	313.4	0.014
106833	M2	352.1	0.306
106833	S2	26.5	0.058
106833	N2	327	0.075
106833	K1	69.8	0.031
106833	M4	279	0.031
106833	O1	208.5	0.007
106833	M6	144.6	0.043
106833	MK3	221.5	0.015
106833	S4	119.6	0.002
106833	MN4	241.2	0.021
106833	S6	233	0.003
106833	2N2	172.6	0.007
106833	OO1	54	0.009
106833	M1	205.4	0.01
106833	J1	52.6	0.009
106833	Q1	193.9	0.013
106833	2Q1	126.8	0.009
106833	P1	27.9	0.019
106833	2SM2	296.7	0.007
106833	M3	320.3	0.007
106833	L2	344.8	0.011
106833	2MK3	256.3	0.018
106833	K2	52.6	0.023
106833	M8	340.6	0.015
106833	MS4	213.8	0.004
106834	M2	323.2	0.287
106834	S2	339.6	0.065
106834	N2	301.6	0.051
106834	K1	33.7	0.033
106834	M4	267.2	0.047
106834	O1	95.3	0.021
106834	M6	159.8	0.058
106834	MK3	227.1	0.006
106834	S4	251.8	0.003
106834	MN4	230.5	0.021
106834	S6	280.5	0.001
106834	2N2	110.8	0.004
106834	OO1	166.2	0.004
106834	M1	115.3	0.004
106834	J1	158.3	0.002
106834	Q1	68	0.008
106834	2Q1	93.1	0.005
106834	P1	284.5	0.019
106834	2SM2	316	0.002
106834	M3	257.7	0.009
106834	L2	355.7	0.003
106834	2MK3	275.4	0.018
106834	K2	306.8	0.02
106834	M8	309.2	0.024
106834	MS4	268.3	0.007
106835	M2	351.1	0.289
106835	S2	21.8	0.082
106835	N2	335.5	0.047
106835	K1	53.9	0.055
106835	M4	286	0.102
106835	O1	133.7	0.043
106835	M6	208.3	0.053
106835	MK3	307.7	0.024
106835	S4	312.4	0.006
106835	MN4	247.2	0.05
106835	S6	89.8	0.002
106835	2N2	191.6	0.006
106835	OO1	168.6	0.002
106835	M1	182.4	0.009
106835	J1	73	0.002
106835	Q1	99	0.01
106835	2Q1	92.1	0.008
106835	P1	287.1	0.01
106835	2SM2	32.9	0.007
106835	M3	285.8	0.006
106835	L2	22.6	0.011
106835	2MK3	349	0.014
106835	K2	357	0.032
106835	M8	275.3	0.02
106835	MS4	290.7	0.019
106836	M2	354.5	0.487
106836	S2	17	0.057
106836	N2	315.6	0.099
106836	K1	163.2	0.102
106836	M4	270.2	0.075
106836	O1	132.1	0.022
106836	M6	212.3	0.089
106836	MK3	266.1	0.013
106836	S4	267.6	0.006
106836	MN4	223.3	0.035
106836	S6	175.1	0.002
106836	2N2	10.7	0.014
106836	OO1	352.1	0.015
106836	M1	215.1	0.006
106836	J1	231.4	0.009
106836	Q1	258.6	0.005
106836	2Q1	83.6	0.004
106836	P1	66.8	0.117
106836	2SM2	348.9	0.005
106836	M3	43.7	0.007
106836	L2	34	0.034
106836	2MK3	302.3	0.012
106836	K2	54.7	0.034
106836	M8	70	0.015
106836	MS4	259.1	0.004
106837	M2	349	0.323
106837	S2	1.8	0.095
106837	N2	347.5	0.066
106837	K1	69.4	0.07
106837	M4	199.1	0.029
106837	O1	120.7	0.092
106837	M6	189	0.093
106837	MK3	287.9	0.029
106837	S4	186.1	0.011
106837	MN4	217.2	0.016
106837	S6	235.9	0.004
106837	2N2	234.5	0.006
106837	OO1	189	0.009
106837	M1	165.3	0.018
106837	J1	117.6	0.009
106837	Q1	93.9	0.021
106837	2Q1	77.5	0.012
106837	P1	149.2	0.009
106837	2SM2	25	0.008
106837	M3	242.1	0.019
106837	L2	10.4	0.011
106837	2MK3	328.3	0.032
106837	K2	324	0.019
106837	M8	8.2	0.051
106837	MS4	146.4	0.022
106838	M2	359.7	0.484
106838	S2	7.7	0.129
106838	N2	342.6	0.1
106838	K1	75.1	0.089
106838	M4	242.6	0.086
106838	O1	124.7	0.095
106838	M6	194.4	0.112
106838	MK3	290	0.023
106838	S4	210.7	0.012
106838	MN4	225.3	0.045
106838	S6	221.3	0.004
106838	2N2	68	0.007
106838	OO1	120.8	0.006
106838	M1	173.9	0.021
106838	J1	135.5	0.009
106838	Q1	104.7	0.016
106838	2Q1	107.3	0.013
106838	P1	8.4	0.013
106838	2SM2	9.5	0.009
106838	M3	255.2	0.022
106838	L2	32	0.022
106838	2MK3	332.3	0.036
106838	K2	342	0.034
106838	M8	16.1	0.053
106838	MS4	197.8	0.019
106839	M2	337.4	0.647
106839	S2	1.1	0.108
106839	N2	313.1	0.11
106839	K1	108.8	0.047
106839	M4	297.3	0.188
106839	O1	186.8	0.018
106839	M6	180.5	0.115
106839	MK3	305.3	0.034
106839	S4	312.4	0.015
106839	MN4	255.5	0.074
106839	S6	46.4	0.003
106839	2N2	287.4	0.006
106839	OO1	321.7	0.011
106839	M1	255.4	0.004
106839	J1	198.1	0.014
106839	Q1	162.4	0.01
106839	2Q1	304.3	0.009
106839	P1	69.2	0.029
106839	2SM2	333.7	0.014
106839	M3	169.5	0.004
106839	L2	36	0.021
106839	2MK3	289.7	0.013
106839	K2	12	0.033
106839	M8	216.4	0.034
106839	MS4	307	0.035
106840	M2	12.4	1.576
106840	S2	26.4	0.202
106840	N2	339.5	0.266
106840	K1	73.2	0.084
106840	M4	99.6	0.167
106840	O1	125.7	0.034
106840	M6	238.4	0.118
106840	MK3	113.3	0.028
106840	S4	83.1	0.007
106840	MN4	79	0.064
106840	S6	310.3	0.007
106840	2N2	316.4	0.018
106840	OO1	25	0.016
106840	M1	173.7	0.013
106840	J1	170.7	0.015
106840	Q1	149.2	0.014
106840	2Q1	55.8	0.003
106840	2SM2	79.6	0.014
106840	M3	83.2	0.014
106840	L2	80.4	0.082
106840	2MK3	106.7	0.016
106840	M8	218.4	0.011
106840	MS4	148.6	0.035
106841	M2	12.7	2.267
106841	S2	21.6	0.271
106841	N2	336.2	0.332
106841	K1	71.9	0.119
106841	M4	123	0.218
106841	O1	123.3	0.052
106841	M6	251.6	0.211
106841	MK3	119.4	0.029
106841	S4	70.8	0.008
106841	MN4	94.7	0.063
106841	S6	9.1	0.006
106841	2N2	335.4	0.037
106841	OO1	24	0.021
106841	M1	169.7	0.019
106841	J1	167.9	0.023
106841	Q1	152.7	0.015
106841	2Q1	47.8	0.008
106841	2SM2	86.9	0.025
106841	M3	103.1	0.018
106841	L2	83.5	0.175
106841	2MK3	110.8	0.019
106841	M8	90.9	0.009
106841	MS4	160.4	0.043
106842	M2	11	2.715
106842	S2	17.2	0.269
106842	N2	327.4	0.342
106842	K1	60.5	0.129
106842	M4	122.8	0.353
106842	O1	142.9	0.042
106842	M6	268.6	0.317
106842	MK3	152	0.056
106842	S4	17.6	0.013
106842	MN4	110.5	0.096
106842	2N2	355.5	0.074
106842	OO1	18	0.02
106842	M1	169.8	0.023
106842	J1	156	0.03
106842	Q1	143.9	0.016
106842	2Q1	38.4	0.009
106842	2SM2	75.2	0.043
106842	M3	115	0.024
106842	L2	74.3	0.292
106842	2MK3	147.9	0.032
106842	M8	34.1	0.039
106842	MS4	134.8	0.058
106843	M2	25.1	1.501
106843	S2	42.2	0.217
106843	N2	358.2	0.219
106843	K1	116.8	0.1
106843	M4	6.9	0.124
106843	O1	130.6	0.073
106843	M6	309.8	0.074
106843	MK3	62.3	0.03
106843	S4	196.9	0.005
106843	MN4	6	0.056
106843	S6	185.2	0.004
106843	2N2	346.6	0.029
106843	OO1	17.2	0.01
106843	M1	162.2	0.018
106843	J1	171.5	0.021
106843	Q1	58.4	0.013
106843	2Q1	22.9	0.006
106843	P1	84.9	0.063
106843	2SM2	58.5	0.013
106843	M3	13	0.016
106843	L2	67.4	0.144
106843	2MK3	118	0.014
106843	K2	38.4	0.066
106843	M8	311.5	0.038
106843	MS4	40	0.015
106844	M2	34.3	1.881
106844	S2	59.9	0.304
106844	N2	5.1	0.341
106844	K1	95.2	0.117
106844	M4	74.7	0.075
106844	O1	134.6	0.063
106844	M6	310.6	0.041
106844	MK3	137.6	0.016
106844	S4	66.9	0.004
106844	MN4	44.8	0.04
106844	S6	247.8	0.007
106844	2N2	29.2	0.023
106844	OO1	53.9	0.012
106844	M1	182.1	0.022
106844	J1	187.9	0.017
106844	Q1	126.9	0.021
106844	2Q1	340.7	0.005
106844	P1	129.2	0.042
106844	2SM2	124.8	0.023
106844	M3	45.9	0.006
106844	L2	99	0.098
106844	2MK3	170.4	0.007
106844	K2	60.4	0.1
106844	M8	83.1	0.019
106844	MS4	125	0.016
106845	M2	32.9	2.151
106845	S2	74.9	0.419
106845	N2	8.5	0.499
106845	K1	91.8	0.114
106845	M4	137.8	0.142
106845	O1	148.9	0.133
106845	M6	264.3	0.097
106845	MK3	120.8	0.059
106845	S4	112.1	0.013
106845	MN4	101.6	0.057
106845	2N2	293.5	0.004
106845	OO1	206.2	0.003
106845	M1	188	0.015
106845	J1	152.3	0.022
106845	Q1	108.9	0.033
106845	2Q1	98.2	0.02
106845	P1	174.5	0.049
106845	2SM2	317.5	0.021
106845	M3	117.6	0.01
106845	L2	45.9	0.084
106845	2MK3	170.7	0.018
106845	K2	54.8	0.122
106845	M8	175.1	0.021
106845	MS4	113.2	0.065
106846	M2	357	1.813
106846	S2	51.9	0.224
106846	N2	344.1	0.234
106846	K1	81.8	0.053
106846	M4	252.4	0.011
106846	O1	145.5	0.025
106846	M6	218.1	0.255
106846	MK3	310.9	0.003
106846	S4	235.1	0.019
106846	MN4	68.2	0.02
106846	S6	341.7	0.022
106846	2N2	274.8	0.112
106846	OO1	30	0.018
106846	M1	131.1	0.015
106846	J1	184.8	0.037
106846	Q1	164.5	0.012
106846	2Q1	129.3	0.006
106846	P1	140	0.023
106846	2SM2	21.8	0.063
106846	M3	78	0.036
106846	L2	15.4	0.217
106846	2MK3	127.9	0.028
106846	K2	33.4	0.139
106846	M8	33.2	0.014
106846	MS4	128.2	0.035
106847	M2	0.2	2.178
106847	S2	38.8	0.38
106847	N2	333.2	0.399
106847	K1	85.7	0.088
106847	M4	135.3	0.049
106847	O1	96	0.048
106847	M6	238.7	0.226
106847	MK3	137.7	0.023
106847	S4	181.6	0.019
106847	MN4	123	0.088
106847	S6	288.8	0.013
106847	2N2	291.9	0.087
106847	OO1	339.8	0.012
106847	M1	113.8	0.017
106847	J1	175.7	0.022
106847	Q1	104.1	0.017
106847	2Q1	124.4	0.012
106847	P1	82.6	0.038
106847	2SM2	20	0.049
106847	M3	91.6	0.046
106847	L2	28.7	0.129
106847	2MK3	144.2	0.02
106847	K2	28.5	0.199
106847	M8	157.9	0.018
106847	MS4	146.7	0.066
106848	M2	0.1	2.36
106848	S2	32.4	0.383
106848	N2	328.4	0.404
106848	K1	70.1	0.113
106848	M4	123.5	0.182
106848	O1	126.4	0.076
106848	M6	243.7	0.212
106848	MK3	121.1	0.028
106848	S4	100.1	0.023
106848	MN4	54	0.046
106848	S6	254.3	0.013
106848	2N2	352.2	0.092
106848	M1	159.7	0.018
106848	J1	22.5	0.006
106848	Q1	67.2	0.034
106848	2Q1	66.8	0.016
106848	P1	18	0.025
106848	2SM2	168.9	0.008
106848	M3	79.4	0.018
106848	L2	79.4	0.185
106848	2MK3	268.4	0.006
106848	K2	37.8	0.158
106848	M8	63.3	0.063
106848	MS4	122.4	0.033
106849	M2	347.7	1.137
106849	S2	15.7	0.14
106849	N2	322.3	0.18
106849	K1	57	0.043
106849	M4	320.6	0.045
106849	O1	99.6	0.039
106849	M6	224.2	0.114
106849	MK3	39.1	0.024
106849	S4	52.2	0.01
106849	MN4	281.5	0.021
106849	S6	120	0.002
106849	2N2	339.7	0.019
106849	OO1	13.6	0.007
106849	M1	131.4	0.013
106849	J1	154.3	0.016
106849	Q1	169.1	0.001
106849	2Q1	55.2	0.01
106849	2SM2	29.8	0.003
106849	M3	26.2	0.012
106849	L2	28.6	0.075
106849	2MK3	87.9	0.017
106849	M8	296.9	0.022
106849	MS4	322.5	0.022
106850	M2	347.3	1.337
106850	S2	12.7	0.166
106850	N2	321.5	0.206
106850	K1	50.3	0.05
106850	M4	294.6	0.053
106850	O1	95	0.041
106850	M6	223.5	0.149
106850	MK3	39.1	0.025
106850	S4	52.8	0.009
106850	MN4	264.8	0.021
106850	S6	110.6	0.003
106850	2N2	335.1	0.022
106850	OO1	9.6	0.01
106850	M1	126.3	0.014
106850	J1	157.8	0.016
106850	Q1	161.7	0.002
106850	2Q1	62.3	0.01
106850	2SM2	33.9	0.006
106850	M3	27.7	0.011
106850	L2	32.1	0.096
106850	2MK3	91.7	0.02
106850	M8	270.3	0.018
106850	MS4	307.7	0.025
106851	M2	342.9	1.484
106851	S2	359.8	0.151
106851	N2	309.7	0.203
106851	K1	47.2	0.034
106851	M4	126.1	0.134
106851	O1	95.6	0.017
106851	M6	194.4	0.059
106851	MK3	122	0.048
106851	S4	346.7	0.005
106851	MN4	102.3	0.06
106851	S6	191.1	0.003
106851	2N2	347	0.032
106851	OO1	349.9	0.014
106851	M1	148.2	0.013
106851	J1	180.7	0.01
106851	Q1	186.5	0.005
106851	2Q1	88.7	0.011
106851	2SM2	15.3	0.014
106851	M3	101.7	0.022
106851	L2	25.3	0.158
106851	2MK3	147.4	0.031
106851	M8	37.4	0.026
106851	MS4	148.7	0.039
106852	M2	52	0.696
106852	S2	96.5	0.112
106852	N2	32.8	0.168
106852	K1	104.4	0.13
106852	M4	157.4	0.039
106852	O1	120.7	0.099
106852	M6	229.6	0.03
106852	MK3	296.6	0.017
106852	S4	270.6	0.007
106852	MN4	111.7	0.006
106852	S6	234.1	0.002
106852	2N2	104	0.015
106852	OO1	121.4	0.013
106852	M1	318.3	0.004
106852	J1	199	0.017
106852	Q1	113.4	0.028
106852	2Q1	322.3	0.011
106852	P1	243.9	0.01
106852	2SM2	22.2	0.011
106852	M3	216.1	0.042
106852	L2	182.4	0.053
106852	2MK3	2.9	0.056
106852	K2	200.2	0.024
106852	M8	214.3	0.011
106852	MS4	94.6	0.025
106853	M2	52.7	1.13
106853	S2	98	0.145
106853	N2	38.1	0.216
106853	K1	136.9	0.1
106853	M4	109.8	0.008
106853	O1	152.5	0.069
106853	M6	328.8	0.043
106853	MK3	153.4	0.044
106853	S4	267.7	0.003
106853	MN4	294.5	0.012
106853	S6	54.2	0.004
106853	2N2	293.7	0.011
106853	OO1	147.7	0.018
106853	M1	245.4	0.006
106853	J1	169.1	0.009
106853	Q1	130.4	0.023
106853	2Q1	279.2	0.004
106853	P1	59.2	0.026
106853	2SM2	11.8	0.012
106853	M3	63.8	0.016
106853	L2	86.9	0.122
106853	2MK3	164.1	0.043
106853	K2	138.3	0.025
106853	M8	301.5	0.02
106853	MS4	164	0.026
106854	M2	53.4	1.305
106854	S2	72.5	0.182
106854	N2	41.3	0.261
106854	K1	161	0.134
106854	M4	194	0.054
106854	O1	195.3	0.093
106854	M6	31.7	0.039
106854	MK3	296.8	0.021
106854	S4	357.4	0.005
106854	MN4	246.6	0.042
106854	S6	309.6	0.007
106854	2N2	357	0.049
106854	OO1	171.7	0.018
106854	M1	206	0.014
106854	J1	202.9	0.004
106854	Q1	177.2	0.026
106854	2Q1	208	0.011
106854	P1	73.1	0.054
106854	2SM2	82.2	0.009
106854	M3	82.7	0.026
106854	L2	76.5	0.15
106854	2MK3	142.8	0.018
106854	K2	74.1	0.084
106854	M8	108.4	0.043
106854	MS4	268.9	0.024
106855	M2	38.9	0.902
106855	S2	58	0.126
106855	N2	28.8	0.189
106855	K1	118.8	0.082
106855	M4	36.1	0.034
106855	O1	142.5	0.074
106855	M6	337.3	0.08
106855	MK3	83.6	0.027
106855	S4	333.7	0.003
106855	MN4	6	0.024
106855	S6	70.6	0.005
106855	2N2	22.1	0.011
106855	OO1	110.7	0.019
106855	M1	193.1	0.012
106855	J1	155	0.013
106855	Q1	148.8	0.017
106855	2Q1	162.5	0.006
106855	P1	94.4	0.037
106855	M3	58.7	0.011
106855	L2	97.3	0.052
106855	2MK3	14	0.018
106855	K2	30.7	0.041
106855	M8	290.5	0.014
106855	MS4	67.2	0.026
106856	M2	57.5	1.496
106856	S2	70.2	0.176
106856	N2	35.6	0.277
106856	K1	127.2	0.12
106856	M4	221.3	0.055
106856	O1	181.5	0.085
106856	M6	129.3	0.087
106856	MK3	217	0.031
106856	S4	61.5	0.008
106856	MN4	227.7	0.045
106856	S6	98.8	0.008
106856	2N2	352.3	0.071
106856	OO1	158.5	0.019
106856	M1	241.2	0.002
106856	J1	258.9	0.005
106856	Q1	163.9	0.024
106856	2Q1	266.9	0.01
106856	P1	125.5	0.028
106856	2SM2	197.4	0.002
106856	M3	143.8	0.037
106856	L2	98.1	0.21
106856	2MK3	202	0.048
106856	K2	67.3	0.073
106856	M8	72	0.008
106856	MS4	212.4	0.042
106857	M2	20	1.054
106857	S2	49.6	0.189
106857	N2	3.7	0.295
106857	K1	101.9	0.073
106857	M4	326.4	0.046
106857	O1	134.2	0.053
106857	M6	287.1	0.022
106857	MK3	45.5	0.012
106857	S4	30.8	0.004
106857	MN4	278.8	0.053
106857	S6	192.4	0.006
106857	2N2	26.2	0.035
106857	OO1	129.1	0.007
106857	M1	198.4	0.004
106857	J1	344.3	0.005
106857	Q1	211.5	0.003
106857	2Q1	9.6	0.007
106857	P1	66.9	0.03
106857	2SM2	142.6	0.015
106857	M3	39.9	0.01
106857	L2	0.7	0.056
106857	2MK3	47.1	0.02
106857	K2	28.8	0.059
106857	M8	216.7	0.022
106857	MS4	350.5	0.027
106858	M2	24.1	1.569
106858	S2	49.3	0.229
106858	N2	6.1	0.342
106858	K1	107.9	0.095
106858	M4	351	0.034
106858	O1	136.7	0.055
106858	M6	338.8	0.053
106858	MK3	101.8	0.024
106858	S4	313.8	0.004
106858	MN4	293.1	0.026
106858	S6	110.4	0.006
106858	2N2	346.4	0.055
106858	OO1	97.3	0.007
106858	M1	99.1	0.006
106858	J1	242.6	0.007
106858	Q1	109.4	0.014
106858	2Q1	343.4	0.003
106858	P1	98.6	0.022
106858	2SM2	132.7	0.023
106858	M3	352.5	0.011
106858	L2	43.9	0.075
106858	2MK3	86.3	0.017
106858	K2	31.3	0.061
106858	M8	242.7	0.017
106858	MS4	355.4	0.017
106859	M2	31.7	2.116
106859	S2	59.9	0.295
106859	N2	14.2	0.462
106859	K1	95.3	0.1
106859	M4	69.3	0.007
106859	O1	148.3	0.032
106859	M6	261.8	0.053
106859	MK3	351.7	0.018
106859	S4	45.5	0.013
106859	MN4	309.6	0.022
106859	S6	208.5	0.005
106859	2N2	339.3	0.038
106859	OO1	65.9	0.007
106859	M1	324.4	0.006
106859	J1	93.6	0.005
106859	Q1	89.7	0.016
106859	2Q1	195.4	0.003
106859	P1	83.4	0.026
106859	2SM2	13.3	0.014
106859	M3	177.3	0.02
106859	L2	63.4	0.189
106859	2MK3	191	0.003
106859	K2	53	0.057
106859	M8	142	0.019
106859	MS4	213.5	0.014
106860	M2	22.5	0.98
106860	S2	51	0.142
106860	N2	10.5	0.221
106860	K1	101.4	0.041
106860	M4	96.6	0.029
106860	O1	127.5	0.028
106860	M6	219.2	0.025
106860	MK3	140.9	0.01
106860	MN4	123	0.031
106860	2N2	2.2	0.035
106860	OO1	143.7	0.012
106860	M1	235.3	0.006
106860	J1	264.3	0.005
106860	Q1	173	0.005
106860	2Q1	78.8	0.002
106860	P1	76	0.029
106860	2SM2	304.2	0.005
106860	M3	88.6	0.015
106860	L2	49.2	0.066
106860	2MK3	242.8	0.002
106860	K2	56	0.048
106860	M8	159	0.011
106860	MS4	218.1	0.015
106861	M2	30.9	1.483
106861	S2	43.4	0.246
106861	N2	12.6	0.283
106861	K1	114.5	0.072
106861	M4	329	0.028
106861	O1	127.3	0.034
106861	M6	73.2	0.034
106861	MK3	124.4	0.017
106861	S4	336.6	0.007
106861	MN4	205.6	0.023
106861	2N2	323	0.064
106861	OO1	135.8	0.008
106861	M1	240.9	0.004
106861	J1	323.7	0.008
106861	Q1	134.7	0.015
106861	2Q1	215	0.01
106861	P1	41.9	0.025
106861	2SM2	121.8	0.01
106861	M3	118.1	0.023
106861	L2	79	0.166
106861	2MK3	188.2	0.017
106861	K2	61.4	0.108
106861	M8	283.2	0.007
106861	MS4	274.8	0.019
106862	M2	31.3	1.736
106862	S2	58	0.279
106862	N2	13	0.39
106862	K1	86.1	0.103
106862	M4	350.8	0.025
106862	O1	205	0.025
106862	M6	335.7	0.012
106862	MK3	39.7	0.004
106862	S4	307.7	0.008
106862	MN4	339	0.042
106862	S6	133.9	0.009
106862	2N2	182.3	0.028
106862	OO1	152.5	0.015
106862	M1	311.5	0.006
106862	J1	343.2	0.011
106862	Q1	93.5	0.021
106862	2Q1	163.8	0.009
106862	P1	150.1	0.048
106862	2SM2	93.1	0.034
106862	M3	270.4	0.013
106862	L2	44.1	0.155
106862	2MK3	46.5	0.002
106862	K2	44.5	0.079
106862	M8	160.7	0.01
106862	MS4	65	0.019
106863	M2	13.3	1.004
106863	S2	57	0.138
106863	N2	2.7	0.232
106863	K1	89	0.049
106863	M4	22.5	0.027
106863	O1	110.7	0.026
106863	M6	200.5	0.048
106863	MK3	73.6	0.018
106863	S4	37.9	0.002
106863	MN4	355.8	0.024
106863	S6	56.5	0.003
106863	2N2	50.9	0.032
106863	OO1	118	0.009
106863	M1	199.6	0.001
106863	J1	173.6	0.008
106863	Q1	123.9	0.011
106863	2Q1	244.4	0.004
106863	P1	117.8	0.02
106863	2SM2	153	0.006
106863	M3	73.7	0.008
106863	L2	11.4	0.076
106863	2MK3	69.2	0.015
106863	K2	4	0.022
106863	M8	283.9	0.011
106863	MS4	9.8	0.014
106864	M2	14.7	1.413
106864	S2	52.5	0.174
106864	N2	4.1	0.311
106864	K1	74.7	0.059
106864	M4	40.4	0.081
106864	O1	113.2	0.043
106864	M6	291.5	0.052
106864	MK3	90	0.026
106864	S4	62.2	0.002
106864	MN4	10.7	0.036
106864	S6	254.5	0.003
106864	2N2	23.8	0.027
106864	OO1	103.6	0.009
106864	M1	149.8	0.006
106864	J1	164.6	0.01
106864	Q1	141.6	0.009
106864	P1	109.4	0.031
106864	2SM2	148.5	0.003
106864	M3	68.2	0.014
106864	L2	26.1	0.132
106864	2MK3	101.6	0.022
106864	K2	24.8	0.034
106864	M8	350.7	0.011
106864	MS4	30	0.014
106865	M2	19.9	1.683
106865	S2	42.7	0.241
106865	N2	4	0.334
106865	K1	85.5	0.079
106865	M4	43.8	0.139
106865	O1	125.5	0.049
106865	M6	324.7	0.066
106865	MK3	94.5	0.028
106865	S4	154.6	0.007
106865	MN4	6.9	0.042
106865	2N2	327.7	0.049
106865	OO1	103.1	0.013
106865	M1	154	0.01
106865	J1	181.6	0.004
106865	Q1	133.7	0.012
106865	2Q1	100.2	0.004
106865	P1	79.8	0.019
106865	2SM2	330	0.007
106865	M3	73.7	0.015
106865	L2	52.2	0.135
106865	2MK3	114.3	0.019
106865	K2	42.5	0.066
106865	M8	78.7	0.017
106865	MS4	46.7	0.026
106866	M2	15.1	1.184
106866	S2	51.7	0.17
106866	N2	5.5	0.248
106866	K1	90.1	0.054
106866	M4	349.4	0.038
106866	O1	118.6	0.042
106866	M6	254	0.043
106866	MK3	64.5	0.022
106866	S4	305.8	0.002
106866	MN4	305.3	0.03
106866	S6	312.2	0.003
106866	2N2	57.7	0.022
106866	OO1	141.9	0.011
106866	M1	149.2	0.008
106866	J1	215.8	0.007
106866	Q1	176.6	0.011
106866	2Q1	305.8	0.006
106866	P1	101.2	0.024
106866	2SM2	110.2	0.01
106866	M3	27.5	0.006
106866	L2	26.8	0.095
106866	2MK3	89.5	0.019
106866	K2	39.7	0.042
106866	M8	16.9	0.01
106866	MS4	31	0.011
106867	M2	16.8	1.459
106867	S2	47.4	0.195
106867	N2	3.3	0.294
106867	K1	95.8	0.067
106867	M4	3.2	0.048
106867	O1	119.5	0.058
106867	M6	270.5	0.076
106867	MK3	74.3	0.03
106867	S4	340.5	0.005
106867	MN4	313.4	0.03
106867	2N2	348.3	0.021
106867	OO1	134.2	0.014
106867	M1	147.1	0.012
106867	J1	207.9	0.007
106867	Q1	163.3	0.016
106867	2Q1	341.4	0.005
106867	P1	69.5	0.021
106867	2SM2	102.4	0.012
106867	M3	39.8	0.01
106867	L2	35.3	0.121
106867	2MK3	111.4	0.024
106867	K2	31.9	0.057
106867	M8	346.9	0.012
106867	MS4	37.2	0.016
106868	M2	21.2	1.649
106868	S2	47.5	0.243
106868	N2	7.7	0.304
106868	K1	97.9	0.081
106868	M4	24.2	0.108
106868	O1	124.9	0.074
106868	M6	292.4	0.087
106868	MK3	83.2	0.04
106868	S4	12.6	0.01
106868	MN4	350.2	0.044
106868	S6	86.5	0.005
106868	2N2	295.3	0.04
106868	OO1	123.5	0.013
106868	M1	133	0.013
106868	J1	197.1	0.008
106868	Q1	135	0.014
106868	2Q1	316.8	0.004
106868	P1	44.8	0.023
106868	2SM2	64.9	0.01
106868	M3	81.1	0.014
106868	L2	53.2	0.124
106868	2MK3	133.4	0.033
106868	K2	49.8	0.066
106868	M8	307.4	0.031
106868	MS4	31.6	0.03
106869	M2	356.3	0.638
106869	S2	54.1	0.072
106869	N2	340.4	0.107
106869	K1	45.3	0.019
106869	M4	212.1	0.092
106869	O1	180.7	0.007
106869	M6	284.9	0.026
106869	MK3	221.6	0.005
106869	S4	156.7	0.005
106869	MN4	224.3	0.007
106869	S6	248.3	0.002
106869	2N2	257.5	0.023
106869	OO1	87.9	0.008
106869	M1	310	0.004
106869	J1	303.3	0.008
106869	Q1	156.7	0.007
106869	2Q1	291.1	0.009
106869	2SM2	109.2	0.004
106869	M3	6.9	0.013
106869	L2	11.4	0.095
106869	2MK3	167.6	0.005
106869	M8	89.5	0.015
106869	MS4	303.9	0.013
106870	M2	19.3	0.73
106870	S2	65.9	0.097
106870	N2	3.7	0.196
106870	K1	131.2	0.042
106870	M4	187.2	0.027
106870	O1	234.2	0.02
106870	M6	21.3	0.011
106870	MK3	325.9	0.005
106870	S4	336.1	0.008
106870	MN4	212.9	0.018
106870	S6	36.7	0.006
106870	2N2	207.1	0.003
106870	OO1	149.1	0.016
106870	M1	2.4	0.008
106870	J1	338	0.014
106870	Q1	174.2	0.015
106870	2Q1	302.4	0.013
106870	2SM2	18.3	0.012
106870	M3	251.8	0.005
106870	L2	45	0.078
106870	2MK3	117.9	0.015
106870	M8	161.7	0.007
106870	MS4	352.5	0.005
106871	M2	20.7	0.674
106871	S2	64.3	0.083
106871	N2	11.8	0.149
106871	K1	97.3	0.049
106871	M4	64.7	0.036
106871	O1	234.5	0.015
106871	M6	237.1	0.011
106871	MK3	203.1	0.004
106871	S4	10.6	0.003
106871	MN4	117.8	0.018
106871	S6	139.5	0.008
106871	2N2	108.9	0.014
106871	OO1	99.3	0.009
106871	M1	76.5	0.001
106871	J1	211.9	0.014
106871	Q1	331	0.006
106871	2Q1	163.7	0.02
106871	2SM2	321.2	0.008
106871	M3	246.2	0.011
106871	L2	26.4	0.033
106871	2MK3	29.1	0.015
106871	M8	269.2	0.013
106871	MS4	208.4	0.006
106872	M2	13.2	0.567
106872	S2	57.8	0.059
106872	N2	350.2	0.12
106872	K1	130.6	0.041
106872	M4	32.8	0.003
106872	O1	166.7	0.014
106872	M6	271.3	0.012
106872	MK3	106.5	0.006
106872	S4	265.2	0.001
106872	MN4	0.6	0.008
106872	2N2	259.2	0.013
106872	OO1	110.5	0.006
106872	M1	263.5	0.005
106872	J1	245.9	0.01
106872	Q1	125.5	0.007
106872	2Q1	258.5	0.003
106872	2SM2	47.3	0.007
106872	M3	28.3	0.004
106872	L2	41.1	0.081
106872	2MK3	92.7	0.009
106872	M8	180.9	0.004
106872	MS4	345.6	0.007
106873	M2	25.8	0.775
106873	S2	67.1	0.108
106873	N2	13.5	0.166
106873	K1	126.6	0.064
106873	M4	29.3	0.036
106873	O1	158.5	0.019
106873	M6	36.7	0.009
106873	MK3	115.2	0.011
106873	S4	86.5	0.007
106873	MN4	28.3	0.026
106873	S6	135.9	0.002
106873	2N2	295.1	0.015
106873	OO1	95	0.01
106873	M1	243.2	0.008
106873	J1	242.2	0.007
106873	Q1	107.7	0.011
106873	2Q1	279.9	0.003
106873	2SM2	337	0.009
106873	M3	112.3	0.007
106873	L2	60.4	0.031
106873	2MK3	122	0.01
106873	M8	201	0.001
106873	MS4	90.9	0.007
106874	M2	38.1	0.745
106874	S2	65.7	0.098
106874	N2	23.7	0.139
106874	K1	66	0.042
106874	M4	18.3	0.01
106874	O1	145.4	0.023
106874	M6	59.9	0.003
106874	MK3	173.8	0.004
106874	S4	276.8	0.002
106874	MN4	12.8	0.005
106874	S6	92	0.002
106874	2N2	50.9	0.014
106874	OO1	240.2	0.012
106874	M1	82.3	0.019
106874	J1	59.6	0.022
106874	Q1	310.5	0.017
106874	2Q1	140.6	0.011
106874	2SM2	148.2	0.019
106874	M3	90.6	0.001
106874	L2	77.2	0.063
106874	2MK3	85	0.006
106874	M8	321	0.003
106874	MS4	100.9	0.005
106875	M2	10.3	0.058
106875	S2	57.3	0.016
106875	N2	33.7	0.016
106875	K1	232.2	0.008
106875	M4	169.9	0.074
106875	O1	232.3	0.012
106875	M6	50.3	0.019
106875	MK3	173.4	0.012
106875	S4	313	0.004
106875	MN4	155.8	0.029
106875	S6	13	0.004
106875	2N2	165.9	0.001
106875	OO1	178.5	0.009
106875	M1	83.9	0.001
106875	J1	351.1	0.006
106875	Q1	167.9	0.008
106875	2Q1	301.4	0.001
106875	2SM2	238.9	0.009
106875	M3	142.2	0.011
106875	L2	29.7	0.011
106875	2MK3	178.8	0.005
106875	M8	230.4	0.014
106875	MS4	209.7	0.022
106876	M2	35.5	0.212
106876	S2	79.8	0.032
106876	N2	34.9	0.047
106876	K1	15.5	0.014
106876	M4	234.1	0.062
106876	O1	163.1	0.014
106876	M6	56.1	0.028
106876	MK3	265.5	0.009
106876	S4	323.8	0.01
106876	MN4	220	0.03
106876	S6	86.9	0.003
106876	2N2	128.8	0.004
106876	OO1	154.3	0.01
106876	M1	153.5	0.003
106876	J1	40.6	0.008
106876	Q1	191.5	0.012
106876	2Q1	7.2	0.005
106876	2SM2	319.7	0.006
106876	M3	247.6	0.003
106876	L2	50	0.017
106876	2MK3	52.8	0.009
106876	M8	222	0.01
106876	MS4	248.2	0.016
106877	M2	49.3	0.36
106877	S2	94.9	0.039
106877	N2	38.1	0.08
106877	K1	63.4	0.03
106877	M4	267.8	0.08
106877	O1	153.1	0.022
106877	M6	56.9	0.035
106877	MK3	273.2	0.008
106877	S4	318.5	0.008
106877	MN4	254.7	0.033
106877	S6	29.8	0.003
106877	2N2	180.7	0.004
106877	OO1	134.7	0.014
106877	M1	175.5	0.004
106877	J1	104.1	0.013
106877	Q1	178.9	0.005
106877	2Q1	36.4	0.014
106877	2SM2	81.3	0.012
106877	M3	14.6	0.004
106877	L2	73.1	0.025
106877	2MK3	85.2	0.011
106877	M8	272.4	0.022
106877	MS4	285.6	0.012
106878	M2	3.8	0.434
106878	S2	48.2	0.054
106878	N2	348.2	0.081
106878	K1	74.1	0.038
106878	M4	319.4	0.083
106878	O1	108.2	0.017
106878	M6	265.2	0.055
106878	MK3	3.7	0.015
106878	S4	294.7	0.004
106878	MN4	296.8	0.027
106878	S6	53.7	0.001
106878	2N2	26.2	0.011
106878	OO1	100.2	0.012
106878	M1	11.5	0.001
106878	J1	235.7	0.005
106878	Q1	168.2	0.002
106878	2Q1	201.1	0.009
106878	P1	226.7	0.02
106878	2SM2	11.2	0.006
106878	M3	8.3	0.014
106878	L2	13.1	0.05
106878	2MK3	67.8	0.022
106878	K2	41.8	0.017
106878	M8	224.3	0.026
106878	MS4	14.9	0.013
106879	M2	20.4	0.512
106879	S2	57.2	0.076
106879	N2	1.4	0.107
106879	K1	108	0.044
106879	M4	2.2	0.058
106879	O1	141	0.019
106879	M6	297.8	0.036
106879	MK3	80.8	0.012
106879	S4	340	0.008
106879	MN4	2.7	0.031
106879	S6	175.5	0.003
106879	2N2	5.5	0.013
106879	OO1	77.7	0.008
106879	M1	267.7	0.003
106879	J1	52.8	0.01
106879	Q1	125.2	0.013
106879	2Q1	168.6	0.008
106879	P1	317.9	0.012
106879	2SM2	306.7	0.011
106879	M3	28.8	0.01
106879	L2	39	0.05
106879	2MK3	116.7	0.012
106879	K2	59	0.023
106879	M8	237.5	0.017
106879	MS4	18.5	0.019
106880	M2	29.5	0.618
106880	S2	56.2	0.078
106880	N2	8.2	0.133
106880	K1	110.9	0.048
106880	M4	48.1	0.043
106880	O1	94.6	0.023
106880	M6	306.3	0.032
106880	MK3	46.1	0.015
106880	S4	43.8	0.009
106880	MN4	25.5	0.03
106880	S6	55	0.002
106880	2N2	349.7	0.017
106880	OO1	34.5	0.004
106880	M1	213.5	0.008
106880	J1	54.4	0.02
106880	Q1	81.3	0.006
106880	2Q1	299.2	0.003
106880	P1	319.1	0.041
106880	2SM2	346.5	0.007
106880	M3	18.9	0.006
106880	L2	55.7	0.072
106880	2MK3	72.1	0.014
106880	K2	18.4	0.023
106880	M8	189.2	0.014
106880	MS4	71	0.012
106881	M2	29	0.374
106881	S2	65.7	0.058
106881	N2	27	0.076
106881	K1	337.8	0.011
106881	M4	299.4	0.055
106881	O1	165.8	0.021
106881	M6	342.9	0.049
106881	MK3	53.8	0.008
106881	S4	268.8	0.004
106881	MN4	253.1	0.016
106881	S6	28.7	0.002
106881	2N2	225.3	0.005
106881	OO1	142.2	0.011
106881	M1	109.9	0.007
106881	J1	0.9	0.017
106881	Q1	233.6	0.014
106881	2Q1	349.4	0.016
106881	2SM2	325.1	0.004
106881	M3	292	0.007
106881	L2	8.1	0.035
106881	2MK3	117.3	0.006
106881	M8	252.4	0.024
106881	MS4	339.8	0.006
106882	M2	42.9	0.328
106882	S2	82.7	0.05
106882	N2	29.1	0.073
106882	K1	349.8	0.037
106882	M4	40.3	0.026
106882	O1	144.5	0.004
106882	M6	342.1	0.041
106882	MK3	63.9	0.016
106882	S4	106.3	0.005
106882	MN4	58.8	0.01
106882	S6	259.4	0.001
106882	2N2	303.2	0.003
106882	OO1	160.2	0.006
106882	M1	63.3	0.003
106882	J1	44.6	0.017
106882	Q1	303.2	0.008
106882	2Q1	12	0.011
106882	2SM2	256.4	0.004
106882	M3	357.9	0.003
106882	L2	33.1	0.045
106882	2MK3	166.5	0.007
106882	M8	356.4	0.006
106882	MS4	115.3	0.007
106883	M2	49.2	0.24
106883	S2	108.1	0.033
106883	N2	43.2	0.063
106883	K1	330.3	0.024
106883	M4	88.9	0.032
106883	O1	147.4	0.018
106883	M6	301.1	0.019
106883	MK3	75.3	0.015
106883	S4	77.7	0.004
106883	MN4	54.7	0.021
106883	S6	49.6	0.004
106883	2N2	125.4	0.008
106883	OO1	109.2	0.005
106883	M1	193.3	0.001
106883	J1	77.6	0.003
106883	Q1	73.7	0.003
106883	2Q1	73.5	0.011
106883	2SM2	81.2	0.01
106883	M3	88.1	0.008
106883	L2	33.1	0.031
106883	2MK3	165.2	0.009
106883	M8	158	0.002
106883	MS4	120.4	0.007
106884	M2	28	1.025
106884	S2	62.5	0.173
106884	N2	11.6	0.263
106884	K1	116.6	0.029
106884	M4	45.7	0.088
106884	O1	127.5	0.026
106884	M6	245.1	0.018
106884	MK3	78.6	0.004
106884	S4	200.7	0.002
106884	MN4	27.3	0.046
106884	S6	289.4	0.001
106884	2N2	356.7	0.021
106884	OO1	183.5	0.003
106884	M1	151	0.003
106884	J1	207.5	0.007
106884	Q1	108.9	0.02
106884	2Q1	171.7	0.007
106884	2SM2	246.7	0.005
106884	M3	69.3	0.004
106884	L2	51.6	0.108
106884	2MK3	44.4	0.015
106884	M8	223.1	0.013
106884	MS4	66.7	0.031
106885	M2	28	1.275
106885	S2	63.2	0.222
106885	N2	11.3	0.326
106885	K1	118.3	0.048
106885	M4	51	0.166
106885	O1	139.6	0.037
106885	M6	238.1	0.007
106885	MK3	124.6	0.017
106885	MN4	37.7	0.079
106885	S6	299.7	0.003
106885	2N2	7.5	0.026
106885	OO1	161.7	0.003
106885	M1	160.9	0.008
106885	J1	174.1	0.008
106885	Q1	126	0.011
106885	2Q1	131.1	0.005
106885	2SM2	278.5	0.005
106885	M3	77.7	0.017
106885	L2	48.2	0.141
106885	2MK3	113.7	0.016
106885	M8	244.2	0.021
106885	MS4	83.9	0.051
106886	M2	28.7	1.273
106886	S2	63.5	0.233
106886	N2	10.7	0.318
106886	K1	119.3	0.067
106886	M4	59.5	0.17
106886	O1	150.5	0.035
106886	M6	155.8	0.012
106886	MK3	132.3	0.03
106886	S4	320.2	0.002
106886	MN4	45.6	0.082
106886	S6	266.5	0.004
106886	2N2	12.6	0.021
106886	OO1	191.1	0.006
106886	M1	151.4	0.011
106886	J1	128	0.014
106886	Q1	221.6	0.004
106886	2Q1	217.5	0.002
106886	2SM2	356.3	0.004
106886	M3	61	0.024
106886	L2	51.6	0.145
106886	2MK3	132.9	0.023
106886	M8	251.2	0.01
106886	MS4	97.2	0.053
106887	M2	25.9	0.68
106887	S2	68.9	0.132
106887	N2	2.5	0.161
106887	K1	137.1	0.02
106887	M4	57.3	0.025
106887	O1	120.8	0.02
106887	M6	40.4	0.029
106887	MK3	102.2	0.011
106887	S4	34.3	0.012
106887	MN4	19.4	0.022
106887	S6	14.4	0.003
106887	2N2	62.9	0.027
106887	OO1	139.8	0.003
106887	M1	273.8	0.002
106887	J1	99.6	0.005
106887	Q1	130.6	0.009
106887	2Q1	242.7	0.005
106887	2SM2	60.1	0.019
106887	M3	61.1	0.008
106887	L2	50.4	0.08
106887	2MK3	45.7	0.015
106887	M8	263.2	0.005
106887	MS4	67.8	0.017
106888	M2	34.8	0.944
106888	S2	69.3	0.164
106888	N2	16.4	0.244
106888	K1	126.8	0.049
106888	M4	68.7	0.046
106888	O1	140.6	0.029
106888	M6	71.1	0.045
106888	MK3	98.4	0.006
106888	S4	60.1	0.003
106888	MN4	23.1	0.017
106888	S6	250.4	0.003
106888	2N2	19.1	0.025
106888	OO1	133.9	0.012
106888	M1	215.2	0.009
106888	J1	292.3	0.002
106888	Q1	124.5	0.009
106888	2Q1	84.6	0.003
106888	2SM2	289.2	0.01
106888	M3	65.7	0.015
106888	L2	56.9	0.088
106888	2MK3	25.1	0.009
106888	M8	207.1	0.006
106888	MS4	36.9	0.017
106889	M2	35.8	1.017
106889	S2	70.5	0.159
106889	N2	18.9	0.259
106889	K1	104.2	0.068
106889	M4	61.6	0.05
106889	O1	150.5	0.025
106889	M6	68.1	0.054
106889	MK3	40.4	0.015
106889	S4	92.3	0.012
106889	MN4	4.4	0.021
106889	2N2	0.3	0.016
106889	OO1	119.5	0.015
106889	M1	184.6	0.009
106889	J1	77.3	0.003
106889	Q1	309.7	0.01
106889	2Q1	324.2	0.007
106889	2SM2	212.9	0.006
106889	M3	31.9	0.016
106889	L2	78.2	0.088
106889	2MK3	142	0.005
106889	M8	112.4	0.003
106889	MS4	43.9	0.015
106890	M2	16.9	0.661
106890	S2	68.7	0.112
106890	N2	0.1	0.17
106890	K1	99.3	0.011
106890	M4	119.6	0.024
106890	O1	167.3	0.015
106890	M6	114.7	0.032
106890	MK3	209.9	0.016
106890	S4	32.7	0.013
106890	MN4	78.1	0.023
106890	S6	278.1	0.003
106890	2N2	20.1	0.017
106890	OO1	62.9	0.004
106890	M1	344.6	0.005
106890	J1	117.4	0.016
106890	Q1	188.1	0.013
106890	2Q1	244.1	0.013
106890	2SM2	233.5	0.009
106890	M3	136.6	0.004
106890	L2	40.9	0.057
106890	2MK3	106.3	0.007
106890	M8	217.7	0.007
106890	MS4	263.2	0.008
106891	M2	29.4	0.768
106891	S2	75.8	0.131
106891	N2	10.7	0.23
106891	K1	148.6	0.025
106891	M4	82.1	0.04
106891	O1	117.3	0.022
106891	M6	78.2	0.029
106891	MK3	176.2	0.013
106891	S4	36.9	0.018
106891	MN4	66.9	0.027
106891	S6	274.3	0.008
106891	2N2	27.5	0.044
106891	OO1	165.1	0.002
106891	M1	113.5	0.007
106891	J1	139.2	0.005
106891	Q1	141.6	0.016
106891	2Q1	166.3	0.01
106891	2SM2	142.1	0.002
106891	M3	57.4	0.009
106891	L2	38	0.059
106891	2MK3	85.8	0.015
106891	M8	249.9	0.003
106891	MS4	96.9	0.014
106892	M2	43	0.839
106892	S2	77.9	0.142
106892	N2	21.6	0.239
106892	K1	130.5	0.049
106892	M4	68.3	0.04
106892	O1	136.3	0.019
106892	M6	70.3	0.05
106892	MK3	112.5	0.017
106892	S4	72.7	0.003
106892	MN4	20.8	0.036
106892	S6	217.6	0.007
106892	2N2	11.1	0.024
106892	OO1	24.8	0.007
106892	M1	260.2	0.006
106892	J1	345.6	0.008
106892	Q1	180.6	0.012
106892	2Q1	61.8	0.014
106892	2SM2	349	0.016
106892	M3	51.4	0.013
106892	L2	40.1	0.106
106892	2MK3	83.2	0.007
106892	M8	174.4	0.018
106892	MS4	70.3	0.01
106893	M2	40.8	0.137
106893	S2	84.1	0.029
106893	N2	21.1	0.036
106893	K1	42.8	0.022
106893	M4	155.6	0.022
106893	O1	41.5	0.019
106893	M6	136.9	0.007
106893	MK3	144.9	0.024
106893	S4	176.4	0.008
106893	MN4	130.9	0.01
106893	S6	258.8	0.003
106893	2N2	57.8	0.006
106893	OO1	341.5	0.004
106893	M1	98.9	0.002
106893	J1	81.8	0.018
106893	Q1	342.8	0.022
106893	2Q1	135.3	0.002
106893	2SM2	115	0.002
106893	M3	65.5	0.004
106893	L2	80.2	0.038
106893	2MK3	333.5	0.007
106893	M8	283.9	0.003
106893	MS4	165.8	0.015
106894	M2	49.6	0.157
106894	S2	69.3	0.036
106894	N2	26.8	0.028
106894	K1	17.7	0.009
106894	M4	144.7	0.032
106894	O1	121	0.013
106894	M6	262.1	0.004
106894	MK3	117.4	0.009
106894	S4	136	0.004
106894	MN4	126.4	0.013
106894	S6	273.2	0.002
106894	2N2	326.4	0.004
106894	OO1	237.4	0.007
106894	M1	165.2	0.002
106894	J1	10	0.003
106894	Q1	313.1	0.009
106894	2Q1	152.7	0.007
106894	2SM2	10.4	0.005
106894	M3	0.1	0.003
106894	L2	100.8	0.021
106894	2MK3	253.7	0.004
106894	M8	88.5	0.001
106894	MS4	186.2	0.007
106895	M2	49.5	0.113
106895	S2	60.2	0.039
106895	N2	19.2	0.027
106895	K1	171.8	0.02
106895	M4	161.6	0.025
106895	O1	171.5	0.015
106895	M6	267.3	0.007
106895	MK3	254.8	0.015
106895	S4	26.2	0.007
106895	MN4	152.3	0.008
106895	S6	256	0.004
106895	2N2	327.2	0.007
106895	OO1	236.9	0.008
106895	M1	325	0.005
106895	J1	3.8	0.001
106895	Q1	254.6	0.007
106895	2Q1	140.3	0.004
106895	2SM2	339.4	0.007
106895	M3	202.8	0.005
106895	L2	75.8	0.006
106895	2MK3	192.5	0.006
106895	M8	36.1	0.003
106895	MS4	274.4	0.006
106896	M2	1.8	0.306
106896	S2	27.5	0.053
106896	N2	333.8	0.077
106896	K1	224.1	0.011
106896	M4	5.1	0.027
106896	O1	113.8	0.014
106896	M6	34.9	0.013
106896	MK3	95.5	0.006
106896	S4	48.2	0.008
106896	MN4	341.2	0.014
106896	S6	85.9	0.004
106896	2N2	311.1	0.023
106896	OO1	94.9	0.003
106896	M1	226	0.004
106896	J1	101.3	0.012
106896	Q1	119	0.017
106896	2Q1	224.5	0.009
106896	2SM2	305.6	0.017
106896	M3	50.3	0.004
106896	L2	11	0.04
106896	2MK3	56.2	0.003
106896	M8	203.1	0.003
106896	MS4	15.4	0.009
106897	M2	21.3	0.463
106897	S2	43.6	0.08
106897	N2	1.1	0.105
106897	K1	134.6	0.01
106897	M4	49	0.039
106897	O1	155	0.021
106897	M6	41.2	0.025
106897	MK3	99.5	0.009
106897	S4	309.3	0.004
106897	MN4	14.3	0.018
106897	S6	235.8	0.001
106897	2N2	319.1	0.019
106897	OO1	280.4	0.004
106897	M1	231.3	0.005
106897	J1	70.9	0.005
106897	Q1	134.5	0.01
106897	2Q1	217	0.004
106897	2SM2	286.8	0.009
106897	M3	76.2	0.005
106897	L2	85.6	0.044
106897	2MK3	342.8	0.002
106897	M8	62.2	0.002
106897	MS4	48.8	0.015
106898	M2	31.5	0.521
106898	S2	63.5	0.088
106898	N2	13.9	0.099
106898	K1	91.1	0.043
106898	M4	60.5	0.029
106898	O1	198.9	0.019
106898	M6	67	0.017
106898	MK3	65.3	0.005
106898	S4	340.1	0.003
106898	MN4	22.1	0.013
106898	S6	318.1	0.005
106898	2N2	268.2	0.015
106898	OO1	227.1	0.004
106898	M1	161.9	0.008
106898	J1	345.3	0.018
106898	Q1	350.9	0.017
106898	2Q1	156	0.003
106898	2SM2	142.5	0.01
106898	M3	352.1	0.007
106898	L2	124.3	0.049
106898	2MK3	199.3	0.002
106898	M8	158.3	0.005
106898	MS4	57.1	0.005
106899	M2	3.8	0.367
106899	S2	47.4	0.069
106899	N2	344.4	0.113
106899	K1	153.2	0.004
106899	M4	75.6	0.013
106899	O1	138.1	0.003
106899	M6	52.4	0.028
106899	MK3	69.6	0.006
106899	S4	293.5	0.002
106899	MN4	25.5	0.009
106899	S6	264.5	0.002
106899	2N2	108.4	0.014
106899	OO1	249.7	0.002
106899	M1	125	0.002
106899	J1	335	0.012
106899	Q1	152.5	0.006
106899	2Q1	177.2	0.008
106899	2SM2	101.9	0.011
106899	M3	65.9	0.003
106899	L2	52.9	0.045
106899	2MK3	343.1	0.004
106899	M8	85.4	0.004
106899	MS4	78.6	0.002
106900	M2	19	0.457
106900	S2	54.2	0.082
106900	N2	357.8	0.127
106900	K1	50.2	0.017
106900	M4	236	0.016
106900	O1	127.6	0.013
106900	M6	64.9	0.038
106900	MK3	49.7	0.007
106900	S4	107.1	0.012
106900	MN4	210	0.016
106900	S6	72.4	0.005
106900	2N2	6.8	0.009
106900	OO1	214.6	0.005
106900	M1	280.7	0.004
106900	J1	27.6	0.008
106900	Q1	137	0.005
106900	2Q1	188.7	0.007
106900	2SM2	40.8	0.001
106900	M3	55.1	0.003
106900	L2	89.9	0.041
106900	2MK3	11.9	0.007
106900	M8	280.3	0.004
106900	MS4	204.3	0.01
106901	M2	21.6	0.434
106901	S2	68.1	0.068
106901	N2	357.1	0.127
106901	K1	89.4	0.026
106901	M4	197.7	0.021
106901	O1	81.5	0.028
106901	M6	74.1	0.047
106901	MK3	160.4	0.009
106901	S4	61.3	0.016
106901	MN4	195	0.016
106901	S6	45.6	0.007
106901	2N2	313.6	0.032
106901	OO1	186.5	0.015
106901	M1	224.8	0.007
106901	J1	151.8	0.009
106901	Q1	2.1	0.018
106901	2Q1	137.1	0.011
106901	2SM2	294.9	0.009
106901	M3	22.1	0.002
106901	L2	64.5	0.051
106901	2MK3	7.1	0.015
106901	M8	292.3	0.01
106901	MS4	228.1	0.011
106902	M2	24	0.341
106902	S2	54.4	0.065
106902	N2	8.6	0.089
106902	K1	59.6	0.021
106902	M4	316.4	0.087
106902	O1	121.6	0.008
106902	M6	355.2	0.005
106902	MK3	86.5	0.01
106902	S4	52.8	0.004
106902	MN4	315.1	0.042
106902	S6	339.8	0.004
106902	2N2	342.4	0.012
106902	OO1	178.3	0.007
106902	M1	26.5	0.004
106902	J1	108.6	0.004
106902	Q1	259.3	0.009
106902	2Q1	55.4	0.004
106902	2SM2	277.8	0.004
106902	M3	64.9	0.009
106902	L2	42	0.02
106902	2MK3	57.9	0.012
106902	M8	232.2	0.005
106902	MS4	348.7	0.03
106903	M2	32.8	0.41
106903	S2	66.5	0.075
106903	N2	13.8	0.112
106903	K1	71.8	0.019
106903	M4	337.8	0.089
106903	O1	168.1	0.011
106903	M6	346.5	0.02
106903	MK3	170.4	0.008
106903	S4	76.2	0.006
106903	MN4	332.7	0.048
106903	S6	72.1	0.001
106903	2N2	355.9	0.018
106903	OO1	179	0.009
106903	M1	30.9	0.001
106903	J1	65.4	0.002
106903	Q1	251.4	0.005
106903	2Q1	129	0.003
106903	2SM2	253.1	0.007
106903	M3	56.2	0.016
106903	L2	87.1	0.03
106903	2MK3	91.3	0.008
106903	M8	242.8	0.009
106903	MS4	11.2	0.028
106904	M2	33.1	0.59
106904	S2	76	0.074
106904	N2	20.5	0.151
106904	K1	107.2	0.024
106904	M4	65.3	0.056
106904	O1	119.1	0.017
106904	M6	68.7	0.094
106904	MK3	126.7	0.009
106904	S4	170.1	0.007
106904	MN4	52.8	0.039
106904	S6	230.4	0.006
106904	2N2	11	0.015
106904	OO1	280.8	0.003
106904	M1	221.9	0.001
106904	J1	186.6	0.011
106904	Q1	46.4	0.004
106904	2Q1	35.5	0.005
106904	2SM2	8.8	0.004
106904	M3	33.6	0.01
106904	L2	77.3	0.052
106904	2MK3	89.2	0.007
106904	M8	15.3	0.008
106904	MS4	144.8	0.016
106905	M2	38.5	0.711
106905	S2	74.6	0.127
106905	N2	23.5	0.196
106905	K1	122.3	0.028
106905	M4	36.7	0.032
106905	O1	109.9	0.021
106905	M6	64.1	0.079
106905	MK3	139	0.018
106905	S4	62.2	0.009
106905	MN4	20.6	0.021
106905	S6	96.2	0.002
106905	2N2	30.5	0.032
106905	OO1	49.7	0.003
106905	M1	155	0.004
106905	J1	118.8	0.008
106905	Q1	112.7	0.012
106905	2Q1	337.1	0.002
106905	2SM2	166.7	0.021
106905	M3	79.3	0.006
106905	L2	93.7	0.066
106905	2MK3	108.2	0.012
106905	M8	136.2	0.012
106905	MS4	36.7	0.011
106906	M2	42.9	0.703
106906	S2	84.7	0.163
106906	N2	25.3	0.198
106906	K1	86.2	0.048
106906	M4	67	0.06
106906	O1	170.5	0.032
106906	M6	80.9	0.054
106906	MK3	94.5	0.013
106906	S4	4.1	0.016
106906	MN4	62.3	0.04
106906	S6	55.1	0.008
106906	2N2	20.4	0.016
106906	OO1	51	0.002
106906	M1	333.1	0.011
106906	J1	108.9	0.008
106906	Q1	270.7	0.003
106906	2Q1	313.1	0.012
106906	2SM2	122.2	0.016
106906	M3	46.6	0.009
106906	L2	68	0.057
106906	2MK3	341.1	0.005
106906	M8	97.5	0.011
106906	MS4	359.3	0.014
106907	M2	29	0.521
106907	S2	78.5	0.097
106907	N2	8.7	0.148
106907	K1	82.4	0.015
106907	M4	0.7	0.037
106907	O1	126.6	0.022
106907	M6	66.2	0.07
106907	MK3	155.9	0.01
106907	S4	106.8	0.006
106907	MN4	346.7	0.016
106907	S6	314.5	0.004
106907	2N2	7.7	0.021
106907	OO1	209.1	0.009
106907	M1	124.3	0.002
106907	J1	135.4	0.006
106907	Q1	64.5	0.007
106907	2Q1	258.7	0.008
106907	2SM2	135.5	0.003
106907	M3	93	0.007
106907	L2	50.3	0.063
106907	2MK3	97.3	0.013
106907	M8	45.6	0.01
106907	MS4	47.3	0.018
106908	M2	40.1	0.544
106908	S2	82.9	0.087
106908	N2	22.9	0.16
106908	K1	132.6	0.009
106908	M4	59.1	0.03
106908	O1	136.8	0.012
106908	M6	70.7	0.065
106908	MK3	162.4	0.007
106908	S4	106.7	0.006
106908	MN4	59.7	0.022
106908	S6	340.9	0.006
106908	2N2	20.5	0.027
106908	OO1	222.8	0.006
106908	M1	167.9	0.005
106908	J1	4.4	0.006
106908	Q1	84.5	0.006
106908	2Q1	308.9	0.003
106908	2SM2	40.8	0.008
106908	M3	62.5	0.006
106908	L2	63.2	0.073
106908	2MK3	118.1	0.012
106908	M8	106.7	0.005
106908	MS4	82.6	0.01
106909	M2	49.5	0.581
106909	S2	73.4	0.099
106909	N2	44	0.156
106909	K1	122.8	0.038
106909	M4	71.3	0.017
106909	O1	165.2	0.023
106909	M6	66	0.065
106909	MK3	114.9	0.007
106909	S4	310.9	0.003
106909	MN4	82.7	0.011
106909	S6	79.8	0.003
106909	2N2	15.7	0.007
106909	OO1	253.3	0.006
106909	M1	79.7	0.001
106909	J1	109.2	0.012
106909	Q1	166.5	0.022
106909	2Q1	343.4	0.004
106909	2SM2	36.8	0.011
106909	M3	24.2	0.007
106909	L2	74.6	0.043
106909	2MK3	151.7	0.006
106909	M8	234.3	0.005
106909	MS4	79.9	0.004
106910	M2	347.9	0.404
106910	S2	15.1	0.059
106910	N2	333.3	0.08
106910	K1	19.1	0.004
106910	M4	332.1	0.078
106910	O1	161.6	0.01
106910	M6	13.7	0.038
106910	MK3	11.6	0.008
106910	S4	282	0.004
106910	MN4	296.7	0.034
106910	S6	247.8	0.001
106910	2N2	147.6	0.007
106910	OO1	184.1	0.009
106910	M1	74	0.002
106910	J1	246.9	0.005
106910	Q1	239.5	0.004
106910	2Q1	93.1	0.008
106910	2SM2	254.1	0.005
106910	M3	306.9	0.006
106910	L2	21.4	0.061
106910	2MK3	116.9	0.01
106910	M8	276.9	0.005
106910	MS4	1.5	0.031
106911	M2	345	0.423
106911	S2	22.8	0.062
106911	N2	331.9	0.096
106911	K1	213	0.005
106911	M4	321.9	0.108
106911	O1	117	0.011
106911	M6	359.9	0.06
106911	MK3	66.6	0.008
106911	S4	100.2	0.002
106911	MN4	304	0.043
106911	S6	338.2	0.004
106911	2N2	151	0.004
106911	OO1	191.5	0.009
106911	M1	143.1	0.002
106911	J1	227.3	0.008
106911	Q1	117.5	0.006
106911	2Q1	91.7	0.009
106911	2SM2	281	0.007
106911	M3	39.2	0.007
106911	L2	12.2	0.071
106911	2MK3	62.1	0.01
106911	M8	294.6	0.012
106911	MS4	346.6	0.034
106912	M2	27.7	0.293
106912	S2	64.2	0.052
106912	N2	5.9	0.089
106912	K1	149.7	0.01
106912	M4	25.5	0.017
106912	O1	162.8	0.008
106912	M6	47	0.067
106912	MK3	173.8	0.009
106912	S4	136.3	0.003
106912	MN4	21.9	0.01
106912	S6	12.7	0.003
106912	2N2	330.8	0.005
106912	OO1	174	0.003
106912	M1	114.8	0.002
106912	J1	292.7	0.005
106912	Q1	111.6	0.004
106912	2Q1	159.9	0.004
106912	2SM2	55.3	0.006
106912	M3	55	0.008
106912	L2	55.7	0.043
106912	2MK3	80.1	0.006
106912	M8	7.9	0.004
106912	MS4	20.7	0.008
106913	M2	45.1	0.396
106913	S2	82.6	0.074
106913	N2	22.6	0.125
106913	K1	143.4	0.02
106913	M4	41.7	0.036
106913	O1	182.7	0.009
106913	M6	63.7	0.076
106913	MK3	146	0.008
106913	S4	89.8	0.005
106913	MN4	16.6	0.019
106913	S6	335.6	0.004
106913	2N2	16.7	0.023
106913	OO1	214	0.008
106913	M1	208.1	0.003
106913	J1	267.3	0.005
106913	Q1	90.6	0.01
106913	2Q1	112.2	0.006
106913	2SM2	70.1	0.011
106913	M3	47.6	0.01
106913	L2	70.7	0.055
106913	2MK3	132.2	0.009
106913	M8	39.8	0.01
106913	MS4	26	0.013
106914	M2	57.6	0.483
106914	S2	80.8	0.095
106914	N2	46.6	0.134
106914	K1	112.1	0.039
106914	M4	74	0.025
106914	O1	193.8	0.008
106914	M6	65.9	0.071
106914	MK3	34.8	0.006
106914	S4	25.6	0.004
106914	MN4	46.4	0.013
106914	S6	45.9	0.002
106914	2N2	355	0.023
106914	OO1	343.7	0.007
106914	M1	218	0.007
106914	J1	108.4	0.019
106914	Q1	144.2	0.015
106914	2Q1	43.1	0.004
106914	2SM2	283.5	0.006
106914	M3	222.1	0.005
106914	L2	130.9	0.043
106914	2MK3	164.5	0.008
106914	M8	58.8	0.007
106914	MS4	58.3	0.011
106915	M2	237.3	0.356
106915	S2	276.7	0.06
106915	N2	218.2	0.109
106915	K1	95.1	0.01
106915	M4	197.1	0.039
106915	O1	44.3	0.011
106915	M6	228.1	0.074
106915	MK3	307.2	0.006
106915	S4	3.8	0.011
106915	MN4	196.2	0.033
106915	S6	197.5	0.005
106915	2N2	171.1	0.02
106915	OO1	67.3	0.006
106915	M1	106	0.001
106915	J1	274.2	0.003
106915	Q1	351.1	0.004
106915	2Q1	214.7	0.005
106915	2SM2	171.5	0.006
106915	M3	331.3	0.007
106915	L2	249.7	0.05
106915	2MK3	275.4	0.009
106915	M8	197.7	0.007
106915	MS4	219.6	0.011
106916	M2	242.4	0.443
106916	S2	278.5	0.074
106916	N2	221.3	0.127
106916	K1	310.7	0.003
106916	M4	225.6	0.044
106916	O1	342.7	0.013
106916	M6	240.7	0.1
106916	MK3	14.1	0.01
106916	S4	329.4	0.005
106916	MN4	213.8	0.028
106916	S6	169.6	0.003
106916	2N2	197.8	0.028
106916	OO1	35.9	0.009
106916	M1	9.7	0.008
106916	J1	300.3	0.006
106916	Q1	309.2	0.01
106916	2Q1	66.5	0.004
106916	2SM2	336.2	0.003
106916	M3	303.6	0.006
106916	L2	281.5	0.041
106916	2MK3	324.3	0.011
106916	M8	191.9	0.017
106916	MS4	245	0.017
106917	M2	255.6	0.503
106917	S2	263.5	0.102
106917	N2	232.8	0.123
106917	K1	278.4	0.034
106917	M4	338.9	0.01
106917	O1	17.4	0.017
106917	M6	250.9	0.097
106917	MK3	200.2	0.002
106917	S4	345.8	0.004
106917	MN4	186.3	0.015
106917	S6	130.8	0.007
106917	2N2	134.3	0.022
106917	OO1	89.5	0.013
106917	M1	279.2	0.003
106917	J1	199.3	0.007
106917	Q1	249.9	0.014
106917	2Q1	109.4	0.007
106917	2SM2	156.3	0.001
106917	M3	111.4	0.005
106917	L2	336.4	0.071
106917	2MK3	350.3	0.009
106917	M8	215.9	0.013
106917	MS4	292.6	0.004
106918	M2	274.4	0.466
106918	S2	303.3	0.067
106918	N2	252.3	0.119
106918	K1	253.7	0.005
106918	M4	254.8	0.075
106918	O1	46.9	0.016
106918	M6	234.1	0.11
106918	MK3	32.9	0.009
106918	S4	87.2	0.008
106918	MN4	259.5	0.042
106918	S6	169	0.012
106918	2N2	129.2	0.025
106918	OO1	96.7	0.007
106918	M1	54.7	0.007
106918	J1	282.9	0.008
106918	Q1	280	0.013
106918	2SM2	94.5	0.013
106918	M3	270.6	0.013
106918	L2	319.3	0.094
106918	2MK3	339.1	0.011
106918	M8	176.1	0.026
106918	MS4	276.2	0.018
106919	M2	279	0.524
106919	S2	305.3	0.078
106919	N2	258.8	0.142
106919	K1	249.5	0.01
106919	M4	281.3	0.06
106919	O1	60.3	0.013
106919	M6	240.4	0.107
106919	MK3	325.1	0.005
106919	S4	30.9	0.009
106919	MN4	250.7	0.036
106919	S6	166.6	0.008
106919	2N2	156.2	0.026
106919	OO1	100.6	0.004
106919	M1	95.7	0.006
106919	J1	312.8	0.007
106919	Q1	308.2	0.01
106919	2Q1	305.9	0.007
106919	2SM2	65.5	0.011
106919	M3	263.5	0.009
106919	L2	327.6	0.084
106919	2MK3	39.4	0.008
106919	M8	207.6	0.015
106919	MS4	289.4	0.018
106920	M2	289.4	0.53
106920	S2	311.1	0.081
106920	N2	267.2	0.143
106920	K1	268.1	0.033
106920	M4	315.8	0.069
106920	O1	14.3	0.02
106920	M6	248.9	0.1
106920	MK3	315.4	0.007
106920	S4	324.9	0.008
106920	MN4	306	0.034
106920	S6	109.1	0.004
106920	2N2	174	0.03
106920	OO1	87.8	0.01
106920	M1	198	0.004
106920	J1	129.6	0.012
106920	Q1	344.1	0.012
106920	2Q1	124	0.003
106920	2SM2	253.2	0.007
106920	M3	16.9	0.004
106920	L2	359.5	0.075
106920	2MK3	345	0.012
106920	M8	292.3	0.017
106920	MS4	342.9	0.018
106921	M2	307.2	0.723
106921	S2	333.8	0.079
106921	N2	294.2	0.144
106921	K1	266.3	0.019
106921	M4	299.6	0.037
106921	O1	75.1	0.019
106921	M6	247.7	0.083
106921	MK3	72.6	0.009
106921	S4	338.8	0.007
106921	MN4	275.3	0.023
106921	S6	89.3	0.004
106921	2N2	183.1	0.004
106921	OO1	325.3	0.002
106921	M1	83.1	0.003
106921	J1	128.8	0.002
106921	Q1	166.9	0.002
106921	2Q1	51.3	0.001
106921	P1	28.2	0.004
106921	2SM2	22.3	0.006
106921	M3	15.5	0.008
106921	L2	329.6	0.108
106921	2MK3	38.2	0.011
106921	K2	336.3	0.029
106921	M8	331.8	0.025
106921	MS4	289.7	0.013
106922	M2	313.8	0.914
106922	S2	338.5	0.119
106922	N2	296.9	0.184
106922	K1	245.1	0.025
106922	M4	317.9	0.178
106922	O1	98.4	0.026
106922	M6	236	0.125
106922	MK3	51.9	0.015
106922	S4	13.7	0.003
106922	MN4	294	0.061
106922	S6	130.5	0.005
106922	2N2	229.2	0.012
106922	OO1	5.9	0.004
106922	M1	103.8	0.007
106922	J1	120.2	0.002
106922	Q1	209.1	0.002
106922	2Q1	4.8	0.002
106922	2SM2	262.3	0.006
106922	M3	357.6	0.012
106922	L2	340.3	0.125
106922	2MK3	39.3	0.025
106922	K2	342.9	0.043
106922	M8	226.3	0.014
106922	MS4	314.8	0.028
106923	M2	322.7	1.134
106923	S2	339.6	0.142
106923	N2	299.9	0.2
106923	K1	235.8	0.028
106923	M4	311.6	0.152
106923	O1	93.4	0.032
106923	M6	212.8	0.139
106923	MK3	52.6	0.017
106923	S4	35.5	0.009
106923	MN4	291.9	0.059
106923	S6	108.7	0.005
106923	2N2	211.5	0.034
106923	OO1	28.9	0.002
106923	M1	134	0.003
106923	J1	128.1	0.006
106923	Q1	16.3	0.005
106923	2Q1	21.4	0.007
106923	P1	67.9	0.006
106923	2SM2	230.3	0.003
106923	M3	0.1	0.009
106923	L2	359.9	0.172
106923	2MK3	42.4	0.013
106923	K2	349.3	0.046
106923	M8	229	0.035
106923	MS4	307.8	0.03
106924	M2	312.6	1.135
106924	S2	349.4	0.157
106924	N2	288.8	0.287
106924	K1	149.7	0.111
106924	M4	17.5	0.039
106924	O1	160	0.081
106924	M6	58.1	0.053
106924	MK3	215.5	0.012
106924	S4	215.8	0.014
106924	MN4	351.2	0.013
106924	S6	151	0.012
106924	2N2	296.3	0.059
106924	OO1	130.9	0.005
106924	M1	161.2	0.004
106924	J1	4	0.003
106924	Q1	188.8	0.014
106924	2Q1	198.3	0.005
106924	2SM2	0.8	0.014
106924	M3	68	0.007
106924	L2	324.4	0.08
106924	2MK3	252.9	0.014
106924	M8	167.5	0.005
106924	MS4	37.1	0.016
106925	M2	314.3	1.439
106925	S2	349.1	0.205
106925	N2	290.7	0.366
106925	K1	151.4	0.146
106925	M4	310.7	0.07
106925	O1	165.3	0.104
106925	M6	69.3	0.043
106925	MK3	183.2	0.018
106925	S4	262.3	0.014
106925	MN4	289.5	0.03
106925	S6	163.5	0.015
106925	2N2	306.9	0.082
106925	OO1	50	0.002
106925	M1	160.1	0.006
106925	J1	332.2	0.008
106925	Q1	185.1	0.011
106925	2Q1	186.9	0.011
106925	2SM2	16.6	0.023
106925	M3	69.3	0.008
106925	L2	330.8	0.089
106925	2MK3	215.6	0.009
106925	M8	65.5	0.011
106925	MS4	356.2	0.022
106926	M2	315.9	1.47
106926	S2	347	0.212
106926	N2	291.3	0.358
106926	K1	154.7	0.153
106926	M4	287.9	0.132
106926	O1	167.8	0.11
106926	M6	64.1	0.052
106926	MK3	145.1	0.022
106926	S4	274.7	0.017
106926	MN4	271.4	0.066
106926	S6	183.8	0.016
106926	2N2	320.9	0.085
106926	OO1	0	0.005
106926	M1	136.1	0.004
106926	J1	141.2	0.003
106926	Q1	205.7	0.007
106926	2Q1	191.8	0.011
106926	2SM2	31.7	0.03
106926	M3	41.7	0.006
106926	L2	341.5	0.098
106926	2MK3	155.4	0.004
106926	M8	46	0.023
106926	MS4	332.3	0.038
106927	M2	314.1	0.931
106927	S2	336.5	0.178
106927	N2	291.2	0.259
106927	K1	139.3	0.085
106927	M4	153.6	0.083
106927	O1	171.1	0.053
106927	M6	24.3	0.05
106927	MK3	344.6	0.018
106927	S4	219.4	0.014
106927	MN4	134.5	0.04
106927	S6	176.1	0.012
106927	2N2	276.3	0.05
106927	OO1	127.2	0.004
106927	M1	218.2	0.006
106927	J1	196	0.007
106927	Q1	181.9	0.011
106927	2Q1	140.2	0.005
106927	P1	187.3	0.021
106927	2SM2	298.2	0.002
106927	M3	342.8	0.011
106927	L2	329.6	0.031
106927	2MK3	353.5	0.015
106927	K2	322	0.051
106927	M8	239.3	0.01
106927	MS4	180.6	0.018
106928	M2	313.6	0.992
106928	S2	337.4	0.185
106928	N2	292.2	0.281
106928	K1	140	0.091
106928	M4	143.5	0.096
106928	O1	169.6	0.053
106928	M6	17.4	0.053
106928	MK3	343.7	0.023
106928	S4	216.6	0.015
106928	MN4	128.7	0.046
106928	S6	179.3	0.013
106928	2N2	277.1	0.056
106928	OO1	115.6	0.004
106928	M1	214.8	0.008
106928	J1	202.3	0.006
106928	Q1	174.2	0.014
106928	2Q1	148.6	0.005
106928	P1	188.2	0.021
106928	2SM2	338.6	0.002
106928	M3	344.6	0.013
106928	L2	321.2	0.032
106928	2MK3	351.3	0.019
106928	K2	323.3	0.047
106928	M8	223.9	0.013
106928	MS4	166.3	0.023
106929	M2	334.5	1.261
106929	S2	344.2	0.118
106929	N2	316.9	0.307
106929	K1	187.8	0.108
106929	M4	326.7	0.035
106929	O1	200.7	0.074
106929	M6	115.5	0.066
106929	MK3	202.1	0.024
106929	S4	170.5	0.007
106929	MN4	305.2	0.016
106929	S6	188.7	0.004
106929	2N2	303.3	0.028
106929	OO1	129.5	0.011
106929	M1	196.7	0.018
106929	J1	214.8	0.004
106929	Q1	157.9	0.008
106929	2Q1	111.9	0.012
106929	P1	197.5	0.036
106929	2SM2	213.5	0.004
106929	M3	80.5	0.012
106929	L2	344.5	0.087
106929	2MK3	230.7	0.015
106929	K2	219.6	0.031
106929	M8	130.3	0.022
106929	MS4	61.1	0.014
106930	M2	335.3	1.631
106930	S2	3.5	0.163
106930	N2	315.6	0.416
106930	K1	181.4	0.198
106930	M4	336.2	0.021
106930	O1	207.4	0.102
106930	M6	121.7	0.075
106930	MK3	219.5	0.019
106930	S4	232.4	0.012
106930	MN4	288.6	0.016
106930	S6	191	0.009
106930	2N2	327.5	0.058
106930	OO1	93.4	0.015
106930	M1	187.1	0.036
106930	J1	145.1	0.005
106930	Q1	194	0.01
106930	2Q1	103.3	0.02
106930	P1	54.7	0.017
106930	2SM2	279	0.014
106930	M3	73.9	0.024
106930	L2	346.3	0.096
106930	2MK3	232.9	0.019
106930	K2	87.7	0.013
106930	M8	139	0.032
106930	MS4	116.8	0.011
106931	M2	335.6	1.666
106931	S2	4.4	0.174
106931	N2	315.2	0.426
106931	K1	179.7	0.207
106931	M4	8.8	0.02
106931	O1	203.8	0.101
106931	M6	123.9	0.074
106931	MK3	227.7	0.026
106931	S4	248.3	0.01
106931	MN4	297.8	0.01
106931	S6	192.7	0.011
106931	2N2	326.8	0.057
106931	OO1	94.1	0.014
106931	M1	182.5	0.038
106931	J1	115.8	0.005
106931	Q1	172.9	0.01
106931	2Q1	97.2	0.024
106931	P1	43.4	0.023
106931	2SM2	260.5	0.009
106931	M3	76.4	0.019
106931	L2	349.1	0.098
106931	2MK3	248	0.018
106931	K2	41.1	0.012
106931	M8	139.7	0.029
106931	MS4	105.7	0.015
106932	M2	329.6	1.076
106932	S2	8	0.182
106932	N2	309.7	0.236
106932	K1	204.1	0.059
106932	M4	146.5	0.167
106932	O1	233	0.046
106932	M6	85.2	0.106
106932	S4	248.9	0.027
106932	NU2	312.4	0.046
106932	S6	163.5	0.008
106932	2N2	290	0.031
106932	OO1	175.1	0.002
106932	LDA2	347.3	0.008
106932	M1	218.5	0.003
106932	J1	189.7	0.004
106932	RHO1	245.4	0.002
106932	Q1	247.3	0.009
106932	T2	6.4	0.011
106932	R2	9.5	0.001
106932	2Q1	261.6	0.001
106932	P1	206.2	0.02
106932	L2	309.8	0.034
106932	K2	11.1	0.049
106932	M8	323.3	0.02
106933	M2	331.8	1.421
106933	S2	9.5	0.258
106933	N2	311.8	0.314
106933	K1	208.6	0.085
106933	M4	138.8	0.204
106933	O1	232.9	0.062
106933	M6	72.2	0.11
106933	S4	248	0.031
106933	NU2	314.5	0.061
106933	S6	249.3	0.001
106933	2N2	291.9	0.042
106933	OO1	184.2	0.003
106933	LDA2	349.2	0.01
106933	M1	220.7	0.004
106933	J1	196.5	0.005
106933	RHO1	243.3	0.002
106933	Q1	244.8	0.012
106933	T2	7.9	0.015
106933	R2	11	0.002
106933	2Q1	256.9	0.002
106933	P1	210.3	0.028
106933	L2	311.8	0.045
106933	K2	12.5	0.07
106933	M8	296.3	0.033
106934	M2	332.5	1.493
106934	S2	7.2	0.277
106934	N2	308.8	0.332
106934	K1	203.8	0.092
106934	M4	126.7	0.155
106934	O1	222.7	0.067
106934	M6	67.3	0.093
106934	S4	243.8	0.022
106934	NU2	312	0.064
106934	S6	354.6	0.007
106934	2N2	285.3	0.044
106934	OO1	184.8	0.003
106934	LDA2	348.6	0.01
106934	M1	213.2	0.005
106934	J1	194.4	0.005
106934	RHO1	230.8	0.003
106934	Q1	232	0.013
106934	T2	5.7	0.016
106934	R2	8.6	0.002
106934	2Q1	241.4	0.002
106934	P1	205.1	0.031
106934	L2	308.9	0.048
106934	K2	10	0.075
106934	M8	296.2	0.037
106935	M2	348.9	0.878
106935	S2	10.7	0.138
106935	N2	337.1	0.17
106935	K1	180.6	0.067
106935	M4	13.9	0.084
106935	O1	220.2	0.034
106935	M6	167.3	0.022
106935	S4	181.7	0.011
106935	NU2	338.7	0.033
106935	S6	193.7	0.01
106935	2N2	325.5	0.023
106935	OO1	141	0.001
106935	LDA2	358.9	0.006
106935	M1	200.3	0.002
106935	J1	160.8	0.003
106935	RHO1	237.1	0.001
106935	Q1	239.9	0.007
106935	T2	10.6	0.008
106935	R2	10.7	0.001
106935	2Q1	259.7	0.001
106935	P1	180.5	0.022
106935	L2	0.5	0.025
106935	K2	10.7	0.037
106935	M8	190.9	0.028
106936	M2	349.9	1.106
106936	S2	17.6	0.173
106936	N2	334.9	0.214
106936	K1	186.2	0.095
106936	M4	4	0.13
106936	O1	206.6	0.058
106936	M6	165.6	0.025
106936	S4	193	0.009
106936	NU2	336.9	0.042
106936	S6	179.7	0.012
106936	2N2	320.1	0.029
106936	OO1	165.7	0.002
106936	LDA2	2.7	0.008
106936	M1	196.3	0.004
106936	J1	175.9	0.005
106936	RHO1	215.3	0.002
106936	Q1	216.7	0.011
106936	T2	17.5	0.01
106936	R2	17.6	0.001
106936	2Q1	226.9	0.002
106936	P1	186.1	0.032
106936	L2	4.7	0.031
106936	K2	17.6	0.047
106936	M8	204.7	0.029
106937	M2	348.6	1.081
106937	S2	17	0.171
106937	N2	333.3	0.21
106937	K1	184.4	0.098
106937	M4	10.6	0.158
106937	O1	206.3	0.061
106937	M6	149.8	0.014
106937	S4	115.2	0.009
106937	NU2	335.3	0.041
106937	S6	163	0.011
106937	2N2	318	0.028
106937	OO1	162.4	0.003
106937	LDA2	1.7	0.008
106937	M1	195.3	0.004
106937	J1	173.4	0.005
106937	RHO1	215.7	0.002
106937	Q1	217.2	0.012
106937	T2	16.9	0.01
106937	R2	17	0.001
106937	2Q1	228.2	0.002
106937	P1	184.3	0.033
106937	L2	3.8	0.03
106937	K2	17	0.046
106937	M8	223.5	0.037
106938	M2	325.4	0.42
106938	S2	332	0.075
106938	N2	292.4	0.09
106938	K1	236.5	0.022
106938	M4	224.8	0.135
106938	O1	135.2	0.023
106938	M6	166.4	0.077
106938	S4	295.1	0.018
106938	NU2	296.8	0.017
106938	S6	66.7	0.018
106938	2N2	259.5	0.012
106938	OO1	337.7	0.001
106938	LDA2	328.4	0.003
106938	M1	185.7	0.002
106938	J1	286.7	0.002
106938	RHO1	91.7	0.001
106938	Q1	84.9	0.005
106938	T2	331.6	0.004
106938	R2	332.2	0.001
106938	2Q1	34.6	0.001
106938	P1	228.8	0.007
106938	L2	292.5	0.013
106938	K2	332.5	0.02
106938	M8	117.9	0.036
106939	M2	327.4	0.366
106939	S2	346.8	0.069
106939	N2	308.1	0.077
106939	K1	236.8	0.026
106939	M4	190.9	0.161
106939	O1	147.9	0.014
106939	M6	135.3	0.067
106939	S4	291.5	0.023
106939	NU2	310.7	0.015
106939	S6	9.3	0.01
106939	2N2	288.9	0.01
106939	OO1	325.7	0.001
106939	LDA2	336.3	0.003
106939	M1	192.3	0.001
106939	J1	280.9	0.001
106939	RHO1	109.7	0.001
106939	Q1	103.7	0.003
106939	T2	345.9	0.004
106939	R2	347.6	0.001
106939	P1	230.1	0.009
106939	L2	308.1	0.011
106939	K2	348.3	0.019
106939	M8	91.3	0.028
106940	M2	327.9	0.374
106940	S2	349.5	0.068
106940	N2	322.6	0.075
106940	K1	235.1	0.036
106940	M4	169.4	0.173
106940	O1	211.8	0.02
106940	M6	119.7	0.066
106940	S4	265.1	0.024
106940	NU2	323.3	0.015
106940	S6	326.6	0.013
106940	2N2	317.4	0.01
106940	OO1	258.3	0.001
106940	LDA2	337.9	0.003
106940	M1	223.4	0.001
106940	J1	246.6	0.002
106940	RHO1	201.7	0.001
106940	Q1	200.1	0.004
106940	T2	348.5	0.004
106940	R2	350.4	0.001
106940	2Q1	188.6	0.001
106940	P1	233.3	0.012
106940	L2	322.7	0.011
106940	K2	351.2	0.019
106940	M8	46.9	0.025
106941	M2	338.4	0.832
106941	S2	18.3	0.153
106941	N2	319.6	0.161
106941	K1	197.2	0.089
106941	M4	301.2	0.045
106941	O1	221.7	0.044
106941	M6	99.4	0.026
106941	S4	193	0.009
106941	NU2	322.1	0.031
106941	S6	175.8	0.003
106941	2N2	300.8	0.021
106941	OO1	172.6	0.002
106941	LDA2	356.8	0.006
106941	M1	209.4	0.003
106941	J1	185	0.003
106941	RHO1	232.2	0.002
106941	Q1	233.8	0.008
106941	T2	16.6	0.009
106941	R2	19.9	0.001
106941	2Q1	245.9	0.001
106941	P1	198.9	0.03
106941	L2	319.6	0.023
106941	K2	21.5	0.042
106941	M8	67.4	0.015
106942	M2	338	0.914
106942	S2	10	0.154
106942	N2	316.6	0.168
106942	K1	192.9	0.094
106942	M4	156.6	0.012
106942	O1	222.4	0.054
106942	M6	137.2	0.03
106942	S4	190.2	0.01
106942	NU2	319.5	0.033
106942	S6	250.2	0.002
106942	2N2	295.4	0.022
106942	OO1	163.2	0.002
106942	LDA2	352.8	0.006
106942	M1	207.5	0.004
106942	J1	178.2	0.004
106942	RHO1	235	0.002
106942	Q1	236.9	0.011
106942	T2	8.6	0.009
106942	R2	11.3	0.001
106942	2Q1	251.6	0.001
106942	P1	195	0.031
106942	L2	316.7	0.024
106942	K2	12.6	0.042
106942	M8	50.7	0.012
106943	M2	337.6	0.923
106943	S2	7	0.142
106943	N2	316.5	0.163
106943	K1	198.3	0.094
106943	M4	68.4	0.025
106943	O1	227	0.067
106943	M6	157.6	0.031
106943	S4	187.9	0.006
106943	NU2	319.4	0.032
106943	S6	254.8	0.006
106943	2N2	295.6	0.022
106943	OO1	169.5	0.003
106943	LDA2	351.2	0.006
106943	M1	212.6	0.005
106943	J1	184	0.005
106943	RHO1	239.3	0.003
106943	Q1	241.2	0.013
106943	T2	5.7	0.008
106943	R2	8.1	0.001
106943	2Q1	255.4	0.002
106943	P1	200.4	0.031
106943	L2	316.6	0.023
106943	K2	9.3	0.039
106943	M8	50.1	0.015
106944	M2	339.2	0.761
106944	S2	16	0.142
106944	N2	311.2	0.163
106944	K1	192.1	0.056
106944	M4	50.5	0.03
106944	O1	211.1	0.035
106944	M6	76.5	0.037
106944	S4	215.2	0.009
106944	NU2	315	0.032
106944	S6	106.3	0.004
106944	2N2	283.3	0.022
106944	OO1	173.1	0.002
106944	LDA2	356.2	0.005
106944	M1	201.5	0.002
106944	J1	182.7	0.003
106944	RHO1	219.2	0.001
106944	Q1	220.4	0.007
106944	T2	14.4	0.008
106944	R2	17.5	0.001
106944	2Q1	229.8	0.001
106944	P1	193.5	0.018
106944	L2	311.3	0.023
106944	K2	19	0.039
106944	M8	286.2	0.024
106945	M2	345	1.018
106945	S2	18.9	0.176
106945	N2	319.8	0.221
106945	K1	203	0.077
106945	M4	315.8	0.063
106945	O1	222.5	0.047
106945	M6	133	0.033
106945	S4	243.6	0.008
106945	NU2	323.2	0.043
106945	S6	140.2	0.008
106945	2N2	294.7	0.029
106945	OO1	183.5	0.002
106945	LDA2	0.7	0.007
106945	M1	212.7	0.003
106945	J1	193.4	0.004
106945	RHO1	230.7	0.002
106945	Q1	232	0.009
106945	T2	17.5	0.01
106945	R2	20.3	0.001
106945	2Q1	241.7	0.001
106945	P1	204.4	0.026
106945	L2	319.9	0.032
106945	K2	21.6	0.048
106945	M8	155.8	0.018
106946	M2	347.3	1.065
106946	S2	18.9	0.181
106946	N2	320.9	0.24
106946	K1	193.9	0.076
106946	M4	336.5	0.095
106946	O1	214.8	0.05
106946	M6	162.4	0.026
106946	S4	189	0.01
106946	NU2	324.5	0.046
106946	S6	158.8	0.005
106946	2N2	294.7	0.032
106946	OO1	172.9	0.002
106946	LDA2	1.9	0.007
106946	M1	204.2	0.004
106946	J1	183.5	0.004
106946	RHO1	223.7	0.002
106946	Q1	225.1	0.01
106946	T2	17.5	0.011
106946	R2	20.1	0.001
106946	2Q1	235.5	0.001
106946	P1	195.4	0.025
106946	L2	321	0.034
106946	K2	21.4	0.049
106946	M8	157.4	0.027
106947	M2	337.8	0.599
106947	S2	20.6	0.12
106947	N2	314.9	0.116
106947	K1	215.9	0.051
106947	M4	180	0.011
106947	O1	216.3	0.034
106947	M6	122.6	0.028
106947	S4	127.1	0.01
106947	NU2	318	0.023
106947	S6	229	0.004
106947	2N2	292	0.015
106947	OO1	215.5	0.001
106947	LDA2	357.6	0.004
106947	M1	216	0.002
106947	J1	215.7	0.003
106947	RHO1	216.4	0.001
106947	Q1	216.3	0.007
106947	T2	20.5	0.007
106947	R2	20.6	0.001
106947	2Q1	216.5	0.001
106947	P1	215.8	0.017
106947	L2	0.7	0.017
106947	K2	20.6	0.033
106947	M8	189	0.011
106948	M2	337.6	0.643
106948	S2	43.3	0.094
106948	N2	302.3	0.125
106948	K1	197.5	0.044
106948	M4	286.2	0.05
106948	O1	184.2	0.031
106948	M6	118.8	0.035
106948	S4	126.3	0.003
106948	NU2	307	0.024
106948	S6	272.2	0.004
106948	2N2	267.1	0.017
106948	OO1	210.8	0.001
106948	LDA2	8	0.005
106948	M1	190.8	0.002
106948	J1	204.2	0.002
106948	RHO1	178.4	0.001
106948	Q1	177.5	0.006
106948	T2	43.2	0.006
106948	R2	43.3	0.001
106948	2Q1	170.8	0.001
106948	P1	197.4	0.015
106948	L2	12.8	0.018
106948	K2	43.3	0.025
106948	M8	175	0.02
106949	M2	7.1	0.174
106949	S2	50.6	0.035
106949	N2	345.6	0.04
106949	K1	257.3	0.027
106949	M4	177.2	0.03
106949	O1	326.2	0.018
106949	M6	122.4	0.036
106949	S4	353	0.004
106949	NU2	348.5	0.008
106949	S6	96.2	0.003
106949	2N2	324.1	0.005
106949	OO1	188.3	0.001
106949	LDA2	27.2	0.001
106949	M1	291.7	0.001
106949	J1	223.1	0.001
106949	RHO1	355.7	0.001
106949	Q1	0.3	0.004
106949	T2	48.8	0.002
106949	P1	262.4	0.009
106949	L2	345.6	0.006
106949	K2	54.1	0.01
106949	M8	93.3	0.012
106950	M2	338.7	0.241
106950	S2	4.4	0.058
106950	N2	312.7	0.042
106950	K1	193.5	0.023
106950	M4	237.1	0.053
106950	O1	221.6	0.02
106950	M6	173.8	0.017
106950	S4	293.8	0.006
106950	NU2	316.2	0.008
106950	S6	212.4	0.007
106950	2N2	286.9	0.006
106950	OO1	165.3	0.001
106950	LDA2	350.5	0.002
106950	M1	207.5	0.001
106950	J1	179.5	0.002
106950	RHO1	233.7	0.001
106950	Q1	235.5	0.004
106950	T2	3.3	0.003
106950	2Q1	249.5	0.001
106950	P1	195.5	0.008
106950	L2	312.8	0.006
106950	K2	6.5	0.016
106950	M8	250.6	0.007
106951	M2	335.4	0.252
106951	S2	9.5	0.072
106951	N2	308.7	0.044
106951	K1	174.6	0.023
106951	M4	252.3	0.069
106951	O1	237.5	0.022
106951	M6	207.3	0.016
106951	S4	301.7	0.007
106951	NU2	312.3	0.009
106951	S6	213.8	0.006
106951	2N2	282.2	0.006
106951	OO1	111.5	0.001
106951	LDA2	351.2	0.002
106951	M1	206	0.002
106951	J1	143.3	0.002
106951	RHO1	264.5	0.001
106951	Q1	268.7	0.004
106951	T2	8.1	0.004
106951	R2	10.9	0.001
106951	2Q1	299.9	0.001
106951	P1	179.2	0.008
106951	L2	308.8	0.006
106951	K2	12.3	0.02
106951	M8	280.2	0.012
106952	M2	334.5	0.189
106952	S2	7.3	0.031
106952	N2	332.3	0.044
106952	K1	257.1	0.021
106952	M4	247	0.079
106952	O1	6.1	0.015
106952	M6	184.2	0.025
106952	MK3	68	0.015
106952	S4	148.7	0.006
106952	MN4	222.8	0.036
106952	S6	218.6	0.008
106952	2N2	356.8	0.01
106952	OO1	14.7	0.003
106952	M1	281.7	0.005
106952	J1	321.1	0.001
106952	Q1	15.6	0.007
106952	2Q1	56.7	0.01
106952	2SM2	245.4	0.008
106952	M3	95	0.004
106952	L2	323.8	0.023
106952	2MK3	81.5	0.004
106952	M8	80.8	0.013
106952	MS4	289.6	0.023
106953	M2	354.1	0.178
106953	S2	21.7	0.025
106953	N2	328.2	0.038
106953	K1	237.8	0.017
106953	M4	313.3	0.026
106953	O1	292.9	0.003
106953	M6	227.9	0.01
106953	MK3	331.7	0.006
106953	S4	303.3	0.002
106953	MN4	287.6	0.006
106953	S6	163.3	0.001
106953	2N2	237.8	0.008
106953	OO1	345	0.002
106953	M1	204.7	0.001
106953	J1	293.5	0.003
106953	2Q1	86.5	0.003
106953	2SM2	310	0.011
106953	M3	310.2	0.001
106953	L2	33.8	0.012
106953	2MK3	15.2	0.003
106953	M8	337.9	0.007
106953	MS4	43.2	0.007
106954	M2	345.6	0.169
106954	S2	8.1	0.013
106954	N2	314.6	0.032
106954	K1	190.6	0.017
106954	M4	291.2	0.009
106954	O1	204.5	0.013
106954	M6	148.4	0.01
106954	MK3	314	0.009
106954	S4	344.9	0.008
106954	MN4	290.9	0.005
106954	S6	14.4	0.006
106954	2N2	200.5	0.011
106954	OO1	240.4	0.002
106954	M1	148.7	0.005
106954	J1	197.1	0.002
106954	Q1	145.3	0.006
106954	2Q1	189.3	0.005
106954	2SM2	297.8	0.009
106954	M3	304.9	0.008
106954	L2	27.3	0.017
106954	2MK3	22.7	0.005
106954	M8	293.9	0.002
106954	MS4	119.8	0.013
106955	M2	349.8	0.294
106955	S2	40.9	0.091
106955	N2	317	0.06
106955	K1	208.9	0.032
106955	M4	156.3	0.052
106955	O1	227.8	0.026
106955	M6	146.6	0.053
106955	S4	233.8	0.01
106955	NU2	321.5	0.012
106955	S6	134.2	0.009
106955	2N2	284.4	0.008
106955	OO1	189.9	0.001
106955	LDA2	13.4	0.002
106955	M1	218.3	0.002
106955	J1	199.5	0.002
106955	RHO1	235.8	0.001
106955	Q1	237.1	0.005
106955	T2	38.8	0.005
106955	R2	42.9	0.001
106955	2Q1	246.5	0.001
106955	P1	210.2	0.01
106955	L2	317.1	0.009
106955	K2	45	0.025
106955	M8	359.4	0.004
106956	M2	347.3	0.387
106956	S2	39.7	0.064
106956	N2	322	0.073
106956	K1	188.4	0.039
106956	M4	326.1	0.043
106956	O1	192.7	0.033
106956	M6	221.4	0.027
106956	S4	45.8	0.009
106956	NU2	325.4	0.014
106956	S6	296.6	0.005
106956	2N2	296.7	0.01
106956	OO1	184.1	0.001
106956	LDA2	11.6	0.003
106956	M1	190.5	0.002
106956	J1	186.3	0.003
106956	RHO1	194.4	0.001
106956	Q1	194.7	0.006
106956	T2	37.6	0.004
106956	R2	41.8	0.001
106956	2Q1	196.8	0.001
106956	P1	188.7	0.013
106956	L2	322	0.01
106956	K2	44	0.017
106956	M8	213.8	0.019
106957	M2	338.8	0.313
106957	S2	298.9	0.029
106957	N2	321.8	0.056
106957	K1	167.2	0.027
106957	M4	319.2	0.07
106957	O1	171	0.024
106957	M6	289.2	0.022
106957	S4	72.1	0.016
106957	NU2	324.1	0.011
106957	S6	27.7	0.007
106957	2N2	304.8	0.007
106957	OO1	163.2	0.001
106957	LDA2	320.2	0.002
106957	M1	169	0.002
106957	J1	165.2	0.002
106957	RHO1	172.6	0.001
106957	Q1	172.8	0.005
106957	T2	300.4	0.002
106957	2Q1	174.8	0.001
106957	P1	167.4	0.009
106957	L2	321.8	0.008
106957	K2	295.7	0.008
106957	M8	172.6	0.007
106958	M2	344.9	0.123
106958	S2	7.4	0.034
106958	N2	293.7	0.031
106958	K1	150	0.014
106958	M4	88.7	0.009
106958	O1	173.7	0.002
106958	M6	286.7	0.009
106958	MK3	256.5	0.016
106958	S4	219.9	0.004
106958	MN4	80.1	0.012
106958	S6	225.9	0.005
106958	2N2	279.1	0.023
106958	OO1	213.2	0.002
106958	M1	19.1	0.006
106958	J1	4.8	0.003
106958	Q1	240.6	0.007
106958	2Q1	45.8	0.003
106958	2SM2	111.6	0.005
106958	M3	127.1	0.013
106958	L2	273	0.012
106958	2MK3	214.1	0.014
106958	M8	128.1	0.013
106958	MS4	46.6	0.011
106959	M2	331.3	0.289
106959	S2	8.3	0.026
106959	N2	305.2	0.074
106959	K1	158.9	0.019
106959	M4	76.4	0.029
106959	O1	180.9	0.008
106959	M6	278.7	0.019
106959	MK3	254.5	0.014
106959	S4	24.2	0.009
106959	MN4	86	0.016
106959	S6	127.7	0.006
106959	2N2	295.1	0.018
106959	M1	216.5	0.006
106959	J1	104.8	0.001
106959	Q1	234.9	0.004
106959	2Q1	75.8	0.002
106959	2SM2	222.1	0.005
106959	M3	41.8	0.004
106959	L2	325.4	0.022
106959	2MK3	189.4	0.003
106959	M8	344.8	0.007
106959	MS4	32.1	0.007
106960	M2	333	0.369
106960	S2	330.1	0.02
106960	N2	320.8	0.086
106960	K1	202.4	0.014
106960	M4	104.3	0.047
106960	O1	210.8	0.005
106960	M6	182.2	0.026
106960	MK3	206.7	0.008
106960	S4	51.5	0.009
106960	MN4	93.9	0.022
106960	S6	142.3	0.01
106960	2N2	73.3	0.015
106960	OO1	344.6	0.003
106960	M1	205.2	0.005
106960	J1	220.7	0.006
106960	Q1	161.5	0.005
106960	2Q1	227.9	0.005
106960	2SM2	231.8	0.017
106960	M3	350.9	0.015
106960	L2	8.5	0.032
106960	2MK3	271.9	0.002
106960	M8	342.3	0.021
106960	MS4	122.5	0.005
106961	M2	344.5	0.308
106961	S2	10	0.067
106961	N2	337.1	0.045
106961	K1	219.6	0.028
106961	M4	212.9	0.1
106961	O1	300.4	0.012
106961	M6	42.9	0.021
106961	S4	233	0.017
106961	NU2	338.1	0.009
106961	S6	186.6	0.002
106961	2N2	329.7	0.006
106961	LDA2	356.3	0.002
106961	M1	260	0.001
106961	J1	179.6	0.001
106961	Q1	340.4	0.002
106961	T2	8.9	0.004
106961	R2	11.1	0.001
106961	P1	225.6	0.009
106961	L2	337.1	0.006
106961	K2	12.1	0.018
106961	M8	34	0.008
106962	M2	348.5	0.391
106962	S2	29.2	0.066
106962	N2	330.9	0.104
106962	K1	228.5	0.03
106962	M4	239.8	0.049
106962	O1	238.9	0.018
106962	M6	136.6	0.023
106962	S4	307.7	0.019
106962	NU2	333.2	0.02
106962	S6	317.9	0.002
106962	2N2	313.3	0.014
106962	OO1	218.1	0.001
106962	LDA2	7.3	0.003
106962	M1	233.6	0.001
106962	J1	223.4	0.001
106962	RHO1	243.3	0.001
106962	Q1	243.9	0.004
106962	T2	27.4	0.004
106962	R2	30.8	0.001
106962	P1	229.2	0.01
106962	L2	330.9	0.015
106962	K2	32.4	0.018
106962	M8	239.1	0.001
106963	M2	337.1	1.838
106963	S2	9.9	0.378
106963	N2	316.9	0.385
106963	K1	187.9	0.134
106963	M4	255.8	0.032
106963	O1	217.6	0.105
106963	M6	117.6	0.093
106963	MK3	188.6	0.006
106963	S4	269.8	0.03
106963	MN4	180.4	0.023
106963	NU2	317.2	0.092
106963	S6	222.5	0.009
106963	MU2	357.7	0.031
106963	2N2	286.6	0.058
106963	OO1	181.6	0.005
106963	LDA2	319.9	0.037
106963	M1	139.4	0.012
106963	J1	189.3	0.017
106963	RHO1	203.7	0.009
106963	Q1	248.9	0.023
106963	2Q1	218	0.014
106963	P1	184.8	0.031
106963	2SM2	67	0.006
106963	M3	334.8	0.008
106963	L2	352.6	0.082
106963	2MK3	251.6	0.009
106963	K2	9.9	0.101
106963	M8	150.1	0.01
106963	MS4	155.1	0.002
106964	M2	337.9	2.232
106964	S2	9.4	0.451
106964	N2	317	0.464
106964	K1	187.5	0.167
106964	M4	254.4	0.043
106964	O1	219.1	0.125
106964	M6	125.1	0.117
106964	MK3	182.5	0.004
106964	S4	267	0.034
106964	MN4	185.3	0.028
106964	NU2	321.8	0.112
106964	S6	225.2	0.011
106964	MU2	8.3	0.029
106964	2N2	288.6	0.077
106964	OO1	171.3	0.006
106964	LDA2	334.2	0.044
106964	M1	139.7	0.014
106964	J1	192	0.019
106964	RHO1	196.1	0.01
106964	Q1	243.6	0.029
106964	2Q1	213.9	0.015
106964	P1	177.5	0.039
106964	2SM2	88.1	0.007
106964	M3	328.8	0.009
106964	L2	352.1	0.102
106964	2MK3	258.4	0.009
106964	K2	9.1	0.119
106964	M8	152.9	0.012
106964	MS4	117	0.007
106965	M2	338.2	2.308
106965	S2	9.1	0.466
106965	N2	316.8	0.479
106965	K1	187.4	0.172
106965	M4	262.1	0.044
106965	O1	218.4	0.13
106965	M6	126.8	0.119
106965	MK3	180	0.006
106965	S4	267	0.035
106965	MN4	190.6	0.026
106965	NU2	322.6	0.113
106965	S6	226.5	0.012
106965	MU2	8.8	0.03
106965	2N2	289.5	0.081
106965	OO1	158.5	0.006
106965	LDA2	336	0.05
106965	M1	142.8	0.014
106965	J1	192.1	0.017
106965	RHO1	194	0.012
106965	Q1	242.8	0.03
106965	2Q1	214.6	0.016
106965	P1	176.8	0.042
106965	2SM2	77.3	0.004
106965	M3	329.8	0.009
106965	L2	351.3	0.104
106965	2MK3	257.9	0.009
106965	K2	9.3	0.123
106965	M8	156.6	0.015
106965	MS4	105.8	0.009
106966	M2	338.3	2.335
106966	S2	8.7	0.471
106966	N2	316.5	0.484
106966	K1	187.1	0.173
106966	M4	269.9	0.044
106966	O1	216.8	0.132
106966	M6	127.1	0.115
106966	MK3	175.3	0.008
106966	S4	268.9	0.036
106966	MN4	195.6	0.023
106966	NU2	323.5	0.11
106966	S6	228	0.015
106966	MU2	6.6	0.033
106966	2N2	288.4	0.083
106966	OO1	156.4	0.004
106966	LDA2	336	0.055
106966	M1	144.3	0.014
106966	J1	191.1	0.015
106966	RHO1	192.8	0.014
106966	Q1	243.8	0.029
106966	2Q1	212.9	0.017
106966	P1	179.5	0.046
106966	M3	327.8	0.009
106966	L2	351.2	0.104
106966	2MK3	260.5	0.01
106966	K2	9.5	0.124
106966	M8	156.6	0.018
106966	MS4	99.4	0.014
106967	K1	337.2	1.16
106967	O1	327.2	1.087
106967	MK3	158.5	0.131
106967	OO1	302	0.037
106967	M1	10.7	0.031
106967	J1	359.3	0.087
106967	Q1	333.5	0.171
106967	2Q1	294.3	0.084
106967	P1	314	0.433
106967	M3	87.5	0.073
106967	2MK3	158.2	0.062
106967	M8	224.9	0.007
106967	MS4	66.6	0.039
106968	K1	336.6	0.941
106968	O1	328.2	0.877
106968	MK3	127.9	0.108
106968	OO1	293.6	0.047
106968	M1	22.1	0.03
106968	J1	5.7	0.07
106968	Q1	335.4	0.125
106968	2Q1	291.6	0.096
106968	P1	313.3	0.322
106968	M3	72.5	0.053
106968	2MK3	135	0.061
106968	M8	176	0.002
106968	MS4	19.9	0.013
106969	K1	333.8	0.658
106969	O1	326.3	0.632
106969	MK3	122.2	0.034
106969	OO1	255.5	0.036
106969	M1	33	0.027
106969	J1	343.6	0.052
106969	Q1	349.4	0.102
106969	2Q1	260.6	0.042
106969	P1	321.5	0.225
106969	M3	79.6	0.026
106969	2MK3	130.5	0.02
106969	M8	175.9	0.006
106969	MS4	61.4	0.014
106970	M2	52.4	0.146
106970	S2	80.4	0.103
106970	N2	104.8	0.031
106970	K1	302.4	0.422
106970	M4	3.5	0.042
106970	O1	297.4	0.348
106970	M6	155.9	0.008
106970	MK3	346.4	0.034
106970	S4	142	0.057
106970	MN4	313.9	0.028
106970	S6	206.8	0.006
106970	2N2	32.3	0.021
106970	OO1	270.9	0.013
106970	M1	9	0.013
106970	J1	311.1	0.03
106970	Q1	309.2	0.053
106970	2Q1	240.9	0.033
106970	P1	270	0.095
106970	2SM2	185.3	0.02
106970	M3	337.9	0.018
106970	L2	83.5	0.004
106970	2MK3	304.5	0.01
106970	K2	5.6	0.012
106970	M8	20.4	0.001
106970	MS4	50	0.035
106971	M2	75.4	0.135
106971	S2	92.5	0.122
106971	N2	113.6	0.041
106971	K1	316.2	0.536
106971	M4	9.7	0.049
106971	O1	308.1	0.458
106971	M6	74.1	0.002
106971	MK3	51.3	0.03
106971	S4	152.9	0.038
106971	MN4	334.8	0.023
106971	S6	220.1	0.003
106971	2N2	38.7	0.025
106971	OO1	330.9	0.014
106971	M1	33.4	0.014
106971	J1	329.4	0.027
106971	Q1	318.4	0.055
106971	2Q1	274.5	0.015
106971	P1	302.7	0.127
106971	2SM2	226.3	0.022
106971	M3	11.5	0.027
106971	L2	36.9	0.008
106971	2MK3	94	0.008
106971	K2	46.9	0.036
106971	M8	174.1	0.001
106971	MS4	42.8	0.014
106972	M2	107.3	0.17
106972	S2	203.6	0.206
106972	N2	194.2	0.026
106972	K1	0	1.059
106972	M4	140.3	0.068
106972	O1	349.8	0.831
106972	M6	334.3	0.008
106972	MK3	201.5	0.115
106972	S4	291.5	0.052
106972	MN4	102.1	0.043
106972	S6	103.6	0.009
106972	2N2	101.3	0.069
106972	OO1	319.8	0.037
106972	M1	94.4	0.045
106972	J1	20.4	0.057
106972	Q1	1.8	0.114
106972	2Q1	326.1	0.1
106972	P1	356.2	0.309
106972	2SM2	300.6	0.071
106972	M3	166.3	0.078
106972	L2	88.3	0.036
106972	2MK3	196.1	0.031
106972	K2	152.3	0.043
106972	M8	208.4	0.003
106972	MS4	200.7	0.031
106973	M2	301.1	0.845
106973	S2	340.7	0.131
106973	N2	288	0.28
106973	K1	120.3	0.126
106973	M4	174.6	0.131
106973	O1	77.9	0.052
106973	M6	341.5	0.045
106973	MK3	333	0.042
106973	S4	26.3	0.019
106973	MN4	160.7	0.076
106973	S6	340.3	0.013
106973	2N2	328.5	0.072
106973	OO1	66.3	0.008
106973	M1	338.6	0.011
106973	J1	51.4	0.01
106973	Q1	142.1	0.017
106973	2Q1	198.3	0.002
106973	P1	126.7	0.016
106973	2SM2	324.6	0.026
106973	M3	38.2	0.018
106973	L2	211.6	0.067
106973	2MK3	273.5	0.02
106973	K2	226.5	0.018
106973	M8	313.8	0.023
106973	MS4	170.7	0.063
106974	M2	304.7	1.543
106974	S2	335	0.252
106974	N2	290.4	0.345
106974	K1	110.4	0.154
106974	M4	157.4	0.15
106974	O1	74.1	0.074
106974	M6	34.4	0.132
106974	MK3	318.2	0.062
106974	S4	14.4	0.034
106974	MN4	177.4	0.086
106974	S6	335.1	0.032
106974	2N2	309.6	0.054
106974	OO1	252.4	0.005
106974	M1	348.6	0.018
106974	J1	86.8	0.011
106974	Q1	132.5	0.016
106974	2Q1	160.9	0.026
106974	P1	110	0.056
106974	2SM2	281.4	0.027
106974	M3	357	0.029
106974	L2	318.7	0.051
106974	2MK3	320.4	0.036
106974	K2	28.1	0.045
106974	M8	350.2	0.01
106974	MS4	159	0.067
106975	M2	304.7	1.78
106975	S2	328.6	0.3
106975	N2	289.1	0.366
106975	K1	100.5	0.183
106975	M4	180.2	0.136
106975	O1	77.7	0.076
106975	M6	44.5	0.137
106975	MK3	323	0.066
106975	S4	19.5	0.028
106975	MN4	181.4	0.096
106975	S6	349.8	0.019
106975	2N2	291.1	0.058
106975	OO1	227.7	0.013
106975	M1	309	0.011
106975	J1	77.9	0.003
106975	Q1	62.3	0.009
106975	2Q1	155.7	0.03
106975	P1	123	0.052
106975	2SM2	300.1	0.02
106975	M3	312.5	0.033
106975	L2	342.7	0.08
106975	2MK3	334.2	0.079
106975	K2	10.1	0.081
106975	M8	24.7	0.019
106975	MS4	171.8	0.072
106976	M2	283.1	0.475
106976	S2	281.9	0.04
106976	N2	283.3	0.119
106976	K1	79.3	0.083
106976	M4	142.5	0.047
106976	O1	56	0.021
106976	M6	2.9	0.067
106976	MK3	318.9	0.005
106976	S4	353.5	0.011
106976	MN4	133.4	0.018
106976	S6	29.2	0.004
106976	2N2	344.8	0.04
106976	OO1	140.2	0.017
106976	M1	195.2	0.011
106976	J1	357.8	0.019
106976	Q1	274.1	0.019
106976	2Q1	20.5	0.006
106976	2SM2	13.4	0.008
106976	M3	324	0.009
106976	L2	240.3	0.037
106976	2MK3	332.4	0.031
106976	K2	243.9	0.033
106976	M8	255.6	0.026
106976	MS4	165.5	0.027
106977	M2	285.2	0.312
106977	S2	318.1	0.066
106977	N2	288.6	0.064
106977	K1	114.4	0.043
106977	M4	65.3	0.051
106977	O1	34.7	0.031
106977	M6	4.9	0.046
106977	MK3	222.7	0.021
106977	S4	10	0.019
106977	MN4	101.8	0.004
106977	S6	288.5	0.002
106977	2N2	231.2	0.014
106977	OO1	306.1	0.004
106977	M1	21	0.008
106977	J1	117.7	0.014
106977	Q1	112.7	0.012
106977	2Q1	198	0.009
106977	2SM2	108.6	0.002
106977	M3	18.9	0.009
106977	L2	293.3	0.001
106977	2MK3	242.1	0.018
106977	K2	12.7	0.027
106977	M8	236	0.015
106977	MS4	84.6	0.025
106978	M2	283.6	0.298
106978	S2	322.7	0.075
106978	N2	280.4	0.052
106978	K1	110.2	0.035
106978	M4	74.8	0.055
106978	O1	52	0.018
106978	M6	1.4	0.048
106978	MK3	228.4	0.028
106978	S4	7.1	0.022
106978	MN4	97	0.003
106978	S6	352.6	0.005
106978	2N2	239.7	0.014
106978	OO1	300.1	0.007
106978	M1	25.2	0.008
106978	J1	135.1	0.012
106978	Q1	164.1	0.008
106978	2Q1	181.4	0.01
106978	2SM2	343	0.004
106978	M3	12	0.007
106978	L2	276	0.008
106978	2MK3	234.4	0.018
106978	K2	7.2	0.037
106978	M8	196.8	0.012
106978	MS4	82	0.031
106979	M2	307.2	0.788
106979	S2	334.4	0.184
106979	N2	285.2	0.23
106979	K1	119.2	0.103
106979	M4	147.1	0.09
106979	O1	89.8	0.046
106979	M6	349.4	0.047
106979	MK3	326.8	0.02
106979	S4	282.1	0.022
106979	MN4	120.3	0.039
106979	S6	113.9	0.005
106979	2N2	264.8	0.073
106979	OO1	353.8	0.004
106979	M1	18.6	0.007
106979	J1	93.6	0.009
106979	Q1	30	0.017
106979	2Q1	94.2	0.018
106979	P1	107.6	0.027
106979	2SM2	74	0.002
106979	M3	14.8	0.014
106979	L2	134.1	0.007
106979	2MK3	276.3	0.009
106979	K2	344.2	0.049
106979	M8	243	0.001
106979	MS4	161.1	0.063
106980	M2	314.9	1.198
106980	S2	330.2	0.251
106980	N2	290.1	0.318
106980	K1	123.6	0.119
106980	M4	145.9	0.131
106980	O1	101.9	0.074
106980	M6	56.7	0.03
106980	MK3	317.6	0.022
106980	S4	291.4	0.027
106980	MN4	122.5	0.054
106980	S6	137	0.008
106980	2N2	246.4	0.063
106980	OO1	22.7	0.005
106980	M1	7.3	0.009
106980	J1	111.8	0.013
106980	Q1	30.8	0.017
106980	2Q1	76.5	0.014
106980	P1	100	0.017
106980	2SM2	344.7	0.013
106980	M3	9.2	0.022
106980	L2	43	0.074
106980	2MK3	330.3	0.017
106980	K2	346.1	0.066
106980	M8	4	0.017
106980	MS4	156.4	0.082
106981	M2	317.8	1.412
106981	S2	328.9	0.292
106981	N2	292.2	0.371
106981	K1	127.8	0.149
106981	M4	130.3	0.115
106981	O1	107	0.106
106981	M6	115.9	0.037
106981	MK3	271.9	0.015
106981	S4	306.9	0.031
106981	MN4	101.1	0.056
106981	S6	152.4	0.016
106981	2N2	253.8	0.064
106981	OO1	350.4	0.014
106981	M1	340.3	0.009
106981	J1	86.1	0.013
106981	Q1	57.1	0.02
106981	2Q1	69	0.011
106981	P1	123.3	0.026
106981	2SM2	326.8	0.018
106981	M3	17.8	0.016
106981	L2	30.2	0.111
106981	2MK3	338.4	0.025
106981	K2	358.5	0.073
106981	M8	18.4	0.025
106981	MS4	155.2	0.094
106982	M2	288.9	0.588
106982	S2	314.6	0.111
106982	N2	284.5	0.147
106982	K1	99.7	0.083
106982	M4	110.1	0.059
106982	O1	82.7	0.048
106982	M6	17	0.041
106982	MK3	293.2	0.031
106982	S4	328.2	0.016
106982	MN4	168.6	0.025
106982	S6	250.4	0.004
106982	2N2	325.5	0.04
106982	OO1	152.2	0.012
106982	M1	1.3	0.005
106982	J1	133	0.014
106982	Q1	102.5	0.016
106982	2Q1	330.3	0.006
106982	2SM2	222.3	0.011
106982	M3	278.4	0.021
106982	L2	235.8	0.044
106982	2MK3	333.7	0.033
106982	K2	322.4	0.059
106982	M8	151.5	0.008
106982	MS4	124.5	0.021
106983	M2	297.1	1.018
106983	S2	333.8	0.174
106983	N2	291.6	0.221
106983	K1	102.5	0.093
106983	M4	98.4	0.052
106983	O1	61.5	0.038
106983	M6	24.8	0.097
106983	MK3	252.4	0.009
106983	S4	14.7	0.011
106983	MN4	168.5	0.032
106983	S6	49.3	0.008
106983	2N2	334	0.025
106983	OO1	148.7	0.011
106983	M1	262.1	0.006
106983	J1	147.6	0.003
106983	Q1	175.2	0.026
106983	2Q1	50	0.007
106983	2SM2	142.9	0.005
106983	M3	320.4	0.02
106983	L2	317.2	0.077
106983	2MK3	311.7	0.029
106983	K2	359.4	0.054
106983	M8	197.2	0.021
106983	MS4	144.4	0.027
106984	M2	304	1.208
106984	S2	339.6	0.181
106984	N2	284.4	0.218
106984	K1	93	0.093
106984	M4	78.6	0.045
106984	O1	349.7	0.01
106984	M6	19.1	0.078
106984	MK3	118.7	0.015
106984	S4	36.3	0.015
106984	MN4	74.9	0.015
106984	S6	98.5	0.007
106984	2N2	218.6	0.01
106984	OO1	146	0.022
106984	M1	239.2	0.018
106984	J1	317.5	0.01
106984	Q1	225.3	0.025
106984	2Q1	44.6	0.016
106984	2SM2	115.3	0.016
106984	M3	336.3	0.04
106984	L2	352.6	0.125
106984	2MK3	9.4	0.029
106984	K2	59.3	0.051
106984	M8	226	0.014
106984	MS4	121.4	0.032
106985	M2	285.7	1.045
106985	S2	317.7	0.254
106985	N2	270.7	0.286
106985	K1	100.7	0.102
106985	M4	125.2	0.09
106985	O1	67.7	0.045
106985	M6	3.3	0.08
106985	MK3	293.9	0.024
106985	S4	316.9	0.041
106985	MN4	113.4	0.022
106985	S6	94.2	0.002
106985	2N2	271.2	0.097
106985	OO1	39.3	0.017
106985	M1	18.8	0.01
106985	J1	102.9	0.009
106985	Q1	36.7	0.003
106985	2Q1	89.3	0.006
106985	P1	98.2	0.038
106985	2SM2	219.2	0.013
106985	M3	6.5	0.022
106985	L2	294.2	0.04
106985	2MK3	265.4	0.031
106985	K2	308.4	0.044
106985	M8	173	0.015
106985	MS4	141.6	0.055
106986	M2	286.8	1.321
106986	S2	315.2	0.281
106986	N2	272	0.349
106986	K1	96.9	0.118
106986	M4	117.4	0.096
106986	O1	73.6	0.05
106986	M6	12.9	0.102
106986	MK3	279.4	0.015
106986	S4	311.9	0.051
106986	MN4	111.8	0.027
106986	S6	89.7	0.004
106986	2N2	279.2	0.09
106986	OO1	41.7	0.013
106986	M1	23.5	0.004
106986	J1	98	0.013
106986	Q1	72.7	0.006
106986	2Q1	94	0.008
106986	P1	97.7	0.04
106986	2SM2	209.9	0.012
106986	M3	357	0.023
106986	L2	309.6	0.072
106986	2MK3	267.2	0.036
106986	K2	318.6	0.059
106986	M8	181.8	0.016
106986	MS4	151.1	0.059
106987	M2	287.6	1.482
106987	S2	314.9	0.293
106987	N2	273.7	0.388
106987	K1	94	0.119
106987	M4	113.4	0.073
106987	O1	80.9	0.052
106987	M6	21	0.113
106987	MK3	278.6	0.009
106987	S4	309.2	0.061
106987	MN4	101.6	0.019
106987	S6	87.9	0.004
106987	2N2	283.8	0.096
106987	OO1	61	0.014
106987	M1	117	0.002
106987	J1	77.4	0.01
106987	Q1	129	0.013
106987	2Q1	92	0.009
106987	P1	96.8	0.031
106987	2SM2	225.7	0.014
106987	M3	359.4	0.026
106987	L2	315.2	0.092
106987	2MK3	278.9	0.034
106987	K2	323.3	0.078
106987	M8	162.6	0.014
106987	MS4	151.1	0.068
106988	M2	303	0.457
106988	S2	349.9	0.057
106988	N2	310.6	0.104
106988	K1	96.8	0.061
106988	M4	134.9	0.031
106988	O1	99.4	0.025
106988	M6	30.1	0.116
106988	MK3	256	0.02
106988	S4	328.1	0.014
106988	MN4	153.8	0.022
106988	S6	37.4	0.013
106988	2N2	12.3	0.016
106988	OO1	223.5	0.005
106988	M1	241.1	0.008
106988	J1	131.6	0.009
106988	Q1	132.9	0.012
106988	2Q1	206	0.014
106988	2SM2	44.9	0.014
106988	M3	266.8	0.009
106988	L2	314.6	0.035
106988	2MK3	305.2	0.025
106988	M8	224.4	0.019
106988	MS4	184.5	0.028
106989	M2	291.2	0.413
106989	S2	327.3	0.043
106989	N2	313.6	0.088
106989	K1	88.4	0.051
106989	M4	99.2	0.041
106989	O1	95.5	0.041
106989	M6	22.7	0.097
106989	MK3	241.1	0.026
106989	S4	345	0.014
106989	MN4	140	0.015
106989	S6	49.9	0.014
106989	2N2	45.9	0.026
106989	OO1	231.9	0.008
106989	M1	3.7	0.004
106989	J1	133.8	0.01
106989	Q1	144.2	0.023
106989	2Q1	247.4	0.012
106989	2SM2	36.9	0.025
106989	M3	264.6	0.003
106989	L2	288.9	0.023
106989	2MK3	298.7	0.024
106989	M8	205	0.017
106989	MS4	170.2	0.031
106990	M2	262.5	0.411
106990	S2	306.2	0.052
106990	N2	257.4	0.093
106990	K1	83.8	0.042
106990	M4	127.6	0.05
106990	O1	68.7	0.042
106990	M6	19.4	0.068
106990	MK3	218.1	0.025
106990	S4	301.7	0.017
106990	MN4	129.4	0.026
106990	S6	275.5	0.004
106990	2N2	5.7	0.046
106990	OO1	277.1	0.005
106990	M1	263.2	0.002
106990	J1	146.6	0.011
106990	Q1	103.2	0.018
106990	2Q1	190.7	0.004
106990	2SM2	26.7	0.021
106990	M3	162.1	0.003
106990	L2	216.9	0.063
106990	2MK3	268.1	0.037
106990	M8	48.5	0.01
106990	MS4	159	0.029
106991	M2	344.4	0.711
106991	S2	5.8	0.128
106991	N2	326.8	0.19
106991	K1	129.8	0.058
106991	M4	130.3	0.007
106991	O1	137.5	0.037
106991	M6	131.9	0.073
106991	MK3	258	0.004
106991	S4	35	0.018
106991	MN4	335	0.013
106991	S6	209.4	0.009
106991	2N2	340.4	0.034
106991	OO1	187.1	0.008
106991	M1	57.8	0.002
106991	J1	172.2	0.014
106991	Q1	134.5	0.01
106991	2Q1	196.1	0.008
106991	P1	73.2	0.014
106991	2SM2	305.7	0.015
106991	M3	61.7	0.009
106991	L2	3	0.065
106991	2MK3	335.6	0.01
106991	K2	17.9	0.045
106991	M8	87.8	0.004
106991	MS4	204.2	0.01
106992	M2	341.2	0.841
106992	S2	354.1	0.154
106992	N2	318.6	0.209
106992	K1	130.2	0.062
106992	M4	26.5	0.021
106992	O1	139.1	0.042
106992	M6	134.3	0.082
106992	MK3	179.9	0.008
106992	S4	39.8	0.018
106992	MN4	341.3	0.018
106992	S6	219.9	0.006
106992	2N2	327.4	0.027
106992	OO1	160.6	0.007
106992	M1	49.3	0.003
106992	J1	171.4	0.02
106992	Q1	111.5	0.011
106992	2Q1	142.6	0.009
106992	P1	55.2	0.015
106992	2SM2	287.7	0.015
106992	M3	37.3	0.007
106992	L2	12.4	0.07
106992	2MK3	314.9	0.006
106992	K2	29.2	0.057
106992	M8	219.7	0.007
106992	MS4	249	0.01
106993	M2	4.7	0.675
106993	S2	34.5	0.069
106993	N2	347.5	0.154
106993	K1	150.2	0.034
106993	M4	269.7	0.054
106993	O1	146	0.04
106993	M6	152.3	0.075
106993	MK3	74.1	0.01
106993	S4	65.1	0.013
106993	MN4	270.1	0.026
106993	S6	274.3	0.006
106993	2N2	121.2	0.021
106993	OO1	158.2	0.008
106993	M1	109.6	0.005
106993	J1	125.9	0.006
106993	Q1	105.2	0.01
106993	2Q1	275	0.01
106993	P1	13.5	0.009
106993	2SM2	194.8	0.007
106993	M3	121.1	0.015
106993	L2	35.9	0.082
106993	2MK3	30.3	0.017
106993	K2	358.7	0.058
106993	M8	89.4	0.014
106993	MS4	292.1	0.035
106994	M2	9.2	0.662
106994	S2	21.2	0.074
106994	N2	351.7	0.145
106994	K1	141.8	0.04
106994	M4	299.8	0.029
106994	O1	167.5	0.041
106994	M6	145	0.083
106994	MK3	149.2	0.004
106994	S4	57.2	0.016
106994	MN4	317.6	0.03
106994	S6	291.1	0.007
106994	2N2	82.2	0.009
106994	OO1	123.7	0.011
106994	M1	70.2	0.007
106994	J1	154	0.008
106994	Q1	118.2	0.014
106994	2Q1	288.9	0.019
106994	P1	36.7	0.018
106994	2SM2	222.8	0.016
106994	M3	132.3	0.014
106994	L2	38.1	0.071
106994	2MK3	60.1	0.008
106994	K2	28	0.062
106994	M8	152.9	0.02
106994	MS4	323.6	0.018
106995	M2	292.4	0.227
106995	S2	337	0.044
106995	N2	286.2	0.059
106995	K1	101.2	0.038
106995	M4	220.2	0.065
106995	O1	93	0.007
106995	M6	70.9	0.032
106995	MK3	342	0.013
106995	S4	167.7	0.008
106995	MN4	190.4	0.046
106995	S6	326.2	0.003
106995	2N2	322.8	0.016
106995	OO1	316.8	0.009
106995	M1	197.5	0.008
106995	J1	83.3	0.009
106995	Q1	64	0.01
106995	2Q1	138.6	0.012
106995	2SM2	347.5	0.004
106995	M3	242.1	0.012
106995	L2	143.1	0.025
106995	2MK3	233.3	0.009
106995	K2	299.5	0.012
106995	M8	58.4	0.021
106995	MS4	216.2	0.028
106996	M2	319.9	0.74
106996	S2	359.7	0.123
106996	N2	314.3	0.164
106996	K1	107.9	0.079
106996	M4	190.1	0.148
106996	O1	98.7	0.038
106996	M6	63.1	0.057
106996	MK3	315.5	0.04
106996	S4	95.2	0.014
106996	MN4	182.2	0.059
106996	S6	75.9	0.008
106996	2N2	22.4	0.03
106996	OO1	157.4	0.007
106996	M1	297.9	0.007
106996	J1	200.7	0.004
106996	Q1	343.7	0.007
106996	2Q1	191	0.007
106996	2SM2	262.6	0.007
106996	M3	11.3	0.009
106996	L2	320.1	0.048
106996	2MK3	342.8	0.032
106996	K2	55.3	0.033
106996	M8	282.4	0.013
106996	MS4	215.2	0.05
106997	M2	352	0.907
106997	S2	1.6	0.145
106997	N2	336.5	0.222
106997	K1	132.6	0.107
106997	M4	192.6	0.048
106997	O1	103.6	0.062
106997	M6	151.9	0.047
106997	MK3	43.5	0.025
106997	S4	67.8	0.011
106997	MN4	125.4	0.028
106997	S6	175.5	0.004
106997	2N2	167.9	0.012
106997	OO1	162.5	0.026
106997	M1	172	0.001
106997	J1	150.2	0.015
106997	Q1	160.2	0.015
106997	2Q1	114.8	0.016
106997	P1	151.9	0.038
106997	2SM2	111.8	0.009
106997	M3	332.9	0.006
106997	L2	29.5	0.087
106997	2MK3	3.8	0.033
106997	K2	30.3	0.056
106997	M8	249.4	0.004
106997	MS4	177.2	0.015
106998	M2	2.9	1.273
106998	S2	19.9	0.205
106998	N2	337.2	0.301
106998	K1	151.5	0.157
106998	M4	354.3	0.125
106998	O1	146.9	0.101
106998	M6	48.1	0.051
106998	MK3	139.6	0.044
106998	S4	17.6	0.018
106998	MN4	302.6	0.047
106998	S6	353.1	0.005
106998	2N2	309.5	0.017
106998	OO1	43.5	0.013
106998	M1	78.1	0.006
106998	J1	69.6	0.024
106998	Q1	227.4	0.007
106998	2Q1	323.3	0.019
106998	P1	95.2	0.047
106998	2SM2	320.8	0.024
106998	M3	65.3	0.021
106998	L2	53.4	0.16
106998	2MK3	74.7	0.021
106998	K2	28	0.061
106998	M8	171.3	0.042
106998	MS4	8.3	0.059
106999	M2	7.7	1.252
106999	S2	27.2	0.219
106999	N2	339.8	0.32
106999	K1	163.4	0.197
106999	M4	349.4	0.133
106999	O1	149	0.108
106999	M6	39.6	0.078
106999	MK3	153	0.047
106999	S4	18.1	0.016
106999	MN4	300.3	0.056
106999	S6	15.8	0.01
106999	2N2	317.9	0.058
106999	OO1	21.7	0.021
106999	M1	69.7	0.017
106999	J1	66.4	0.015
106999	Q1	263.1	0.008
106999	2Q1	280.6	0.019
106999	P1	123.9	0.053
106999	2SM2	320	0.028
106999	M3	83.3	0.028
106999	L2	60.8	0.124
106999	2MK3	97	0.015
106999	K2	25.1	0.073
106999	M8	140.7	0.042
106999	MS4	3.4	0.075
107000	M2	14.4	1.289
107000	S2	31.3	0.28
107000	N2	346.2	0.333
107000	K1	196.5	0.191
107000	M4	254	0.041
107000	O1	180.4	0.131
107000	M6	118.5	0.062
107000	MK3	273.4	0.019
107000	S4	356.4	0.012
107000	MN4	176.6	0.014
107000	S6	203.2	0.01
107000	2N2	311.8	0.035
107000	OO1	133.6	0.008
107000	M1	215.9	0.022
107000	J1	156.3	0.026
107000	Q1	59.8	0.021
107000	2Q1	338.6	0.034
107000	P1	314.5	0.05
107000	2SM2	274	0.016
107000	M3	68.6	0.017
107000	L2	69.8	0.116
107000	2MK3	339.9	0.014
107000	K2	52.1	0.032
107000	M8	211.3	0.009
107000	MS4	226.3	0.022
107001	M2	6.2	1.179
107001	S2	25.6	0.243
107001	N2	341.8	0.268
107001	K1	176.9	0.109
107001	M4	289.1	0.072
107001	O1	158.6	0.108
107001	M6	168.4	0.032
107001	MK3	127.1	0.024
107001	S4	23.8	0.015
107001	MN4	257.4	0.031
107001	S6	58.2	0.006
107001	2N2	205.6	0.053
107001	OO1	354.7	0.006
107001	M1	225.6	0.027
107001	J1	173.8	0.027
107001	Q1	94.1	0.034
107001	2Q1	338.5	0.013
107001	P1	315.3	0.057
107001	2SM2	240.6	0.021
107001	M3	14.9	0.037
107001	L2	53.7	0.177
107001	2MK3	59.9	0.038
107001	K2	146.2	0.044
107001	M8	45.3	0.017
107001	MS4	271.5	0.015
107002	M2	349.2	0.818
107002	S2	19.4	0.196
107002	N2	333.9	0.207
107002	K1	155.9	0.082
107002	M4	268.4	0.019
107002	O1	126.5	0.064
107002	M6	172.1	0.064
107002	MK3	16.8	0.025
107002	S4	346.1	0.009
107002	MN4	288.9	0.023
107002	S6	39.4	0.003
107002	2N2	25.1	0.052
107002	OO1	114.2	0.019
107002	M1	178.2	0.011
107002	J1	197.9	0.023
107002	Q1	114.4	0.027
107002	2Q1	121.5	0.005
107002	2SM2	202.4	0.017
107002	M3	335.3	0.015
107002	L2	349.4	0.112
107002	2MK3	341.3	0.045
107002	K2	83.9	0.059
107002	M8	356.3	0.019
107002	MS4	235.4	0.015
107003	M2	310.5	0.469
107003	S2	340.4	0.052
107003	N2	299.7	0.11
107003	K1	175.3	0.028
107003	M4	146.6	0.116
107003	O1	161.5	0.004
107003	M6	176.4	0.081
107003	MK3	295.8	0.032
107003	S4	123.2	0.01
107003	MN4	100.6	0.059
107003	S6	219	0.003
107003	2N2	50.5	0.02
107003	OO1	195.2	0.006
107003	M1	77	0.004
107003	J1	113.9	0.008
107003	Q1	198.9	0.004
107003	2Q1	167.5	0.014
107003	P1	175.1	0.004
107003	2SM2	298.2	0.002
107003	M3	69.9	0.004
107003	L2	336.8	0.06
107003	2MK3	268.2	0.04
107003	K2	343.4	0.041
107003	M8	270.4	0.014
107003	MS4	177.9	0.057
107004	M2	316.6	0.551
107004	S2	335.7	0.075
107004	N2	296.9	0.14
107004	K1	79.4	0.036
107004	M4	183.1	0.072
107004	O1	56.9	0.03
107004	M6	137.3	0.043
107004	MK3	2.8	0.022
107004	S4	48.8	0.007
107004	MN4	152.7	0.036
107004	S6	338.9	0.003
107004	2N2	349	0.026
107004	OO1	222	0.005
107004	M1	81.6	0.006
107004	J1	357.3	0.006
107004	Q1	84	0.009
107004	2Q1	155.2	0.021
107004	P1	24.8	0.006
107004	2SM2	277.1	0.007
107004	M3	310.9	0.014
107004	L2	335.9	0.075
107004	2MK3	332	0.023
107004	K2	356.1	0.043
107004	M8	214.3	0.017
107004	MS4	219	0.024
107005	M2	333.9	0.782
107005	S2	2.4	0.113
107005	N2	311.3	0.187
107005	K1	127.3	0.062
107005	M4	139.6	0.115
107005	O1	80.2	0.04
107005	M6	156.6	0.022
107005	MK3	206.6	0.005
107005	S4	344.6	0.01
107005	MN4	132.2	0.048
107005	S6	319.1	0.005
107005	2N2	340.8	0.022
107005	OO1	288.6	0.01
107005	M1	74.5	0.005
107005	J1	22.1	0.003
107005	Q1	125.2	0.008
107005	2Q1	172.6	0.016
107005	P1	124	0.013
107005	2SM2	347.8	0.004
107005	M3	281.2	0.008
107005	L2	6.2	0.104
107005	2MK3	301	0.022
107005	K2	347.9	0.04
107005	M8	323.4	0.018
107005	MS4	179.2	0.034
107006	M2	337.6	0.533
107006	S2	9.7	0.053
107006	N2	310.1	0.117
107006	K1	139.3	0.06
107006	M4	147.6	0.064
107006	O1	115.3	0.022
107006	M6	6	0.025
107006	MK3	316.8	0.004
107006	S4	114.1	0.003
107006	MN4	127.5	0.028
107006	S6	275.9	0.006
107006	2N2	85.2	0.01
107006	OO1	335.7	0.009
107006	M1	304.2	0.007
107006	J1	228.1	0.008
107006	Q1	59.7	0.003
107006	2Q1	159.7	0.005
107006	P1	177.1	0.023
107006	2SM2	340.2	0.013
107006	M3	266.1	0.002
107006	L2	12.8	0.071
107006	2MK3	335.6	0.02
107006	K2	332.6	0.046
107006	M8	284.3	0.025
107006	MS4	173.5	0.017
107007	M2	328.3	0.566
107007	S2	358.7	0.094
107007	N2	295.1	0.148
107007	K1	138.9	0.051
107007	M4	111.3	0.105
107007	O1	64.4	0.005
107007	M6	290.1	0.107
107007	MK3	296.6	0.018
107007	S4	353.7	0.005
107007	MN4	104.6	0.048
107007	S6	353.9	0.007
107007	2N2	304.9	0.034
107007	OO1	30	0.006
107007	M1	249.5	0.012
107007	J1	268.2	0.01
107007	Q1	260.7	0.009
107007	2Q1	318.9	0.003
107007	P1	255.4	0.02
107007	2SM2	300.6	0.017
107007	M3	66	0.009
107007	L2	13.9	0.055
107007	2MK3	29.4	0.009
107007	K2	306.3	0.059
107007	M8	359.4	0.013
107007	MS4	151.9	0.054
107008	M2	9.9	0.549
107008	S2	336	0.084
107008	N2	344.5	0.108
107008	K1	188.1	0.094
107008	M4	349	0.155
107008	O1	201	0.077
107008	M6	29.5	0.068
107008	MK3	187.4	0.031
107008	S4	288.6	0.007
107008	MN4	332.7	0.076
107008	S6	41.5	0.001
107008	2N2	168	0.037
107008	OO1	9.4	0.027
107008	M1	181.3	0.008
107008	J1	94.8	0.007
107008	Q1	161.7	0.007
107008	2Q1	359.6	0.02
107008	P1	158.9	0.045
107008	2SM2	126.1	0.011
107008	M3	60.1	0.029
107008	L2	59.4	0.096
107008	2MK3	126.7	0.034
107008	K2	76	0.053
107008	M8	80.7	0.057
107008	MS4	49.5	0.055
107009	M2	9.1	0.609
107009	S2	349.3	0.091
107009	N2	337.1	0.127
107009	K1	185.6	0.098
107009	M4	330.4	0.166
107009	O1	216.7	0.065
107009	M6	44.4	0.039
107009	MK3	160	0.021
107009	S4	242.1	0.007
107009	MN4	324.3	0.076
107009	S6	332.1	0.002
107009	2N2	194	0.036
107009	OO1	16.3	0.027
107009	M1	234.7	0.005
107009	J1	119	0.01
107009	Q1	191	0.009
107009	2Q1	41.6	0.023
107009	P1	165.7	0.062
107009	2SM2	157.3	0.006
107009	M3	61.2	0.034
107009	L2	67.7	0.09
107009	2MK3	127.4	0.038
107009	K2	82.7	0.038
107009	M8	104	0.038
107009	MS4	41.8	0.064
107010	M2	358.3	0.52
107010	S2	15.3	0.092
107010	N2	329.1	0.154
107010	K1	174	0.057
107010	M4	338.2	0.138
107010	O1	203.3	0.028
107010	M6	94.1	0.039
107010	MK3	192.8	0.027
107010	S4	286.4	0.005
107010	MN4	336.7	0.052
107010	S6	287.6	0.006
107010	2N2	313.4	0.047
107010	OO1	48.3	0.013
107010	M1	258.1	0.003
107010	J1	130.7	0.006
107010	Q1	157.1	0.014
107010	2Q1	51.7	0.022
107010	P1	177.2	0.043
107010	2SM2	268.6	0.008
107010	M3	89.6	0.031
107010	L2	70.6	0.013
107010	2MK3	176.3	0.025
107010	K2	4.4	0.038
107010	M8	168.1	0.034
107010	MS4	31.5	0.05
107011	M2	341.4	2.098
107011	S2	3.3	0.279
107011	N2	317.2	0.475
107011	K1	172.2	0.03
107011	M4	31.8	0.014
107011	O1	111.6	0.053
107011	M6	120.8	0.153
107011	MK3	57.2	0.018
107011	S4	11	0.018
107011	MN4	345.1	0.021
107011	S6	137	0.01
107011	2N2	99.3	0.046
107011	OO1	323.8	0.006
107011	M1	125.3	0.009
107011	J1	99.7	0.019
107011	Q1	53.7	0.021
107011	2Q1	295.9	0.007
107011	P1	279	0.016
107011	2SM2	252.8	0.017
107011	M3	30.8	0.016
107011	L2	21.7	0.291
107011	2MK3	13.1	0.021
107011	K2	24.3	0.089
107011	M8	125.6	0.021
107011	MS4	230.8	0.024
107012	M2	341.5	2.793
107012	S2	1	0.377
107012	N2	316.2	0.64
107012	K1	166.6	0.046
107012	M4	49.9	0.056
107012	O1	120	0.07
107012	M6	123.7	0.198
107012	MK3	71.1	0.022
107012	S4	27.3	0.025
107012	MN4	3.6	0.036
107012	S6	127.1	0.008
107012	2N2	100	0.056
107012	OO1	263.6	0.007
107012	M1	138.2	0.011
107012	J1	106.3	0.025
107012	Q1	54.9	0.027
107012	P1	270.3	0.019
107012	2SM2	255.5	0.027
107012	M3	41.1	0.016
107012	L2	22.3	0.39
107012	2MK3	10.6	0.025
107012	K2	25.3	0.134
107012	M8	114.9	0.025
107012	MS4	208	0.019
107013	M2	341.2	2.844
107013	S2	0.7	0.389
107013	N2	315.7	0.654
107013	K1	167.1	0.047
107013	M4	66.3	0.061
107013	O1	123.5	0.073
107013	M6	125.6	0.197
107013	MK3	81.6	0.019
107013	S4	28.6	0.029
107013	MN4	18.1	0.036
107013	S6	131.7	0.005
107013	2N2	102.9	0.049
107013	OO1	267.2	0.005
107013	M1	138.4	0.011
107013	J1	101.9	0.024
107013	Q1	55.7	0.026
107013	P1	268.6	0.022
107013	2SM2	258.1	0.027
107013	M3	48.8	0.017
107013	L2	22.3	0.394
107013	2MK3	1.7	0.024
107013	K2	22.5	0.135
107013	M8	126.2	0.02
107013	MS4	203.1	0.019
107014	M2	342.7	2.35
107014	S2	7.6	0.332
107014	N2	316.7	0.541
107014	K1	148.6	0.035
107014	M4	5.3	0.063
107014	O1	102.9	0.047
107014	M6	128.2	0.137
107014	MK3	67.6	0.028
107014	S4	23.5	0.021
107014	MN4	327.2	0.045
107014	S6	140.5	0.006
107014	2N2	27.5	0.02
107014	OO1	248.6	0.009
107014	M1	140.5	0.004
107014	J1	100.5	0.02
107014	Q1	45.2	0.026
107014	2Q1	41	0.009
107014	P1	266.8	0.012
107014	2SM2	269.9	0.018
107014	M3	52.7	0.012
107014	L2	20.9	0.299
107014	2MK3	3	0.031
107014	K2	10.1	0.115
107014	M8	143.3	0.02
107014	MS4	339.7	0.015
107015	M2	342.3	3.2
107015	S2	6	0.438
107015	N2	316.6	0.723
107015	K1	142.8	0.048
107015	M4	357.1	0.155
107015	O1	109.4	0.072
107015	M6	126.3	0.208
107015	MK3	77.2	0.043
107015	S4	18	0.032
107015	MN4	324.1	0.092
107015	S6	140	0.007
107015	2N2	95.6	0.039
107015	OO1	266.5	0.009
107015	M1	144.1	0.006
107015	J1	95.3	0.028
107015	Q1	52.7	0.035
107015	2Q1	26.2	0.011
107015	P1	275.5	0.017
107015	2SM2	266.1	0.029
107015	M3	28.7	0.019
107015	L2	23.4	0.441
107015	2MK3	15.7	0.043
107015	K2	15.7	0.142
107015	M8	157.8	0.028
107015	MS4	348.2	0.031
107016	M2	342.1	3.431
107016	S2	5.7	0.471
107016	N2	315.5	0.767
107016	K1	131.1	0.048
107016	M4	351	0.211
107016	O1	113.8	0.084
107016	M6	124.8	0.22
107016	MK3	81.5	0.048
107016	S4	22.7	0.036
107016	MN4	313.2	0.116
107016	S6	114.5	0.005
107016	2N2	101.9	0.042
107016	OO1	273.4	0.009
107016	M1	126.9	0.007
107016	J1	91.7	0.03
107016	Q1	57	0.038
107016	2Q1	47.4	0.008
107016	P1	297.9	0.018
107016	2SM2	263.9	0.035
107016	M3	23.3	0.022
107016	L2	23.2	0.485
107016	2MK3	23.9	0.049
107016	K2	14.9	0.147
107016	M8	151.5	0.035
107016	MS4	352.9	0.053
107017	M2	343	1.549
107017	S2	15.1	0.162
107017	N2	331.1	0.317
107017	K1	129.9	0.038
107017	M4	346.9	0.086
107017	O1	105	0.042
107017	M6	120	0.104
107017	MK3	71.9	0.03
107017	S4	111.5	0.004
107017	MN4	1.6	0.053
107017	2N2	191.4	0.016
107017	OO1	350.9	0.004
107017	M1	129.1	0.01
107017	J1	226.8	0.009
107017	Q1	131.3	0.013
107017	2Q1	264.3	0.003
107017	2SM2	309.9	0.01
107017	M3	29.9	0.016
107017	L2	355.4	0.171
107017	2MK3	44.3	0.034
107017	K2	327.7	0.04
107017	M8	147	0.04
107017	MS4	71.4	0.011
107018	M2	341.7	1.981
107018	S2	11.5	0.197
107018	N2	330.3	0.403
107018	K1	123.9	0.045
107018	M4	351.7	0.119
107018	O1	104.7	0.054
107018	M6	119.5	0.178
107018	MK3	73.1	0.039
107018	S4	96.6	0.002
107018	MN4	353.1	0.075
107018	S6	173.7	0.003
107018	2N2	195.1	0.015
107018	OO1	33.9	0.003
107018	M1	127.2	0.009
107018	J1	209.9	0.009
107018	Q1	115.6	0.016
107018	2Q1	232.5	0.005
107018	2SM2	310.4	0.01
107018	M3	23.2	0.021
107018	L2	352.8	0.222
107018	2MK3	41.9	0.043
107018	K2	313.9	0.057
107018	M8	160	0.042
107018	MS4	53.4	0.016
107019	M2	339.3	2.106
107019	S2	5.1	0.209
107019	N2	326.5	0.426
107019	K1	110.6	0.042
107019	M4	4	0.101
107019	O1	92.7	0.052
107019	M6	111	0.193
107019	MK3	81.8	0.046
107019	S4	139.1	0.012
107019	MN4	343.6	0.075
107019	S6	26.9	0.002
107019	2N2	220.6	0.021
107019	OO1	90.5	0.003
107019	M1	105.3	0.007
107019	J1	224.9	0.008
107019	Q1	109.2	0.018
107019	2Q1	225.5	0.007
107019	2SM2	287	0.003
107019	M3	11	0.023
107019	L2	354.4	0.222
107019	2MK3	44.6	0.043
107019	K2	305.7	0.05
107019	M8	189.8	0.049
107019	MS4	27.7	0.023
107020	M2	344.5	2.968
107020	S2	7.1	0.409
107020	N2	318.3	0.667
107020	K1	173.5	0.027
107020	M4	115.2	0.064
107020	O1	114	0.068
107020	M6	149.8	0.179
107020	MK3	79.1	0.03
107020	S4	38	0.027
107020	MN4	42	0.015
107020	S6	222.4	0.008
107020	2N2	109.5	0.046
107020	OO1	246.3	0.01
107020	M1	144.8	0.005
107020	J1	104.6	0.027
107020	Q1	43.2	0.035
107020	2Q1	352.6	0.006
107020	P1	287.7	0.018
107020	2SM2	264.2	0.023
107020	M3	45.2	0.012
107020	L2	27	0.406
107020	2MK3	2.5	0.028
107020	K2	19.3	0.129
107020	M8	279.4	0.012
107020	MS4	229.2	0.031
107021	M2	344.4	3.726
107021	S2	6.7	0.509
107021	N2	317.7	0.836
107021	K1	173.4	0.033
107021	M4	101.8	0.068
107021	O1	113.1	0.085
107021	M6	148.7	0.231
107021	MK3	76.4	0.038
107021	S4	38	0.036
107021	MN4	17.4	0.022
107021	S6	220.1	0.011
107021	2N2	112.4	0.061
107021	OO1	242	0.012
107021	M1	150.9	0.006
107021	J1	107.7	0.034
107021	Q1	40	0.044
107021	2Q1	324.8	0.008
107021	P1	297.4	0.025
107021	2SM2	260.9	0.03
107021	M3	54.5	0.016
107021	L2	26.6	0.511
107021	2MK3	6.2	0.036
107021	K2	20.2	0.164
107021	M8	262.9	0.013
107021	MS4	234.4	0.034
107022	M2	344.1	3.921
107022	S2	6.7	0.533
107022	N2	317.3	0.88
107022	K1	175	0.033
107022	M4	90.9	0.077
107022	O1	114.4	0.09
107022	M6	148.7	0.24
107022	MK3	83.5	0.04
107022	S4	35.7	0.038
107022	MN4	16.6	0.027
107022	S6	223.9	0.013
107022	2N2	113.9	0.064
107022	OO1	248	0.013
107022	M1	148.3	0.007
107022	J1	106.2	0.034
107022	Q1	39.6	0.045
107022	2Q1	322.8	0.009
107022	P1	294.3	0.029
107022	2SM2	264.3	0.033
107022	M3	57.3	0.018
107022	L2	26.6	0.541
107022	2MK3	9.7	0.039
107022	K2	19.5	0.167
107022	M8	247.2	0.015
107022	MS4	225.2	0.029
107023	M2	329.6	0.675
107023	S2	1.3	0.056
107023	N2	317.5	0.119
107023	K1	313.2	0.055
107023	M4	331.7	0.142
107023	O1	35.4	0.027
107023	M6	145	0.015
107023	MK3	30.3	0.012
107023	S4	272.3	0.002
107023	MN4	320.3	0.058
107023	S6	221	0.007
107023	2N2	209.6	0.024
107023	OO1	329.6	0.011
107023	M1	70.1	0.011
107023	J1	165.1	0.002
107023	Q1	18.1	0.009
107023	2Q1	323.4	0.007
107023	P1	217.4	0.006
107023	2SM2	135.4	0.004
107023	M3	66.6	0.009
107023	L2	353.9	0.085
107023	2MK3	126.1	0.018
107023	K2	299	0.011
107023	M8	186.3	0.017
107023	MS4	24.7	0.029
107024	M2	3.7	1.003
107024	S2	23.8	0.181
107024	N2	345.3	0.256
107024	K1	148.9	0.178
107024	M4	148.3	0.05
107024	O1	133.1	0.098
107024	M6	165.7	0.031
107024	MK3	150.5	0.013
107024	S4	25.7	0.019
107024	MN4	136.8	0.02
107024	S6	152.7	0.003
107024	2N2	3.9	0.045
107024	OO1	143.8	0.01
107024	M1	173.5	0.007
107024	J1	133.2	0.018
107024	Q1	133.3	0.017
107024	2Q1	125.9	0.012
107024	P1	121.7	0.047
107024	2SM2	298	0.005
107024	M3	21.6	0.016
107024	L2	22.8	0.107
107024	2MK3	349.7	0.012
107024	K2	44.9	0.065
107024	M8	21.4	0.016
107024	MS4	232.3	0.022
107025	M2	20.5	1.447
107025	S2	34.9	0.25
107025	N2	359.4	0.358
107025	K1	160.6	0.284
107025	M4	233	0.04
107025	O1	141	0.155
107025	M6	276	0.01
107025	MK3	178.3	0.032
107025	S4	63.5	0.023
107025	MN4	201.4	0.012
107025	S6	279.9	0.008
107025	2N2	337.7	0.029
107025	OO1	202.2	0.008
107025	M1	134	0.011
107025	J1	134.3	0.022
107025	Q1	163.7	0.019
107025	2Q1	209.1	0.02
107025	P1	143.4	0.062
107025	2SM2	357.4	0.016
107025	M3	42.6	0.036
107025	L2	68.2	0.152
107025	2MK3	70.4	0.029
107025	K2	53.8	0.064
107025	M8	136.9	0.02
107025	MS4	253.5	0.017
107026	M2	29	1.693
107026	S2	35.2	0.301
107026	N2	359.1	0.391
107026	K1	172.2	0.326
107026	M4	287.7	0.095
107026	O1	172.3	0.162
107026	M6	357.6	0.025
107026	MK3	133.6	0.014
107026	S4	40.5	0.014
107026	MN4	279.6	0.023
107026	S6	268.2	0.007
107026	2N2	288.3	0.059
107026	OO1	338	0.031
107026	M1	56.8	0.012
107026	J1	132.6	0.025
107026	Q1	243.1	0.016
107026	2Q1	277.7	0.037
107026	P1	151	0.085
107026	2SM2	355.4	0.026
107026	M3	81.6	0.035
107026	L2	91	0.217
107026	2MK3	79.2	0.046
107026	K2	68.3	0.08
107026	M8	96.5	0.009
107026	MS4	284.4	0.038
107027	M2	11.7	1.491
107027	S2	41.4	0.264
107027	N2	353.7	0.392
107027	K1	154.3	0.248
107027	M4	250.6	0.042
107027	O1	129.5	0.131
107027	M6	211.8	0.034
107027	MK3	103.3	0.02
107027	S4	66.3	0.025
107027	MN4	205.6	0.004
107027	S6	282	0.008
107027	2N2	2.9	0.086
107027	OO1	272.5	0.007
107027	M1	129.1	0.007
107027	J1	136.8	0.023
107027	Q1	131.1	0.019
107027	2Q1	204.8	0.022
107027	P1	135	0.034
107027	2SM2	303.6	0.015
107027	M3	2.5	0.023
107027	L2	29.6	0.128
107027	2MK3	32.1	0.042
107027	K2	34.2	0.08
107027	M8	19.5	0.015
107027	MS4	269.5	0.024
107028	M2	24.1	1.943
107028	S2	33.4	0.307
107028	N2	0.8	0.456
107028	K1	166.4	0.3
107028	M4	340.9	0.075
107028	O1	142.7	0.175
107028	M6	63.9	0.008
107028	MK3	141.1	0.061
107028	S4	59	0.021
107028	MN4	303.2	0.038
107028	2N2	295.9	0.066
107028	OO1	307.4	0.026
107028	M1	88.3	0.012
107028	J1	129.4	0.029
107028	Q1	147.7	0.012
107028	2Q1	237.9	0.043
107028	P1	170.6	0.031
107028	2SM2	333.8	0.022
107028	M3	51	0.046
107028	L2	77.1	0.215
107028	2MK3	96.4	0.074
107028	K2	46.7	0.117
107028	M8	26.1	0.015
107028	MS4	353.2	0.011
107029	M2	32.1	2.088
107029	S2	37.1	0.394
107029	N2	1.9	0.518
107029	K1	173.8	0.429
107029	M4	297.3	0.094
107029	O1	170.2	0.219
107029	M6	101.8	0.06
107029	MK3	84.8	0.003
107029	S4	89.4	0.026
107029	MN4	299.6	0.04
107029	2N2	302.7	0.071
107029	OO1	14.9	0.039
107029	M1	66.2	0.023
107029	J1	119.4	0.049
107029	Q1	165.3	0.021
107029	2Q1	260.5	0.034
107029	P1	149.4	0.122
107029	2SM2	14.5	0.021
107029	M3	94.4	0.04
107029	L2	100.2	0.24
107029	2MK3	72.8	0.023
107029	K2	65.6	0.125
107029	M8	176.3	0.01
107029	MS4	301.5	0.046
107030	M2	17.6	1.437
107030	S2	37.9	0.256
107030	N2	358.7	0.344
107030	K1	164.7	0.224
107030	M4	235.1	0.225
107030	O1	130.3	0.073
107030	M6	321	0.049
107030	MK3	359.6	0.022
107030	S4	71.8	0.017
107030	MN4	212.8	0.086
107030	S6	313.1	0.012
107030	2N2	335.9	0.049
107030	OO1	266.2	0.019
107030	M1	9.2	0.013
107030	J1	185	0.022
107030	Q1	339	0.003
107030	2Q1	191.9	0.024
107030	P1	178.5	0.065
107030	2SM2	266.8	0.006
107030	M3	33.6	0.013
107030	L2	47.8	0.128
107030	2MK3	15.6	0.049
107030	K2	55.3	0.086
107030	M8	120	0.018
107030	MS4	256.7	0.071
107031	M2	21.2	1.566
107031	S2	48.4	0.286
107031	N2	2.4	0.384
107031	K1	158.1	0.242
107031	M4	292.3	0.168
107031	O1	130	0.136
107031	M6	300.9	0.055
107031	MK3	65.3	0.027
107031	S4	75.8	0.019
107031	MN4	288.7	0.062
107031	2N2	345.7	0.081
107031	OO1	256.2	0.026
107031	M1	67.3	0.013
107031	J1	161.4	0.013
107031	Q1	151.7	0.024
107031	2Q1	216.2	0.03
107031	P1	150.8	0.036
107031	2SM2	226.8	0.006
107031	M3	343.4	0.011
107031	L2	42.8	0.12
107031	2MK3	25.7	0.06
107031	K2	50.4	0.085
107031	M8	37.4	0.017
107031	MS4	312.6	0.053
107032	M2	28.6	1.737
107032	S2	46.7	0.264
107032	N2	5.1	0.433
107032	K1	157.7	0.293
107032	M4	0.7	0.236
107032	O1	142.4	0.183
107032	M6	109.1	0.046
107032	MK3	111.4	0.089
107032	S4	43.5	0.038
107032	MN4	332.9	0.109
107032	S6	205.8	0.011
107032	2N2	4.3	0.071
107032	OO1	314.3	0.022
107032	M1	96.4	0.016
107032	J1	130.6	0.033
107032	Q1	116	0.026
107032	2Q1	227.7	0.004
107032	P1	106.7	0.065
107032	2SM2	352.4	0.008
107032	M3	43.2	0.037
107032	L2	55.1	0.185
107032	2MK3	80.1	0.087
107032	K2	61.3	0.132
107032	M8	304.1	0.013
107032	MS4	350.3	0.093
107033	M2	288	1.166
107033	S2	314.5	0.261
107033	N2	270.6	0.316
107033	K1	99	0.087
107033	M4	0.8	0.04
107033	O1	64.8	0.037
107033	M6	27.8	0.055
107033	MK3	317.7	0.014
107033	S4	320	0.051
107033	MN4	304.4	0.026
107033	S6	186.7	0.007
107033	2N2	286.8	0.072
107033	OO1	11.2	0.004
107033	M1	337.8	0.008
107033	J1	73.9	0.011
107033	Q1	356.5	0.005
107033	2Q1	61	0.01
107033	P1	66.9	0.022
107033	2SM2	167.4	0.016
107033	M3	0.6	0.024
107033	L2	307.2	0.075
107033	2MK3	263.9	0.03
107033	K2	334.6	0.042
107033	M8	123.1	0.029
107033	MS4	97.1	0.018
107034	M2	289.1	1.442
107034	S2	314.6	0.309
107034	N2	272.5	0.384
107034	K1	103.8	0.111
107034	M4	241.8	0.066
107034	O1	77.8	0.045
107034	M6	25.5	0.093
107034	MK3	27.3	0.015
107034	S4	318.2	0.06
107034	MN4	247.9	0.052
107034	S6	152.6	0.008
107034	2N2	285.8	0.086
107034	OO1	78.9	0.005
107034	M1	16.2	0.005
107034	J1	102.4	0.011
107034	Q1	95.9	0.004
107034	2Q1	145.1	0.007
107034	P1	77.9	0.029
107034	2SM2	150.2	0.007
107034	M3	351.5	0.038
107034	L2	312.8	0.108
107034	2MK3	287.1	0.038
107034	K2	339.2	0.072
107034	M8	139.5	0.016
107034	MS4	229.2	0.022
107035	M2	287.8	1.452
107035	S2	306.8	0.323
107035	N2	271.1	0.401
107035	K1	103.9	0.101
107035	M4	262.9	0.126
107035	O1	101.4	0.048
107035	M6	56.7	0.087
107035	MK3	73.1	0.031
107035	S4	323.7	0.061
107035	MN4	260.1	0.079
107035	S6	205.2	0.01
107035	2N2	272.8	0.086
107035	OO1	78.2	0.011
107035	M1	74.1	0.002
107035	J1	89.6	0.015
107035	Q1	165.9	0.003
107035	2Q1	106.7	0.004
107035	P1	72.3	0.019
107035	2SM2	127.6	0.012
107035	M3	345.4	0.04
107035	L2	303.8	0.122
107035	2MK3	308.4	0.036
107035	K2	7.4	0.097
107035	M8	6.4	0.013
107035	MS4	279.9	0.042
107036	M2	286.1	1.037
107036	S2	325.5	0.203
107036	N2	280.9	0.249
107036	K1	91.7	0.112
107036	M4	133.9	0.082
107036	O1	93.7	0.059
107036	M6	43.1	0.19
107036	MK3	285.5	0.019
107036	S4	18.4	0.044
107036	MN4	230.2	0.038
107036	S6	59.7	0.022
107036	2N2	335.5	0.049
107036	OO1	57.4	0.003
107036	M1	29.1	0.008
107036	J1	257.8	0.001
107036	Q1	142.5	0.016
107036	2Q1	149.3	0.003
107036	P1	132.6	0.008
107036	2SM2	13.8	0.014
107036	M3	321.9	0.013
107036	L2	261.7	0.056
107036	2MK3	307.7	0.033
107036	K2	353	0.064
107036	M8	198.7	0.017
107036	MS4	177.2	0.031
107037	M2	296.9	1.077
107037	S2	322.6	0.18
107037	N2	280.4	0.278
107037	K1	92.6	0.077
107037	M4	187	0.083
107037	O1	73.1	0.035
107037	M6	66.1	0.16
107037	MK3	244.1	0.003
107037	S4	27.3	0.041
107037	MN4	257.6	0.049
107037	S6	46	0.019
107037	2N2	313.5	0.062
107037	OO1	3.3	0.005
107037	M1	38	0.005
107037	J1	97.3	0.003
107037	Q1	149.4	0.012
107037	2Q1	121.5	0.006
107037	P1	88.1	0.023
107037	2SM2	296.9	0.019
107037	M3	352.4	0.038
107037	L2	336.1	0.027
107037	2MK3	340.8	0.027
107037	K2	327.8	0.036
107037	M8	14.4	0.028
107037	MS4	189	0.023
107038	M2	324.7	2.198
107038	S2	0.7	0.307
107038	N2	321.9	0.463
107038	K1	124.4	0.218
107038	M4	313.8	0.22
107038	O1	117.9	0.088
107038	M6	81.6	0.256
107038	MK3	77.5	0.074
107038	S4	35.4	0.034
107038	MN4	302.9	0.127
107038	S6	34.5	0.009
107038	2N2	118.4	0.028
107038	OO1	160.2	0.018
107038	M1	122.1	0.003
107038	J1	226.3	0.005
107038	Q1	156	0.029
107038	2Q1	35.4	0.009
107038	P1	84.8	0.019
107038	2SM2	76.2	0.003
107038	M3	358	0.026
107038	L2	322.1	0.207
107038	2MK3	8.2	0.1
107038	K2	9.7	0.09
107038	M8	82.7	0.063
107038	MS4	326.1	0.036
107039	M2	299.3	0.865
107039	S2	333.2	0.172
107039	N2	282.3	0.234
107039	K1	86	0.059
107039	M4	159.3	0.096
107039	O1	92.8	0.026
107039	M6	31.4	0.078
107039	MK3	304.7	0.009
107039	S4	320.7	0.037
107039	MN4	145.1	0.037
107039	S6	143.5	0.003
107039	2N2	293.7	0.048
107039	OO1	224.7	0.004
107039	M1	179.1	0.002
107039	J1	65.1	0.008
107039	Q1	173.8	0.007
107039	2Q1	139.7	0.015
107039	P1	334.2	0.006
107039	2SM2	35.8	0.003
107039	M3	355.4	0.013
107039	L2	323.5	0.058
107039	2MK3	286.5	0.025
107039	K2	315.3	0.038
107039	M8	250.8	0.014
107039	MS4	185.6	0.06
107040	M2	302.1	0.944
107040	S2	328.7	0.187
107040	N2	284.4	0.263
107040	K1	90.1	0.077
107040	M4	177	0.128
107040	O1	89.9	0.028
107040	M6	42.3	0.069
107040	MK3	329	0.019
107040	S4	325.8	0.038
107040	MN4	155.1	0.051
107040	S6	180.4	0.005
107040	2N2	288.5	0.057
107040	OO1	186.3	0.006
107040	M1	352.2	0.004
107040	J1	58.3	0.009
107040	Q1	182.8	0.009
107040	2Q1	139.6	0.012
107040	P1	62.7	0.016
107040	2SM2	57.3	0.005
107040	M3	5.2	0.019
107040	L2	313.7	0.053
107040	2MK3	286.6	0.033
107040	K2	333.6	0.049
107040	M8	273	0.019
107040	MS4	194.3	0.072
107041	M2	69.8	1.28
107041	S2	63.6	0.555
107041	N2	50.2	0.29
107041	K1	131.7	0.407
107041	M4	282.8	0.054
107041	O1	111	0.252
107041	NU2	52.9	0.056
107041	2N2	30.6	0.039
107041	OO1	152.4	0.011
107041	M1	121.4	0.018
107041	J1	142	0.02
107041	Q1	100.5	0.049
107041	T2	63.5	0.033
107041	P1	131.7	0.135
107041	L2	89.4	0.036
107041	K2	63.5	0.151
107042	M2	138.4	1.254
107042	S2	153.8	0.247
107042	N2	116.8	0.223
107042	K1	135.4	0.273
107042	M4	29.4	0.108
107042	O1	103.8	0.143
107042	M6	309	0.05
107042	MK3	7	0.135
107042	S4	77.4	0.002
107042	MN4	10.9	0.036
107042	NU2	127	0.054
107042	S6	197.1	0.002
107042	MU2	284.1	0.062
107042	2N2	107.6	0.038
107042	OO1	244.6	0.021
107042	LDA2	112.6	0.027
107042	S1	146.8	0.04
107042	M1	182	0.031
107042	J1	208.2	0.015
107042	RHO1	47.5	0.003
107042	Q1	129.6	0.024
107042	T2	114.9	0.026
107042	R2	359.2	0.028
107042	2Q1	337.6	0.004
107042	P1	146.1	0.082
107042	2SM2	313.1	0.013
107042	M3	37.7	0.006
107042	L2	133	0.085
107042	2MK3	336.2	0.134
107042	K2	131.2	0.115
107042	M8	217.1	0.009
107042	MS4	32.3	0.036
107043	M2	176.6	1.55
107043	S2	187.5	0.343
107043	N2	151.5	0.297
107043	K1	177.5	0.569
107043	M4	201	0.042
107043	O1	163.2	0.334
107043	M6	44.5	0.062
107043	MK3	54.3	0.039
107043	S4	359.1	0.007
107043	MN4	129.7	0.011
107043	NU2	157.1	0.071
107043	MU2	343.8	0.053
107043	2N2	161.4	0.034
107043	OO1	246.3	0.02
107043	LDA2	182.9	0.037
107043	S1	195.3	0.022
107043	M1	218	0.035
107043	J1	218.7	0.019
107043	RHO1	150.2	0.016
107043	Q1	165.5	0.061
107043	T2	136.3	0.025
107043	R2	97.1	0.022
107043	2Q1	177.9	0.008
107043	P1	180.8	0.166
107043	2SM2	12.4	0.014
107043	M3	321.9	0.008
107043	L2	179.6	0.085
107043	2MK3	19.8	0.089
107043	K2	173.7	0.133
107043	M8	251.6	0.004
107043	MS4	190.4	0.009
107044	M2	173.6	2.265
107044	S2	204.5	0.592
107044	N2	156.5	0.457
107044	K1	168.5	0.569
107044	M4	161.6	0.154
107044	O1	158.8	0.296
107044	M6	320.1	0.079
107044	NU2	158.8	0.089
107044	2N2	139.4	0.061
107044	OO1	178.2	0.013
107044	LDA2	187.9	0.016
107044	M1	163.7	0.021
107044	J1	173.2	0.023
107044	RHO1	154.6	0.011
107044	Q1	153.8	0.058
107044	T2	204.5	0.035
107044	P1	168.4	0.188
107044	L2	190.7	0.064
107044	K2	204.5	0.161
107044	M8	257.3	0.031
107045	M2	268.8	2.461
107045	S2	58	0.041
107045	N2	189.9	0.477
107045	K1	326.3	0.508
107045	M4	153.7	0.353
107045	O1	311.4	0.214
107045	M6	323.5	0.185
107045	NU2	200.6	0.123
107045	2N2	109	0.085
107045	LDA2	338.1	0.017
107045	M1	319.4	0.016
107045	J1	333.2	0.017
107045	Q1	303.5	0.041
107045	P1	326.6	0.168
107045	L2	349.7	0.069
107045	K2	58.7	0.011
107045	M8	182.4	0.081
107046	M2	40.5	0.741
107046	S2	92.9	0.16
107046	N2	347.1	0.222
107046	K1	101.6	0.026
107046	M4	344.2	0.182
107046	O1	128.6	0.023
107046	M6	145.1	0.311
107046	S4	230.4	0.013
107046	NU2	354.3	0.043
107046	S6	29.3	0.024
107046	2N2	293.8	0.029
107046	OO1	74.5	0.001
107046	LDA2	64.8	0.005
107046	M1	115	0.002
107046	J1	88.2	0.002
107046	RHO1	140.2	0.001
107046	Q1	141.9	0.004
107046	T2	90.7	0.009
107046	R2	95	0.001
107046	2Q1	155.4	0.001
107046	P1	103.5	0.008
107046	L2	347.2	0.032
107046	K2	97.1	0.043
107046	M8	210.7	0.072
107047	M2	32.2	1.075
107047	S2	69.9	0.109
107047	N2	355.4	0.198
107047	K1	115.4	0.038
107047	M4	5.2	0.162
107047	O1	124.4	0.024
107047	M6	147.3	0.302
107047	S4	290.4	0.016
107047	NU2	0.4	0.038
107047	S6	137.1	0.001
107047	2N2	318.7	0.026
107047	OO1	106.3	0.001
107047	LDA2	49.6	0.008
107047	M1	119.8	0.002
107047	J1	110.9	0.002
107047	RHO1	128.2	0.001
107047	Q1	128.8	0.005
107047	T2	68.3	0.006
107047	R2	71.4	0.001
107047	2Q1	133.3	0.001
107047	P1	116	0.013
107047	L2	355.5	0.028
107047	K2	72.9	0.03
107047	M8	229.2	0.062
107048	M2	29	1.212
107048	S2	61.2	0.121
107048	N2	357.9	0.206
107048	K1	122.3	0.043
107048	M4	51	0.126
107048	O1	119.2	0.023
107048	M6	159.2	0.325
107048	S4	31	0.01
107048	NU2	2	0.04
107048	S6	220	0.004
107048	2N2	326.9	0.027
107048	OO1	125.3	0.001
107048	LDA2	43.8	0.008
107048	M1	120.7	0.002
107048	J1	123.8	0.002
107048	RHO1	117.8	0.001
107048	Q1	117.5	0.004
107048	T2	59.8	0.007
107048	R2	62.5	0.001
107048	2Q1	116	0.001
107048	P1	122	0.014
107048	L2	357.9	0.029
107048	K2	63.8	0.033
107048	M8	235.4	0.045
107049	M2	25.4	1.239
107049	S2	69.1	0.17
107049	N2	0.7	0.239
107049	K1	129.6	0.058
107049	M4	345	0.202
107049	O1	108.7	0.034
107049	M6	138.1	0.243
107049	S4	45.9	0.008
107049	NU2	4.1	0.046
107049	S6	224.5	0.001
107049	2N2	336.1	0.032
107049	OO1	150.3	0.001
107049	LDA2	45.6	0.009
107049	M1	119.1	0.002
107049	J1	139.9	0.003
107049	RHO1	99.7	0.001
107049	Q1	98.3	0.007
107049	T2	67.3	0.01
107049	R2	70.8	0.001
107049	2Q1	88	0.001
107049	P1	127.9	0.019
107049	L2	0.8	0.034
107049	K2	72.6	0.046
107049	M8	260.8	0.045
107050	M2	33.9	1.522
107050	S2	71.9	0.225
107050	N2	2.2	0.318
107050	K1	144.1	0.066
107050	M4	331.6	0.208
107050	O1	128.3	0.04
107050	M6	139.3	0.321
107050	S4	49.9	0.006
107050	NU2	6.5	0.062
107050	S6	4.5	0.009
107050	2N2	330.6	0.042
107050	OO1	159.8	0.002
107050	LDA2	51.5	0.011
107050	M1	136.2	0.003
107050	J1	151.9	0.003
107050	RHO1	121.5	0.002
107050	Q1	120.4	0.008
107050	T2	70.3	0.013
107050	R2	73.4	0.002
107050	2Q1	112.6	0.001
107050	P1	142.9	0.022
107050	L2	2.3	0.045
107050	K2	75	0.061
107050	M8	258.2	0.049
107051	M2	15.1	0.817
107051	S2	54.5	0.128
107051	N2	337.6	0.148
107051	K1	105.9	0.033
107051	M4	279.9	0.119
107051	O1	62	0.024
107051	M6	163.5	0.132
107051	S4	68	0.02
107051	NU2	342.6	0.029
107051	S6	110.4	0.006
107051	2N2	300.1	0.02
107051	OO1	149.7	0.001
107051	LDA2	33.4	0.006
107051	M1	83.9	0.002
107051	J1	127.7	0.002
107051	RHO1	43.1	0.001
107051	Q1	40.2	0.005
107051	T2	52.9	0.008
107051	R2	56.1	0.001
107051	2Q1	18.4	0.001
107051	P1	102.5	0.011
107051	L2	337.6	0.021
107051	K2	57.7	0.035
107051	M8	168.1	0.064
107052	M2	13.4	2.022
107052	S2	58	0.293
107052	N2	341.7	0.4
107052	K1	110.4	0.078
107052	M4	43.9	0.154
107052	O1	63.7	0.057
107052	M6	127.3	0.318
107052	S4	356.7	0.029
107052	NU2	345.9	0.078
107052	S6	66.3	0.007
107052	2N2	310	0.053
107052	OO1	157	0.002
107052	LDA2	34	0.014
107052	M1	87	0.004
107052	J1	133.6	0.004
107052	RHO1	43.6	0.002
107052	Q1	40.5	0.011
107052	T2	56.1	0.017
107052	R2	59.8	0.002
107052	2Q1	17.3	0.001
107052	P1	106.8	0.026
107052	L2	341.7	0.057
107052	K2	61.6	0.08
107052	M8	219.9	0.116
107053	M2	16.4	2.019
107053	S2	58.5	0.292
107053	N2	342.2	0.409
107053	K1	108.7	0.083
107053	M4	39.9	0.221
107053	O1	83.6	0.059
107053	M6	123.4	0.359
107053	S4	347.6	0.019
107053	NU2	346.8	0.079
107053	S6	112.6	0.009
107053	2N2	308.1	0.054
107053	OO1	133.7	0.003
107053	LDA2	35.9	0.014
107053	M1	96.1	0.004
107053	J1	121.1	0.005
107053	RHO1	72.8	0.002
107053	Q1	71.1	0.011
107053	T2	56.7	0.017
107053	R2	60.1	0.002
107053	2Q1	58.7	0.002
107053	P1	106.7	0.027
107053	L2	342.3	0.059
107053	K2	61.9	0.079
107053	M8	208	0.079
107054	M2	23.4	1.989
107054	S2	58	0.262
107054	N2	345.8	0.409
107054	K1	118.3	0.086
107054	M4	34.9	0.198
107054	O1	101.1	0.063
107054	M6	123	0.359
107054	S4	43.7	0.015
107054	NU2	350.9	0.079
107054	S6	95.9	0.013
107054	2N2	308.2	0.054
107054	OO1	135.4	0.003
107054	LDA2	39.4	0.014
107054	M1	109.6	0.004
107054	J1	126.8	0.005
107054	RHO1	93.7	0.002
107054	Q1	92.5	0.012
107054	T2	56.6	0.015
107054	R2	59.4	0.002
107054	2Q1	84.1	0.002
107054	P1	116.9	0.029
107054	L2	345.8	0.058
107054	K2	60.8	0.071
107054	M8	198.4	0.071
107055	M2	12.4	2.141
107055	S2	56.3	0.324
107055	N2	347.2	0.422
107055	K1	114.6	0.117
107055	M4	317.3	0.185
107055	O1	90.9	0.062
107055	M6	146.1	0.241
107055	S4	145.2	0.034
107055	NU2	350.6	0.082
107055	S6	18.3	0.013
107055	2N2	322.1	0.056
107055	OO1	138.1	0.003
107055	LDA2	32.7	0.015
107055	M1	102.7	0.004
107055	J1	126.3	0.005
107055	RHO1	80.7	0.002
107055	Q1	79.1	0.012
107055	T2	54.4	0.019
107055	R2	58	0.003
107055	2Q1	67.4	0.002
107055	P1	112.7	0.039
107055	L2	347.3	0.06
107055	K2	59.8	0.088
107055	M8	243.6	0.086
107056	M2	19.6	2.24
107056	S2	58.9	0.328
107056	N2	348.3	0.45
107056	K1	119	0.13
107056	M4	21.4	0.231
107056	O1	99.5	0.076
107056	M6	119.9	0.269
107056	S4	145.3	0.018
107056	NU2	352.6	0.087
107056	S6	317.7	0.012
107056	2N2	317.1	0.06
107056	OO1	138.4	0.003
107056	LDA2	37.8	0.016
107056	M1	109.2	0.005
107056	J1	128.7	0.006
107056	RHO1	91.1	0.003
107056	Q1	89.7	0.015
107056	T2	57.3	0.019
107056	R2	60.5	0.003
107056	2Q1	80.1	0.002
107056	P1	117.4	0.043
107056	L2	348.4	0.064
107056	K2	62.1	0.089
107056	M8	297.8	0.088
107057	M2	27.7	2.22
107057	S2	60.6	0.323
107057	N2	353.8	0.454
107057	K1	120.4	0.112
107057	M4	73.6	0.323
107057	O1	100.4	0.067
107057	M6	114.8	0.43
107057	S4	285.5	0.013
107057	NU2	358.4	0.088
107057	S6	286.4	0.011
107057	2N2	320.1	0.06
107057	OO1	140.3	0.003
107057	LDA2	42.9	0.016
107057	M1	110.4	0.005
107057	J1	130.3	0.005
107057	RHO1	91.8	0.003
107057	Q1	90.5	0.013
107057	T2	59.2	0.019
107057	R2	62	0.003
107057	2Q1	80.6	0.002
107057	P1	118.8	0.037
107057	L2	353.9	0.065
107057	K2	63.3	0.088
107057	M8	9.5	0.029
107058	M2	3.3	0.832
107058	S2	44.5	0.131
107058	N2	341.1	0.148
107058	K1	73.5	0.029
107058	M4	9	0.088
107058	O1	10.9	0.006
107058	M6	140.1	0.122
107058	S4	71.6	0.007
107058	NU2	344.1	0.029
107058	S6	143.5	0.022
107058	2N2	319	0.02
107058	LDA2	22.3	0.006
107058	Q1	339.7	0.001
107058	T2	42.7	0.008
107058	R2	46.1	0.001
107058	P1	68.7	0.009
107058	L2	341.2	0.021
107058	K2	47.8	0.036
107058	M8	130.1	0.055
107059	M2	17.2	0.88
107059	S2	53.7	0.155
107059	N2	346.5	0.21
107059	K1	108.2	0.05
107059	M4	344	0.104
107059	O1	132.2	0.02
107059	M6	106.7	0.174
107059	S4	341.2	0.011
107059	NU2	350.7	0.041
107059	S6	174.6	0.012
107059	2N2	316	0.028
107059	OO1	84.1	0.001
107059	LDA2	34.1	0.006
107059	M1	120.1	0.001
107059	J1	96.2	0.002
107059	RHO1	142.4	0.001
107059	Q1	144	0.004
107059	T2	52.1	0.009
107059	R2	55.1	0.001
107059	2Q1	155.9	0.001
107059	P1	109.9	0.016
107059	L2	346.6	0.03
107059	K2	56.6	0.042
107059	M8	227.7	0.07
107060	M2	359.4	0.894
107060	S2	26.1	0.112
107060	N2	323.2	0.159
107060	K1	57.8	0.039
107060	M4	233.7	0.078
107060	O1	91.6	0.008
107060	M6	96.6	0.152
107060	S4	62.5	0.005
107060	NU2	328	0.031
107060	S6	329.7	0.006
107060	2N2	287.1	0.021
107060	LDA2	11.7	0.006
107060	M1	74.6	0.001
107060	J1	41	0.001
107060	Q1	108.2	0.002
107060	T2	25	0.007
107060	R2	27.2	0.001
107060	P1	60.2	0.013
107060	L2	323.2	0.023
107060	K2	28.3	0.031
107060	M8	309.8	0.021
107061	M2	1.4	0.879
107061	S2	46.4	0.106
107061	N2	332.8	0.145
107061	K1	71.2	0.03
107061	M4	280.1	0.062
107061	O1	109.5	0.01
107061	M6	76.9	0.11
107061	S4	19.2	0.002
107061	NU2	336.6	0.028
107061	S6	40.1	0.007
107061	2N2	304.3	0.019
107061	LDA2	22.2	0.006
107061	M1	90.3	0.001
107061	J1	52.2	0.001
107061	Q1	128.5	0.002
107061	T2	44.5	0.006
107061	R2	48.1	0.001
107061	P1	74	0.01
107061	L2	332.8	0.021
107061	K2	50	0.029
107061	M8	152	0.012
107062	M2	12.6	0.886
107062	S2	63.4	0.113
107062	N2	353.4	0.163
107062	K1	103	0.041
107062	M4	351.6	0.059
107062	O1	114.1	0.027
107062	M6	53.3	0.108
107062	S4	25.9	0.006
107062	NU2	356	0.032
107062	S6	38.4	0.015
107062	2N2	334.3	0.022
107062	OO1	91.8	0.001
107062	LDA2	36.1	0.006
107062	M1	108.5	0.002
107062	J1	97.4	0.002
107062	RHO1	118.8	0.001
107062	Q1	119.5	0.005
107062	T2	61.2	0.007
107062	R2	65.4	0.001
107062	2Q1	125.1	0.001
107062	P1	103.7	0.013
107062	L2	353.4	0.023
107062	K2	67.5	0.031
107062	M8	201.6	0.054
107063	M2	20.3	1.123
107063	S2	62.4	0.164
107063	N2	353.9	0.208
107063	K1	116.3	0.061
107063	M4	105.8	0.023
107063	O1	108	0.039
107063	M6	296	0.031
107063	S4	330.6	0.009
107063	NU2	357.5	0.04
107063	S6	10.2	0.004
107063	2N2	327.6	0.028
107063	OO1	124.6	0.002
107063	LDA2	39.8	0.008
107063	M1	112.1	0.003
107063	J1	120.4	0.003
107063	RHO1	104.4	0.001
107063	Q1	103.8	0.008
107063	T2	60.6	0.01
107063	R2	64.1	0.001
107063	2Q1	99.7	0.001
107063	P1	115.6	0.02
107063	L2	354	0.03
107063	K2	65.8	0.045
107063	M8	216	0.009
107064	M2	25	1.167
107064	S2	65	0.173
107064	N2	354.4	0.22
107064	K1	119.9	0.06
107064	M4	100.6	0.066
107064	O1	114.4	0.043
107064	M6	24.2	0.02
107064	S4	356.7	0.011
107064	NU2	358.5	0.043
107064	S6	352.2	0.008
107064	2N2	323.8	0.029
107064	OO1	125.4	0.002
107064	LDA2	43.5	0.008
107064	M1	117.1	0.003
107064	J1	122.6	0.003
107064	RHO1	112	0.002
107064	Q1	111.6	0.008
107064	T2	63.3	0.01
107064	R2	66.6	0.001
107064	2Q1	108.9	0.001
107064	P1	119.4	0.02
107064	L2	354.4	0.031
107064	K2	68.2	0.047
107064	M8	46.6	0.008
107065	M2	26.6	1.158
107065	S2	63.4	0.17
107065	N2	355	0.229
107065	K1	124.6	0.065
107065	M4	110.3	0.096
107065	O1	117	0.035
107065	M6	57.7	0.046
107065	S4	50.4	0.003
107065	NU2	359.3	0.044
107065	S6	331.6	0.006
107065	2N2	323.5	0.03
107065	OO1	132.2	0.002
107065	LDA2	43.6	0.008
107065	M1	120.8	0.003
107065	J1	128.4	0.003
107065	RHO1	113.7	0.001
107065	Q1	113.2	0.007
107065	T2	61.8	0.01
107065	R2	64.9	0.001
107065	2Q1	109.5	0.001
107065	P1	124	0.022
107065	L2	355.1	0.033
107065	K2	66.4	0.046
107065	M8	116.6	0.015
107066	M2	311.5	0.48
107066	S2	339.4	0.084
107066	N2	293.2	0.113
107066	K1	161.1	0.042
107066	M4	60.6	0.032
107066	O1	181.2	0.034
107066	M6	8.4	0.019
107066	MK3	168.4	0.018
107066	S4	148.1	0.008
107066	MN4	24.1	0.018
107066	NU2	243.7	0.013
107066	S6	90	0.006
107066	MU2	16.3	0.024
107066	2N2	223.1	0.026
107066	OO1	116	0.005
107066	LDA2	304.6	0.023
107066	M1	103	0.003
107066	J1	292.4	0.004
107066	RHO1	293.3	0.001
107066	Q1	158.3	0.005
107066	2Q1	68.2	0.003
107066	P1	149.6	0.009
107066	2SM2	339.8	0.004
107066	M3	70.4	0.002
107066	L2	294.7	0.018
107066	2MK3	189.7	0.014
107066	K2	342.9	0.03
107066	M8	207.7	0.006
107066	MS4	48.6	0.019
107067	M2	318.7	0.564
107067	S2	342.7	0.088
107067	N2	300.6	0.127
107067	K1	164.3	0.048
107067	M4	73.9	0.019
107067	O1	180.8	0.037
107067	M6	74.2	0.033
107067	MK3	168.9	0.015
107067	S4	181.7	0.005
107067	MN4	50	0.011
107067	NU2	270.6	0.026
107067	S6	108.3	0.004
107067	MU2	61.6	0.015
107067	2N2	243.5	0.026
107067	OO1	108.8	0.005
107067	LDA2	316.7	0.031
107067	M1	131.7	0.003
107067	J1	298	0.003
107067	RHO1	90.4	0.002
107067	Q1	191.3	0.005
107067	2Q1	62.7	0.002
107067	P1	151.9	0.006
107067	2SM2	319.8	0.002
107067	M3	194.2	0.001
107067	L2	311.4	0.024
107067	2MK3	201	0.008
107067	K2	347.1	0.029
107067	M8	265.3	0.014
107067	MS4	69.2	0.012
107068	M2	322	0.593
107068	S2	348.8	0.091
107068	N2	304.9	0.131
107068	K1	165	0.053
107068	M4	348.8	0.019
107068	O1	180.6	0.043
107068	M6	96.4	0.045
107068	MK3	160.9	0.016
107068	S4	188.3	0.004
107068	MN4	349.5	0.009
107068	NU2	276.7	0.033
107068	S6	101.2	0.003
107068	MU2	101.1	0.012
107068	2N2	258.3	0.029
107068	OO1	110.4	0.005
107068	LDA2	328.7	0.032
107068	M1	120.7	0.003
107068	J1	277.3	0.003
107068	RHO1	96	0.004
107068	Q1	196.7	0.006
107068	2Q1	70.7	0.002
107068	P1	176.3	0.01
107068	2SM2	262.7	0.003
107068	M3	187.9	0.001
107068	L2	315.1	0.029
107068	2MK3	201.9	0.006
107068	K2	343.4	0.027
107068	M8	291.4	0.003
107068	MS4	76.7	0.008
107069	M2	324.3	0.599
107069	S2	351.7	0.094
107069	N2	308.2	0.132
107069	K1	167.7	0.055
107069	M4	332.5	0.058
107069	O1	182.7	0.048
107069	M6	108.1	0.045
107069	MK3	163.7	0.02
107069	S4	191.2	0.006
107069	MN4	315.3	0.024
107069	NU2	280.3	0.039
107069	S6	109.1	0.002
107069	MU2	132.6	0.009
107069	2N2	270.7	0.029
107069	OO1	123.9	0.003
107069	LDA2	335.3	0.029
107069	M1	90.8	0.005
107069	J1	263.9	0.003
107069	RHO1	101.5	0.006
107069	Q1	193.8	0.005
107069	2Q1	210.2	0.001
107069	P1	193.4	0.014
107069	2SM2	263.6	0.008
107069	M3	88.3	0.001
107069	L2	321.4	0.032
107069	2MK3	207.2	0.011
107069	K2	343.2	0.03
107069	M8	104.4	0.01
107069	MS4	50.9	0.01
107070	M2	210.1	0.096
107070	S2	201.4	0.007
107070	N2	172.9	0.024
107070	K1	84.6	0.006
107070	M4	282.5	0.027
107070	O1	90.6	0.004
107070	M6	48.2	0.029
107070	MK3	155.3	0.004
107070	S4	90.6	0.007
107070	MN4	289.7	0.013
107070	S6	3.7	0.007
107070	2N2	341.3	0.001
107070	OO1	126.5	0.001
107070	M1	129.5	0.003
107070	J1	114.2	0.001
107070	Q1	116.9	0.003
107070	2Q1	179.4	0.002
107070	2SM2	4	0.003
107070	M3	66.9	0.002
107070	L2	249.1	0.009
107070	2MK3	231.8	0.007
107070	M8	43	0.008
107070	MS4	314.2	0.014
107071	M2	263.2	0.125
107071	S2	326.5	0.004
107071	N2	273.2	0.035
107071	K1	115.3	0.004
107071	M4	104.7	0.03
107071	O1	2.9	0.005
107071	M6	12.8	0.025
107071	MK3	271.1	0.009
107071	S4	156.6	0.014
107071	MN4	104.5	0.02
107071	S6	150.5	0.006
107071	2N2	18.4	0.004
107071	OO1	270.9	0.002
107071	M1	233.4	0.003
107071	J1	220.9	0.004
107071	Q1	73.1	0.002
107071	2Q1	117.9	0.003
107071	2SM2	9.2	0.004
107071	M3	248.7	0.001
107071	L2	223.6	0.017
107071	2MK3	257.8	0.003
107071	M8	144.9	0.006
107071	MS4	142.9	0.005
107072	M2	324.7	0.288
107072	S2	348.7	0.026
107072	N2	303.3	0.075
107072	K1	138.9	0.029
107072	M4	160	0.075
107072	O1	51.2	0.009
107072	M6	69.5	0.006
107072	MK3	310.4	0.023
107072	S4	195.7	0.014
107072	MN4	138.2	0.036
107072	S6	140.4	0.01
107072	2N2	2.3	0.011
107072	OO1	355.2	0.004
107072	M1	232	0.007
107072	J1	190.6	0.002
107072	Q1	94.3	0.007
107072	2Q1	105.8	0.004
107072	2SM2	112.1	0.008
107072	M3	261.5	0.005
107072	L2	339.3	0.019
107072	2MK3	352.5	0.01
107072	M8	326	0.01
107072	MS4	177.3	0.022
107073	M2	311	0.722
107073	S2	343.5	0.143
107073	N2	278.2	0.158
107073	K1	149.8	0.064
107073	M4	318.8	0.064
107073	O1	165.5	0.038
107073	M6	96.7	0.025
107073	MK3	174.1	0.012
107073	S4	211.7	0.011
107073	MN4	310.4	0.02
107073	S6	170.6	0.009
107073	2N2	228	0.033
107073	OO1	142.8	0.004
107073	M1	149.9	0.006
107073	J1	194.7	0.003
107073	Q1	157	0.009
107073	2Q1	40.4	0.007
107073	P1	181.9	0.018
107073	2SM2	2.4	0.006
107073	M3	226.1	0.003
107073	L2	333.2	0.033
107073	2MK3	175.7	0.013
107073	K2	6.6	0.043
107073	M8	5	0.014
107073	MS4	22.2	0.026
107074	M2	312.5	0.771
107074	S2	343.7	0.147
107074	N2	279.3	0.163
107074	K1	149.5	0.065
107074	M4	307.9	0.052
107074	O1	167.7	0.038
107074	M6	84.2	0.039
107074	MK3	170.8	0.01
107074	S4	204.8	0.011
107074	MN4	300.2	0.019
107074	S6	180.8	0.008
107074	2N2	240.4	0.032
107074	OO1	142	0.004
107074	M1	159.2	0.006
107074	J1	192.3	0.002
107074	Q1	157.3	0.009
107074	2Q1	37.5	0.006
107074	P1	180.8	0.022
107074	2SM2	339.2	0.007
107074	M3	239.7	0.003
107074	L2	344	0.036
107074	2MK3	176	0.012
107074	K2	3.9	0.043
107074	M8	354	0.009
107074	MS4	20	0.024
107075	M2	314.3	0.806
107075	S2	343.6	0.146
107075	N2	280.6	0.164
107075	K1	150.2	0.063
107075	M4	296.4	0.045
107075	O1	169.1	0.038
107075	M6	81.7	0.053
107075	MK3	166.8	0.008
107075	S4	199.5	0.013
107075	MN4	293.1	0.018
107075	S6	189.4	0.008
107075	2N2	256.7	0.033
107075	OO1	140.5	0.004
107075	M1	172.4	0.005
107075	J1	199.2	0.003
107075	Q1	166.2	0.008
107075	2Q1	30	0.005
107075	P1	175.8	0.022
107075	2SM2	325.2	0.009
107075	M3	262.7	0.002
107075	L2	355.2	0.04
107075	2MK3	173	0.011
107075	K2	358.9	0.044
107075	M8	333.7	0.007
107075	MS4	18.3	0.021
107076	M2	324.5	0.186
107076	S2	330.9	0.034
107076	N2	297.6	0.041
107076	K1	164.8	0.022
107076	M4	353.4	0.015
107076	O1	236.2	0.007
107076	M6	140.6	0.011
107076	MK3	222.1	0.006
107076	S4	127	0.008
107076	MN4	24.3	0.003
107076	S6	127.2	0.004
107076	2N2	235.1	0.016
107076	OO1	310.3	0.004
107076	M1	347.4	0.006
107076	J1	88.8	0.001
107076	Q1	131	0.005
107076	2Q1	22.1	0.009
107076	P1	226.2	0.01
107076	2SM2	265.1	0.005
107076	M3	179	0.002
107076	L2	346.4	0.003
107076	2MK3	124.9	0.007
107076	K2	19.5	0.021
107076	M8	105.6	0.006
107076	MS4	37.8	0.015
107077	M2	322.3	0.295
107077	S2	15.2	0.054
107077	N2	288	0.062
107077	K1	180.7	0.03
107077	M4	5.9	0.022
107077	O1	192.2	0.011
107077	M6	106.8	0.029
107077	MK3	280.9	0.005
107077	S4	123.5	0.006
107077	MN4	299.1	0.014
107077	S6	51.9	0.001
107077	2N2	284.2	0.013
107077	OO1	315.6	0.002
107077	M1	56.6	0.003
107077	Q1	106.2	0.006
107077	2Q1	80	0.005
107077	P1	337.5	0.006
107077	2SM2	168.2	0.003
107077	M3	243.6	0.005
107077	L2	349.5	0.023
107077	2MK3	306.5	0.01
107077	K2	357.5	0.009
107077	M8	156.5	0.002
107077	MS4	76.4	0.013
107078	M2	317.2	0.299
107078	S2	353.6	0.065
107078	N2	290.7	0.065
107078	K1	187	0.038
107078	M4	352.7	0.026
107078	O1	137.7	0.011
107078	M6	106	0.034
107078	MK3	273.7	0.007
107078	S4	112.7	0.01
107078	MN4	299.2	0.021
107078	S6	105.6	0.002
107078	2N2	257.2	0.017
107078	OO1	63.2	0.002
107078	M1	135.1	0.005
107078	J1	30.3	0.004
107078	Q1	8.5	0.001
107078	2Q1	87	0.005
107078	P1	298.1	0.012
107078	2SM2	144.5	0.004
107078	M3	220.7	0.006
107078	L2	0.9	0.023
107078	2MK3	300.6	0.011
107078	K2	53.9	0.016
107078	M8	77.2	0.004
107078	MS4	61.9	0.018
107079	M2	324.2	0.186
107079	S2	10.9	0.039
107079	N2	296.6	0.031
107079	K1	158.6	0.008
107079	M4	18.5	0.02
107079	O1	177.6	0.018
107079	M6	122.8	0.017
107079	MK3	241.8	0.014
107079	S4	161.8	0.005
107079	MN4	319.9	0.012
107079	S6	131.4	0.005
107079	2N2	359.5	0.006
107079	OO1	141.4	0.002
107079	M1	122.6	0.005
107079	J1	60.5	0.001
107079	Q1	208.3	0.005
107079	2Q1	273.2	0.006
107079	2SM2	341.9	0.006
107079	M3	236	0.006
107079	L2	350.9	0.009
107079	2MK3	275.7	0.012
107079	K2	297.7	0.005
107079	M8	154.4	0.004
107079	MS4	97.7	0.011
107080	M2	328.8	0.212
107080	S2	16.7	0.039
107080	N2	298	0.04
107080	K1	177.9	0.019
107080	M4	4	0.015
107080	O1	197.6	0.011
107080	M6	138.5	0.015
107080	MK3	288.6	0.006
107080	S4	77.3	0.001
107080	MN4	336.8	0.012
107080	S6	149.1	0.004
107080	2N2	299.6	0.004
107080	OO1	202.6	0.001
107080	M1	143.9	0.006
107080	J1	357.5	0.001
107080	Q1	264.9	0.005
107080	2Q1	284.3	0.007
107080	2SM2	16.9	0.01
107080	M3	261.2	0.006
107080	L2	2.5	0.012
107080	2MK3	230.5	0.011
107080	K2	336.7	0.008
107080	M8	342.7	0.003
107080	MS4	16.7	0.004
107081	M2	330.6	0.221
107081	S2	357	0.036
107081	N2	293.4	0.043
107081	K1	196	0.024
107081	M4	345.8	0.018
107081	O1	285.1	0.008
107081	M6	146.2	0.015
107081	MK3	352.5	0.008
107081	S4	317.2	0.002
107081	MN4	345.7	0.011
107081	S6	109.9	0.003
107081	2N2	274.9	0.014
107081	OO1	192.9	0.003
107081	M1	183.1	0.006
107081	J1	177.4	0.004
107081	Q1	292.7	0.004
107081	2Q1	279.2	0.003
107081	2SM2	21.3	0.007
107081	M3	256.8	0.008
107081	L2	35.2	0.014
107081	2MK3	191.2	0.017
107081	K2	27.7	0.022
107081	M8	344.7	0.005
107081	MS4	350.9	0.018
107082	M2	48.8	0.935
107082	S2	109.8	0.089
107082	N2	5.3	0.162
107082	K1	130.1	0.064
107082	M4	327.7	0.136
107082	O1	117.4	0.048
107082	M6	339.6	0.064
107082	MK3	66.5	0.016
107082	S4	287.5	0.007
107082	MN4	273.2	0.057
107082	S6	34.4	0.002
107082	2N2	18.1	0.032
107082	OO1	280.7	0.001
107082	M1	217.9	0.003
107082	Q1	77.3	0.01
107082	P1	157.1	0.015
107082	2SM2	319	0.014
107082	M3	312.5	0.004
107082	L2	80.3	0.075
107082	2MK3	109.4	0.017
107082	K2	161.9	0.012
107082	M8	282.2	0.033
107082	MS4	5.4	0.017
107083	M2	58.3	1.183
107083	S2	111.8	0.113
107083	N2	11.4	0.223
107083	K1	134.7	0.073
107083	M4	332.4	0.169
107083	O1	119.4	0.059
107083	M6	41.4	0.081
107083	MK3	122.6	0.012
107083	S4	312.9	0.009
107083	MN4	271.1	0.061
107083	S6	232.6	0.003
107083	2N2	29.9	0.03
107083	M1	169.8	0.004
107083	J1	163.9	0.003
107083	Q1	94.1	0.013
107083	P1	156	0.031
107083	2SM2	332.6	0.009
107083	M3	352	0.004
107083	L2	93.1	0.114
107083	2MK3	156.8	0.016
107083	K2	140	0.023
107083	M8	324.8	0.042
107083	MS4	12.1	0.014
107084	M2	64.3	1.256
107084	S2	103.2	0.126
107084	N2	16.4	0.236
107084	K1	142.9	0.084
107084	M4	336.5	0.095
107084	O1	124.3	0.069
107084	M6	74.8	0.16
107084	MK3	178.9	0.019
107084	S4	353.2	0.004
107084	MN4	282.7	0.031
107084	S6	252.7	0.002
107084	2N2	15.2	0.015
107084	OO1	150.5	0.002
107084	M1	155.6	0.003
107084	J1	221.7	0.002
107084	Q1	94.6	0.017
107084	2Q1	262.2	0.002
107084	P1	154.1	0.027
107084	2SM2	44.9	0.002
107084	M3	33.4	0.004
107084	L2	107.7	0.119
107084	2MK3	171	0.018
107084	K2	104.2	0.028
107084	M8	349.3	0.025
107084	MS4	315.9	0.009
107085	M2	55.9	1.221
107085	S2	111.7	0.13
107085	N2	17.3	0.208
107085	K1	139.4	0.071
107085	M4	75	0.043
107085	O1	124.6	0.057
107085	M6	50.8	0.154
107085	S4	316.8	0.015
107085	NU2	22.5	0.04
107085	S6	77.4	0.009
107085	2N2	338.9	0.028
107085	OO1	154.1	0.002
107085	LDA2	81.7	0.009
107085	M1	131.9	0.004
107085	J1	146.7	0.005
107085	RHO1	118.2	0.002
107085	Q1	117.1	0.011
107085	T2	109.3	0.008
107085	R2	113.9	0.001
107085	2Q1	109.8	0.001
107085	P1	138.2	0.024
107085	L2	17.4	0.03
107085	K2	116.2	0.035
107085	M8	82.5	0.03
107086	M2	64	1.483
107086	S2	98.6	0.187
107086	N2	27.3	0.269
107086	K1	150.9	0.089
107086	M4	196.9	0.063
107086	O1	137.3	0.072
107086	M6	115.7	0.051
107086	S4	98.3	0.007
107086	NU2	32.2	0.052
107086	S6	295.6	0.004
107086	2N2	350.6	0.036
107086	OO1	164.4	0.003
107086	LDA2	80	0.01
107086	M1	144	0.005
107086	J1	157.6	0.006
107086	RHO1	131.4	0.003
107086	Q1	130.5	0.014
107086	T2	97.1	0.011
107086	R2	100	0.001
107086	2Q1	123.8	0.002
107086	P1	149.8	0.029
107086	L2	27.3	0.039
107086	K2	101.4	0.051
107086	M8	130.8	0.055
107087	M2	70.4	1.565
107087	S2	104.6	0.212
107087	N2	33.3	0.294
107087	K1	157.6	0.106
107087	M4	231.6	0.078
107087	O1	140.2	0.085
107087	M6	128.1	0.082
107087	S4	173.6	0.004
107087	NU2	38.3	0.057
107087	S6	228.2	0.004
107087	2N2	356.2	0.039
107087	OO1	174.8	0.004
107087	LDA2	86.2	0.011
107087	M1	148.8	0.006
107087	J1	166.2	0.007
107087	RHO1	132.7	0.003
107087	Q1	131.5	0.017
107087	T2	103.2	0.012
107087	R2	106	0.002
107087	2Q1	122.9	0.002
107087	P1	156.2	0.035
107087	L2	33.3	0.042
107087	K2	107.4	0.058
107087	M8	147.4	0.034
107088	M2	24.1	0.79
107088	S2	70.8	0.098
107088	N2	348.7	0.137
107088	K1	121.8	0.043
107088	M4	200	0.158
107088	O1	98.5	0.03
107088	M6	51	0.056
107088	S4	350.4	0.004
107088	NU2	353.5	0.027
107088	S6	192.1	0.004
107088	2N2	313.5	0.018
107088	OO1	145	0.001
107088	LDA2	45.7	0.006
107088	M1	110.1	0.002
107088	J1	133.3	0.002
107088	RHO1	88.5	0.001
107088	Q1	86.9	0.006
107088	T2	68.9	0.006
107088	R2	72.7	0.001
107088	2Q1	75.3	0.001
107088	P1	119.9	0.014
107088	L2	348.8	0.02
107088	K2	74.6	0.027
107088	M8	103.5	0.038
107089	M2	33.1	0.894
107089	S2	65.9	0.12
107089	N2	354.7	0.18
107089	K1	129.5	0.048
107089	M4	190.2	0.134
107089	O1	105.4	0.035
107089	M6	20.3	0.086
107089	S4	141.9	0.005
107089	NU2	359.8	0.035
107089	S6	26.4	0.002
107089	2N2	316.3	0.024
107089	OO1	153.4	0.002
107089	LDA2	48.2	0.006
107089	M1	117.4	0.002
107089	J1	141.4	0.003
107089	RHO1	95.1	0.001
107089	Q1	93.4	0.007
107089	T2	64.5	0.007
107089	R2	67.2	0.001
107089	2Q1	81.5	0.001
107089	P1	127.6	0.016
107089	L2	354.7	0.026
107089	K2	68.5	0.033
107089	M8	124.3	0.003
107090	M2	65.6	1.78
107090	S2	115.7	0.25
107090	N2	32.8	0.336
107090	K1	150.7	0.123
107090	M4	307.4	0.02
107090	O1	132.8	0.085
107090	M6	51.4	0.142
107090	S4	355	0.015
107090	NU2	37.2	0.065
107090	S6	19.2	0.012
107090	2N2	0.1	0.045
107090	OO1	168.4	0.004
107090	LDA2	88.8	0.012
107090	M1	141.7	0.006
107090	J1	159.5	0.007
107090	RHO1	125.1	0.003
107090	Q1	123.9	0.016
107090	T2	113.6	0.015
107090	R2	117.7	0.002
107090	2Q1	115.1	0.002
107090	P1	149.2	0.041
107090	L2	32.9	0.048
107090	K2	119.7	0.068
107090	M8	246.2	0.025
107091	M2	68.9	2.474
107091	S2	113.3	0.321
107091	N2	33.8	0.464
107091	K1	150.9	0.163
107091	M4	207.3	0.139
107091	O1	130.5	0.125
107091	M6	69.5	0.191
107091	S4	87	0.002
107091	NU2	38.5	0.09
107091	S6	290.3	0.011
107091	2N2	358.8	0.062
107091	OO1	171.2	0.005
107091	LDA2	89.5	0.017
107091	M1	140.7	0.009
107091	J1	161	0.01
107091	RHO1	121.8	0.005
107091	Q1	120.4	0.024
107091	T2	111.5	0.019
107091	R2	115.1	0.003
107091	2Q1	110.3	0.003
107091	P1	149.3	0.054
107091	L2	33.9	0.066
107091	K2	116.9	0.087
107091	M8	166.2	0.059
107092	M2	72.1	2.494
107092	S2	118	0.443
107092	N2	40.1	0.483
107092	K1	156.4	0.181
107092	M4	242.6	0.258
107092	O1	140.1	0.134
107092	M6	43.6	0.115
107092	S4	357.3	0.008
107092	NU2	44.4	0.094
107092	S6	14.4	0.014
107092	2N2	8.2	0.064
107092	OO1	172.6	0.006
107092	LDA2	93.4	0.017
107092	M1	148.2	0.01
107092	J1	164.5	0.011
107092	RHO1	133.1	0.005
107092	Q1	132	0.026
107092	T2	116.1	0.026
107092	R2	119.9	0.004
107092	2Q1	123.9	0.003
107092	P1	155.1	0.06
107092	L2	40.2	0.069
107092	K2	121.7	0.12
107092	M8	167.3	0.02
107093	M2	71.8	2.539
107093	S2	114.4	0.277
107093	N2	40.7	0.365
107093	K1	147.8	0.165
107093	M4	251.7	0.117
107093	O1	129.7	0.138
107093	M6	58.3	0.26
107093	MK3	196.6	0.036
107093	S4	94.7	0.007
107093	MN4	260.4	0.024
107093	2N2	337.9	0.087
107093	OO1	219.4	0.005
107093	M1	203.8	0.005
107093	J1	128.9	0.008
107093	Q1	121.3	0.022
107093	2Q1	107.7	0.003
107093	P1	157.6	0.046
107093	2SM2	35.6	0.013
107093	M3	12.2	0.006
107093	L2	87.2	0.153
107093	2MK3	165.5	0.06
107093	K2	109.6	0.08
107093	M8	247.4	0.046
107093	MS4	334.2	0.019
107094	M2	71.5	3.033
107094	S2	116	0.34
107094	N2	41.1	0.45
107094	K1	149.6	0.203
107094	M4	280.9	0.137
107094	O1	131.6	0.165
107094	M6	64	0.301
107094	MK3	207.3	0.031
107094	MN4	266.8	0.027
107094	2N2	337.5	0.105
107094	OO1	206.5	0.008
107094	M1	199	0.006
107094	J1	126.5	0.009
107094	Q1	124.9	0.024
107094	2Q1	89.3	0.005
107094	P1	152.8	0.058
107094	2SM2	53.6	0.01
107094	M3	303.9	0.004
107094	L2	85.9	0.171
107094	2MK3	167.2	0.061
107094	K2	110.6	0.094
107094	M8	269.6	0.042
107094	MS4	350.1	0.023
107095	M2	70.2	2.997
107095	S2	117.5	0.34
107095	N2	39.4	0.473
107095	K1	151.8	0.206
107095	M4	305.5	0.111
107095	O1	134.5	0.168
107095	M6	71.3	0.269
107095	MK3	223.9	0.021
107095	S4	266.1	0.007
107095	MN4	259.2	0.017
107095	S6	347.5	0.004
107095	2N2	335.5	0.101
107095	OO1	210.3	0.009
107095	M1	203.1	0.011
107095	J1	130.4	0.006
107095	Q1	135.1	0.025
107095	2Q1	73.2	0.005
107095	P1	148.2	0.057
107095	2SM2	136.6	0.008
107095	L2	80.5	0.149
107095	2MK3	168.9	0.047
107095	K2	107.8	0.084
107095	M8	300.7	0.036
107095	MS4	353.1	0.022
107096	M2	71.6	2.373
107096	S2	121.3	0.333
107096	N2	40.4	0.443
107096	K1	151.7	0.174
107096	M4	305.9	0.148
107096	O1	133.9	0.145
107096	M6	64.5	0.188
107096	S4	43.2	0.006
107096	NU2	44.6	0.086
107096	S6	281.3	0.001
107096	2N2	9.3	0.059
107096	OO1	169.3	0.006
107096	LDA2	94.6	0.017
107096	M1	142.7	0.01
107096	J1	160.5	0.011
107096	RHO1	126.3	0.006
107096	Q1	125.1	0.028
107096	T2	119.2	0.02
107096	R2	123.3	0.003
107096	2Q1	116.3	0.004
107096	P1	150.3	0.058
107096	L2	40.5	0.063
107096	K2	125.3	0.09
107096	M8	258.7	0.038
107097	M2	71.7	2.638
107097	S2	120.3	0.371
107097	N2	40.2	0.489
107097	K1	151.6	0.193
107097	M4	305.4	0.156
107097	O1	134.1	0.161
107097	M6	66.5	0.205
107097	S4	30.1	0.006
107097	NU2	44.5	0.095
107097	S6	184.5	0.002
107097	2N2	8.9	0.065
107097	OO1	169	0.007
107097	LDA2	94.2	0.018
107097	M1	142.8	0.011
107097	J1	160.2	0.013
107097	RHO1	126.6	0.006
107097	Q1	125.3	0.031
107097	T2	118.3	0.022
107097	R2	122.3	0.003
107097	2Q1	116.7	0.004
107097	P1	150.2	0.064
107097	L2	40.3	0.07
107097	K2	124.3	0.101
107097	M8	256.4	0.034
107098	M2	71.9	2.736
107098	S2	119.7	0.377
107098	N2	39.9	0.504
107098	K1	151.3	0.199
107098	M4	310.1	0.159
107098	O1	134.3	0.164
107098	M6	65.3	0.215
107098	S4	17.1	0.007
107098	NU2	44.2	0.098
107098	S6	162.8	0.003
107098	2N2	8	0.067
107098	OO1	168.2	0.007
107098	LDA2	94	0.019
107098	M1	142.7	0.012
107098	J1	159.7	0.013
107098	RHO1	127	0.006
107098	Q1	125.8	0.032
107098	T2	117.7	0.022
107098	R2	121.6	0.003
107098	2Q1	117.4	0.004
107098	P1	149.9	0.066
107098	L2	40	0.072
107098	K2	123.6	0.103
107098	M8	253.8	0.03
107099	M2	70.4	2.565
107099	S2	117	0.352
107099	N2	40.6	0.525
107099	K1	152.9	0.174
107099	M4	225.2	0.066
107099	O1	134.6	0.133
107099	M6	61.5	0.23
107099	S4	57.3	0.009
107099	NU2	44.6	0.102
107099	S6	29	0.004
107099	2N2	10.9	0.07
107099	OO1	171	0.006
107099	LDA2	92	0.018
107099	M1	143.6	0.009
107099	J1	161.9	0.01
107099	RHO1	126.7	0.005
107099	Q1	125.4	0.026
107099	T2	115.1	0.021
107099	R2	118.9	0.003
107099	2Q1	116.4	0.003
107099	P1	151.4	0.057
107099	L2	40.6	0.075
107099	K2	120.8	0.096
107099	M8	164.4	0.038
107100	M2	71.6	3.518
107100	S2	118	0.452
107100	N2	41.3	0.714
107100	K1	154.1	0.228
107100	M4	231.5	0.09
107100	O1	135.1	0.174
107100	M6	62.1	0.317
107100	S4	57.8	0.012
107100	NU2	45.3	0.139
107100	S6	3	0.003
107100	2N2	11	0.095
107100	OO1	173	0.007
107100	LDA2	93.1	0.025
107100	M1	144.5	0.012
107100	J1	163.5	0.014
107100	RHO1	126.9	0.007
107100	Q1	125.6	0.034
107100	T2	116.1	0.027
107100	R2	119.9	0.004
107100	2Q1	116.2	0.005
107100	P1	152.6	0.075
107100	L2	41.3	0.102
107100	K2	121.8	0.123
107100	M8	182.2	0.039
107101	M2	72.3	3.914
107101	S2	119.4	0.471
107101	N2	41.8	0.786
107101	K1	154.2	0.25
107101	M4	296.4	0.16
107101	O1	135.2	0.189
107101	M6	64.7	0.36
107101	S4	44.5	0.016
107101	NU2	45.9	0.152
107101	S6	28.4	0.002
107101	2N2	11.5	0.104
107101	OO1	173	0.008
107101	LDA2	94.1	0.027
107101	M1	144.6	0.013
107101	J1	163.5	0.015
107101	RHO1	127.1	0.007
107101	Q1	125.8	0.037
107101	T2	117.4	0.028
107101	R2	121.3	0.004
107101	2Q1	116.4	0.005
107101	P1	152.7	0.083
107101	L2	41.9	0.112
107101	K2	123.2	0.128
107101	M8	240	0.033
107102	M2	75.1	3.323
107102	S2	90.3	0.468
107102	N2	66.8	0.645
107102	K1	149.5	0.197
107102	M4	186.3	0.154
107102	O1	154	0.174
107102	M6	72.1	0.359
107102	S4	178.2	0.008
107102	NU2	67.9	0.125
107102	S6	36	0.009
107102	2N2	58.7	0.086
107102	OO1	144.9	0.007
107102	LDA2	82.1	0.023
107102	M1	151.7	0.012
107102	J1	147.2	0.014
107102	RHO1	155.9	0.007
107102	Q1	156.2	0.034
107102	T2	90.2	0.028
107102	R2	90.3	0.004
107102	2Q1	158.5	0.005
107102	P1	149.4	0.065
107102	L2	83.2	0.093
107102	K2	90.3	0.127
107102	M8	295.2	0.022
107103	M2	74.7	3.756
107103	S2	95.3	0.535
107103	N2	63.6	0.729
107103	K1	149.2	0.229
107103	M4	206.6	0.153
107103	O1	150	0.189
107103	M6	69.2	0.394
107103	S4	355.5	0.008
107103	NU2	65.2	0.141
107103	S6	43.3	0.012
107103	2N2	52.7	0.097
107103	OO1	148.3	0.008
107103	LDA2	84.2	0.026
107103	M1	149.5	0.013
107103	J1	148.8	0.015
107103	RHO1	150.3	0.007
107103	Q1	150.3	0.037
107103	T2	95.2	0.032
107103	R2	95.3	0.004
107103	2Q1	150.8	0.005
107103	P1	149.1	0.076
107103	L2	85.7	0.105
107103	K2	95.3	0.146
107103	M8	124.1	0.014
107104	M2	74.9	3.931
107104	S2	94.3	0.555
107104	N2	64.4	0.763
107104	K1	150.5	0.234
107104	M4	192.9	0.214
107104	O1	150.8	0.192
107104	M6	64.7	0.397
107104	S4	313.2	0.012
107104	NU2	65.9	0.148
107104	S6	45.5	0.019
107104	2N2	54.1	0.101
107104	OO1	150.1	0.008
107104	LDA2	83.8	0.028
107104	M1	150.6	0.014
107104	J1	150.3	0.015
107104	RHO1	150.9	0.007
107104	Q1	150.9	0.037
107104	T2	94.2	0.033
107104	R2	94.3	0.004
107104	2Q1	151.1	0.005
107104	P1	150.4	0.077
107104	L2	85.2	0.11
107104	K2	94.3	0.151
107104	M8	127.6	0.06
107105	M2	78.1	2.681
107105	S2	119.1	0.297
107105	N2	52.1	0.402
107105	K1	156.5	0.175
107105	M4	335.6	0.139
107105	O1	136	0.14
107105	M6	62.9	0.204
107105	MK3	201.6	0.037
107105	S4	117.7	0.003
107105	MN4	324.7	0.024
107105	2N2	342.7	0.114
107105	OO1	203.7	0.006
107105	M1	200.6	0.005
107105	J1	138.2	0.008
107105	Q1	132.9	0.019
107105	P1	157.8	0.046
107105	2SM2	85.8	0.007
107105	M3	259.4	0.008
107105	L2	88.8	0.168
107105	2MK3	167.3	0.059
107105	K2	113.6	0.102
107105	M8	312.5	0.059
107105	MS4	29.5	0.024
107106	M2	78.1	3.137
107106	S2	119.5	0.342
107106	N2	52	0.466
107106	K1	156	0.202
107106	M4	343.9	0.133
107106	O1	136.4	0.162
107106	M6	65.9	0.247
107106	MK3	203.5	0.044
107106	S4	118.9	0.004
107106	MN4	332.9	0.021
107106	2N2	341.7	0.132
107106	OO1	213.2	0.006
107106	M1	200.8	0.005
107106	J1	144.4	0.01
107106	Q1	132.7	0.021
107106	P1	157	0.055
107106	2SM2	93.5	0.01
107106	M3	267.8	0.008
107106	L2	90.7	0.199
107106	2MK3	169.2	0.072
107106	K2	110.7	0.115
107106	M8	316.3	0.057
107106	MS4	34.9	0.021
107107	M2	77.6	3.313
107107	S2	119.6	0.369
107107	N2	50.1	0.508
107107	K1	156.9	0.209
107107	M4	345.8	0.125
107107	O1	137.8	0.17
107107	M6	59.5	0.297
107107	MK3	203.2	0.042
107107	MN4	315.9	0.022
107107	S6	264.8	0.004
107107	2N2	338.1	0.136
107107	OO1	223.3	0.009
107107	M1	205.2	0.008
107107	J1	144.3	0.009
107107	Q1	138.3	0.023
107107	2Q1	115.4	0.005
107107	P1	146.8	0.062
107107	2SM2	136.9	0.009
107107	M3	270.6	0.01
107107	L2	90.2	0.19
107107	2MK3	169	0.067
107107	K2	110.6	0.12
107107	M8	338.2	0.023
107107	MS4	30.9	0.023
107108	M2	79.6	3.361
107108	S2	125.3	0.386
107108	N2	56.5	0.523
107108	K1	155	0.212
107108	M4	74	0.213
107108	O1	134.3	0.164
107108	M6	62.9	0.401
107108	MK3	189.8	0.086
107108	S4	225.2	0.008
107108	MN4	49.9	0.073
107108	2N2	336.7	0.132
107108	OO1	212.5	0.008
107108	M1	200.6	0.01
107108	J1	131.6	0.009
107108	Q1	134.4	0.029
107108	2Q1	165.3	0.003
107108	P1	150.9	0.059
107108	2SM2	8.8	0.007
107108	M3	260.2	0.02
107108	L2	85.1	0.222
107108	2MK3	162.6	0.109
107108	K2	125.4	0.121
107108	M8	41.3	0.039
107108	MS4	136	0.058
107109	M2	79.3	4.134
107109	S2	124.9	0.474
107109	N2	56.7	0.638
107109	K1	155.5	0.259
107109	M4	72.7	0.252
107109	O1	134.6	0.2
107109	M6	62.8	0.504
107109	MK3	190	0.105
107109	S4	224.2	0.01
107109	MN4	49.6	0.087
107109	2N2	336.4	0.163
107109	OO1	215.5	0.01
107109	M1	202.2	0.012
107109	J1	130.1	0.011
107109	Q1	134.7	0.034
107109	P1	150.9	0.07
107109	2SM2	14.1	0.009
107109	M3	261.4	0.024
107109	L2	85.1	0.28
107109	2MK3	162.9	0.135
107109	K2	125.7	0.149
107109	M8	55.1	0.044
107109	MS4	134.2	0.066
107110	M2	79.3	4.373
107110	S2	124.7	0.502
107110	N2	56.8	0.668
107110	K1	155.6	0.272
107110	M4	66.2	0.228
107110	O1	134.9	0.212
107110	M6	62.7	0.543
107110	MK3	190.8	0.107
107110	S4	230.5	0.01
107110	MN4	48.1	0.083
107110	2N2	336.1	0.171
107110	OO1	215.8	0.011
107110	M1	204.9	0.013
107110	J1	132.9	0.011
107110	Q1	135.7	0.035
107110	P1	149.6	0.072
107110	2SM2	13.6	0.008
107110	M3	261.9	0.023
107110	L2	85.3	0.297
107110	2MK3	163.7	0.14
107110	K2	126.7	0.157
107110	M8	32.2	0.031
107110	MS4	132.2	0.061
107111	M2	81.9	2.009
107111	S2	128.6	0.231
107111	N2	45.9	0.351
107111	K1	160.8	0.118
107111	M4	94.9	0.045
107111	O1	144.7	0.092
107111	M6	74	0.282
107111	S4	254.3	0.002
107111	NU2	50.8	0.068
107111	S6	0.4	0.011
107111	2N2	10	0.047
107111	OO1	176.8	0.004
107111	LDA2	103.5	0.014
107111	M1	152.7	0.007
107111	J1	168.8	0.007
107111	RHO1	137.7	0.003
107111	Q1	136.6	0.018
107111	T2	126.7	0.014
107111	R2	130.5	0.002
107111	2Q1	128.7	0.002
107111	P1	159.5	0.039
107111	L2	46	0.05
107111	K2	132.4	0.063
107111	M8	23.9	0.033
107112	M2	81.9	2.22
107112	S2	129.9	0.26
107112	N2	45.6	0.397
107112	K1	159.5	0.131
107112	M4	128.6	0.064
107112	O1	142	0.101
107112	M6	70.1	0.317
107112	S4	252.8	0.008
107112	NU2	50.5	0.077
107112	S6	353.4	0.009
107112	2N2	9.4	0.053
107112	OO1	177	0.004
107112	LDA2	104.1	0.016
107112	M1	150.7	0.007
107112	J1	168.2	0.008
107112	RHO1	134.4	0.004
107112	Q1	133.2	0.02
107112	T2	127.9	0.015
107112	R2	131.8	0.002
107112	2Q1	124.6	0.003
107112	P1	158.1	0.043
107112	L2	45.7	0.057
107112	K2	133.7	0.071
107112	M8	42.5	0.031
107113	M2	82.3	2.259
107113	S2	128.8	0.271
107113	N2	45.9	0.409
107113	K1	159.5	0.136
107113	M4	129.7	0.075
107113	O1	138.6	0.106
107113	M6	66.4	0.312
107113	S4	236.4	0.004
107113	NU2	50.8	0.079
107113	S6	337.4	0.008
107113	2N2	9.6	0.054
107113	OO1	180.4	0.005
107113	LDA2	103.8	0.016
107113	M1	149	0.008
107113	J1	169.9	0.008
107113	RHO1	129.6	0.004
107113	Q1	128.1	0.021
107113	T2	126.8	0.016
107113	R2	130.6	0.002
107113	2Q1	117.8	0.003
107113	P1	157.9	0.045
107113	L2	46	0.059
107113	K2	132.5	0.074
107113	M8	73.5	0.025
107114	M2	274.1	1.801
107114	S2	307.1	0.388
107114	N2	263	0.362
107114	K1	189	0.595
107114	M4	165.7	0.169
107114	O1	159.4	0.321
107114	M6	284.1	0.172
107114	MK3	99.3	0.112
107114	S4	46.9	0.005
107114	MN4	151.5	0.083
107114	S6	46.5	0.005
107114	2N2	148.7	0.056
107114	OO1	263.2	0.097
107114	M1	176.1	0.017
107114	J1	216.9	0.034
107114	Q1	172.4	0.057
107114	2Q1	269.1	0.019
107114	P1	187.9	0.169
107114	2SM2	151.8	0.02
107114	M3	174.4	0.036
107114	L2	274.6	0.125
107114	2MK3	87.2	0.093
107114	K2	263.9	0.118
107114	M8	188.6	0.045
107114	MS4	219.3	0.068
107115	M2	274.2	1.977
107115	S2	307.6	0.423
107115	N2	263.3	0.395
107115	K1	189.3	0.649
107115	M4	163.5	0.181
107115	O1	160.5	0.348
107115	M6	283.9	0.19
107115	MK3	98.5	0.118
107115	S4	50.6	0.005
107115	MN4	149.5	0.09
107115	S6	46.3	0.006
107115	2N2	147.6	0.063
107115	OO1	264.7	0.109
107115	M1	179.4	0.019
107115	J1	219.2	0.036
107115	Q1	173	0.065
107115	2Q1	266.8	0.02
107115	P1	188.2	0.185
107115	2SM2	149.6	0.022
107115	M3	173.8	0.037
107115	L2	274.5	0.139
107115	2MK3	88.6	0.099
107115	K2	263	0.129
107115	M8	186.2	0.05
107115	MS4	217.1	0.074
107116	M2	274.3	2.089
107116	S2	307.9	0.444
107116	N2	263.5	0.416
107116	K1	189.5	0.686
107116	M4	163.1	0.194
107116	O1	160.6	0.367
107116	M6	283.7	0.201
107116	MK3	98.5	0.125
107116	S4	54	0.003
107116	MN4	148.7	0.095
107116	S6	44.6	0.006
107116	2N2	144.8	0.067
107116	OO1	265.3	0.114
107116	M1	180.5	0.02
107116	J1	220.8	0.036
107116	Q1	172.8	0.07
107116	2Q1	269.4	0.023
107116	P1	188.5	0.196
107116	2SM2	149.1	0.024
107116	M3	175.6	0.038
107116	L2	274.8	0.149
107116	2MK3	90	0.104
107116	K2	261.6	0.136
107116	M8	185.3	0.055
107116	MS4	216.6	0.08
107117	M2	274.4	2.177
107117	S2	308.3	0.458
107117	N2	263.7	0.431
107117	K1	189.6	0.712
107117	M4	163.7	0.207
107117	O1	160.4	0.383
107117	M6	283.8	0.209
107117	MK3	99.2	0.131
107117	S4	57.5	0.003
107117	MN4	148.7	0.1
107117	S6	42.5	0.006
107117	2N2	142.1	0.071
107117	OO1	265.6	0.12
107117	M1	180	0.02
107117	J1	221.4	0.035
107117	Q1	172.2	0.073
107117	2Q1	272.8	0.027
107117	P1	188.4	0.205
107117	2SM2	150.9	0.025
107117	M3	179.2	0.04
107117	L2	275.6	0.158
107117	2MK3	91.9	0.108
107117	K2	260.1	0.143
107117	M8	184.8	0.06
107117	MS4	217	0.086
107118	M2	274.4	2.25
107118	S2	308.7	0.47
107118	N2	264	0.444
107118	K1	189.7	0.732
107118	M4	164.9	0.22
107118	O1	160.1	0.397
107118	M6	284	0.215
107118	MK3	100.6	0.136
107118	S4	65.9	0.003
107118	MN4	149.5	0.104
107118	S6	49.6	0.004
107118	2N2	140.2	0.075
107118	OO1	265.4	0.127
107118	M1	178.9	0.021
107118	J1	220.9	0.035
107118	Q1	172.1	0.075
107118	2Q1	276.5	0.031
107118	P1	188.1	0.21
107118	2SM2	154.8	0.025
107118	M3	183.7	0.041
107118	L2	276.6	0.166
107118	2MK3	94	0.113
107118	K2	259.5	0.151
107118	M8	184	0.064
107118	MS4	217.5	0.091
107119	M2	274.6	2.313
107119	S2	309	0.481
107119	N2	264.3	0.454
107119	K1	189.7	0.754
107119	M4	166.2	0.233
107119	O1	159.8	0.408
107119	M6	284.4	0.218
107119	MK3	102.2	0.14
107119	S4	73.6	0.004
107119	MN4	150.7	0.108
107119	S6	61.3	0.004
107119	2N2	139.6	0.079
107119	OO1	265	0.132
107119	M1	177.6	0.022
107119	J1	220.9	0.035
107119	Q1	172.3	0.076
107119	2Q1	278.3	0.034
107119	P1	188.4	0.215
107119	2SM2	158.3	0.026
107119	M3	188.1	0.043
107119	L2	277.1	0.173
107119	2MK3	95.4	0.119
107119	K2	259	0.158
107119	M8	183.2	0.069
107119	MS4	217.8	0.096
107120	M2	274.6	2.363
107120	S2	308.2	0.492
107120	N2	264.4	0.463
107120	K1	189.1	0.764
107120	M4	167.9	0.243
107120	O1	159.1	0.416
107120	M6	284.1	0.217
107120	MK3	103.8	0.141
107120	S4	63.6	0.003
107120	MN4	151.3	0.11
107120	S6	58.2	0.004
107120	2N2	141.7	0.08
107120	OO1	266.4	0.135
107120	M1	176.1	0.024
107120	J1	220.9	0.034
107120	Q1	170.8	0.078
107120	2Q1	276.5	0.036
107120	P1	186	0.222
107120	2SM2	161.9	0.026
107120	M3	188.3	0.043
107120	L2	277.6	0.181
107120	2MK3	98.2	0.124
107120	K2	263.9	0.163
107120	M8	183.8	0.07
107120	MS4	220.2	0.102
107121	M2	274.3	2.356
107121	S2	304	0.527
107121	N2	264.5	0.459
107121	K1	181.9	0.697
107121	M4	180.7	0.223
107121	O1	156.1	0.401
107121	M6	281.7	0.178
107121	MK3	124.7	0.131
107121	S4	200.7	0.005
107121	MN4	162.9	0.106
107121	S6	86.3	0.01
107121	2N2	145	0.066
107121	OO1	268.1	0.156
107121	M1	163	0.019
107121	J1	239.4	0.035
107121	Q1	161.2	0.079
107121	2Q1	274.4	0.051
107121	P1	167.3	0.276
107121	2SM2	140.9	0.019
107121	M3	212.9	0.049
107121	L2	275.6	0.184
107121	2MK3	121.7	0.128
107121	K2	290.5	0.173
107121	M8	196.5	0.072
107121	MS4	220.1	0.114
107122	M2	311.2	0.414
107122	S2	345.1	0.102
107122	N2	280.2	0.1
107122	K1	202.7	0.149
107122	M4	260.3	0.006
107122	O1	182.5	0.044
107122	M6	242.8	0.007
107122	MK3	2.7	0.014
107122	S4	275	0.004
107122	MN4	112.4	0.006
107122	NU2	326.3	0.023
107122	S6	208.9	0.001
107122	MU2	160.7	0.013
107122	2N2	270.9	0.023
107122	OO1	198.5	0.013
107122	LDA2	349.5	0.008
107122	M1	198.1	0.007
107122	J1	229	0.019
107122	RHO1	237.5	0.013
107122	Q1	152.7	0.018
107122	2Q1	81.3	0.006
107122	P1	188.9	0.055
107122	2SM2	315.6	0.003
107122	M3	114	0.005
107122	L2	338.8	0.021
107122	2MK3	324.6	0.01
107122	K2	341.8	0.024
107122	M8	350.1	0.003
107122	MS4	240.8	0.016
107123	M2	311.6	0.422
107123	S2	343.9	0.106
107123	N2	280.9	0.1
107123	K1	202.5	0.152
107123	M4	284.9	0.006
107123	O1	177.5	0.045
107123	M6	230.5	0.006
107123	MK3	2.6	0.013
107123	S4	272.8	0.005
107123	MN4	98.7	0.004
107123	NU2	320	0.022
107123	S6	231	0.001
107123	MU2	153.2	0.009
107123	2N2	272.2	0.025
107123	OO1	187.9	0.013
107123	LDA2	356.4	0.008
107123	M1	188.5	0.008
107123	J1	231.5	0.019
107123	RHO1	236.9	0.011
107123	Q1	152.7	0.017
107123	2Q1	78.9	0.006
107123	P1	190.4	0.05
107123	2SM2	300.2	0.003
107123	M3	115.3	0.004
107123	L2	341.2	0.025
107123	2MK3	346.4	0.01
107123	K2	345.5	0.025
107123	M8	335.4	0.002
107123	MS4	241.5	0.015
107124	M2	311.6	0.428
107124	S2	343.7	0.109
107124	N2	282	0.1
107124	K1	201.1	0.152
107124	M4	299.1	0.007
107124	O1	173.6	0.047
107124	M6	222.5	0.007
107124	MK3	8.6	0.011
107124	S4	264.7	0.005
107124	MN4	77.3	0.004
107124	NU2	314.3	0.02
107124	S6	245.5	0.002
107124	MU2	141.9	0.007
107124	2N2	275.3	0.026
107124	OO1	176.4	0.013
107124	LDA2	3.5	0.01
107124	M1	188.7	0.009
107124	J1	231.2	0.016
107124	RHO1	242.1	0.006
107124	Q1	152.3	0.016
107124	2Q1	74.2	0.008
107124	P1	191.6	0.049
107124	2SM2	307	0.003
107124	M3	96.7	0.003
107124	L2	344.7	0.026
107124	2MK3	348.7	0.009
107124	K2	347.9	0.026
107124	M8	297.4	0.002
107124	MS4	236.2	0.013
107125	M2	311.4	0.431
107125	S2	343.4	0.112
107125	N2	282.2	0.1
107125	K1	200.2	0.151
107125	M4	308.8	0.006
107125	O1	171.9	0.05
107125	M6	210.3	0.007
107125	MK3	19.4	0.011
107125	S4	271.1	0.005
107125	MN4	66.3	0.005
107125	NU2	309.3	0.021
107125	MU2	124.8	0.004
107125	2N2	277.9	0.027
107125	OO1	178.9	0.014
107125	LDA2	4.3	0.009
107125	M1	190.3	0.008
107125	J1	234.3	0.016
107125	RHO1	262	0.006
107125	Q1	163.9	0.015
107125	2Q1	82	0.008
107125	P1	191.7	0.048
107125	2SM2	311.7	0.004
107125	M3	88.5	0.002
107125	L2	342.9	0.026
107125	2MK3	353.6	0.008
107125	K2	353.9	0.027
107125	M8	277.7	0.003
107125	MS4	230.8	0.011
107126	M2	310.8	0.432
107126	S2	343.4	0.113
107126	N2	281.8	0.101
107126	K1	199.5	0.151
107126	M4	335.4	0.006
107126	O1	171.4	0.052
107126	M6	189.6	0.006
107126	MK3	28.6	0.01
107126	S4	258.2	0.004
107126	MN4	48	0.004
107126	NU2	302.6	0.02
107126	MU2	92	0.002
107126	2N2	277.1	0.029
107126	OO1	178.1	0.016
107126	LDA2	8.3	0.009
107126	M1	192.2	0.009
107126	J1	235.4	0.015
107126	RHO1	281.1	0.005
107126	Q1	165.6	0.014
107126	2Q1	91.4	0.008
107126	P1	192.9	0.044
107126	2SM2	317	0.004
107126	M3	91.6	0.001
107126	L2	339.9	0.025
107126	2MK3	344.9	0.006
107126	K2	356	0.03
107126	M8	282.9	0.004
107126	MS4	218.7	0.009
107127	M2	310.2	0.431
107127	S2	343	0.114
107127	N2	282.4	0.1
107127	K1	198.8	0.149
107127	M4	333.3	0.006
107127	O1	171.4	0.055
107127	M6	178.5	0.006
107127	MK3	33.3	0.011
107127	S4	234.5	0.003
107127	MN4	53.5	0.004
107127	NU2	301.2	0.021
107127	S6	128.9	0.001
107127	2N2	279.7	0.028
107127	OO1	179.2	0.017
107127	LDA2	6.7	0.008
107127	M1	189.4	0.009
107127	J1	235.9	0.015
107127	RHO1	307.3	0.005
107127	Q1	170.9	0.013
107127	2Q1	91.6	0.01
107127	P1	194.8	0.044
107127	2SM2	323.4	0.004
107127	M3	77.4	0.002
107127	L2	335.9	0.025
107127	2MK3	335.2	0.005
107127	K2	359.8	0.029
107127	M8	280.9	0.004
107127	MS4	208.1	0.009
107128	M2	309.6	0.429
107128	S2	343.1	0.113
107128	N2	282.6	0.099
107128	K1	198.9	0.148
107128	M4	336.2	0.005
107128	O1	173	0.056
107128	M6	157.5	0.005
107128	MK3	43.8	0.01
107128	S4	213.9	0.002
107128	MN4	35	0.004
107128	NU2	298.9	0.019
107128	S6	127.1	0.001
107128	MU2	343.3	0.002
107128	2N2	281.3	0.029
107128	OO1	175.4	0.017
107128	LDA2	356.9	0.009
107128	M1	190.4	0.01
107128	J1	237	0.017
107128	RHO1	307.5	0.008
107128	Q1	183.4	0.015
107128	2Q1	92.8	0.011
107128	P1	198.2	0.04
107128	2SM2	331.3	0.004
107128	M3	106.6	0.001
107128	L2	332.7	0.024
107128	2MK3	300.7	0.005
107128	K2	358.2	0.029
107128	M8	290.6	0.005
107128	MS4	193.6	0.008
107129	M2	308.8	0.427
107129	S2	342.5	0.113
107129	N2	283.2	0.099
107129	K1	199.1	0.147
107129	M4	320.3	0.004
107129	O1	174.4	0.057
107129	M6	145.3	0.007
107129	MK3	59.2	0.01
107129	S4	195.4	0.002
107129	MN4	53.1	0.004
107129	NU2	301.7	0.02
107129	S6	119.9	0.002
107129	MU2	359	0.002
107129	2N2	283.2	0.029
107129	OO1	180	0.017
107129	LDA2	347.3	0.01
107129	M1	188.5	0.01
107129	J1	238.8	0.016
107129	RHO1	296.5	0.009
107129	Q1	187	0.016
107129	2Q1	93.3	0.012
107129	P1	198	0.04
107129	2SM2	336	0.004
107129	M3	90.9	0.002
107129	L2	331.5	0.024
107129	2MK3	287.2	0.004
107129	K2	358.8	0.03
107129	M8	289	0.005
107129	MS4	183.5	0.009
107130	M2	308.4	0.424
107130	S2	342.5	0.112
107130	N2	282.9	0.098
107130	K1	198.7	0.146
107130	M4	316.3	0.003
107130	O1	176.7	0.057
107130	M6	127.9	0.007
107130	MK3	56.3	0.011
107130	S4	178.7	0.004
107130	MN4	48.8	0.004
107130	NU2	299.3	0.02
107130	S6	149.7	0.002
107130	MU2	13.1	0.001
107130	2N2	286.6	0.027
107130	OO1	185.9	0.016
107130	LDA2	345.2	0.012
107130	M1	190.2	0.01
107130	J1	241.3	0.017
107130	RHO1	285.7	0.012
107130	Q1	188.7	0.018
107130	2Q1	82.6	0.012
107130	P1	200.5	0.039
107130	2SM2	338.8	0.004
107130	M3	97.9	0.003
107130	L2	330.7	0.023
107130	2MK3	284.1	0.007
107130	K2	359.3	0.03
107130	M8	286.7	0.007
107130	MS4	175.8	0.009
107131	M2	307.9	0.419
107131	S2	341.6	0.111
107131	N2	283.3	0.097
107131	K1	198.1	0.144
107131	M4	232.9	0.003
107131	O1	177.4	0.059
107131	M6	111.6	0.007
107131	MK3	59.8	0.014
107131	S4	149.9	0.004
107131	MN4	57.1	0.002
107131	NU2	302.4	0.022
107131	S6	131.9	0.002
107131	MU2	127.2	0.001
107131	2N2	290.3	0.022
107131	OO1	182.9	0.015
107131	LDA2	341.7	0.013
107131	M1	183	0.009
107131	J1	246.8	0.018
107131	RHO1	293.4	0.014
107131	Q1	195.4	0.02
107131	2Q1	80.8	0.012
107131	P1	202.3	0.04
107131	2SM2	335.1	0.004
107131	M3	107.9	0.004
107131	L2	333.1	0.024
107131	2MK3	267.2	0.008
107131	K2	0.4	0.031
107131	M8	290.8	0.005
107131	MS4	170.8	0.008
107132	M2	307.5	0.417
107132	S2	340.9	0.109
107132	N2	283	0.094
107132	K1	198.6	0.143
107132	M4	214.6	0.005
107132	O1	179.2	0.06
107132	M6	105.9	0.009
107132	MK3	62.3	0.014
107132	S4	154.8	0.005
107132	MN4	56.4	0.002
107132	NU2	300.4	0.022
107132	S6	165.8	0.002
107132	MU2	135.9	0.003
107132	2N2	289.4	0.02
107132	OO1	191.7	0.014
107132	LDA2	343.1	0.014
107132	M1	183.4	0.009
107132	J1	251.9	0.018
107132	RHO1	288.4	0.016
107132	Q1	196.5	0.021
107132	2Q1	80.5	0.012
107132	P1	203.8	0.039
107132	2SM2	308	0.003
107132	M3	107.6	0.006
107132	L2	333.6	0.022
107132	2MK3	263.1	0.01
107132	K2	359.6	0.031
107132	M8	289.7	0.005
107132	MS4	163.4	0.008
107133	M2	307.2	0.413
107133	S2	340.4	0.107
107133	N2	283.3	0.089
107133	K1	198.5	0.141
107133	M4	201.2	0.009
107133	O1	181.4	0.059
107133	M6	98.7	0.009
107133	MK3	56.6	0.015
107133	S4	132.7	0.005
107133	MN4	86	0.002
107133	NU2	301.8	0.021
107133	S6	186	0.002
107133	MU2	138	0.003
107133	2N2	288.1	0.018
107133	OO1	193.4	0.017
107133	LDA2	337.7	0.014
107133	M1	182.5	0.01
107133	J1	251.4	0.018
107133	RHO1	288.3	0.016
107133	Q1	194.7	0.02
107133	2Q1	78.5	0.011
107133	P1	203.3	0.039
107133	2SM2	294.4	0.003
107133	M3	127.4	0.006
107133	L2	338.1	0.021
107133	2MK3	260.6	0.011
107133	K2	1.3	0.029
107133	M8	300.6	0.004
107133	MS4	159.8	0.008
107134	M2	306.9	0.407
107134	S2	338.9	0.105
107134	N2	282.3	0.087
107134	K1	198.7	0.14
107134	M4	197.8	0.013
107134	O1	181.6	0.058
107134	M6	96.3	0.01
107134	MK3	51.8	0.015
107134	S4	124.5	0.006
107134	MN4	65.2	0.002
107134	NU2	301.8	0.022
107134	S6	210	0.002
107134	MU2	137.2	0.004
107134	2N2	287	0.016
107134	OO1	191.6	0.016
107134	LDA2	333.9	0.015
107134	M1	178	0.01
107134	J1	255.6	0.019
107134	RHO1	281.3	0.015
107134	Q1	194.7	0.019
107134	2Q1	75.2	0.01
107134	P1	203.3	0.038
107134	2SM2	277.5	0.002
107134	M3	130.4	0.008
107134	L2	343.9	0.022
107134	2MK3	264.6	0.011
107134	K2	1	0.029
107134	M8	308.3	0.003
107134	MS4	155.6	0.008
107135	M2	306.6	0.402
107135	S2	338.6	0.102
107135	N2	283.8	0.084
107135	K1	198.8	0.137
107135	M4	200.4	0.016
107135	O1	182.2	0.058
107135	M6	89.1	0.011
107135	MK3	51.3	0.015
107135	S4	123.2	0.008
107135	MN4	114.5	0.002
107135	NU2	306.3	0.02
107135	S6	261.6	0.001
107135	MU2	142.5	0.005
107135	2N2	283.8	0.013
107135	OO1	196.2	0.017
107135	LDA2	335.1	0.015
107135	M1	180	0.011
107135	J1	255.4	0.02
107135	RHO1	272.7	0.014
107135	Q1	188.2	0.017
107135	2Q1	69	0.011
107135	P1	205.3	0.04
107135	2SM2	238	0.003
107135	M3	137.4	0.009
107135	L2	348	0.021
107135	2MK3	263.1	0.011
107135	K2	359.1	0.029
107135	M8	328.2	0.003
107135	MS4	144.4	0.008
107136	M2	306.5	0.397
107136	S2	338.1	0.1
107136	N2	283.6	0.082
107136	K1	198.6	0.136
107136	M4	196.9	0.019
107136	O1	184.2	0.055
107136	M6	83.9	0.011
107136	MK3	49	0.017
107136	S4	123.1	0.009
107136	MN4	129.4	0.002
107136	NU2	312.4	0.019
107136	S6	259.3	0.001
107136	MU2	172.3	0.006
107136	2N2	274.9	0.011
107136	OO1	188.2	0.016
107136	LDA2	332.3	0.014
107136	M1	181.8	0.011
107136	J1	254.4	0.018
107136	RHO1	265.7	0.015
107136	Q1	184.6	0.018
107136	2Q1	63.7	0.009
107136	P1	208.4	0.039
107136	2SM2	232	0.005
107136	M3	142.8	0.011
107136	L2	352.9	0.021
107136	2MK3	271.8	0.01
107136	K2	357.4	0.027
107136	M8	342.2	0.003
107136	MS4	149.5	0.009
107137	M2	306.3	0.392
107137	S2	336.5	0.098
107137	N2	283.6	0.081
107137	K1	198.7	0.134
107137	M4	199.7	0.022
107137	O1	186.2	0.053
107137	M6	90.2	0.011
107137	MK3	50.7	0.018
107137	S4	132.7	0.01
107137	MN4	147.1	0.004
107137	NU2	316.3	0.02
107137	S6	305.5	0.001
107137	MU2	167	0.008
107137	2N2	265.4	0.007
107137	OO1	191.3	0.018
107137	LDA2	331.4	0.013
107137	M1	182.2	0.011
107137	J1	250.6	0.018
107137	RHO1	267.7	0.016
107137	Q1	184.6	0.015
107137	2Q1	51	0.009
107137	P1	207.3	0.04
107137	2SM2	231.2	0.006
107137	M3	144.3	0.011
107137	L2	351.9	0.02
107137	2MK3	275.1	0.009
107137	K2	355.9	0.025
107137	M8	344.8	0.002
107137	MS4	154.7	0.009
107138	M2	306	0.387
107138	S2	334.5	0.096
107138	N2	284.9	0.081
107138	K1	198.7	0.134
107138	M4	202.3	0.022
107138	O1	189.1	0.051
107138	M6	94.4	0.011
107138	MK3	51.2	0.018
107138	S4	129.2	0.009
107138	MN4	151.6	0.006
107138	NU2	321.5	0.02
107138	S6	306	0.002
107138	MU2	176.4	0.007
107138	2N2	245.2	0.007
107138	OO1	190.7	0.017
107138	LDA2	326.6	0.011
107138	M1	181.1	0.011
107138	J1	245.9	0.018
107138	RHO1	258.3	0.016
107138	Q1	180.1	0.015
107138	2Q1	32.9	0.009
107138	P1	205.7	0.04
107138	2SM2	231.6	0.009
107138	M3	147.7	0.012
107138	L2	353.8	0.019
107138	2MK3	282.1	0.007
107138	K2	349.5	0.026
107138	M8	352.2	0.003
107138	MS4	160	0.008
107139	M2	305.9	0.384
107139	S2	332.9	0.094
107139	N2	284.8	0.08
107139	K1	198.7	0.133
107139	M4	201.4	0.025
107139	O1	193.1	0.049
107139	M6	96.2	0.01
107139	MK3	52.4	0.02
107139	S4	135.5	0.01
107139	MN4	154	0.007
107139	NU2	327.8	0.02
107139	S6	12.6	0.002
107139	MU2	179.4	0.007
107139	2N2	236.4	0.006
107139	OO1	196.9	0.02
107139	LDA2	333	0.009
107139	M1	183.5	0.01
107139	J1	242	0.016
107139	RHO1	257.3	0.016
107139	Q1	176.3	0.014
107139	2Q1	23.6	0.009
107139	P1	205.3	0.041
107139	2SM2	231.6	0.01
107139	M3	151.3	0.013
107139	L2	0.9	0.017
107139	2MK3	300.9	0.005
107139	K2	344.7	0.026
107139	M8	5.9	0.003
107139	MS4	168.6	0.01
107140	M2	305.8	0.381
107140	S2	330.9	0.092
107140	N2	284.9	0.08
107140	K1	198.4	0.131
107140	M4	203	0.025
107140	O1	199	0.046
107140	M6	94.7	0.009
107140	MK3	50.4	0.021
107140	S4	138.8	0.008
107140	MN4	154.6	0.009
107140	NU2	328.5	0.02
107140	S6	32.8	0.002
107140	MU2	179	0.008
107140	2N2	210.7	0.006
107140	OO1	200.1	0.021
107140	LDA2	337.6	0.009
107140	M1	185.6	0.009
107140	J1	232.1	0.015
107140	RHO1	251.9	0.016
107140	Q1	172.7	0.013
107140	2Q1	20.5	0.009
107140	P1	203.4	0.043
107140	2SM2	244.6	0.011
107140	M3	161.2	0.013
107140	L2	7.9	0.016
107140	2MK3	324.5	0.005
107140	K2	338.2	0.027
107140	M8	356.9	0.002
107140	MS4	174.6	0.009
107141	M2	305.6	0.379
107141	S2	328.6	0.091
107141	N2	285	0.08
107141	K1	198.5	0.127
107141	M4	204.5	0.027
107141	O1	204.3	0.045
107141	M6	98.7	0.01
107141	MK3	53	0.022
107141	S4	144.4	0.007
107141	MN4	153.4	0.011
107141	NU2	334.8	0.019
107141	S6	30.9	0.003
107141	MU2	170.8	0.008
107141	2N2	196.7	0.005
107141	OO1	203.4	0.02
107141	LDA2	323.5	0.008
107141	M1	181	0.008
107141	J1	220.9	0.015
107141	RHO1	238.6	0.016
107141	Q1	159.7	0.012
107141	2Q1	23.9	0.008
107141	P1	199	0.046
107141	2SM2	243.2	0.01
107141	M3	159.4	0.012
107141	L2	6.7	0.016
107141	2MK3	356.3	0.005
107141	K2	329.6	0.029
107141	M8	356.4	0.002
107141	MS4	175	0.007
107142	M2	305.6	0.375
107142	S2	328.2	0.089
107142	N2	284.3	0.08
107142	K1	198.7	0.125
107142	M4	202.2	0.029
107142	O1	207.3	0.044
107142	M6	99	0.009
107142	MK3	53.6	0.023
107142	S4	153.2	0.006
107142	MN4	154.9	0.012
107142	NU2	338.1	0.018
107142	S6	39.7	0.002
107142	MU2	173.5	0.009
107142	2N2	183.4	0.006
107142	OO1	206.5	0.018
107142	LDA2	315.2	0.007
107142	M1	183	0.006
107142	J1	212	0.014
107142	RHO1	236.3	0.018
107142	Q1	159.1	0.013
107142	2Q1	15.7	0.007
107142	P1	196.4	0.048
107142	2SM2	256	0.011
107142	M3	159.6	0.011
107142	L2	5.6	0.017
107142	2MK3	20.4	0.006
107142	K2	327.1	0.03
107142	M8	21.8	0.002
107142	MS4	185.1	0.007
107143	M2	305.6	0.374
107143	S2	326.7	0.088
107143	N2	283.6	0.078
107143	K1	199.5	0.121
107143	M4	201.5	0.029
107143	O1	213.3	0.044
107143	M6	106.8	0.008
107143	MK3	56.3	0.024
107143	S4	165	0.005
107143	MN4	155.9	0.012
107143	NU2	338.9	0.016
107143	S6	40.4	0.003
107143	MU2	170.9	0.011
107143	2N2	169.3	0.008
107143	OO1	204.8	0.015
107143	LDA2	304.6	0.007
107143	M1	187	0.005
107143	J1	205	0.015
107143	RHO1	229.4	0.017
107143	Q1	142.3	0.013
107143	2Q1	40.4	0.005
107143	P1	193.5	0.049
107143	2SM2	259.3	0.012
107143	M3	159.7	0.01
107143	L2	9.4	0.017
107143	2MK3	27.5	0.007
107143	K2	322.6	0.03
107143	M8	26.5	0.003
107143	MS4	187.2	0.007
107144	M2	305.4	0.371
107144	S2	325.9	0.087
107144	N2	283	0.079
107144	K1	199	0.118
107144	M4	199.3	0.031
107144	O1	215.8	0.046
107144	M6	103.7	0.009
107144	MK3	56.4	0.024
107144	S4	179.8	0.004
107144	MN4	159.5	0.014
107144	NU2	340.5	0.014
107144	S6	36.3	0.003
107144	MU2	176	0.011
107144	2N2	161.6	0.009
107144	OO1	210.9	0.013
107144	LDA2	295.9	0.008
107144	M1	185.5	0.004
107144	J1	194	0.016
107144	RHO1	217.7	0.019
107144	Q1	131.6	0.014
107144	2Q1	43.9	0.005
107144	P1	192.9	0.052
107144	2SM2	265.4	0.013
107144	M3	167.7	0.008
107144	L2	5.3	0.018
107144	2MK3	37.9	0.01
107144	K2	319.9	0.031
107144	M8	26.2	0.003
107144	MS4	196.5	0.009
107145	M2	305.4	0.368
107145	S2	324.7	0.086
107145	N2	283	0.078
107145	K1	198.2	0.116
107145	M4	198.6	0.032
107145	O1	218.9	0.048
107145	M6	100.9	0.008
107145	MK3	58.6	0.024
107145	S4	186.3	0.004
107145	MN4	165.3	0.014
107145	NU2	343.9	0.014
107145	S6	27.4	0.002
107145	MU2	171.1	0.012
107145	2N2	159.4	0.009
107145	OO1	211.8	0.01
107145	LDA2	287.8	0.008
107145	M1	190.9	0.003
107145	J1	187.5	0.018
107145	RHO1	221.1	0.018
107145	Q1	127.9	0.015
107145	2Q1	55.6	0.005
107145	P1	194.4	0.054
107145	2SM2	269.1	0.013
107145	M3	162.9	0.008
107145	L2	8.1	0.019
107145	2MK3	43.2	0.01
107145	K2	313.9	0.029
107145	M8	39.3	0.004
107145	MS4	195.9	0.01
107146	M2	305.4	0.367
107146	S2	322.8	0.086
107146	N2	282.6	0.076
107146	K1	199.6	0.115
107146	M4	196.2	0.033
107146	O1	222.3	0.049
107146	M6	104.9	0.008
107146	MK3	61.5	0.024
107146	S4	207.6	0.004
107146	MN4	167.6	0.013
107146	NU2	340.5	0.011
107146	S6	2.9	0.002
107146	MU2	173.2	0.011
107146	2N2	160.1	0.011
107146	OO1	221	0.009
107146	LDA2	279.3	0.009
107146	M1	166	0.002
107146	J1	183.1	0.02
107146	RHO1	220.9	0.018
107146	Q1	127.1	0.013
107146	2Q1	57	0.006
107146	P1	194.2	0.056
107146	2SM2	275.9	0.012
107146	M3	161.2	0.007
107146	L2	10.5	0.02
107146	2MK3	51.1	0.013
107146	K2	312.3	0.029
107146	M8	39.9	0.004
107146	MS4	200.9	0.011
107147	M2	305.3	0.365
107147	S2	321.8	0.086
107147	N2	282.3	0.074
107147	K1	200.9	0.112
107147	M4	195.9	0.034
107147	O1	225	0.054
107147	M6	106.2	0.009
107147	MK3	64.8	0.024
107147	S4	208.9	0.003
107147	MN4	171.7	0.013
107147	NU2	333.4	0.009
107147	S6	357.4	0.003
107147	MU2	165.9	0.01
107147	2N2	161.3	0.012
107147	OO1	210.9	0.008
107147	LDA2	274.3	0.009
107147	M1	35.1	0.001
107147	J1	179.9	0.02
107147	RHO1	224.4	0.019
107147	Q1	127.6	0.014
107147	2Q1	52.2	0.006
107147	P1	194.6	0.058
107147	2SM2	279.8	0.011
107147	M3	152.7	0.007
107147	L2	9.8	0.021
107147	2MK3	58.2	0.013
107147	K2	304.1	0.029
107147	M8	39.7	0.004
107147	MS4	204.6	0.014
107148	M2	305.3	0.363
107148	S2	321.2	0.085
107148	N2	282.9	0.072
107148	K1	201.9	0.112
107148	M4	193.3	0.034
107148	O1	226.2	0.058
107148	M6	101	0.009
107148	MK3	68.3	0.022
107148	S4	228.8	0.003
107148	MN4	168.6	0.013
107148	NU2	329.5	0.007
107148	S6	7.3	0.003
107148	MU2	161.6	0.009
107148	2N2	160.4	0.011
107148	OO1	196.7	0.005
107148	LDA2	277.6	0.012
107148	M1	24.1	0.002
107148	J1	176.1	0.021
107148	RHO1	224.8	0.019
107148	Q1	136.2	0.015
107148	2Q1	82.1	0.006
107148	P1	194.4	0.057
107148	2SM2	288.5	0.011
107148	M3	169.5	0.006
107148	L2	10.9	0.026
107148	2MK3	62.5	0.014
107148	K2	301.1	0.027
107148	M8	41.9	0.004
107148	MS4	210.9	0.015
107149	M2	305.3	0.362
107149	S2	320.7	0.084
107149	N2	284.1	0.07
107149	K1	202.9	0.113
107149	M4	191.8	0.033
107149	O1	225.9	0.062
107149	M6	105	0.008
107149	MK3	74.2	0.022
107149	S4	254.1	0.003
107149	MN4	178.9	0.012
107149	NU2	315.8	0.007
107149	S6	344.9	0.003
107149	MU2	159.6	0.009
107149	2N2	162.8	0.011
107149	OO1	151.2	0.005
107149	LDA2	279.1	0.013
107149	M1	17.1	0.004
107149	J1	181.4	0.021
107149	RHO1	222.5	0.018
107149	Q1	138.7	0.014
107149	2Q1	90.1	0.008
107149	P1	195	0.055
107149	2SM2	291.2	0.01
107149	M3	162.4	0.005
107149	L2	11	0.031
107149	2MK3	67.1	0.014
107149	K2	296.9	0.028
107149	M8	59.9	0.004
107149	MS4	217.3	0.017
107150	M2	305.5	0.358
107150	S2	321.7	0.085
107150	N2	284.7	0.068
107150	K1	205.2	0.114
107150	M4	191.5	0.032
107150	O1	225.4	0.067
107150	M6	94.3	0.007
107150	MK3	78.5	0.021
107150	S4	247.7	0.003
107150	MN4	190.3	0.012
107150	NU2	299.3	0.007
107150	S6	344	0.002
107150	MU2	141.4	0.009
107150	2N2	163.1	0.011
107150	OO1	137.7	0.006
107150	LDA2	279.1	0.016
107150	M1	20.4	0.005
107150	J1	180.5	0.022
107150	RHO1	219.6	0.016
107150	Q1	133.5	0.014
107150	2Q1	78.5	0.008
107150	P1	194.5	0.053
107150	2SM2	298.6	0.008
107150	M3	176.4	0.005
107150	L2	10.7	0.037
107150	2MK3	67.8	0.014
107150	K2	290.9	0.024
107150	M8	78.4	0.004
107150	MS4	221.7	0.018
107151	M2	306	0.358
107151	S2	322	0.087
107151	N2	286	0.066
107151	K1	207.6	0.117
107151	M4	191.3	0.031
107151	O1	223.6	0.071
107151	M6	95.3	0.007
107151	MK3	87.8	0.021
107151	S4	281	0.003
107151	MN4	187.1	0.012
107151	NU2	287.5	0.008
107151	S6	283.3	0.001
107151	MU2	131.6	0.009
107151	2N2	161	0.011
107151	OO1	128.1	0.008
107151	LDA2	280.9	0.016
107151	M1	28.4	0.006
107151	J1	182.7	0.025
107151	RHO1	221.6	0.014
107151	Q1	135.3	0.012
107151	2Q1	69.9	0.009
107151	P1	191.9	0.05
107151	2SM2	313.9	0.008
107151	M3	193.6	0.003
107151	L2	10.7	0.041
107151	2MK3	71.5	0.013
107151	K2	289.9	0.026
107151	M8	87.8	0.004
107151	MS4	224.2	0.019
107152	M2	306.8	0.357
107152	S2	325.1	0.09
107152	N2	287.8	0.066
107152	K1	210	0.118
107152	M4	191.5	0.03
107152	O1	222.1	0.076
107152	M6	83.4	0.006
107152	MK3	94.7	0.022
107152	S4	304.9	0.003
107152	MN4	186.1	0.012
107152	NU2	280.7	0.01
107152	S6	359.7	0.001
107152	MU2	121.5	0.01
107152	2N2	155.5	0.01
107152	OO1	115.2	0.008
107152	LDA2	284.1	0.017
107152	M1	33	0.007
107152	J1	183.4	0.026
107152	RHO1	225.7	0.015
107152	Q1	133	0.013
107152	2Q1	47.3	0.011
107152	P1	189.4	0.051
107152	2SM2	335.8	0.009
107152	M3	200.2	0.003
107152	L2	9.2	0.043
107152	2MK3	77.4	0.013
107152	K2	295.2	0.024
107152	M8	117.2	0.003
107152	MS4	225.6	0.02
107153	M2	308	0.357
107153	S2	327.6	0.094
107153	N2	288.4	0.063
107153	K1	212.1	0.119
107153	M4	189.3	0.03
107153	O1	219.7	0.08
107153	M6	83.1	0.007
107153	MK3	104.5	0.023
107153	S4	313	0.004
107153	MN4	181.3	0.013
107153	NU2	271.5	0.01
107153	S6	38.9	0.002
107153	MU2	119.7	0.011
107153	2N2	148.6	0.011
107153	OO1	144	0.008
107153	LDA2	292.5	0.015
107153	M1	42.7	0.007
107153	J1	191.1	0.027
107153	RHO1	235.8	0.016
107153	Q1	147.8	0.013
107153	2Q1	28.4	0.015
107153	P1	186	0.052
107153	2SM2	1.8	0.009
107153	M3	206.5	0.005
107153	L2	11	0.042
107153	2MK3	84.2	0.012
107153	K2	302.9	0.023
107153	M8	115	0.003
107153	MS4	231.2	0.021
107154	M2	309.2	0.359
107154	S2	330.5	0.097
107154	N2	288.7	0.064
107154	K1	214.3	0.12
107154	M4	192.6	0.03
107154	O1	218	0.085
107154	M6	78.7	0.008
107154	MK3	111	0.026
107154	S4	308.1	0.004
107154	MN4	169	0.014
107154	NU2	269	0.012
107154	S6	75.6	0.002
107154	MU2	125.5	0.012
107154	2N2	137.9	0.01
107154	OO1	190.2	0.005
107154	LDA2	307.1	0.011
107154	M1	50.9	0.007
107154	J1	201.3	0.027
107154	RHO1	245	0.015
107154	Q1	147.8	0.012
107154	2Q1	21.4	0.017
107154	P1	182.2	0.052
107154	2SM2	15.4	0.009
107154	M3	195.1	0.005
107154	L2	9.7	0.036
107154	2MK3	101.8	0.011
107154	K2	311.8	0.022
107154	M8	100.7	0.003
107154	MS4	232.5	0.019
107155	M2	310.4	0.359
107155	S2	332.2	0.096
107155	N2	289.5	0.068
107155	K1	215.9	0.122
107155	M4	197.3	0.03
107155	O1	216.1	0.085
107155	M6	82	0.008
107155	MK3	110	0.026
107155	S4	296.6	0.004
107155	MN4	160.8	0.015
107155	NU2	278.5	0.015
107155	S6	122.6	0.004
107155	MU2	143	0.013
107155	2N2	133.8	0.012
107155	OO1	225.4	0.004
107155	LDA2	323.5	0.01
107155	M1	54.2	0.005
107155	J1	212.4	0.026
107155	RHO1	249.5	0.014
107155	Q1	153.3	0.011
107155	2Q1	11.2	0.018
107155	P1	181.7	0.051
107155	2SM2	34.1	0.01
107155	M3	184.3	0.005
107155	L2	10.3	0.033
107155	2MK3	115.8	0.01
107155	K2	322.2	0.024
107155	M8	74.3	0.003
107155	MS4	238.5	0.017
107156	M2	312.1	0.362
107156	S2	335	0.094
107156	N2	290.5	0.072
107156	K1	216.8	0.128
107156	M4	198.7	0.03
107156	O1	215.6	0.085
107156	M6	87.7	0.008
107156	MK3	103.4	0.028
107156	S4	277.2	0.002
107156	MN4	150.5	0.016
107156	NU2	281	0.015
107156	S6	129.3	0.005
107156	MU2	159.7	0.012
107156	2N2	134	0.009
107156	OO1	260.1	0.005
107156	LDA2	341	0.011
107156	M1	78.5	0.005
107156	J1	221.9	0.023
107156	RHO1	257.3	0.009
107156	Q1	155.3	0.01
107156	2Q1	8.5	0.018
107156	P1	185.8	0.049
107156	2SM2	41.3	0.009
107156	M3	173.3	0.005
107156	L2	8.4	0.029
107156	2MK3	129.5	0.008
107156	K2	332.9	0.027
107156	M8	82.6	0.004
107156	MS4	245.5	0.015
107157	M2	313.7	0.368
107157	S2	338	0.091
107157	N2	292.5	0.075
107157	K1	219.2	0.134
107157	M4	202.4	0.029
107157	O1	216	0.082
107157	M6	104.1	0.007
107157	MK3	98.3	0.029
107157	S4	283.7	0.002
107157	MN4	142.8	0.017
107157	NU2	285.3	0.016
107157	S6	131.6	0.006
107157	MU2	179.9	0.013
107157	2N2	137.3	0.008
107157	OO1	269	0.012
107157	LDA2	353	0.01
107157	M1	92.5	0.005
107157	J1	225.3	0.018
107157	RHO1	237.1	0.005
107157	Q1	163.7	0.011
107157	2Q1	356.6	0.015
107157	P1	192.5	0.046
107157	2SM2	58.4	0.009
107157	M3	181.6	0.005
107157	L2	6.7	0.028
107157	2MK3	135.3	0.005
107157	K2	332.4	0.032
107157	M8	92.7	0.005
107157	MS4	262.8	0.014
107158	M2	315	0.373
107158	S2	341.4	0.088
107158	N2	293.1	0.077
107158	K1	221.3	0.141
107158	M4	206.1	0.025
107158	O1	215	0.081
107158	M6	111.6	0.008
107158	MK3	95.3	0.031
107158	S4	138.9	0.001
107158	MN4	141.1	0.016
107158	NU2	288.5	0.012
107158	S6	151.4	0.007
107158	MU2	209.2	0.015
107158	2N2	150.5	0.006
107158	OO1	266.6	0.013
107158	LDA2	359.4	0.011
107158	M1	112.8	0.005
107158	J1	230.1	0.014
107158	RHO1	183.4	0.002
107158	Q1	163.7	0.011
107158	2Q1	340.9	0.014
107158	P1	201.9	0.044
107158	2SM2	64.6	0.008
107158	M3	166.3	0.007
107158	L2	6.4	0.026
107158	2MK3	137.8	0.001
107158	K2	334.8	0.036
107158	M8	108.5	0.007
107158	MS4	277.7	0.013
107159	M2	315.2	0.377
107159	S2	344.6	0.087
107159	N2	292.9	0.077
107159	K1	223.6	0.147
107159	M4	218.7	0.02
107159	O1	212.5	0.081
107159	M6	119.4	0.009
107159	MK3	93.8	0.029
107159	S4	130.5	0.002
107159	MN4	140.7	0.013
107159	NU2	291.9	0.009
107159	S6	172.9	0.006
107159	MU2	220.9	0.021
107159	2N2	178.7	0.004
107159	OO1	273.7	0.015
107159	LDA2	350.5	0.012
107159	M1	137.1	0.005
107159	J1	242.8	0.01
107159	RHO1	88.5	0.006
107159	Q1	176.7	0.01
107159	2Q1	332.7	0.015
107159	P1	215.7	0.041
107159	2SM2	67.1	0.005
107159	M3	167.1	0.008
107159	L2	1.4	0.025
107159	2MK3	331.8	0.004
107159	K2	336.9	0.04
107159	M8	123	0.007
107159	MS4	297.8	0.013
107160	M2	314.8	0.379
107160	S2	347.7	0.087
107160	N2	291.9	0.076
107160	K1	226.3	0.155
107160	M4	239.1	0.015
107160	O1	206.5	0.085
107160	M6	108.9	0.008
107160	MK3	94.5	0.024
107160	S4	131.7	0.003
107160	MN4	152.1	0.012
107160	NU2	268.1	0.004
107160	S6	191.7	0.004
107160	MU2	226	0.024
107160	2N2	242.8	0.006
107160	OO1	274.2	0.017
107160	LDA2	337.9	0.015
107160	M1	158.8	0.005
107160	J1	282.1	0.005
107160	RHO1	101.7	0.011
107160	Q1	174.5	0.011
107160	2Q1	328.2	0.015
107160	P1	229.4	0.039
107160	2SM2	66.6	0.002
107160	M3	162.4	0.012
107160	L2	356.2	0.026
107160	2MK3	338.1	0.01
107160	K2	335.5	0.045
107160	M8	119.2	0.007
107160	MS4	309.2	0.013
107161	M2	313	0.378
107161	S2	348	0.084
107161	N2	290.2	0.078
107161	K1	228.7	0.16
107161	M4	265.3	0.015
107161	O1	201	0.087
107161	M6	81.5	0.008
107161	MK3	90.6	0.018
107161	S4	162.2	0.004
107161	MN4	164.7	0.009
107161	NU2	255.3	0.003
107161	S6	226.9	0.002
107161	MU2	224.7	0.026
107161	2N2	270.7	0.009
107161	OO1	277.2	0.019
107161	LDA2	330.6	0.016
107161	M1	186	0.004
107161	J1	336.5	0.005
107161	RHO1	109	0.016
107161	Q1	180	0.009
107161	2Q1	329	0.016
107161	P1	239.2	0.038
107161	2SM2	270.1	0.003
107161	M3	155.6	0.015
107161	L2	353.4	0.025
107161	2MK3	339.7	0.014
107161	K2	332.1	0.048
107161	M8	131.9	0.005
107161	MS4	313.9	0.012
107162	M2	310.6	0.372
107162	S2	347.6	0.082
107162	N2	288.6	0.077
107162	K1	230.9	0.16
107162	M4	278.1	0.018
107162	O1	196.7	0.089
107162	M6	59	0.007
107162	MK3	70.4	0.012
107162	S4	172.5	0.005
107162	MN4	182.2	0.006
107162	NU2	219.1	0.003
107162	S6	225	0.001
107162	MU2	226.6	0.025
107162	2N2	278.5	0.013
107162	OO1	278.2	0.027
107162	LDA2	328.7	0.017
107162	M1	220.3	0.004
107162	J1	355.8	0.006
107162	RHO1	110.5	0.015
107162	Q1	184.3	0.009
107162	2Q1	328.9	0.015
107162	P1	245	0.034
107162	2SM2	276.2	0.006
107162	M3	148.6	0.014
107162	L2	346.6	0.022
107162	2MK3	339.8	0.016
107162	K2	330.6	0.048
107162	M8	162.9	0.003
107162	MS4	310.8	0.011
107163	M2	307.9	0.364
107163	S2	345.8	0.08
107163	N2	284.1	0.078
107163	K1	232	0.156
107163	M4	270.9	0.018
107163	O1	194.9	0.089
107163	M6	37.3	0.006
107163	MK3	31.2	0.009
107163	S4	169.2	0.003
107163	MN4	192.3	0.007
107163	NU2	242.7	0.004
107163	MU2	221.2	0.019
107163	2N2	287.4	0.014
107163	OO1	272.4	0.034
107163	LDA2	327.1	0.015
107163	M1	242	0.007
107163	J1	357.8	0.01
107163	RHO1	113.4	0.019
107163	Q1	180	0.006
107163	2Q1	322.8	0.016
107163	P1	249.3	0.03
107163	2SM2	273.1	0.01
107163	M3	135.9	0.013
107163	L2	340.9	0.023
107163	2MK3	336.5	0.014
107163	K2	328	0.044
107163	M8	197.3	0.005
107163	MS4	296.9	0.011
107164	M2	305.7	0.355
107164	S2	341.6	0.079
107164	N2	278.4	0.076
107164	K1	231.8	0.147
107164	M4	257.9	0.017
107164	O1	193.9	0.091
107164	M6	39.8	0.004
107164	MK3	10.3	0.013
107164	S4	181.1	0.004
107164	MN4	191	0.01
107164	NU2	274.6	0.007
107164	S6	96.4	0.001
107164	MU2	215	0.018
107164	2N2	284.9	0.012
107164	OO1	272.7	0.04
107164	LDA2	329.3	0.013
107164	M1	253	0.008
107164	J1	5.6	0.012
107164	RHO1	115.2	0.021
107164	Q1	176.5	0.007
107164	2Q1	319.5	0.012
107164	P1	251	0.026
107164	2SM2	279.6	0.01
107164	M3	116.7	0.012
107164	L2	331.6	0.026
107164	2MK3	330.9	0.016
107164	K2	323.7	0.042
107164	M8	212.8	0.005
107164	MS4	276.2	0.008
107165	M2	303.8	0.348
107165	S2	339.1	0.077
107165	N2	272.9	0.072
107165	K1	230.4	0.136
107165	M4	244.7	0.016
107165	O1	194.2	0.091
107165	M6	94	0.004
107165	MK3	6.9	0.018
107165	S4	186.8	0.004
107165	MN4	187.6	0.012
107165	NU2	270.4	0.009
107165	S6	177.5	0.001
107165	MU2	220	0.015
107165	2N2	284.3	0.012
107165	OO1	268.9	0.043
107165	LDA2	335.1	0.013
107165	M1	254.3	0.01
107165	J1	12.2	0.015
107165	RHO1	115.5	0.021
107165	Q1	197.1	0.007
107165	2Q1	306	0.009
107165	P1	253.6	0.027
107165	2SM2	280.1	0.012
107165	M3	104.2	0.013
107165	L2	332.9	0.031
107165	2MK3	323.5	0.018
107165	K2	318.6	0.042
107165	M8	215.6	0.006
107165	MS4	242.1	0.007
107166	M2	302.6	0.342
107166	S2	335.7	0.076
107166	N2	268.6	0.068
107166	K1	229.1	0.126
107166	M4	235	0.016
107166	O1	193.2	0.099
107166	M6	111.8	0.006
107166	MK3	13.8	0.021
107166	S4	176.9	0.004
107166	MN4	186.9	0.011
107166	NU2	281.7	0.009
107166	S6	206	0.002
107166	MU2	217.4	0.014
107166	2N2	283.9	0.008
107166	OO1	264.2	0.042
107166	LDA2	338.4	0.013
107166	M1	252.9	0.013
107166	J1	12.1	0.016
107166	RHO1	107.1	0.023
107166	Q1	214.2	0.008
107166	2Q1	289.4	0.009
107166	P1	252.1	0.027
107166	2SM2	286.7	0.014
107166	M3	104.2	0.017
107166	L2	333.7	0.036
107166	2MK3	316	0.025
107166	K2	312.4	0.044
107166	M8	208.3	0.006
107166	MS4	222.4	0.007
107167	M2	301.4	0.332
107167	S2	334	0.073
107167	N2	266	0.065
107167	K1	227.5	0.117
107167	M4	237	0.017
107167	O1	191.7	0.107
107167	M6	120.4	0.009
107167	MK3	20.1	0.023
107167	S4	167.9	0.004
107167	MN4	199.4	0.011
107167	NU2	279.3	0.005
107167	S6	213	0.002
107167	MU2	207	0.011
107167	2N2	300.7	0.006
107167	OO1	250.5	0.031
107167	LDA2	344.3	0.013
107167	M1	249.8	0.014
107167	J1	5.4	0.015
107167	RHO1	106.1	0.022
107167	Q1	217	0.008
107167	2Q1	291.8	0.011
107167	P1	251.9	0.029
107167	2SM2	291.6	0.014
107167	M3	105.7	0.022
107167	L2	337	0.038
107167	2MK3	315.6	0.029
107167	K2	305.7	0.044
107167	M8	201.3	0.008
107167	MS4	228.6	0.006
107168	M2	306.9	0.443
107168	S2	325.1	0.099
107168	N2	279	0.083
107168	K1	178.4	0.155
107168	M4	335.7	0.004
107168	O1	145.1	0.08
107168	M6	307.7	0.013
107168	MK3	6.8	0.013
107168	S4	233.6	0.002
107168	MN4	29.5	0.011
107168	NU2	285.6	0.034
107168	MU2	103.8	0.018
107168	2N2	208.3	0.014
107168	OO1	130.5	0.007
107168	LDA2	297.3	0.015
107168	M1	180.2	0.008
107168	J1	190.1	0.01
107168	RHO1	304.9	0.006
107168	Q1	147.7	0.016
107168	2Q1	252.9	0.008
107168	P1	175.4	0.054
107168	2SM2	146.2	0.006
107168	M3	105	0.006
107168	L2	352.9	0.046
107168	2MK3	35.8	0.01
107168	K2	354	0.037
107168	M8	254.4	0.005
107168	MS4	157.8	0.012
107169	M2	305.3	0.437
107169	S2	327.1	0.101
107169	N2	279.4	0.086
107169	K1	181.4	0.145
107169	M4	234.7	0.001
107169	O1	146.7	0.076
107169	M6	301.4	0.012
107169	MK3	4.9	0.015
107169	S4	253.2	0.002
107169	MN4	30.9	0.009
107169	NU2	279.1	0.03
107169	S6	77.6	0.001
107169	MU2	85.2	0.011
107169	2N2	212.7	0.015
107169	OO1	121.2	0.009
107169	LDA2	296.9	0.016
107169	M1	172.3	0.007
107169	J1	184.4	0.011
107169	RHO1	298.8	0.007
107169	Q1	148.2	0.015
107169	2Q1	259	0.006
107169	P1	175.1	0.056
107169	2SM2	168.7	0.006
107169	M3	107.7	0.005
107169	L2	344.5	0.041
107169	2MK3	27.1	0.009
107169	K2	347	0.04
107169	M8	262.6	0.005
107169	MS4	159.1	0.011
107170	M2	303.6	0.433
107170	S2	328.9	0.102
107170	N2	278.9	0.089
107170	K1	184.8	0.136
107170	M4	200.3	0.005
107170	O1	149	0.071
107170	M6	301.4	0.012
107170	MK3	2.7	0.019
107170	S4	258.2	0.002
107170	MN4	33.8	0.006
107170	NU2	273.5	0.027
107170	S6	67.5	0.001
107170	MU2	59.3	0.008
107170	2N2	213.6	0.015
107170	OO1	110.5	0.01
107170	LDA2	294.2	0.016
107170	M1	160	0.007
107170	J1	184.5	0.012
107170	RHO1	294.9	0.008
107170	Q1	149.9	0.016
107170	2Q1	272.7	0.004
107170	P1	175.6	0.057
107170	2SM2	181.1	0.006
107170	M3	122.6	0.005
107170	L2	334.4	0.037
107170	2MK3	15.9	0.008
107170	K2	342.1	0.042
107170	M8	264.3	0.005
107170	MS4	162.1	0.012
107171	M2	301.9	0.43
107171	S2	330.7	0.102
107171	N2	278.3	0.091
107171	K1	188.4	0.128
107171	M4	196	0.009
107171	O1	152	0.067
107171	M6	300.1	0.011
107171	MK3	3.3	0.023
107171	S4	269.2	0.002
107171	MN4	43.1	0.004
107171	NU2	266.4	0.024
107171	S6	55.6	0.001
107171	MU2	16.2	0.007
107171	2N2	221.9	0.016
107171	OO1	112.1	0.011
107171	LDA2	292.2	0.016
107171	M1	150	0.006
107171	J1	185.3	0.014
107171	RHO1	285.8	0.01
107171	Q1	147.5	0.016
107171	2Q1	301.8	0.002
107171	P1	174.9	0.056
107171	2SM2	200.2	0.006
107171	M3	135.3	0.005
107171	L2	323.6	0.035
107171	2MK3	356.9	0.007
107171	K2	339.2	0.044
107171	M8	266.6	0.004
107171	MS4	171	0.012
107172	M2	300.2	0.429
107172	S2	332.5	0.101
107172	N2	277.7	0.092
107172	K1	192.1	0.121
107172	M4	191.5	0.012
107172	O1	154.8	0.062
107172	M6	299.4	0.01
107172	MK3	5.3	0.027
107172	S4	244.6	0.003
107172	MN4	78.9	0.002
107172	NU2	260.7	0.022
107172	MU2	349.4	0.009
107172	2N2	230	0.018
107172	OO1	119.7	0.013
107172	LDA2	292.4	0.015
107172	M1	135.6	0.005
107172	J1	185.8	0.016
107172	RHO1	272.1	0.009
107172	Q1	144.7	0.018
107172	2Q1	332	0.002
107172	P1	174.2	0.056
107172	2SM2	214.6	0.005
107172	M3	146.6	0.005
107172	L2	314.5	0.035
107172	2MK3	339.2	0.006
107172	K2	336.5	0.046
107172	M8	265.4	0.004
107172	MS4	180.1	0.013
107173	M2	298.7	0.428
107173	S2	333.4	0.099
107173	N2	277.2	0.092
107173	K1	194.9	0.114
107173	M4	185.3	0.015
107173	O1	157.7	0.058
107173	M6	294.7	0.008
107173	MK3	7.7	0.03
107173	S4	233.7	0.003
107173	MN4	126.1	0.003
107173	NU2	254	0.019
107173	S6	239.9	0.001
107173	MU2	337.6	0.013
107173	2N2	238.7	0.02
107173	OO1	120.1	0.015
107173	LDA2	288.7	0.015
107173	M1	119.7	0.004
107173	J1	188.4	0.018
107173	RHO1	255	0.01
107173	Q1	140.7	0.018
107173	2Q1	26.8	0.002
107173	P1	174.7	0.055
107173	2SM2	224.3	0.005
107173	M3	151.5	0.006
107173	L2	306.5	0.038
107173	2MK3	333.5	0.007
107173	K2	333.9	0.047
107173	M8	260.6	0.003
107173	MS4	187.9	0.014
107174	M2	297.4	0.43
107174	S2	334.1	0.097
107174	N2	276.4	0.093
107174	K1	197.2	0.109
107174	M4	183.2	0.018
107174	O1	161.5	0.054
107174	M6	282.1	0.005
107174	MK3	9.5	0.031
107174	S4	212.8	0.004
107174	MN4	143.1	0.004
107174	NU2	255.5	0.018
107174	S6	247.5	0.003
107174	MU2	339.2	0.014
107174	2N2	245	0.021
107174	OO1	115.3	0.016
107174	LDA2	286.2	0.016
107174	M1	93.9	0.003
107174	J1	192.2	0.02
107174	RHO1	247.7	0.012
107174	Q1	138.7	0.018
107174	2Q1	61.4	0.003
107174	P1	176	0.054
107174	2SM2	239	0.004
107174	M3	149.5	0.008
107174	L2	302.4	0.041
107174	2MK3	326	0.009
107174	K2	331.6	0.049
107174	M8	260.6	0.002
107174	MS4	197.9	0.015
107175	M2	296.4	0.434
107175	S2	334	0.095
107175	N2	275.6	0.094
107175	K1	199.4	0.106
107175	M4	180.8	0.022
107175	O1	168.6	0.05
107175	M6	245.3	0.003
107175	MK3	8.8	0.031
107175	S4	192.6	0.005
107175	MN4	151.9	0.004
107175	NU2	260.9	0.017
107175	S6	242.8	0.002
107175	MU2	342.7	0.014
107175	2N2	246.9	0.023
107175	OO1	117.5	0.016
107175	LDA2	285.1	0.017
107175	M1	68.9	0.004
107175	J1	193.9	0.023
107175	RHO1	239.1	0.016
107175	Q1	137.5	0.02
107175	2Q1	71.4	0.006
107175	P1	177.8	0.053
107175	2SM2	265.5	0.004
107175	M3	142	0.008
107175	L2	300.1	0.043
107175	2MK3	323.1	0.01
107175	K2	330.7	0.05
107175	M8	252.7	0.002
107175	MS4	204.8	0.017
107176	M2	295.7	0.438
107176	S2	333.4	0.091
107176	N2	275.4	0.095
107176	K1	200.6	0.104
107176	M4	180.4	0.024
107176	O1	178	0.046
107176	M6	194.6	0.004
107176	MK3	11.5	0.029
107176	S4	180.4	0.006
107176	MN4	154.5	0.005
107176	NU2	271.1	0.016
107176	S6	242.4	0.001
107176	MU2	347.2	0.013
107176	2N2	248	0.026
107176	OO1	116.7	0.018
107176	LDA2	285	0.017
107176	M1	48.4	0.005
107176	J1	196.7	0.024
107176	RHO1	238.7	0.018
107176	Q1	135.3	0.02
107176	2Q1	78.4	0.007
107176	P1	181	0.052
107176	2SM2	285.2	0.004
107176	M3	130.6	0.008
107176	L2	300.7	0.043
107176	2MK3	320.9	0.011
107176	K2	327.8	0.049
107176	M8	232.4	0.002
107176	MS4	209.4	0.019
107177	M2	295.5	0.441
107177	S2	332.7	0.088
107177	N2	275	0.095
107177	K1	201.9	0.104
107177	M4	181.3	0.025
107177	O1	187.2	0.046
107177	M6	190.8	0.007
107177	MK3	16.1	0.027
107177	S4	175.8	0.006
107177	MN4	156	0.005
107177	NU2	281.7	0.015
107177	MU2	351.5	0.011
107177	2N2	247.7	0.028
107177	OO1	123.5	0.02
107177	LDA2	286.1	0.017
107177	M1	29.6	0.005
107177	J1	199.7	0.023
107177	RHO1	239.8	0.02
107177	Q1	132.9	0.02
107177	2Q1	82.5	0.008
107177	P1	183.9	0.05
107177	2SM2	306	0.005
107177	M3	117.2	0.007
107177	L2	303.6	0.044
107177	2MK3	311.8	0.012
107177	K2	325.1	0.048
107177	M8	216.3	0.002
107177	MS4	212.9	0.022
107178	M2	295.4	0.444
107178	S2	331.7	0.085
107178	N2	274.5	0.095
107178	K1	203.2	0.104
107178	M4	183.9	0.027
107178	O1	195.9	0.048
107178	M6	189.3	0.009
107178	MK3	20	0.026
107178	S4	180.5	0.006
107178	MN4	152.2	0.004
107178	NU2	290.9	0.016
107178	MU2	353.4	0.009
107178	2N2	246.3	0.031
107178	OO1	127.5	0.021
107178	LDA2	289	0.019
107178	M1	17.7	0.006
107178	J1	203.6	0.022
107178	RHO1	244.9	0.022
107178	Q1	136.7	0.019
107178	2Q1	81.4	0.009
107178	P1	186.6	0.048
107178	2SM2	321.5	0.006
107178	M3	100	0.007
107178	L2	309.3	0.044
107178	2MK3	306.2	0.012
107178	K2	321.1	0.047
107178	M8	191.6	0.003
107178	MS4	217.4	0.024
107179	M2	295.5	0.447
107179	S2	330.1	0.082
107179	N2	273.5	0.095
107179	K1	205.3	0.105
107179	M4	187	0.026
107179	O1	203.2	0.051
107179	M6	187.5	0.01
107179	MK3	20.8	0.025
107179	S4	183.4	0.006
107179	MN4	144.9	0.003
107179	NU2	297.8	0.018
107179	S6	19.6	0.001
107179	MU2	3.2	0.006
107179	2N2	247.7	0.032
107179	OO1	133.3	0.019
107179	LDA2	288.7	0.02
107179	M1	8.3	0.007
107179	J1	208	0.02
107179	RHO1	245.8	0.023
107179	Q1	135.4	0.019
107179	2Q1	75.3	0.009
107179	P1	189.4	0.046
107179	2SM2	331.4	0.006
107179	M3	91.4	0.008
107179	L2	312.9	0.045
107179	2MK3	301.2	0.011
107179	K2	318.2	0.046
107179	M8	177.6	0.005
107179	MS4	221.3	0.026
107180	M2	295.7	0.448
107180	S2	328.2	0.081
107180	N2	273.2	0.093
107180	K1	208.7	0.106
107180	M4	192.7	0.026
107180	O1	208.6	0.054
107180	M6	187.1	0.011
107180	MK3	20.8	0.024
107180	S4	199.1	0.007
107180	MN4	148.3	0.003
107180	NU2	300.1	0.018
107180	S6	8.2	0.001
107180	MU2	44.8	0.004
107180	2N2	249.2	0.032
107180	OO1	133	0.017
107180	LDA2	290	0.019
107180	M1	3.5	0.007
107180	J1	214.1	0.019
107180	RHO1	248.9	0.023
107180	Q1	138.6	0.018
107180	2Q1	63.2	0.01
107180	P1	191.7	0.045
107180	2SM2	334.7	0.007
107180	M3	84.3	0.008
107180	L2	317.2	0.045
107180	2MK3	289.9	0.011
107180	K2	315	0.045
107180	M8	174.2	0.006
107180	MS4	223.9	0.027
107181	M2	296.1	0.447
107181	S2	326	0.081
107181	N2	273.2	0.09
107181	K1	211.8	0.109
107181	M4	198.5	0.025
107181	O1	212.5	0.058
107181	M6	186	0.011
107181	MK3	18.5	0.021
107181	S4	209.3	0.008
107181	MN4	160.7	0.003
107181	NU2	305.4	0.017
107181	S6	36	0.002
107181	MU2	73.1	0.004
107181	2N2	253.6	0.031
107181	OO1	136.5	0.016
107181	LDA2	293.2	0.018
107181	M1	6	0.007
107181	J1	221.4	0.018
107181	RHO1	249.7	0.023
107181	Q1	144.1	0.017
107181	2Q1	50.8	0.011
107181	P1	194.6	0.043
107181	2SM2	334.7	0.008
107181	M3	79.5	0.007
107181	L2	320.7	0.045
107181	2MK3	276.6	0.011
107181	K2	312.1	0.045
107181	M8	173.1	0.007
107181	MS4	226.5	0.027
107182	M2	296.4	0.444
107182	S2	324.4	0.081
107182	N2	273.9	0.088
107182	K1	214.9	0.113
107182	M4	206.8	0.023
107182	O1	215.3	0.061
107182	M6	184.4	0.011
107182	MK3	13.6	0.02
107182	S4	216.6	0.009
107182	MN4	168	0.003
107182	NU2	313	0.015
107182	S6	39.7	0.002
107182	MU2	91.2	0.005
107182	2N2	260.5	0.029
107182	OO1	138.5	0.013
107182	LDA2	298	0.017
107182	M1	12.9	0.007
107182	J1	232.3	0.018
107182	RHO1	248.1	0.02
107182	Q1	147.3	0.016
107182	2Q1	41.9	0.009
107182	P1	197.4	0.041
107182	2SM2	333.2	0.009
107182	M3	67.5	0.007
107182	L2	324.4	0.045
107182	2MK3	269.2	0.012
107182	K2	309.9	0.044
107182	M8	168.7	0.007
107182	MS4	226	0.027
107183	M2	296.9	0.439
107183	S2	323.5	0.083
107183	N2	275.1	0.087
107183	K1	218	0.117
107183	M4	214.9	0.02
107183	O1	216.9	0.064
107183	M6	183.6	0.01
107183	MK3	10.9	0.019
107183	S4	218.9	0.009
107183	MN4	179.1	0.003
107183	NU2	324.9	0.014
107183	S6	45.2	0.002
107183	MU2	112.1	0.005
107183	2N2	267.7	0.028
107183	OO1	151.3	0.012
107183	LDA2	301.1	0.016
107183	M1	17.6	0.006
107183	J1	244.3	0.019
107183	RHO1	246	0.017
107183	Q1	148.8	0.016
107183	2Q1	41.6	0.008
107183	P1	200.4	0.039
107183	2SM2	332.4	0.008
107183	M3	60.3	0.007
107183	L2	328.3	0.044
107183	2MK3	261.5	0.012
107183	K2	308.2	0.044
107183	M8	171.4	0.007
107183	MS4	223.8	0.026
107184	M2	297.3	0.432
107184	S2	322.5	0.085
107184	N2	276.4	0.087
107184	K1	221.1	0.12
107184	M4	223.6	0.018
107184	O1	216.5	0.067
107184	M6	180.6	0.008
107184	MK3	9.6	0.019
107184	S4	225.5	0.009
107184	MN4	224.1	0.003
107184	NU2	332.8	0.014
107184	S6	0.5	0.002
107184	MU2	136.2	0.004
107184	2N2	272.3	0.027
107184	OO1	187.1	0.009
107184	LDA2	307.9	0.017
107184	M1	21.9	0.005
107184	J1	252.1	0.021
107184	RHO1	246.8	0.015
107184	Q1	154	0.016
107184	2Q1	43.8	0.006
107184	P1	203.2	0.038
107184	2SM2	333.4	0.008
107184	M3	56.5	0.006
107184	L2	333	0.043
107184	2MK3	259.5	0.012
107184	K2	305.6	0.045
107184	M8	167.8	0.007
107184	MS4	219.8	0.025
107185	M2	297.8	0.426
107185	S2	322.3	0.089
107185	N2	276.4	0.088
107185	K1	223.6	0.125
107185	M4	235.2	0.016
107185	O1	215.7	0.07
107185	M6	176.6	0.007
107185	MK3	8.1	0.018
107185	S4	228.3	0.009
107185	MN4	263.1	0.005
107185	NU2	330.1	0.014
107185	S6	322.5	0.001
107185	MU2	138.3	0.005
107185	2N2	277.5	0.024
107185	OO1	227.1	0.009
107185	LDA2	315.7	0.017
107185	M1	18.2	0.005
107185	J1	257.4	0.021
107185	RHO1	256.7	0.011
107185	Q1	160.9	0.013
107185	2Q1	46.4	0.004
107185	P1	205.8	0.039
107185	2SM2	331.3	0.005
107185	M3	62.9	0.005
107185	L2	338	0.041
107185	2MK3	261.9	0.014
107185	K2	305.6	0.046
107185	M8	165	0.006
107185	MS4	214.7	0.023
107186	M2	298.2	0.418
107186	S2	323.4	0.093
107186	N2	275.3	0.087
107186	K1	225.2	0.131
107186	M4	249.5	0.016
107186	O1	214.2	0.073
107186	M6	166.9	0.004
107186	MK3	8.8	0.017
107186	S4	235.8	0.008
107186	MN4	266.5	0.009
107186	NU2	326.2	0.013
107186	S6	299.9	0.003
107186	MU2	154.4	0.003
107186	2N2	278.6	0.021
107186	OO1	245.2	0.01
107186	LDA2	327.6	0.015
107186	M1	354.2	0.005
107186	J1	263.1	0.021
107186	RHO1	263.9	0.007
107186	Q1	167.5	0.011
107186	2Q1	46.5	0.002
107186	P1	207.5	0.04
107186	2SM2	312.6	0.001
107186	M3	59.4	0.004
107186	L2	343.1	0.037
107186	2MK3	266	0.013
107186	K2	307.5	0.048
107186	M8	151.8	0.004
107186	MS4	206.9	0.022
107187	M2	298.6	0.413
107187	S2	324.6	0.098
107187	N2	273.6	0.086
107187	K1	225.5	0.137
107187	M4	264.2	0.017
107187	O1	212.7	0.076
107187	M6	147.1	0.003
107187	MK3	14.7	0.016
107187	S4	235	0.005
107187	MN4	268.7	0.012
107187	NU2	313.9	0.014
107187	S6	292.5	0.003
107187	MU2	180.9	0.001
107187	2N2	274.1	0.016
107187	OO1	260.9	0.013
107187	LDA2	329.8	0.014
107187	M1	331.6	0.006
107187	J1	270.3	0.017
107187	RHO1	226.3	0.003
107187	Q1	164.9	0.01
107187	2Q1	344	0.004
107187	P1	208.3	0.04
107187	2SM2	186.6	0.001
107187	M3	53.9	0.002
107187	L2	344	0.034
107187	2MK3	266.4	0.012
107187	K2	306	0.049
107187	M8	116.7	0.003
107187	MS4	197.2	0.019
107188	M2	298.9	0.405
107188	S2	326.1	0.103
107188	N2	270.9	0.084
107188	K1	225.3	0.142
107188	M4	271.7	0.019
107188	O1	211.6	0.079
107188	M6	118.2	0.003
107188	MK3	16.1	0.013
107188	S4	224.3	0.004
107188	MN4	267.9	0.014
107188	NU2	295.8	0.016
107188	S6	288.1	0.003
107188	MU2	29	0.002
107188	2N2	272.5	0.011
107188	OO1	273.1	0.016
107188	LDA2	332.8	0.012
107188	M1	313.6	0.007
107188	J1	282.6	0.012
107188	RHO1	155.3	0.007
107188	Q1	157.1	0.008
107188	2Q1	326.3	0.007
107188	P1	205	0.038
107188	2SM2	161.9	0.001
107188	M3	261.7	0.002
107188	L2	346.8	0.03
107188	2MK3	258.7	0.011
107188	K2	302.7	0.049
107188	M8	110.3	0.003
107188	MS4	183.8	0.015
107189	M2	299	0.396
107189	S2	327.5	0.109
107189	N2	268.7	0.081
107189	K1	224.1	0.146
107189	M4	276.4	0.023
107189	O1	210.5	0.083
107189	M6	69.6	0.002
107189	MK3	16.9	0.011
107189	S4	148.8	0.002
107189	MN4	266.2	0.016
107189	NU2	290.1	0.017
107189	S6	298.6	0.003
107189	MU2	10.7	0.007
107189	2N2	274	0.01
107189	OO1	286.4	0.016
107189	LDA2	333.3	0.011
107189	M1	293.5	0.009
107189	J1	314.6	0.007
107189	RHO1	150.6	0.015
107189	Q1	145.3	0.007
107189	2Q1	334.1	0.009
107189	P1	203.2	0.037
107189	2SM2	188.8	0.003
107189	M3	251	0.004
107189	L2	350.5	0.024
107189	2MK3	252	0.008
107189	K2	301.3	0.049
107189	M8	123.7	0.003
107189	MS4	165.9	0.011
107190	M2	298.7	0.387
107190	S2	329.6	0.112
107190	N2	268.8	0.078
107190	K1	222.5	0.149
107190	M4	277.3	0.027
107190	O1	210.5	0.085
107190	M6	31.6	0.005
107190	MK3	19.4	0.012
107190	S4	110.3	0.004
107190	MN4	267.2	0.018
107190	NU2	284.5	0.017
107190	S6	321.2	0.002
107190	MU2	2.1	0.008
107190	2N2	273.2	0.008
107190	OO1	294.2	0.018
107190	LDA2	339.5	0.011
107190	M1	276.8	0.01
107190	J1	359.9	0.008
107190	RHO1	144.5	0.021
107190	Q1	124.5	0.008
107190	2Q1	337.3	0.01
107190	P1	204.2	0.037
107190	2SM2	201.6	0.002
107190	M3	240.9	0.005
107190	L2	358.1	0.019
107190	2MK3	235.3	0.005
107190	K2	300.1	0.047
107190	M8	131.1	0.003
107190	MS4	144.4	0.01
107191	M2	298.7	0.377
107191	S2	330.8	0.113
107191	N2	271.6	0.074
107191	K1	221	0.154
107191	M4	272.4	0.03
107191	O1	210.5	0.089
107191	M6	12.6	0.008
107191	MK3	19.5	0.013
107191	S4	94.8	0.006
107191	MN4	266.9	0.019
107191	NU2	289.4	0.013
107191	S6	10.7	0.001
107191	MU2	341.8	0.007
107191	2N2	265.8	0.005
107191	OO1	288.3	0.019
107191	LDA2	347.4	0.011
107191	M1	262.9	0.012
107191	J1	13.4	0.012
107191	RHO1	146	0.028
107191	Q1	116.2	0.008
107191	2Q1	342.4	0.008
107191	P1	206.5	0.037
107191	2SM2	272.1	0.002
107191	M3	211.1	0.006
107191	L2	13.3	0.015
107191	2MK3	303.2	0.001
107191	K2	299.8	0.043
107191	M8	126.2	0.002
107191	MS4	118.5	0.009
107192	M2	298.5	0.368
107192	S2	330.6	0.114
107192	N2	275	0.073
107192	K1	219.9	0.16
107192	M4	268.1	0.031
107192	O1	210.9	0.094
107192	M6	4.2	0.009
107192	MK3	19	0.014
107192	S4	93.7	0.006
107192	MN4	256.1	0.02
107192	NU2	296.3	0.011
107192	S6	101.9	0.001
107192	MU2	314.9	0.005
107192	2N2	84.3	0.002
107192	OO1	279.1	0.019
107192	LDA2	358.3	0.012
107192	M1	256.1	0.013
107192	J1	17.5	0.016
107192	RHO1	144.7	0.033
107192	Q1	110.1	0.009
107192	2Q1	340.6	0.005
107192	P1	204.7	0.036
107192	2SM2	318.1	0.004
107192	M3	187.7	0.007
107192	L2	39.3	0.012
107192	2MK3	14.9	0.004
107192	K2	298.1	0.04
107192	M8	131.8	0.001
107192	MS4	94.7	0.01
107193	M2	295.3	0.36
107193	S2	327.8	0.111
107193	N2	276.1	0.073
107193	K1	217.3	0.168
107193	M4	258.2	0.033
107193	O1	209.3	0.099
107193	M6	348	0.01
107193	MK3	14.1	0.016
107193	S4	111.9	0.005
107193	MN4	237.5	0.021
107193	NU2	304.4	0.009
107193	S6	155.6	0.002
107193	MU2	257.7	0.004
107193	2N2	79.9	0.009
107193	OO1	270.8	0.02
107193	LDA2	10.7	0.011
107193	M1	246.7	0.012
107193	J1	19.7	0.017
107193	RHO1	138.4	0.033
107193	Q1	99.3	0.008
107193	P1	203.6	0.035
107193	2SM2	309.6	0.006
107193	M3	166.2	0.007
107193	L2	55.1	0.011
107193	2MK3	4.3	0.006
107193	K2	289.1	0.034
107193	M8	137	0.001
107193	MS4	66.1	0.011
107194	M2	297.9	0.354
107194	S2	330.9	0.106
107194	N2	281.4	0.075
107194	K1	218	0.177
107194	M4	255.3	0.032
107194	O1	208	0.106
107194	M6	347.5	0.008
107194	MK3	23.8	0.016
107194	S4	136.1	0.006
107194	MN4	228.2	0.021
107194	NU2	326.6	0.008
107194	S6	189.4	0.003
107194	MU2	228.8	0.007
107194	2N2	82.4	0.015
107194	OO1	267.2	0.022
107194	LDA2	20.7	0.012
107194	M1	238.3	0.011
107194	J1	26.3	0.015
107194	RHO1	132.6	0.03
107194	Q1	84	0.006
107194	2Q1	167.5	0.006
107194	P1	207.7	0.03
107194	2SM2	321.1	0.007
107194	M3	153.6	0.007
107194	L2	61.3	0.01
107194	2MK3	352.5	0.009
107194	K2	282.4	0.031
107194	M8	122	0.001
107194	MS4	55.5	0.011
107195	M2	297.4	0.351
107195	S2	329.5	0.098
107195	N2	282.6	0.078
107195	K1	217.4	0.186
107195	M4	244.9	0.031
107195	O1	204.2	0.114
107195	M6	330.8	0.007
107195	MK3	21.1	0.017
107195	S4	149.5	0.008
107195	MN4	218.8	0.021
107195	NU2	335.9	0.01
107195	S6	150.9	0.002
107195	MU2	214.4	0.01
107195	2N2	82.3	0.021
107195	OO1	262.7	0.021
107195	LDA2	25.1	0.01
107195	M1	226.5	0.01
107195	J1	27.6	0.009
107195	RHO1	118.9	0.025
107195	Q1	26.1	0.003
107195	2Q1	159.2	0.01
107195	P1	211.8	0.026
107195	2SM2	323.8	0.008
107195	M3	139.7	0.009
107195	L2	32	0.008
107195	2MK3	342.6	0.013
107195	K2	272.7	0.029
107195	M8	358.2	0.001
107195	MS4	36.4	0.01
107196	M2	296.3	0.35
107196	S2	327.9	0.091
107196	N2	283.9	0.081
107196	K1	216.8	0.197
107196	M4	232.2	0.029
107196	O1	200.7	0.12
107196	M6	318.4	0.007
107196	MK3	15.1	0.015
107196	S4	155.5	0.008
107196	MN4	211.6	0.019
107196	NU2	347.1	0.011
107196	S6	111.4	0.003
107196	MU2	212.2	0.01
107196	2N2	80.3	0.022
107196	OO1	255.8	0.022
107196	LDA2	20.2	0.01
107196	M1	208.7	0.011
107196	J1	358.6	0.002
107196	RHO1	99.5	0.019
107196	Q1	313.7	0.004
107196	2Q1	159.3	0.011
107196	P1	217.8	0.025
107196	2SM2	324.1	0.009
107196	M3	133.7	0.011
107196	L2	352.9	0.009
107196	2MK3	336.3	0.018
107196	K2	263.5	0.031
107196	M8	359.8	0.002
107196	MS4	358.1	0.008
107197	M2	294.6	0.349
107197	S2	329.8	0.087
107197	N2	284.7	0.083
107197	K1	216.4	0.205
107197	M4	220.6	0.026
107197	O1	198.1	0.128
107197	M6	292.6	0.006
107197	MK3	9.5	0.014
107197	S4	152.7	0.008
107197	MN4	202.3	0.015
107197	NU2	356.3	0.012
107197	S6	105.1	0.003
107197	MU2	223.1	0.009
107197	2N2	78.9	0.019
107197	OO1	250	0.027
107197	LDA2	6.1	0.01
107197	M1	196.9	0.011
107197	J1	242.4	0.006
107197	RHO1	58.8	0.014
107197	Q1	274.9	0.009
107197	2Q1	142	0.01
107197	P1	219.8	0.028
107197	2SM2	316	0.009
107197	M3	120.2	0.014
107197	L2	317.5	0.011
107197	2MK3	327.2	0.023
107197	K2	259	0.03
107197	M8	1.6	0.003
107197	MS4	309.1	0.008
107198	M2	292.6	0.347
107198	S2	334.2	0.089
107198	N2	280.6	0.085
107198	K1	217.1	0.212
107198	M4	208.9	0.02
107198	O1	194.9	0.134
107198	M6	257.1	0.007
107198	MK3	356.5	0.01
107198	S4	147.6	0.01
107198	MN4	185.9	0.009
107198	NU2	349.1	0.013
107198	S6	98.4	0.003
107198	MU2	227	0.007
107198	2N2	74.4	0.013
107198	OO1	247.4	0.033
107198	LDA2	351	0.011
107198	M1	189.3	0.011
107198	J1	244.8	0.013
107198	RHO1	20.4	0.016
107198	Q1	267.6	0.012
107198	2Q1	110.6	0.01
107198	P1	222	0.034
107198	2SM2	317.2	0.007
107198	M3	105.5	0.018
107198	L2	291	0.014
107198	2MK3	311.4	0.03
107198	K2	259.1	0.026
107198	M8	357.8	0.005
107198	MS4	281.6	0.008
107199	M2	290.5	0.34
107199	S2	338.1	0.098
107199	N2	274.4	0.086
107199	K1	219.4	0.218
107199	M4	199.1	0.015
107199	O1	191.8	0.138
107199	M6	213.8	0.008
107199	MK3	339.2	0.009
107199	S4	136.1	0.011
107199	MN4	158.4	0.005
107199	NU2	335.4	0.017
107199	S6	114.2	0.001
107199	MU2	219.8	0.005
107199	2N2	70.8	0.007
107199	OO1	247.9	0.042
107199	LDA2	348.7	0.012
107199	M1	186.9	0.01
107199	J1	262.1	0.018
107199	RHO1	15.5	0.016
107199	Q1	255.8	0.008
107199	2Q1	80.9	0.013
107199	P1	220.3	0.037
107199	2SM2	285	0.005
107199	M3	86.2	0.021
107199	L2	263.1	0.018
107199	2MK3	294.3	0.033
107199	K2	275.5	0.018
107199	M8	336.6	0.005
107199	MS4	255.2	0.007
107200	M2	288.1	0.323
107200	S2	340.3	0.105
107200	N2	266.1	0.083
107200	K1	221.7	0.222
107200	M4	172.4	0.01
107200	O1	190.6	0.14
107200	M6	189.1	0.012
107200	MK3	305.2	0.014
107200	S4	127	0.012
107200	MN4	127	0.002
107200	NU2	318.4	0.018
107200	S6	301	0.001
107200	MU2	173.7	0.004
107200	2N2	66.2	0.003
107200	OO1	254.9	0.047
107200	LDA2	4.7	0.01
107200	M1	184.9	0.01
107200	J1	271.3	0.022
107200	RHO1	17.9	0.011
107200	Q1	183	0.006
107200	2Q1	65.6	0.017
107200	P1	219.4	0.04
107200	2SM2	247.2	0.005
107200	M3	68.9	0.024
107200	L2	239.1	0.024
107200	2MK3	275.6	0.037
107200	K2	303.6	0.013
107200	M8	304.6	0.007
107200	MS4	225.1	0.004
107201	M2	286.2	0.3
107201	S2	338.6	0.109
107201	N2	255.6	0.076
107201	K1	222.9	0.222
107201	M4	145.5	0.012
107201	O1	190.1	0.138
107201	M6	176.1	0.015
107201	MK3	291.8	0.023
107201	S4	128.6	0.013
107201	MN4	217.1	0.001
107201	NU2	296.7	0.018
107201	S6	292.3	0.003
107201	MU2	175.7	0.005
107201	2N2	181.9	0.002
107201	OO1	259.1	0.039
107201	LDA2	48.2	0.006
107201	M1	188	0.009
107201	J1	278.2	0.026
107201	RHO1	42.2	0.007
107201	Q1	153.3	0.008
107201	2Q1	71.1	0.019
107201	P1	216.2	0.04
107201	2SM2	245.6	0.006
107201	M3	53	0.025
107201	L2	226	0.032
107201	2MK3	259.9	0.039
107201	K2	334	0.018
107201	M8	296.7	0.008
107201	MS4	150.9	0.003
107202	M2	285.1	0.273
107202	S2	335	0.099
107202	N2	247.2	0.067
107202	K1	222	0.22
107202	M4	129.2	0.015
107202	O1	191.6	0.135
107202	M6	162.1	0.017
107202	MK3	286.6	0.036
107202	S4	129	0.014
107202	MN4	233.5	0.004
107202	NU2	275.5	0.018
107202	S6	268.2	0.006
107202	MU2	191.2	0.009
107202	2N2	152.3	0.008
107202	OO1	244.8	0.023
107202	LDA2	98	0.007
107202	M1	207.4	0.008
107202	J1	286.7	0.028
107202	RHO1	97.1	0.007
107202	Q1	185.2	0.007
107202	2Q1	77.8	0.019
107202	P1	213.2	0.035
107202	2SM2	253.5	0.008
107202	M3	35.4	0.021
107202	L2	212.7	0.032
107202	2MK3	249	0.039
107202	K2	335.8	0.023
107202	M8	287.3	0.008
107202	MS4	86.6	0.008
107203	M2	297.7	0.064
107203	S2	326.2	0.025
107203	N2	259.9	0.022
107203	K1	235.3	0.019
107203	M4	62.2	0.008
107203	O1	180.7	0.037
107203	M6	212.1	0.01
107203	MK3	31.1	0.01
107203	S4	353.5	0.001
107203	MN4	42.8	0.002
107203	S6	142.2	0.003
107203	2N2	296.8	0.008
107203	OO1	78.6	0.005
107203	M1	306.5	0.003
107203	J1	247.7	0.005
107203	Q1	187.4	0.011
107203	2Q1	313	0.012
107203	P1	138.1	0.009
107203	2SM2	118.9	0.002
107203	M3	188.9	0.002
107203	L2	233.6	0.008
107203	2MK3	330	0.012
107203	K2	10.5	0.011
107203	M8	89.9	0.003
107203	MS4	132.8	0.004
107204	M2	304.6	0.165
107204	S2	328.2	0.038
107204	N2	287.9	0.029
107204	K1	204.2	0.066
107204	M4	94.4	0.017
107204	O1	217	0.031
107204	M6	237.9	0.003
107204	MK3	33.9	0.019
107204	S4	88.7	0.002
107204	MN4	91.5	0.005
107204	S6	284.7	0.002
107204	2N2	232.6	0.014
107204	OO1	348.4	0.02
107204	M1	233.5	0.002
107204	J1	153.7	0.002
107204	Q1	266.4	0.005
107204	2Q1	155.5	0.002
107204	P1	210.5	0.02
107204	2SM2	304.1	0.005
107204	M3	97.3	0.006
107204	L2	322.7	0.015
107204	2MK3	294.4	0.013
107204	K2	325.6	0.017
107204	M8	187.4	0.002
107204	MS4	133.1	0.009
107205	M2	260.5	0.136
107205	S2	288.2	0.032
107205	N2	229.9	0.031
107205	K1	159.8	0.044
107205	M4	295.4	0.027
107205	O1	118.8	0.066
107205	M6	123.2	0.004
107205	MK3	303.7	0.024
107205	S4	148.1	0.003
107205	MN4	274	0.014
107205	S6	14.7	0.002
107205	2N2	208.5	0.012
107205	OO1	285.1	0.006
107205	M1	161.1	0.009
107205	J1	108.5	0.008
107205	Q1	118	0.012
107205	2Q1	89.3	0.002
107205	P1	72.4	0.017
107205	2SM2	238.2	0.005
107205	M3	13.9	0.013
107205	L2	21.7	0.011
107205	2MK3	254.6	0.018
107205	K2	229.1	0.021
107205	M8	193	0.002
107205	MS4	351.4	0.005
107206	M2	264.4	0.142
107206	S2	292	0.035
107206	N2	232.5	0.031
107206	K1	161.4	0.045
107206	M4	295.9	0.023
107206	O1	119.7	0.064
107206	M6	118.1	0.004
107206	MK3	302.1	0.026
107206	S4	134.5	0.005
107206	MN4	274.1	0.013
107206	S6	12.5	0.002
107206	2N2	211.3	0.012
107206	OO1	279.9	0.008
107206	M1	165.1	0.009
107206	J1	114.5	0.008
107206	Q1	122	0.013
107206	2Q1	134.2	0.001
107206	P1	74.7	0.018
107206	2SM2	217.3	0.006
107206	M3	11.6	0.012
107206	L2	15	0.013
107206	2MK3	256.5	0.019
107206	K2	230.1	0.019
107206	M8	187.7	0.002
107206	MS4	20.7	0.003
107207	M2	267.7	0.146
107207	S2	293	0.038
107207	N2	235.2	0.03
107207	K1	161.1	0.047
107207	M4	294.7	0.019
107207	O1	121.7	0.059
107207	M6	115.4	0.004
107207	MK3	300.6	0.026
107207	S4	130.2	0.006
107207	MN4	276	0.012
107207	S6	12.6	0.002
107207	2N2	209	0.012
107207	OO1	271.4	0.01
107207	M1	165.6	0.008
107207	J1	122.2	0.007
107207	Q1	120.6	0.013
107207	2Q1	217.5	0.003
107207	P1	83	0.018
107207	2SM2	202.2	0.007
107207	M3	5.8	0.012
107207	L2	11.6	0.012
107207	2MK3	255.9	0.02
107207	K2	235.7	0.017
107207	M8	187.2	0.002
107207	MS4	66.7	0.003
107208	M2	271	0.15
107208	S2	294.6	0.039
107208	N2	239.4	0.029
107208	K1	164	0.048
107208	M4	284.6	0.014
107208	O1	123.9	0.053
107208	M6	103.6	0.002
107208	MK3	301.2	0.024
107208	S4	120.2	0.007
107208	MN4	276.6	0.01
107208	S6	0.6	0.001
107208	2N2	199.2	0.012
107208	OO1	262.4	0.014
107208	M1	160.8	0.006
107208	J1	137.3	0.007
107208	Q1	120.2	0.012
107208	2Q1	225.1	0.005
107208	P1	89.8	0.018
107208	2SM2	198.3	0.007
107208	M3	0.4	0.011
107208	L2	15.3	0.012
107208	2MK3	254.1	0.019
107208	K2	239.2	0.018
107208	M8	170.4	0.002
107208	MS4	96.9	0.004
107209	M2	274.8	0.155
107209	S2	299.5	0.039
107209	N2	244.7	0.03
107209	K1	170.1	0.051
107209	M4	255.8	0.01
107209	O1	128.1	0.045
107209	M6	23	0.001
107209	MK3	307	0.021
107209	S4	117.1	0.007
107209	MN4	274.6	0.008
107209	S6	274.9	0.001
107209	2N2	192	0.01
107209	OO1	254	0.017
107209	M1	153.8	0.005
107209	J1	156.4	0.006
107209	Q1	121	0.011
107209	2Q1	229.7	0.007
107209	P1	99.3	0.016
107209	2SM2	193.1	0.007
107209	M3	357.8	0.011
107209	L2	20.5	0.012
107209	2MK3	250.9	0.016
107209	K2	237.4	0.018
107209	M8	170	0.002
107209	MS4	103.6	0.005
107210	M2	279.3	0.161
107210	S2	303.8	0.04
107210	N2	252.7	0.031
107210	K1	177.3	0.055
107210	M4	215.4	0.01
107210	O1	137	0.039
107210	M6	291.7	0.001
107210	MK3	318.8	0.015
107210	S4	116.4	0.007
107210	MN4	266.5	0.005
107210	S6	255.9	0.001
107210	2N2	182.5	0.009
107210	OO1	244	0.021
107210	M1	153.5	0.004
107210	J1	179.3	0.004
107210	Q1	120.1	0.009
107210	2Q1	227.5	0.009
107210	P1	117.7	0.012
107210	2SM2	197	0.008
107210	M3	2.8	0.009
107210	L2	24.5	0.013
107210	2MK3	250.8	0.013
107210	K2	237.8	0.018
107210	M8	182.4	0.002
107210	MS4	108.2	0.006
107211	M2	284	0.168
107211	S2	305.9	0.042
107211	N2	261.5	0.034
107211	K1	186	0.06
107211	M4	191.8	0.014
107211	O1	150	0.035
107211	M6	271.8	0.003
107211	MK3	341.2	0.011
107211	S4	120.1	0.005
107211	MN4	217	0.003
107211	S6	262.4	0.001
107211	2N2	171.4	0.006
107211	OO1	240.9	0.024
107211	M1	162.7	0.004
107211	J1	200.2	0.004
107211	Q1	117.1	0.007
107211	2Q1	217.5	0.01
107211	P1	148.4	0.01
107211	2SM2	201.7	0.007
107211	M3	16	0.006
107211	L2	24.7	0.013
107211	2MK3	251.3	0.009
107211	K2	248.8	0.016
107211	M8	210.9	0.001
107211	MS4	124.7	0.006
107212	M2	288.6	0.177
107212	S2	310.4	0.043
107212	N2	270.2	0.037
107212	K1	194.5	0.068
107212	M4	176.6	0.017
107212	O1	166.2	0.034
107212	M6	256.6	0.005
107212	MK3	12.7	0.009
107212	S4	132	0.003
107212	MN4	170.5	0.006
107212	2N2	160.7	0.004
107212	OO1	240.8	0.026
107212	M1	181	0.004
107212	J1	213.1	0.005
107212	Q1	121.6	0.006
107212	2Q1	214.1	0.012
107212	P1	203.6	0.012
107212	2SM2	203.6	0.006
107212	M3	46.8	0.003
107212	L2	20	0.012
107212	2MK3	257.8	0.006
107212	K2	256.8	0.013
107212	M8	215.4	0.001
107212	MS4	146.1	0.007
107213	M2	292.6	0.186
107213	S2	315	0.046
107213	N2	278	0.041
107213	K1	200.8	0.077
107213	M4	162.7	0.019
107213	O1	184.3	0.035
107213	M6	249.6	0.01
107213	MK3	51.6	0.007
107213	S4	221.1	0.001
107213	MN4	153	0.009
107213	S6	291	0.001
107213	2N2	135.2	0.001
107213	OO1	235.8	0.027
107213	M1	200.7	0.004
107213	J1	246	0.004
107213	Q1	145.8	0.004
107213	2Q1	212.7	0.012
107213	P1	227.7	0.02
107213	2SM2	200.2	0.005
107213	M3	122.7	0.002
107213	L2	5.4	0.011
107213	2MK3	283.3	0.001
107213	K2	278.9	0.01
107213	M8	95.6	0.001
107213	MS4	165.4	0.009
107214	M2	295.9	0.197
107214	S2	320.7	0.052
107214	N2	286.1	0.045
107214	K1	208.6	0.087
107214	M4	147	0.023
107214	O1	200.7	0.042
107214	M6	251	0.015
107214	MK3	85.2	0.01
107214	S4	290.1	0.002
107214	MN4	142.8	0.011
107214	S6	341.7	0.001
107214	2N2	316.1	0.002
107214	OO1	231.8	0.026
107214	M1	228.5	0.005
107214	J1	272.2	0.007
107214	Q1	208.1	0.004
107214	2Q1	205.4	0.011
107214	P1	242.7	0.029
107214	2SM2	169.1	0.004
107214	M3	162.6	0.005
107214	L2	341.7	0.008
107214	2MK3	45.3	0.006
107214	K2	328.8	0.008
107214	M8	71.9	0.002
107214	MS4	169.1	0.013
107215	M2	298.9	0.209
107215	S2	326.5	0.058
107215	N2	293.6	0.048
107215	K1	215.4	0.1
107215	M4	131.4	0.031
107215	O1	214.9	0.052
107215	M6	256.7	0.02
107215	MK3	96.3	0.018
107215	S4	316.2	0.003
107215	MN4	137.1	0.013
107215	S6	212.2	0.002
107215	2N2	301	0.004
107215	OO1	235.6	0.027
107215	M1	250.1	0.006
107215	J1	282.7	0.011
107215	Q1	234	0.008
107215	2Q1	192.7	0.01
107215	P1	247.9	0.039
107215	2SM2	133.6	0.003
107215	M3	175.1	0.009
107215	L2	296.6	0.009
107215	2MK3	49.4	0.015
107215	K2	9.9	0.012
107215	M8	83.3	0.004
107215	MS4	163.3	0.017
107216	M2	302.7	0.223
107216	S2	330.9	0.07
107216	N2	300.3	0.051
107216	K1	221.2	0.112
107216	M4	124.5	0.043
107216	O1	225.9	0.07
107216	M6	258.6	0.023
107216	MK3	96.8	0.031
107216	S4	317.7	0.002
107216	MN4	132.4	0.016
107216	S6	171.1	0.003
107216	2N2	279.6	0.005
107216	OO1	254.5	0.028
107216	M1	265.9	0.007
107216	J1	273.7	0.015
107216	Q1	236.5	0.011
107216	2Q1	186	0.01
107216	P1	246.1	0.05
107216	2SM2	103	0.004
107216	M3	174	0.013
107216	L2	268.9	0.016
107216	2MK3	44	0.026
107216	K2	35.8	0.02
107216	M8	86.5	0.004
107216	MS4	157.7	0.019
107217	M2	307.7	0.243
107217	S2	329.9	0.079
107217	N2	301.9	0.055
107217	K1	227.7	0.11
107217	M4	122.9	0.05
107217	O1	231.3	0.09
107217	M6	253.4	0.022
107217	MK3	95.5	0.042
107217	S4	312.9	0.004
107217	MN4	117.1	0.02
107217	S6	160.7	0.005
107217	2N2	265.3	0.01
107217	OO1	296.2	0.02
107217	M1	248.8	0.01
107217	J1	245.8	0.015
107217	Q1	228.2	0.01
107217	2Q1	162.1	0.014
107217	P1	232.8	0.049
107217	2SM2	122	0.005
107217	M3	151.6	0.019
107217	L2	275.2	0.027
107217	2MK3	37.3	0.035
107217	K2	39.6	0.036
107217	M8	21.2	0.003
107217	MS4	154.7	0.018
107218	M2	291.6	0.652
107218	S2	312.1	0.154
107218	N2	273.2	0.135
107218	K1	195	0.256
107218	M4	141.2	0.056
107218	O1	166	0.136
107218	M6	301.7	0.029
107218	MK3	63.2	0.044
107218	S4	159.1	0.005
107218	MN4	133.1	0.025
107218	S6	50.3	0.001
107218	2N2	203.5	0.026
107218	OO1	236.9	0.02
107218	M1	164.9	0.003
107218	J1	196.7	0.018
107218	Q1	149.3	0.023
107218	2Q1	151.4	0.008
107218	P1	187	0.076
107218	2SM2	220.4	0.008
107218	M3	115.8	0.015
107218	L2	324.9	0.046
107218	2MK3	348.7	0.029
107218	K2	313.6	0.04
107218	M8	175	0.014
107218	MS4	176.4	0.034
107219	M2	291.6	0.675
107219	S2	312.1	0.158
107219	N2	273.4	0.141
107219	K1	194.5	0.268
107219	M4	142.4	0.059
107219	O1	164.7	0.143
107219	M6	299.9	0.028
107219	MK3	66.2	0.048
107219	S4	158.3	0.005
107219	MN4	137.3	0.027
107219	S6	76.3	0.001
107219	2N2	207	0.028
107219	OO1	231.7	0.018
107219	M1	152.2	0.004
107219	J1	196.2	0.018
107219	Q1	147.3	0.026
107219	2Q1	153.3	0.008
107219	P1	187	0.08
107219	2SM2	224	0.007
107219	M3	118.4	0.017
107219	L2	324.1	0.047
107219	2MK3	353	0.032
107219	K2	311.9	0.044
107219	M8	171.6	0.014
107219	MS4	176.9	0.036
107220	M2	291.5	0.687
107220	S2	312.1	0.161
107220	N2	273.6	0.142
107220	K1	194.2	0.273
107220	M4	143.7	0.061
107220	O1	162.8	0.147
107220	M6	297.6	0.027
107220	MK3	67.8	0.049
107220	S4	158.8	0.006
107220	MN4	139.7	0.027
107220	S6	33.1	0.001
107220	2N2	208.6	0.03
107220	OO1	233	0.016
107220	M1	150.2	0.005
107220	J1	196.2	0.019
107220	Q1	147.9	0.026
107220	2Q1	164.2	0.007
107220	P1	187.1	0.08
107220	2SM2	223.9	0.007
107220	M3	122.9	0.019
107220	L2	323.8	0.047
107220	2MK3	356.9	0.033
107220	K2	310.3	0.046
107220	M8	169.4	0.013
107220	MS4	178.4	0.036
107221	M2	291.2	0.694
107221	S2	311.9	0.162
107221	N2	273.8	0.143
107221	K1	193.6	0.275
107221	M4	145.7	0.061
107221	O1	161	0.149
107221	M6	296	0.026
107221	MK3	68.5	0.051
107221	S4	162.2	0.006
107221	MN4	141	0.028
107221	S6	356.5	0.001
107221	2N2	210.1	0.032
107221	OO1	236.8	0.017
107221	M1	158.1	0.005
107221	J1	197.5	0.018
107221	Q1	150.7	0.027
107221	2Q1	191.3	0.006
107221	P1	187.2	0.079
107221	2SM2	231.7	0.007
107221	M3	127.3	0.019
107221	L2	322.7	0.048
107221	2MK3	1.3	0.031
107221	K2	308.2	0.05
107221	M8	168.7	0.012
107221	MS4	181.5	0.035
107222	M2	290.8	0.7
107222	S2	312.1	0.162
107222	N2	274.2	0.143
107222	K1	193	0.276
107222	M4	148.5	0.06
107222	O1	159.7	0.15
107222	M6	293.2	0.027
107222	MK3	67.8	0.052
107222	S4	159.5	0.007
107222	MN4	142	0.028
107222	S6	336.7	0.001
107222	2N2	210.6	0.031
107222	OO1	244.6	0.02
107222	M1	172.4	0.006
107222	J1	199.6	0.017
107222	Q1	156	0.028
107222	2Q1	218.7	0.005
107222	P1	187.5	0.079
107222	2SM2	231.8	0.006
107222	M3	132.7	0.019
107222	L2	320.4	0.047
107222	2MK3	7.8	0.03
107222	K2	305	0.053
107222	M8	169.8	0.012
107222	MS4	184.6	0.035
107223	M2	290.4	0.705
107223	S2	312	0.164
107223	N2	274.3	0.144
107223	K1	192.5	0.275
107223	M4	152.1	0.059
107223	O1	158.5	0.15
107223	M6	290.2	0.029
107223	MK3	67.2	0.053
107223	S4	159	0.008
107223	MN4	143.1	0.028
107223	S6	280.3	0.001
107223	2N2	211	0.03
107223	OO1	246	0.023
107223	M1	177	0.007
107223	J1	202.7	0.016
107223	Q1	159.6	0.029
107223	2Q1	247.1	0.005
107223	P1	188.5	0.079
107223	2SM2	228.9	0.006
107223	M3	138.5	0.019
107223	L2	318.2	0.047
107223	2MK3	15	0.029
107223	K2	303.8	0.055
107223	M8	168	0.012
107223	MS4	188	0.035
107224	M2	290	0.71
107224	S2	312.1	0.165
107224	N2	274.4	0.144
107224	K1	192.3	0.274
107224	M4	156.7	0.059
107224	O1	157.9	0.149
107224	M6	287.4	0.031
107224	MK3	67.6	0.054
107224	S4	157.1	0.007
107224	MN4	144.2	0.028
107224	S6	292.7	0.001
107224	2N2	210	0.029
107224	OO1	250.1	0.025
107224	M1	177.3	0.009
107224	J1	204.3	0.016
107224	Q1	163.1	0.03
107224	2Q1	261.9	0.006
107224	P1	189.5	0.079
107224	2SM2	233.7	0.006
107224	M3	141.8	0.02
107224	L2	316.9	0.047
107224	2MK3	21	0.03
107224	K2	303.3	0.057
107224	M8	167.7	0.012
107224	MS4	190.2	0.037
107225	M2	289.9	0.713
107225	S2	312.6	0.166
107225	N2	274.2	0.145
107225	K1	192.9	0.273
107225	M4	161.3	0.06
107225	O1	158.4	0.148
107225	M6	285.1	0.033
107225	MK3	69.4	0.055
107225	S4	152.8	0.007
107225	MN4	144.3	0.029
107225	S6	300.2	0.002
107225	2N2	210.6	0.028
107225	OO1	254.6	0.025
107225	M1	178.2	0.01
107225	J1	200.1	0.016
107225	Q1	162.8	0.03
107225	2Q1	266.7	0.006
107225	P1	190.9	0.078
107225	2SM2	238.4	0.006
107225	M3	143.2	0.022
107225	L2	315.7	0.047
107225	2MK3	24.9	0.032
107225	K2	303.7	0.055
107225	M8	170.1	0.011
107225	MS4	191.3	0.037
107226	M2	290	0.716
107226	S2	313.9	0.166
107226	N2	273.8	0.145
107226	K1	193.5	0.274
107226	M4	164.7	0.062
107226	O1	160	0.148
107226	M6	283.9	0.033
107226	MK3	73.5	0.056
107226	S4	154.7	0.006
107226	MN4	146	0.03
107226	S6	273.1	0.002
107226	2N2	211.4	0.028
107226	OO1	254.6	0.028
107226	M1	183.2	0.011
107226	J1	199.1	0.017
107226	Q1	164	0.029
107226	2Q1	275.8	0.005
107226	P1	192.1	0.078
107226	2SM2	239.2	0.007
107226	M3	145.8	0.022
107226	L2	315.4	0.047
107226	2MK3	29.5	0.034
107226	K2	301.6	0.054
107226	M8	178.1	0.011
107226	MS4	193.2	0.037
107227	M2	290.1	0.715
107227	S2	315.1	0.163
107227	N2	273.2	0.146
107227	K1	193.9	0.275
107227	M4	169	0.062
107227	O1	161.7	0.149
107227	M6	280	0.031
107227	MK3	78.5	0.056
107227	S4	164	0.006
107227	MN4	145.8	0.029
107227	S6	253.9	0.002
107227	2N2	213.6	0.028
107227	OO1	259.1	0.03
107227	M1	188.4	0.012
107227	J1	199.7	0.016
107227	Q1	164.6	0.029
107227	2Q1	290.2	0.005
107227	P1	193	0.079
107227	2SM2	236	0.007
107227	M3	144.7	0.021
107227	L2	314.6	0.047
107227	2MK3	35.4	0.035
107227	K2	297	0.055
107227	M8	188.4	0.01
107227	MS4	198.5	0.035
107228	M2	275.6	0.781
107228	S2	296.4	0.227
107228	N2	249	0.173
107228	K1	213	0.137
107228	M4	180.3	0.059
107228	O1	171.9	0.085
107228	M6	340.2	0.024
107228	MK3	50.3	0.029
107228	S4	150.2	0.01
107228	MN4	179.6	0.023
107228	S6	298.1	0.004
107228	2N2	159.6	0.03
107228	OO1	33.7	0.063
107228	M1	179.4	0.006
107228	J1	149.6	0.034
107228	Q1	211.1	0.027
107228	2Q1	8.7	0.042
107228	P1	29	0.007
107228	2SM2	175.1	0.005
107228	M3	289.5	0.034
107228	L2	273.7	0.108
107228	2MK3	164.5	0.066
107228	K2	31	0.121
107228	M8	235.8	0.015
107228	MS4	235	0.031
107229	M2	277.2	0.791
107229	S2	299.3	0.22
107229	N2	247.8	0.172
107229	K1	222.3	0.136
107229	M4	168.1	0.073
107229	O1	165.7	0.085
107229	M6	345.3	0.022
107229	MK3	57.5	0.039
107229	S4	124.2	0.009
107229	MN4	161.5	0.026
107229	S6	262.2	0.004
107229	2N2	171.9	0.033
107229	OO1	36.2	0.068
107229	M1	172.1	0.008
107229	J1	148.3	0.036
107229	Q1	204.7	0.033
107229	2Q1	357.8	0.05
107229	P1	5.4	0.019
107229	2SM2	182.8	0.012
107229	M3	281.5	0.037
107229	L2	276.8	0.106
107229	2MK3	156.3	0.074
107229	K2	38.9	0.1
107229	M8	232.5	0.013
107229	MS4	245.7	0.029
107230	M2	277.8	0.8
107230	S2	302.4	0.207
107230	N2	246.9	0.171
107230	K1	229.1	0.145
107230	M4	162.3	0.081
107230	O1	168.5	0.086
107230	M6	357.9	0.02
107230	MK3	62.3	0.038
107230	S4	106.7	0.01
107230	MN4	146.5	0.03
107230	S6	253.3	0.006
107230	2N2	173.7	0.039
107230	OO1	35.3	0.069
107230	M1	176.1	0.007
107230	J1	143.5	0.037
107230	Q1	205.5	0.038
107230	2Q1	352.9	0.055
107230	P1	356.7	0.032
107230	2SM2	180.9	0.018
107230	M3	275.8	0.039
107230	L2	278.8	0.108
107230	2MK3	150.3	0.077
107230	K2	43.7	0.083
107230	M8	232.5	0.011
107230	MS4	249.5	0.025
107231	M2	278	0.805
107231	S2	305	0.19
107231	N2	246	0.17
107231	K1	232.4	0.154
107231	M4	158.3	0.083
107231	O1	172.9	0.088
107231	M6	21.9	0.019
107231	MK3	66.7	0.033
107231	S4	92.5	0.011
107231	MN4	136.7	0.034
107231	S6	247.4	0.008
107231	2N2	172.8	0.041
107231	OO1	33.2	0.069
107231	M1	172.8	0.007
107231	J1	141.9	0.038
107231	Q1	205.8	0.045
107231	2Q1	350.1	0.059
107231	P1	354.2	0.038
107231	2SM2	175.6	0.024
107231	M3	273.3	0.042
107231	L2	279.5	0.108
107231	2MK3	146	0.077
107231	K2	45.4	0.067
107231	M8	236.8	0.01
107231	MS4	245.8	0.022
107232	M2	278.2	0.807
107232	S2	309.5	0.174
107232	N2	245.8	0.169
107232	K1	234.4	0.166
107232	M4	155	0.083
107232	O1	177.9	0.091
107232	M6	46.2	0.022
107232	MK3	70.1	0.027
107232	S4	83	0.012
107232	MN4	130.4	0.039
107232	S6	246.2	0.008
107232	2N2	169.8	0.042
107232	OO1	30.5	0.07
107232	M1	177.5	0.005
107232	J1	137.4	0.039
107232	Q1	205.9	0.049
107232	2Q1	347.7	0.064
107232	P1	349	0.044
107232	2SM2	170.8	0.029
107232	M3	272.4	0.043
107232	L2	280.3	0.109
107232	2MK3	143.3	0.075
107232	K2	54.6	0.052
107232	M8	246.5	0.009
107232	MS4	238.6	0.02
107233	M2	278.2	0.811
107233	S2	314.6	0.161
107233	N2	246.1	0.166
107233	K1	234.3	0.179
107233	M4	154.5	0.081
107233	O1	185.4	0.099
107233	M6	56.7	0.027
107233	MK3	74.6	0.019
107233	S4	71.8	0.014
107233	MN4	122.7	0.045
107233	S6	241.5	0.008
107233	2N2	165.1	0.042
107233	OO1	21.5	0.071
107233	M1	254.6	0.002
107233	J1	125.6	0.041
107233	Q1	205.9	0.047
107233	2Q1	346.2	0.067
107233	P1	345.8	0.048
107233	2SM2	171.9	0.032
107233	M3	270.2	0.04
107233	L2	282.7	0.117
107233	2MK3	141.6	0.07
107233	K2	64	0.045
107233	M8	271.2	0.006
107233	MS4	220.8	0.019
107234	M2	278.1	0.815
107234	S2	321.9	0.15
107234	N2	247.5	0.16
107234	K1	234	0.192
107234	M4	154.8	0.078
107234	O1	193.5	0.109
107234	M6	57.7	0.033
107234	MK3	81.2	0.01
107234	S4	60.6	0.018
107234	MN4	118.4	0.051
107234	S6	241.3	0.007
107234	2N2	158.9	0.042
107234	OO1	11.2	0.071
107234	M1	325	0.007
107234	J1	115	0.043
107234	Q1	211.2	0.039
107234	2Q1	345.2	0.071
107234	P1	343.9	0.051
107234	2SM2	175.6	0.034
107234	M3	266	0.037
107234	L2	284.4	0.126
107234	2MK3	139.3	0.063
107234	K2	88.4	0.039
107234	M8	309.9	0.006
107234	MS4	199.3	0.02
107235	M2	278.1	0.818
107235	S2	331	0.141
107235	N2	249.6	0.154
107235	K1	233.7	0.199
107235	M4	156.5	0.079
107235	O1	199.2	0.117
107235	M6	56.1	0.038
107235	MK3	97.8	0.005
107235	S4	59.7	0.021
107235	MN4	116.2	0.053
107235	S6	231	0.004
107235	2N2	151.6	0.044
107235	OO1	4.9	0.07
107235	M1	332.3	0.012
107235	J1	108.4	0.043
107235	Q1	225.9	0.032
107235	2Q1	344.3	0.075
107235	P1	343.4	0.05
107235	2SM2	175.2	0.037
107235	M3	261.8	0.035
107235	L2	285.7	0.131
107235	2MK3	136.2	0.058
107235	K2	127.7	0.044
107235	M8	348.4	0.008
107235	MS4	180.9	0.021
107236	M2	278.1	0.815
107236	S2	339.4	0.131
107236	N2	250.6	0.15
107236	K1	233.9	0.192
107236	M4	157.8	0.082
107236	O1	201.3	0.121
107236	M6	58.1	0.042
107236	MK3	224	0.002
107236	S4	57.7	0.025
107236	MN4	117.3	0.051
107236	S6	241.1	0.003
107236	2N2	146.4	0.043
107236	OO1	2.7	0.074
107236	M1	339.8	0.014
107236	J1	106.7	0.041
107236	Q1	239.1	0.032
107236	2Q1	344	0.081
107236	P1	351.3	0.043
107236	2SM2	171.4	0.04
107236	M3	259.3	0.036
107236	L2	287.2	0.129
107236	2MK3	134	0.056
107236	K2	150.4	0.062
107236	M8	355.4	0.011
107236	MS4	173.4	0.022
107237	M2	304.9	1.882
107237	S2	339.7	0.4
107237	N2	292.3	0.37
107237	K1	211.1	0.762
107237	M4	199.1	0.205
107237	O1	187.7	0.451
107237	M6	351.2	0.185
107237	MK3	125.5	0.14
107237	S4	179.3	0.002
107237	MN4	189.7	0.093
107237	S6	155.7	0.01
107237	2N2	195.9	0.048
107237	OO1	282.4	0.119
107237	M1	228.3	0.021
107237	J1	226.5	0.038
107237	Q1	195.3	0.082
107237	2Q1	297.5	0.012
107237	P1	214	0.212
107237	2SM2	172.7	0.016
107237	M3	200.7	0.04
107237	L2	308.2	0.13
107237	2MK3	99.6	0.136
107237	K2	289.3	0.16
107237	M8	272.9	0.063
107237	MS4	247	0.096
107238	M2	303.9	2.31
107238	S2	339.2	0.47
107238	N2	291	0.445
107238	K1	209.1	0.912
107238	M4	200.7	0.196
107238	O1	183.7	0.53
107238	M6	346.9	0.204
107238	MK3	128.6	0.118
107238	S4	259.7	0.011
107238	MN4	190.9	0.091
107238	S6	155.1	0.011
107238	2N2	209	0.068
107238	OO1	281.1	0.147
107238	M1	214.6	0.024
107238	J1	226.8	0.044
107238	Q1	190.6	0.094
107238	2Q1	281.8	0.012
107238	P1	210.6	0.239
107238	2SM2	160.1	0.022
107238	M3	201.4	0.032
107238	L2	306.8	0.16
107238	2MK3	111.4	0.132
107238	K2	292.5	0.212
107238	M8	286	0.056
107238	MS4	257	0.123
107239	M2	302.7	0.405
107239	S2	324	0.102
107239	N2	274.9	0.08
107239	K1	205.2	0.139
107239	M4	174.1	0.043
107239	O1	171.1	0.053
107239	M6	123.9	0.01
107239	MK3	44.5	0.036
107239	S4	96.3	0.004
107239	MN4	198.1	0.019
107239	NU2	312.2	0.031
107239	S6	142.3	0.004
107239	MU2	112.1	0.012
107239	2N2	219.2	0.012
107239	OO1	115.3	0.004
107239	LDA2	284.1	0.019
107239	M1	104.2	0.002
107239	J1	238.7	0.013
107239	RHO1	316.9	0.009
107239	Q1	130.7	0.005
107239	2Q1	121.1	0.017
107239	P1	193.5	0.044
107239	2SM2	218.6	0.004
107239	M3	129.2	0.015
107239	L2	0.9	0.045
107239	2MK3	338.8	0.009
107239	K2	305.7	0.028
107239	M8	0.9	0.008
107239	MS4	222.8	0.004
107240	M2	306	0.415
107240	S2	330.1	0.092
107240	N2	289.9	0.079
107240	K1	208.9	0.154
107240	M4	154.9	0.004
107240	O1	188.8	0.048
107240	M6	96.9	0.014
107240	MK3	39.5	0.034
107240	S4	65.1	0.002
107240	MN4	182.4	0.005
107240	NU2	257.6	0.015
107240	S6	201.4	0.003
107240	MU2	130	0.014
107240	2N2	14.4	0.009
107240	OO1	136.8	0.027
107240	LDA2	356.3	0.015
107240	M1	100	0.007
107240	J1	199.6	0.01
107240	RHO1	232	0.023
107240	Q1	141.8	0.026
107240	2Q1	124.4	0.009
107240	P1	184.6	0.047
107240	2SM2	169	0.003
107240	M3	91.1	0.011
107240	L2	353.3	0.033
107240	2MK3	267.9	0.019
107240	K2	1.4	0.032
107240	M8	231.5	0.003
107240	MS4	210	0.008
107241	M2	289	0.326
107241	S2	322.3	0.087
107241	N2	268.4	0.066
107241	K1	214.2	0.165
107241	M4	264.1	0.035
107241	O1	218	0.073
107241	M6	335	0.015
107241	MK3	78.9	0.018
107241	S4	164.8	0.008
107241	MN4	257.6	0.012
107241	NU2	283.7	0.012
107241	S6	234.1	0.003
107241	MU2	49.1	0.012
107241	2N2	230.4	0.018
107241	OO1	282.7	0.013
107241	LDA2	347.6	0.007
107241	M1	329.2	0.006
107241	J1	206	0.009
107241	RHO1	200.9	0.01
107241	Q1	100.2	0.009
107241	2Q1	61.3	0.02
107241	P1	134.9	0.033
107241	2SM2	165.2	0.008
107241	M3	325.8	0.006
107241	L2	231.6	0.019
107241	2MK3	100.3	0.008
107241	K2	338.7	0.045
107241	M8	274.2	0.004
107241	MS4	231.5	0.008
107242	M2	278.6	0.484
107242	S2	299.6	0.09
107242	N2	250.2	0.093
107242	K1	196.6	0.194
107242	M4	191.2	0.067
107242	O1	144.8	0.104
107242	M6	152.6	0.02
107242	MK3	37	0.021
107242	S4	267.8	0.009
107242	MN4	157.6	0.026
107242	S6	71.2	0.005
107242	2N2	200.8	0.027
107242	OO1	319.1	0.043
107242	M1	163.8	0.008
107242	J1	28.9	0.022
107242	Q1	175.6	0.026
107242	2Q1	297.1	0.029
107242	P1	248.9	0.05
107242	2SM2	303.3	0.011
107242	M3	302.4	0.009
107242	L2	268.9	0.038
107242	2MK3	138.6	0.015
107242	K2	286.2	0.09
107242	M8	148.2	0.019
107242	MS4	230.1	0.027
107243	M2	277.6	0.501
107243	S2	332.5	0.087
107243	N2	264.1	0.101
107243	K1	205.1	0.234
107243	M4	140.7	0.015
107243	O1	154.4	0.077
107243	M6	93.6	0.021
107243	MK3	286.3	0.031
107243	S4	243.5	0.006
107243	MN4	265.9	0.007
107243	S6	252.8	0.003
107243	2N2	173.4	0.03
107243	OO1	297.5	0.045
107243	M1	175.9	0.014
107243	J1	3.3	0.022
107243	Q1	183.5	0.03
107243	2Q1	280.4	0.042
107243	P1	246.8	0.116
107243	2SM2	178.2	0.015
107243	M3	347.2	0.001
107243	L2	290.8	0.045
107243	2MK3	262.6	0.035
107243	K2	245.1	0.078
107243	M8	26.5	0.019
107243	MS4	347.6	0.005
107244	M2	285.6	0.467
107244	S2	0.2	0.112
107244	N2	282.5	0.101
107244	K1	210.9	0.264
107244	M4	66.3	0.052
107244	O1	192.5	0.131
107244	M6	27.2	0.018
107244	MK3	281.8	0.047
107244	S4	215.4	0.015
107244	MN4	197.6	0.015
107244	2N2	155.7	0.029
107244	OO1	300.4	0.079
107244	M1	229.8	0.022
107244	J1	345.3	0.038
107244	Q1	197	0.053
107244	2Q1	263.4	0.07
107244	P1	236.4	0.157
107244	2SM2	190.6	0.033
107244	M3	44.6	0.01
107244	L2	281.6	0.04
107244	2MK3	239.8	0.043
107244	K2	223.3	0.111
107244	M8	334.1	0.005
107244	MS4	76.4	0.023
107245	M2	294.8	0.608
107245	S2	322.6	0.125
107245	N2	282.6	0.127
107245	K1	187.2	0.224
107245	M4	350.1	0.055
107245	O1	153.5	0.176
107245	M6	100.1	0.016
107245	MK3	262.6	0.033
107245	S4	149.4	0.015
107245	MN4	348.2	0.022
107245	S6	333.7	0.002
107245	2N2	197.1	0.028
107245	OO1	270.5	0.034
107245	M1	215.1	0.013
107245	J1	302	0.015
107245	Q1	168.8	0.043
107245	2Q1	302.7	0.03
107245	P1	174.4	0.058
107245	2SM2	198	0.001
107245	M3	22.3	0.019
107245	L2	313.6	0.054
107245	2MK3	261	0.049
107245	K2	289.1	0.065
107245	M8	280.4	0.02
107245	MS4	57.5	0.015
107246	M2	296.4	0.636
107246	S2	322.7	0.144
107246	N2	279	0.133
107246	K1	190.7	0.224
107246	M4	329	0.086
107246	O1	156.3	0.162
107246	M6	122.3	0.025
107246	MK3	250.6	0.038
107246	S4	178.7	0.016
107246	MN4	328.1	0.026
107246	S6	357.1	0.003
107246	2N2	215.1	0.027
107246	OO1	294	0.029
107246	M1	210.5	0.009
107246	J1	265.7	0.011
107246	Q1	170.9	0.034
107246	2Q1	305.7	0.021
107246	P1	166.5	0.065
107246	2SM2	282.5	0.003
107246	M3	3.7	0.005
107246	L2	308.9	0.053
107246	2MK3	246	0.038
107246	K2	304.3	0.067
107246	M8	281.4	0.018
107246	MS4	347.8	0.016
107247	M2	297.3	0.624
107247	S2	324.1	0.149
107247	N2	279.1	0.131
107247	K1	192.1	0.219
107247	M4	321.8	0.119
107247	O1	153.3	0.146
107247	M6	133.9	0.029
107247	MK3	249.9	0.07
107247	S4	191.5	0.018
107247	MN4	316.4	0.036
107247	S6	318.8	0.002
107247	2N2	224.6	0.031
107247	OO1	343.8	0.02
107247	M1	163.4	0.011
107247	J1	233.5	0.009
107247	Q1	162.8	0.019
107247	2Q1	344.3	0.013
107247	P1	159.3	0.062
107247	2SM2	305.9	0.007
107247	M3	206.1	0.005
107247	L2	312	0.052
107247	2MK3	226.8	0.035
107247	K2	307.4	0.065
107247	M8	242.2	0.022
107247	MS4	338.9	0.024
107248	M2	298.2	2.072
107248	S2	328.2	0.447
107248	N2	279.9	0.408
107248	K1	202.9	0.856
107248	M4	121.2	0.14
107248	O1	182.4	0.486
107248	M6	309.3	0.102
107248	MK3	33	0.11
107248	S4	137.6	0.011
107248	MN4	127.7	0.044
107248	S6	96.8	0.01
107248	2N2	227.6	0.091
107248	OO1	291.6	0.098
107248	M1	224.3	0.025
107248	J1	215.1	0.042
107248	Q1	191.2	0.075
107248	2Q1	76.5	0.01
107248	P1	205.8	0.238
107248	2SM2	200.8	0.025
107248	M3	124.9	0.034
107248	L2	317.4	0.143
107248	2MK3	4.7	0.083
107248	K2	279.8	0.168
107248	M8	132.4	0.023
107248	MS4	139.4	0.048
107249	M2	298.3	2.131
107249	S2	328.8	0.462
107249	N2	280.6	0.42
107249	K1	202.9	0.881
107249	M4	121.4	0.144
107249	O1	181.9	0.499
107249	M6	310	0.102
107249	MK3	34.8	0.115
107249	S4	151.3	0.012
107249	MN4	127.7	0.05
107249	S6	102.9	0.01
107249	2N2	227.3	0.093
107249	OO1	287.7	0.099
107249	M1	225.4	0.027
107249	J1	218.4	0.045
107249	Q1	192	0.081
107249	2Q1	48.3	0.007
107249	P1	206.3	0.245
107249	2SM2	194.3	0.026
107249	M3	122.5	0.035
107249	L2	318.8	0.145
107249	2MK3	3.1	0.085
107249	K2	279.2	0.168
107249	M8	132.3	0.023
107249	MS4	145.4	0.052
107250	M2	298.4	2.165
107250	S2	328.9	0.47
107250	N2	281.3	0.428
107250	K1	203.3	0.89
107250	M4	121.3	0.147
107250	O1	181.9	0.508
107250	M6	311.4	0.101
107250	MK3	35.2	0.12
107250	S4	156	0.013
107250	MN4	125.5	0.056
107250	S6	108.4	0.009
107250	2N2	227.1	0.093
107250	OO1	285.4	0.102
107250	M1	227.7	0.028
107250	J1	219.3	0.046
107250	Q1	192.3	0.085
107250	2Q1	6.9	0.006
107250	P1	206.3	0.245
107250	2SM2	194	0.025
107250	M3	117.8	0.036
107250	L2	319.9	0.147
107250	2MK3	359.9	0.086
107250	K2	280.8	0.17
107250	M8	134.6	0.024
107250	MS4	148.5	0.057
107251	M2	298.6	2.188
107251	S2	328.6	0.474
107251	N2	281.7	0.432
107251	K1	203.7	0.894
107251	M4	121	0.149
107251	O1	182.4	0.514
107251	M6	313.1	0.099
107251	MK3	35	0.124
107251	S4	157.2	0.014
107251	MN4	122.6	0.06
107251	S6	114.7	0.008
107251	2N2	227	0.094
107251	OO1	283.7	0.105
107251	M1	230.1	0.03
107251	J1	219.1	0.046
107251	Q1	192	0.087
107251	2Q1	332.5	0.007
107251	P1	205.9	0.244
107251	2SM2	197	0.025
107251	M3	112.5	0.037
107251	L2	320.7	0.149
107251	2MK3	356.4	0.086
107251	K2	283.8	0.175
107251	M8	137.2	0.023
107251	MS4	149.9	0.063
107252	M2	298.8	2.203
107252	S2	328.1	0.478
107252	N2	282	0.435
107252	K1	204.1	0.892
107252	M4	120.8	0.15
107252	O1	183.1	0.519
107252	M6	314.7	0.097
107252	MK3	34.3	0.128
107252	S4	155.9	0.015
107252	MN4	119.9	0.064
107252	S6	120.2	0.006
107252	2N2	226.5	0.095
107252	OO1	282.6	0.11
107252	M1	232.2	0.031
107252	J1	219	0.046
107252	Q1	191	0.089
107252	2Q1	306.9	0.009
107252	P1	205.2	0.241
107252	2SM2	202.1	0.024
107252	M3	106.7	0.038
107252	L2	321.5	0.152
107252	2MK3	353	0.087
107252	K2	287.6	0.179
107252	M8	140	0.021
107252	MS4	150.3	0.068
107253	M2	298.9	2.211
107253	S2	327.4	0.48
107253	N2	282.2	0.435
107253	K1	204.5	0.889
107253	M4	121.2	0.149
107253	O1	183.9	0.521
107253	M6	316.1	0.094
107253	MK3	33.5	0.134
107253	S4	153.1	0.016
107253	MN4	118	0.066
107253	S6	123.7	0.005
107253	2N2	225.3	0.096
107253	OO1	282.1	0.113
107253	M1	232.7	0.032
107253	J1	219.6	0.046
107253	Q1	190.3	0.089
107253	2Q1	293.4	0.011
107253	P1	204.5	0.24
107253	2SM2	208.2	0.023
107253	M3	101.7	0.039
107253	L2	321.9	0.155
107253	2MK3	350	0.087
107253	K2	291.4	0.184
107253	M8	143.3	0.018
107253	MS4	150.7	0.072
107254	M2	299	2.211
107254	S2	327	0.48
107254	N2	282.4	0.432
107254	K1	204.9	0.886
107254	M4	122.8	0.145
107254	O1	184.5	0.521
107254	M6	317.6	0.092
107254	MK3	32.8	0.139
107254	S4	149.2	0.018
107254	MN4	117.3	0.067
107254	S6	126.8	0.004
107254	2N2	223.9	0.098
107254	OO1	281.3	0.114
107254	M1	232.4	0.032
107254	J1	219.9	0.045
107254	Q1	189.8	0.09
107254	2Q1	285.6	0.012
107254	P1	204.3	0.239
107254	2SM2	213	0.022
107254	M3	98.3	0.04
107254	L2	322.3	0.157
107254	2MK3	347.3	0.086
107254	K2	294	0.187
107254	M8	147.9	0.015
107254	MS4	152	0.075
107255	M2	298.9	2.186
107255	S2	326.6	0.463
107255	N2	282.3	0.419
107255	K1	204.6	0.873
107255	M4	124.3	0.121
107255	O1	183.6	0.509
107255	M6	319	0.08
107255	MK3	26.2	0.129
107255	S4	148.4	0.017
107255	MN4	116.8	0.058
107255	S6	116.6	0.005
107255	2N2	223.7	0.102
107255	OO1	283.1	0.115
107255	M1	233.1	0.029
107255	J1	219	0.04
107255	Q1	187.1	0.087
107255	2Q1	285.7	0.011
107255	P1	204.5	0.232
107255	2SM2	213.1	0.021
107255	M3	90.1	0.035
107255	L2	323	0.16
107255	2MK3	335.5	0.074
107255	K2	296.5	0.205
107255	M8	153	0.011
107255	MS4	155.9	0.068
107256	M2	253.3	0.436
107256	S2	274.3	0.088
107256	N2	257.7	0.061
107256	K1	143	0.117
107256	M4	217.5	0.142
107256	O1	99	0.084
107256	M6	311.7	0.035
107256	MK3	111.2	0.047
107256	S4	292.1	0.014
107256	MN4	193.3	0.065
107256	S6	320.5	0.015
107256	2N2	98.8	0.034
107256	OO1	328.7	0.033
107256	M1	146.5	0.011
107256	J1	49.8	0.011
107256	Q1	73.2	0.005
107256	2Q1	335.9	0.029
107256	P1	114	0.012
107256	2SM2	182.2	0.02
107256	M3	61.7	0.01
107256	L2	268.3	0.06
107256	2MK3	128.8	0.003
107256	M8	301.1	0.009
107256	MS4	250.8	0.073
107257	M2	253.8	0.453
107257	S2	274.9	0.091
107257	N2	258.6	0.063
107257	K1	142.8	0.125
107257	M4	216.5	0.145
107257	O1	98	0.092
107257	M6	310.6	0.033
107257	MK3	113.4	0.044
107257	S4	293.4	0.013
107257	MN4	192.9	0.065
107257	S6	317.3	0.014
107257	2N2	102.7	0.036
107257	OO1	325.7	0.035
107257	M1	149.3	0.01
107257	J1	49.2	0.012
107257	Q1	81	0.004
107257	2Q1	335.3	0.031
107257	P1	124.1	0.013
107257	2SM2	185.2	0.02
107257	M3	56.9	0.009
107257	L2	267.9	0.059
107257	2MK3	163.9	0.01
107257	M8	300.3	0.01
107257	MS4	251	0.077
107258	M2	254.3	0.465
107258	S2	276	0.093
107258	N2	259.7	0.066
107258	K1	142.7	0.133
107258	M4	214.9	0.147
107258	O1	97.4	0.099
107258	M6	308.4	0.031
107258	MK3	114.1	0.041
107258	S4	295.9	0.011
107258	MN4	192.6	0.065
107258	S6	311.7	0.012
107258	2N2	107.2	0.037
107258	OO1	323.1	0.036
107258	M1	147.2	0.01
107258	J1	53.5	0.012
107258	Q1	83	0.005
107258	2Q1	334.1	0.032
107258	P1	132.5	0.014
107258	2SM2	186.7	0.019
107258	M3	54.1	0.009
107258	L2	266.4	0.059
107258	2MK3	167.3	0.017
107258	M8	296.5	0.01
107258	MS4	250.2	0.079
107259	M2	255	0.477
107259	S2	277.3	0.094
107259	N2	260.3	0.068
107259	K1	141.9	0.141
107259	M4	213.3	0.15
107259	O1	97.1	0.106
107259	M6	306.3	0.029
107259	MK3	113.3	0.039
107259	S4	301.3	0.008
107259	MN4	191.2	0.066
107259	S6	306.1	0.009
107259	2N2	110.3	0.038
107259	OO1	319.9	0.036
107259	M1	147.5	0.01
107259	J1	53.9	0.012
107259	Q1	89.4	0.005
107259	2Q1	331.3	0.034
107259	P1	139.2	0.018
107259	2SM2	188.8	0.019
107259	M3	51.4	0.009
107259	L2	265.5	0.058
107259	2MK3	170.6	0.022
107259	M8	287.1	0.009
107259	MS4	248.9	0.079
107260	M2	255.8	0.487
107260	S2	278.2	0.095
107260	N2	261.2	0.07
107260	K1	141.7	0.151
107260	M4	211	0.153
107260	O1	96.9	0.112
107260	M6	302.9	0.025
107260	MK3	109.7	0.037
107260	S4	308.6	0.007
107260	MN4	190	0.066
107260	S6	296.9	0.008
107260	2N2	113.2	0.038
107260	OO1	316.5	0.038
107260	M1	145.3	0.01
107260	J1	50.2	0.012
107260	Q1	99.9	0.006
107260	2Q1	329.8	0.033
107260	P1	148.6	0.022
107260	2SM2	190.8	0.018
107260	M3	48.8	0.009
107260	L2	265.6	0.057
107260	2MK3	172.8	0.025
107260	M8	276.2	0.008
107260	MS4	247.6	0.08
107261	M2	256.7	0.498
107261	S2	279.5	0.097
107261	N2	262.3	0.073
107261	K1	141	0.159
107261	M4	209	0.157
107261	O1	97.1	0.119
107261	M6	298.5	0.021
107261	MK3	105	0.035
107261	S4	324.7	0.005
107261	MN4	189.4	0.066
107261	S6	285.3	0.007
107261	2N2	115.9	0.037
107261	OO1	313.9	0.041
107261	M1	145	0.011
107261	J1	41.9	0.013
107261	Q1	118.9	0.008
107261	2Q1	324.4	0.034
107261	P1	153	0.028
107261	2SM2	191.9	0.016
107261	M3	49.4	0.009
107261	L2	266.1	0.056
107261	2MK3	172.7	0.027
107261	M8	255.2	0.007
107261	MS4	245.4	0.079
107262	M2	257.6	0.506
107262	S2	280.7	0.099
107262	N2	262.9	0.076
107262	K1	139.7	0.165
107262	M4	206.5	0.16
107262	O1	97.3	0.124
107262	M6	292.1	0.017
107262	MK3	99.5	0.033
107262	S4	347.2	0.004
107262	MN4	188.5	0.065
107262	S6	275	0.008
107262	2N2	119.1	0.035
107262	OO1	310.1	0.043
107262	M1	145.3	0.012
107262	J1	35	0.013
107262	Q1	132.4	0.011
107262	2Q1	321.4	0.032
107262	P1	152.3	0.034
107262	2SM2	195.3	0.015
107262	M3	46.5	0.008
107262	L2	269.1	0.054
107262	2MK3	176.7	0.026
107262	M8	237.4	0.007
107262	MS4	242.3	0.078
107263	M2	258.6	0.513
107263	S2	281.8	0.101
107263	N2	263.9	0.079
107263	K1	138.8	0.167
107263	M4	203.7	0.163
107263	O1	98.2	0.129
107263	M6	282.9	0.014
107263	MK3	92.8	0.034
107263	S4	10.1	0.005
107263	MN4	187.5	0.065
107263	S6	259.5	0.009
107263	2N2	122.8	0.033
107263	OO1	309.7	0.043
107263	M1	147.4	0.013
107263	J1	27	0.015
107263	Q1	142.4	0.014
107263	2Q1	316.3	0.03
107263	P1	149.9	0.039
107263	2SM2	195.3	0.014
107263	M3	42.6	0.008
107263	L2	271.8	0.054
107263	2MK3	179.5	0.023
107263	M8	228.6	0.007
107263	MS4	238.3	0.076
107264	M2	259.4	0.518
107264	S2	282.9	0.101
107264	N2	264.3	0.08
107264	K1	137.5	0.169
107264	M4	200.9	0.166
107264	O1	100.1	0.131
107264	M6	269.8	0.011
107264	MK3	89.1	0.035
107264	S4	21.3	0.005
107264	MN4	186.5	0.064
107264	S6	245.2	0.011
107264	2N2	126	0.03
107264	OO1	307.1	0.046
107264	M1	149.7	0.015
107264	J1	22.7	0.017
107264	Q1	149	0.015
107264	2Q1	309.4	0.03
107264	P1	147.5	0.045
107264	2SM2	194.8	0.013
107264	M3	45.9	0.007
107264	L2	274.8	0.054
107264	2MK3	183.4	0.02
107264	M8	225.8	0.008
107264	MS4	234.9	0.073
107265	M2	260	0.522
107265	S2	283.2	0.101
107265	N2	264.7	0.08
107265	K1	135.5	0.168
107265	M4	198.6	0.168
107265	O1	103.1	0.134
107265	M6	250.6	0.008
107265	MK3	86.9	0.036
107265	S4	44.1	0.006
107265	MN4	186.5	0.063
107265	S6	237.4	0.012
107265	2N2	129.7	0.028
107265	OO1	306.7	0.049
107265	M1	152	0.017
107265	J1	18.4	0.02
107265	Q1	156.8	0.015
107265	2Q1	304.9	0.029
107265	P1	143.2	0.053
107265	2SM2	188.9	0.011
107265	M3	48.2	0.008
107265	L2	277.2	0.055
107265	2MK3	189.1	0.016
107265	M8	224.2	0.008
107265	MS4	232.4	0.07
107266	M2	260.8	0.523
107266	S2	284.1	0.1
107266	N2	265.7	0.079
107266	K1	134	0.169
107266	M4	196.4	0.171
107266	O1	106.6	0.136
107266	M6	228.4	0.007
107266	MK3	86.8	0.037
107266	S4	50.2	0.007
107266	MN4	187.2	0.063
107266	S6	234.4	0.013
107266	2N2	132.9	0.028
107266	OO1	308.3	0.053
107266	M1	153.2	0.019
107266	J1	9.7	0.022
107266	Q1	165.9	0.016
107266	2Q1	302.8	0.029
107266	P1	141.8	0.062
107266	2SM2	181	0.009
107266	M3	60.4	0.008
107266	L2	278.1	0.056
107266	2MK3	204.6	0.012
107266	M8	226.7	0.007
107266	MS4	230.1	0.067
107267	M2	261.4	0.523
107267	S2	284.9	0.099
107267	N2	266.7	0.078
107267	K1	131.4	0.169
107267	M4	194.6	0.173
107267	O1	110.7	0.139
107267	M6	213.2	0.005
107267	MK3	90.3	0.039
107267	S4	55.1	0.007
107267	MN4	187.7	0.065
107267	S6	231.7	0.012
107267	2N2	134.6	0.027
107267	OO1	312.5	0.053
107267	M1	155.7	0.021
107267	J1	1.7	0.025
107267	Q1	182.3	0.016
107267	2Q1	306	0.029
107267	P1	140.5	0.073
107267	2SM2	162.2	0.008
107267	M3	68.7	0.01
107267	L2	277.3	0.055
107267	2MK3	240.8	0.008
107267	M8	224.7	0.006
107267	MS4	229.5	0.066
107268	M2	262	0.521
107268	S2	285.9	0.099
107268	N2	267.5	0.078
107268	K1	129.3	0.17
107268	M4	193.9	0.174
107268	O1	113.4	0.141
107268	M6	167.9	0.002
107268	MK3	95.9	0.04
107268	S4	49.5	0.007
107268	MN4	187.6	0.067
107268	S6	229.3	0.01
107268	2N2	133.6	0.026
107268	OO1	318.2	0.056
107268	M1	153.4	0.023
107268	J1	355.5	0.026
107268	Q1	196.3	0.019
107268	2Q1	312	0.03
107268	P1	141.4	0.084
107268	2SM2	142.2	0.009
107268	M3	77.4	0.011
107268	L2	274.7	0.054
107268	2MK3	284.7	0.008
107268	M8	216.4	0.006
107268	MS4	230.3	0.065
107269	M2	262.8	0.52
107269	S2	287.3	0.098
107269	N2	268.2	0.078
107269	K1	128.3	0.171
107269	M4	193.9	0.174
107269	O1	116.2	0.144
107269	M6	94.5	0.005
107269	MK3	101.3	0.042
107269	S4	41.2	0.009
107269	MN4	186.7	0.069
107269	S6	222.6	0.008
107269	2N2	128.8	0.024
107269	OO1	323	0.057
107269	M1	150.9	0.024
107269	J1	350.3	0.029
107269	Q1	204.7	0.023
107269	2Q1	318.6	0.031
107269	P1	142.8	0.091
107269	2SM2	134.9	0.013
107269	M3	86.1	0.012
107269	L2	271.1	0.053
107269	2MK3	314.7	0.012
107269	M8	217.1	0.008
107269	MS4	232.2	0.064
107270	M2	263.4	0.517
107270	S2	288.5	0.097
107270	N2	269.5	0.08
107270	K1	130.9	0.165
107270	M4	195.1	0.169
107270	O1	119.3	0.145
107270	M6	87.2	0.01
107270	MK3	106.3	0.043
107270	S4	33.3	0.012
107270	MN4	186.6	0.069
107270	S6	209.7	0.006
107270	2N2	121.9	0.025
107270	OO1	326.5	0.063
107270	M1	146.1	0.023
107270	J1	350.6	0.031
107270	Q1	212	0.025
107270	2Q1	326.6	0.031
107270	P1	146.3	0.09
107270	2SM2	131.5	0.018
107270	M3	91	0.012
107270	L2	267.4	0.053
107270	2MK3	330.8	0.014
107270	M8	226.8	0.009
107270	MS4	234.6	0.062
107271	M2	281.4	0.535
107271	S2	311.9	0.138
107271	N2	295.3	0.094
107271	K1	186.3	0.162
107271	M4	213.7	0.072
107271	O1	170.4	0.073
107271	M6	178.3	0.019
107271	MK3	115.6	0.01
107271	MN4	201.7	0.021
107271	S6	17.1	0.004
107271	2N2	67.4	0.031
107271	OO1	290.7	0.04
107271	M1	41.9	0.007
107271	J1	273.5	0.021
107271	Q1	209.6	0.022
107271	2Q1	250.7	0.03
107271	P1	195.6	0.043
107271	2SM2	80.4	0.01
107271	M3	83.3	0.019
107271	L2	210.1	0.05
107271	2MK3	173.9	0.017
107271	M8	213.6	0.015
107271	MS4	252.6	0.043
107272	M2	286.4	0.504
107272	S2	320.6	0.144
107272	N2	277	0.091
107272	K1	189.9	0.2
107272	M4	224.6	0.095
107272	O1	141.1	0.045
107272	M6	85.3	0.008
107272	MK3	84	0.044
107272	S4	232	0.01
107272	MN4	217	0.042
107272	S6	209.4	0.004
107272	2N2	240.8	0.026
107272	OO1	283.7	0.031
107272	M1	70.4	0.016
107272	J1	229.3	0.007
107272	Q1	196.9	0.012
107272	2Q1	225.1	0.031
107272	P1	229.1	0.058
107272	2SM2	102.9	0.01
107272	M3	14.6	0.007
107272	L2	214.1	0.031
107272	2MK3	136	0.027
107272	M8	246.2	0.009
107272	MS4	251.7	0.05
107273	M2	288.3	0.458
107273	S2	322.2	0.146
107273	N2	270.3	0.084
107273	K1	182.5	0.219
107273	M4	223.3	0.059
107273	O1	147	0.067
107273	M6	56	0.021
107273	MK3	47.9	0.021
107273	S4	241.2	0.012
107273	MN4	213.1	0.034
107273	S6	235.4	0.011
107273	2N2	232	0.033
107273	OO1	249.9	0.027
107273	M1	93.1	0.014
107273	J1	42.3	0.007
107273	Q1	153.5	0.006
107273	2Q1	224	0.027
107273	P1	206	0.072
107273	2SM2	156.8	0.003
107273	M3	1.3	0.009
107273	L2	196.6	0.021
107273	2MK3	143.5	0.034
107273	M8	197.8	0.002
107273	MS4	252.7	0.03
107274	M2	320.4	0.506
107274	S2	3.6	0.12
107274	N2	315.9	0.127
107274	K1	257	0.258
107274	M4	132.2	0.047
107274	O1	282.2	0.204
107274	M6	342.5	0.013
107274	MK3	81.6	0.074
107274	S4	169.5	0.005
107274	MN4	131.7	0.015
107274	S6	39.5	0.003
107274	2N2	268.1	0.004
107274	OO1	252.7	0.078
107274	M1	0.4	0.019
107274	J1	227.6	0.036
107274	Q1	239.1	0.044
107274	2Q1	210.4	0.014
107274	P1	247.4	0.129
107274	2SM2	95.2	0.018
107274	M3	135.1	0.034
107274	L2	276.4	0.034
107274	2MK3	54.5	0.07
107274	K2	284.9	0.038
107274	M8	356	0.015
107274	MS4	190.4	0.029
107275	M2	320	0.531
107275	S2	5.6	0.124
107275	N2	314.7	0.132
107275	K1	255.9	0.27
107275	M4	128.2	0.044
107275	O1	281.4	0.205
107275	M6	344	0.015
107275	MK3	80.9	0.073
107275	S4	154	0.006
107275	MN4	124.8	0.013
107275	S6	40.5	0.003
107275	2N2	302.5	0.004
107275	OO1	249	0.081
107275	M1	2.4	0.02
107275	J1	233.2	0.035
107275	Q1	240.3	0.045
107275	2Q1	199.4	0.011
107275	P1	248.2	0.131
107275	2SM2	92	0.018
107275	M3	142	0.034
107275	L2	277.9	0.038
107275	2MK3	57.6	0.068
107275	K2	284.5	0.045
107275	M8	354	0.014
107275	MS4	190.7	0.028
107276	M2	320	0.549
107276	S2	5.1	0.128
107276	N2	313.6	0.135
107276	K1	254.4	0.278
107276	M4	124.2	0.043
107276	O1	280.5	0.206
107276	M6	346.4	0.017
107276	MK3	79.8	0.072
107276	S4	147.2	0.006
107276	MN4	115.4	0.012
107276	S6	51.9	0.003
107276	2N2	323.2	0.006
107276	OO1	245.1	0.081
107276	M1	4.5	0.02
107276	J1	239.3	0.034
107276	Q1	243.1	0.045
107276	2Q1	180	0.009
107276	P1	248.8	0.134
107276	2SM2	90.1	0.019
107276	M3	148	0.034
107276	L2	280.1	0.04
107276	2MK3	60.2	0.067
107276	K2	288.2	0.045
107276	M8	353.1	0.014
107276	MS4	188.6	0.026
107277	M2	320.1	0.564
107277	S2	4.5	0.132
107277	N2	312.5	0.137
107277	K1	252.6	0.282
107277	M4	121.8	0.042
107277	O1	279.4	0.205
107277	M6	345.7	0.017
107277	MK3	78.6	0.072
107277	S4	142.6	0.006
107277	MN4	103	0.011
107277	S6	65.9	0.003
107277	2N2	329.1	0.009
107277	OO1	241.6	0.08
107277	M1	6.6	0.019
107277	J1	245.3	0.034
107277	Q1	244	0.045
107277	2Q1	159.4	0.01
107277	P1	248.5	0.137
107277	2SM2	89.9	0.018
107277	M3	153.9	0.034
107277	L2	281.9	0.041
107277	2MK3	63.5	0.066
107277	K2	291.6	0.045
107277	M8	349.7	0.013
107277	MS4	184.8	0.024
107278	M2	320.3	0.575
107278	S2	3.9	0.136
107278	N2	311.3	0.137
107278	K1	250.3	0.285
107278	M4	120.6	0.042
107278	O1	277.7	0.203
107278	M6	345.5	0.016
107278	MK3	78.3	0.072
107278	S4	119.4	0.004
107278	MN4	91.2	0.011
107278	S6	76	0.003
107278	2N2	328.7	0.011
107278	OO1	238.2	0.076
107278	M1	9	0.019
107278	J1	251.1	0.035
107278	Q1	244.3	0.043
107278	2Q1	146.2	0.011
107278	P1	247.8	0.14
107278	2SM2	90.6	0.017
107278	M3	158.8	0.034
107278	L2	283.1	0.042
107278	2MK3	67.2	0.065
107278	K2	295.2	0.044
107278	M8	345	0.011
107278	MS4	179.7	0.023
107279	M2	320.8	0.583
107279	S2	2.8	0.14
107279	N2	310	0.136
107279	K1	248.5	0.286
107279	M4	120.4	0.042
107279	O1	275.7	0.199
107279	M6	340.3	0.015
107279	MK3	78.7	0.074
107279	S4	75.8	0.003
107279	MN4	85.3	0.012
107279	S6	80.8	0.003
107279	2N2	318.8	0.013
107279	OO1	236.3	0.073
107279	M1	10.7	0.018
107279	J1	254.1	0.036
107279	Q1	242.4	0.041
107279	2Q1	144.5	0.012
107279	P1	246.7	0.14
107279	2SM2	92.6	0.014
107279	M3	163.9	0.032
107279	L2	284.7	0.04
107279	2MK3	70.5	0.062
107279	K2	301.3	0.04
107279	M8	336.4	0.01
107279	MS4	174.1	0.021
107280	M2	321.4	0.591
107280	S2	1	0.145
107280	N2	308.6	0.135
107280	K1	247.1	0.287
107280	M4	119.2	0.043
107280	O1	273.7	0.193
107280	M6	334.9	0.014
107280	MK3	78.9	0.076
107280	S4	37.2	0.005
107280	MN4	86.1	0.013
107280	S6	85.3	0.002
107280	2N2	308.3	0.015
107280	OO1	235.8	0.068
107280	M1	12.3	0.017
107280	J1	253.5	0.036
107280	Q1	240.2	0.039
107280	2Q1	144.2	0.012
107280	P1	246.4	0.138
107280	2SM2	95.2	0.011
107280	M3	169	0.031
107280	L2	287.2	0.038
107280	2MK3	73.7	0.061
107280	K2	312.6	0.036
107280	M8	330	0.01
107280	MS4	167.6	0.019
107281	M2	322	0.597
107281	S2	0	0.151
107281	N2	307.4	0.135
107281	K1	246.3	0.288
107281	M4	118.1	0.041
107281	O1	271.3	0.186
107281	M6	328.7	0.014
107281	MK3	78.9	0.079
107281	S4	21.8	0.007
107281	MN4	87.8	0.015
107281	S6	64.1	0.001
107281	2N2	299.1	0.017
107281	OO1	235.5	0.065
107281	M1	12.5	0.015
107281	J1	252.9	0.035
107281	Q1	238.3	0.037
107281	2Q1	151.6	0.011
107281	P1	246.4	0.134
107281	2SM2	97.4	0.007
107281	M3	174.9	0.029
107281	L2	291.4	0.036
107281	2MK3	76.8	0.059
107281	K2	322.3	0.031
107281	M8	327	0.01
107281	MS4	162.9	0.018
107282	M2	322.7	0.603
107282	S2	359	0.156
107282	N2	306.4	0.134
107282	K1	245.8	0.287
107282	M4	118.2	0.041
107282	O1	268.3	0.178
107282	M6	322.4	0.014
107282	MK3	79.4	0.081
107282	S4	20.4	0.008
107282	MN4	89.5	0.016
107282	S6	330.2	0.001
107282	2N2	288.8	0.018
107282	OO1	234.9	0.063
107282	M1	11.5	0.014
107282	J1	250.1	0.034
107282	Q1	236.7	0.036
107282	2Q1	160.9	0.011
107282	P1	246.3	0.129
107282	2SM2	90.6	0.004
107282	M3	180.8	0.027
107282	L2	294.7	0.033
107282	2MK3	79.5	0.055
107282	K2	333.1	0.03
107282	M8	321.7	0.01
107282	MS4	160.3	0.017
107283	M2	323.5	0.609
107283	S2	357.3	0.158
107283	N2	305.9	0.134
107283	K1	245.4	0.286
107283	M4	119.8	0.039
107283	O1	265.1	0.171
107283	M6	317	0.016
107283	MK3	80.1	0.082
107283	S4	16	0.007
107283	MN4	92.8	0.018
107283	S6	286.3	0.002
107283	2N2	278	0.019
107283	OO1	235.9	0.062
107283	M1	8.8	0.012
107283	J1	248.7	0.034
107283	Q1	235.5	0.035
107283	2Q1	181.2	0.012
107283	P1	246.9	0.124
107283	2SM2	53.9	0.002
107283	M3	186.8	0.024
107283	L2	299.5	0.031
107283	2MK3	82	0.051
107283	K2	341.2	0.033
107283	M8	315.4	0.009
107283	MS4	161.6	0.018
107284	M2	324.3	0.614
107284	S2	355.7	0.159
107284	N2	305.6	0.134
107284	K1	245	0.286
107284	M4	124	0.036
107284	O1	261.6	0.163
107284	M6	309.8	0.016
107284	MK3	82	0.083
107284	S4	14.4	0.006
107284	MN4	95.2	0.019
107284	S6	280.8	0.003
107284	2N2	269.7	0.019
107284	OO1	239.6	0.062
107284	M1	7.4	0.011
107284	J1	247.9	0.032
107284	Q1	233.9	0.033
107284	2Q1	200	0.014
107284	P1	247.8	0.119
107284	2SM2	340.5	0.002
107284	M3	192.8	0.022
107284	L2	306.3	0.029
107284	2MK3	85.1	0.046
107284	K2	346.6	0.037
107284	M8	308	0.009
107284	MS4	163.9	0.019
107285	M2	325.2	0.618
107285	S2	353.8	0.162
107285	N2	305.7	0.134
107285	K1	244.6	0.286
107285	M4	129.7	0.035
107285	O1	257.2	0.156
107285	M6	303.5	0.016
107285	MK3	84.1	0.084
107285	S4	13.6	0.004
107285	MN4	100.8	0.019
107285	S6	275.9	0.004
107285	2N2	261.4	0.02
107285	OO1	243.7	0.062
107285	M1	7.3	0.009
107285	J1	248.9	0.029
107285	Q1	234.4	0.031
107285	2Q1	215.2	0.017
107285	P1	248.3	0.113
107285	2SM2	313.7	0.005
107285	M3	198.7	0.019
107285	L2	314	0.027
107285	2MK3	87.4	0.041
107285	K2	354	0.042
107285	M8	297.7	0.008
107285	MS4	169.6	0.022
107286	M2	326	0.621
107286	S2	352.2	0.164
107286	N2	306.2	0.135
107286	K1	244	0.283
107286	M4	137.4	0.033
107286	O1	252.1	0.15
107286	M6	299.4	0.014
107286	MK3	86	0.084
107286	S4	4.6	0.002
107286	MN4	106.2	0.018
107286	S6	269.9	0.005
107286	2N2	255.5	0.022
107286	OO1	251.1	0.062
107286	M1	5.7	0.008
107286	J1	248.7	0.027
107286	Q1	236.5	0.029
107286	2Q1	224.2	0.02
107286	P1	247.9	0.107
107286	2SM2	308	0.007
107286	M3	206.2	0.015
107286	L2	323.1	0.025
107286	2MK3	90.2	0.034
107286	K2	358.7	0.048
107286	M8	285.2	0.007
107286	MS4	173.4	0.025
107287	M2	326.9	0.623
107287	S2	350.7	0.166
107287	N2	306.9	0.135
107287	K1	243.1	0.279
107287	M4	145.3	0.032
107287	O1	246.2	0.145
107287	M6	296.3	0.012
107287	MK3	87.6	0.083
107287	S4	305.3	0.001
107287	MN4	114.8	0.017
107287	S6	271.2	0.006
107287	2N2	249.5	0.024
107287	OO1	256.6	0.062
107287	M1	355.7	0.006
107287	J1	253.5	0.026
107287	Q1	239.9	0.03
107287	2Q1	233	0.024
107287	P1	246.7	0.101
107287	2SM2	303.5	0.009
107287	M3	212.8	0.012
107287	L2	334.1	0.024
107287	2MK3	93.8	0.028
107287	K2	3.8	0.053
107287	M8	262.9	0.006
107287	MS4	176.2	0.028
107288	M2	327.7	0.625
107288	S2	350.1	0.167
107288	N2	307.5	0.134
107288	K1	241.8	0.274
107288	M4	153.6	0.031
107288	O1	240.3	0.142
107288	M6	294	0.01
107288	MK3	88.7	0.08
107288	S4	260.7	0.003
107288	MN4	122.7	0.015
107288	S6	275.3	0.007
107288	2N2	248.4	0.028
107288	OO1	261.4	0.063
107288	M1	328.1	0.004
107288	J1	259.2	0.024
107288	Q1	239.6	0.031
107288	2Q1	239.1	0.027
107288	P1	245	0.097
107288	2SM2	300.7	0.011
107288	M3	220.5	0.009
107288	L2	346	0.024
107288	2MK3	98.7	0.022
107288	K2	5.9	0.057
107288	M8	239.6	0.005
107288	MS4	178.5	0.03
107289	M2	328.3	0.625
107289	S2	349.7	0.168
107289	N2	308.3	0.133
107289	K1	239.9	0.269
107289	M4	159.9	0.03
107289	O1	234.4	0.139
107289	M6	298.6	0.008
107289	MK3	88.8	0.078
107289	S4	244.3	0.004
107289	MN4	132	0.015
107289	S6	273.5	0.007
107289	2N2	248.5	0.031
107289	OO1	267.2	0.064
107289	M1	274.6	0.004
107289	J1	267.4	0.023
107289	Q1	236.1	0.033
107289	2Q1	244.1	0.029
107289	P1	242.4	0.092
107289	2SM2	295.7	0.011
107289	M3	226.6	0.007
107289	L2	359	0.025
107289	2MK3	105.9	0.017
107289	K2	8.3	0.06
107289	M8	217.4	0.005
107289	MS4	180.4	0.033
107290	M2	328.9	0.626
107290	S2	349.6	0.168
107290	N2	308.8	0.131
107290	K1	237.2	0.267
107290	M4	167.7	0.028
107290	O1	228.3	0.138
107290	M6	308.2	0.006
107290	MK3	88.2	0.073
107290	S4	239.5	0.004
107290	MN4	139.9	0.013
107290	S6	275.3	0.006
107290	2N2	250.2	0.035
107290	OO1	271.9	0.066
107290	M1	247.6	0.007
107290	J1	279	0.023
107290	Q1	231	0.035
107290	2Q1	250.5	0.033
107290	P1	240.7	0.091
107290	2SM2	285.7	0.012
107290	M3	231.1	0.005
107290	L2	10.7	0.026
107290	2MK3	117.1	0.011
107290	K2	9.9	0.063
107290	M8	194.6	0.003
107290	MS4	180.7	0.035
107291	M2	329.2	0.626
107291	S2	349.8	0.165
107291	N2	309.1	0.129
107291	K1	233.8	0.266
107291	M4	175.5	0.029
107291	O1	223.1	0.138
107291	M6	324.6	0.005
107291	MK3	87.5	0.069
107291	S4	233.7	0.005
107291	MN4	142.8	0.013
107291	S6	269.3	0.006
107291	2N2	253.6	0.037
107291	OO1	276.8	0.07
107291	M1	240.3	0.01
107291	J1	288.7	0.023
107291	Q1	228.7	0.037
107291	2Q1	255.2	0.035
107291	P1	237.5	0.092
107291	2SM2	277.4	0.011
107291	M3	250.3	0.005
107291	L2	18.8	0.028
107291	2MK3	148.2	0.008
107291	K2	8.9	0.064
107291	M8	173.3	0.002
107291	MS4	180.5	0.037
107292	M2	329.5	0.626
107292	S2	349.2	0.163
107292	N2	309.2	0.128
107292	K1	231.7	0.266
107292	M4	184.1	0.028
107292	O1	218.5	0.141
107292	M6	351.2	0.005
107292	MK3	86.7	0.063
107292	S4	241.6	0.004
107292	MN4	146.1	0.013
107292	S6	262.5	0.006
107292	2N2	259.8	0.039
107292	OO1	282.4	0.074
107292	M1	238.2	0.012
107292	J1	296.5	0.022
107292	Q1	226.2	0.037
107292	2Q1	260.3	0.036
107292	P1	235.8	0.089
107292	2SM2	268.5	0.011
107292	M3	267.8	0.005
107292	L2	23.6	0.03
107292	2MK3	177.4	0.01
107292	K2	7.9	0.068
107292	M8	118.6	0.001
107292	MS4	180.4	0.04
107293	M2	329.4	0.627
107293	S2	348	0.16
107293	N2	309.1	0.127
107293	K1	230.1	0.27
107293	M4	193.2	0.029
107293	O1	214.9	0.145
107293	M6	2.2	0.007
107293	MK3	86.5	0.056
107293	S4	275.2	0.004
107293	MN4	148.1	0.013
107293	S6	260	0.006
107293	2N2	266.6	0.04
107293	OO1	285.6	0.076
107293	M1	236	0.014
107293	J1	301.5	0.022
107293	Q1	222.8	0.037
107293	2Q1	266.4	0.036
107293	P1	235.4	0.087
107293	2SM2	260.2	0.01
107293	M3	270.9	0.004
107293	L2	23.9	0.03
107293	2MK3	189.2	0.015
107293	K2	7.4	0.073
107293	MS4	179.6	0.042
107294	M2	328.9	0.628
107294	S2	346.5	0.159
107294	N2	308.9	0.125
107294	K1	228	0.275
107294	M4	199.9	0.03
107294	O1	211.7	0.148
107294	M6	9.4	0.009
107294	MK3	86.6	0.047
107294	S4	315.9	0.004
107294	MN4	151.1	0.012
107294	S6	257.5	0.006
107294	2N2	272.2	0.039
107294	OO1	286.5	0.075
107294	M1	229.7	0.016
107294	J1	303.8	0.021
107294	Q1	222.3	0.035
107294	2Q1	273.2	0.034
107294	P1	233.2	0.086
107294	2SM2	249.8	0.008
107294	M3	285	0.005
107294	L2	21.4	0.032
107294	2MK3	195.3	0.025
107294	K2	10	0.08
107294	M8	337.4	0.002
107294	MS4	178	0.044
107295	M2	325.2	0.592
107295	S2	336.9	0.137
107295	N2	305.7	0.108
107295	K1	211.5	0.241
107295	M4	258.2	0.011
107295	O1	187.1	0.117
107295	M6	338.9	0.005
107295	MK3	36.9	0.023
107295	S4	321.6	0.005
107295	MN4	173.4	0.004
107295	S6	278.8	0.003
107295	2N2	291.4	0.043
107295	OO1	298.2	0.058
107295	M1	218.3	0.012
107295	J1	346.2	0.018
107295	Q1	180.5	0.022
107295	2Q1	283.3	0.025
107295	P1	208.8	0.087
107295	2SM2	255.6	0.003
107295	M3	320.9	0.012
107295	L2	7.8	0.037
107295	2MK3	227.7	0.063
107295	K2	10.6	0.11
107295	M8	343.7	0.004
107295	MS4	178.7	0.026
107296	M2	315.7	0.538
107296	S2	351	0.152
107296	N2	296.1	0.12
107296	K1	238.9	0.227
107296	M4	150.5	0.063
107296	O1	237.3	0.114
107296	M6	51.9	0.015
107296	MK3	59.4	0.037
107296	S4	340.3	0.003
107296	MN4	127.8	0.026
107296	S6	91.5	0.004
107296	2N2	310.8	0.011
107296	OO1	272.1	0.075
107296	M1	281.9	0.008
107296	J1	281.4	0.027
107296	Q1	237.7	0.04
107296	2Q1	242.4	0.022
107296	P1	240.6	0.069
107296	2SM2	141.4	0.005
107296	M3	305.8	0.003
107296	L2	306.2	0.03
107296	2MK3	101.6	0.009
107296	K2	346.7	0.029
107296	M8	246.2	0.007
107296	MS4	193.9	0.014
107297	M2	310.3	0.555
107297	S2	342.2	0.122
107297	N2	292.6	0.125
107297	K1	248.1	0.17
107297	M4	139.8	0.033
107297	O1	281.3	0.106
107297	M6	32.2	0.012
107297	MK3	83.7	0.043
107297	S4	261.6	0.005
107297	MN4	140.7	0.024
107297	S6	100.1	0.004
107297	2N2	284	0.015
107297	OO1	268.2	0.069
107297	M1	22.7	0.007
107297	J1	271.5	0.016
107297	Q1	261.9	0.026
107297	2Q1	244.6	0.033
107297	P1	246.2	0.079
107297	2SM2	187.1	0.007
107297	M3	108.2	0.01
107297	L2	280.2	0.027
107297	2MK3	35.1	0.013
107297	K2	331.7	0.047
107297	M8	181.3	0.001
107297	MS4	157.9	0.024
107298	M2	307.3	0.529
107298	S2	333.1	0.102
107298	N2	286.2	0.109
107298	K1	242.1	0.135
107298	M4	152.7	0.008
107298	O1	296.1	0.092
107298	M6	79.1	0.02
107298	MK3	90.5	0.028
107298	S4	250.4	0.013
107298	MN4	153.7	0.013
107298	S6	92.5	0.004
107298	2N2	252.1	0.025
107298	OO1	276.8	0.044
107298	M1	62.2	0.006
107298	J1	355.8	0.007
107298	Q1	294.3	0.014
107298	2Q1	256.4	0.016
107298	P1	244.4	0.074
107298	2SM2	151.2	0.015
107298	M3	106.2	0.008
107298	L2	282	0.035
107298	2MK3	140.9	0.014
107298	K2	334.8	0.064
107298	M8	228.2	0.007
107298	MS4	167.7	0.017
107299	M2	307.4	0.726
107299	S2	337.3	0.169
107299	N2	287.2	0.146
107299	K1	203.9	0.221
107299	M4	241	0.052
107299	O1	174.3	0.139
107299	M6	299.7	0.021
107299	MK3	82.7	0.047
107299	S4	217.3	0.013
107299	MN4	286.4	0.015
107299	S6	124	0.001
107299	2N2	276.8	0.03
107299	OO1	267.1	0.116
107299	M1	184.3	0.015
107299	J1	316.7	0.037
107299	Q1	214.9	0.025
107299	2Q1	307	0.049
107299	P1	242.1	0.041
107299	2SM2	174.1	0.01
107299	M3	190.9	0.028
107299	L2	300.9	0.071
107299	2MK3	72.8	0.055
107299	K2	342.8	0.088
107299	M8	2.8	0.016
107299	MS4	221.3	0.026
107300	M2	326.5	0.561
107300	S2	354.8	0.145
107300	N2	314.8	0.132
107300	K1	230.1	0.298
107300	M4	165.7	0.05
107300	O1	237.2	0.116
107300	M6	27.4	0.027
107300	MK3	100.5	0.045
107300	S4	207.6	0.012
107300	MN4	152.4	0.031
107300	S6	329.7	0.01
107300	2N2	310.5	0.01
107300	OO1	243.3	0.021
107300	M1	302.9	0.009
107300	J1	253	0.029
107300	Q1	262.4	0.014
107300	2Q1	200.7	0.02
107300	P1	235.1	0.106
107300	2SM2	19.9	0.008
107300	M3	181.3	0.012
107300	L2	32.6	0.025
107300	2MK3	98.2	0.025
107300	K2	358.4	0.055
107300	M8	115.4	0.008
107300	MS4	208.7	0.025
107301	M2	325	0.478
107301	S2	353.4	0.13
107301	N2	303.5	0.123
107301	K1	239.5	0.286
107301	M4	163	0.078
107301	O1	276.4	0.143
107301	M6	15.5	0.033
107301	MK3	56.3	0.085
107301	S4	212.2	0.011
107301	MN4	151.6	0.051
107301	S6	97.3	0.004
107301	2N2	261.6	0.011
107301	OO1	190.6	0.049
107301	M1	312.8	0.015
107301	J1	206.5	0.05
107301	Q1	332.1	0.02
107301	2Q1	147.3	0.045
107301	P1	243.5	0.089
107301	2SM2	336.8	0.013
107301	M3	118.8	0.025
107301	L2	95.8	0.031
107301	2MK3	243.4	0.012
107301	K2	77.1	0.035
107301	M8	170	0.013
107301	MS4	118.2	0.014
107302	M2	290.3	0.222
107302	S2	312.5	0.06
107302	N2	271.1	0.036
107302	K1	171	0.089
107302	M4	171.1	0.013
107302	O1	151.1	0.074
107302	M6	54.3	0.017
107302	MK3	52.4	0.026
107302	S4	184.1	0.005
107302	MN4	182.5	0.006
107302	S6	149.4	0.003
107302	2N2	270.6	0.018
107302	OO1	237	0.01
107302	M1	152.3	0.01
107302	J1	224.9	0.007
107302	Q1	214.4	0.003
107302	2Q1	41.3	0.013
107302	P1	190.6	0.046
107302	2SM2	175.9	0.011
107302	M3	123.2	0.015
107302	L2	279.7	0.013
107302	2MK3	357.8	0.022
107302	K2	299.9	0.023
107302	MS4	189.5	0.013
107303	M2	274.9	0.349
107303	S2	307.7	0.092
107303	N2	254.4	0.069
107303	K1	132.2	0.127
107303	M4	160.3	0.04
107303	O1	143.2	0.07
107303	M6	71.5	0.013
107303	MK3	40.6	0.023
107303	S4	298.4	0.003
107303	MN4	144.1	0.021
107303	S6	98.2	0.002
107303	2N2	139.6	0.006
107303	OO1	76.6	0.014
107303	M1	23.9	0.008
107303	J1	322.8	0.017
107303	Q1	143.1	0.032
107303	2Q1	108.6	0.011
107303	P1	158.4	0.061
107303	2SM2	143.3	0.007
107303	M3	67.4	0.009
107303	L2	292.9	0.037
107303	2MK3	356.8	0.01
107303	K2	59	0.011
107303	M8	59.4	0.005
107303	MS4	208.7	0.009
107304	M2	270.5	0.388
107304	S2	308.2	0.099
107304	N2	249.8	0.073
107304	K1	137.1	0.097
107304	M4	151.7	0.044
107304	O1	170.3	0.036
107304	M6	52.6	0.019
107304	MK3	16.6	0.038
107304	S4	104	0.006
107304	MN4	111.9	0.031
107304	S6	97.2	0.004
107304	2N2	127.1	0.009
107304	OO1	318.4	0.033
107304	M1	298.3	0.013
107304	J1	142.9	0.008
107304	Q1	103.4	0.008
107304	2Q1	199.2	0.007
107304	P1	133.4	0.044
107304	2SM2	129.5	0.016
107304	M3	46.3	0.009
107304	L2	290.7	0.052
107304	2MK3	306	0.011
107304	K2	281.2	0.015
107304	M8	99.8	0.006
107304	MS4	194	0.014
107305	M2	283.7	0.202
107305	S2	327.7	0.049
107305	N2	269.7	0.009
107305	K1	182.8	0.325
107305	M4	81.8	0.008
107305	O1	154.8	0.216
107305	M6	25.4	0.005
107305	MK3	273	0.015
107305	S4	49.2	0.001
107305	MN4	111	0.013
107305	S6	97.8	0.004
107305	2N2	226.6	0.017
107305	OO1	73.4	0.014
107305	M1	146.4	0.028
107305	J1	64.1	0.014
107305	Q1	116.1	0.042
107305	2Q1	126.2	0.03
107305	2SM2	142.4	0.012
107305	M3	137.3	0.017
107305	L2	224.6	0.016
107305	2MK3	261.9	0.021
107305	K2	279.9	0.03
107305	M8	20.4	0.002
107305	MS4	124.5	0.003
107306	M2	283.8	0.205
107306	S2	329	0.047
107306	N2	261.1	0.009
107306	K1	183.1	0.321
107306	M4	72.3	0.008
107306	O1	156	0.213
107306	M6	22.5	0.005
107306	MK3	283.6	0.014
107306	S4	34.3	0.003
107306	MN4	105.7	0.012
107306	S6	111.1	0.003
107306	2N2	223.6	0.018
107306	OO1	76.2	0.017
107306	M1	147.7	0.028
107306	J1	68.3	0.015
107306	Q1	116.5	0.044
107306	2Q1	130.9	0.028
107306	2SM2	143.2	0.013
107306	M3	133.7	0.017
107306	L2	225.6	0.015
107306	2MK3	262.2	0.02
107306	K2	284.2	0.026
107306	M8	350.9	0.003
107306	MS4	141.8	0.004
107307	M2	282.9	0.204
107307	S2	330.1	0.045
107307	N2	250.6	0.009
107307	K1	183.5	0.315
107307	M4	71.4	0.009
107307	O1	157.4	0.208
107307	M6	20.4	0.004
107307	MK3	297.4	0.015
107307	S4	39.8	0.004
107307	MN4	98.9	0.01
107307	S6	118.2	0.003
107307	2N2	220.2	0.019
107307	OO1	84.3	0.017
107307	M1	148.9	0.028
107307	J1	72	0.015
107307	Q1	115.4	0.044
107307	2Q1	132.4	0.027
107307	2SM2	145.4	0.013
107307	M3	131.9	0.017
107307	L2	232.8	0.016
107307	2MK3	263.4	0.019
107307	K2	291.6	0.022
107307	M8	349.6	0.002
107307	MS4	142.5	0.005
107308	M2	281.7	0.2
107308	S2	322.9	0.045
107308	N2	230.9	0.011
107308	K1	183.8	0.303
107308	M4	68	0.01
107308	O1	158.6	0.2
107308	M6	23.7	0.005
107308	MK3	309.9	0.017
107308	S4	42.6	0.004
107308	MN4	87.4	0.009
107308	S6	122.5	0.004
107308	2N2	219.8	0.019
107308	OO1	93.9	0.019
107308	M1	147.8	0.028
107308	J1	71.4	0.015
107308	Q1	113.8	0.042
107308	2Q1	129.5	0.027
107308	2SM2	144.9	0.014
107308	M3	130.1	0.017
107308	L2	238.5	0.017
107308	2MK3	265.3	0.017
107308	K2	291.3	0.027
107308	M8	11.2	0.001
107308	MS4	130.3	0.004
107309	M2	280.8	0.2
107309	S2	318.2	0.044
107309	N2	222.6	0.012
107309	K1	184.6	0.299
107309	M4	66.1	0.011
107309	O1	159.3	0.197
107309	M6	28.9	0.004
107309	MK3	319.9	0.016
107309	S4	45.4	0.003
107309	MN4	74.4	0.008
107309	S6	122.5	0.004
107309	2N2	222.6	0.021
107309	OO1	98.2	0.02
107309	M1	148.6	0.027
107309	J1	73.9	0.016
107309	Q1	113.1	0.042
107309	2Q1	130.3	0.025
107309	2SM2	146	0.012
107309	M3	132	0.016
107309	L2	242.9	0.018
107309	2MK3	266.7	0.015
107309	K2	287.6	0.03
107309	M8	55.6	0.001
107309	MS4	104.6	0.003
107310	M2	280	0.201
107310	S2	314.5	0.044
107310	N2	221.9	0.013
107310	K1	185.3	0.298
107310	M4	66.2	0.012
107310	O1	160.3	0.197
107310	M6	26.1	0.004
107310	MK3	324.8	0.016
107310	S4	53.6	0.002
107310	MN4	62.5	0.008
107310	S6	122.7	0.003
107310	2N2	228.5	0.022
107310	OO1	100.4	0.02
107310	M1	149.2	0.027
107310	J1	77.4	0.015
107310	Q1	112.2	0.042
107310	2Q1	133.5	0.024
107310	2SM2	152.3	0.01
107310	M3	131.5	0.016
107310	L2	245.9	0.019
107310	2MK3	270.1	0.013
107310	K2	284.5	0.032
107310	M8	73.4	0.001
107310	MS4	54.8	0.003
107311	M2	279.6	0.202
107311	S2	315.3	0.045
107311	N2	226.2	0.014
107311	K1	186	0.295
107311	M4	63.1	0.011
107311	O1	161	0.197
107311	M6	32	0.004
107311	MK3	325.6	0.017
107311	S4	18	0.001
107311	MN4	57.6	0.008
107311	S6	136.6	0.002
107311	2N2	232.9	0.023
107311	OO1	104.5	0.016
107311	M1	149.7	0.026
107311	J1	75.4	0.014
107311	Q1	112.6	0.041
107311	2Q1	139.3	0.023
107311	2SM2	164.2	0.008
107311	M3	131.1	0.014
107311	L2	244.6	0.019
107311	2MK3	277.8	0.013
107311	K2	291	0.033
107311	M8	55	0.001
107311	MS4	25.9	0.004
107312	M2	279.7	0.204
107312	S2	319	0.05
107312	N2	234.3	0.016
107312	K1	186.6	0.293
107312	M4	58.8	0.011
107312	O1	161.9	0.198
107312	M6	33.9	0.004
107312	MK3	327.4	0.017
107312	S4	314.7	0.001
107312	MN4	46.3	0.006
107312	S6	100.7	0.001
107312	2N2	238.8	0.024
107312	OO1	106.8	0.011
107312	M1	149.3	0.026
107312	J1	69.6	0.012
107312	Q1	113.7	0.041
107312	2Q1	141.8	0.023
107312	2SM2	175.3	0.006
107312	M3	132	0.014
107312	L2	240.4	0.018
107312	2MK3	282.5	0.013
107312	K2	301.3	0.037
107312	M8	65.2	0.001
107312	MS4	13.7	0.008
107313	M2	280.1	0.206
107313	S2	319.5	0.056
107313	N2	237.2	0.019
107313	K1	187	0.287
107313	M4	47.4	0.01
107313	O1	162.7	0.197
107313	M6	38.5	0.005
107313	MK3	331.9	0.017
107313	MN4	21	0.006
107313	S6	99.3	0.001
107313	2N2	242.7	0.026
107313	OO1	114	0.005
107313	M1	147.7	0.025
107313	J1	61.6	0.01
107313	Q1	116.8	0.039
107313	2Q1	143.4	0.023
107313	2SM2	200.2	0.004
107313	M3	131.5	0.015
107313	L2	235.8	0.017
107313	2MK3	279.9	0.013
107313	K2	304.3	0.043
107313	M8	31.1	0.001
107313	MS4	5.3	0.01
107314	M2	280.6	0.207
107314	S2	317.1	0.061
107314	N2	242.8	0.024
107314	K1	187.4	0.28
107314	M4	40.7	0.011
107314	O1	163.7	0.195
107314	M6	39.2	0.007
107314	MK3	340.4	0.019
107314	S4	120.1	0.001
107314	MN4	6.3	0.005
107314	S6	194.3	0.001
107314	2N2	244.6	0.026
107314	OO1	223.1	0.004
107314	M1	147.3	0.023
107314	J1	57.4	0.008
107314	Q1	119.2	0.037
107314	2Q1	143.5	0.023
107314	2SM2	223.8	0.002
107314	M3	125.1	0.015
107314	L2	231	0.016
107314	2MK3	270.9	0.012
107314	K2	301	0.046
107314	M8	0.9	0.002
107314	MS4	355.7	0.011
107315	M2	281.6	0.209
107315	S2	313.1	0.063
107315	N2	243.9	0.027
107315	K1	188.5	0.271
107315	M4	37	0.01
107315	O1	165.2	0.191
107315	M6	38	0.009
107315	MK3	348.3	0.019
107315	S4	146.4	0.001
107315	MN4	11.1	0.006
107315	S6	232.3	0.002
107315	2N2	242.5	0.026
107315	OO1	251.8	0.01
107315	M1	151.9	0.022
107315	J1	73.3	0.006
107315	Q1	123.6	0.037
107315	2Q1	141.4	0.02
107315	2SM2	337.3	0.003
107315	M3	115.7	0.016
107315	L2	239	0.015
107315	2MK3	264.1	0.013
107315	K2	293.5	0.046
107315	M8	2.3	0.002
107315	MS4	342.3	0.012
107316	M2	282.9	0.211
107316	S2	308	0.064
107316	N2	241.2	0.029
107316	K1	190.2	0.26
107316	M4	37.7	0.01
107316	O1	166.8	0.184
107316	M6	40.2	0.011
107316	MK3	352.7	0.018
107316	S4	307.5	0.002
107316	MN4	13.6	0.007
107316	S6	255.3	0.002
107316	2N2	240.3	0.026
107316	OO1	254.4	0.014
107316	M1	156.7	0.021
107316	J1	99.7	0.008
107316	Q1	128.3	0.035
107316	2Q1	135.9	0.016
107316	2SM2	357.1	0.006
107316	M3	107.8	0.018
107316	L2	253.6	0.016
107316	2MK3	255.6	0.014
107316	K2	286.4	0.047
107316	M8	1	0.002
107316	MS4	322.3	0.013
107317	M2	284.5	0.214
107317	S2	305.3	0.063
107317	N2	240	0.028
107317	K1	192.1	0.246
107317	M4	32	0.008
107317	O1	169.1	0.175
107317	M6	42.5	0.013
107317	MK3	6	0.017
107317	S4	310.9	0.007
107317	MN4	2.4	0.008
107317	S6	278.1	0.003
107317	2N2	239.7	0.025
107317	OO1	260.7	0.017
107317	M1	162.3	0.022
107317	J1	108.1	0.013
107317	Q1	132.5	0.033
107317	2Q1	118.7	0.014
107317	2SM2	2.6	0.01
107317	M3	99.8	0.019
107317	L2	266.4	0.019
107317	2MK3	252.9	0.017
107317	K2	281.3	0.043
107317	M8	347.2	0.002
107317	MS4	308.4	0.014
107318	M2	285.8	0.221
107318	S2	307	0.061
107318	N2	238.8	0.025
107318	K1	194.2	0.228
107318	M4	15.7	0.004
107318	O1	171.7	0.163
107318	M6	46.6	0.013
107318	MK3	20.5	0.019
107318	S4	314.4	0.01
107318	MN4	355	0.008
107318	S6	294.2	0.005
107318	2N2	242.8	0.023
107318	OO1	267.2	0.016
107318	M1	170.6	0.023
107318	J1	115.4	0.017
107318	Q1	140.6	0.03
107318	2Q1	100	0.016
107318	2SM2	12.2	0.013
107318	M3	99.4	0.02
107318	L2	271	0.024
107318	2MK3	253.4	0.018
107318	K2	284.1	0.035
107318	M8	352.9	0.002
107318	MS4	303.6	0.016
107319	M2	286.7	0.231
107319	S2	306.7	0.056
107319	N2	239.8	0.025
107319	K1	195.9	0.208
107319	M4	311.2	0.003
107319	O1	174.3	0.15
107319	M6	52	0.013
107319	MK3	27.5	0.024
107319	S4	322.4	0.014
107319	MN4	336.3	0.008
107319	S6	286.7	0.006
107319	2N2	249.8	0.021
107319	OO1	280.3	0.015
107319	M1	176.7	0.024
107319	J1	113.4	0.019
107319	Q1	148.1	0.029
107319	2Q1	89.6	0.018
107319	2SM2	24	0.013
107319	M3	97.6	0.018
107319	L2	271.5	0.027
107319	2MK3	254.5	0.019
107319	K2	284	0.025
107319	M8	309.2	0.002
107319	MS4	301.5	0.016
107320	M2	286.9	0.241
107320	S2	306.4	0.047
107320	N2	241.1	0.026
107320	K1	196.6	0.188
107320	M4	275.7	0.005
107320	O1	176.1	0.133
107320	M6	55.6	0.011
107320	MK3	29.4	0.03
107320	S4	322.1	0.017
107320	MN4	301.2	0.008
107320	S6	277.1	0.007
107320	2N2	255	0.018
107320	OO1	295.8	0.021
107320	M1	182.1	0.022
107320	J1	107.2	0.019
107320	Q1	161.1	0.025
107320	2Q1	85.8	0.021
107320	2SM2	39.5	0.013
107320	M3	92.4	0.015
107320	L2	266.2	0.029
107320	2MK3	261.3	0.018
107320	K2	252.1	0.009
107320	M8	314.7	0.001
107320	MS4	304.1	0.019
107321	M2	287	0.255
107321	S2	302.2	0.037
107321	N2	243.3	0.029
107321	K1	196.5	0.17
107321	M4	288	0.009
107321	O1	177.8	0.116
107321	M6	52.7	0.009
107321	MK3	28.3	0.033
107321	S4	318.3	0.019
107321	MN4	276.7	0.01
107321	S6	272.4	0.004
107321	2N2	256.7	0.015
107321	OO1	302	0.026
107321	M1	187.7	0.02
107321	J1	97	0.018
107321	Q1	179.1	0.022
107321	2Q1	78.7	0.02
107321	2SM2	53.9	0.013
107321	M3	74.2	0.012
107321	L2	265.4	0.028
107321	2MK3	262.1	0.016
107321	K2	168.5	0.014
107321	M8	46.2	0.001
107321	MS4	305.9	0.022
107322	M2	287.4	0.267
107322	S2	302.1	0.029
107322	N2	245.2	0.032
107322	K1	195.3	0.149
107322	M4	298.6	0.014
107322	O1	179.8	0.101
107322	M6	48.9	0.008
107322	MK3	27.4	0.03
107322	S4	312.8	0.019
107322	MN4	266.7	0.014
107322	S6	291.9	0.001
107322	2N2	246.8	0.011
107322	OO1	304.1	0.028
107322	M1	195.9	0.016
107322	J1	85.2	0.017
107322	Q1	196.1	0.018
107322	2Q1	65.2	0.017
107322	2SM2	72.4	0.011
107322	M3	47.8	0.012
107322	L2	261.7	0.027
107322	2MK3	257.5	0.014
107322	K2	148.8	0.021
107322	M8	90.7	0.002
107322	MS4	305.8	0.024
107323	M2	288.8	0.277
107323	S2	304.7	0.027
107323	N2	245.7	0.036
107323	K1	194.4	0.127
107323	M4	307.6	0.021
107323	O1	181.8	0.087
107323	M6	40.9	0.007
107323	MK3	29.7	0.024
107323	S4	304.7	0.019
107323	MN4	269.1	0.018
107323	S6	36.1	0.003
107323	2N2	220.1	0.007
107323	OO1	296.7	0.027
107323	M1	215.7	0.012
107323	J1	73.1	0.018
107323	Q1	214.2	0.016
107323	2Q1	40.7	0.014
107323	2SM2	81.1	0.01
107323	M3	18.7	0.014
107323	L2	250.5	0.023
107323	2MK3	252.9	0.011
107323	K2	148.2	0.021
107323	M8	97.4	0.004
107323	MS4	306.8	0.025
107324	M2	290.8	0.285
107324	S2	318.2	0.031
107324	N2	248.2	0.04
107324	K1	193.7	0.107
107324	M4	314.2	0.026
107324	O1	185.4	0.076
107324	M6	20.5	0.007
107324	MK3	37.8	0.016
107324	S4	297.1	0.017
107324	MN4	277.7	0.02
107324	S6	18.5	0.004
107324	2N2	172.6	0.009
107324	OO1	279.6	0.024
107324	M1	245.7	0.013
107324	J1	65.4	0.023
107324	Q1	227.6	0.014
107324	2Q1	15.8	0.014
107324	2SM2	98.6	0.009
107324	M3	3	0.017
107324	L2	241.6	0.022
107324	2MK3	252.4	0.01
107324	K2	128.8	0.012
107324	M8	116.5	0.006
107324	MS4	306.1	0.025
107325	M2	293.6	0.291
107325	S2	334.4	0.04
107325	N2	255.6	0.044
107325	K1	193.4	0.089
107325	M4	314.8	0.031
107325	O1	190.1	0.065
107325	M6	4	0.007
107325	MK3	50.7	0.009
107325	S4	296	0.015
107325	MN4	282.4	0.022
107325	S6	319.3	0.003
107325	2N2	153	0.012
107325	OO1	269.4	0.02
107325	M1	265.5	0.016
107325	J1	58.9	0.024
107325	Q1	228.6	0.017
107325	2Q1	10.6	0.018
107325	2SM2	108.7	0.008
107325	M3	351.1	0.02
107325	L2	239.8	0.02
107325	2MK3	252.9	0.009
107325	K2	49.8	0.01
107325	M8	141.8	0.005
107325	MS4	305.8	0.023
107326	M2	296.7	0.295
107326	S2	349.4	0.049
107326	N2	268	0.048
107326	K1	193.1	0.077
107326	M4	310.8	0.033
107326	O1	194.5	0.054
107326	M6	357.5	0.009
107326	MK3	35.9	0.002
107326	S4	286.4	0.013
107326	MN4	283.3	0.02
107326	S6	271	0.005
107326	2N2	149.9	0.011
107326	OO1	268.2	0.018
107326	M1	274.9	0.019
107326	J1	49.2	0.02
107326	Q1	235	0.023
107326	2Q1	3	0.02
107326	2SM2	109.8	0.006
107326	M3	342.7	0.024
107326	L2	247.1	0.017
107326	2MK3	244.6	0.012
107326	K2	33.9	0.02
107326	M8	164.5	0.005
107326	MS4	302.8	0.019
107327	M2	300	0.298
107327	S2	358.1	0.064
107327	N2	278.9	0.054
107327	K1	194.1	0.066
107327	M4	305.4	0.033
107327	O1	203.4	0.045
107327	M6	1.7	0.01
107327	MK3	288	0.006
107327	S4	274.4	0.012
107327	MN4	282.3	0.018
107327	S6	250.4	0.008
107327	2N2	144.6	0.007
107327	OO1	270.7	0.021
107327	M1	282.1	0.022
107327	J1	36.7	0.013
107327	Q1	239.6	0.029
107327	2Q1	357.5	0.019
107327	2SM2	94.3	0.005
107327	M3	341.7	0.026
107327	L2	259	0.016
107327	2MK3	239.2	0.013
107327	K2	28.4	0.036
107327	M8	183.9	0.004
107327	MS4	292.7	0.017
107328	M2	303.5	0.299
107328	S2	0.6	0.075
107328	N2	285.8	0.06
107328	K1	199.1	0.054
107328	M4	296.5	0.032
107328	O1	210.5	0.038
107328	M6	19.3	0.011
107328	MK3	279.8	0.012
107328	S4	272.2	0.01
107328	MN4	274.7	0.014
107328	S6	232.7	0.009
107328	2N2	87.6	0.003
107328	OO1	272.1	0.024
107328	M1	286.9	0.023
107328	J1	354.2	0.008
107328	Q1	240.9	0.032
107328	2Q1	349.8	0.02
107328	2SM2	57.8	0.004
107328	M3	343.7	0.026
107328	L2	275.9	0.012
107328	2MK3	231.2	0.013
107328	K2	27.5	0.048
107328	M8	196.5	0.003
107328	MS4	283.6	0.014
107329	M2	306.8	0.301
107329	S2	359.4	0.083
107329	N2	291.2	0.065
107329	K1	211.7	0.04
107329	M4	284.3	0.031
107329	O1	221.8	0.031
107329	M6	32.1	0.012
107329	MK3	281.7	0.017
107329	S4	282	0.007
107329	MN4	256.4	0.013
107329	S6	213.4	0.009
107329	2N2	18.5	0.005
107329	OO1	282.4	0.026
107329	M1	288.3	0.024
107329	J1	307.1	0.011
107329	Q1	240.3	0.032
107329	2Q1	351.5	0.02
107329	2SM2	20.8	0.005
107329	M3	341	0.025
107329	L2	314.3	0.009
107329	2MK3	223.7	0.012
107329	K2	24.5	0.054
107329	M8	220.4	0.003
107329	MS4	267.7	0.011
107330	M2	309.6	0.304
107330	S2	356.3	0.09
107330	N2	294.7	0.067
107330	K1	236.9	0.027
107330	M4	272.4	0.032
107330	O1	242.6	0.024
107330	M6	41.9	0.011
107330	MK3	281.2	0.021
107330	S4	277.1	0.003
107330	MN4	243.1	0.012
107330	S6	203.3	0.01
107330	2N2	351.4	0.008
107330	OO1	290.7	0.025
107330	M1	291.3	0.025
107330	J1	290	0.016
107330	Q1	240.9	0.03
107330	2Q1	352.7	0.021
107330	2SM2	4.5	0.008
107330	M3	338	0.023
107330	L2	3.2	0.012
107330	2MK3	215.4	0.01
107330	K2	16.4	0.06
107330	M8	220.5	0.003
107330	MS4	243.3	0.011
107331	M2	312	0.306
107331	S2	349.7	0.095
107331	N2	297.3	0.068
107331	K1	285.8	0.025
107331	M4	264.5	0.032
107331	O1	273.9	0.021
107331	M6	53.7	0.01
107331	MK3	279.2	0.024
107331	S4	165.5	0.001
107331	MN4	225.2	0.012
107331	S6	205	0.009
107331	2N2	341.5	0.009
107331	OO1	298.9	0.021
107331	M1	295.3	0.025
107331	J1	284	0.02
107331	Q1	242.1	0.024
107331	2Q1	358.8	0.023
107331	2SM2	353.8	0.01
107331	M3	333.4	0.02
107331	L2	18.8	0.019
107331	2MK3	199.3	0.008
107331	K2	2.5	0.063
107331	M8	203.2	0.004
107331	MS4	229.5	0.012
107332	M2	313.9	0.309
107332	S2	342.6	0.099
107332	N2	297.9	0.068
107332	K1	318.3	0.035
107332	M4	256.2	0.033
107332	O1	299.7	0.024
107332	M6	58.4	0.01
107332	MK3	273.2	0.025
107332	S4	124.9	0.004
107332	MN4	214.8	0.012
107332	S6	222.9	0.008
107332	2N2	329.3	0.009
107332	OO1	309.8	0.016
107332	M1	298.9	0.022
107332	J1	282.8	0.023
107332	Q1	242.7	0.017
107332	2Q1	3.9	0.022
107332	2SM2	354.3	0.011
107332	M3	324.2	0.017
107332	L2	26.3	0.022
107332	2MK3	195.9	0.011
107332	K2	349.4	0.067
107332	M8	201.1	0.003
107332	MS4	213.8	0.012
107333	M2	314.6	0.31
107333	S2	338.1	0.099
107333	N2	297.5	0.068
107333	K1	334.8	0.047
107333	M4	249.9	0.032
107333	O1	314.3	0.029
107333	M6	58	0.01
107333	MK3	266.1	0.024
107333	S4	122.4	0.006
107333	MN4	211.1	0.013
107333	S6	239.9	0.008
107333	2N2	309.4	0.009
107333	OO1	335.2	0.008
107333	M1	303.6	0.019
107333	J1	281.8	0.026
107333	Q1	239.2	0.013
107333	2Q1	4	0.022
107333	2SM2	352.8	0.012
107333	M3	317.1	0.015
107333	L2	34.6	0.026
107333	2MK3	198.4	0.013
107333	K2	342.2	0.068
107333	M8	226.7	0.002
107333	MS4	203.5	0.011
107334	M2	314.5	0.313
107334	S2	334.8	0.1
107334	N2	297.7	0.068
107334	K1	343.8	0.06
107334	M4	243.4	0.03
107334	O1	326.9	0.031
107334	M6	58.8	0.01
107334	MK3	253.2	0.023
107334	S4	125	0.007
107334	MN4	209.8	0.014
107334	S6	251.2	0.006
107334	2N2	287	0.011
107334	OO1	104.1	0.001
107334	M1	311.4	0.015
107334	J1	278.3	0.03
107334	Q1	230.7	0.013
107334	2Q1	3.1	0.021
107334	2SM2	339.1	0.013
107334	M3	308.4	0.012
107334	L2	38.3	0.033
107334	2MK3	205.2	0.015
107334	K2	336.3	0.068
107334	M8	229.8	0.001
107334	MS4	197.2	0.008
107335	M2	314.1	0.316
107335	S2	332.6	0.097
107335	N2	296.4	0.067
107335	K1	349.1	0.069
107335	M4	238.6	0.027
107335	O1	338.6	0.033
107335	M6	49.8	0.01
107335	MK3	240.1	0.023
107335	S4	140.4	0.008
107335	MN4	206.6	0.014
107335	S6	259.1	0.006
107335	2N2	272.2	0.013
107335	OO1	135	0.006
107335	M1	321.4	0.013
107335	J1	273.6	0.032
107335	Q1	234.2	0.013
107335	2Q1	3.3	0.018
107335	2SM2	331.7	0.015
107335	M3	299.4	0.01
107335	L2	37.4	0.041
107335	2MK3	212.7	0.016
107335	K2	330.5	0.061
107335	M8	272.9	0.002
107335	MS4	195.1	0.006
107336	M2	313.6	0.318
107336	S2	328.1	0.097
107336	N2	295.7	0.065
107336	K1	351.5	0.075
107336	M4	236.7	0.025
107336	O1	347.6	0.038
107336	M6	52.5	0.01
107336	MK3	229	0.027
107336	S4	149	0.008
107336	MN4	205.9	0.015
107336	S6	265.9	0.005
107336	2N2	263.6	0.014
107336	OO1	131.4	0.011
107336	M1	326.7	0.012
107336	J1	261.5	0.034
107336	Q1	242.9	0.017
107336	2Q1	1.4	0.017
107336	2SM2	313.9	0.017
107336	M3	289.8	0.012
107336	L2	35.6	0.046
107336	2MK3	222.6	0.017
107336	K2	322.3	0.058
107336	M8	289	0.003
107336	MS4	173.4	0.004
107337	M2	312.8	0.317
107337	S2	325.1	0.098
107337	N2	292.2	0.062
107337	K1	352.7	0.075
107337	M4	236.8	0.027
107337	O1	356	0.042
107337	M6	50.7	0.011
107337	MK3	222.2	0.031
107337	S4	143.4	0.006
107337	MN4	210.6	0.013
107337	S6	294.1	0.005
107337	2N2	265.4	0.013
107337	OO1	130	0.018
107337	M1	330.3	0.011
107337	J1	250.7	0.034
107337	Q1	245.7	0.019
107337	2Q1	353.2	0.02
107337	2SM2	298.9	0.02
107337	M3	292.1	0.013
107337	L2	35.7	0.048
107337	2MK3	222.7	0.016
107337	K2	319	0.054
107337	M8	277.3	0.005
107337	MS4	150.7	0.005
107338	M2	314.2	0.308
107338	S2	329.6	0.095
107338	N2	287.1	0.059
107338	K1	341.3	0.077
107338	M4	263	0.028
107338	O1	349.2	0.057
107338	M6	60.2	0.004
107338	MK3	221.3	0.042
107338	S4	130.2	0.005
107338	MN4	246.3	0.011
107338	S6	314.7	0.004
107338	2N2	262.1	0.015
107338	OO1	112.4	0.022
107338	M1	321.5	0.007
107338	J1	248.5	0.031
107338	Q1	255.2	0.018
107338	2Q1	346.4	0.023
107338	2SM2	286.8	0.019
107338	M3	303	0.016
107338	L2	32.8	0.041
107338	2MK3	212.5	0.025
107338	K2	334.4	0.04
107338	M8	293.5	0.003
107338	MS4	75.7	0.006
107339	M2	282.3	0.806
107339	S2	301.4	0.179
107339	N2	267.7	0.167
107339	K1	171.1	0.208
107339	M4	252.5	0.074
107339	O1	131.2	0.173
107339	M6	44.4	0.075
107339	MK3	253.9	0.055
107339	S4	115.4	0.009
107339	MN4	213.3	0.032
107339	S6	192.6	0.004
107339	2N2	171.9	0.029
107339	OO1	9.2	0.024
107339	M1	154.1	0.008
107339	J1	216.3	0.027
107339	Q1	132.6	0.018
107339	2Q1	24.1	0.013
107339	P1	160.7	0.075
107339	2SM2	192.8	0.017
107339	M3	303.3	0.017
107339	L2	308	0.115
107339	2MK3	225.8	0.036
107339	K2	322.6	0.079
107339	M8	129.4	0.003
107339	MS4	298.9	0.033
107340	M2	291.4	0.636
107340	S2	326.2	0.092
107340	N2	281.8	0.131
107340	K1	174	0.225
107340	M4	269.7	0.08
107340	O1	142.6	0.209
107340	M6	67	0.055
107340	MK3	271.1	0.026
107340	S4	126	0.008
107340	MN4	266.6	0.025
107340	S6	137.6	0.007
107340	2N2	270.3	0.008
107340	OO1	13.6	0.047
107340	M1	202.8	0.012
107340	J1	204.7	0.04
107340	Q1	164.7	0.026
107340	2Q1	41.6	0.025
107340	P1	155.4	0.056
107340	2SM2	121.6	0.007
107340	M3	120.5	0.007
107340	L2	303.7	0.055
107340	2MK3	245.4	0.033
107340	K2	290.2	0.088
107340	M8	186.2	0.009
107340	MS4	313.7	0.016
107341	M2	312.9	0.491
107341	S2	344.9	0.111
107341	N2	305	0.093
107341	K1	171.1	0.183
107341	M4	272.7	0.208
107341	O1	123.7	0.163
107341	M6	73.1	0.069
107341	MK3	173.4	0.092
107341	S4	336.2	0.02
107341	MN4	264.4	0.082
107341	S6	88.1	0.01
107341	2N2	241.4	0.042
107341	OO1	52.8	0.056
107341	M1	168.4	0.002
107341	J1	187	0.026
107341	Q1	223.8	0.008
107341	2Q1	341.2	0.025
107341	P1	206.2	0.043
107341	2SM2	257.2	0.013
107341	M3	262.4	0.008
107341	L2	69.1	0.064
107341	2MK3	188.3	0.095
107341	K2	259.9	0.074
107341	M8	78.5	0.016
107341	MS4	327.6	0.084
107342	M2	267.3	0.458
107342	S2	289.7	0.114
107342	N2	253.7	0.074
107342	K1	144.9	0.134
107342	M4	320.3	0.139
107342	O1	114.1	0.105
107342	M6	116.5	0.025
107342	MK3	236.1	0.076
107342	S4	103.8	0.007
107342	MN4	283.9	0.056
107342	S6	94.8	0.005
107342	2N2	187.4	0.034
107342	OO1	342.6	0.028
107342	M1	110	0.009
107342	J1	140.3	0.009
107342	Q1	84	0.024
107342	2Q1	294.7	0.014
107342	P1	133.5	0.033
107342	2SM2	112	0.008
107342	M3	301.2	0.016
107342	L2	271.3	0.052
107342	2MK3	224.4	0.054
107342	K2	322.5	0.033
107342	M8	133.6	0.023
107342	MS4	359.3	0.076
107343	M2	277.1	0.57
107343	S2	294.2	0.141
107343	N2	260.4	0.086
107343	K1	147.3	0.198
107343	M4	314.8	0.166
107343	O1	116.3	0.14
107343	M6	134.4	0.041
107343	MK3	226.9	0.079
107343	S4	92.9	0.007
107343	MN4	277	0.073
107343	2N2	199.5	0.05
107343	OO1	352.5	0.039
107343	M1	116	0.011
107343	J1	132.8	0.012
107343	Q1	81.5	0.026
107343	2Q1	301.9	0.026
107343	P1	154.2	0.048
107343	2SM2	81.9	0.006
107343	M3	308.5	0.012
107343	L2	292.8	0.055
107343	2MK3	235.9	0.062
107343	K2	329.7	0.047
107343	M8	108.2	0.034
107343	MS4	351.6	0.077
107344	M2	281.1	0.526
107344	S2	297.2	0.139
107344	N2	260.2	0.078
107344	K1	143	0.201
107344	M4	306.6	0.172
107344	O1	118.7	0.124
107344	M6	167.8	0.023
107344	MK3	204.5	0.074
107344	S4	60.3	0.007
107344	MN4	269.7	0.082
107344	S6	309.7	0.003
107344	2N2	204.5	0.041
107344	OO1	354.4	0.051
107344	M1	119.4	0.011
107344	J1	119.9	0.006
107344	Q1	90.7	0.025
107344	2Q1	296.3	0.038
107344	P1	151.9	0.049
107344	2SM2	23.9	0.011
107344	M3	270	0.008
107344	L2	294.9	0.045
107344	2MK3	242.3	0.058
107344	K2	351.6	0.037
107344	M8	91.5	0.036
107344	MS4	342.2	0.077
107345	M2	303.2	2.593
107345	S2	334	0.586
107345	N2	281.2	0.501
107345	K1	207.8	0.78
107345	M4	191.7	0.278
107345	O1	205.7	0.377
107345	M6	81.7	0.064
107345	MK3	50.6	0.207
107345	S4	197.5	0.02
107345	MN4	180.5	0.082
107345	NU2	301.8	0.113
107345	MU2	88.2	0.044
107345	2N2	251.7	0.034
107345	OO1	252.7	0.089
107345	LDA2	311.6	0.081
107345	M1	248.8	0.018
107345	J1	244.2	0.035
107345	RHO1	203.2	0.012
107345	Q1	193	0.07
107345	2Q1	247.9	0.023
107345	P1	203.4	0.226
107345	2SM2	201.2	0.016
107345	M3	147.4	0.028
107345	L2	336.2	0.188
107345	2MK3	84.6	0.03
107345	K2	323.3	0.207
107345	M8	326.8	0.04
107345	MS4	213.9	0.113
107346	M2	304.4	2.767
107346	S2	333.8	0.65
107346	N2	280.5	0.539
107346	K1	205.8	0.88
107346	M4	183.9	0.334
107346	O1	196.3	0.419
107346	M6	109.3	0.137
107346	MK3	49.9	0.232
107346	S4	181.7	0.026
107346	MN4	167.4	0.095
107346	NU2	298.4	0.115
107346	MU2	112.4	0.026
107346	2N2	261.7	0.048
107346	OO1	247.2	0.088
107346	LDA2	312.8	0.082
107346	M1	225	0.023
107346	J1	243.8	0.051
107346	RHO1	153.5	0.021
107346	Q1	181.6	0.066
107346	2Q1	246.1	0.036
107346	P1	200.5	0.26
107346	2SM2	174.9	0.017
107346	M3	131	0.049
107346	L2	342.3	0.161
107346	2MK3	8.1	0.061
107346	K2	321.3	0.225
107346	M8	351.1	0.033
107346	MS4	206.1	0.149
107347	M2	305.8	2.527
107347	S2	334.7	0.599
107347	N2	280	0.48
107347	K1	202.7	0.845
107347	M4	177.7	0.275
107347	O1	189.8	0.358
107347	M6	103.5	0.172
107347	MK3	31.7	0.175
107347	S4	184.9	0.025
107347	MN4	156.8	0.078
107347	NU2	291.5	0.113
107347	S6	84.1	0.004
107347	MU2	147.6	0.018
107347	2N2	261.6	0.061
107347	OO1	263.6	0.094
107347	LDA2	318.8	0.059
107347	M1	223.4	0.012
107347	J1	227.2	0.046
107347	RHO1	158.5	0.009
107347	Q1	174	0.06
107347	2Q1	220.2	0.053
107347	P1	199.9	0.23
107347	2SM2	137.5	0.019
107347	M3	125.5	0.052
107347	L2	346.7	0.122
107347	2MK3	330.7	0.056
107347	K2	322.1	0.218
107347	M8	359.6	0.027
107347	MS4	198.6	0.15
107348	M2	291.9	1.671
107348	S2	321.9	0.386
107348	N2	273.9	0.321
107348	K1	179.2	0.553
107348	M4	290.5	0.427
107348	O1	132.3	0.485
107348	M6	29.7	0.123
107348	MK3	211.1	0.237
107348	S4	315.5	0.008
107348	MN4	263.7	0.17
107348	S6	125.5	0.004
107348	2N2	198.4	0.077
107348	OO1	303.7	0.02
107348	M1	191.2	0.033
107348	J1	185.1	0.02
107348	Q1	126.1	0.076
107348	2Q1	354.9	0.068
107348	P1	165.7	0.141
107348	2SM2	206.9	0.015
107348	M3	290	0.062
107348	L2	314	0.129
107348	2MK3	178.6	0.176
107348	K2	312.1	0.119
107348	M8	89.4	0.075
107348	MS4	331.9	0.218
107349	M2	296.7	1.875
107349	S2	323.8	0.445
107349	N2	280.4	0.346
107349	K1	182.9	0.584
107349	M4	284.7	0.391
107349	O1	136.7	0.494
107349	M6	39.5	0.117
107349	MK3	203.5	0.207
107349	S4	327.8	0.022
107349	MN4	258.4	0.155
107349	S6	28.6	0.008
107349	2N2	193	0.089
107349	OO1	305	0.053
107349	M1	200.4	0.028
107349	J1	188.5	0.019
107349	Q1	137.4	0.081
107349	2Q1	344.9	0.065
107349	P1	164.6	0.155
107349	2SM2	210.9	0.022
107349	M3	285.3	0.054
107349	L2	313.5	0.162
107349	2MK3	182.4	0.171
107349	K2	335.8	0.146
107349	M8	83.4	0.071
107349	MS4	324.2	0.204
107350	M2	298.9	1.836
107350	S2	326.7	0.446
107350	N2	284.8	0.326
107350	K1	184.6	0.573
107350	M4	285.1	0.37
107350	O1	134.9	0.437
107350	M6	33.9	0.109
107350	MK3	205.1	0.185
107350	S4	315.1	0.029
107350	MN4	258.9	0.144
107350	S6	0.1	0.01
107350	2N2	190.8	0.101
107350	OO1	287.5	0.111
107350	M1	216	0.02
107350	J1	287.4	0.015
107350	Q1	137.7	0.064
107350	2Q1	331.5	0.067
107350	P1	162.3	0.139
107350	2SM2	181.4	0.008
107350	M3	287	0.052
107350	L2	309.9	0.155
107350	2MK3	185.2	0.172
107350	K2	350.9	0.153
107350	M8	81	0.063
107350	MS4	323.5	0.208
107351	M2	300.2	2.992
107351	S2	332.1	0.722
107351	N2	274.3	0.587
107351	K1	201.4	0.987
107351	M4	210.6	0.117
107351	O1	181.5	0.53
107351	M6	38.6	0.115
107351	MK3	50.5	0.088
107351	S4	242.5	0.026
107351	MN4	184.7	0.042
107351	NU2	292.8	0.142
107351	S6	253.8	0.006
107351	MU2	64	0.029
107351	2N2	281.5	0.062
107351	OO1	245.9	0.099
107351	LDA2	305.1	0.067
107351	M1	218.8	0.039
107351	J1	247.2	0.061
107351	RHO1	148.9	0.04
107351	Q1	161.2	0.063
107351	2Q1	344.6	0.016
107351	P1	194.9	0.279
107351	2SM2	163	0.014
107351	M3	156	0.022
107351	L2	326.4	0.169
107351	2MK3	133.2	0.067
107351	K2	322.4	0.239
107351	M8	279.2	0.029
107351	MS4	243.7	0.042
107352	M2	300.4	3.09
107352	S2	332.2	0.748
107352	N2	274.4	0.609
107352	K1	201.4	1.023
107352	M4	212.3	0.118
107352	O1	181	0.548
107352	M6	41.4	0.116
107352	MK3	50.9	0.091
107352	S4	242.7	0.027
107352	MN4	186.6	0.045
107352	NU2	292.8	0.147
107352	S6	252.9	0.006
107352	MU2	62.6	0.03
107352	2N2	281.6	0.065
107352	OO1	245.9	0.101
107352	LDA2	305	0.069
107352	M1	217.4	0.04
107352	J1	246.9	0.062
107352	RHO1	149.6	0.04
107352	Q1	161.1	0.066
107352	2Q1	345.7	0.017
107352	P1	194.7	0.291
107352	2SM2	159.5	0.014
107352	M3	157.1	0.024
107352	L2	326.9	0.173
107352	2MK3	131.6	0.065
107352	K2	322.4	0.247
107352	M8	282.3	0.029
107352	MS4	245.1	0.045
107353	M2	300.6	3.17
107353	S2	332.2	0.768
107353	N2	274.6	0.625
107353	K1	201.4	1.053
107353	M4	213.3	0.118
107353	O1	180.6	0.564
107353	M6	44.2	0.116
107353	MK3	50.8	0.094
107353	S4	243.8	0.028
107353	MN4	188.5	0.047
107353	NU2	292.8	0.151
107353	S6	255.6	0.005
107353	MU2	62.1	0.029
107353	2N2	281	0.067
107353	OO1	245.3	0.101
107353	LDA2	305.2	0.07
107353	M1	216.2	0.04
107353	J1	246.4	0.063
107353	RHO1	149	0.04
107353	Q1	160.2	0.067
107353	2Q1	349	0.016
107353	P1	194.4	0.3
107353	2SM2	154.6	0.014
107353	M3	155.3	0.026
107353	L2	327.2	0.176
107353	2MK3	128.6	0.063
107353	K2	322.3	0.255
107353	M8	285.3	0.028
107353	MS4	245.6	0.047
107354	M2	300.8	3.237
107354	S2	332.3	0.785
107354	N2	274.9	0.64
107354	K1	201.4	1.08
107354	M4	214.4	0.117
107354	O1	180.5	0.577
107354	M6	46.8	0.115
107354	MK3	49.9	0.098
107354	S4	244.3	0.029
107354	MN4	189.7	0.047
107354	NU2	293.1	0.153
107354	S6	257.6	0.005
107354	MU2	62.3	0.029
107354	2N2	280.3	0.069
107354	OO1	244.7	0.101
107354	LDA2	305	0.071
107354	M1	216.2	0.04
107354	J1	246.1	0.063
107354	RHO1	149.5	0.041
107354	Q1	159.6	0.069
107354	2Q1	352.2	0.015
107354	P1	194.3	0.308
107354	2SM2	153.8	0.014
107354	M3	154.9	0.027
107354	L2	327.8	0.18
107354	2MK3	125.6	0.061
107354	K2	322.4	0.262
107354	M8	287.3	0.027
107354	MS4	246.4	0.049
107355	M2	301	3.296
107355	S2	332.4	0.8
107355	N2	275.1	0.651
107355	K1	201.5	1.103
107355	M4	214.8	0.115
107355	O1	180.4	0.587
107355	M6	49.5	0.114
107355	MK3	49	0.102
107355	S4	243.6	0.029
107355	MN4	190.5	0.047
107355	NU2	293.2	0.155
107355	S6	250.6	0.005
107355	MU2	65.2	0.028
107355	2N2	280.2	0.07
107355	OO1	244.5	0.103
107355	LDA2	305	0.073
107355	M1	216.5	0.04
107355	J1	245.4	0.062
107355	RHO1	147.4	0.042
107355	Q1	159	0.07
107355	2Q1	354.2	0.013
107355	P1	194.1	0.314
107355	2SM2	153.6	0.014
107355	M3	154.9	0.029
107355	L2	328.7	0.183
107355	2MK3	122.6	0.059
107355	K2	322.6	0.268
107355	M8	290.3	0.026
107355	MS4	246.5	0.049
107356	M2	301.2	3.348
107356	S2	332.5	0.811
107356	N2	275.2	0.66
107356	K1	201.6	1.122
107356	M4	214.5	0.113
107356	O1	180.5	0.595
107356	M6	52.2	0.115
107356	MK3	47.2	0.107
107356	S4	243.5	0.03
107356	MN4	190.9	0.047
107356	NU2	293.2	0.156
107356	S6	254.8	0.004
107356	MU2	70.7	0.028
107356	2N2	280.2	0.07
107356	OO1	244.6	0.104
107356	LDA2	305.3	0.074
107356	M1	216.5	0.04
107356	J1	245	0.062
107356	RHO1	146.7	0.042
107356	Q1	159.4	0.071
107356	2Q1	357.2	0.012
107356	P1	194.1	0.32
107356	2SM2	154.7	0.015
107356	M3	154.4	0.03
107356	L2	329.5	0.186
107356	2MK3	120.7	0.056
107356	K2	322.7	0.274
107356	M8	293.3	0.026
107356	MS4	245.6	0.049
107357	M2	301.3	3.392
107357	S2	332.6	0.821
107357	N2	275.4	0.668
107357	K1	201.8	1.138
107357	M4	213.3	0.11
107357	O1	180.9	0.602
107357	M6	54.1	0.116
107357	MK3	45	0.112
107357	S4	242.9	0.03
107357	MN4	190.9	0.046
107357	NU2	293.5	0.157
107357	MU2	76	0.028
107357	2N2	280.1	0.071
107357	OO1	244.9	0.104
107357	LDA2	305.6	0.076
107357	M1	216.9	0.039
107357	J1	244.4	0.061
107357	RHO1	146.5	0.042
107357	Q1	159.7	0.073
107357	2Q1	0.4	0.01
107357	P1	194.1	0.324
107357	2SM2	156	0.016
107357	M3	152.3	0.03
107357	L2	330.4	0.19
107357	2MK3	120.3	0.052
107357	K2	323.1	0.277
107357	M8	296	0.026
107357	MS4	244.2	0.047
107358	M2	301.5	3.43
107358	S2	332.7	0.827
107358	N2	275.6	0.674
107358	K1	201.9	1.149
107358	M4	211.5	0.108
107358	O1	181.2	0.607
107358	M6	56	0.118
107358	MK3	42.7	0.116
107358	S4	241.3	0.03
107358	MN4	191.2	0.045
107358	NU2	294	0.158
107358	MU2	82	0.03
107358	2N2	280	0.07
107358	OO1	245.5	0.105
107358	LDA2	306.1	0.078
107358	M1	217.6	0.039
107358	J1	244.2	0.061
107358	RHO1	147	0.042
107358	Q1	160.1	0.075
107358	2Q1	8.7	0.008
107358	P1	194.3	0.328
107358	2SM2	156.3	0.017
107358	M3	150.6	0.031
107358	L2	331.3	0.195
107358	2MK3	119.8	0.047
107358	K2	323.3	0.281
107358	M8	300.7	0.026
107358	MS4	242.3	0.046
107359	M2	301.6	3.462
107359	S2	332.8	0.831
107359	N2	275.7	0.678
107359	K1	202.1	1.157
107359	M4	209.4	0.108
107359	O1	181.5	0.61
107359	M6	57.4	0.121
107359	MK3	40.3	0.119
107359	S4	240.6	0.03
107359	MN4	190.1	0.045
107359	NU2	294.5	0.159
107359	MU2	88	0.034
107359	2N2	279.5	0.069
107359	OO1	246	0.106
107359	LDA2	306.5	0.079
107359	M1	217.9	0.038
107359	J1	244.4	0.06
107359	RHO1	146.6	0.039
107359	Q1	160.9	0.077
107359	2Q1	15.5	0.007
107359	P1	194.3	0.331
107359	2SM2	158.9	0.017
107359	M3	149.3	0.031
107359	L2	332	0.199
107359	2MK3	119.3	0.042
107359	K2	323.5	0.284
107359	M8	304.4	0.026
107359	MS4	239.2	0.045
107360	M2	301.7	3.49
107360	S2	332.8	0.834
107360	N2	276	0.681
107360	K1	202.2	1.162
107360	M4	207	0.109
107360	O1	181.9	0.611
107360	M6	58.4	0.123
107360	MK3	38.2	0.122
107360	S4	237.5	0.03
107360	MN4	189.9	0.045
107360	NU2	295	0.16
107360	MU2	92.5	0.037
107360	2N2	277.8	0.069
107360	OO1	246.4	0.106
107360	LDA2	307.2	0.08
107360	M1	218.9	0.038
107360	J1	243.8	0.058
107360	RHO1	145.9	0.039
107360	Q1	160.5	0.079
107360	P1	194.5	0.333
107360	2SM2	161.1	0.018
107360	M3	147	0.03
107360	L2	332.9	0.203
107360	2MK3	120	0.036
107360	K2	323.6	0.287
107360	M8	307.6	0.027
107360	MS4	236.4	0.044
107361	M2	301.9	3.514
107361	S2	332.8	0.836
107361	N2	276.1	0.684
107361	K1	202.3	1.166
107361	M4	205.1	0.112
107361	O1	181.9	0.612
107361	M6	59.1	0.126
107361	MK3	36.7	0.124
107361	S4	235.5	0.029
107361	MN4	190.5	0.045
107361	NU2	295.6	0.161
107361	MU2	94.9	0.041
107361	2N2	276.9	0.068
107361	OO1	247	0.106
107361	LDA2	307.7	0.081
107361	M1	219.4	0.037
107361	J1	243.5	0.057
107361	RHO1	146.2	0.038
107361	Q1	160.3	0.081
107361	P1	194.6	0.335
107361	2SM2	164.2	0.019
107361	M3	144.7	0.03
107361	L2	333.7	0.208
107361	2MK3	120.6	0.031
107361	K2	323.3	0.289
107361	M8	310.5	0.027
107361	MS4	234	0.043
107362	M2	302	3.537
107362	S2	332.8	0.837
107362	N2	276.3	0.686
107362	K1	202.4	1.169
107362	M4	204	0.117
107362	O1	182	0.612
107362	M6	59.4	0.128
107362	MK3	36.3	0.126
107362	S4	234.5	0.028
107362	MN4	190.6	0.047
107362	NU2	296.2	0.162
107362	MU2	98.6	0.045
107362	2N2	275.5	0.065
107362	OO1	248.1	0.106
107362	LDA2	308.7	0.083
107362	M1	219.6	0.036
107362	J1	243.3	0.056
107362	RHO1	148.1	0.036
107362	Q1	160.7	0.083
107362	P1	194.6	0.337
107362	2SM2	167.9	0.019
107362	M3	141.5	0.03
107362	L2	334.5	0.213
107362	2MK3	122.2	0.026
107362	K2	323.3	0.289
107362	M8	314.5	0.027
107362	MS4	231.5	0.044
107363	M2	302.1	3.557
107363	S2	332.9	0.839
107363	N2	276.5	0.689
107363	K1	202.5	1.172
107363	M4	203.8	0.124
107363	O1	181.8	0.611
107363	M6	59.5	0.13
107363	MK3	36.2	0.127
107363	S4	233.8	0.027
107363	MN4	191.3	0.049
107363	NU2	296.7	0.163
107363	MU2	100.5	0.049
107363	2N2	274.1	0.064
107363	OO1	249.3	0.106
107363	LDA2	309.9	0.085
107363	M1	219.5	0.035
107363	J1	241.8	0.054
107363	RHO1	148.4	0.034
107363	Q1	160.7	0.085
107363	P1	194.8	0.339
107363	2SM2	170	0.019
107363	M3	139.1	0.03
107363	L2	335.2	0.217
107363	2MK3	123.6	0.021
107363	K2	323.3	0.289
107363	M8	316.4	0.028
107363	MS4	230.4	0.045
107364	M2	302.2	3.577
107364	S2	332.8	0.841
107364	N2	276.6	0.691
107364	K1	202.5	1.174
107364	M4	204.1	0.133
107364	O1	181.5	0.612
107364	M6	59.5	0.131
107364	MK3	36.7	0.127
107364	S4	231.7	0.027
107364	MN4	192.2	0.052
107364	NU2	296.9	0.164
107364	MU2	101.7	0.053
107364	2N2	272	0.063
107364	OO1	251.4	0.106
107364	LDA2	310.1	0.086
107364	M1	218.5	0.035
107364	J1	240.2	0.055
107364	RHO1	149.9	0.033
107364	Q1	161.1	0.088
107364	P1	194.9	0.342
107364	2SM2	172.6	0.019
107364	M3	137.8	0.03
107364	L2	335.7	0.221
107364	2MK3	122.1	0.017
107364	K2	323.1	0.289
107364	M8	317.5	0.028
107364	MS4	230	0.047
107365	M2	302.4	3.596
107365	S2	332.8	0.843
107365	N2	276.8	0.694
107365	K1	202.6	1.177
107365	M4	205.3	0.142
107365	O1	180.9	0.613
107365	M6	59.1	0.132
107365	MK3	38	0.128
107365	S4	231.9	0.026
107365	MN4	193.6	0.054
107365	NU2	297.5	0.165
107365	MU2	103.2	0.055
107365	2N2	269.2	0.062
107365	OO1	252.6	0.107
107365	LDA2	310.3	0.088
107365	M1	217.9	0.034
107365	J1	239.1	0.054
107365	RHO1	152	0.032
107365	Q1	161.7	0.09
107365	P1	195.2	0.343
107365	2SM2	176.2	0.019
107365	M3	136.8	0.029
107365	L2	336.4	0.224
107365	2MK3	119.2	0.014
107365	K2	323.1	0.288
107365	M8	316.4	0.029
107365	MS4	229.9	0.05
107366	M2	302.5	3.615
107366	S2	332.9	0.847
107366	N2	277.1	0.697
107366	K1	202.5	1.181
107366	M4	207.2	0.152
107366	O1	180.4	0.614
107366	M6	58.3	0.131
107366	MK3	39.7	0.129
107366	S4	229	0.027
107366	MN4	195.3	0.058
107366	NU2	297.9	0.165
107366	MU2	104.5	0.058
107366	2N2	265.8	0.062
107366	OO1	254.9	0.108
107366	LDA2	310	0.09
107366	M1	217.2	0.035
107366	J1	238	0.055
107366	RHO1	154.9	0.033
107366	Q1	161.8	0.092
107366	2Q1	290.5	0.005
107366	P1	195.4	0.345
107366	2SM2	178	0.02
107366	M3	135.6	0.03
107366	L2	336.5	0.228
107366	2MK3	116.2	0.011
107366	K2	323.1	0.287
107366	M8	314.2	0.029
107366	MS4	229.8	0.053
107367	M2	302.6	3.633
107367	S2	332.9	0.85
107367	N2	277.4	0.699
107367	K1	202.4	1.184
107367	M4	209.3	0.163
107367	O1	179.7	0.615
107367	M6	57.1	0.128
107367	MK3	42	0.131
107367	S4	228.1	0.028
107367	MN4	196.5	0.062
107367	NU2	298.5	0.166
107367	MU2	105.1	0.06
107367	2N2	263.1	0.063
107367	OO1	256.3	0.111
107367	LDA2	310	0.092
107367	M1	217	0.035
107367	J1	238.1	0.055
107367	RHO1	155.1	0.033
107367	Q1	162.4	0.093
107367	2Q1	291.6	0.007
107367	P1	195.7	0.347
107367	2SM2	179.4	0.019
107367	M3	133.7	0.03
107367	L2	336.9	0.231
107367	2MK3	108.3	0.009
107367	K2	323.3	0.286
107367	M8	310.4	0.029
107367	MS4	229.9	0.057
107368	M2	302.7	3.651
107368	S2	332.8	0.852
107368	N2	277.5	0.701
107368	K1	202.2	1.187
107368	M4	211.5	0.175
107368	O1	178.9	0.615
107368	M6	56.3	0.124
107368	MK3	44.5	0.135
107368	S4	225.8	0.029
107368	MN4	197.3	0.065
107368	NU2	298.7	0.166
107368	MU2	106.2	0.063
107368	2N2	259.7	0.064
107368	OO1	257.6	0.114
107368	LDA2	309.8	0.095
107368	M1	215.4	0.035
107368	J1	240.7	0.055
107368	RHO1	154	0.033
107368	Q1	163.7	0.094
107368	2Q1	292.4	0.01
107368	P1	196	0.347
107368	2SM2	179	0.018
107368	M3	132.6	0.03
107368	L2	337	0.235
107368	2MK3	93.2	0.007
107368	K2	323.4	0.284
107368	M8	307.6	0.029
107368	MS4	230.4	0.062
107369	M2	302.5	3.629
107369	S2	332.6	0.84
107369	N2	277	0.689
107369	K1	200.5	1.168
107369	M4	223.7	0.172
107369	O1	174.9	0.595
107369	M6	62	0.112
107369	MK3	34.6	0.104
107369	S4	221.4	0.027
107369	MN4	210.5	0.065
107369	NU2	298.7	0.168
107369	S6	314.5	0.004
107369	MU2	113.6	0.067
107369	2N2	263.1	0.073
107369	OO1	262.8	0.122
107369	LDA2	309	0.103
107369	M1	214	0.032
107369	J1	235.5	0.055
107369	RHO1	155.7	0.035
107369	Q1	159.7	0.088
107369	2Q1	258.9	0.014
107369	P1	195	0.344
107369	2SM2	172.1	0.016
107369	M3	129.9	0.019
107369	L2	339	0.243
107369	2MK3	227.3	0.029
107369	K2	325.7	0.299
107369	M8	314.6	0.031
107369	MS4	249.5	0.061
107370	M2	301.9	3.211
107370	S2	333.8	0.787
107370	N2	276.4	0.605
107370	K1	193.6	0.987
107370	M4	278.3	0.318
107370	O1	155.6	0.501
107370	M6	99.9	0.102
107370	MK3	223.1	0.192
107370	S4	191.8	0.041
107370	MN4	247.7	0.101
107370	NU2	292.4	0.14
107370	S6	8	0.011
107370	MU2	175	0.046
107370	2N2	247.5	0.082
107370	OO1	251.7	0.13
107370	LDA2	297.7	0.092
107370	M1	207.4	0.014
107370	J1	228.2	0.07
107370	RHO1	112.7	0.035
107370	Q1	154.9	0.041
107370	2Q1	264.7	0.03
107370	P1	194.5	0.306
107370	2SM2	48.2	0.013
107370	M3	298.1	0.035
107370	L2	345.3	0.206
107370	2MK3	225.9	0.149
107370	K2	325	0.313
107370	M8	336	0.029
107370	MS4	301.7	0.093
107371	M2	301.4	2.801
107371	S2	330.6	0.679
107371	N2	285.8	0.557
107371	K1	199.9	0.923
107371	M4	202.9	0.107
107371	O1	178.2	0.49
107371	M6	50.8	0.111
107371	MK3	46	0.08
107371	S4	228.4	0.019
107371	MN4	182.8	0.048
107371	2N2	224.9	0.054
107371	OO1	275.7	0.122
107371	M1	231.4	0.027
107371	J1	234.9	0.039
107371	Q1	179.9	0.067
107371	2Q1	45.4	0.01
107371	P1	194	0.265
107371	2SM2	178.4	0.022
107371	M3	175.1	0.018
107371	L2	310.2	0.2
107371	2MK3	133.3	0.041
107371	K2	328.9	0.24
107371	M8	341.7	0.004
107371	MS4	239.9	0.046
107372	M2	301.5	2.891
107372	S2	330.5	0.7
107372	N2	286	0.575
107372	K1	199.9	0.951
107372	M4	202.2	0.112
107372	O1	178	0.503
107372	M6	53.1	0.117
107372	MK3	44.3	0.08
107372	S4	228.2	0.019
107372	MN4	183.5	0.051
107372	2N2	223.5	0.057
107372	OO1	276.8	0.126
107372	M1	231.7	0.028
107372	J1	233.3	0.041
107372	Q1	178.8	0.068
107372	2Q1	48.9	0.01
107372	P1	193.9	0.271
107372	2SM2	180.6	0.022
107372	M3	178.1	0.017
107372	L2	310.6	0.205
107372	2MK3	136.4	0.04
107372	K2	328.8	0.248
107372	M8	335.8	0.006
107372	MS4	238.8	0.048
107373	M2	301.6	2.965
107373	S2	330.5	0.718
107373	N2	286.2	0.59
107373	K1	199.9	0.976
107373	M4	202.4	0.117
107373	O1	177.6	0.515
107373	M6	54.8	0.122
107373	MK3	43.9	0.081
107373	S4	232.2	0.019
107373	MN4	184.4	0.053
107373	2N2	222	0.06
107373	OO1	276.5	0.13
107373	M1	232.1	0.028
107373	J1	234.3	0.041
107373	Q1	177.3	0.068
107373	2Q1	53.1	0.009
107373	P1	194.2	0.279
107373	2SM2	181.6	0.023
107373	M3	178.6	0.017
107373	L2	310.8	0.21
107373	2MK3	137.2	0.039
107373	K2	328.9	0.254
107373	M8	332.6	0.009
107373	MS4	238.7	0.049
107374	M2	301.7	3.029
107374	S2	330.5	0.735
107374	N2	286.4	0.602
107374	K1	199.8	0.998
107374	M4	203.3	0.123
107374	O1	177	0.526
107374	M6	55.9	0.126
107374	MK3	44.7	0.08
107374	S4	234.1	0.019
107374	MN4	186.1	0.055
107374	2N2	221.2	0.063
107374	OO1	275.9	0.133
107374	M1	231.2	0.029
107374	J1	235.2	0.043
107374	Q1	175.4	0.069
107374	2Q1	53.8	0.008
107374	P1	194.4	0.286
107374	2SM2	182.5	0.023
107374	M3	180.4	0.017
107374	L2	311.2	0.214
107374	2MK3	137.4	0.038
107374	K2	329	0.258
107374	M8	333.2	0.011
107374	MS4	240.2	0.051
107375	M2	301.8	3.086
107375	S2	330.6	0.749
107375	N2	286.6	0.614
107375	K1	199.8	1.016
107375	M4	205.1	0.128
107375	O1	176.2	0.536
107375	M6	56.7	0.128
107375	MK3	47	0.079
107375	S4	235.9	0.02
107375	MN4	188.5	0.059
107375	2N2	220.5	0.066
107375	OO1	274.7	0.135
107375	M1	229.3	0.029
107375	J1	236.2	0.045
107375	Q1	172.8	0.071
107375	2Q1	64.7	0.006
107375	P1	194.5	0.292
107375	2SM2	183.5	0.024
107375	M3	181.5	0.018
107375	L2	311.7	0.217
107375	2MK3	136.1	0.038
107375	K2	328.9	0.261
107375	M8	332.8	0.014
107375	MS4	242.8	0.053
107376	M2	301.9	3.135
107376	S2	330.6	0.76
107376	N2	286.8	0.625
107376	K1	199.7	1.03
107376	M4	207.4	0.134
107376	O1	175.4	0.545
107376	M6	57.2	0.13
107376	MK3	50	0.079
107376	S4	237.5	0.019
107376	MN4	190.9	0.061
107376	2N2	219.3	0.068
107376	OO1	273.2	0.135
107376	M1	227	0.03
107376	J1	236.3	0.047
107376	Q1	171	0.074
107376	P1	194.4	0.297
107376	2SM2	184.3	0.025
107376	M3	181.8	0.019
107376	L2	312.2	0.219
107376	2MK3	135	0.038
107376	K2	328.7	0.265
107376	M8	334.9	0.016
107376	MS4	245.7	0.055
107377	M2	302	3.177
107377	S2	330.7	0.768
107377	N2	287	0.634
107377	K1	199.7	1.041
107377	M4	209.8	0.141
107377	O1	174.6	0.554
107377	M6	57.7	0.131
107377	MK3	53.1	0.078
107377	S4	238.6	0.019
107377	MN4	192.6	0.064
107377	2N2	218.1	0.071
107377	OO1	271.8	0.136
107377	M1	225.8	0.03
107377	J1	236.8	0.049
107377	Q1	170	0.075
107377	P1	194.5	0.301
107377	2SM2	185.1	0.025
107377	M3	182.3	0.019
107377	L2	312.4	0.221
107377	2MK3	133.9	0.039
107377	K2	328.1	0.268
107377	M8	337	0.019
107377	MS4	248.7	0.057
107378	M2	302.1	3.213
107378	S2	330.8	0.773
107378	N2	287.2	0.641
107378	K1	199.7	1.049
107378	M4	212.1	0.148
107378	O1	173.9	0.561
107378	M6	57.8	0.132
107378	MK3	55.9	0.078
107378	S4	238.9	0.018
107378	MN4	195.1	0.066
107378	2N2	216	0.073
107378	OO1	271	0.137
107378	M1	223.8	0.031
107378	J1	236.6	0.05
107378	Q1	169.7	0.076
107378	P1	194.6	0.303
107378	2SM2	187.2	0.026
107378	M3	183.7	0.02
107378	L2	312.9	0.224
107378	2MK3	133.2	0.039
107378	K2	327.5	0.272
107378	M8	339.4	0.023
107378	MS4	251.7	0.058
107379	M2	302.2	3.242
107379	S2	330.8	0.776
107379	N2	287.4	0.647
107379	K1	199.7	1.057
107379	M4	214.5	0.155
107379	O1	173.2	0.566
107379	M6	57.8	0.132
107379	MK3	58.8	0.078
107379	S4	240.5	0.017
107379	MN4	197.4	0.069
107379	2N2	214.3	0.076
107379	OO1	270.3	0.137
107379	M1	221.7	0.031
107379	J1	236.5	0.052
107379	Q1	168.6	0.076
107379	P1	195.1	0.306
107379	2SM2	187.4	0.025
107379	M3	182.3	0.02
107379	L2	313.3	0.227
107379	2MK3	132.1	0.039
107379	K2	327	0.275
107379	M8	339.9	0.026
107379	MS4	254.1	0.06
107380	M2	302.3	3.267
107380	S2	330.8	0.779
107380	N2	287.6	0.652
107380	K1	199.6	1.06
107380	M4	216.6	0.163
107380	O1	172.6	0.571
107380	M6	57.8	0.133
107380	MK3	61.3	0.078
107380	S4	241.1	0.018
107380	MN4	199.2	0.071
107380	2N2	211.9	0.079
107380	OO1	270.2	0.138
107380	M1	219.1	0.031
107380	J1	236	0.054
107380	Q1	167.8	0.078
107380	P1	195	0.308
107380	2SM2	189.2	0.026
107380	M3	182.6	0.02
107380	L2	313.8	0.231
107380	2MK3	130.8	0.039
107380	K2	326.4	0.279
107380	M8	340.8	0.03
107380	MS4	256.6	0.063
107381	M2	302.4	3.29
107381	S2	330.8	0.782
107381	N2	287.8	0.655
107381	K1	199.7	1.063
107381	M4	218.4	0.172
107381	O1	172.2	0.574
107381	M6	58	0.133
107381	MK3	64.1	0.079
107381	S4	243.5	0.018
107381	MN4	201.6	0.073
107381	2N2	209.6	0.083
107381	OO1	270	0.139
107381	M1	217.4	0.031
107381	J1	235.1	0.056
107381	Q1	167	0.08
107381	2Q1	232.1	0.005
107381	P1	195.1	0.309
107381	2SM2	191.4	0.026
107381	M3	181	0.021
107381	L2	314.3	0.234
107381	2MK3	129.9	0.038
107381	K2	326.4	0.28
107381	M8	340.9	0.033
107381	MS4	258.2	0.065
107382	M2	302.5	3.31
107382	S2	330.7	0.783
107382	N2	288	0.657
107382	K1	199.8	1.064
107382	M4	220	0.182
107382	O1	171.8	0.575
107382	M6	58	0.134
107382	MK3	66	0.08
107382	S4	245.1	0.018
107382	MN4	203.7	0.075
107382	2N2	207.7	0.087
107382	OO1	270.1	0.141
107382	M1	216	0.031
107382	J1	235.2	0.057
107382	Q1	167.2	0.081
107382	2Q1	249.7	0.007
107382	P1	195.2	0.309
107382	2SM2	192.9	0.027
107382	M3	177.6	0.021
107382	L2	314.7	0.237
107382	2MK3	128.1	0.037
107382	K2	326.2	0.282
107382	M8	341.1	0.036
107382	MS4	259.3	0.067
107383	M2	302.5	3.327
107383	S2	330.8	0.785
107383	N2	288.1	0.658
107383	K1	199.8	1.066
107383	M4	221	0.193
107383	O1	171.5	0.574
107383	M6	58.2	0.134
107383	MK3	67.5	0.082
107383	S4	248.9	0.017
107383	MN4	206	0.078
107383	2N2	205.3	0.091
107383	OO1	270.5	0.143
107383	M1	213.9	0.032
107383	J1	234.8	0.057
107383	Q1	167.6	0.084
107383	2Q1	261.2	0.01
107383	P1	195.8	0.31
107383	2SM2	192.7	0.027
107383	M3	173.4	0.022
107383	L2	315.2	0.239
107383	2MK3	124.6	0.035
107383	K2	325.7	0.282
107383	M8	340.3	0.039
107383	MS4	259.8	0.07
107384	M2	302.6	3.341
107384	S2	330.7	0.784
107384	N2	288.2	0.66
107384	K1	199.9	1.064
107384	M4	222	0.205
107384	O1	171.2	0.573
107384	M6	58.2	0.135
107384	MK3	68.1	0.085
107384	S4	251.1	0.017
107384	MN4	208.2	0.08
107384	2N2	203.2	0.096
107384	OO1	270.4	0.146
107384	M1	212.9	0.032
107384	J1	235.4	0.057
107384	Q1	168.3	0.086
107384	2Q1	268.9	0.013
107384	P1	196.2	0.309
107384	2SM2	193.5	0.028
107384	M3	167.5	0.023
107384	L2	315.7	0.241
107384	2MK3	121.5	0.033
107384	K2	325.4	0.282
107384	M8	338.9	0.041
107384	MS4	259.5	0.073
107385	M2	302.6	3.353
107385	S2	330.6	0.784
107385	N2	288.3	0.66
107385	K1	200	1.063
107385	M4	222.6	0.218
107385	O1	170.9	0.571
107385	M6	58.3	0.135
107385	MK3	68.3	0.09
107385	S4	253.1	0.017
107385	MN4	209.8	0.082
107385	2N2	201.8	0.101
107385	OO1	271.1	0.149
107385	M1	211.5	0.032
107385	J1	236.3	0.058
107385	Q1	169.9	0.088
107385	2Q1	275.4	0.017
107385	P1	196.9	0.308
107385	2SM2	193	0.027
107385	M3	164.1	0.025
107385	L2	316	0.243
107385	2MK3	115.8	0.031
107385	K2	325.4	0.283
107385	M8	336.7	0.042
107385	MS4	258.9	0.075
107386	M2	302.6	3.361
107386	S2	330.4	0.785
107386	N2	288.3	0.66
107386	K1	200	1.058
107386	M4	222.9	0.23
107386	O1	170.7	0.569
107386	M6	57.8	0.135
107386	MK3	68.5	0.096
107386	S4	250.2	0.016
107386	MN4	211	0.085
107386	2N2	200.8	0.106
107386	OO1	272.7	0.152
107386	M1	210.7	0.032
107386	J1	238.6	0.058
107386	Q1	171.8	0.089
107386	2Q1	283.9	0.021
107386	P1	197.2	0.306
107386	2SM2	192.5	0.026
107386	M3	159.3	0.027
107386	L2	315.9	0.245
107386	2MK3	111.6	0.03
107386	K2	325.7	0.282
107386	M8	335	0.042
107386	MS4	257.8	0.079
107387	M2	302.5	3.362
107387	S2	330	0.783
107387	N2	288.3	0.655
107387	K1	199.9	1.048
107387	M4	224	0.239
107387	O1	170.7	0.562
107387	M6	57.3	0.135
107387	MK3	66.9	0.098
107387	S4	256.1	0.017
107387	MN4	212.9	0.087
107387	S6	350.6	0.004
107387	2N2	200.1	0.114
107387	OO1	274.1	0.162
107387	M1	208.5	0.032
107387	J1	242.9	0.058
107387	Q1	174.9	0.089
107387	2Q1	290.7	0.026
107387	P1	197.3	0.302
107387	2SM2	187.8	0.025
107387	M3	151.8	0.025
107387	L2	315.7	0.249
107387	2MK3	116.2	0.029
107387	K2	326.6	0.284
107387	M8	331.3	0.043
107387	MS4	259.5	0.083
107388	M2	302.1	3.133
107388	S2	330.7	0.692
107388	N2	288.5	0.584
107388	K1	196	0.932
107388	M4	255.6	0.246
107388	O1	164.8	0.421
107388	M6	60.4	0.12
107388	MK3	279.9	0.083
107388	S4	273	0.026
107388	MN4	248.6	0.106
107388	S6	312.3	0.008
107388	2N2	207.5	0.159
107388	OO1	292.1	0.162
107388	M1	214.5	0.024
107388	J1	228	0.035
107388	Q1	170.8	0.045
107388	2Q1	17.6	0.016
107388	P1	194.8	0.263
107388	2SM2	144.3	0.012
107388	M3	309	0.027
107388	L2	318.8	0.256
107388	2MK3	195.5	0.133
107388	K2	328.1	0.337
107388	M8	340.8	0.046
107388	MS4	291.7	0.135
107389	M2	340	0.56
107389	S2	349.5	0.13
107389	N2	313.9	0.071
107389	K1	196.2	0.165
107389	M4	276.5	0.087
107389	O1	181.1	0.059
107389	M6	165.9	0.068
107389	MK3	90.6	0.039
107389	S4	282.8	0.022
107389	MN4	212.1	0.024
107389	S6	234.5	0.003
107389	2N2	248.6	0.061
107389	OO1	336	0.05
107389	M1	293.1	0.009
107389	J1	35.5	0.014
107389	Q1	333.3	0.011
107389	2Q1	357.1	0.02
107389	P1	213.8	0.053
107389	2SM2	253.6	0.013
107389	M3	24.1	0.011
107389	L2	19.3	0.057
107389	2MK3	278.7	0.025
107389	K2	13.9	0.068
107389	M8	101.9	0.03
107389	MS4	308.1	0.033
107390	M2	326.4	0.605
107390	S2	338.8	0.128
107390	N2	299.8	0.074
107390	K1	172.3	0.148
107390	M4	290.8	0.122
107390	O1	133.6	0.024
107390	M6	160.1	0.06
107390	MK3	96.2	0.047
107390	S4	279.7	0.019
107390	MN4	241.5	0.027
107390	S6	182.3	0.005
107390	2N2	228.4	0.083
107390	OO1	311.3	0.062
107390	M1	309.3	0.009
107390	J1	14.8	0.024
107390	Q1	33.6	0.022
107390	2Q1	309	0.002
107390	P1	204.3	0.05
107390	2SM2	245.6	0.019
107390	M3	38.6	0.014
107390	L2	6.4	0.077
107390	2MK3	303	0.026
107390	K2	350.1	0.056
107390	M8	95.9	0.036
107390	MS4	318.9	0.043
107391	M2	316	0.603
107391	S2	328.8	0.102
107391	N2	294.3	0.084
107391	K1	161.1	0.144
107391	M4	296.7	0.152
107391	O1	115.3	0.039
107391	M6	164.9	0.045
107391	MK3	122	0.054
107391	S4	292.7	0.029
107391	MN4	260.6	0.043
107391	S6	244.8	0.003
107391	2N2	216.7	0.077
107391	OO1	311.4	0.07
107391	M1	298.8	0.008
107391	J1	0.6	0.022
107391	Q1	48.7	0.018
107391	2Q1	339.4	0.017
107391	P1	171	0.038
107391	2SM2	252.4	0.026
107391	M3	30.9	0.022
107391	L2	347.2	0.089
107391	2MK3	304.7	0.024
107391	K2	321.6	0.067
107391	M8	90.2	0.035
107391	MS4	328.6	0.06
107392	M2	265.3	0.906
107392	S2	286	0.184
107392	N2	247.8	0.141
107392	K1	163.7	0.092
107392	M4	154.7	0.243
107392	O1	253.2	0.093
107392	M6	56	0.101
107392	MK3	10.1	0.141
107392	S4	170	0.025
107392	MN4	132.1	0.078
107392	S6	31.9	0.007
107392	2N2	149.8	0.078
107392	OO1	281.9	0.068
107392	M1	306.9	0.016
107392	J1	329.7	0.009
107392	Q1	259.1	0.016
107392	2Q1	214.5	0.019
107392	P1	183.1	0.027
107392	2SM2	189.9	0.016
107392	M3	53.5	0.031
107392	L2	287.4	0.104
107392	2MK3	283	0.044
107392	K2	284.1	0.059
107392	M8	329.6	0.036
107392	MS4	175.1	0.112
107393	M2	264.8	1.128
107393	S2	284.4	0.232
107393	N2	245.3	0.174
107393	K1	164.7	0.123
107393	M4	153.2	0.318
107393	O1	250.8	0.107
107393	M6	54.9	0.152
107393	MK3	7.3	0.181
107393	S4	170.5	0.025
107393	MN4	133.2	0.101
107393	S6	24.8	0.008
107393	2N2	151.7	0.096
107393	OO1	284.7	0.089
107393	M1	309.6	0.02
107393	J1	335.2	0.015
107393	Q1	255.6	0.02
107393	2Q1	225.2	0.025
107393	P1	185.9	0.032
107393	2SM2	188.5	0.022
107393	M3	53.9	0.039
107393	L2	284.9	0.127
107393	2MK3	282.5	0.055
107393	K2	290	0.08
107393	M8	325.4	0.062
107393	MS4	175	0.146
107394	M2	264.1	1.102
107394	S2	283.4	0.233
107394	N2	244.1	0.172
107394	K1	158.5	0.134
107394	M4	147.4	0.336
107394	O1	249.3	0.098
107394	M6	50.2	0.176
107394	MK3	4.5	0.19
107394	S4	169.1	0.023
107394	MN4	127.9	0.109
107394	S6	354.3	0.008
107394	2N2	154.5	0.097
107394	OO1	283.6	0.092
107394	M1	312.8	0.017
107394	J1	348.3	0.018
107394	Q1	262.5	0.018
107394	2Q1	235.1	0.023
107394	P1	179.1	0.034
107394	2SM2	183.7	0.02
107394	M3	55.5	0.041
107394	L2	280.4	0.114
107394	2MK3	284.1	0.049
107394	K2	293	0.091
107394	M8	322.8	0.071
107394	MS4	172.1	0.146
107395	M2	311.1	1.861
107395	S2	341.1	0.48
107395	N2	284.8	0.319
107395	K1	205.9	0.691
107395	M4	283.9	0.052
107395	O1	177.5	0.359
107395	M6	315.7	0.032
107395	MK3	137.6	0.065
107395	S4	180.4	0.018
107395	MN4	248.9	0.028
107395	S6	153.2	0.01
107395	2N2	292.5	0.061
107395	OO1	267.4	0.066
107395	M1	247.4	0.01
107395	J1	271	0.016
107395	Q1	128.8	0.038
107395	2Q1	171.3	0.04
107395	P1	196.1	0.24
107395	2SM2	223.3	0.004
107395	M3	208.5	0.023
107395	L2	353.6	0.05
107395	2MK3	95.6	0.027
107395	K2	325.6	0.166
107395	M8	203.3	0.031
107395	MS4	286.4	0.041
107396	M2	311	1.913
107396	S2	340.9	0.491
107396	N2	284.7	0.326
107396	K1	205.1	0.705
107396	M4	283.4	0.058
107396	O1	176.4	0.37
107396	M6	322	0.03
107396	MK3	139.8	0.067
107396	S4	182.7	0.018
107396	MN4	249.6	0.03
107396	S6	149.6	0.008
107396	2N2	290	0.062
107396	OO1	264.6	0.059
107396	M1	237.4	0.011
107396	J1	265.5	0.017
107396	Q1	127.8	0.037
107396	2Q1	169.2	0.038
107396	P1	196.6	0.245
107396	2SM2	209.8	0.007
107396	M3	202.3	0.022
107396	L2	353.8	0.053
107396	2MK3	92.3	0.024
107396	K2	325.4	0.166
107396	M8	206.8	0.029
107396	MS4	286.8	0.042
107397	M2	310.8	1.947
107397	S2	340.6	0.497
107397	N2	284.5	0.329
107397	K1	204.3	0.712
107397	M4	282.7	0.065
107397	O1	175.1	0.377
107397	M6	324.7	0.028
107397	MK3	139.4	0.068
107397	S4	185.6	0.017
107397	MN4	249.9	0.032
107397	S6	145.4	0.007
107397	2N2	287	0.063
107397	OO1	258.4	0.053
107397	M1	230.2	0.011
107397	J1	260.8	0.018
107397	Q1	129.1	0.038
107397	2Q1	166.4	0.035
107397	P1	197.4	0.247
107397	2SM2	202.3	0.009
107397	M3	196.6	0.022
107397	L2	354.9	0.056
107397	2MK3	89	0.022
107397	K2	325.2	0.163
107397	M8	211.5	0.027
107397	MS4	286.8	0.045
107398	M2	310.6	1.974
107398	S2	340.5	0.5
107398	N2	284.3	0.332
107398	K1	203.3	0.716
107398	M4	281.5	0.073
107398	O1	173.7	0.382
107398	M6	324.4	0.027
107398	MK3	138.5	0.07
107398	S4	191.6	0.016
107398	MN4	249	0.035
107398	S6	141.8	0.006
107398	2N2	284.2	0.064
107398	OO1	249.9	0.048
107398	M1	223.3	0.012
107398	J1	259.3	0.02
107398	Q1	130.1	0.038
107398	2Q1	164	0.031
107398	P1	198.2	0.249
107398	2SM2	195.8	0.01
107398	M3	190.4	0.022
107398	L2	355.1	0.058
107398	2MK3	86.2	0.022
107398	K2	325.2	0.159
107398	M8	215	0.027
107398	MS4	286.5	0.048
107399	M2	310.3	1.995
107399	S2	340.2	0.502
107399	N2	284	0.333
107399	K1	202.4	0.717
107399	M4	280.5	0.082
107399	O1	172.6	0.385
107399	M6	323.3	0.027
107399	MK3	135.5	0.071
107399	S4	196.6	0.018
107399	MN4	247.6	0.037
107399	S6	135.7	0.007
107399	2N2	281.8	0.065
107399	OO1	241	0.043
107399	M1	218.3	0.013
107399	J1	257.3	0.023
107399	Q1	132.5	0.038
107399	2Q1	160.8	0.027
107399	P1	198.8	0.251
107399	2SM2	190.3	0.011
107399	M3	185.7	0.023
107399	L2	355.2	0.06
107399	2MK3	85.7	0.022
107399	K2	324.1	0.156
107399	M8	219.8	0.027
107399	MS4	285.5	0.052
107400	M2	309.9	2.012
107400	S2	339.8	0.505
107400	N2	283.6	0.333
107400	K1	201.6	0.716
107400	M4	278.7	0.09
107400	O1	171.4	0.387
107400	M6	321.8	0.027
107400	MK3	131.9	0.074
107400	S4	201.7	0.019
107400	MN4	246.1	0.04
107400	S6	129.6	0.007
107400	2N2	279.4	0.067
107400	OO1	229.2	0.039
107400	M1	215.4	0.013
107400	J1	255	0.026
107400	Q1	134	0.038
107400	2Q1	156.9	0.024
107400	P1	199.1	0.253
107400	2SM2	187.6	0.011
107400	M3	183	0.025
107400	L2	354.8	0.061
107400	2MK3	85.5	0.024
107400	K2	323.1	0.157
107400	M8	223.7	0.029
107400	MS4	285.4	0.056
107401	M2	309.5	2.024
107401	S2	339.6	0.508
107401	N2	283.1	0.334
107401	K1	200.7	0.716
107401	M4	277	0.098
107401	O1	170.6	0.388
107401	M6	322.6	0.028
107401	MK3	127.9	0.078
107401	S4	204.3	0.022
107401	MN4	245.1	0.042
107401	S6	131.2	0.007
107401	2N2	277.8	0.068
107401	OO1	215.5	0.036
107401	M1	213.2	0.014
107401	J1	254.1	0.03
107401	Q1	135.8	0.037
107401	2Q1	150.3	0.021
107401	P1	199.7	0.251
107401	2SM2	181.5	0.012
107401	M3	182.1	0.026
107401	L2	354.7	0.061
107401	2MK3	85.2	0.025
107401	K2	322.6	0.158
107401	M8	227.7	0.03
107401	MS4	285.2	0.06
107402	M2	309.1	2.033
107402	S2	339.2	0.509
107402	N2	282.3	0.333
107402	K1	199.9	0.715
107402	M4	274.6	0.107
107402	O1	169.7	0.386
107402	M6	323.7	0.028
107402	MK3	123.4	0.083
107402	S4	206	0.025
107402	MN4	242.5	0.045
107402	S6	133.8	0.007
107402	2N2	277	0.069
107402	OO1	202.2	0.035
107402	M1	212	0.015
107402	J1	254	0.032
107402	Q1	138.5	0.037
107402	2Q1	143	0.019
107402	P1	199.8	0.249
107402	2SM2	177.5	0.013
107402	M3	182.4	0.027
107402	L2	354.8	0.061
107402	2MK3	83.1	0.027
107402	K2	321.1	0.158
107402	M8	231.5	0.031
107402	MS4	285.9	0.064
107403	M2	308.6	2.039
107403	S2	338.8	0.509
107403	N2	281.6	0.332
107403	K1	199.1	0.713
107403	M4	272.1	0.116
107403	O1	169	0.384
107403	M6	326.8	0.028
107403	MK3	118.7	0.09
107403	S4	207.5	0.028
107403	MN4	239.8	0.047
107403	S6	139.7	0.006
107403	2N2	276.5	0.071
107403	OO1	190.5	0.036
107403	M1	210.5	0.016
107403	J1	253.1	0.035
107403	Q1	140.8	0.036
107403	2Q1	135	0.018
107403	P1	200.1	0.246
107403	2SM2	173.5	0.014
107403	M3	183.3	0.028
107403	L2	354.3	0.061
107403	2MK3	83.7	0.028
107403	K2	319.4	0.157
107403	M8	235.8	0.031
107403	MS4	286.1	0.068
107404	M2	308.1	2.042
107404	S2	338.3	0.508
107404	N2	281	0.331
107404	K1	198.4	0.712
107404	M4	269.8	0.126
107404	O1	168.4	0.38
107404	M6	331.6	0.027
107404	MK3	114.1	0.097
107404	S4	206.2	0.03
107404	MN4	237.7	0.05
107404	S6	146.2	0.006
107404	2N2	276	0.072
107404	OO1	182.2	0.038
107404	M1	210.9	0.017
107404	J1	253.6	0.036
107404	Q1	143.9	0.036
107404	2Q1	127.9	0.017
107404	P1	200.3	0.242
107404	2SM2	172.5	0.014
107404	M3	184.5	0.029
107404	L2	353.1	0.061
107404	2MK3	82.5	0.029
107404	K2	317.4	0.157
107404	M8	239.8	0.032
107404	MS4	286.8	0.072
107405	M2	307.6	2.041
107405	S2	337.8	0.504
107405	N2	280.3	0.329
107405	K1	197.9	0.708
107405	M4	267.3	0.137
107405	O1	167.9	0.373
107405	M6	338.4	0.027
107405	MK3	110.5	0.104
107405	S4	204.7	0.031
107405	MN4	236.3	0.053
107405	S6	152	0.005
107405	2N2	276.2	0.072
107405	OO1	179.8	0.043
107405	M1	211.9	0.017
107405	J1	252.2	0.037
107405	Q1	145.8	0.036
107405	2Q1	121.8	0.017
107405	P1	200.2	0.237
107405	2SM2	172.4	0.014
107405	M3	186.2	0.029
107405	L2	353.4	0.061
107405	2MK3	82.5	0.03
107405	K2	315.4	0.159
107405	M8	243.8	0.031
107405	MS4	287.1	0.075
107406	M2	307.1	2.039
107406	S2	337	0.501
107406	N2	279.8	0.325
107406	K1	197.5	0.703
107406	M4	264.8	0.149
107406	O1	167.5	0.363
107406	M6	346.4	0.025
107406	MK3	107.4	0.112
107406	S4	203.5	0.032
107406	MN4	235.2	0.056
107406	S6	158.1	0.005
107406	2N2	276.9	0.072
107406	OO1	179.2	0.045
107406	M1	213.1	0.018
107406	J1	250.6	0.037
107406	Q1	149.1	0.037
107406	2Q1	118	0.016
107406	P1	199.9	0.231
107406	2SM2	173.4	0.012
107406	M3	187.3	0.029
107406	L2	354.2	0.061
107406	2MK3	80.6	0.03
107406	K2	313	0.16
107406	M8	247.9	0.03
107406	MS4	287	0.08
107407	M2	306.6	2.033
107407	S2	336.4	0.495
107407	N2	279.4	0.321
107407	K1	197.2	0.697
107407	M4	262.8	0.163
107407	O1	167	0.352
107407	M6	355.3	0.024
107407	MK3	105.7	0.12
107407	S4	202.6	0.033
107407	MN4	234.3	0.059
107407	S6	158.1	0.005
107407	2N2	277.7	0.071
107407	OO1	178.5	0.048
107407	M1	214.4	0.018
107407	J1	250.9	0.036
107407	Q1	152.1	0.038
107407	2Q1	116.4	0.015
107407	P1	199.7	0.224
107407	2SM2	177.6	0.011
107407	M3	188.2	0.029
107407	L2	354.8	0.061
107407	2MK3	78.2	0.029
107407	K2	311	0.159
107407	M8	253	0.029
107407	MS4	286.6	0.084
107408	M2	306.1	2.025
107408	S2	335.6	0.488
107408	N2	279.1	0.317
107408	K1	197	0.688
107408	M4	261.2	0.179
107408	O1	166.7	0.34
107408	M6	5.3	0.023
107408	MK3	104.8	0.128
107408	S4	201.3	0.034
107408	MN4	233.6	0.062
107408	S6	161.4	0.005
107408	2N2	279.3	0.071
107408	OO1	176.7	0.05
107408	M1	216.6	0.018
107408	J1	249.6	0.035
107408	Q1	155.6	0.039
107408	2Q1	118.5	0.015
107408	P1	199.3	0.218
107408	2SM2	177.6	0.009
107408	M3	189	0.029
107408	L2	355.6	0.061
107408	2MK3	75.7	0.029
107408	K2	309	0.157
107408	M8	259	0.027
107408	MS4	286.3	0.088
107409	M2	305.6	2.013
107409	S2	334.6	0.478
107409	N2	278.7	0.312
107409	K1	196.6	0.678
107409	M4	260.3	0.195
107409	O1	166.3	0.326
107409	M6	13.6	0.022
107409	MK3	104.8	0.136
107409	S4	201.9	0.035
107409	MN4	232.5	0.066
107409	S6	154.8	0.004
107409	2N2	281.9	0.068
107409	OO1	175.6	0.051
107409	M1	219.2	0.018
107409	J1	245.9	0.034
107409	Q1	157.3	0.038
107409	2Q1	121.7	0.016
107409	P1	199.4	0.209
107409	2SM2	178.5	0.008
107409	M3	189.4	0.029
107409	L2	357	0.061
107409	2MK3	72.8	0.029
107409	K2	306.1	0.151
107409	M8	267.6	0.024
107409	MS4	285.7	0.093
107410	M2	305.2	1.999
107410	S2	333.6	0.467
107410	N2	278	0.307
107410	K1	196	0.666
107410	M4	259.9	0.213
107410	O1	166.2	0.31
107410	M6	18.3	0.021
107410	MK3	105.5	0.144
107410	S4	203.9	0.037
107410	MN4	230.9	0.071
107410	S6	133.7	0.003
107410	2N2	286.4	0.066
107410	OO1	175.3	0.052
107410	M1	220.9	0.018
107410	J1	240.3	0.032
107410	Q1	158	0.038
107410	2Q1	131.2	0.015
107410	P1	200.1	0.2
107410	2SM2	183.3	0.008
107410	M3	189	0.029
107410	L2	357.7	0.062
107410	2MK3	70.6	0.033
107410	K2	303.3	0.142
107410	M8	281.2	0.022
107410	MS4	284.8	0.098
107411	M2	304.7	1.981
107411	S2	332.2	0.457
107411	N2	277.3	0.303
107411	K1	195.5	0.652
107411	M4	259.8	0.23
107411	O1	165.8	0.292
107411	M6	17.2	0.021
107411	MK3	106.2	0.152
107411	S4	204.3	0.039
107411	MN4	229.6	0.076
107411	2N2	291.4	0.063
107411	OO1	174	0.052
107411	M1	224.2	0.018
107411	J1	234.5	0.032
107411	Q1	157	0.037
107411	2Q1	140.7	0.014
107411	P1	199.9	0.191
107411	2SM2	182.4	0.009
107411	M3	188.3	0.029
107411	L2	358.9	0.062
107411	2MK3	69.2	0.036
107411	K2	300.1	0.135
107411	M8	300.5	0.021
107411	MS4	283.3	0.104
107412	M2	303.7	1.942
107412	S2	331.2	0.441
107412	N2	276.2	0.297
107412	K1	193.7	0.634
107412	M4	264.6	0.247
107412	O1	161.3	0.269
107412	M6	3	0.005
107412	MK3	110.5	0.134
107412	S4	204.4	0.038
107412	MN4	235.1	0.078
107412	2N2	296.5	0.067
107412	OO1	182	0.052
107412	M1	226.2	0.017
107412	J1	225.6	0.03
107412	Q1	149.8	0.035
107412	2Q1	153.3	0.016
107412	P1	198.6	0.178
107412	2SM2	178.4	0.011
107412	M3	197	0.027
107412	L2	1.3	0.064
107412	2MK3	72.8	0.022
107412	K2	304.4	0.13
107412	M8	328.3	0.025
107412	MS4	291.1	0.114
107413	M2	315.6	0.26
107413	S2	350.2	0.103
107413	N2	297.6	0.061
107413	K1	183.2	0.198
107413	M4	345.6	0.108
107413	O1	174.4	0.151
107413	M6	13.8	0.041
107413	MK3	194.2	0.112
107413	S4	302.9	0.02
107413	MN4	330.2	0.042
107413	S6	350	0.005
107413	2N2	67.4	0.026
107413	OO1	254.2	0.016
107413	M1	262.5	0.008
107413	J1	209.7	0.002
107413	Q1	166.5	0.031
107413	2Q1	17.9	0.028
107413	P1	228.4	0.039
107413	2SM2	225.5	0.017
107413	M3	308	0.033
107413	L2	271.1	0.005
107413	2MK3	167.4	0.048
107413	K2	306.7	0.044
107413	M8	25.4	0.009
107413	MS4	2.9	0.049
107414	M2	316.5	0.262
107414	S2	350.3	0.098
107414	N2	297.4	0.058
107414	K1	186.6	0.19
107414	M4	341.4	0.102
107414	O1	177.1	0.144
107414	M6	4.5	0.033
107414	MK3	193.8	0.105
107414	S4	305.4	0.021
107414	MN4	329.1	0.038
107414	S6	2.3	0.006
107414	2N2	69.8	0.032
107414	OO1	254.9	0.022
107414	M1	271.9	0.01
107414	J1	194.4	0.003
107414	Q1	163.9	0.032
107414	2Q1	19.4	0.031
107414	P1	229.2	0.038
107414	2SM2	232.4	0.015
107414	M3	312.2	0.031
107414	L2	305.2	0.007
107414	2MK3	175	0.044
107414	K2	296.9	0.048
107414	M8	17.9	0.007
107414	MS4	0.9	0.044
107415	M2	317.4	0.263
107415	S2	348.5	0.091
107415	N2	297.8	0.055
107415	K1	191.5	0.18
107415	M4	337.2	0.094
107415	O1	179.5	0.138
107415	M6	354.1	0.027
107415	MK3	193.3	0.096
107415	S4	305.2	0.021
107415	MN4	327.3	0.034
107415	S6	16	0.007
107415	2N2	71.3	0.037
107415	OO1	260.5	0.026
107415	M1	281	0.012
107415	J1	187.4	0.003
107415	Q1	160.3	0.033
107415	2Q1	21.7	0.033
107415	P1	226.5	0.036
107415	2SM2	241.2	0.013
107415	M3	313.9	0.029
107415	L2	331.4	0.009
107415	2MK3	182.1	0.04
107415	K2	286.7	0.054
107415	M8	9.8	0.006
107415	MS4	359.2	0.038
107416	M2	318.5	0.265
107416	S2	348.2	0.083
107416	N2	297.7	0.052
107416	K1	197.4	0.172
107416	M4	332.5	0.085
107416	O1	181.6	0.131
107416	M6	340.5	0.02
107416	MK3	192.9	0.086
107416	S4	306.6	0.021
107416	MN4	326.7	0.029
107416	S6	27.7	0.008
107416	2N2	72	0.039
107416	OO1	270.2	0.03
107416	M1	288.7	0.013
107416	J1	167.1	0.003
107416	Q1	156.5	0.033
107416	2Q1	22	0.033
107416	P1	221.9	0.035
107416	2SM2	260.7	0.01
107416	M3	316.9	0.026
107416	L2	346.4	0.013
107416	2MK3	190.9	0.037
107416	K2	279.5	0.055
107416	M8	3.9	0.004
107416	MS4	358.6	0.033
107417	M2	319.8	0.267
107417	S2	348.3	0.078
107417	N2	297	0.049
107417	K1	204.2	0.163
107417	M4	327.2	0.076
107417	O1	183.4	0.124
107417	M6	316.7	0.015
107417	MK3	192.3	0.074
107417	S4	307.3	0.02
107417	MN4	329.6	0.024
107417	S6	36.9	0.008
107417	2N2	73.2	0.04
107417	OO1	281.8	0.038
107417	M1	294.5	0.015
107417	J1	167.7	0.004
107417	Q1	151.3	0.033
107417	2Q1	20.5	0.032
107417	P1	213.9	0.035
107417	2SM2	279.8	0.01
107417	M3	319.9	0.022
107417	L2	358.6	0.016
107417	2MK3	197.6	0.034
107417	K2	275.9	0.055
107417	M8	349.8	0.003
107417	MS4	357.4	0.029
107418	M2	321.5	0.268
107418	S2	347.4	0.075
107418	N2	297.2	0.046
107418	K1	210.2	0.155
107418	M4	322	0.067
107418	O1	183.9	0.118
107418	M6	283.9	0.014
107418	MK3	191.2	0.06
107418	S4	310.7	0.019
107418	MN4	332.5	0.018
107418	S6	44.2	0.008
107418	2N2	76.2	0.037
107418	OO1	291.8	0.047
107418	M1	296.4	0.015
107418	J1	161.6	0.007
107418	Q1	147.6	0.033
107418	2Q1	19.5	0.029
107418	P1	208.7	0.038
107418	2SM2	295.7	0.009
107418	M3	317	0.018
107418	L2	8.2	0.02
107418	2MK3	201	0.031
107418	K2	277.3	0.059
107418	M8	329	0.002
107418	MS4	356.6	0.025
107419	M2	323.3	0.267
107419	S2	347.7	0.071
107419	N2	297.5	0.043
107419	K1	214.9	0.148
107419	M4	315.6	0.057
107419	O1	183.1	0.113
107419	M6	258.8	0.017
107419	MK3	190.4	0.046
107419	S4	311.5	0.017
107419	MN4	334.9	0.013
107419	S6	55.1	0.008
107419	2N2	82.9	0.032
107419	OO1	300	0.05
107419	M1	297.1	0.015
107419	J1	169.4	0.007
107419	Q1	143	0.031
107419	2Q1	17.2	0.025
107419	P1	208.9	0.041
107419	2SM2	304.3	0.009
107419	M3	306.8	0.015
107419	L2	16.1	0.023
107419	2MK3	201.7	0.026
107419	K2	280.2	0.058
107419	M8	286	0.001
107419	MS4	356.4	0.021
107420	M2	325.1	0.266
107420	S2	346.6	0.068
107420	N2	297.5	0.043
107420	K1	218.2	0.144
107420	M4	307.2	0.047
107420	O1	181.3	0.111
107420	M6	243.8	0.02
107420	MK3	191	0.034
107420	S4	313.6	0.014
107420	MN4	337.3	0.008
107420	S6	68.7	0.008
107420	2N2	93.7	0.026
107420	OO1	308.4	0.046
107420	M1	293.7	0.013
107420	J1	188.8	0.006
107420	Q1	140.2	0.029
107420	2Q1	13	0.02
107420	P1	214.2	0.044
107420	2SM2	309.8	0.009
107420	M3	292.7	0.014
107420	L2	23.8	0.026
107420	2MK3	200.3	0.024
107420	K2	284.5	0.058
107420	M8	251.7	0.002
107420	MS4	353.9	0.017
107421	M2	326.4	0.263
107421	S2	346.5	0.064
107421	N2	297.5	0.041
107421	K1	220.5	0.141
107421	M4	295.4	0.037
107421	O1	179.6	0.113
107421	M6	237.6	0.02
107421	MK3	194.1	0.025
107421	S4	317.4	0.011
107421	MN4	342.5	0.004
107421	S6	77.9	0.01
107421	2N2	108.6	0.019
107421	OO1	317	0.038
107421	M1	284.7	0.011
107421	J1	223.8	0.006
107421	Q1	142.8	0.028
107421	2Q1	4.5	0.016
107421	P1	222.6	0.045
107421	2SM2	320	0.008
107421	M3	281.5	0.014
107421	L2	29.1	0.028
107421	2MK3	200.5	0.022
107421	K2	289.4	0.055
107421	M8	241.7	0.003
107421	MS4	347.8	0.011
107422	M2	327.1	0.259
107422	S2	346.8	0.06
107422	N2	297.9	0.04
107422	K1	222	0.135
107422	M4	274.7	0.028
107422	O1	178.8	0.118
107422	M6	232.5	0.019
107422	MK3	204.9	0.021
107422	S4	325.6	0.01
107422	MN4	9.4	0.002
107422	S6	81.4	0.01
107422	2N2	136.2	0.014
107422	OO1	324.8	0.027
107422	M1	262.5	0.009
107422	J1	248.8	0.008
107422	Q1	147.2	0.027
107422	2Q1	358.6	0.014
107422	P1	230.9	0.049
107422	2SM2	330.6	0.007
107422	M3	277.9	0.015
107422	L2	33.7	0.029
107422	2MK3	204.8	0.022
107422	K2	293.7	0.049
107422	M8	237.5	0.004
107422	MS4	333.3	0.007
107423	M2	327.3	0.254
107423	S2	348.4	0.058
107423	N2	297.9	0.039
107423	K1	222.9	0.13
107423	M4	244.9	0.025
107423	O1	179.1	0.122
107423	M6	226.5	0.016
107423	MK3	218.7	0.021
107423	S4	335.6	0.009
107423	MN4	35.2	0.003
107423	S6	84.3	0.01
107423	2N2	176.7	0.012
107423	OO1	333.4	0.016
107423	M1	237.5	0.009
107423	J1	268.4	0.01
107423	Q1	153.5	0.026
107423	2Q1	347.8	0.011
107423	P1	238.7	0.055
107423	2SM2	335.4	0.006
107423	M3	282.4	0.017
107423	L2	37.2	0.028
107423	2MK3	211.7	0.026
107423	K2	299.8	0.047
107423	M8	225.4	0.004
107423	MS4	309.8	0.005
107424	M2	327.1	0.249
107424	S2	352.5	0.058
107424	N2	298.4	0.036
107424	K1	225.8	0.123
107424	M4	221	0.029
107424	O1	180.7	0.125
107424	M6	211.8	0.013
107424	MK3	232.7	0.026
107424	S4	343.5	0.011
107424	MN4	43	0.004
107424	S6	86.5	0.008
107424	2N2	207.7	0.018
107424	OO1	358.9	0.007
107424	M1	213.5	0.01
107424	J1	268.3	0.011
107424	Q1	155.4	0.023
107424	2Q1	325.7	0.009
107424	P1	241	0.064
107424	2SM2	326.5	0.005
107424	M3	291.1	0.02
107424	L2	38.3	0.025
107424	2MK3	215.7	0.032
107424	K2	307.8	0.044
107424	M8	213.7	0.005
107424	MS4	276.2	0.005
107425	M2	326.3	0.243
107425	S2	355.9	0.059
107425	N2	302.9	0.033
107425	K1	228.8	0.119
107425	M4	207.5	0.033
107425	O1	183.2	0.121
107425	M6	192.1	0.013
107425	MK3	242.9	0.035
107425	S4	347.7	0.012
107425	MN4	34.3	0.005
107425	S6	82.7	0.007
107425	2N2	218.5	0.025
107425	OO1	96.9	0.006
107425	M1	193.9	0.012
107425	J1	270.4	0.012
107425	Q1	161.1	0.02
107425	2Q1	311	0.008
107425	P1	241.7	0.074
107425	2SM2	308.1	0.005
107425	M3	295.8	0.023
107425	L2	39.2	0.021
107425	2MK3	216	0.039
107425	K2	312.5	0.044
107425	M8	196.5	0.005
107425	MS4	252.1	0.008
107426	M2	324.8	0.237
107426	S2	358.3	0.058
107426	N2	309.7	0.032
107426	K1	231.4	0.119
107426	M4	199.2	0.036
107426	O1	186.6	0.112
107426	M6	173.6	0.016
107426	MK3	249.5	0.047
107426	S4	348.6	0.012
107426	MN4	19.3	0.005
107426	S6	77	0.007
107426	2N2	217.8	0.032
107426	OO1	136.3	0.011
107426	M1	181.2	0.014
107426	J1	277.4	0.012
107426	Q1	177.7	0.018
107426	2Q1	295.6	0.008
107426	P1	240.6	0.082
107426	2SM2	307	0.006
107426	M3	298.6	0.028
107426	L2	39.1	0.018
107426	2MK3	213.5	0.048
107426	K2	311.7	0.046
107426	M8	166.3	0.005
107426	MS4	248.7	0.013
107427	M2	322.7	0.229
107427	S2	359.4	0.059
107427	N2	315	0.032
107427	K1	233.9	0.123
107427	M4	195.4	0.038
107427	O1	192	0.101
107427	M6	164.5	0.02
107427	MK3	253.3	0.062
107427	S4	349.1	0.012
107427	MN4	15.2	0.004
107427	S6	79.8	0.006
107427	2N2	213.3	0.039
107427	OO1	148.1	0.02
107427	M1	172.2	0.015
107427	J1	281.5	0.012
107427	Q1	189.1	0.019
107427	2Q1	274.1	0.011
107427	P1	236.7	0.085
107427	2SM2	306.1	0.007
107427	M3	299.1	0.033
107427	L2	38.1	0.017
107427	2MK3	210.6	0.058
107427	K2	307.9	0.051
107427	M8	130.3	0.006
107427	MS4	248.6	0.016
107428	M2	320.3	0.221
107428	S2	2.5	0.06
107428	N2	315.6	0.033
107428	K1	234.2	0.133
107428	M4	195.8	0.04
107428	O1	199.6	0.087
107428	M6	159.2	0.024
107428	MK3	254.6	0.079
107428	S4	353.8	0.012
107428	MN4	122.6	0.001
107428	S6	60.6	0.004
107428	2N2	206.9	0.046
107428	OO1	148.8	0.026
107428	M1	161.4	0.016
107428	J1	285.1	0.014
107428	Q1	189.5	0.025
107428	2Q1	260.9	0.014
107428	P1	232.8	0.085
107428	2SM2	292.7	0.009
107428	M3	300.8	0.037
107428	L2	39.3	0.018
107428	2MK3	209.4	0.066
107428	K2	304.6	0.051
107428	M8	123.7	0.008
107428	MS4	249.9	0.019
107429	M2	316.9	0.209
107429	S2	6.4	0.06
107429	N2	313.5	0.035
107429	K1	233.7	0.146
107429	M4	199.3	0.04
107429	O1	209.7	0.073
107429	M6	157.3	0.028
107429	MK3	253.8	0.095
107429	S4	354.3	0.01
107429	MN4	160.9	0.005
107429	S6	346.1	0.005
107429	2N2	197	0.053
107429	OO1	149.7	0.033
107429	M1	145	0.015
107429	J1	298.1	0.014
107429	Q1	184.4	0.031
107429	2Q1	255.3	0.019
107429	P1	227	0.083
107429	2SM2	268.1	0.011
107429	M3	305.9	0.038
107429	L2	35.5	0.022
107429	2MK3	209.7	0.073
107429	K2	299.7	0.046
107429	M8	115.8	0.009
107429	MS4	247.1	0.021
107430	M2	294.3	0.356
107430	S2	302.8	0.081
107430	N2	251.4	0.053
107430	K1	157.2	0.106
107430	M4	54.3	0.019
107430	O1	150.5	0.076
107430	M6	79.4	0.014
107430	MK3	279	0.051
107430	S4	47.5	0.001
107430	MN4	26.2	0.011
107430	S6	18.7	0.004
107430	2N2	268.7	0.035
107430	OO1	166.9	0.048
107430	M1	164.6	0.001
107430	J1	21.5	0.007
107430	Q1	119.8	0.008
107430	2Q1	85.3	0.021
107430	2SM2	268.3	0.003
107430	M3	331.1	0.013
107430	L2	8.2	0.027
107430	2MK3	299.9	0.014
107430	K2	294.8	0.052
107430	M8	275.3	0.01
107430	MS4	55.6	0.009
107431	M2	296	0.346
107431	S2	304.6	0.073
107431	N2	254.8	0.048
107431	K1	162	0.104
107431	M4	52.1	0.018
107431	O1	151	0.071
107431	M6	81.1	0.012
107431	MK3	275.9	0.05
107431	S4	72.2	0.001
107431	MN4	28.6	0.011
107431	S6	23.9	0.004
107431	2N2	261.8	0.035
107431	OO1	166.8	0.047
107431	M1	183	0.002
107431	J1	35	0.006
107431	Q1	109.2	0.01
107431	2Q1	82.4	0.015
107431	2SM2	311.6	0.002
107431	M3	337.8	0.013
107431	L2	4.7	0.025
107431	2MK3	270.5	0.016
107431	K2	291.9	0.044
107431	M8	277.6	0.011
107431	MS4	53.9	0.006
107432	M2	297.8	0.334
107432	S2	305.7	0.068
107432	N2	258.6	0.043
107432	K1	167.7	0.102
107432	M4	45.8	0.016
107432	O1	153.8	0.064
107432	M6	80.2	0.012
107432	MK3	271.3	0.048
107432	S4	162.3	0.001
107432	MN4	34.9	0.012
107432	S6	22.9	0.005
107432	2N2	257.1	0.033
107432	OO1	165	0.044
107432	M1	189.9	0.003
107432	J1	51.7	0.007
107432	Q1	114	0.011
107432	2Q1	69.3	0.006
107432	2SM2	357.3	0.002
107432	M3	344.8	0.014
107432	L2	5.7	0.023
107432	2MK3	251	0.023
107432	K2	287.6	0.04
107432	M8	283.8	0.011
107432	MS4	45.5	0.003
107433	M2	299.6	0.323
107433	S2	310.6	0.063
107433	N2	262.5	0.04
107433	K1	173.8	0.103
107433	M4	38	0.016
107433	O1	157.4	0.058
107433	M6	74	0.012
107433	MK3	267.4	0.045
107433	S4	179.6	0.002
107433	MN4	36.8	0.012
107433	S6	22.6	0.006
107433	2N2	252.5	0.031
107433	OO1	166.9	0.04
107433	M1	208.1	0.002
107433	J1	55.9	0.008
107433	Q1	129.3	0.012
107433	2Q1	312.5	0.003
107433	2SM2	21.2	0.003
107433	M3	348.2	0.015
107433	L2	9.5	0.023
107433	2MK3	243.4	0.032
107433	K2	287.7	0.034
107433	M8	289.4	0.012
107433	MS4	64.2	0.002
107434	M2	301.7	0.312
107434	S2	315.5	0.061
107434	N2	265.3	0.038
107434	K1	179.2	0.107
107434	M4	29.8	0.017
107434	O1	160.3	0.051
107434	M6	67	0.012
107434	MK3	262.3	0.04
107434	S4	186.6	0.004
107434	MN4	31.4	0.013
107434	S6	23	0.007
107434	2N2	250.3	0.03
107434	OO1	172.5	0.036
107434	M1	212.4	0.003
107434	J1	49.8	0.008
107434	Q1	144.7	0.012
107434	2Q1	284.5	0.007
107434	2SM2	51.6	0.004
107434	M3	351.9	0.016
107434	L2	12.1	0.023
107434	2MK3	242.6	0.038
107434	K2	290.7	0.034
107434	M8	290.3	0.011
107434	MS4	117.6	0.002
107435	M2	303.6	0.301
107435	S2	321.1	0.059
107435	N2	266.4	0.036
107435	K1	184.6	0.111
107435	M4	27.7	0.017
107435	O1	159	0.043
107435	M6	62.1	0.012
107435	MK3	257.1	0.032
107435	S4	196.4	0.005
107435	MN4	26.1	0.013
107435	S6	24.3	0.007
107435	2N2	252.1	0.028
107435	OO1	184.5	0.034
107435	M1	220.9	0.003
107435	J1	40.1	0.008
107435	Q1	150	0.01
107435	2Q1	279.3	0.008
107435	2SM2	72.1	0.004
107435	M3	358.2	0.015
107435	L2	11.7	0.021
107435	2MK3	244.5	0.041
107435	K2	297.2	0.032
107435	M8	285.6	0.009
107435	MS4	131.8	0.005
107436	M2	304.6	0.288
107436	S2	322.7	0.053
107436	N2	266.8	0.034
107436	K1	189.4	0.114
107436	M4	28	0.017
107436	O1	152.3	0.034
107436	M6	57	0.011
107436	MK3	255.7	0.023
107436	S4	202.7	0.007
107436	MN4	23.5	0.013
107436	S6	26.3	0.006
107436	2N2	257.2	0.024
107436	OO1	205	0.034
107436	M1	233.3	0.003
107436	J1	29.5	0.005
107436	Q1	144	0.007
107436	2Q1	280.1	0.006
107436	2SM2	64.3	0.004
107436	M3	7.2	0.012
107436	L2	6.7	0.021
107436	2MK3	247.7	0.039
107436	K2	297.2	0.028
107436	M8	284.6	0.008
107436	MS4	148.2	0.007
107437	M2	304.8	0.273
107437	S2	322.4	0.049
107437	N2	266	0.032
107437	K1	193	0.113
107437	M4	31.5	0.017
107437	O1	135.2	0.025
107437	M6	38.6	0.01
107437	MK3	266.6	0.015
107437	S4	204.3	0.009
107437	MN4	22.9	0.01
107437	S6	10.7	0.005
107437	2N2	269.5	0.02
107437	OO1	226.3	0.039
107437	M1	239.7	0.003
107437	J1	37.5	0.004
107437	Q1	110.3	0.005
107437	2Q1	276.2	0.004
107437	2SM2	58	0.006
107437	M3	22.8	0.01
107437	L2	359.3	0.02
107437	2MK3	254.9	0.033
107437	K2	303.8	0.025
107437	M8	293.4	0.007
107437	MS4	158.1	0.011
107438	M2	304.2	0.258
107438	S2	322.7	0.048
107438	N2	265	0.031
107438	K1	196.1	0.113
107438	M4	39.1	0.014
107438	O1	106.8	0.023
107438	M6	17.6	0.01
107438	MK3	301.4	0.013
107438	S4	203.6	0.011
107438	MN4	28.6	0.006
107438	S6	352.8	0.005
107438	2N2	285.7	0.017
107438	OO1	243.3	0.043
107438	M1	226.9	0.004
107438	J1	62.5	0.004
107438	Q1	81.4	0.007
107438	2Q1	287.8	0.004
107438	2SM2	56.1	0.009
107438	M3	45.8	0.01
107438	L2	351.5	0.019
107438	2MK3	269.7	0.026
107438	K2	315.5	0.025
107438	M8	303.5	0.004
107438	MS4	160.9	0.015
107439	M2	302.7	0.245
107439	S2	321.5	0.047
107439	N2	266.1	0.032
107439	K1	198.5	0.112
107439	M4	61.6	0.011
107439	O1	84.4	0.029
107439	M6	358.8	0.011
107439	MK3	331.9	0.018
107439	S4	200.3	0.012
107439	MN4	100.2	0.002
107439	S6	348.7	0.005
107439	2N2	299.3	0.012
107439	OO1	259.1	0.047
107439	M1	205.8	0.005
107439	J1	101.8	0.004
107439	Q1	78.3	0.008
107439	2Q1	302.8	0.005
107439	2SM2	53.9	0.011
107439	M3	69.6	0.011
107439	L2	348	0.017
107439	2MK3	291.1	0.021
107439	K2	319.7	0.025
107439	M8	322.6	0.001
107439	MS4	163.4	0.019
107440	M2	301.3	0.232
107440	S2	319.7	0.047
107440	N2	270.1	0.033
107440	K1	199.9	0.112
107440	M4	102.1	0.012
107440	O1	78.1	0.039
107440	M6	345.3	0.011
107440	MK3	352.2	0.027
107440	S4	197	0.013
107440	MN4	165.6	0.006
107440	S6	355.3	0.003
107440	2N2	314.3	0.006
107440	OO1	270.6	0.048
107440	M1	185.8	0.007
107440	J1	122.8	0.008
107440	Q1	95.7	0.007
107440	2Q1	315.1	0.006
107440	2SM2	54.4	0.013
107440	M3	83.5	0.013
107440	L2	352	0.015
107440	2MK3	310.3	0.018
107440	K2	315.5	0.021
107440	M8	106.2	0.002
107440	MS4	166.3	0.022
107441	M2	299.6	0.224
107441	S2	315.2	0.052
107441	N2	276.8	0.034
107441	K1	199.4	0.115
107441	M4	130	0.016
107441	O1	79	0.045
107441	M6	330.9	0.012
107441	MK3	3.5	0.037
107441	S4	199.2	0.014
107441	MN4	173.1	0.01
107441	S6	44.8	0.002
107441	2N2	173.8	0.001
107441	OO1	284	0.045
107441	M1	174.1	0.008
107441	J1	133.8	0.013
107441	Q1	128.2	0.01
107441	2Q1	333	0.008
107441	2SM2	51.3	0.014
107441	M3	94.9	0.014
107441	L2	358.6	0.011
107441	2MK3	328.1	0.016
107441	K2	299.6	0.021
107441	M8	121.8	0.004
107441	MS4	170.1	0.024
107442	M2	298.4	0.221
107442	S2	315.9	0.059
107442	N2	285.9	0.036
107442	K1	197.4	0.124
107442	M4	145.7	0.021
107442	O1	87.4	0.047
107442	M6	322.4	0.015
107442	MK3	9.2	0.045
107442	S4	201.4	0.014
107442	MN4	170.4	0.012
107442	S6	66.4	0.002
107442	2N2	146.5	0.009
107442	OO1	297.6	0.046
107442	M1	175.6	0.008
107442	J1	142.7	0.019
107442	Q1	139.3	0.013
107442	2Q1	347.1	0.007
107442	2SM2	42.9	0.014
107442	M3	101.1	0.015
107442	L2	3	0.007
107442	2MK3	338.3	0.016
107442	K2	293.4	0.023
107442	M8	123.3	0.006
107442	MS4	174.1	0.025
107443	M2	298.5	0.219
107443	S2	321.2	0.064
107443	N2	296.1	0.04
107443	K1	194.6	0.138
107443	M4	155.5	0.025
107443	O1	103.8	0.048
107443	M6	321.7	0.018
107443	MK3	10.9	0.052
107443	S4	201.3	0.014
107443	MN4	162.9	0.013
107443	S6	117.8	0.002
107443	2N2	144.9	0.015
107443	OO1	303.8	0.051
107443	M1	183.6	0.008
107443	J1	143.5	0.024
107443	Q1	132.8	0.016
107443	2Q1	299.5	0.002
107443	2SM2	35	0.014
107443	M3	101	0.017
107443	L2	342.2	0.004
107443	2MK3	337.8	0.015
107443	K2	292.8	0.02
107443	M8	120.2	0.009
107443	MS4	175.3	0.026
107444	M2	301	0.22
107444	S2	327.3	0.072
107444	N2	303.8	0.044
107444	K1	192.2	0.155
107444	M4	163.1	0.033
107444	O1	122.1	0.054
107444	M6	320.6	0.02
107444	MK3	12.8	0.06
107444	S4	200	0.013
107444	MN4	154.4	0.016
107444	S6	152.3	0.002
107444	2N2	135.8	0.018
107444	OO1	303.2	0.055
107444	M1	187.3	0.009
107444	J1	142.7	0.03
107444	Q1	122.1	0.017
107444	2Q1	202.6	0.008
107444	2SM2	34.3	0.014
107444	M3	97.8	0.019
107444	L2	273.9	0.004
107444	2MK3	325.6	0.015
107444	K2	308.1	0.017
107444	M8	115.8	0.011
107444	MS4	175.8	0.026
107445	M2	306.6	0.224
107445	S2	333.5	0.084
107445	N2	307.5	0.048
107445	K1	190.4	0.172
107445	M4	166	0.044
107445	O1	133.1	0.065
107445	M6	315.5	0.021
107445	MK3	18.9	0.072
107445	S4	191.9	0.013
107445	MN4	150	0.022
107445	S6	170.1	0.003
107445	2N2	115	0.02
107445	OO1	303.1	0.061
107445	M1	178.9	0.01
107445	J1	142.2	0.036
107445	Q1	110.7	0.019
107445	2Q1	199.6	0.018
107445	2SM2	35.1	0.012
107445	M3	97.3	0.019
107445	L2	241.7	0.005
107445	2MK3	317	0.017
107445	K2	343.5	0.02
107445	M8	114.6	0.013
107445	MS4	176.6	0.025
107446	M2	314.5	0.239
107446	S2	338.2	0.098
107446	N2	308.9	0.052
107446	K1	188.9	0.189
107446	M4	169.8	0.061
107446	O1	138.9	0.072
107446	M6	309.2	0.021
107446	MK3	27.7	0.09
107446	S4	183.1	0.014
107446	MN4	150.5	0.03
107446	S6	181.3	0.003
107446	2N2	91.1	0.025
107446	OO1	302.7	0.068
107446	M1	173	0.012
107446	J1	141.5	0.041
107446	Q1	107.2	0.023
107446	2Q1	202.3	0.026
107446	2SM2	39.3	0.01
107446	M3	105.6	0.022
107446	L2	207.5	0.006
107446	2MK3	322.6	0.018
107446	K2	4.3	0.032
107446	M8	112.7	0.017
107446	MS4	178.1	0.025
107447	M2	323.1	0.274
107447	S2	342.8	0.108
107447	N2	308.5	0.061
107447	K1	189	0.209
107447	M4	175.3	0.084
107447	O1	142.3	0.073
107447	M6	304.9	0.021
107447	MK3	38.1	0.122
107447	S4	176.7	0.016
107447	MN4	151.7	0.04
107447	S6	212.2	0.003
107447	2N2	74.1	0.032
107447	OO1	298.9	0.074
107447	M1	174.7	0.011
107447	J1	139.5	0.041
107447	Q1	107.3	0.027
107447	2Q1	204.2	0.032
107447	2SM2	67	0.007
107447	M3	119.9	0.029
107447	L2	162.1	0.009
107447	2MK3	345.7	0.022
107447	K2	13.5	0.048
107447	M8	108	0.019
107447	MS4	177.8	0.028
107448	M2	304.2	1.043
107448	S2	334.2	0.264
107448	N2	279.2	0.162
107448	K1	202.9	0.342
107448	M4	157.7	0.082
107448	O1	193.3	0.18
107448	M6	50.7	0.044
107448	MK3	15.4	0.086
107448	S4	210.3	0.017
107448	MN4	135.5	0.022
107448	S6	47.6	0.004
107448	2N2	268	0.043
107448	OO1	188.5	0.035
107448	M1	249.8	0.011
107448	J1	282	0.018
107448	Q1	168.5	0.025
107448	2Q1	311.7	0.015
107448	P1	201.4	0.091
107448	2SM2	128.8	0.004
107448	M3	114.6	0.015
107448	L2	347.3	0.025
107448	2MK3	214.8	0.01
107448	K2	325.6	0.1
107448	M8	249.6	0.016
107448	MS4	192	0.046
107449	M2	312.4	1.277
107449	S2	339.9	0.284
107449	N2	287	0.196
107449	K1	207.7	0.408
107449	M4	173.2	0.09
107449	O1	199.6	0.203
107449	M6	80.9	0.054
107449	MK3	33.6	0.105
107449	S4	223.8	0.008
107449	MN4	158	0.03
107449	S6	108.9	0.003
107449	2N2	284.7	0.041
107449	OO1	182.3	0.034
107449	M1	231.4	0.016
107449	J1	257.5	0.034
107449	Q1	183	0.029
107449	2Q1	234.2	0.013
107449	P1	206.9	0.134
107449	2SM2	155.1	0.003
107449	M3	121.3	0.02
107449	L2	0.3	0.05
107449	2MK3	331.9	0.035
107449	K2	323.1	0.094
107449	M8	285	0.005
107449	MS4	209.4	0.051
107450	M2	315.4	1.239
107450	S2	353.4	0.262
107450	N2	287.5	0.178
107450	K1	196.8	0.46
107450	M4	211.9	0.055
107450	O1	194.2	0.21
107450	M6	100.2	0.062
107450	MK3	37.4	0.043
107450	S4	115.1	0.005
107450	MN4	170.1	0.016
107450	S6	32	0.007
107450	2N2	276.1	0.071
107450	OO1	206.8	0.063
107450	M1	199.6	0.027
107450	J1	296.5	0.045
107450	Q1	195.4	0.035
107450	2Q1	104.1	0.015
107450	P1	250	0.106
107450	2SM2	193.5	0.013
107450	M3	42.9	0.017
107450	L2	337.8	0.064
107450	2MK3	283.8	0.069
107450	K2	0.7	0.11
107450	M8	14.3	0.015
107450	MS4	235.8	0.024
107451	M2	278.8	1.391
107451	S2	316.9	0.313
107451	N2	261.4	0.194
107451	K1	190.1	0.34
107451	M4	125.9	0.088
107451	O1	182.8	0.131
107451	M6	21.1	0.142
107451	MK3	306	0.095
107451	S4	189.1	0.017
107451	MN4	92	0.032
107451	S6	109.5	0.008
107451	2N2	202.9	0.081
107451	OO1	180.8	0.037
107451	M1	215.4	0.012
107451	J1	254.7	0.028
107451	Q1	171	0.024
107451	2Q1	315.6	0.011
107451	P1	185.8	0.107
107451	2SM2	242.5	0.006
107451	M3	338.7	0.024
107451	L2	294.8	0.061
107451	2MK3	198.4	0.123
107451	K2	290	0.099
107451	M8	231.9	0.018
107451	MS4	136.4	0.074
107452	M2	281.1	1.79
107452	S2	318.1	0.398
107452	N2	263.9	0.243
107452	K1	190.1	0.43
107452	M4	129.5	0.083
107452	O1	188.3	0.174
107452	M6	19.8	0.182
107452	MK3	305.2	0.126
107452	S4	184.3	0.021
107452	MN4	95.7	0.036
107452	S6	109.9	0.004
107452	2N2	207.5	0.107
107452	OO1	181.5	0.056
107452	M1	223.4	0.017
107452	J1	262	0.039
107452	Q1	173.1	0.031
107452	2Q1	300.9	0.019
107452	P1	191.1	0.143
107452	2SM2	277.3	0.004
107452	M3	349.3	0.032
107452	L2	298.5	0.081
107452	2MK3	201.1	0.155
107452	K2	294.7	0.129
107452	M8	254	0.006
107452	MS4	136.8	0.092
107453	M2	282.6	1.809
107453	S2	317.2	0.398
107453	N2	262.6	0.249
107453	K1	191.8	0.442
107453	M4	127.2	0.051
107453	O1	185.6	0.174
107453	M6	20.6	0.176
107453	MK3	298.9	0.135
107453	S4	187.6	0.02
107453	MN4	105.8	0.034
107453	S6	107.4	0.005
107453	2N2	214.1	0.102
107453	OO1	186.8	0.06
107453	M1	221.9	0.019
107453	J1	258.6	0.033
107453	Q1	170.4	0.034
107453	2Q1	299.3	0.016
107453	P1	192.1	0.137
107453	2SM2	315.6	0.004
107453	M3	350	0.031
107453	L2	309	0.082
107453	2MK3	202.1	0.148
107453	K2	293.7	0.139
107453	M8	10.2	0.011
107453	MS4	135.5	0.082
107454	M2	271.6	0.861
107454	S2	299.5	0.165
107454	N2	254.4	0.104
107454	K1	173.1	0.144
107454	M4	340.1	0.008
107454	O1	238.6	0.035
107454	M6	3	0.086
107454	MK3	296.7	0.024
107454	S4	164.7	0.006
107454	MN4	291.8	0.002
107454	S6	93.7	0.002
107454	2N2	220.2	0.052
107454	OO1	193.1	0.025
107454	M1	234.5	0.002
107454	J1	256.1	0.016
107454	Q1	205.7	0.006
107454	2Q1	254.5	0.007
107454	P1	186.2	0.046
107454	2SM2	114.8	0.006
107454	M3	329.3	0.01
107454	L2	298.3	0.053
107454	2MK3	203.1	0.057
107454	K2	278.9	0.064
107454	M8	57.8	0.007
107454	MS4	92	0.002
107455	M2	268.4	1.035
107455	S2	301.2	0.202
107455	N2	250.9	0.14
107455	K1	172.2	0.174
107455	M4	337.3	0.054
107455	O1	264.8	0.061
107455	M6	354.1	0.093
107455	MK3	280.8	0.05
107455	S4	186.7	0.01
107455	MN4	322.4	0.012
107455	S6	115.3	0.006
107455	2N2	211.5	0.063
107455	OO1	173	0.037
107455	M1	255.1	0.006
107455	J1	264	0.019
107455	Q1	269.1	0.011
107455	2Q1	282.9	0.008
107455	P1	181.8	0.062
107455	2SM2	106.8	0.01
107455	M3	334.1	0.015
107455	L2	284.1	0.064
107455	2MK3	188.2	0.071
107455	K2	276	0.061
107455	M8	45.8	0.017
107455	MS4	40.5	0.021
107456	M2	274.3	0.324
107456	S2	310.8	0.074
107456	N2	248.2	0.051
107456	K1	151.2	0.086
107456	M4	141.8	0.028
107456	O1	98.3	0.045
107456	M6	73.8	0.01
107456	MK3	303.7	0.017
107456	S4	199.7	0.004
107456	MN4	51.4	0.007
107456	S6	194.2	0.004
107456	2N2	216.1	0.019
107456	OO1	193.4	0.023
107456	M1	148	0.005
107456	J1	230.2	0.006
107456	Q1	178.5	0.01
107456	2Q1	55.3	0.006
107456	P1	208.7	0.031
107456	2SM2	87.6	0.002
107456	M3	297.5	0.01
107456	L2	272.7	0.012
107456	2MK3	182.4	0.025
107456	K2	297	0.032
107456	M8	293.6	0.004
107456	MS4	148.6	0.02
107457	M2	277.2	0.371
107457	S2	315.3	0.083
107457	N2	260.5	0.059
107457	K1	173.8	0.059
107457	M4	144.9	0.027
107457	O1	191.3	0.005
107457	M6	20	0.042
107457	MK3	260.1	0.04
107457	S4	155.5	0.004
107457	MN4	133.4	0.008
107457	S6	71.7	0.002
107457	2N2	198.2	0.025
107457	OO1	146.5	0.014
107457	M1	241.7	0.006
107457	J1	259.6	0.019
107457	Q1	161.2	0.014
107457	2Q1	285.6	0.001
107457	P1	183.8	0.03
107457	2SM2	214.1	0.001
107457	M3	320.7	0.011
107457	L2	280.1	0.017
107457	2MK3	200.3	0.044
107457	K2	292.4	0.042
107457	M8	272	0.007
107457	MS4	158.5	0.011
107458	M2	272.4	0.366
107458	S2	309.3	0.094
107458	N2	255.2	0.048
107458	K1	180.4	0.05
107458	M4	258.9	0.061
107458	O1	294.2	0.012
107458	M6	342	0.045
107458	MK3	235.2	0.04
107458	S4	204.8	0.005
107458	MN4	214	0.015
107458	S6	83.6	0.005
107458	2N2	185.4	0.022
107458	OO1	66.7	0.011
107458	M1	254.9	0.013
107458	J1	282.3	0.023
107458	Q1	42.3	0.014
107458	2Q1	236.2	0.011
107458	P1	158.9	0.021
107458	2SM2	207.1	0.006
107458	M3	302.7	0.014
107458	L2	335.5	0.013
107458	2MK3	201.3	0.043
107458	K2	303.5	0.05
107458	M8	321.6	0.01
107458	MS4	329	0.013
107459	M2	302.9	0.488
107459	S2	349.7	0.084
107459	N2	278.1	0.075
107459	K1	183.4	0.135
107459	M4	291	0.025
107459	O1	181.2	0.079
107459	M6	79.6	0.029
107459	MK3	223.4	0.008
107459	S4	138.7	0.016
107459	MN4	210.1	0.004
107459	S6	181.8	0.006
107459	2N2	254	0.032
107459	OO1	197.2	0.04
107459	M1	219.9	0.007
107459	J1	295.9	0.002
107459	Q1	194.4	0.012
107459	2Q1	186.4	0.006
107459	P1	199.6	0.047
107459	2SM2	326.1	0.004
107459	M3	351.4	0.007
107459	L2	325.3	0.013
107459	2MK3	203.3	0.027
107459	K2	352	0.026
107459	M8	68.7	0.006
107459	MS4	318.1	0.012
107460	M2	308.3	0.347
107460	S2	346.5	0.096
107460	N2	288.7	0.061
107460	K1	210.8	0.126
107460	M4	285.8	0.054
107460	O1	168.4	0.036
107460	M6	56.7	0.011
107460	MK3	150.7	0.034
107460	S4	255.9	0.011
107460	MN4	261.2	0.023
107460	S6	53.1	0.002
107460	2N2	15.3	0.014
107460	OO1	213.4	0.011
107460	M1	251.6	0.011
107460	J1	339.2	0.006
107460	Q1	107.9	0.004
107460	2Q1	346.1	0.006
107460	P1	235.8	0.034
107460	2SM2	166.5	0.006
107460	M3	234.3	0.011
107460	L2	355.7	0.006
107460	2MK3	150.3	0.021
107460	K2	351.7	0.014
107460	M8	253.6	0.008
107460	MS4	312.5	0.018
107461	M2	309.4	0.332
107461	S2	339.7	0.087
107461	N2	284.9	0.053
107461	K1	227.8	0.157
107461	M4	259.2	0.036
107461	O1	156.9	0.066
107461	M6	28.9	0.017
107461	MK3	140.9	0.017
107461	S4	183.2	0.007
107461	MN4	248.1	0.019
107461	S6	11.4	0.004
107461	2N2	0.2	0.018
107461	OO1	241.8	0.004
107461	M1	195.9	0.002
107461	J1	90.4	0.006
107461	Q1	89.6	0.025
107461	2Q1	314.4	0.006
107461	P1	211.7	0.042
107461	2SM2	3.8	0.005
107461	M3	202.2	0.008
107461	L2	355	0.013
107461	2MK3	125.3	0.023
107461	K2	341.4	0.035
107461	M8	246.2	0.005
107461	MS4	6.3	0.023
107462	M2	301.4	1.718
107462	S2	332.6	0.384
107462	N2	277.5	0.323
107462	K1	203.2	0.494
107462	M4	145.3	0.093
107462	O1	192.6	0.249
107462	M6	73.5	0.124
107462	MK3	342	0.063
107462	S4	187.1	0.016
107462	MN4	153.4	0.022
107462	NU2	296.6	0.066
107462	S6	121	0.002
107462	MU2	115.8	0.023
107462	2N2	250.9	0.034
107462	OO1	258.8	0.077
107462	LDA2	311.3	0.054
107462	M1	225.2	0.013
107462	J1	247.4	0.027
107462	RHO1	140.7	0.011
107462	Q1	180.9	0.037
107462	2Q1	278.6	0.015
107462	P1	198.2	0.138
107462	2SM2	196.9	0.016
107462	M3	117.7	0.007
107462	L2	334.9	0.116
107462	2MK3	213.8	0.043
107462	K2	314.5	0.15
107462	M8	239.1	0.027
107462	MS4	168.7	0.028
107463	M2	303.1	1.8
107463	S2	333.8	0.39
107463	N2	277.5	0.329
107463	K1	202.9	0.507
107463	M4	182.7	0.056
107463	O1	196.1	0.272
107463	M6	73.9	0.129
107463	MK3	359.5	0.079
107463	S4	217.3	0.015
107463	MN4	171.1	0.019
107463	NU2	299.1	0.072
107463	S6	114.4	0.003
107463	MU2	125.4	0.045
107463	2N2	258.2	0.031
107463	OO1	252	0.058
107463	LDA2	316.8	0.051
107463	M1	237.9	0.014
107463	J1	240.7	0.026
107463	RHO1	143.7	0.012
107463	Q1	179.2	0.036
107463	2Q1	235.2	0.016
107463	P1	196.5	0.147
107463	2SM2	206.2	0.01
107463	M3	82.5	0.014
107463	L2	340.1	0.123
107463	2MK3	234.3	0.037
107463	K2	319	0.14
107463	M8	202.7	0.011
107463	MS4	191.8	0.033
107464	M2	304.7	1.742
107464	S2	336.3	0.38
107464	N2	280.5	0.321
107464	K1	204.2	0.508
107464	M4	205.3	0.052
107464	O1	196.4	0.268
107464	M6	68.6	0.106
107464	MK3	348.6	0.06
107464	S4	215.3	0.009
107464	MN4	204.5	0.012
107464	NU2	298.1	0.066
107464	S6	127.4	0.005
107464	MU2	119.5	0.038
107464	2N2	261.6	0.032
107464	OO1	258.7	0.06
107464	LDA2	315.7	0.045
107464	M1	245.5	0.018
107464	J1	231.6	0.026
107464	RHO1	166.3	0.015
107464	Q1	179.4	0.037
107464	2Q1	249.7	0.008
107464	P1	195	0.148
107464	2SM2	197.1	0.007
107464	M3	82.1	0.005
107464	L2	339.2	0.119
107464	2MK3	217.4	0.039
107464	K2	317.9	0.136
107464	M8	230.9	0.012
107464	MS4	196.2	0.025
107465	M2	318.1	0.251
107465	S2	3	0.087
107465	N2	303.9	0.047
107465	K1	189.3	0.142
107465	M4	34	0.043
107465	O1	148.6	0.161
107465	M6	13.3	0.032
107465	MK3	216.1	0.053
107465	S4	57.9	0.004
107465	MN4	17.7	0.014
107465	S6	233	0.003
107465	2N2	251.7	0.022
107465	OO1	209.8	0.016
107465	M1	181.1	0.012
107465	J1	238.9	0.027
107465	Q1	173.2	0.026
107465	2Q1	176.8	0.019
107465	P1	247.5	0.047
107465	2SM2	131.6	0.005
107465	M3	294.3	0.011
107465	L2	111.2	0.006
107465	2MK3	156.3	0.035
107465	K2	320.5	0.04
107465	M8	293	0.006
107465	MS4	108.8	0.018
107466	M2	326.7	0.309
107466	S2	356.6	0.088
107466	N2	303	0.053
107466	K1	213.9	0.175
107466	M4	82.3	0.022
107466	O1	183.2	0.151
107466	M6	29.6	0.021
107466	MK3	199.6	0.023
107466	S4	344.4	0.003
107466	MN4	5.9	0.008
107466	S6	296.8	0.004
107466	2N2	357.8	0.006
107466	OO1	126.3	0.005
107466	M1	236.4	0.012
107466	J1	244.6	0.013
107466	Q1	145.1	0.016
107466	2Q1	137.9	0.011
107466	P1	216.3	0.048
107466	2SM2	204	0.003
107466	M3	284.6	0.008
107466	L2	67.7	0.009
107466	2MK3	145.3	0.019
107466	K2	296.1	0.026
107466	M8	296.8	0.008
107466	MS4	96.7	0.018
107467	M2	326.8	0.337
107467	S2	355.4	0.081
107467	N2	302	0.06
107467	K1	211.4	0.197
107467	M4	172.4	0.019
107467	O1	184.4	0.136
107467	M6	68.8	0.019
107467	MK3	277.7	0.025
107467	S4	252.1	0.004
107467	MN4	318.8	0.003
107467	S6	257.6	0.001
107467	2N2	309.9	0.009
107467	OO1	257.5	0.007
107467	M1	253.9	0.012
107467	J1	247	0.008
107467	Q1	110.2	0.019
107467	2Q1	130.7	0.014
107467	P1	203.3	0.062
107467	2SM2	323.9	0.006
107467	M3	312.2	0.01
107467	L2	262.4	0.004
107467	2MK3	198	0.033
107467	K2	319.9	0.031
107467	M8	359.1	0.006
107467	MS4	126.3	0.006
107468	M2	276.5	0.295
107468	S2	316.4	0.05
107468	N2	260.8	0.029
107468	K1	174	0.042
107468	M4	131.2	0.023
107468	O1	165.9	0.029
107468	M6	30.4	0.023
107468	MK3	289.6	0.025
107468	S4	181.1	0.007
107468	MN4	79.1	0.005
107468	S6	76.6	0.003
107468	2N2	203.4	0.018
107468	OO1	139.2	0.016
107468	M1	130.6	0.002
107468	J1	238.4	0.013
107468	Q1	153.1	0.012
107468	2Q1	78	0.005
107468	P1	202.5	0.024
107468	2SM2	158.9	0.003
107468	M3	340.3	0.003
107468	L2	296.7	0.027
107468	2MK3	221.4	0.02
107468	K2	255.8	0.022
107468	M8	86.8	0.006
107468	MS4	131.5	0.012
107469	M2	280.7	0.333
107469	S2	316.1	0.06
107469	N2	258.4	0.036
107469	K1	175.2	0.049
107469	M4	132.3	0.027
107469	O1	173.3	0.033
107469	M6	32.7	0.028
107469	MK3	302.9	0.022
107469	S4	182	0.006
107469	MN4	88.7	0.006
107469	S6	76.1	0.003
107469	2N2	218.2	0.019
107469	OO1	139.4	0.019
107469	M1	167.8	0.002
107469	J1	248.5	0.013
107469	Q1	149.8	0.012
107469	2Q1	84.4	0.005
107469	P1	201.1	0.024
107469	2SM2	143.2	0.004
107469	M3	43.1	0.004
107469	L2	307	0.027
107469	2MK3	238.7	0.019
107469	K2	267.3	0.022
107469	M8	99.6	0.005
107469	MS4	145.2	0.014
107470	M2	284.3	0.363
107470	S2	316.9	0.069
107470	N2	258	0.042
107470	K1	177.2	0.057
107470	M4	136	0.03
107470	O1	179.9	0.038
107470	M6	38.4	0.031
107470	MK3	320.3	0.022
107470	S4	181.4	0.006
107470	MN4	96.7	0.007
107470	S6	81.7	0.003
107470	2N2	229.8	0.02
107470	OO1	138	0.019
107470	M1	202.7	0.002
107470	J1	258.5	0.013
107470	Q1	149.9	0.012
107470	2Q1	100.7	0.005
107470	P1	199.5	0.024
107470	2SM2	130.1	0.004
107470	M3	75.7	0.006
107470	L2	315.7	0.025
107470	2MK3	255.5	0.018
107470	K2	280.4	0.022
107470	M8	115.9	0.005
107470	MS4	158.3	0.016
107471	M2	287.4	0.388
107471	S2	318.5	0.074
107471	N2	258.2	0.048
107471	K1	181.1	0.064
107471	M4	142.2	0.034
107471	O1	184.8	0.043
107471	M6	45.7	0.033
107471	MK3	340.1	0.023
107471	S4	190.1	0.008
107471	MN4	100	0.008
107471	S6	102.6	0.003
107471	2N2	240.5	0.02
107471	OO1	133.5	0.018
107471	M1	227.9	0.002
107471	J1	261.1	0.012
107471	Q1	151.7	0.013
107471	2Q1	114.2	0.005
107471	P1	197.3	0.024
107471	2SM2	126.5	0.004
107471	M3	91.1	0.007
107471	L2	322.3	0.023
107471	2MK3	272.2	0.016
107471	K2	285.7	0.021
107471	M8	133.4	0.003
107471	MS4	170.7	0.018
107472	M2	290.3	0.405
107472	S2	320.7	0.079
107472	N2	260	0.055
107472	K1	185.6	0.069
107472	M4	152.6	0.037
107472	O1	188.6	0.047
107472	M6	54.4	0.035
107472	MK3	359.5	0.024
107472	S4	198.8	0.008
107472	MN4	115.4	0.009
107472	S6	127.1	0.003
107472	2N2	250.6	0.019
107472	OO1	136.9	0.015
107472	M1	238.9	0.002
107472	J1	260.1	0.009
107472	Q1	158.6	0.011
107472	2Q1	128.5	0.005
107472	P1	195	0.022
107472	2SM2	121.9	0.004
107472	M3	102.7	0.008
107472	L2	325.6	0.02
107472	2MK3	282.9	0.014
107472	K2	286.6	0.019
107472	M8	195.1	0.002
107472	MS4	184.7	0.02
107473	M2	292.8	0.414
107473	S2	323.2	0.082
107473	N2	261.5	0.059
107473	K1	189.8	0.071
107473	M4	165	0.037
107473	O1	191.6	0.047
107473	M6	63.7	0.037
107473	MK3	18.3	0.027
107473	S4	204.2	0.007
107473	MN4	128.1	0.009
107473	S6	143.6	0.003
107473	2N2	260.6	0.019
107473	OO1	151.9	0.012
107473	M1	252.6	0.002
107473	J1	252.6	0.006
107473	Q1	168.9	0.009
107473	2Q1	132.8	0.005
107473	P1	191.1	0.023
107473	2SM2	117.3	0.004
107473	M3	112.6	0.008
107473	L2	331.5	0.018
107473	2MK3	291.8	0.012
107473	K2	286.9	0.019
107473	M8	267.5	0.003
107473	MS4	193.7	0.022
107474	M2	295.2	0.417
107474	S2	325.2	0.084
107474	N2	263.2	0.062
107474	K1	193.3	0.074
107474	M4	178.3	0.037
107474	O1	195.1	0.047
107474	M6	71.1	0.037
107474	MK3	32.2	0.033
107474	S4	216.1	0.005
107474	MN4	140.5	0.009
107474	S6	164.1	0.002
107474	2N2	270.1	0.019
107474	OO1	170.8	0.011
107474	M1	265	0.002
107474	J1	236.3	0.005
107474	Q1	186.6	0.008
107474	2Q1	119.6	0.005
107474	P1	190.2	0.024
107474	2SM2	122.6	0.004
107474	M3	119.5	0.007
107474	L2	336.8	0.017
107474	2MK3	302.2	0.009
107474	K2	285.7	0.018
107474	M8	296.5	0.003
107474	MS4	200.7	0.023
107475	M2	297.6	0.418
107475	S2	325.1	0.084
107475	N2	266	0.062
107475	K1	195.9	0.079
107475	M4	191.3	0.039
107475	O1	201	0.047
107475	M6	76.9	0.035
107475	MK3	43.7	0.041
107475	S4	222.2	0.004
107475	MN4	158.7	0.01
107475	S6	173.1	0.002
107475	2N2	277.9	0.018
107475	OO1	188.1	0.012
107475	M1	300.4	0.002
107475	J1	228.8	0.003
107475	Q1	207.7	0.007
107475	2Q1	127.7	0.005
107475	P1	195.1	0.025
107475	2SM2	140.9	0.004
107475	M3	126.3	0.007
107475	L2	342.6	0.015
107475	2MK3	319.7	0.009
107475	K2	275.9	0.019
107475	M8	330.5	0.003
107475	MS4	211.8	0.022
107476	M2	300	0.418
107476	S2	324.9	0.087
107476	N2	267.3	0.063
107476	K1	200.2	0.086
107476	M4	203.8	0.042
107476	O1	206.1	0.05
107476	M6	80.5	0.033
107476	MK3	50.2	0.047
107476	S4	215	0.005
107476	MN4	174.5	0.011
107476	S6	153.7	0.002
107476	2N2	289.5	0.019
107476	OO1	214.2	0.014
107476	M1	322.1	0.003
107476	Q1	219.5	0.007
107476	2Q1	155.1	0.006
107476	P1	195.5	0.025
107476	2SM2	175.2	0.004
107476	M3	123.1	0.008
107476	L2	348.1	0.014
107476	2MK3	337.8	0.012
107476	K2	285.5	0.019
107476	M8	21.2	0.004
107476	MS4	222.9	0.019
107477	M2	298.6	0.41
107477	S2	315.9	0.084
107477	N2	259.6	0.058
107477	K1	193.1	0.098
107477	M4	209.5	0.025
107477	O1	173.4	0.046
107477	M6	91.7	0.017
107477	MK3	25	0.05
107477	S4	325.2	0.001
107477	MN4	244.7	0.004
107477	S6	185.7	0.003
107477	2N2	315.4	0.03
107477	OO1	265.5	0.032
107477	M1	24	0.006
107477	J1	133.6	0.007
107477	Q1	64.2	0.002
107477	2Q1	199.3	0.012
107477	P1	177.6	0.025
107477	2SM2	186.8	0.008
107477	M3	39.5	0.01
107477	L2	32.4	0.01
107477	2MK3	308.8	0.032
107477	K2	322.8	0.015
107477	M8	77	0.01
107477	MS4	315.9	0.005
107478	M2	275.9	0.371
107478	S2	294.3	0.071
107478	N2	229.2	0.048
107478	K1	131.3	0.066
107478	M4	4.1	0.088
107478	O1	112.4	0.027
107478	M6	79.5	0.056
107478	MK3	243	0.054
107478	S4	311.2	0.008
107478	MN4	319.7	0.028
107478	S6	83	0.003
107478	2N2	262	0.018
107478	OO1	119.5	0.003
107478	M1	87.3	0.004
107478	J1	92.8	0.007
107478	Q1	110.4	0.01
107478	2Q1	308.2	0.005
107478	P1	305.5	0.012
107478	2SM2	180.9	0.011
107478	M3	314.1	0.008
107478	L2	351.2	0.019
107478	2MK3	253.3	0.029
107478	K2	245.7	0.033
107478	M8	150.5	0.021
107478	MS4	57.5	0.023
107479	M2	277.5	0.406
107479	S2	291.7	0.078
107479	N2	231.2	0.054
107479	K1	131.8	0.075
107479	M4	0.6	0.092
107479	O1	123.7	0.037
107479	M6	78.5	0.062
107479	MK3	240.7	0.058
107479	S4	321.2	0.006
107479	MN4	318.7	0.028
107479	S6	82.6	0.004
107479	2N2	266.2	0.021
107479	OO1	139.3	0.007
107479	M1	114.2	0.004
107479	J1	71.8	0.003
107479	Q1	119.6	0.009
107479	2Q1	357.7	0.003
107479	P1	305.6	0.013
107479	2SM2	182.6	0.01
107479	M3	321.8	0.007
107479	L2	348.8	0.022
107479	2MK3	255.6	0.03
107479	K2	245.4	0.042
107479	M8	146.1	0.023
107479	MS4	52.8	0.021
107480	M2	278.9	0.426
107480	S2	292.2	0.084
107480	N2	233.5	0.058
107480	K1	129.8	0.083
107480	M4	358.1	0.091
107480	O1	136	0.046
107480	M6	78.6	0.065
107480	MK3	239.7	0.057
107480	S4	329.1	0.004
107480	MN4	315.3	0.026
107480	S6	76.7	0.004
107480	2N2	267.9	0.025
107480	OO1	133.3	0.013
107480	M1	140.6	0.005
107480	J1	305.9	0.004
107480	Q1	128	0.008
107480	2Q1	64.2	0.004
107480	P1	298.8	0.013
107480	2SM2	185.9	0.008
107480	M3	324.5	0.006
107480	L2	346.9	0.023
107480	2MK3	257.1	0.033
107480	K2	246.2	0.048
107480	M8	141.2	0.025
107480	MS4	47	0.018
107481	M2	280.1	0.44
107481	S2	295.8	0.089
107481	N2	235.2	0.064
107481	K1	125.6	0.092
107481	M4	356.3	0.089
107481	O1	145.5	0.054
107481	M6	78.9	0.066
107481	MK3	240.7	0.055
107481	S4	320.9	0.002
107481	MN4	313.8	0.023
107481	S6	64.4	0.005
107481	2N2	268.9	0.03
107481	OO1	122.6	0.021
107481	M1	157.1	0.007
107481	J1	292.4	0.01
107481	Q1	121.9	0.006
107481	2Q1	88.3	0.008
107481	P1	280.2	0.014
107481	2SM2	188	0.006
107481	M3	340.9	0.005
107481	L2	340.8	0.025
107481	2MK3	260	0.04
107481	K2	250.9	0.047
107481	M8	135	0.027
107481	MS4	44.9	0.015
107482	M2	279.7	0.454
107482	S2	298.9	0.102
107482	N2	232.4	0.073
107482	K1	114.8	0.109
107482	M4	359.8	0.089
107482	O1	143	0.071
107482	M6	80.6	0.061
107482	MK3	257.2	0.056
107482	S4	123.6	0.004
107482	MN4	335.9	0.02
107482	S6	34.1	0.005
107482	2N2	278.9	0.039
107482	OO1	91.1	0.021
107482	M1	164	0.01
107482	J1	269.5	0.009
107482	Q1	83.3	0.016
107482	2Q1	135.4	0.012
107482	P1	225.2	0.024
107482	2SM2	209.2	0.008
107482	M3	25.6	0.012
107482	L2	337.3	0.025
107482	2MK3	268.2	0.058
107482	K2	272.6	0.04
107482	M8	124.7	0.028
107482	MS4	65	0.02
107483	M2	279.6	0.455
107483	S2	303.9	0.103
107483	N2	230.9	0.073
107483	K1	115.2	0.127
107483	M4	354	0.09
107483	O1	137.3	0.076
107483	M6	84.5	0.07
107483	MK3	261.9	0.063
107483	S4	266.2	0.004
107483	MN4	335.7	0.02
107483	S6	42.4	0.004
107483	2N2	268.7	0.046
107483	OO1	106.6	0.041
107483	M1	145.2	0.009
107483	J1	255.7	0.014
107483	Q1	69	0.015
107483	2Q1	109.9	0.022
107483	P1	222.4	0.031
107483	2SM2	186.3	0.007
107483	M3	15.8	0.019
107483	L2	338.5	0.019
107483	2MK3	259.4	0.068
107483	K2	281.8	0.036
107483	M8	121.2	0.026
107483	MS4	51	0.012
107484	M2	298.8	1.197
107484	S2	333.8	0.225
107484	N2	281.3	0.151
107484	K1	198.5	0.308
107484	M4	196.5	0.091
107484	O1	187.7	0.179
107484	M6	50	0.103
107484	MK3	24.4	0.031
107484	S4	222.5	0.014
107484	MN4	168	0.026
107484	S6	53.4	0.004
107484	2N2	242.6	0.073
107484	OO1	179.8	0.044
107484	M1	241.7	0.012
107484	J1	284.3	0.03
107484	Q1	181.7	0.024
107484	2Q1	50.3	0.012
107484	P1	213	0.089
107484	2SM2	186.2	0.004
107484	M3	344.1	0.008
107484	L2	317.7	0.062
107484	2MK3	220.7	0.088
107484	K2	305.1	0.072
107484	M8	254.5	0.011
107484	MS4	188.1	0.056
107485	M2	297.8	1.319
107485	S2	331.3	0.246
107485	N2	279.8	0.165
107485	K1	196.8	0.337
107485	M4	203.2	0.11
107485	O1	181.5	0.193
107485	M6	57	0.127
107485	MK3	29.2	0.026
107485	S4	222.7	0.017
107485	MN4	171.7	0.032
107485	S6	54.6	0.005
107485	2N2	238.9	0.082
107485	OO1	174.6	0.047
107485	M1	234.8	0.013
107485	J1	283.1	0.03
107485	Q1	182.2	0.023
107485	2Q1	40.7	0.015
107485	P1	208.2	0.086
107485	2SM2	184.7	0.004
107485	M3	353.3	0.008
107485	L2	315.4	0.07
107485	2MK3	219.7	0.095
107485	K2	299.9	0.082
107485	M8	302	0.014
107485	MS4	187.1	0.065
107486	M2	296.2	1.31
107486	S2	329.3	0.237
107486	N2	277.6	0.165
107486	K1	193.7	0.337
107486	M4	229.9	0.084
107486	O1	175.5	0.164
107486	M6	77.5	0.103
107486	MK3	275.4	0.046
107486	S4	259.1	0.012
107486	MN4	191.9	0.022
107486	S6	26.7	0.006
107486	2N2	240.8	0.104
107486	OO1	163.8	0.066
107486	M1	236.2	0.019
107486	J1	301.9	0.02
107486	Q1	163.8	0.021
107486	2Q1	81.9	0.023
107486	P1	202.4	0.073
107486	2SM2	133.8	0.007
107486	M3	318.4	0.019
107486	L2	323	0.078
107486	2MK3	220.5	0.141
107486	K2	295.1	0.1
107486	M8	28.1	0.021
107486	MS4	214.5	0.023
107487	M2	306.7	1.079
107487	S2	334.4	0.246
107487	N2	282.1	0.16
107487	K1	198.6	0.299
107487	M4	225.9	0.141
107487	O1	167.6	0.149
107487	M6	118.1	0.065
107487	MK3	83.8	0.067
107487	S4	209.2	0.008
107487	MN4	203.9	0.044
107487	S6	206.7	0.003
107487	2N2	261.7	0.052
107487	OO1	182.6	0.052
107487	M1	218.9	0.01
107487	J1	275.9	0.026
107487	Q1	181.1	0.016
107487	2Q1	70.6	0.008
107487	P1	202.8	0.096
107487	2SM2	217.8	0.007
107487	M3	151	0.014
107487	L2	346.5	0.036
107487	2MK3	242.3	0.022
107487	K2	310.2	0.101
107487	M8	61.1	0.009
107487	MS4	254.6	0.043
107488	M2	305.8	1.099
107488	S2	336.2	0.236
107488	N2	284.7	0.161
107488	K1	196.5	0.314
107488	M4	236.5	0.136
107488	O1	162.6	0.164
107488	M6	98.9	0.054
107488	MK3	108.9	0.057
107488	S4	212	0.016
107488	MN4	212.9	0.043
107488	S6	236.1	0.004
107488	2N2	251.1	0.053
107488	OO1	197.9	0.05
107488	M1	219.6	0.01
107488	J1	277.8	0.024
107488	Q1	190.2	0.014
107488	2Q1	69	0.017
107488	P1	207.8	0.101
107488	2SM2	223.8	0.009
107488	M3	178.5	0.009
107488	L2	335.3	0.039
107488	2MK3	205.7	0.027
107488	K2	308	0.089
107488	M8	19.7	0.017
107488	MS4	252.7	0.035
107489	M2	306.1	1.1
107489	S2	339.2	0.239
107489	N2	288.3	0.168
107489	K1	200.6	0.351
107489	M4	239.3	0.136
107489	O1	166.9	0.193
107489	M6	80.8	0.053
107489	MK3	141.4	0.053
107489	S4	195.6	0.019
107489	MN4	211	0.035
107489	S6	278.8	0.003
107489	2N2	253.1	0.049
107489	OO1	219.5	0.049
107489	M1	205.9	0.009
107489	J1	293.9	0.019
107489	Q1	179.2	0.02
107489	2Q1	78.2	0.02
107489	P1	209.4	0.098
107489	2SM2	188.6	0.009
107489	M3	219.9	0.012
107489	L2	321.5	0.036
107489	2MK3	180.2	0.043
107489	K2	315	0.087
107489	M8	6.3	0.017
107489	MS4	240.8	0.034
107490	M2	331.5	1.894
107490	S2	10.2	0.412
107490	N2	315.8	0.277
107490	K1	228.3	0.55
107490	M4	285.7	0.171
107490	O1	231.1	0.334
107490	M6	107	0.14
107490	MK3	193.1	0.186
107490	S4	336.2	0.004
107490	MN4	266.6	0.052
107490	S6	317.2	0.005
107490	2N2	267.6	0.089
107490	OO1	227	0.1
107490	M1	263	0.022
107490	J1	301.1	0.042
107490	Q1	228.3	0.04
107490	2Q1	236	0.012
107490	P1	228.6	0.189
107490	2SM2	194.2	0.016
107490	M3	294.1	0.057
107490	L2	334.1	0.083
107490	2MK3	215.9	0.226
107490	K2	333.7	0.18
107490	M8	42.1	0.034
107490	MS4	320.1	0.049
107491	M2	331.6	1.978
107491	S2	10.2	0.429
107491	N2	315.9	0.288
107491	K1	228.7	0.573
107491	M4	286.3	0.174
107491	O1	231.8	0.35
107491	M6	106.5	0.148
107491	MK3	194.1	0.191
107491	S4	329	0.004
107491	MN4	267.3	0.054
107491	S6	313.4	0.006
107491	2N2	267.7	0.094
107491	OO1	227.4	0.104
107491	M1	264.6	0.024
107491	J1	302.2	0.044
107491	Q1	228.7	0.041
107491	2Q1	235.2	0.014
107491	P1	228.8	0.198
107491	2SM2	194.9	0.017
107491	M3	294.5	0.059
107491	L2	334.8	0.086
107491	2MK3	216.5	0.236
107491	K2	333.9	0.189
107491	M8	42.7	0.036
107491	MS4	320	0.05
107492	M2	331.7	2.042
107492	S2	10.4	0.443
107492	N2	316.3	0.297
107492	K1	229.1	0.591
107492	M4	287	0.176
107492	O1	232.5	0.364
107492	M6	105.8	0.153
107492	MK3	195	0.195
107492	S4	329.4	0.005
107492	MN4	267.9	0.055
107492	S6	313.8	0.006
107492	2N2	267.5	0.097
107492	OO1	227.7	0.109
107492	M1	264.7	0.025
107492	J1	303.1	0.045
107492	Q1	228.9	0.043
107492	2Q1	233.8	0.014
107492	P1	229.1	0.205
107492	2SM2	195.7	0.018
107492	M3	295.1	0.061
107492	L2	335	0.09
107492	2MK3	216.8	0.243
107492	K2	333.9	0.195
107492	M8	42.3	0.036
107492	MS4	320.8	0.049
107493	M2	331.9	2.097
107493	S2	10.5	0.454
107493	N2	316.5	0.305
107493	K1	229.5	0.608
107493	M4	288.1	0.176
107493	O1	233.2	0.377
107493	M6	105.2	0.157
107493	MK3	196	0.198
107493	S4	324.6	0.005
107493	MN4	268.2	0.056
107493	S6	307.2	0.006
107493	2N2	267.3	0.1
107493	OO1	227.4	0.112
107493	M1	265.5	0.026
107493	J1	303.7	0.047
107493	Q1	229	0.044
107493	2Q1	232.9	0.015
107493	P1	229.5	0.212
107493	2SM2	196.1	0.018
107493	M3	295.9	0.062
107493	L2	335.4	0.092
107493	2MK3	217.3	0.251
107493	K2	334	0.2
107493	M8	42.5	0.037
107493	MS4	321.5	0.048
107494	M2	332	2.146
107494	S2	10.7	0.464
107494	N2	316.6	0.311
107494	K1	230	0.621
107494	M4	289.4	0.176
107494	O1	233.9	0.388
107494	M6	104.5	0.16
107494	MK3	197.3	0.201
107494	S4	328.5	0.005
107494	MN4	269.4	0.056
107494	S6	309.4	0.006
107494	2N2	267.7	0.103
107494	OO1	227.6	0.115
107494	M1	266.5	0.026
107494	J1	304	0.047
107494	Q1	228.9	0.046
107494	2Q1	233.1	0.016
107494	P1	229.8	0.218
107494	2SM2	196.7	0.018
107494	M3	296.9	0.064
107494	L2	335.5	0.095
107494	2MK3	217.8	0.256
107494	K2	334.1	0.205
107494	M8	42.2	0.037
107494	MS4	322.3	0.047
107495	M2	332.1	2.189
107495	S2	10.9	0.472
107495	N2	316.8	0.317
107495	K1	230.3	0.634
107495	M4	290.7	0.176
107495	O1	234.5	0.398
107495	M6	103.9	0.163
107495	MK3	198.3	0.203
107495	S4	327.6	0.005
107495	MN4	270.1	0.057
107495	S6	309.9	0.007
107495	2N2	267.8	0.105
107495	OO1	227.9	0.118
107495	M1	267.3	0.027
107495	J1	304.3	0.048
107495	Q1	229	0.047
107495	2Q1	232.6	0.017
107495	P1	230.3	0.222
107495	2SM2	195.7	0.019
107495	M3	297.7	0.065
107495	L2	335.9	0.097
107495	2MK3	218.2	0.262
107495	K2	334	0.207
107495	M8	41.9	0.037
107495	MS4	324.3	0.046
107496	M2	332.2	2.229
107496	S2	11.1	0.478
107496	N2	316.9	0.323
107496	K1	230.6	0.647
107496	M4	291.9	0.175
107496	O1	235.1	0.408
107496	M6	103.3	0.166
107496	MK3	199.4	0.205
107496	S4	327.6	0.006
107496	MN4	271	0.057
107496	S6	307.2	0.007
107496	2N2	267.9	0.108
107496	OO1	228.4	0.12
107496	M1	267.8	0.028
107496	J1	305.1	0.049
107496	Q1	229.1	0.048
107496	2Q1	233.6	0.018
107496	P1	231	0.226
107496	2SM2	195.5	0.019
107496	M3	298	0.066
107496	L2	336.1	0.099
107496	2MK3	218.6	0.267
107496	K2	334	0.21
107496	M8	42.1	0.036
107496	MS4	325.4	0.045
107497	M2	332.3	2.264
107497	S2	11.3	0.485
107497	N2	317	0.328
107497	K1	230.9	0.658
107497	M4	293	0.175
107497	O1	235.6	0.416
107497	M6	102.7	0.168
107497	MK3	200.3	0.207
107497	S4	329.1	0.006
107497	MN4	272	0.056
107497	S6	303.3	0.007
107497	2N2	267.9	0.11
107497	OO1	228.1	0.123
107497	M1	268.1	0.028
107497	J1	305.2	0.049
107497	Q1	229.3	0.049
107497	2Q1	234.3	0.019
107497	P1	231.3	0.23
107497	2SM2	196.4	0.019
107497	M3	298.6	0.067
107497	L2	336	0.1
107497	2MK3	219	0.271
107497	K2	334	0.213
107497	M8	42.1	0.036
107497	MS4	326.9	0.044
107498	M2	332.4	2.295
107498	S2	11.5	0.49
107498	N2	317.2	0.333
107498	K1	231.2	0.668
107498	M4	294.3	0.175
107498	O1	236	0.423
107498	M6	102.3	0.17
107498	MK3	201.3	0.209
107498	S4	325.1	0.006
107498	MN4	272.7	0.057
107498	S6	301.7	0.007
107498	2N2	268.2	0.111
107498	OO1	228.3	0.125
107498	M1	268.5	0.029
107498	J1	305.3	0.05
107498	Q1	229.9	0.049
107498	2Q1	233.2	0.019
107498	P1	231.3	0.233
107498	2SM2	196	0.02
107498	M3	299.4	0.068
107498	L2	336.2	0.102
107498	2MK3	219.4	0.276
107498	K2	333.9	0.215
107498	M8	42.3	0.036
107498	MS4	329.6	0.043
107499	M2	331.7	2.321
107499	S2	9.1	0.501
107499	N2	315.6	0.335
107499	K1	229.8	0.663
107499	M4	294	0.152
107499	O1	232.8	0.409
107499	M6	95.9	0.169
107499	MK3	204.8	0.18
107499	S4	147	0.01
107499	MN4	275.3	0.044
107499	S6	351.6	0.008
107499	2N2	277.6	0.105
107499	OO1	245.4	0.119
107499	M1	270.7	0.026
107499	J1	299.2	0.046
107499	Q1	221.1	0.041
107499	2Q1	243.4	0.038
107499	P1	228	0.242
107499	2SM2	220	0.028
107499	M3	305.5	0.06
107499	L2	335.7	0.101
107499	2MK3	224.1	0.262
107499	K2	339.2	0.231
107499	M8	33.7	0.026
107499	MS4	353.4	0.018
107500	M2	332.5	1.081
107500	S2	2.3	0.287
107500	N2	309.3	0.2
107500	K1	217.3	0.415
107500	M4	191.3	0.05
107500	O1	197.9	0.198
107500	M6	133.6	0.015
107500	MK3	34.8	0.105
107500	S4	248.9	0.015
107500	MN4	161.3	0.018
107500	S6	43.7	0.004
107500	2N2	326.4	0.027
107500	OO1	224	0.018
107500	M1	259	0.003
107500	J1	238.8	0.014
107500	Q1	156.4	0.027
107500	2Q1	173.4	0.031
107500	P1	215.3	0.15
107500	2SM2	102.2	0.006
107500	M3	52	0.013
107500	L2	351.5	0.022
107500	2MK3	346.5	0.019
107500	K2	338.8	0.118
107500	M8	341.1	0.012
107500	MS4	285.2	0.027
107501	M2	332.3	1.337
107501	S2	358.7	0.339
107501	N2	306.7	0.23
107501	K1	215.8	0.49
107501	M4	239.6	0.052
107501	O1	196.2	0.235
107501	M6	124.6	0.03
107501	MK3	41.4	0.098
107501	S4	241	0.016
107501	MN4	168.5	0.016
107501	2N2	311.7	0.045
107501	OO1	231.9	0.032
107501	M1	249.6	0.008
107501	J1	268.2	0.021
107501	Q1	171.9	0.033
107501	2Q1	152.7	0.018
107501	P1	217.3	0.167
107501	2SM2	104.7	0.004
107501	M3	109.9	0.015
107501	L2	18.1	0.029
107501	2MK3	357.4	0.035
107501	K2	339.9	0.146
107501	M8	13.4	0.009
107501	MS4	273.3	0.047
107502	M2	331.6	1.441
107502	S2	355.6	0.35
107502	N2	303.1	0.241
107502	K1	213.5	0.498
107502	M4	279.2	0.06
107502	O1	197.3	0.236
107502	M6	129.1	0.028
107502	MK3	61	0.094
107502	S4	228.5	0.011
107502	MN4	216.5	0.014
107502	S6	315	0.003
107502	2N2	317.3	0.063
107502	OO1	233.7	0.053
107502	M1	241.7	0.014
107502	J1	287.2	0.024
107502	Q1	196.6	0.033
107502	2Q1	135.7	0.009
107502	P1	213.1	0.161
107502	2SM2	202.1	0.004
107502	M3	126.7	0.017
107502	L2	32.3	0.042
107502	2MK3	2.7	0.042
107502	K2	341.7	0.152
107502	M8	77.1	0.015
107502	MS4	280	0.046
107503	M2	329.3	1.018
107503	S2	2.9	0.258
107503	N2	306.7	0.187
107503	K1	218.5	0.393
107503	M4	197.9	0.069
107503	O1	213.2	0.191
107503	M6	105.2	0.035
107503	MK3	65.2	0.122
107503	S4	219.1	0.014
107503	MN4	158.7	0.026
107503	S6	82	0.002
107503	2N2	349.9	0.013
107503	OO1	232.6	0.036
107503	M1	261	0.009
107503	J1	260.9	0.016
107503	Q1	173	0.033
107503	2Q1	228.7	0.023
107503	P1	211.9	0.139
107503	2SM2	320.1	0.003
107503	M3	152.5	0.021
107503	L2	343.8	0.017
107503	2MK3	33.7	0.024
107503	K2	351	0.083
107503	M8	58.9	0.005
107503	MS4	220.6	0.029
107504	M2	329.5	1.085
107504	S2	2.6	0.272
107504	N2	306.8	0.197
107504	K1	218.5	0.418
107504	M4	197.8	0.072
107504	O1	212.2	0.202
107504	M6	108.7	0.039
107504	MK3	64.5	0.127
107504	S4	219	0.015
107504	MN4	159	0.025
107504	S6	73.6	0.002
107504	2N2	336.7	0.014
107504	OO1	233.5	0.037
107504	M1	263.2	0.009
107504	J1	258.9	0.016
107504	Q1	172.4	0.036
107504	2Q1	228.8	0.024
107504	P1	211.7	0.146
107504	2SM2	314	0.003
107504	M3	151.2	0.023
107504	L2	346.9	0.02
107504	2MK3	28.8	0.027
107504	K2	350.2	0.089
107504	M8	59.4	0.005
107504	MS4	220.6	0.03
107505	M2	329.7	1.128
107505	S2	2.3	0.281
107505	N2	307	0.204
107505	K1	218.2	0.434
107505	M4	198.7	0.075
107505	O1	210.9	0.211
107505	M6	111.1	0.04
107505	MK3	64.2	0.133
107505	S4	219.1	0.016
107505	MN4	160.5	0.026
107505	S6	71.2	0.002
107505	2N2	329.6	0.017
107505	OO1	232.8	0.038
107505	M1	260.4	0.009
107505	J1	258.3	0.016
107505	Q1	173.2	0.037
107505	2Q1	228.6	0.023
107505	P1	212.2	0.149
107505	2SM2	322.5	0.002
107505	M3	151	0.024
107505	L2	350.2	0.022
107505	2MK3	28.5	0.03
107505	K2	349.6	0.093
107505	M8	63.5	0.005
107505	MS4	220.9	0.032
107506	M2	330	1.159
107506	S2	2	0.289
107506	N2	307.1	0.208
107506	K1	217.8	0.447
107506	M4	200.3	0.077
107506	O1	209.6	0.219
107506	M6	113.2	0.041
107506	MK3	64.3	0.138
107506	S4	219.9	0.016
107506	MN4	163.7	0.027
107506	S6	74.6	0.003
107506	2N2	323.6	0.02
107506	OO1	231.2	0.039
107506	M1	257.9	0.009
107506	J1	260.7	0.017
107506	Q1	174.5	0.039
107506	2Q1	228.8	0.023
107506	P1	212.9	0.151
107506	2SM2	327.8	0.002
107506	M3	148.5	0.026
107506	L2	354.9	0.022
107506	2MK3	28.5	0.033
107506	K2	349.7	0.097
107506	M8	64.2	0.005
107506	MS4	221.8	0.034
107507	M2	330.2	1.184
107507	S2	1.7	0.297
107507	N2	307	0.212
107507	K1	217.3	0.457
107507	M4	201.9	0.08
107507	O1	208.3	0.226
107507	M6	115.8	0.041
107507	MK3	64.9	0.142
107507	S4	220.9	0.016
107507	MN4	167.6	0.028
107507	S6	74.9	0.003
107507	2N2	319.4	0.024
107507	OO1	229.5	0.04
107507	M1	252.4	0.009
107507	J1	260.8	0.018
107507	Q1	175.8	0.04
107507	2Q1	230.9	0.022
107507	P1	214.4	0.151
107507	M3	147.8	0.027
107507	L2	359.3	0.023
107507	2MK3	28.4	0.036
107507	K2	349.9	0.101
107507	M8	72.3	0.005
107507	MS4	222.8	0.034
107508	M2	330.5	1.202
107508	S2	1.5	0.302
107508	N2	307	0.214
107508	K1	216.8	0.463
107508	M4	204.1	0.082
107508	O1	207	0.232
107508	M6	119.1	0.041
107508	MK3	65.5	0.144
107508	S4	222.3	0.017
107508	MN4	171.8	0.029
107508	S6	81.7	0.003
107508	2N2	317.4	0.027
107508	OO1	226.8	0.041
107508	M1	247.9	0.01
107508	J1	262.7	0.019
107508	Q1	176.4	0.041
107508	2Q1	232.7	0.02
107508	P1	215.9	0.152
107508	M3	147.3	0.028
107508	L2	5.2	0.024
107508	2MK3	29.1	0.037
107508	K2	350.1	0.104
107508	M8	82.7	0.004
107508	MS4	222.9	0.035
107509	M2	330.7	1.217
107509	S2	1.4	0.307
107509	N2	306.8	0.215
107509	K1	216.4	0.47
107509	M4	206.8	0.084
107509	O1	206.1	0.237
107509	M6	122.8	0.04
107509	MK3	66.4	0.143
107509	S4	225.8	0.017
107509	MN4	175.4	0.03
107509	S6	93.9	0.003
107509	2N2	316.4	0.03
107509	OO1	224.7	0.04
107509	M1	243.5	0.01
107509	J1	262.7	0.022
107509	Q1	176	0.043
107509	2Q1	235.2	0.018
107509	P1	217.3	0.153
107509	M3	145.3	0.029
107509	L2	9.8	0.025
107509	2MK3	28.3	0.039
107509	K2	350.7	0.106
107509	M8	93.6	0.004
107509	MS4	223	0.035
107510	M2	330.9	1.229
107510	S2	1.3	0.31
107510	N2	306.6	0.216
107510	K1	216.1	0.476
107510	M4	210.1	0.085
107510	O1	205.1	0.241
107510	M6	126.5	0.039
107510	MK3	67.2	0.14
107510	S4	230.7	0.017
107510	MN4	178.7	0.031
107510	S6	107.3	0.002
107510	2N2	314.9	0.033
107510	OO1	223.3	0.039
107510	M1	243.3	0.011
107510	J1	262.7	0.024
107510	Q1	175.8	0.044
107510	2Q1	238.9	0.016
107510	P1	218.3	0.153
107510	M3	143.7	0.03
107510	L2	12.8	0.027
107510	2MK3	27.1	0.039
107510	K2	350.8	0.107
107510	M8	98.8	0.003
107510	MS4	224.6	0.035
107511	M2	331.2	1.24
107511	S2	1.1	0.311
107511	N2	306.4	0.216
107511	K1	215.8	0.48
107511	M4	213.8	0.084
107511	O1	204.4	0.244
107511	M6	130.1	0.036
107511	MK3	67.1	0.136
107511	S4	236.8	0.018
107511	MN4	181	0.031
107511	S6	127.9	0.002
107511	2N2	315.2	0.036
107511	OO1	221.2	0.037
107511	M1	244.7	0.012
107511	J1	263.9	0.027
107511	Q1	175.9	0.047
107511	2Q1	240.5	0.013
107511	P1	219.1	0.153
107511	M3	142.9	0.029
107511	L2	16.6	0.029
107511	2MK3	24.8	0.039
107511	K2	349	0.105
107511	M8	99.5	0.003
107511	MS4	226.1	0.036
107512	M2	331.5	1.251
107512	S2	0.5	0.312
107512	N2	306	0.217
107512	K1	215.9	0.483
107512	M4	217.2	0.082
107512	O1	203.4	0.246
107512	M6	134.8	0.034
107512	MK3	67.1	0.132
107512	S4	242.4	0.018
107512	MN4	183.8	0.031
107512	S6	157.5	0.002
107512	2N2	316.1	0.038
107512	OO1	218.9	0.036
107512	M1	244.4	0.012
107512	J1	265.5	0.029
107512	Q1	177.4	0.048
107512	2Q1	236.6	0.01
107512	P1	219.2	0.153
107512	M3	141.6	0.028
107512	L2	20	0.032
107512	2MK3	22.4	0.038
107512	K2	346.2	0.106
107512	M8	102.8	0.002
107512	MS4	228	0.036
107513	M2	331.9	1.263
107513	S2	359.6	0.315
107513	N2	305.5	0.216
107513	K1	215.6	0.486
107513	M4	220.8	0.079
107513	O1	202.2	0.248
107513	M6	138.4	0.033
107513	MK3	67	0.127
107513	S4	247.5	0.019
107513	MN4	186.7	0.03
107513	S6	167.2	0.003
107513	2N2	314.5	0.04
107513	OO1	216	0.037
107513	M1	243.7	0.013
107513	J1	268.2	0.031
107513	Q1	180	0.047
107513	2Q1	222.9	0.008
107513	P1	220.4	0.153
107513	M3	140.8	0.028
107513	L2	24.6	0.033
107513	2MK3	20.9	0.039
107513	K2	343.5	0.108
107513	M8	112.4	0.002
107513	MS4	230.6	0.037
107514	M2	332.3	1.275
107514	S2	358.8	0.318
107514	N2	305.3	0.216
107514	K1	215.4	0.488
107514	M4	224.7	0.076
107514	O1	200.9	0.249
107514	M6	142.3	0.033
107514	MK3	66.6	0.122
107514	S4	249.4	0.019
107514	MN4	188	0.029
107514	S6	163	0.004
107514	2N2	312.7	0.042
107514	OO1	209.8	0.039
107514	M1	241.2	0.014
107514	J1	271	0.032
107514	Q1	183.1	0.045
107514	2Q1	196	0.007
107514	P1	221.4	0.153
107514	M3	141.2	0.027
107514	L2	29.9	0.034
107514	2MK3	19.2	0.039
107514	K2	341.8	0.113
107514	M8	123	0.002
107514	MS4	234.2	0.037
107515	M2	332.7	1.285
107515	S2	358.4	0.322
107515	N2	305.7	0.216
107515	K1	215.5	0.491
107515	M4	228.1	0.073
107515	O1	199.3	0.25
107515	M6	146.5	0.034
107515	MK3	66.6	0.115
107515	S4	253.8	0.019
107515	MN4	188.6	0.027
107515	S6	151.7	0.005
107515	2N2	310.6	0.043
107515	OO1	203.8	0.039
107515	M1	238	0.014
107515	J1	274.8	0.032
107515	Q1	187.7	0.042
107515	2Q1	172.8	0.009
107515	P1	221.3	0.153
107515	M3	142.3	0.027
107515	L2	33.2	0.034
107515	2MK3	19.9	0.04
107515	K2	342	0.116
107515	M8	143.2	0.002
107515	MS4	238.4	0.038
107516	M2	333.1	1.293
107516	S2	358.8	0.324
107516	N2	306	0.218
107516	K1	215.8	0.495
107516	M4	231.3	0.07
107516	O1	197.5	0.252
107516	M6	149.9	0.035
107516	MK3	66.6	0.107
107516	S4	256.4	0.019
107516	MN4	191.1	0.025
107516	S6	149.9	0.006
107516	2N2	310	0.044
107516	OO1	201.6	0.039
107516	M1	233.5	0.014
107516	J1	276.8	0.032
107516	Q1	193.2	0.038
107516	2Q1	156.4	0.011
107516	P1	221	0.151
107516	2SM2	29.1	0.003
107516	M3	144.7	0.026
107516	L2	35.5	0.032
107516	2MK3	21.4	0.039
107516	K2	343.4	0.117
107516	M8	169.5	0.002
107516	MS4	241.5	0.039
107517	M2	333.5	1.297
107517	S2	359.4	0.328
107517	N2	306.5	0.22
107517	K1	216.1	0.498
107517	M4	235.2	0.067
107517	O1	195.6	0.256
107517	M6	152.1	0.036
107517	MK3	66.7	0.1
107517	S4	258.2	0.018
107517	MN4	191.6	0.022
107517	S6	146.7	0.007
107517	2N2	310.8	0.046
107517	OO1	203	0.036
107517	M1	230.9	0.015
107517	J1	277.7	0.03
107517	Q1	195.6	0.035
107517	2Q1	144.4	0.014
107517	P1	220.2	0.148
107517	2SM2	31.4	0.004
107517	M3	146.2	0.025
107517	L2	36.1	0.03
107517	2MK3	26.7	0.037
107517	K2	345.8	0.121
107517	M8	187	0.002
107517	MS4	244.7	0.039
107518	M2	333.6	1.294
107518	S2	0.2	0.328
107518	N2	307	0.217
107518	K1	215.7	0.505
107518	M4	239.2	0.06
107518	O1	192.3	0.257
107518	M6	157.1	0.036
107518	MK3	63	0.092
107518	S4	252.4	0.016
107518	MN4	197.4	0.018
107518	S6	133.9	0.007
107518	2N2	312.9	0.05
107518	OO1	215.3	0.031
107518	M1	229	0.013
107518	J1	273.3	0.029
107518	Q1	196.3	0.032
107518	2Q1	136.8	0.017
107518	P1	219.6	0.141
107518	2SM2	16.1	0.006
107518	M3	147.3	0.02
107518	L2	43.3	0.027
107518	2MK3	27.2	0.034
107518	K2	350.6	0.122
107518	M8	150.1	0.002
107518	MS4	248.7	0.035
107519	M2	332.4	1.247
107519	S2	357.4	0.319
107519	N2	304.5	0.208
107519	K1	211.2	0.472
107519	M4	294.7	0.035
107519	O1	177.7	0.259
107519	M6	187.7	0.055
107519	MK3	14.9	0.067
107519	S4	298.7	0.006
107519	MN4	235.8	0.006
107519	S6	184.2	0.006
107519	2N2	324.2	0.068
107519	OO1	261.7	0.055
107519	M1	219.6	0.012
107519	J1	251.8	0.016
107519	Q1	166.3	0.03
107519	2Q1	167.5	0.015
107519	P1	211.8	0.144
107519	M3	114.6	0.011
107519	L2	52.3	0.029
107519	2MK3	330.8	0.04
107519	K2	352.8	0.166
107519	M8	75.6	0.014
107519	MS4	341.6	0.029
107520	M2	316.6	0.569
107520	S2	352.2	0.13
107520	N2	289.3	0.088
107520	K1	195.6	0.203
107520	M4	281.5	0.037
107520	O1	151.8	0.124
107520	M6	83.1	0.019
107520	MK3	151.8	0.023
107520	S4	278.3	0.005
107520	MN4	279.1	0.012
107520	S6	58.3	0.002
107520	2N2	266.7	0.029
107520	OO1	206.9	0.027
107520	M1	260.7	0.008
107520	J1	333.2	0.017
107520	Q1	87.3	0.009
107520	2Q1	89.4	0.017
107520	P1	185.7	0.04
107520	2SM2	72.8	0.002
107520	M3	258.1	0.012
107520	L2	355.9	0.018
107520	2MK3	225.3	0.011
107520	K2	324.6	0.052
107520	MS4	305.2	0.025
107521	M2	318.1	0.584
107521	S2	350.4	0.132
107521	N2	290.6	0.09
107521	K1	196.1	0.198
107521	M4	280.9	0.037
107521	O1	153.3	0.115
107521	M6	86.6	0.019
107521	MK3	133.9	0.023
107521	S4	279.1	0.005
107521	MN4	265.7	0.01
107521	S6	79.6	0.002
107521	2N2	264.4	0.026
107521	OO1	200.5	0.028
107521	M1	263.2	0.008
107521	J1	330.2	0.015
107521	Q1	94	0.008
107521	2Q1	73.5	0.013
107521	P1	189.2	0.047
107521	2SM2	113	0.002
107521	M3	254.8	0.011
107521	L2	4.3	0.019
107521	2MK3	250.9	0.006
107521	K2	319.6	0.054
107521	M8	173	0.003
107521	MS4	300.2	0.025
107522	M2	320	0.59
107522	S2	349.3	0.134
107522	N2	293.3	0.092
107522	K1	197.3	0.197
107522	M4	275.9	0.035
107522	O1	156.2	0.109
107522	M6	91.8	0.018
107522	MK3	115.2	0.028
107522	S4	289.5	0.006
107522	MN4	249.5	0.009
107522	S6	90.7	0.002
107522	2N2	265.1	0.023
107522	OO1	195.4	0.026
107522	M1	264.1	0.008
107522	J1	328.3	0.013
107522	Q1	96.8	0.007
107522	2Q1	61.4	0.011
107522	P1	191.8	0.051
107522	2SM2	165.5	0.002
107522	M3	246.2	0.011
107522	L2	12.2	0.019
107522	2MK3	325.8	0.003
107522	K2	315.9	0.054
107522	M8	172.1	0.005
107522	MS4	292.8	0.022
107523	M2	322	0.589
107523	S2	349.1	0.135
107523	N2	297.1	0.093
107523	K1	200.3	0.199
107523	M4	269.6	0.033
107523	O1	161	0.106
107523	M6	102.8	0.016
107523	MK3	103.3	0.037
107523	S4	299.8	0.006
107523	MN4	234.5	0.009
107523	S6	129.3	0.001
107523	2N2	271.1	0.02
107523	OO1	191.5	0.025
107523	M1	262.6	0.008
107523	J1	330.3	0.012
107523	Q1	92.1	0.006
107523	2Q1	59.3	0.009
107523	P1	194.5	0.052
107523	2SM2	194.3	0.005
107523	M3	227.3	0.01
107523	L2	18.6	0.017
107523	2MK3	33.6	0.006
107523	K2	313	0.052
107523	M8	179.3	0.007
107523	MS4	279.8	0.018
107524	M2	324.4	0.583
107524	S2	348.4	0.135
107524	N2	300.8	0.093
107524	K1	204.2	0.202
107524	M4	262.8	0.031
107524	O1	167.1	0.104
107524	M6	120	0.015
107524	MK3	97.6	0.048
107524	S4	302.9	0.005
107524	MN4	224.6	0.008
107524	2N2	281.9	0.018
107524	OO1	188.9	0.026
107524	M1	255.4	0.009
107524	J1	324.7	0.011
107524	Q1	86.6	0.003
107524	2Q1	66.2	0.007
107524	P1	199.6	0.053
107524	2SM2	205.8	0.007
107524	M3	204.7	0.011
107524	L2	24.1	0.015
107524	2MK3	49.5	0.01
107524	K2	308.8	0.05
107524	M8	184.1	0.009
107524	MS4	254.3	0.015
107525	M2	327.2	0.574
107525	S2	348.4	0.134
107525	N2	303.7	0.092
107525	K1	208.9	0.209
107525	M4	257.2	0.031
107525	O1	174.1	0.103
107525	M6	137.8	0.014
107525	MK3	93.4	0.059
107525	S4	279.3	0.003
107525	MN4	217	0.007
107525	S6	4	0.001
107525	2N2	295.2	0.019
107525	OO1	188	0.025
107525	M1	244.2	0.009
107525	J1	314.7	0.011
107525	2Q1	95.8	0.006
107525	P1	206.5	0.053
107525	2SM2	212.8	0.007
107525	M3	191.3	0.013
107525	L2	31.4	0.015
107525	2MK3	53.7	0.013
107525	K2	309.5	0.048
107525	M8	190.5	0.009
107525	MS4	228.5	0.016
107526	M2	330.3	0.565
107526	S2	350.2	0.135
107526	N2	305.4	0.091
107526	K1	214.6	0.221
107526	M4	252.9	0.032
107526	O1	182.8	0.104
107526	M6	152.6	0.014
107526	MK3	89.4	0.067
107526	S4	222.4	0.002
107526	MN4	207.2	0.007
107526	S6	345.1	0.002
107526	2N2	313.3	0.021
107526	OO1	193.3	0.021
107526	M1	229.7	0.008
107526	J1	308.1	0.01
107526	Q1	218.4	0.006
107526	2Q1	124.7	0.008
107526	P1	212.2	0.051
107526	2SM2	215	0.006
107526	M3	181.8	0.012
107526	L2	38.2	0.017
107526	2MK3	47.1	0.016
107526	K2	321.7	0.047
107526	M8	190.9	0.009
107526	MS4	216.1	0.019
107527	M2	333.5	0.555
107527	S2	352.6	0.136
107527	N2	306.3	0.092
107527	K1	220.5	0.236
107527	M4	249.3	0.037
107527	O1	194.1	0.107
107527	M6	168.5	0.014
107527	MK3	85.3	0.074
107527	S4	196.8	0.003
107527	MN4	200.8	0.01
107527	S6	312.7	0.003
107527	2N2	330	0.026
107527	OO1	214.1	0.019
107527	M1	213.4	0.007
107527	J1	326.6	0.007
107527	Q1	212.5	0.013
107527	2Q1	146.3	0.01
107527	P1	219.4	0.051
107527	2SM2	224.9	0.005
107527	M3	165.8	0.01
107527	L2	48.6	0.019
107527	2MK3	35.2	0.017
107527	K2	340.4	0.049
107527	M8	170.5	0.008
107527	MS4	212.7	0.022
107528	M2	336.7	0.544
107528	S2	354.5	0.139
107528	N2	308.3	0.093
107528	K1	226.8	0.25
107528	M4	247.5	0.041
107528	O1	206.7	0.113
107528	M6	180	0.015
107528	MK3	81.6	0.079
107528	S4	199.8	0.006
107528	MN4	207	0.014
107528	S6	292	0.002
107528	2N2	339.9	0.031
107528	OO1	246	0.025
107528	M1	193.7	0.006
107528	J1	19.6	0.004
107528	Q1	216.3	0.021
107528	2Q1	176.1	0.011
107528	P1	223.7	0.054
107528	2SM2	262.4	0.004
107528	M3	138.1	0.009
107528	L2	62	0.018
107528	2MK3	29.5	0.02
107528	K2	357.9	0.056
107528	M8	145.2	0.009
107528	MS4	215.6	0.022
107529	M2	339	0.537
107529	S2	355.3	0.14
107529	N2	312.1	0.094
107529	K1	232.7	0.259
107529	M4	250.5	0.043
107529	O1	218.7	0.121
107529	M6	180.3	0.017
107529	MK3	80.5	0.079
107529	S4	202.8	0.01
107529	MN4	209.8	0.018
107529	S6	231.2	0.002
107529	2N2	343.8	0.037
107529	OO1	269.8	0.034
107529	M1	172.8	0.007
107529	J1	104.7	0.004
107529	Q1	227.2	0.027
107529	2Q1	210.9	0.011
107529	P1	226.5	0.055
107529	2SM2	325.9	0.004
107529	M3	125.5	0.011
107529	L2	79.6	0.015
107529	2MK3	37.3	0.024
107529	K2	7.5	0.06
107529	M8	135.7	0.011
107529	MS4	224.6	0.021
107530	M2	338.9	0.52
107530	S2	355.6	0.135
107530	N2	314.2	0.095
107530	K1	235.3	0.25
107530	M4	265.3	0.037
107530	O1	222.2	0.113
107530	M6	192	0.019
107530	MK3	73.7	0.066
107530	S4	188.8	0.012
107530	MN4	205	0.015
107530	S6	199.1	0.004
107530	2N2	345.6	0.043
107530	OO1	292.4	0.053
107530	M1	147.3	0.009
107530	J1	156	0.011
107530	Q1	237.2	0.03
107530	2Q1	244.3	0.014
107530	P1	222.5	0.06
107530	2SM2	334.4	0.005
107530	M3	104.1	0.015
107530	L2	121	0.012
107530	2MK3	22.8	0.029
107530	K2	21.6	0.066
107530	M8	129.6	0.014
107530	MS4	229.6	0.009
107531	M2	281.2	0.563
107531	S2	302.7	0.13
107531	N2	249.5	0.085
107531	K1	192.5	0.228
107531	M4	88.1	0.016
107531	O1	157.4	0.128
107531	M6	341.3	0.032
107531	MK3	39.6	0.043
107531	S4	20.4	0.01
107531	MN4	33.2	0.024
107531	S6	344.7	0.001
107531	2N2	228.7	0.016
107531	OO1	215.2	0.033
107531	M1	205.7	0.019
107531	J1	228	0.008
107531	Q1	143.2	0.016
107531	2Q1	67.5	0.013
107531	P1	177.5	0.072
107531	2SM2	159.9	0.002
107531	M3	291.9	0.005
107531	L2	315.6	0.021
107531	2MK3	341.6	0.035
107531	K2	306.1	0.034
107531	M8	267.9	0.004
107531	MS4	119.9	0.019
107532	M2	279.5	0.551
107532	S2	304.5	0.123
107532	N2	245.6	0.097
107532	K1	194.8	0.215
107532	M4	160.7	0.026
107532	O1	158.2	0.123
107532	M6	5.2	0.025
107532	MK3	22.4	0.021
107532	S4	102.5	0.001
107532	MN4	167.5	0.006
107532	S6	83.8	0.004
107532	2N2	146.5	0.004
107532	OO1	234.4	0.014
107532	M1	202.8	0.013
107532	J1	196.6	0.007
107532	Q1	102.9	0.008
107532	2Q1	22.9	0.019
107532	P1	181.7	0.051
107532	2SM2	166.9	0.007
107532	M3	50.7	0.006
107532	L2	293.9	0.012
107532	2MK3	355.5	0.027
107532	K2	271.9	0.042
107532	M8	203.8	0.008
107532	MS4	161	0.004
107533	M2	265.7	0.585
107533	S2	282.2	0.105
107533	N2	231.8	0.087
107533	K1	196	0.164
107533	M4	120.6	0.089
107533	O1	190.5	0.128
107533	M6	16.1	0.059
107533	MK3	313	0.045
107533	S4	20.4	0.015
107533	MN4	114.4	0.034
107533	S6	311.2	0.01
107533	2N2	351.5	0.003
107533	OO1	299	0.012
107533	M1	303	0.029
107533	J1	145.9	0.017
107533	Q1	216.6	0.022
107533	2Q1	137.9	0.01
107533	P1	207.5	0.046
107533	2SM2	17.5	0.005
107533	M3	71.6	0.006
107533	L2	298.3	0.028
107533	2MK3	167.2	0.014
107533	K2	268	0.058
107533	M8	100.9	0.003
107533	MS4	91.7	0.023
107534	M2	271.5	0.644
107534	S2	301	0.159
107534	N2	235.5	0.114
107534	K1	186.1	0.311
107534	M4	81.4	0.049
107534	O1	164.3	0.242
107534	M6	322.7	0.034
107534	MK3	24.1	0.017
107534	S4	81.6	0.008
107534	MN4	70.5	0.008
107534	S6	134.4	0.004
107534	2N2	303.3	0.017
107534	OO1	234.2	0.045
107534	M1	217.3	0.019
107534	J1	238.7	0.014
107534	Q1	162.6	0.035
107534	2Q1	300.1	0.005
107534	P1	198.8	0.09
107534	2SM2	172.5	0.013
107534	M3	206.2	0.014
107534	L2	346.8	0.025
107534	2MK3	23.8	0.022
107534	K2	236.5	0.044
107534	M8	126.7	0.008
107534	MS4	188.8	0.022
107535	M2	280.1	0.752
107535	S2	300.9	0.155
107535	N2	244.2	0.126
107535	K1	194.6	0.287
107535	M4	117.1	0.038
107535	O1	156.2	0.127
107535	M6	25.6	0.042
107535	MK3	350.7	0.072
107535	S4	92.1	0.011
107535	MN4	65.7	0.013
107535	S6	10.7	0.003
107535	2N2	318.5	0.016
107535	OO1	202.5	0.011
107535	M1	134.1	0.004
107535	J1	195.3	0.012
107535	Q1	119.8	0.019
107535	2Q1	146.1	0.017
107535	P1	177.7	0.101
107535	2SM2	286	0.012
107535	M3	53.9	0.006
107535	L2	299.5	0.017
107535	2MK3	301.7	0.055
107535	K2	309.3	0.05
107535	MS4	153.3	0.023
107536	M2	278	0.777
107536	S2	299.8	0.16
107536	N2	242	0.123
107536	K1	189.9	0.293
107536	M4	133	0.041
107536	O1	152.7	0.143
107536	M6	23	0.043
107536	MK3	356.2	0.064
107536	S4	82.1	0.008
107536	MN4	88.5	0.01
107536	S6	19.5	0.003
107536	2N2	290.2	0.018
107536	OO1	82.7	0.009
107536	M1	78.6	0.007
107536	J1	146.9	0.025
107536	Q1	109.8	0.027
107536	2Q1	130.7	0.012
107536	P1	170	0.102
107536	2SM2	303.6	0.006
107536	M3	32.1	0.008
107536	L2	300.5	0.019
107536	2MK3	294.2	0.048
107536	K2	310.7	0.051
107536	M8	34	0.001
107536	MS4	164.1	0.023
107537	M2	280.8	0.839
107537	S2	299.6	0.174
107537	N2	247.7	0.134
107537	K1	175.8	0.345
107537	M4	52.9	0.012
107537	O1	143.1	0.224
107537	M6	12.2	0.041
107537	MK3	20.2	0.023
107537	S4	327.7	0.005
107537	MN4	6.3	0.01
107537	S6	309.7	0.005
107537	2N2	297.7	0.017
107537	OO1	215.3	0.049
107537	M1	158.7	0.022
107537	J1	172.7	0.007
107537	Q1	108.2	0.062
107537	2Q1	271.1	0.014
107537	P1	166.7	0.132
107537	2SM2	14.2	0.01
107537	M3	212.7	0.004
107537	L2	331.7	0.061
107537	2MK3	328.3	0.031
107537	K2	325.2	0.03
107537	M8	175.4	0.004
107537	MS4	158.9	0.028
107538	M2	284.6	0.776
107538	S2	303.1	0.19
107538	N2	245.4	0.128
107538	K1	198.1	0.339
107538	M4	167.3	0.023
107538	O1	168.9	0.185
107538	M6	21	0.034
107538	MK3	82.7	0.055
107538	S4	73.1	0.009
107538	MN4	138.8	0.009
107538	S6	173.1	0.002
107538	2N2	280.9	0.022
107538	OO1	249.6	0.025
107538	M1	182.9	0.007
107538	J1	220.6	0.015
107538	Q1	151.8	0.022
107538	2Q1	137.2	0.011
107538	P1	187.8	0.082
107538	2SM2	241.8	0.004
107538	M3	327.9	0.002
107538	L2	336.4	0.033
107538	2MK3	338.2	0.031
107538	K2	280.2	0.054
107538	M8	42.3	0.005
107538	MS4	175.6	0.022
107539	M2	279.7	0.71
107539	S2	306.5	0.176
107539	N2	242.3	0.138
107539	K1	199.4	0.326
107539	M4	102.2	0.064
107539	O1	177	0.211
107539	M6	337.4	0.035
107539	MK3	358.7	0.085
107539	S4	46.3	0.011
107539	MN4	92.5	0.018
107539	S6	41.1	0.002
107539	2N2	337.6	0.026
107539	OO1	285.2	0.03
107539	M1	268	0.018
107539	J1	224.2	0.025
107539	Q1	210.4	0.021
107539	2Q1	114.5	0.012
107539	P1	190.7	0.099
107539	2SM2	188.3	0.007
107539	M3	48.5	0.026
107539	L2	152.1	0.021
107539	2MK3	324	0.077
107539	K2	295.1	0.059
107539	M8	193.5	0.006
107539	MS4	108.9	0.022
107540	M2	277.3	0.722
107540	S2	299.4	0.173
107540	N2	247.8	0.124
107540	K1	188.5	0.303
107540	M4	105.3	0.048
107540	O1	161.2	0.189
107540	M6	297.3	0.021
107540	MK3	21.7	0.063
107540	S4	142	0.005
107540	MN4	120.5	0.016
107540	S6	46.4	0.002
107540	2N2	28.1	0.015
107540	OO1	226	0.035
107540	M1	111.9	0.003
107540	J1	235.7	0.006
107540	Q1	103.9	0.015
107540	2Q1	149.3	0.014
107540	P1	178	0.078
107540	2SM2	337.4	0.007
107540	M3	71.2	0.011
107540	L2	350.9	0.027
107540	2MK3	344.3	0.035
107540	K2	284.7	0.019
107540	M8	166.9	0.006
107540	MS4	172.5	0.034
107541	M2	274.6	0.751
107541	S2	296.3	0.166
107541	N2	238.2	0.133
107541	K1	183.3	0.329
107541	M4	153.1	0.079
107541	O1	145.1	0.204
107541	M6	83.2	0.006
107541	MK3	59.6	0.091
107541	S4	87.8	0.005
107541	MN4	104.9	0.03
107541	2N2	284.5	0.018
107541	OO1	231.3	0.023
107541	M1	208.5	0.014
107541	J1	204.9	0.016
107541	Q1	136.8	0.025
107541	2Q1	92.3	0.012
107541	P1	173.7	0.098
107541	2SM2	212.1	0.007
107541	M3	58.6	0.012
107541	L2	337.3	0.021
107541	2MK3	345	0.043
107541	K2	247.3	0.036
107541	M8	218.8	0.006
107541	MS4	178.5	0.027
107542	M2	296	0.273
107542	S2	310.8	0.076
107542	N2	245.3	0.042
107542	K1	202.2	0.146
107542	M4	318.8	0.033
107542	O1	164	0.101
107542	M6	230.6	0.017
107542	MK3	256.6	0.011
107542	S4	105.6	0.002
107542	MN4	275.4	0.021
107542	S6	97.5	0.002
107542	2N2	314.7	0.016
107542	OO1	279.4	0.019
107542	M1	244.6	0.022
107542	J1	240.4	0.003
107542	Q1	170.7	0.029
107542	2Q1	224.9	0.011
107542	P1	200.1	0.026
107542	2SM2	188.4	0.01
107542	M3	118.8	0.009
107542	L2	42.6	0.026
107542	2MK3	269.4	0.016
107542	K2	301.7	0.033
107542	M8	252.3	0.002
107542	MS4	10.5	0.008
107543	M2	296	0.313
107543	S2	324.2	0.072
107543	N2	242.2	0.06
107543	K1	199.1	0.158
107543	M4	307.9	0.007
107543	O1	163.6	0.11
107543	M6	261.9	0.015
107543	MK3	339.7	0.009
107543	S4	37.7	0.003
107543	MN4	206.7	0.007
107543	S6	168.7	0.002
107543	2N2	326.5	0.021
107543	OO1	231	0.035
107543	M1	222.1	0.014
107543	J1	192.1	0.01
107543	Q1	144	0.025
107543	2Q1	154.8	0.019
107543	P1	167.7	0.042
107543	2SM2	226.8	0.003
107543	M3	32.6	0.011
107543	L2	122.2	0.009
107543	2MK3	335.4	0.022
107543	K2	314.9	0.011
107543	M8	160.4	0.003
107543	MS4	259.3	0.013
107544	M2	294	0.332
107544	S2	313.8	0.099
107544	N2	236.9	0.027
107544	K1	206.1	0.134
107544	M4	144.5	0.039
107544	O1	207.2	0.061
107544	M6	311.3	0.012
107544	MK3	351.7	0.026
107544	S4	156	0.006
107544	MN4	123	0.024
107544	S6	336.5	0.003
107544	2N2	63.9	0.006
107544	OO1	252.5	0.035
107544	M1	341.8	0.015
107544	J1	110	0.018
107544	Q1	294.6	0.006
107544	2Q1	230.3	0.016
107544	P1	164.3	0.061
107544	2SM2	298.3	0.004
107544	M3	313.1	0.022
107544	L2	4.2	0.025
107544	2MK3	232.8	0.009
107544	K2	351.8	0.044
107544	M8	186.2	0.004
107544	MS4	230	0.013
107545	M2	286.8	0.471
107545	S2	310.6	0.305
107545	N2	250.4	0.187
107545	K1	201.3	0.233
107545	M4	283.8	0.052
107545	O1	107.7	0.117
107545	M6	286.5	0.074
107545	MK3	136.2	0.151
107545	S4	99.7	0.054
107545	MN4	321.4	0.045
107545	S6	28.4	0.004
107545	2N2	62.7	0.124
107545	OO1	7.3	0.063
107545	M1	96.6	0.03
107545	J1	156.1	0.059
107545	Q1	311	0.027
107545	2Q1	119.6	0.076
107545	P1	147.2	0.043
107545	2SM2	77	0.031
107545	M3	193.1	0.064
107545	L2	191.7	0.046
107545	2MK3	69.9	0.141
107545	K2	277.2	0.118
107545	M8	265.5	0.051
107545	MS4	337.4	0.092
107546	M2	293.3	0.901
107546	S2	316.8	0.175
107546	N2	258.3	0.118
107546	K1	190.4	0.344
107546	M4	54.6	0.048
107546	O1	188.5	0.141
107546	M6	277	0.014
107546	MK3	268.9	0.068
107546	MN4	345.7	0.006
107546	S6	250.1	0.011
107546	2N2	289.4	0.047
107546	OO1	291.3	0.031
107546	M1	231.7	0.015
107546	J1	172.2	0.012
107546	Q1	225.2	0.031
107546	2Q1	4.1	0.022
107546	P1	195.3	0.093
107546	2SM2	243	0.023
107546	M3	270.3	0.018
107546	L2	11.9	0.02
107546	2MK3	94	0.012
107546	K2	252.7	0.046
107546	M8	290.2	0.009
107546	MS4	45.7	0.034
107547	M2	293.2	0.896
107547	S2	317.5	0.198
107547	N2	256.6	0.117
107547	K1	195.7	0.344
107547	M4	66.5	0.061
107547	O1	191.2	0.14
107547	M6	166.1	0.009
107547	MK3	272.7	0.096
107547	S4	126.7	0.011
107547	MN4	57.1	0.011
107547	S6	232.6	0.008
107547	2N2	296.4	0.047
107547	OO1	286.4	0.035
107547	M1	250.3	0.015
107547	J1	173	0.026
107547	Q1	193.5	0.037
107547	2Q1	337.5	0.024
107547	P1	189.7	0.088
107547	2SM2	250.9	0.024
107547	M3	260	0.017
107547	L2	31.5	0.043
107547	2MK3	346.8	0.015
107547	K2	274	0.054
107547	M8	253.8	0.008
107547	MS4	61.2	0.022
107548	M2	292.1	0.874
107548	S2	326.3	0.178
107548	N2	272.9	0.173
107548	K1	196.4	0.473
107548	M4	223.8	0.114
107548	O1	163.3	0.408
107548	M6	184.9	0.066
107548	MK3	191.9	0.037
107548	S4	107	0.018
107548	MN4	181.6	0.046
107548	S6	178.2	0.004
107548	2N2	243.4	0.036
107548	OO1	229.5	0.082
107548	M1	237.7	0.069
107548	J1	275.8	0.047
107548	Q1	169	0.074
107548	2Q1	61.7	0.07
107548	P1	194.5	0.177
107548	2SM2	156.2	0.022
107548	M3	289.9	0.048
107548	L2	277.4	0.011
107548	2MK3	160.8	0.109
107548	K2	316.3	0.146
107548	M8	125.9	0.044
107548	MS4	167	0.022
107549	M2	298.5	0.79
107549	S2	339	0.186
107549	N2	263.2	0.11
107549	K1	207.7	0.425
107549	M4	54.6	0.084
107549	O1	160.4	0.391
107549	M6	124	0.046
107549	MK3	266.4	0.14
107549	S4	82.8	0.012
107549	MN4	29.1	0.03
107549	S6	48.8	0.005
107549	2N2	188.7	0.05
107549	OO1	184.1	0.138
107549	M1	197.4	0.037
107549	J1	258.5	0.058
107549	Q1	138.3	0.121
107549	2Q1	298.5	0.073
107549	P1	187.1	0.176
107549	2SM2	15	0.012
107549	M3	289.2	0.011
107549	L2	359.3	0.026
107549	2MK3	200.1	0.05
107549	K2	275.9	0.086
107549	M8	118.6	0.01
107549	MS4	41.9	0.031
107550	M2	298.8	0.759
107550	S2	337.9	0.166
107550	N2	254.9	0.105
107550	K1	209.5	0.414
107550	M4	35.9	0.101
107550	O1	158.9	0.381
107550	M6	98.6	0.043
107550	MK3	272.6	0.155
107550	S4	61.8	0.015
107550	MN4	358.6	0.024
107550	S6	55	0.003
107550	2N2	190.9	0.054
107550	OO1	170.1	0.164
107550	M1	197.1	0.033
107550	J1	269.8	0.061
107550	Q1	139.2	0.126
107550	2Q1	298	0.082
107550	P1	182.8	0.149
107550	2SM2	340.9	0.012
107550	M3	287.3	0.005
107550	L2	1.7	0.033
107550	2MK3	201	0.068
107550	K2	277.3	0.083
107550	M8	150.3	0.002
107550	MS4	43.9	0.041
107551	M2	271.1	0.554
107551	S2	299.2	0.187
107551	N2	238.6	0.143
107551	K1	171	0.191
107551	M4	62.4	0.117
107551	O1	93.2	0.14
107551	M6	308	0.018
107551	MK3	305	0.074
107551	S4	47.7	0.006
107551	MN4	31.6	0.059
107551	NU2	241.5	0.025
107551	S6	355.3	0.005
107551	MU2	176.4	0.041
107551	2N2	57	0.023
107551	OO1	161.6	0.055
107551	LDA2	34.3	0.011
107551	M1	254.4	0.018
107551	J1	62.1	0.004
107551	RHO1	49.6	0.002
107551	Q1	297.9	0.014
107551	2Q1	118.4	0.027
107551	P1	144.5	0.056
107551	2SM2	194.2	0.006
107551	M3	320.4	0.038
107551	L2	48.2	0.019
107551	2MK3	341.5	0.022
107551	K2	200.5	0.019
107551	M8	308.3	0.012
107551	MS4	86.3	0.052
107552	M2	284	0.723
107552	S2	305.1	0.167
107552	N2	247.3	0.138
107552	K1	194.1	0.325
107552	M4	196.9	0.071
107552	O1	189.3	0.233
107552	M6	58.8	0.042
107552	MK3	56.6	0.1
107552	S4	296.8	0.001
107552	MN4	151.7	0.039
107552	NU2	266.5	0.016
107552	S6	91.4	0.007
107552	MU2	152.9	0.028
107552	2N2	252.1	0.02
107552	LDA2	324.3	0.02
107552	M1	210.7	0.007
107552	J1	232.2	0.014
107552	RHO1	167.6	0.01
107552	Q1	140.8	0.044
107552	2Q1	335.6	0.011
107552	P1	193.9	0.096
107552	2SM2	126.3	0.004
107552	M3	91	0.02
107552	L2	314.5	0.039
107552	2MK3	318.7	0.044
107552	K2	325.1	0.072
107552	M8	1.5	0.011
107552	MS4	216.5	0.055
107553	M2	286.5	0.746
107553	S2	314.8	0.148
107553	N2	262.8	0.149
107553	K1	207.3	0.326
107553	M4	199.3	0.131
107553	O1	202.9	0.208
107553	M6	55.6	0.03
107553	MK3	52.7	0.087
107553	S4	337.5	0.005
107553	MN4	162.5	0.044
107553	NU2	250.5	0.04
107553	S6	98	0.007
107553	2N2	209.6	0.023
107553	OO1	210	0.02
107553	LDA2	329.9	0.017
107553	M1	180.1	0.009
107553	J1	232.4	0.018
107553	RHO1	126.1	0.013
107553	Q1	168.3	0.03
107553	2Q1	318.9	0.007
107553	P1	214.2	0.112
107553	2SM2	60.5	0.01
107553	M3	138.2	0.018
107553	L2	309.1	0.052
107553	2MK3	287	0.025
107553	K2	321.3	0.051
107553	M8	30	0.017
107553	MS4	215.8	0.057
107554	M2	291.1	0.308
107554	S2	307.3	0.074
107554	N2	270.5	0.037
107554	K1	204.5	0.112
107554	M4	265.3	0.017
107554	O1	196.7	0.061
107554	M6	236.8	0.01
107554	MK3	96.6	0.006
107554	S4	51	0.001
107554	MN4	263.4	0.01
107554	S6	112.1	0.003
107554	2N2	158.2	0.005
107554	OO1	320.9	0.002
107554	M1	14.3	0.003
107554	J1	197.8	0.005
107554	Q1	316.7	0.012
107554	2Q1	100.9	0.002
107554	P1	200.7	0.032
107554	2SM2	280.7	0.008
107554	M3	258.5	0.01
107554	L2	359.9	0.012
107554	2MK3	265.9	0.007
107554	K2	303.6	0.032
107554	M8	356.2	0.004
107554	MS4	6.6	0.005
107555	M2	295.9	0.315
107555	S2	321	0.058
107555	N2	270.7	0.068
107555	K1	206	0.149
107555	M4	14.5	0.024
107555	O1	174.4	0.1
107555	M6	266.2	0.018
107555	MK3	302.6	0.015
107555	S4	99.7	0.011
107555	MN4	303.4	0.008
107555	S6	149.5	0.001
107555	2N2	316.8	0.006
107555	OO1	185.4	0.002
107555	M1	181.1	0.005
107555	J1	216.1	0.023
107555	Q1	171.1	0.02
107555	2Q1	37	0.005
107555	P1	205.7	0.062
107555	2SM2	98.6	0.009
107555	M3	132.9	0.006
107555	L2	301.5	0.005
107555	2MK3	301.3	0.012
107555	K2	269.8	0.023
107555	M8	222.7	0.002
107555	MS4	50.4	0.002
107556	M2	303.5	0.299
107556	S2	338.4	0.075
107556	N2	267.4	0.073
107556	K1	194.9	0.154
107556	M4	22.5	0.036
107556	O1	161.2	0.111
107556	M6	272.2	0.025
107556	MK3	331.1	0.033
107556	S4	85.2	0.001
107556	MN4	324.1	0.008
107556	S6	261.3	0.003
107556	2N2	349.5	0.017
107556	OO1	241	0.021
107556	M1	206.5	0.017
107556	J1	259.4	0.019
107556	Q1	168.4	0.028
107556	2Q1	255.2	0.008
107556	P1	193.1	0.079
107556	2SM2	61.8	0.006
107556	M3	90.8	0.021
107556	L2	21.1	0.016
107556	2MK3	324	0.023
107556	K2	286.1	0.017
107556	M8	230.9	0.006
107556	MS4	253.1	0.012
107557	M2	298.4	1.746
107557	S2	321	0.402
107557	N2	264.6	0.33
107557	K1	199.2	0.695
107557	M4	167.1	0.061
107557	O1	178.3	0.344
107557	M6	97.1	0.025
107557	MK3	346.8	0.091
107557	S4	68	0.007
107557	MN4	117.7	0.016
107557	NU2	282.6	0.062
107557	MU2	142.7	0.077
107557	2N2	197.4	0.014
107557	OO1	284	0.045
107557	LDA2	356.1	0.037
107557	M1	255.2	0.026
107557	J1	180.2	0.023
107557	RHO1	139.9	0.02
107557	Q1	179.9	0.034
107557	2Q1	256.7	0.014
107557	P1	196.6	0.207
107557	2SM2	290.4	0.004
107557	M3	50.4	0.031
107557	L2	345.6	0.112
107557	2MK3	302.5	0.093
107557	K2	339.9	0.105
107557	M8	307.9	0.007
107557	MS4	197.8	0.011
107558	M2	297.2	1.796
107558	S2	324.6	0.432
107558	N2	259.8	0.363
107558	K1	189.3	0.7
107558	M4	294.2	0.162
107558	O1	165.5	0.358
107558	M6	94.2	0.019
107558	MK3	159.4	0.057
107558	S4	125.3	0.012
107558	MN4	236.8	0.041
107558	NU2	255.5	0.058
107558	S6	30.3	0.006
107558	MU2	176.1	0.078
107558	2N2	225.4	0.034
107558	OO1	235.5	0.054
107558	LDA2	4.9	0.05
107558	M1	240.1	0.045
107558	J1	232.3	0.018
107558	RHO1	158.5	0.025
107558	Q1	187	0.054
107558	2Q1	180.5	0.019
107558	P1	193.2	0.172
107558	2SM2	262.8	0.02
107558	M3	306.3	0.015
107558	L2	351.4	0.091
107558	2MK3	274.6	0.049
107558	K2	325	0.099
107558	M8	348.7	0.019
107558	MS4	331.2	0.049
107559	M2	294.3	1.542
107559	S2	323.3	0.401
107559	N2	256	0.328
107559	K1	180.9	0.646
107559	M4	300.2	0.253
107559	O1	149.1	0.294
107559	M6	116.2	0.053
107559	MK3	193	0.154
107559	S4	117.7	0.014
107559	MN4	251.7	0.074
107559	NU2	259.5	0.049
107559	S6	68.7	0.003
107559	MU2	199	0.069
107559	2N2	210.5	0.052
107559	OO1	224.5	0.039
107559	LDA2	23.7	0.055
107559	M1	216.8	0.05
107559	J1	255.3	0.038
107559	RHO1	165.2	0.021
107559	Q1	187.2	0.042
107559	2Q1	135.3	0.026
107559	P1	190	0.143
107559	2SM2	272.6	0.021
107559	M3	296.8	0.032
107559	L2	344.4	0.059
107559	2MK3	240.5	0.035
107559	K2	311.8	0.075
107559	M8	328.2	0.033
107559	MS4	333.5	0.091
107560	M2	274.7	0.99
107560	S2	303.9	0.186
107560	N2	242.2	0.147
107560	K1	180.1	0.2
107560	M4	207.9	0.083
107560	O1	191.1	0.073
107560	M6	260.7	0.032
107560	MK3	45.6	0.086
107560	S4	268.3	0.007
107560	MN4	188.9	0.038
107560	S6	246.6	0.01
107560	2N2	250.6	0.053
107560	OO1	189.7	0.053
107560	M1	230.9	0.01
107560	J1	323.8	0.029
107560	Q1	214.3	0.008
107560	2Q1	339.1	0.036
107560	P1	166.3	0.071
107560	2SM2	122.2	0.016
107560	M3	248.8	0.012
107560	L2	314.4	0.049
107560	2MK3	285.3	0.054
107560	K2	259.7	0.043
107560	M8	99.4	0.03
107560	MS4	127.4	0.04
107561	M2	283.6	0.888
107561	S2	300.7	0.22
107561	N2	248.3	0.142
107561	K1	186.9	0.392
107561	M4	279.5	0.033
107561	O1	160.3	0.207
107561	M6	332.2	0.023
107561	MK3	133.5	0.075
107561	S4	55.7	0.004
107561	MN4	228	0.036
107561	S6	172.3	0.008
107561	2N2	311.8	0.067
107561	OO1	336.2	0.058
107561	M1	51.7	0.025
107561	J1	178.5	0.035
107561	Q1	33.4	0.025
107561	2Q1	171.8	0.02
107561	P1	178.9	0.073
107561	2SM2	215.4	0.01
107561	M3	176.2	0.041
107561	L2	2.9	0.052
107561	2MK3	39.5	0.069
107561	K2	261.7	0.062
107561	M8	143.7	0.02
107561	MS4	251.4	0.035
107562	M2	290.3	0.904
107562	S2	281.4	0.189
107562	N2	235.4	0.088
107562	K1	193.2	0.394
107562	M4	299	0.04
107562	O1	205.8	0.185
107562	M6	316.5	0.026
107562	MK3	126.5	0.043
107562	S4	353.7	0.025
107562	MN4	299.4	0.03
107562	S6	235.8	0.006
107562	2N2	290.4	0.094
107562	OO1	308	0.094
107562	M1	14.4	0.046
107562	J1	181.6	0.028
107562	Q1	14.5	0.022
107562	2Q1	207	0.018
107562	P1	220.7	0.078
107562	2SM2	43.5	0.006
107562	M3	180	0.044
107562	L2	352.2	0.083
107562	2MK3	24.2	0.061
107562	K2	251.8	0.128
107562	M8	132.5	0.029
107562	MS4	287.3	0.025
107563	M2	276.9	0.396
107563	S2	328.4	0.098
107563	N2	233.8	0.094
107563	K1	169.9	0.13
107563	M4	27.4	0.048
107563	O1	107.6	0.08
107563	M6	247.7	0.011
107563	MK3	254.4	0.047
107563	S4	185.1	0.007
107563	MN4	309.5	0.017
107563	S6	26.4	0.001
107563	2N2	315.7	0.02
107563	OO1	3.5	0.011
107563	M1	85.9	0.019
107563	J1	203.2	0.028
107563	Q1	25	0.024
107563	2Q1	68.3	0.004
107563	P1	165	0.029
107563	2SM2	192.4	0.004
107563	M3	182	0.018
107563	L2	202.6	0.008
107563	2MK3	4.1	0.007
107563	M8	44.7	0.004
107563	MS4	49.3	0.015
107564	M2	274.4	0.313
107564	S2	326	0.07
107564	N2	237.2	0.071
107564	K1	190.6	0.104
107564	M4	17.8	0.056
107564	O1	132.2	0.032
107564	M6	146.3	0.014
107564	MK3	261.8	0.04
107564	S4	176.2	0.005
107564	MN4	326.2	0.016
107564	S6	45	0.004
107564	2N2	307.6	0.013
107564	OO1	76.6	0.012
107564	M1	8.7	0.006
107564	J1	205	0.03
107564	Q1	301.4	0.012
107564	2Q1	303.9	0.003
107564	P1	223.9	0.032
107564	2SM2	231.8	0.001
107564	M3	145.3	0.012
107564	L2	294.5	0.009
107564	2MK3	282.8	0.007
107564	M8	8.5	0.012
107564	MS4	51.9	0.022
107565	M2	269.8	0.225
107565	S2	301.2	0.063
107565	N2	241.3	0.062
107565	K1	192	0.107
107565	M4	323	0.027
107565	O1	169.1	0.058
107565	M6	80.4	0.015
107565	MK3	246.7	0.032
107565	S4	273.8	0.007
107565	MN4	252.1	0.016
107565	S6	100.3	0.003
107565	2N2	163.8	0.003
107565	OO1	356.5	0.018
107565	M1	318.7	0.012
107565	J1	232.3	0.022
107565	Q1	207.9	0.017
107565	2Q1	25	0.006
107565	P1	217.4	0.051
107565	2SM2	13.7	0.01
107565	M3	196	0.004
107565	L2	288.4	0.009
107565	2MK3	280.3	0.009
107565	M8	298.1	0.008
107565	MS4	282.1	0.027
107566	M2	229.2	2.463
107566	S2	257.5	0.523
107566	N2	186.4	0.217
107566	K1	156	0.294
107566	M4	74.7	0.376
107566	O1	221.9	0.148
107566	M6	159.7	0.191
107566	MK3	311.3	0.263
107566	S4	11.5	0.008
107566	MN4	18.4	0.102
107566	S6	61.8	0.008
107566	2N2	227.4	0.185
107566	OO1	183.8	0.126
107566	M1	223.8	0.039
107566	J1	321.7	0.046
107566	Q1	199.1	0.045
107566	2Q1	306.1	0.03
107566	P1	137.4	0.144
107566	2SM2	71.1	0.036
107566	M3	334.6	0.039
107566	L2	285	0.253
107566	2MK3	227.2	0.092
107566	K2	282.4	0.191
107566	M8	30.9	0.068
107566	MS4	115.7	0.126
107567	M2	229.8	3.084
107567	S2	251.6	0.588
107567	N2	184.2	0.351
107567	K1	157.1	0.365
107567	M4	80.3	0.46
107567	O1	222.4	0.182
107567	M6	155.5	0.249
107567	MK3	310.3	0.321
107567	S4	64.7	0.021
107567	MN4	29.6	0.142
107567	S6	14.1	0.006
107567	2N2	214.9	0.196
107567	OO1	186.1	0.125
107567	M1	225.7	0.041
107567	J1	301.8	0.045
107567	Q1	203.6	0.059
107567	2Q1	305.6	0.033
107567	P1	132.5	0.152
107567	2SM2	105.9	0.011
107567	M3	346.1	0.04
107567	L2	278.5	0.222
107567	2MK3	217.7	0.095
107567	K2	252.3	0.177
107567	M8	27.1	0.087
107567	MS4	114.6	0.167
107568	M2	268.5	1.393
107568	S2	286.1	0.313
107568	N2	230.3	0.232
107568	K1	172.6	0.396
107568	M4	200.9	0.057
107568	O1	153.1	0.179
107568	M6	190.6	0.082
107568	MK3	351.5	0.169
107568	S4	189	0.014
107568	MN4	60.1	0.022
107568	S6	26.5	0.007
107568	2N2	294.2	0.056
107568	OO1	177.6	0.036
107568	M1	173.4	0.018
107568	J1	299	0.021
107568	Q1	126.6	0.035
107568	2Q1	145.1	0.007
107568	P1	143.3	0.117
107568	2SM2	296.5	0.01
107568	M3	284.3	0.015
107568	L2	336.6	0.07
107568	2MK3	291.2	0.093
107568	K2	285.4	0.118
107568	M8	151.9	0.017
107568	MS4	182.8	0.057
107569	M2	271.6	1.912
107569	S2	287.8	0.447
107569	N2	230	0.346
107569	K1	167.6	0.637
107569	M4	210.1	0.18
107569	O1	142.5	0.339
107569	M6	173.4	0.14
107569	MK3	19.6	0.247
107569	S4	168.2	0.023
107569	MN4	152	0.065
107569	S6	71.9	0.007
107569	2N2	316.6	0.093
107569	OO1	230.4	0.054
107569	M1	238.7	0.028
107569	J1	338.5	0.014
107569	Q1	143.7	0.041
107569	2Q1	97.6	0.031
107569	P1	152.2	0.149
107569	2SM2	278.3	0.005
107569	M3	276	0.034
107569	L2	342.9	0.069
107569	2MK3	320.4	0.174
107569	K2	288.2	0.126
107569	M8	171.3	0.022
107569	MS4	212	0.127
107570	M2	272.3	1.854
107570	S2	285.4	0.425
107570	N2	225.7	0.326
107570	K1	173	0.689
107570	M4	201.7	0.28
107570	O1	143.5	0.379
107570	M6	167.8	0.183
107570	MK3	31.4	0.319
107570	S4	187.9	0.02
107570	MN4	154.9	0.099
107570	S6	127.7	0.012
107570	2N2	317.2	0.1
107570	OO1	260.4	0.06
107570	M1	243.6	0.026
107570	J1	201.9	0.017
107570	Q1	164.6	0.04
107570	2Q1	95.4	0.034
107570	P1	157.6	0.136
107570	2SM2	139.4	0.011
107570	M3	283.1	0.03
107570	L2	342.4	0.066
107570	2MK3	330.6	0.199
107570	K2	289.7	0.12
107570	M8	166.7	0.021
107570	MS4	220	0.169
107571	M2	286.9	1.933
107571	S2	319.7	0.424
107571	N2	259.5	0.358
107571	K1	194.9	0.694
107571	M4	104.6	0.128
107571	O1	189.7	0.331
107571	M6	16.5	0.026
107571	MK3	313.4	0.17
107571	S4	33.4	0.006
107571	MN4	60.1	0.045
107571	NU2	277.6	0.082
107571	S6	17.7	0.004
107571	MU2	135.7	0.032
107571	2N2	200.7	0.041
107571	OO1	123.7	0.015
107571	LDA2	327.9	0.018
107571	M1	144.7	0.019
107571	J1	222.4	0.069
107571	RHO1	269.5	0.029
107571	Q1	139.5	0.06
107571	2Q1	52.6	0.012
107571	P1	188.9	0.258
107571	2SM2	188.5	0.003
107571	M3	44.5	0.015
107571	L2	319.4	0.112
107571	2MK3	269.1	0.13
107571	K2	312.9	0.154
107571	M8	208.1	0.032
107571	MS4	109.3	0.034
107572	M2	293	1.991
107572	S2	317.3	0.528
107572	N2	258.8	0.43
107572	K1	194	0.849
107572	M4	201.7	0.05
107572	O1	169.1	0.408
107572	M6	317.7	0.017
107572	MK3	24.2	0.125
107572	S4	97.5	0.013
107572	MN4	120.4	0.02
107572	NU2	296.4	0.056
107572	S6	312.5	0.005
107572	MU2	179.2	0.073
107572	2N2	275.4	0.029
107572	OO1	264.6	0.048
107572	LDA2	318.7	0.02
107572	M1	234.4	0.029
107572	J1	224.9	0.04
107572	RHO1	162.6	0.078
107572	Q1	190.9	0.069
107572	2Q1	118.9	0.024
107572	P1	194.9	0.233
107572	2SM2	138.7	0.029
107572	M3	275.7	0.014
107572	L2	352.1	0.071
107572	2MK3	342.2	0.118
107572	K2	339.6	0.148
107572	M8	319.3	0.014
107572	MS4	235.9	0.013
107573	M2	293.5	1.974
107573	S2	317.6	0.526
107573	N2	260.3	0.441
107573	K1	193.4	0.849
107573	M4	210	0.069
107573	O1	168.8	0.416
107573	M6	283.1	0.012
107573	MK3	42.2	0.183
107573	S4	108.9	0.022
107573	MN4	168	0.027
107573	NU2	301.1	0.051
107573	S6	268.8	0.004
107573	MU2	196.1	0.073
107573	2N2	285.3	0.034
107573	OO1	277.9	0.053
107573	LDA2	357.4	0.018
107573	M1	233.2	0.04
107573	J1	250.6	0.027
107573	RHO1	149.6	0.068
107573	Q1	193.1	0.073
107573	2Q1	122.6	0.032
107573	P1	195.2	0.232
107573	2SM2	150.3	0.022
107573	M3	233.9	0.014
107573	L2	351.4	0.061
107573	2MK3	356.6	0.159
107573	K2	342.1	0.138
107573	M8	336.5	0.017
107573	MS4	257.6	0.031
107574	M2	280.1	2.252
107574	S2	305.1	0.472
107574	N2	245.2	0.327
107574	K1	190.4	0.744
107574	M4	255.1	0.039
107574	O1	161.2	0.433
107574	M6	251.1	0.098
107574	MK3	329.6	0.015
107574	S4	181.2	0.01
107574	MN4	191.5	0.037
107574	S6	49.7	0.005
107574	2N2	263.7	0.06
107574	OO1	235	0.117
107574	M1	232.9	0.035
107574	J1	140.7	0.013
107574	Q1	180.4	0.061
107574	2Q1	304.9	0.016
107574	P1	179.3	0.239
107574	2SM2	214.9	0.014
107574	M3	3.6	0.045
107574	L2	343.9	0.074
107574	2MK3	244.5	0.07
107574	K2	280.5	0.146
107574	M8	163.4	0.025
107574	MS4	96.6	0.028
107575	M2	280.5	2.249
107575	S2	302.4	0.486
107575	N2	241.3	0.336
107575	K1	186.3	0.818
107575	M4	208.7	0.068
107575	O1	154	0.528
107575	M6	273.4	0.022
107575	MK3	237.7	0.041
107575	S4	106.7	0.02
107575	MN4	144.7	0.036
107575	S6	78.7	0.01
107575	2N2	288.1	0.104
107575	OO1	226.3	0.126
107575	M1	254.5	0.064
107575	J1	60.2	0.019
107575	Q1	178.2	0.046
107575	2Q1	83.7	0.035
107575	P1	178.4	0.214
107575	2SM2	241.7	0.022
107575	M3	343.4	0.022
107575	L2	355	0.108
107575	2MK3	241.5	0.029
107575	K2	279.5	0.132
107575	M8	74.5	0.009
107575	MS4	118.1	0.046
107576	M2	280.8	2.226
107576	S2	300.9	0.492
107576	N2	243.6	0.326
107576	K1	184.8	0.786
107576	M4	218.3	0.074
107576	O1	158	0.512
107576	M6	345.1	0.013
107576	MK3	211.6	0.042
107576	S4	94.6	0.024
107576	MN4	141.6	0.038
107576	S6	109.3	0.01
107576	2N2	281.8	0.104
107576	OO1	231.8	0.188
107576	M1	247.9	0.082
107576	J1	53	0.033
107576	Q1	203.2	0.077
107576	2Q1	66.2	0.073
107576	P1	183.6	0.204
107576	2SM2	223.2	0.007
107576	M3	328.6	0.018
107576	L2	347.9	0.115
107576	2MK3	213.2	0.016
107576	K2	285	0.157
107576	M8	74.3	0.023
107576	MS4	110.2	0.058
107577	M2	295	0.273
107577	S2	326.4	0.062
107577	N2	257.8	0.047
107577	K1	220.9	0.14
107577	M4	16.7	0.018
107577	O1	172.4	0.048
107577	M6	251.9	0.011
107577	MK3	310.3	0.023
107577	S4	115.8	0.002
107577	MN4	331.1	0.012
107577	S6	195.4	0.003
107577	2N2	53.3	0.006
107577	OO1	211.8	0.01
107577	M1	237.2	0.006
107577	J1	131.7	0.008
107577	Q1	235.1	0.003
107577	2Q1	36.2	0.003
107577	2SM2	19	0.008
107577	M3	213.3	0.002
107577	L2	29.4	0.014
107577	2MK3	327.5	0.015
107577	M8	278.9	0.002
107577	MS4	14.9	0.005
107578	M2	302.7	0.364
107578	S2	329.5	0.064
107578	N2	257.3	0.055
107578	K1	193.5	0.143
107578	M4	291.1	0.011
107578	O1	168.3	0.079
107578	M6	217.8	0.004
107578	MK3	350.6	0.021
107578	S4	140	0.003
107578	MN4	229.4	0.006
107578	S6	335.7	0.002
107578	2N2	331.9	0.015
107578	OO1	209	0.025
107578	M1	199.3	0.008
107578	J1	336.9	0.006
107578	Q1	208.1	0.013
107578	2Q1	32.1	0.005
107578	2SM2	259	0.005
107578	M3	23.8	0.011
107578	L2	46.2	0.011
107578	2MK3	261.9	0.016
107578	M8	290.1	0.002
107578	MS4	216.8	0.006
107579	M2	304.5	0.407
107579	S2	333	0.083
107579	N2	265.3	0.062
107579	K1	184.2	0.167
107579	M4	264.5	0.024
107579	O1	162	0.08
107579	M6	165.6	0.005
107579	MK3	37.8	0.017
107579	S4	233.4	0.005
107579	MN4	216.2	0.018
107579	S6	131.2	0.001
107579	2N2	331.9	0.017
107579	OO1	216	0.026
107579	M1	184	0.007
107579	J1	283.8	0.006
107579	Q1	118.3	0.016
107579	2Q1	195.1	0.002
107579	2SM2	81.8	0.005
107579	M3	345.8	0.003
107579	L2	26.2	0.024
107579	2MK3	278.4	0.017
107579	M8	81.8	0.003
107579	MS4	240.1	0.014
107580	M2	279.3	2.35
107580	S2	300.4	0.522
107580	N2	238.7	0.342
107580	K1	188.8	0.783
107580	M4	5.3	0.123
107580	O1	160.8	0.448
107580	M6	304.3	0.087
107580	MK3	259.9	0.164
107580	S4	40.9	0.034
107580	MN4	325.4	0.046
107580	S6	154.1	0.005
107580	2N2	270.6	0.101
107580	OO1	196.9	0.097
107580	M1	200.3	0.039
107580	J1	228.5	0.054
107580	Q1	155	0.083
107580	2Q1	334.1	0.01
107580	P1	182.3	0.247
107580	2SM2	179.7	0.014
107580	M3	279.5	0.021
107580	L2	340.1	0.096
107580	2MK3	222.1	0.105
107580	K2	272	0.222
107580	M8	248.8	0.024
107580	MS4	66.8	0.092
107581	M2	281.7	2.625
107581	S2	305.6	0.572
107581	N2	246.4	0.39
107581	K1	185.5	0.976
107581	M4	313.3	0.058
107581	O1	149.8	0.578
107581	M6	242.5	0.059
107581	MK3	222.8	0.176
107581	S4	9.5	0.042
107581	MN4	294	0.032
107581	S6	118.9	0.013
107581	2N2	233.3	0.092
107581	OO1	196	0.155
107581	M1	216.5	0.056
107581	J1	248.4	0.052
107581	Q1	145.2	0.099
107581	2Q1	96.6	0.017
107581	P1	189.8	0.327
107581	2SM2	177.9	0.042
107581	M3	255.7	0.044
107581	L2	335.8	0.093
107581	2MK3	173.5	0.08
107581	K2	271	0.283
107581	M8	209.1	0.05
107581	MS4	37.1	0.104
107582	M2	285.8	2.736
107582	S2	310	0.594
107582	N2	252.8	0.418
107582	K1	190.8	1.125
107582	M4	242.7	0.026
107582	O1	151.4	0.66
107582	M6	221.6	0.061
107582	MK3	197.7	0.187
107582	S4	357.2	0.033
107582	MN4	242.7	0.019
107582	S6	117	0.014
107582	2N2	199	0.083
107582	OO1	189.1	0.178
107582	M1	226	0.061
107582	J1	240.1	0.057
107582	Q1	149.6	0.119
107582	2Q1	95.4	0.027
107582	P1	194.9	0.368
107582	2SM2	170.5	0.041
107582	M3	227.9	0.057
107582	L2	345.5	0.092
107582	2MK3	114.8	0.1
107582	K2	271.9	0.284
107582	M8	172.9	0.059
107582	MS4	11.1	0.129
107583	M2	298.1	2.075
107583	S2	317.9	0.593
107583	N2	257.9	0.419
107583	K1	194	0.99
107583	M4	277.1	0.172
107583	O1	154.8	0.612
107583	M6	191.8	0.08
107583	MK3	143.8	0.175
107583	S4	207	0.009
107583	MN4	222.9	0.08
107583	S6	220.3	0.007
107583	2N2	358.9	0.137
107583	OO1	282.5	0.137
107583	M1	234.7	0.038
107583	J1	145	0.011
107583	Q1	104.6	0.013
107583	2Q1	111.1	0.086
107583	P1	173	0.239
107583	2SM2	264.1	0.012
107583	M3	205	0.031
107583	L2	33	0.047
107583	2MK3	33.5	0.078
107583	K2	313.3	0.186
107583	M8	148.3	0.02
107583	MS4	245.6	0.085
107584	M2	295.9	2.263
107584	S2	318	0.649
107584	N2	259.2	0.452
107584	K1	192.8	1.068
107584	M4	275.2	0.124
107584	O1	155.7	0.673
107584	M6	206.6	0.096
107584	MK3	120.5	0.188
107584	S4	313.3	0.015
107584	MN4	218.7	0.076
107584	S6	125.4	0.007
107584	2N2	350.9	0.096
107584	OO1	266.3	0.146
107584	M1	222.9	0.045
107584	J1	188	0.024
107584	Q1	147.1	0.029
107584	2Q1	98.5	0.079
107584	P1	178.5	0.257
107584	2SM2	196.7	0.023
107584	M3	111.7	0.023
107584	L2	42.8	0.057
107584	2MK3	30.5	0.085
107584	K2	320	0.196
107584	M8	153.3	0.037
107584	MS4	231.6	0.046
107585	M2	296.6	2.436
107585	S2	319	0.649
107585	N2	262.6	0.441
107585	K1	194.6	1.157
107585	M4	264.9	0.077
107585	O1	158.2	0.684
107585	M6	226.3	0.087
107585	MK3	112	0.196
107585	S4	309	0.024
107585	MN4	200.9	0.087
107585	S6	85.2	0.017
107585	2N2	332.2	0.053
107585	OO1	261.3	0.156
107585	M1	234	0.044
107585	J1	157.8	0.018
107585	Q1	159.3	0.045
107585	2Q1	100.9	0.078
107585	P1	189.5	0.269
107585	2SM2	162.5	0.031
107585	M3	105.2	0.034
107585	L2	8.5	0.078
107585	2MK3	32.9	0.101
107585	K2	335.3	0.191
107585	M8	163.9	0.066
107585	MS4	282.6	0.055
107586	M2	298.3	0.241
107586	S2	325.5	0.058
107586	N2	252.9	0.054
107586	K1	195	0.088
107586	M4	341.9	0.014
107586	O1	169	0.046
107586	M6	306.4	0.009
107586	MK3	234.5	0.012
107586	S4	205.9	0.004
107586	MN4	311.4	0.006
107586	S6	122	0.002
107586	2N2	139.7	0.013
107586	OO1	64.6	0.017
107586	M1	270.1	0.003
107586	J1	212.8	0.007
107586	Q1	192.2	0.01
107586	2Q1	90.4	0.003
107586	P1	224.9	0.026
107586	2SM2	235	0.005
107586	M3	203.9	0.003
107586	L2	38.6	0.01
107586	2MK3	339	0.011
107586	K2	294	0.019
107586	M8	340.1	0.001
107586	MS4	349	0.01
107587	M2	305.2	0.219
107587	S2	309.1	0.05
107587	N2	271.5	0.063
107587	K1	195.5	0.096
107587	M4	306.1	0.006
107587	O1	196.5	0.04
107587	M6	282	0.01
107587	MK3	278.7	0.016
107587	S4	339.6	0.001
107587	MN4	221	0.004
107587	S6	196.5	0.001
107587	2N2	205.9	0.01
107587	OO1	343.9	0.007
107587	M1	208.4	0.009
107587	J1	227.9	0.011
107587	Q1	187.3	0.009
107587	2Q1	250.7	0.001
107587	P1	181.4	0.014
107587	2SM2	185.9	0.001
107587	M3	191.3	0.004
107587	L2	357.8	0.026
107587	2MK3	326.9	0.014
107587	K2	323.1	0.014
107587	M8	60.2	0.002
107587	MS4	322.9	0.007
107588	M2	298.3	0.245
107588	S2	301.1	0.077
107588	N2	257.1	0.055
107588	K1	219.2	0.102
107588	M4	267.7	0.011
107588	O1	189.8	0.03
107588	M6	329.7	0.007
107588	MK3	285.5	0.017
107588	S4	52.7	0.004
107588	MN4	235	0.006
107588	S6	247.1	0.002
107588	2N2	71.7	0.008
107588	OO1	277.7	0.007
107588	M1	182.4	0.012
107588	J1	131.2	0.013
107588	Q1	107.4	0.021
107588	2Q1	206	0.016
107588	P1	186	0.041
107588	2SM2	209.5	0.011
107588	M3	254	0.003
107588	L2	355.3	0.02
107588	2MK3	280.5	0.008
107588	K2	198.9	0.01
107588	M8	330.9	0.002
107588	MS4	208.9	0.001
107589	M2	275.2	2.329
107589	S2	293.9	0.524
107589	N2	237.5	0.34
107589	K1	188.7	0.749
107589	M4	174.2	0.274
107589	O1	167.2	0.328
107589	M6	324.9	0.096
107589	MK3	37.3	0.13
107589	S4	199.6	0.01
107589	MN4	108.5	0.064
107589	S6	16.1	0.018
107589	2N2	240.5	0.061
107589	OO1	210.5	0.08
107589	M1	190.1	0.037
107589	J1	261.3	0.043
107589	Q1	179.1	0.066
107589	2Q1	116.2	0.018
107589	P1	187.1	0.216
107589	2SM2	109	0.011
107589	M3	327.5	0.045
107589	L2	312.1	0.141
107589	2MK3	196.1	0.094
107589	K2	294.9	0.256
107589	M8	187.9	0.034
107589	MS4	188.8	0.071
107590	M2	277.6	2.242
107590	S2	289.4	0.571
107590	N2	231.4	0.353
107590	K1	194.9	0.733
107590	M4	164	0.187
107590	O1	197.8	0.264
107590	M6	333.1	0.102
107590	MK3	27.7	0.131
107590	S4	170.4	0.006
107590	MN4	86.1	0.081
107590	S6	35.6	0.017
107590	2N2	280.9	0.087
107590	OO1	179.2	0.072
107590	M1	137.2	0.029
107590	J1	349.1	0.021
107590	Q1	195.3	0.084
107590	2Q1	160	0.042
107590	P1	194.1	0.211
107590	2SM2	33.3	0.004
107590	M3	23.2	0.058
107590	L2	328.2	0.163
107590	2MK3	241.1	0.193
107590	K2	311.7	0.252
107590	M8	204.8	0.049
107590	MS4	206.2	0.098
107591	M2	279.1	2.131
107591	S2	288.8	0.552
107591	N2	231.1	0.325
107591	K1	203	0.681
107591	M4	91.3	0.096
107591	O1	229.8	0.312
107591	M6	319.7	0.084
107591	MK3	0	0.082
107591	S4	113.7	0.009
107591	MN4	72.4	0.073
107591	S6	57.7	0.009
107591	2N2	282.1	0.102
107591	OO1	131.5	0.094
107591	M1	95.1	0.039
107591	J1	55.5	0.043
107591	Q1	198.1	0.078
107591	2Q1	178.1	0.083
107591	P1	196.8	0.227
107591	2SM2	325.5	0.01
107591	M3	40.3	0.094
107591	L2	333.2	0.165
107591	2MK3	247.2	0.281
107591	K2	332.5	0.198
107591	M8	217.3	0.057
107591	MS4	225.3	0.079
107592	M2	287.4	2.369
107592	S2	320.7	0.605
107592	N2	261.7	0.518
107592	K1	192.1	0.949
107592	M4	142.7	0.147
107592	O1	178.3	0.535
107592	M6	270.3	0.066
107592	MK3	17.5	0.16
107592	S4	210.4	0.023
107592	MN4	118.7	0.055
107592	NU2	239.2	0.102
107592	S6	180.1	0.009
107592	MU2	244.3	0.059
107592	2N2	218	0.077
107592	OO1	237.6	0.066
107592	LDA2	4.3	0.042
107592	M1	209.5	0.065
107592	J1	229.4	0.098
107592	RHO1	129	0.027
107592	Q1	167.3	0.103
107592	2Q1	123.7	0.009
107592	P1	193.3	0.322
107592	2SM2	165.2	0.008
107592	M3	55.4	0.013
107592	L2	306	0.04
107592	2MK3	26.2	0.08
107592	K2	297.1	0.15
107592	M8	133.1	0.007
107592	MS4	171.8	0.075
107593	M2	293.3	2.837
107593	S2	321.8	0.717
107593	N2	262.6	0.592
107593	K1	195.1	1.185
107593	M4	126.3	0.151
107593	O1	176.7	0.639
107593	M6	18.8	0.025
107593	MK3	2.3	0.183
107593	S4	207	0.015
107593	MN4	64.9	0.038
107593	NU2	264.3	0.115
107593	S6	156.2	0.006
107593	MU2	176.6	0.072
107593	2N2	232.3	0.078
107593	OO1	235.3	0.055
107593	LDA2	353.6	0.056
107593	M1	217	0.041
107593	J1	216.1	0.084
107593	RHO1	130.1	0.023
107593	Q1	158.3	0.109
107593	2Q1	275.3	0.013
107593	P1	196.1	0.388
107593	2SM2	202.2	0.018
107593	M3	93.5	0.026
107593	L2	347.3	0.124
107593	2MK3	352.5	0.13
107593	K2	318.7	0.176
107593	M8	202.7	0.016
107593	MS4	176.5	0.061
107594	M2	296	2.982
107594	S2	322.9	0.721
107594	N2	263.8	0.611
107594	K1	194.6	1.238
107594	M4	89.1	0.025
107594	O1	172.5	0.663
107594	M6	81.8	0.051
107594	MK3	327.6	0.053
107594	S4	185.2	0.009
107594	MN4	52.5	0.009
107594	NU2	271.9	0.121
107594	MU2	175.6	0.095
107594	2N2	237.3	0.078
107594	OO1	186.2	0.027
107594	LDA2	348.8	0.053
107594	M1	216.5	0.056
107594	J1	228.2	0.087
107594	RHO1	127.8	0.018
107594	Q1	162.1	0.107
107594	2Q1	221	0.015
107594	P1	198	0.411
107594	2SM2	173.9	0.01
107594	M3	7.1	0.034
107594	L2	347.5	0.158
107594	2MK3	320.3	0.101
107594	K2	329.7	0.212
107594	M8	288.1	0.005
107594	MS4	201.6	0.047
107595	M2	281.8	2.534
107595	S2	298	0.613
107595	N2	233.8	0.437
107595	K1	186.6	0.918
107595	M4	26.4	0.256
107595	O1	163.4	0.479
107595	M6	185.2	0.087
107595	MK3	313.3	0.353
107595	S4	60.2	0.076
107595	MN4	331.1	0.106
107595	S6	193.8	0.016
107595	2N2	346	0.129
107595	OO1	282.1	0.061
107595	M1	268.2	0.007
107595	J1	129.4	0.047
107595	Q1	94.9	0.073
107595	2Q1	262	0.024
107595	P1	170.5	0.295
107595	2SM2	253.1	0.056
107595	M3	310	0.047
107595	L2	9.7	0.147
107595	2MK3	286.5	0.218
107595	K2	307.5	0.202
107595	M8	6.5	0.029
107595	MS4	35.7	0.133
107596	M2	283.1	2.832
107596	S2	294.4	0.63
107596	N2	231	0.421
107596	K1	186.3	1.029
107596	M4	359.6	0.261
107596	O1	155.6	0.633
107596	M6	172.7	0.06
107596	MK3	299.9	0.313
107596	S4	58	0.079
107596	MN4	318.1	0.122
107596	S6	142.1	0.013
107596	2N2	317.1	0.201
107596	OO1	299.2	0.092
107596	M1	287.6	0.018
107596	J1	118.5	0.06
107596	Q1	92.3	0.085
107596	2Q1	143.2	0.042
107596	P1	165.7	0.3
107596	2SM2	244.3	0.063
107596	M3	317.6	0.06
107596	L2	355.6	0.194
107596	2MK3	268.2	0.223
107596	K2	311.7	0.253
107596	M8	340.9	0.047
107596	MS4	30.5	0.153
107597	M2	283.5	2.879
107597	S2	293.8	0.619
107597	N2	231.5	0.407
107597	K1	186.3	1.039
107597	M4	347.2	0.285
107597	O1	148.9	0.667
107597	M6	146.5	0.053
107597	MK3	288.6	0.313
107597	S4	52.7	0.065
107597	MN4	311.4	0.113
107597	S6	146.7	0.011
107597	2N2	306.6	0.214
107597	OO1	305.9	0.077
107597	M1	265.3	0.027
107597	J1	126.9	0.056
107597	Q1	102.7	0.092
107597	2Q1	101.5	0.039
107597	P1	171.2	0.325
107597	2SM2	246.8	0.07
107597	M3	317.7	0.09
107597	L2	352.3	0.193
107597	2MK3	254.6	0.214
107597	K2	307.2	0.299
107597	M8	338.6	0.06
107597	MS4	25.2	0.17
107598	M2	312.9	0.396
107598	S2	340.7	0.09
107598	N2	265.1	0.095
107598	K1	186.3	0.21
107598	M4	27.4	0.022
107598	O1	144	0.067
107598	M6	12.4	0.011
107598	MK3	314.7	0.037
107598	S4	303.4	0.014
107598	MN4	345	0.019
107598	S6	135.5	0.007
107598	2N2	216	0.022
107598	OO1	159.4	0.014
107598	M1	128.5	0.006
107598	J1	272.8	0.022
107598	Q1	18.5	0.014
107598	2Q1	153.1	0.01
107598	P1	191.2	0.044
107598	2SM2	60.4	0.009
107598	M3	321.2	0.03
107598	L2	15.5	0.041
107598	2MK3	335.7	0.042
107598	K2	8.3	0.074
107598	M8	305.8	0.01
107598	MS4	49.4	0.005
107599	M2	322.3	0.43
107599	S2	341	0.125
107599	N2	289.7	0.087
107599	K1	213.9	0.273
107599	M4	308.2	0.029
107599	O1	206.9	0.084
107599	M6	334.2	0.019
107599	MK3	38.4	0.042
107599	S4	145.6	0.006
107599	MN4	257.9	0.025
107599	S6	118.4	0.004
107599	2N2	196.9	0.026
107599	OO1	142.9	0.056
107599	M1	221.2	0.021
107599	J1	257	0.005
107599	Q1	351.1	0.005
107599	2Q1	129.5	0.033
107599	P1	216.9	0.053
107599	2SM2	207.2	0.01
107599	M3	109.2	0.01
107599	L2	32.5	0.039
107599	2MK3	23.7	0.048
107599	K2	53.6	0.019
107599	M8	61.2	0.009
107599	MS4	186.8	0.005
107600	M2	342.4	0.399
107600	S2	5.1	0.093
107600	N2	306.3	0.072
107600	K1	240.5	0.327
107600	M4	278.7	0.091
107600	O1	222.3	0.1
107600	M6	6.8	0.029
107600	MK3	148.6	0.071
107600	S4	118.2	0.01
107600	MN4	244.6	0.054
107600	S6	81.6	0.006
107600	2N2	146.9	0.021
107600	OO1	218.7	0.019
107600	M1	261.2	0.016
107600	J1	133.3	0.017
107600	Q1	117.6	0.018
107600	2Q1	314.7	0.015
107600	P1	209.5	0.073
107600	2SM2	276.3	0.015
107600	M3	201.4	0.02
107600	L2	68.5	0.032
107600	2MK3	122.1	0.032
107600	K2	354.5	0.058
107600	M8	315.2	0.007
107600	MS4	332.6	0.043
107601	M2	20.1	1.219
107601	S2	40.8	0.211
107601	N2	339.4	0.251
107601	K1	236.4	0.359
107601	M4	247.3	0.089
107601	O1	220.7	0.213
107601	M6	34.2	0.157
107601	MK3	29.7	0.124
107601	S4	73.3	0.002
107601	MN4	196.3	0.042
107601	S6	207.9	0.003
107601	2N2	137.4	0.103
107601	OO1	161	0.057
107601	M1	315.6	0.028
107601	J1	94.3	0.012
107601	Q1	185.5	0.031
107601	2Q1	329.7	0.045
107601	P1	250.4	0.079
107601	2SM2	242	0.021
107601	M3	210.8	0.034
107601	L2	70.4	0.17
107601	2MK3	12.9	0.164
107601	K2	69.1	0.096
107601	M8	339.3	0.014
107601	MS4	261.5	0.021
107602	M2	24.3	1.439
107602	S2	36.3	0.228
107602	N2	342.6	0.299
107602	K1	241.9	0.481
107602	M4	250.1	0.083
107602	O1	220.6	0.226
107602	M6	31.2	0.191
107602	MK3	43.3	0.137
107602	S4	184.9	0.006
107602	MN4	201.7	0.041
107602	S6	272.7	0.003
107602	2N2	149.7	0.135
107602	OO1	178	0.105
107602	M1	344.1	0.025
107602	J1	128.5	0.013
107602	Q1	191.1	0.029
107602	2Q1	352	0.033
107602	P1	234.9	0.105
107602	2SM2	247.7	0.032
107602	M3	207.1	0.034
107602	L2	77.3	0.213
107602	2MK3	21.9	0.218
107602	K2	89.6	0.108
107602	M8	336.2	0.03
107602	MS4	249.8	0.019
107603	M2	30.2	1.533
107603	S2	33.2	0.24
107603	N2	343.7	0.308
107603	K1	235.9	0.437
107603	M4	294.2	0.054
107603	O1	211.7	0.217
107603	M6	37.7	0.231
107603	MK3	49	0.075
107603	S4	196.2	0.011
107603	MN4	225.6	0.033
107603	S6	68.6	0.005
107603	2N2	177.3	0.131
107603	OO1	195.8	0.072
107603	M1	344.4	0.018
107603	J1	219.8	0.01
107603	Q1	172.2	0.033
107603	2Q1	341.3	0.01
107603	P1	241.6	0.101
107603	2SM2	254.6	0.035
107603	M3	224.7	0.046
107603	L2	90.4	0.247
107603	2MK3	34.6	0.198
107603	K2	88.3	0.076
107603	M8	302.1	0.038
107603	MS4	321.9	0.014
107604	M2	53.2	1.591
107604	S2	72.3	0.266
107604	N2	14.5	0.324
107604	K1	321.5	0.331
107604	M4	238.2	0.124
107604	O1	299.8	0.187
107604	M6	33.1	0.2
107604	MK3	64.8	0.166
107604	S4	282.5	0.003
107604	MN4	191.5	0.062
107604	2N2	193.3	0.121
107604	OO1	177.3	0.057
107604	M1	23.7	0.016
107604	J1	134.4	0.017
107604	Q1	279.3	0.065
107604	2Q1	73.5	0.018
107604	P1	317.2	0.081
107604	2SM2	245.7	0.03
107604	M3	177.9	0.062
107604	L2	101.6	0.215
107604	2MK3	15.9	0.179
107604	K2	102.7	0.097
107604	M8	38.3	0.015
107604	MS4	254.8	0.033
107605	M2	50.8	1.713
107605	S2	70.3	0.26
107605	N2	11.7	0.34
107605	K1	314.1	0.315
107605	M4	241.7	0.081
107605	O1	299.5	0.197
107605	M6	29.9	0.206
107605	MK3	58.5	0.127
107605	S4	264.4	0.004
107605	MN4	185.2	0.043
107605	S6	261.9	0.004
107605	2N2	180.4	0.125
107605	OO1	178.7	0.068
107605	M1	11.8	0.024
107605	J1	110.1	0.019
107605	Q1	284.5	0.055
107605	2Q1	11.8	0.019
107605	P1	318.4	0.072
107605	2SM2	250.5	0.029
107605	M3	177.2	0.058
107605	L2	98.8	0.243
107605	2MK3	15.2	0.178
107605	K2	116.7	0.118
107605	M8	16	0.03
107605	MS4	258.2	0.031
107606	M2	45.6	1.773
107606	S2	71	0.241
107606	N2	6.2	0.343
107606	K1	290.3	0.297
107606	M4	286.8	0.043
107606	O1	289.7	0.185
107606	M6	21.6	0.192
107606	MK3	28.9	0.062
107606	S4	234.6	0.008
107606	MN4	174.9	0.016
107606	S6	335.8	0.003
107606	2N2	156.8	0.131
107606	OO1	169.7	0.07
107606	M1	353.7	0.034
107606	J1	61.1	0.019
107606	Q1	286.8	0.041
107606	2Q1	341.4	0.031
107606	P1	325.1	0.043
107606	2SM2	270.2	0.024
107606	M3	190.7	0.041
107606	L2	91	0.255
107606	2MK3	13.8	0.148
107606	K2	125	0.15
107606	M8	339.8	0.041
107606	MS4	258.2	0.026
107607	M2	238.4	2.465
107607	S2	265.9	0.407
107607	N2	199.6	0.497
107607	K1	142.4	0.482
107607	M4	124.4	0.09
107607	O1	121.8	0.188
107607	M6	203.1	0.214
107607	MK3	188.9	0.058
107607	S4	43.3	0.01
107607	MN4	92.9	0.034
107607	S6	187.6	0.005
107607	2N2	358.5	0.117
107607	OO1	12	0.074
107607	M1	173.8	0.043
107607	J1	225.5	0.036
107607	Q1	117	0.036
107607	2Q1	144.3	0.022
107607	P1	159.1	0.125
107607	2SM2	94.6	0.031
107607	M3	15.9	0.02
107607	L2	279.8	0.299
107607	2MK3	194.8	0.132
107607	K2	299.9	0.169
107607	M8	61.6	0.032
107607	MS4	130.7	0.038
107608	M2	238.4	2.464
107608	S2	267.1	0.417
107608	N2	199.5	0.501
107608	K1	143.4	0.485
107608	M4	123.6	0.104
107608	O1	122.5	0.216
107608	M6	201.4	0.212
107608	MK3	177	0.057
107608	S4	64.4	0.008
107608	MN4	101.8	0.045
107608	S6	169.1	0.004
107608	2N2	357.6	0.113
107608	OO1	3.9	0.063
107608	M1	177.9	0.042
107608	J1	221.7	0.038
107608	Q1	112.4	0.04
107608	2Q1	154.6	0.024
107608	P1	163.2	0.124
107608	2SM2	101.2	0.027
107608	M3	353.7	0.013
107608	L2	280.3	0.299
107608	2MK3	190.8	0.117
107608	K2	295.2	0.172
107608	M8	52.5	0.036
107608	MS4	140.4	0.034
107609	M2	238.4	2.451
107609	S2	267.7	0.421
107609	N2	199.8	0.498
107609	K1	144.2	0.484
107609	M4	126.5	0.111
107609	O1	123	0.217
107609	M6	200.4	0.207
107609	MK3	166.9	0.061
107609	S4	61.3	0.005
107609	MN4	106.6	0.053
107609	S6	156.6	0.005
107609	2N2	354.6	0.11
107609	OO1	6	0.065
107609	M1	182.4	0.044
107609	J1	228.1	0.04
107609	Q1	117.2	0.038
107609	2Q1	162.9	0.029
107609	P1	165.3	0.119
107609	2SM2	102.1	0.029
107609	M3	2.8	0.009
107609	L2	279.7	0.301
107609	2MK3	185.7	0.111
107609	K2	290	0.171
107609	M8	56.3	0.037
107609	MS4	156.1	0.031
107610	M2	267.2	0.676
107610	S2	298.1	0.124
107610	N2	221.8	0.132
107610	K1	170.8	0.243
107610	M4	7.7	0.072
107610	O1	168.1	0.262
107610	M6	146.4	0.013
107610	MK3	260.8	0.129
107610	S4	81.5	0.004
107610	MN4	325.8	0.038
107610	S6	130.3	0.008
107610	2N2	87.8	0.022
107610	OO1	274.9	0.053
107610	M1	17.2	0.012
107610	J1	190.8	0.033
107610	Q1	116	0.056
107610	2Q1	280.5	0.01
107610	P1	193.7	0.091
107610	2SM2	124.2	0.025
107610	M3	244.2	0.038
107610	L2	332.7	0.036
107610	2MK3	262.7	0.107
107610	K2	322	0.094
107610	M8	258.2	0.009
107610	MS4	351.4	0.039
107611	M2	275.3	0.82
107611	S2	288.5	0.174
107611	N2	224.4	0.173
107611	K1	170.2	0.274
107611	M4	38.9	0.1
107611	O1	153.1	0.26
107611	M6	108.2	0.022
107611	MK3	266.8	0.108
107611	S4	339.7	0.011
107611	MN4	353.2	0.038
107611	S6	328.5	0.009
107611	2N2	103.3	0.064
107611	OO1	298.2	0.06
107611	M1	84.9	0.017
107611	J1	157.1	0.053
107611	Q1	103.9	0.051
107611	2Q1	52.4	0.039
107611	P1	184.9	0.094
107611	2SM2	184.7	0.04
107611	M3	251.9	0.056
107611	L2	12.6	0.048
107611	2MK3	275.5	0.073
107611	K2	341.9	0.068
107611	M8	124.3	0.012
107611	MS4	32.2	0.058
107612	M2	277.9	0.89
107612	S2	288.4	0.182
107612	N2	224.4	0.196
107612	K1	167.8	0.309
107612	M4	42.1	0.126
107612	O1	145.5	0.284
107612	M6	107.3	0.016
107612	MK3	271.3	0.128
107612	S4	338.9	0.034
107612	MN4	31.5	0.025
107612	S6	310.3	0.002
107612	2N2	115	0.092
107612	OO1	309.1	0.049
107612	M1	99.5	0.032
107612	J1	167.4	0.056
107612	Q1	109.6	0.048
107612	2Q1	52.8	0.082
107612	P1	173.8	0.092
107612	2SM2	213.9	0.045
107612	M3	247.2	0.057
107612	L2	28.5	0.036
107612	2MK3	280.6	0.089
107612	K2	31.7	0.059
107612	M8	79.8	0.011
107612	MS4	38.5	0.096
107613	M2	230.3	0.393
107613	S2	290.7	0.093
107613	N2	223.5	0.086
107613	K1	175.1	0.156
107613	M4	311.5	0.078
107613	O1	144.6	0.106
107613	M6	218.2	0.02
107613	MK3	213	0.07
107613	S4	14.3	0.029
107613	MN4	256.5	0.037
107613	S6	148.4	0.006
107613	2N2	336.8	0.011
107613	OO1	336.8	0.025
107613	M1	337	0.011
107613	J1	345.5	0.007
107613	Q1	107.3	0.035
107613	2Q1	241.6	0.023
107613	P1	142	0.076
107613	2SM2	180.7	0.016
107613	M3	235.1	0.038
107613	L2	251.2	0.024
107613	2MK3	102.2	0.043
107613	M8	181.6	0.012
107613	MS4	357.9	0.05
107614	M2	259.8	0.587
107614	S2	287.9	0.04
107614	N2	219.6	0.105
107614	K1	171.3	0.164
107614	M4	301	0.038
107614	O1	174.9	0.124
107614	M6	59.1	0.021
107614	MK3	12.6	0.028
107614	S4	142.4	0.027
107614	MN4	239.5	0.028
107614	S6	295	0.005
107614	2N2	177.4	0.048
107614	OO1	36.7	0.049
107614	M1	209	0.047
107614	J1	319.2	0.035
107614	Q1	139.6	0.017
107614	2Q1	108.3	0.015
107614	P1	138	0.011
107614	2SM2	61.2	0.026
107614	M3	4	0.013
107614	L2	229.4	0.083
107614	2MK3	257.6	0.05
107614	M8	148.6	0.007
107614	MS4	143.5	0.012
107615	M2	262.4	0.646
107615	S2	217.6	0.044
107615	N2	211.3	0.131
107615	K1	153	0.13
107615	M4	280.4	0.031
107615	O1	169.1	0.157
107615	M6	69	0.034
107615	MK3	12.5	0.064
107615	S4	141	0.03
107615	MN4	235.3	0.031
107615	S6	314	0.009
107615	2N2	157.3	0.055
107615	OO1	95.7	0.055
107615	M1	216.9	0.057
107615	J1	332.5	0.049
107615	Q1	61.4	0.028
107615	2Q1	67.5	0.016
107615	P1	315.4	0.066
107615	2SM2	62.4	0.041
107615	M3	341.7	0.021
107615	L2	243.3	0.092
107615	2MK3	242.2	0.093
107615	M8	237.2	0.009
107615	MS4	127.2	0.038
107616	M2	285.2	0.405
107616	S2	242.1	0.069
107616	N2	254.7	0.09
107616	K1	223	0.207
107616	M4	307.6	0.031
107616	O1	194.6	0.133
107616	M6	290.5	0.021
107616	MK3	357.2	0.108
107616	S4	265.1	0.004
107616	MN4	172.4	0.005
107616	S6	14.5	0.015
107616	2N2	157	0.02
107616	OO1	28.8	0.043
107616	M1	301.7	0.021
107616	J1	119.3	0.034
107616	Q1	255.4	0.031
107616	2Q1	274.9	0.053
107616	P1	226.4	0.043
107616	2SM2	184.1	0.021
107616	M3	11.9	0.03
107616	L2	42.7	0.039
107616	2MK3	2.2	0.084
107616	K2	6.3	0.066
107616	M8	314.8	0.019
107616	MS4	127.6	0.052
107617	M2	294.2	0.516
107617	S2	291.3	0.076
107617	N2	251.8	0.118
107617	K1	200.8	0.301
107617	M4	147.4	0.063
107617	O1	172.3	0.303
107617	M6	34.9	0.007
107617	MK3	312.3	0.107
107617	S4	306.2	0.027
107617	MN4	109.5	0.022
107617	S6	236.9	0.006
107617	2N2	185.2	0.054
107617	OO1	177.3	0.045
107617	M1	291.9	0.022
107617	J1	216.2	0.02
107617	Q1	129.9	0.027
107617	2Q1	307.4	0.026
107617	P1	217.6	0.107
107617	2SM2	158.6	0.028
107617	M3	66.2	0.025
107617	L2	359	0.018
107617	2MK3	298.1	0.037
107617	K2	24.4	0.065
107617	M8	50.1	0.012
107617	MS4	223.6	0.05
107618	M2	300.8	0.852
107618	S2	309.3	0.148
107618	N2	262.9	0.175
107618	K1	174	0.378
107618	M4	180.1	0.049
107618	O1	170.3	0.241
107618	M6	54.8	0.029
107618	MK3	234.5	0.109
107618	S4	191.3	0.012
107618	MN4	176.5	0.037
107618	S6	212	0.006
107618	2N2	175.2	0.023
107618	OO1	184.6	0.103
107618	M1	220.4	0.034
107618	J1	258.7	0.043
107618	Q1	109.6	0.034
107618	2Q1	100.1	0.074
107618	P1	148.4	0.026
107618	2SM2	163.9	0.019
107618	M3	323.4	0.012
107618	L2	335.4	0.075
107618	2MK3	217.8	0.122
107618	K2	255.2	0.042
107618	M8	103.1	0.017
107618	MS4	252.8	0.082
107619	M2	277.3	0.356
107619	S2	332.6	0.127
107619	N2	276.6	0.074
107619	K1	190.1	0.244
107619	M4	151.9	0.069
107619	O1	145.4	0.169
107619	M6	58.2	0.01
107619	MK3	70.2	0.066
107619	S4	218.5	0.003
107619	MN4	185.5	0.021
107619	S6	36.5	0.008
107619	2N2	188.8	0.049
107619	OO1	220.7	0.083
107619	M1	56.8	0.027
107619	J1	181.9	0.036
107619	Q1	92.3	0.045
107619	2Q1	286.8	0.021
107619	P1	177	0.079
107619	2SM2	353.3	0.023
107619	M3	161.9	0.031
107619	L2	202.5	0.052
107619	2MK3	183.7	0.033
107619	K2	208.3	0.028
107619	M8	277.6	0.011
107619	MS4	203.3	0.025
107620	M2	331.4	0.372
107620	S2	4.9	0.144
107620	N2	293.9	0.097
107620	K1	206.6	0.187
107620	M4	274.9	0.024
107620	O1	309.2	0.012
107620	M6	237.8	0.014
107620	MK3	138.1	0.098
107620	S4	38.7	0.003
107620	MN4	327.8	0.012
107620	S6	253.2	0.005
107620	2N2	167.8	0.034
107620	OO1	265.2	0.019
107620	M1	238.3	0.033
107620	J1	356.4	0.047
107620	Q1	251.5	0.029
107620	2Q1	262.4	0.039
107620	P1	82.1	0.022
107620	2SM2	148.9	0.019
107620	M3	201.2	0.027
107620	L2	332.2	0.039
107620	2MK3	118.1	0.046
107620	K2	305.6	0.068
107620	M8	210.4	0.006
107620	MS4	284.3	0.011
107621	M2	338.4	0.372
107621	S2	3.5	0.089
107621	N2	304.6	0.088
107621	K1	203.9	0.258
107621	M4	325.8	0.021
107621	O1	318.2	0.075
107621	M6	248.7	0.022
107621	MK3	158	0.119
107621	S4	84.4	0.012
107621	MN4	325.4	0.014
107621	S6	242.9	0.004
107621	2N2	59.5	0.021
107621	OO1	114.6	0.066
107621	M1	252.8	0.069
107621	J1	332.8	0.08
107621	Q1	278.2	0.061
107621	2Q1	227.8	0.077
107621	P1	45.2	0.115
107621	2SM2	184.4	0.024
107621	M3	224.9	0.036
107621	L2	308.6	0.057
107621	2MK3	108.1	0.039
107621	K2	303.9	0.017
107621	M8	279.9	0.005
107621	MS4	40.1	0.004
107622	M2	302.3	1.073
107622	S2	340.2	0.213
107622	N2	265.6	0.254
107622	K1	210.1	0.516
107622	M4	157.6	0.139
107622	O1	248.9	0.255
107622	M6	108.3	0.046
107622	MK3	20.7	0.217
107622	S4	5.3	0.026
107622	MN4	134.1	0.062
107622	S6	6.1	0.018
107622	2N2	164.2	0.028
107622	OO1	68.1	0.099
107622	M1	174.1	0.041
107622	J1	248.7	0.078
107622	Q1	220.4	0.083
107622	2Q1	79.3	0.076
107622	P1	224.8	0.172
107622	2SM2	233.7	0.013
107622	M3	88.3	0.039
107622	L2	335.4	0.033
107622	2MK3	96.8	0.019
107622	K2	37.5	0.138
107622	M8	311.7	0.002
107622	MS4	171.8	0.066
107623	M2	294	0.877
107623	S2	324.3	0.224
107623	N2	254.4	0.217
107623	K1	205	0.525
107623	M4	334.3	0.035
107623	O1	182	0.32
107623	M6	251.7	0.038
107623	MK3	183.9	0.081
107623	S4	124	0.006
107623	MN4	289.8	0.023
107623	S6	130.4	0.014
107623	2N2	202.2	0.042
107623	OO1	71.3	0.021
107623	M1	236.6	0.055
107623	J1	263.4	0.047
107623	Q1	149.5	0.022
107623	2Q1	208.8	0.059
107623	P1	220.5	0.132
107623	2SM2	184.7	0.015
107623	M3	354.6	0.013
107623	L2	55.7	0.027
107623	2MK3	281.7	0.014
107623	K2	294.7	0.058
107623	M8	271	0.021
107623	MS4	326.3	0.032
107624	M2	296.2	0.818
107624	S2	333.2	0.216
107624	N2	255	0.2
107624	K1	201.8	0.498
107624	M4	288.8	0.051
107624	O1	176.8	0.307
107624	M6	287.6	0.037
107624	MK3	168.6	0.114
107624	S4	214.5	0.016
107624	MN4	252.3	0.032
107624	S6	143.1	0.017
107624	2N2	195.5	0.037
107624	OO1	137.7	0.054
107624	M1	257.7	0.041
107624	J1	305.1	0.028
107624	Q1	105.2	0.036
107624	2Q1	215.7	0.028
107624	P1	216.6	0.142
107624	2SM2	182.5	0.013
107624	M3	195.4	0.019
107624	L2	29.1	0.034
107624	2MK3	207.7	0.016
107624	K2	303	0.109
107624	M8	203	0.007
107624	MS4	296.7	0.035
107625	M2	295.5	0.909
107625	S2	337.9	0.186
107625	N2	264.2	0.218
107625	K1	201	0.322
107625	M4	219	0.133
107625	O1	257	0.137
107625	M6	187.7	0.049
107625	MK3	66.6	0.158
107625	S4	142.9	0.016
107625	MN4	172.3	0.068
107625	S6	52.7	0.003
107625	2N2	271.9	0.055
107625	OO1	75.8	0.151
107625	M1	184.8	0.027
107625	J1	221.2	0.032
107625	Q1	222.5	0.071
107625	2Q1	136.6	0.031
107625	P1	239.9	0.139
107625	2SM2	168.8	0.02
107625	M3	103	0.039
107625	L2	328.8	0.083
107625	2MK3	8.6	0.089
107625	K2	206	0.032
107625	M8	198.5	0.018
107625	MS4	249.7	0.091
107626	M2	297.6	0.86
107626	S2	325	0.264
107626	N2	263.8	0.171
107626	K1	204.3	0.442
107626	M4	346.4	0.02
107626	O1	175.8	0.17
107626	M6	298.8	0.033
107626	MK3	351.2	0.057
107626	S4	174.1	0.008
107626	MN4	316.5	0.018
107626	S6	214.9	0.015
107626	2N2	189	0.053
107626	OO1	166	0.047
107626	M1	191.4	0.028
107626	J1	200.4	0.059
107626	Q1	220	0.016
107626	2Q1	90.2	0.041
107626	P1	241.4	0.087
107626	2SM2	88.1	0.013
107626	M3	357.5	0.015
107626	L2	4.8	0.032
107626	2MK3	42.5	0.026
107626	K2	311.4	0.1
107626	M8	50.8	0.003
107626	MS4	38.3	0.038
107627	M2	301	0.728
107627	S2	326.6	0.212
107627	N2	260.6	0.167
107627	K1	204.2	0.55
107627	M4	113.8	0.043
107627	O1	183.6	0.257
107627	M6	307.2	0.016
107627	MK3	23.1	0.093
107627	S4	11.3	0.008
107627	MN4	73.2	0.019
107627	S6	222.1	0.019
107627	2N2	152.9	0.076
107627	OO1	276.1	0.044
107627	M1	235.5	0.01
107627	J1	231.1	0.043
107627	Q1	142.1	0.058
107627	2Q1	61.3	0.028
107627	P1	204.7	0.173
107627	2SM2	160.1	0.014
107627	M3	316.3	0.02
107627	L2	111.2	0.049
107627	2MK3	0.1	0.043
107627	K2	7.9	0.116
107627	M8	143.8	0.014
107627	MS4	93.2	0.034
107628	M2	289.3	1.346
107628	S2	316.3	0.363
107628	N2	247.8	0.321
107628	K1	192	0.51
107628	M4	74.1	0.066
107628	O1	184.3	0.288
107628	M6	95	0.01
107628	MK3	293.2	0.077
107628	S4	94.7	0.03
107628	MN4	34.1	0.027
107628	S6	21.8	0.013
107628	2N2	20.6	0.047
107628	OO1	2.7	0.015
107628	M1	207.5	0.059
107628	J1	274.4	0.06
107628	Q1	175.7	0.062
107628	2Q1	241.1	0.084
107628	P1	211	0.223
107628	2SM2	98.4	0.038
107628	M3	56	0.049
107628	L2	324.5	0.1
107628	2MK3	292	0.106
107628	K2	321.6	0.121
107628	M8	346.3	0.002
107628	MS4	64.1	0.028
107629	M2	294.5	1.488
107629	S2	344	0.38
107629	N2	268	0.355
107629	K1	199.1	0.878
107629	M4	252	0.045
107629	O1	175.6	0.344
107629	M6	251.5	0.019
107629	MK3	68.7	0.058
107629	S4	279	0.017
107629	MN4	202.1	0.025
107629	S6	141.7	0.012
107629	2N2	197.3	0.079
107629	OO1	332.7	0.06
107629	M1	161.1	0.047
107629	J1	226.3	0.103
107629	Q1	131.9	0.084
107629	2Q1	70.9	0.073
107629	P1	216.1	0.276
107629	2SM2	302.3	0.013
107629	M3	195.3	0.036
107629	L2	323.7	0.067
107629	2MK3	333.7	0.029
107629	K2	346	0.154
107629	M8	110.7	0.023
107629	MS4	346.6	0.033
107630	M2	296.3	1.365
107630	S2	359.8	0.342
107630	N2	271.7	0.277
107630	K1	193.4	0.806
107630	M4	219.5	0.131
107630	O1	149.8	0.317
107630	M6	286.5	0.072
107630	MK3	123.4	0.145
107630	S4	240.6	0.037
107630	MN4	171.6	0.064
107630	S6	191	0.015
107630	2N2	17.8	0.01
107630	OO1	149.4	0.063
107630	M1	4.7	0.024
107630	J1	219.5	0.028
107630	Q1	94.4	0.101
107630	2Q1	34.5	0.1
107630	P1	205.2	0.172
107630	2SM2	116.8	0.012
107630	M3	170.8	0.1
107630	L2	318.1	0.151
107630	2MK3	184.1	0.086
107630	K2	329.5	0.223
107630	M8	87.8	0.03
107630	MS4	244.8	0.069
107631	M2	288	0.928
107631	S2	326.9	0.265
107631	N2	257.5	0.23
107631	K1	175.4	0.576
107631	M4	277.6	0.027
107631	O1	152.7	0.134
107631	M6	134.1	0.008
107631	MK3	109.9	0.047
107631	S4	209.4	0.008
107631	MN4	284.1	0.023
107631	S6	164.7	0.008
107631	2N2	146.6	0.07
107631	OO1	187	0.064
107631	M1	159.9	0.02
107631	J1	271.4	0.046
107631	Q1	101.3	0.021
107631	2Q1	5.9	0.035
107631	P1	167.2	0.092
107631	2SM2	236	0.039
107631	M3	198.1	0.015
107631	L2	14.4	0.066
107631	2MK3	294.1	0.024
107631	K2	327.9	0.121
107631	M8	318.2	0.004
107631	MS4	111.2	0.019
107632	M2	287.8	0.962
107632	S2	314.9	0.232
107632	N2	241.2	0.244
107632	K1	169.1	0.489
107632	M4	156.5	0.023
107632	O1	168.6	0.224
107632	M6	107.7	0.012
107632	MK3	318.1	0.103
107632	S4	239.7	0.016
107632	MN4	78.3	0.029
107632	S6	340.9	0.01
107632	2N2	34.6	0.028
107632	OO1	239.9	0.04
107632	M1	283.9	0.024
107632	J1	220	0.026
107632	Q1	216.8	0.036
107632	2Q1	236.3	0.045
107632	P1	341.8	0.023
107632	2SM2	107.4	0.009
107632	M3	63.2	0.047
107632	L2	10.4	0.053
107632	2MK3	309.7	0.069
107632	K2	10.2	0.095
107632	M8	233.7	0.009
107632	MS4	217.7	0.017
107633	M2	289.2	0.992
107633	S2	287.6	0.242
107633	N2	239.7	0.219
107633	K1	182.7	0.504
107633	M4	117.2	0.069
107633	O1	172.6	0.262
107633	M6	50.2	0.012
107633	MK3	322.9	0.123
107633	S4	151.5	0.014
107633	MN4	100.4	0.039
107633	2N2	24.8	0.047
107633	OO1	245.2	0.06
107633	M1	289.8	0.041
107633	J1	333.6	0.006
107633	Q1	221.7	0.068
107633	2Q1	246.1	0.06
107633	P1	352.5	0.035
107633	2SM2	128.1	0.027
107633	M3	38.8	0.09
107633	L2	327.5	0.058
107633	2MK3	324	0.049
107633	K2	65.1	0.059
107633	M8	1.1	0.009
107633	MS4	209.7	0.037
107634	M2	282.6	1.296
107634	S2	303.2	0.264
107634	N2	244.6	0.344
107634	K1	182.9	0.734
107634	M4	81.2	0.033
107634	O1	171.2	0.553
107634	M6	148.2	0.021
107634	MK3	265.8	0.113
107634	S4	107.2	0.027
107634	MN4	345.7	0.004
107634	S6	247.6	0.015
107634	2N2	157.8	0.025
107634	OO1	315.5	0.034
107634	M1	194	0.04
107634	J1	263.2	0.034
107634	Q1	141.1	0.155
107634	2Q1	303.6	0.04
107634	P1	204.2	0.197
107634	2SM2	67.9	0.026
107634	M3	330.2	0.025
107634	L2	341.2	0.065
107634	2MK3	258.4	0.039
107634	K2	314	0.067
107634	M8	235.7	0.01
107634	MS4	113.3	0.089
107635	M2	288.6	1.553
107635	S2	328	0.291
107635	N2	257.4	0.428
107635	K1	193.5	0.948
107635	M4	49.5	0.047
107635	O1	179.2	0.731
107635	M6	4	0.01
107635	MK3	279.4	0.16
107635	S4	326.3	0.011
107635	MN4	29.3	0.023
107635	S6	269.4	0.01
107635	2N2	76.5	0.038
107635	OO1	292.5	0.087
107635	M1	111	0.021
107635	J1	267.2	0.02
107635	Q1	133.4	0.189
107635	2Q1	310.6	0.011
107635	P1	205.8	0.3
107635	2SM2	103.6	0.022
107635	M3	237	0.047
107635	L2	2.1	0.067
107635	2MK3	266.5	0.073
107635	K2	337.5	0.192
107635	M8	295.9	0.005
107635	MS4	79.4	0.156
107636	M2	290.5	1.577
107636	S2	334.4	0.304
107636	N2	260.9	0.445
107636	K1	196.8	0.997
107636	M4	41.3	0.067
107636	O1	181.9	0.757
107636	M6	345.1	0.032
107636	MK3	284.6	0.183
107636	S4	320.9	0.022
107636	MN4	33.3	0.028
107636	S6	267.1	0.012
107636	2N2	87.1	0.044
107636	OO1	290	0.099
107636	M1	89.4	0.036
107636	J1	257	0.011
107636	Q1	131.7	0.207
107636	2Q1	77.9	0.016
107636	P1	208.1	0.317
107636	2SM2	117.8	0.022
107636	M3	225.9	0.073
107636	L2	19.1	0.058
107636	2MK3	276	0.065
107636	K2	342.7	0.223
107636	M8	281.3	0.009
107636	MS4	71.2	0.172
107637	M2	295.6	1.234
107637	S2	327.6	0.306
107637	N2	274	0.254
107637	K1	202.4	0.878
107637	M4	145.3	0.061
107637	O1	184.6	0.468
107637	M6	49	0.029
107637	MK3	3.7	0.074
107637	S4	343.4	0.011
107637	MN4	100	0.011
107637	NU2	287.8	0.055
107637	S6	296.4	0.01
107637	MU2	205.6	0.028
107637	2N2	216.5	0.021
107637	OO1	218.9	0.047
107637	LDA2	308.5	0.024
107637	M1	218.7	0.05
107637	J1	251.4	0.057
107637	RHO1	94.2	0.024
107637	Q1	174.8	0.075
107637	2Q1	169.6	0.021
107637	P1	204.2	0.299
107637	2SM2	135	0.019
107637	M3	49.2	0.01
107637	L2	309.3	0.053
107637	2MK3	265.1	0.04
107637	K2	328.7	0.051
107637	M8	15.9	0.009
107637	MS4	201.3	0.065
107638	M2	301	1.521
107638	S2	327.1	0.395
107638	N2	268.5	0.321
107638	K1	204.9	0.887
107638	M4	245.5	0.041
107638	O1	187.5	0.409
107638	M6	119.2	0.018
107638	MK3	95.5	0.155
107638	S4	59.2	0.018
107638	MN4	212.2	0.017
107638	NU2	261.6	0.058
107638	MU2	190.9	0.045
107638	2N2	212.5	0.012
107638	OO1	236.7	0.091
107638	LDA2	338.2	0.02
107638	M1	211.9	0.033
107638	J1	222.7	0.05
107638	RHO1	79.3	0.007
107638	Q1	173.8	0.068
107638	2Q1	1.3	0.022
107638	P1	199.7	0.255
107638	2SM2	214.9	0.016
107638	M3	123.5	0.008
107638	L2	17	0.043
107638	2MK3	20.9	0.048
107638	K2	358	0.083
107638	M8	216.6	0.002
107638	MS4	270.8	0.032
107639	M2	296.4	1.247
107639	S2	325	0.275
107639	N2	265.2	0.258
107639	K1	204.8	0.706
107639	M4	61.9	0.015
107639	O1	180	0.371
107639	M6	182	0.02
107639	MK3	227.6	0.023
107639	S4	222.1	0.012
107639	MN4	239	0.018
107639	NU2	273.1	0.046
107639	MU2	155.9	0.038
107639	2N2	296.9	0.04
107639	OO1	318.3	0.085
107639	LDA2	195	0.005
107639	M1	263.7	0.023
107639	J1	228.7	0.03
107639	RHO1	193.1	0.021
107639	Q1	167.5	0.043
107639	2Q1	264.1	0.01
107639	P1	207.5	0.193
107639	2SM2	3.2	0.003
107639	M3	122.1	0.011
107639	L2	350.8	0.046
107639	2MK3	103.2	0.056
107639	K2	325.6	0.142
107639	M8	259.6	0.023
107639	MS4	71.8	0.009
107640	M2	305.5	0.999
107640	S2	332.8	0.235
107640	N2	270.3	0.258
107640	K1	189.4	0.495
107640	M4	258.9	0.033
107640	O1	171.1	0.205
107640	M6	126	0.011
107640	MK3	56.2	0.048
107640	S4	134.7	0.009
107640	MN4	220.4	0.02
107640	S6	7.4	0.007
107640	2N2	162.3	0.017
107640	OO1	45.8	0.037
107640	M1	186.1	0.011
107640	J1	227.1	0.047
107640	Q1	158.3	0.019
107640	2Q1	290.3	0.021
107640	P1	195.5	0.175
107640	2SM2	249.1	0.025
107640	M3	132.7	0.01
107640	L2	350.5	0.057
107640	2MK3	324.5	0.013
107640	K2	357.2	0.048
107640	M8	139.7	0.005
107640	MS4	263.5	0.004
107641	M2	283.7	0.968
107641	S2	331.2	0.159
107641	N2	248.3	0.203
107641	K1	193.6	0.511
107641	M4	64.8	0.019
107641	O1	173.1	0.353
107641	M6	359.6	0.018
107641	MK3	243.4	0.171
107641	S4	128.3	0.027
107641	MN4	36.8	0.022
107641	S6	12.3	0.005
107641	2N2	33	0.022
107641	OO1	240.2	0.032
107641	M1	210.1	0.032
107641	J1	297.9	0.012
107641	Q1	168.5	0.072
107641	2Q1	91.2	0.026
107641	P1	207.6	0.105
107641	2SM2	196	0.012
107641	M3	288.4	0.055
107641	L2	340.9	0.07
107641	2MK3	233.6	0.074
107641	K2	354.2	0.144
107641	M8	348.7	0.005
107641	MS4	72.8	0.017
107642	M2	285.3	0.657
107642	S2	331.1	0.126
107642	N2	238.7	0.171
107642	K1	159.1	0.355
107642	M4	174.6	0.078
107642	O1	128.8	0.316
107642	M6	189.1	0.006
107642	MK3	172.9	0.173
107642	S4	33.1	0.031
107642	MN4	146.1	0.048
107642	S6	135.2	0.008
107642	2N2	159	0.028
107642	OO1	11	0.096
107642	M1	109.3	0.049
107642	J1	227.4	0.051
107642	Q1	85.1	0.064
107642	2Q1	181.2	0.031
107642	P1	125.2	0.01
107642	2SM2	358.4	0.006
107642	M3	67.7	0.003
107642	L2	287.6	0.022
107642	2MK3	152.6	0.081
107642	K2	184.3	0.007
107642	M8	73.3	0.006
107642	MS4	250.8	0.05
107643	M2	282.8	0.867
107643	S2	311.7	0.193
107643	N2	246.9	0.152
107643	K1	199.9	0.498
107643	M4	288.7	0.055
107643	O1	182.9	0.206
107643	M6	130.2	0.009
107643	MK3	234.1	0.03
107643	S4	156.3	0.013
107643	MN4	229.7	0.02
107643	NU2	241.5	0.029
107643	S6	92.7	0.009
107643	MU2	229.5	0.018
107643	2N2	274.1	0.011
107643	OO1	118.1	0.025
107643	LDA2	316.9	0.023
107643	M1	270.7	0.012
107643	J1	214.5	0.023
107643	RHO1	94.9	0.028
107643	Q1	184.6	0.034
107643	2Q1	278.5	0.015
107643	P1	196.5	0.141
107643	2SM2	295.7	0.005
107643	M3	210.5	0.009
107643	L2	334	0.074
107643	2MK3	237.9	0.015
107643	K2	319.1	0.076
107643	M8	82.7	0.001
107643	MS4	270.8	0.017
107644	M2	283.8	0.761
107644	S2	318.6	0.155
107644	N2	246.6	0.115
107644	K1	199.1	0.416
107644	M4	237.2	0.038
107644	O1	170.3	0.14
107644	M6	227	0.018
107644	MK3	179.2	0.044
107644	S4	175.8	0.031
107644	MN4	192.3	0.021
107644	NU2	217.1	0.024
107644	S6	110.8	0.005
107644	MU2	39.8	0.008
107644	2N2	341.3	0.029
107644	OO1	184.3	0.057
107644	LDA2	303.7	0.029
107644	M1	322	0.026
107644	J1	103.4	0.013
107644	RHO1	110.4	0.028
107644	Q1	222.7	0.01
107644	2Q1	274.3	0.038
107644	P1	184.6	0.13
107644	2SM2	147.4	0.009
107644	M3	173.4	0.023
107644	L2	322.8	0.091
107644	2MK3	151.6	0.04
107644	K2	298.9	0.083
107644	M8	334.1	0.004
107644	MS4	188.5	0.044
107645	M2	240.7	2.932
107645	S2	247.6	0.699
107645	N2	217.1	0.629
107645	K1	149.3	0.786
107645	M4	288.6	0.084
107645	O1	137.8	0.094
107645	M6	205.7	0.252
107645	MK3	186.7	0.121
107645	S4	191	0.03
107645	MN4	239	0.102
107645	S6	253.7	0.007
107645	2N2	74.1	0.012
107645	OO1	122.5	0.029
107645	M1	166.2	0.021
107645	J1	187.1	0.1
107645	Q1	171	0.095
107645	2Q1	161.8	0.043
107645	P1	119.8	0.166
107645	2SM2	137.8	0.086
107645	M3	122.8	0.096
107645	L2	262.4	0.188
107645	2MK3	196.9	0.138
107645	M8	267	0.025
107645	MS4	288.7	0.08
107646	M2	240.3	3.515
107646	S2	248.2	0.789
107646	N2	220.5	0.722
107646	K1	149.4	0.901
107646	M4	279.7	0.119
107646	O1	144.4	0.114
107646	M6	204.4	0.326
107646	MK3	192.9	0.152
107646	S4	184.7	0.031
107646	MN4	246	0.113
107646	S6	250.3	0.012
107646	2N2	94.2	0.062
107646	OO1	84.3	0.025
107646	M1	185.6	0.039
107646	J1	185	0.104
107646	Q1	172.4	0.11
107646	2Q1	176.9	0.051
107646	P1	124.3	0.176
107646	2SM2	130.9	0.1
107646	M3	113.1	0.089
107646	L2	264.2	0.273
107646	2MK3	192.1	0.184
107646	M8	257.3	0.031
107646	MS4	298.7	0.09
107647	M2	240.1	3.888
107647	S2	248.7	0.837
107647	N2	222.7	0.777
107647	K1	149.5	0.943
107647	M4	276.5	0.133
107647	O1	143.5	0.131
107647	M6	203.7	0.369
107647	MK3	194.6	0.168
107647	S4	170.7	0.03
107647	MN4	247.7	0.113
107647	S6	251.6	0.015
107647	2N2	96.5	0.104
107647	OO1	50.5	0.035
107647	M1	188.9	0.057
107647	J1	184.6	0.096
107647	Q1	173.3	0.117
107647	2Q1	184.5	0.061
107647	P1	135.9	0.178
107647	2SM2	125.9	0.105
107647	M3	102.9	0.085
107647	L2	264.9	0.333
107647	2MK3	189.8	0.215
107647	M8	249.5	0.032
107647	MS4	302.8	0.09
107648	M2	239.9	4.151
107648	S2	249	0.87
107648	N2	223.8	0.817
107648	K1	149.2	0.965
107648	M4	272.9	0.135
107648	O1	140.4	0.146
107648	M6	203.1	0.4
107648	MK3	194.9	0.173
107648	S4	158.4	0.03
107648	MN4	247	0.109
107648	S6	258.6	0.017
107648	2N2	97.8	0.133
107648	OO1	33.6	0.05
107648	M1	186	0.073
107648	J1	185.3	0.093
107648	Q1	171.8	0.119
107648	2Q1	190.9	0.071
107648	P1	146.2	0.186
107648	2SM2	121.4	0.107
107648	M3	94	0.083
107648	L2	265.1	0.374
107648	2MK3	188.8	0.238
107648	M8	244.8	0.03
107648	MS4	305.4	0.082
107649	M2	239.8	4.358
107649	S2	249.4	0.9
107649	N2	224.4	0.851
107649	K1	148.7	0.984
107649	M4	268.8	0.134
107649	O1	137.8	0.164
107649	M6	202.9	0.42
107649	MK3	194.5	0.176
107649	S4	154.3	0.031
107649	MN4	246.8	0.104
107649	S6	271.4	0.019
107649	2N2	101.3	0.152
107649	OO1	27.3	0.066
107649	M1	184.6	0.088
107649	J1	186.4	0.092
107649	Q1	170.9	0.121
107649	2Q1	193.8	0.077
107649	P1	152.9	0.194
107649	2SM2	117.7	0.11
107649	M3	89.6	0.084
107649	L2	265.3	0.403
107649	2MK3	188.6	0.253
107649	M8	239.5	0.03
107649	MS4	305	0.073
107650	M2	239.8	4.522
107650	S2	249.7	0.925
107650	N2	224.4	0.88
107650	K1	148.2	0.997
107650	M4	263.7	0.13
107650	O1	136.2	0.182
107650	M6	202.6	0.43
107650	MK3	193.7	0.173
107650	S4	151.1	0.034
107650	MN4	245.5	0.096
107650	S6	278.5	0.02
107650	2N2	103.8	0.166
107650	OO1	24.2	0.083
107650	M1	184.6	0.1
107650	J1	187.4	0.088
107650	Q1	170.2	0.122
107650	2Q1	196.3	0.079
107650	P1	159.2	0.201
107650	2SM2	115	0.112
107650	M3	86	0.085
107650	L2	265.5	0.421
107650	2MK3	188.4	0.264
107650	M8	234.3	0.03
107650	MS4	301.8	0.063
107651	M2	239.8	4.653
107651	S2	249.9	0.947
107651	N2	224.3	0.904
107651	K1	147.9	1.012
107651	M4	258.4	0.128
107651	O1	135.2	0.197
107651	M6	202.6	0.435
107651	MK3	192.2	0.17
107651	S4	148.9	0.037
107651	MN4	242.8	0.089
107651	S6	282.2	0.018
107651	2N2	106.2	0.174
107651	OO1	22	0.092
107651	M1	184.4	0.111
107651	J1	190.1	0.085
107651	Q1	169.2	0.122
107651	2Q1	199.1	0.082
107651	P1	162.6	0.211
107651	2SM2	112.9	0.113
107651	M3	84.3	0.085
107651	L2	265.6	0.433
107651	2MK3	188.1	0.27
107651	M8	231.2	0.031
107651	MS4	294.6	0.054
107652	M2	239.9	4.763
107652	S2	250.2	0.969
107652	N2	223.9	0.927
107652	K1	147.4	1.021
107652	M4	253.2	0.126
107652	O1	134.4	0.211
107652	M6	202.4	0.438
107652	MK3	190.2	0.167
107652	S4	148.7	0.038
107652	MN4	236.8	0.082
107652	S6	289	0.017
107652	2N2	109.3	0.179
107652	OO1	19.9	0.098
107652	M1	184.4	0.121
107652	J1	192.4	0.082
107652	Q1	166.7	0.125
107652	2Q1	202.5	0.082
107652	P1	167	0.22
107652	2SM2	111.2	0.113
107652	M3	84.4	0.086
107652	L2	265.8	0.439
107652	2MK3	188.2	0.273
107652	M8	226.5	0.032
107652	MS4	283.4	0.048
107653	M2	240	4.861
107653	S2	250.4	0.986
107653	N2	223.6	0.947
107653	K1	147.4	1.044
107653	M4	247.5	0.124
107653	O1	133.8	0.227
107653	M6	202.5	0.439
107653	MK3	187.1	0.16
107653	S4	147.3	0.037
107653	MN4	229.9	0.078
107653	S6	292.8	0.015
107653	2N2	112	0.182
107653	OO1	16.8	0.101
107653	M1	184.1	0.127
107653	J1	193.2	0.084
107653	Q1	164.3	0.125
107653	2Q1	205.6	0.081
107653	P1	166.3	0.233
107653	2SM2	110.9	0.115
107653	M3	83.9	0.085
107653	L2	265.8	0.444
107653	2MK3	188	0.272
107653	M8	219.1	0.033
107653	MS4	269.7	0.044
107654	M2	240.1	4.948
107654	S2	250.6	1.005
107654	N2	223.2	0.967
107654	K1	146.8	1.059
107654	M4	240.3	0.123
107654	O1	133.2	0.243
107654	M6	202.3	0.435
107654	MK3	184.8	0.153
107654	S4	145.2	0.035
107654	MN4	221.1	0.075
107654	S6	298.5	0.016
107654	2N2	114.7	0.181
107654	OO1	13.9	0.105
107654	M1	184.6	0.134
107654	J1	194.4	0.084
107654	Q1	162.7	0.127
107654	2Q1	207.8	0.08
107654	P1	168.9	0.238
107654	2SM2	111.4	0.117
107654	M3	83.9	0.085
107654	L2	265.9	0.447
107654	2MK3	187.7	0.271
107654	M8	216.9	0.035
107654	MS4	256.9	0.044
107655	M2	240.3	5.026
107655	S2	250.7	1.023
107655	N2	222.8	0.986
107655	K1	146.5	1.067
107655	M4	232.9	0.121
107655	O1	132.6	0.261
107655	M6	202.3	0.432
107655	MK3	181.7	0.146
107655	S4	141.2	0.036
107655	MN4	213.4	0.075
107655	S6	305.2	0.014
107655	2N2	117.3	0.178
107655	OO1	13.6	0.104
107655	M1	184.2	0.14
107655	J1	197.5	0.087
107655	Q1	161.6	0.127
107655	2Q1	208.4	0.079
107655	P1	172.4	0.252
107655	2SM2	111.3	0.119
107655	M3	83.9	0.085
107655	L2	266.1	0.448
107655	2MK3	187.5	0.267
107655	M8	212.8	0.037
107655	MS4	244.3	0.044
107656	M2	240.4	5.104
107656	S2	250.9	1.042
107656	N2	222.3	1.004
107656	K1	146.1	1.075
107656	M4	224	0.121
107656	O1	132.1	0.281
107656	M6	202.5	0.428
107656	MK3	179	0.141
107656	S4	137	0.036
107656	MN4	205.6	0.072
107656	S6	313.2	0.014
107656	2N2	120.1	0.176
107656	OO1	13	0.108
107656	M1	184.7	0.144
107656	J1	199.6	0.088
107656	Q1	160.6	0.124
107656	2Q1	211.3	0.076
107656	P1	175.8	0.262
107656	2SM2	111.6	0.12
107656	M3	85.1	0.085
107656	L2	266	0.449
107656	2MK3	187.4	0.262
107656	M8	209.1	0.041
107656	MS4	230.1	0.043
107657	M2	240.6	5.177
107657	S2	251.1	1.057
107657	N2	221.8	1.021
107657	K1	145.5	1.072
107657	M4	215.5	0.121
107657	O1	131.3	0.304
107657	M6	202.5	0.422
107657	MK3	176.6	0.135
107657	S4	136.2	0.035
107657	MN4	198.7	0.071
107657	S6	316	0.013
107657	2N2	122.8	0.177
107657	OO1	13.6	0.116
107657	M1	184.6	0.152
107657	J1	201.8	0.087
107657	Q1	159.6	0.12
107657	2Q1	213.6	0.07
107657	P1	180.7	0.272
107657	2SM2	112	0.122
107657	M3	86.8	0.084
107657	L2	265.7	0.45
107657	2MK3	188.1	0.259
107657	M8	205.8	0.043
107657	MS4	213.9	0.045
107658	M2	240.7	5.244
107658	S2	251.1	1.07
107658	N2	221.2	1.038
107658	K1	145	1.066
107658	M4	207.2	0.122
107658	O1	130.6	0.323
107658	M6	202.5	0.417
107658	MK3	174.9	0.133
107658	S4	134.8	0.033
107658	MN4	193.1	0.068
107658	S6	321.9	0.009
107658	2N2	125.3	0.177
107658	OO1	14.5	0.121
107658	M1	184.7	0.156
107658	J1	203.6	0.087
107658	Q1	159.3	0.115
107658	2Q1	216.4	0.067
107658	P1	184.7	0.286
107658	2SM2	111.3	0.122
107658	M3	87.9	0.085
107658	L2	265.2	0.451
107658	2MK3	188.9	0.257
107658	M8	202.9	0.046
107658	MS4	202.1	0.049
107659	M2	240.8	5.3
107659	S2	251.2	1.081
107659	N2	220.7	1.053
107659	K1	145	1.063
107659	M4	200.5	0.124
107659	O1	129.9	0.34
107659	M6	202.4	0.412
107659	MK3	173.6	0.134
107659	S4	133.5	0.03
107659	MN4	189.2	0.067
107659	2N2	127.8	0.178
107659	OO1	15	0.127
107659	M1	184.1	0.159
107659	J1	205.1	0.089
107659	Q1	159.8	0.107
107659	2Q1	218.9	0.064
107659	P1	186.5	0.301
107659	2SM2	111.5	0.122
107659	M3	88.3	0.086
107659	L2	264.7	0.452
107659	2MK3	189.6	0.256
107659	M8	201.1	0.049
107659	MS4	194	0.052
107660	M2	240.9	5.348
107660	S2	251.4	1.091
107660	N2	220.2	1.064
107660	K1	144.7	1.055
107660	M4	195.8	0.126
107660	O1	129.6	0.354
107660	M6	202.4	0.407
107660	MK3	172.8	0.137
107660	S4	130.8	0.027
107660	MN4	185.8	0.065
107660	2N2	129.7	0.181
107660	OO1	15.4	0.137
107660	M1	183.8	0.162
107660	J1	205.6	0.09
107660	Q1	160.2	0.1
107660	2Q1	220.2	0.061
107660	P1	189.4	0.314
107660	2SM2	111.6	0.122
107660	M3	88.3	0.086
107660	L2	264.2	0.452
107660	2MK3	190.3	0.258
107660	M8	198.7	0.051
107660	MS4	188.5	0.055
107661	M2	241	5.387
107661	S2	251.5	1.097
107661	N2	219.8	1.074
107661	K1	144.4	1.048
107661	M4	193.4	0.127
107661	O1	129	0.365
107661	M6	202.4	0.402
107661	MK3	172	0.139
107661	S4	127.6	0.025
107661	MN4	183.6	0.065
107661	2N2	131.2	0.184
107661	OO1	14.3	0.147
107661	M1	183.5	0.164
107661	J1	205.1	0.088
107661	Q1	160.5	0.094
107661	2Q1	220.6	0.059
107661	P1	191.4	0.324
107661	2SM2	111.2	0.123
107661	M3	88.5	0.088
107661	L2	263.4	0.452
107661	2MK3	191.3	0.258
107661	M8	196.3	0.052
107661	MS4	185.6	0.057
107662	M2	241.1	5.418
107662	S2	251.6	1.102
107662	N2	219.4	1.082
107662	K1	144.3	1.046
107662	M4	192	0.127
107662	O1	128.2	0.371
107662	M6	202.2	0.399
107662	MK3	171.6	0.141
107662	S4	124.6	0.024
107662	MN4	183.1	0.066
107662	2N2	132.3	0.187
107662	OO1	15.2	0.155
107662	M1	183.9	0.165
107662	J1	204.8	0.089
107662	Q1	161	0.091
107662	2Q1	223.5	0.057
107662	P1	192.1	0.332
107662	2SM2	109.8	0.123
107662	M3	89.7	0.089
107662	L2	262.8	0.452
107662	2MK3	191.8	0.259
107662	M8	195	0.053
107662	MS4	183.5	0.059
107663	M2	241.1	5.441
107663	S2	251.6	1.104
107663	N2	219.1	1.087
107663	K1	144.5	1.045
107663	M4	191.4	0.126
107663	O1	127.7	0.376
107663	M6	202.1	0.395
107663	MK3	172.3	0.144
107663	S4	125.4	0.025
107663	MN4	183.1	0.067
107663	2N2	133.3	0.189
107663	OO1	15	0.162
107663	M1	183.7	0.164
107663	J1	205.3	0.09
107663	Q1	160.8	0.089
107663	2Q1	224.3	0.056
107663	P1	191.7	0.337
107663	2SM2	109	0.124
107663	M3	89.7	0.092
107663	L2	262.2	0.452
107663	2MK3	192.1	0.261
107663	M8	193.3	0.055
107663	MS4	181.8	0.059
107664	M2	241.2	5.455
107664	S2	251.7	1.103
107664	N2	218.8	1.087
107664	K1	145.1	1.042
107664	M4	191.8	0.124
107664	O1	127.3	0.38
107664	M6	201.9	0.394
107664	MK3	172.7	0.149
107664	S4	121.5	0.025
107664	MN4	184.6	0.068
107664	2N2	133.6	0.194
107664	OO1	15.3	0.17
107664	M1	184.1	0.164
107664	J1	203.9	0.091
107664	Q1	161	0.086
107664	2Q1	226.1	0.056
107664	P1	190.7	0.347
107664	2SM2	107.4	0.124
107664	M3	89.2	0.092
107664	L2	261.6	0.453
107664	2MK3	192.6	0.266
107664	M8	193.5	0.055
107664	MS4	182	0.058
107665	M2	241.2	5.461
107665	S2	251.7	1.099
107665	N2	218.7	1.087
107665	K1	145.8	1.032
107665	M4	194	0.121
107665	O1	126.6	0.38
107665	M6	201.9	0.392
107665	MK3	173.1	0.156
107665	S4	114.9	0.026
107665	MN4	187.4	0.07
107665	2N2	133.6	0.199
107665	OO1	14.9	0.174
107665	M1	183.3	0.165
107665	J1	203.9	0.092
107665	Q1	161.8	0.084
107665	2Q1	228.4	0.055
107665	P1	190	0.36
107665	2SM2	105.9	0.125
107665	M3	89.5	0.093
107665	L2	261.1	0.454
107665	2MK3	193.4	0.271
107665	M8	192.9	0.055
107665	MS4	181.7	0.057
107666	M2	241.2	5.459
107666	S2	251.8	1.094
107666	N2	218.6	1.086
107666	K1	145.8	1.026
107666	M4	195.7	0.117
107666	O1	126.1	0.377
107666	M6	201.9	0.39
107666	MK3	173.6	0.16
107666	S4	110.6	0.026
107666	MN4	189.5	0.071
107666	2N2	133.7	0.203
107666	OO1	15.3	0.177
107666	M1	183.2	0.166
107666	J1	203.8	0.089
107666	Q1	162.4	0.084
107666	2Q1	228.4	0.055
107666	P1	190.4	0.36
107666	2SM2	104.9	0.124
107666	M3	88.5	0.092
107666	L2	260.7	0.454
107666	2MK3	193.5	0.275
107666	M8	192	0.054
107666	MS4	181.5	0.053
107667	M2	241.2	5.451
107667	S2	251.8	1.089
107667	N2	218.6	1.082
107667	K1	145.8	1.027
107667	M4	198.8	0.113
107667	O1	125.7	0.371
107667	M6	202	0.39
107667	MK3	174.5	0.169
107667	S4	108.7	0.026
107667	MN4	191.6	0.073
107667	2N2	133	0.208
107667	OO1	15.6	0.178
107667	M1	184	0.165
107667	J1	201.7	0.088
107667	Q1	163	0.084
107667	2Q1	228.4	0.053
107667	P1	189.9	0.353
107667	2SM2	104.4	0.124
107667	M3	87.8	0.094
107667	L2	260.5	0.455
107667	2MK3	193.6	0.281
107667	M8	191.6	0.052
107667	MS4	183.1	0.048
107668	M2	241.2	5.438
107668	S2	251.9	1.082
107668	N2	218.7	1.074
107668	K1	145.7	1.031
107668	M4	203.5	0.11
107668	O1	125.2	0.364
107668	M6	202	0.389
107668	MK3	174.2	0.178
107668	S4	106.9	0.026
107668	MN4	193.8	0.073
107668	2N2	132.5	0.212
107668	OO1	15	0.178
107668	M1	185.2	0.164
107668	J1	200.5	0.085
107668	Q1	164	0.083
107668	2Q1	227.4	0.054
107668	P1	189.4	0.344
107668	2SM2	103.5	0.123
107668	M3	87	0.095
107668	L2	260.4	0.456
107668	2MK3	193.8	0.284
107668	M8	192.7	0.048
107668	MS4	186.8	0.042
107669	M2	241.2	5.42
107669	S2	252	1.072
107669	N2	218.8	1.066
107669	K1	145.8	1.019
107669	M4	208.2	0.108
107669	O1	125.5	0.358
107669	M6	202.4	0.388
107669	MK3	174.6	0.185
107669	S4	106.3	0.026
107669	MN4	197	0.074
107669	S6	239	0.009
107669	2N2	132.4	0.216
107669	OO1	14.3	0.183
107669	M1	185.8	0.164
107669	J1	200.6	0.08
107669	Q1	164.2	0.081
107669	2Q1	227.4	0.054
107669	P1	189.9	0.344
107669	2SM2	102.4	0.122
107669	M3	86.3	0.095
107669	L2	260.1	0.459
107669	2MK3	194.1	0.289
107669	M8	192.6	0.046
107669	MS4	189.3	0.039
107670	M2	241.1	5.399
107670	S2	252	1.063
107670	N2	219	1.057
107670	K1	145.7	1.016
107670	M4	212.4	0.105
107670	O1	125.3	0.349
107670	M6	202.8	0.386
107670	MK3	175.1	0.192
107670	S4	107.5	0.027
107670	MN4	200.5	0.071
107670	S6	240.6	0.01
107670	2N2	131.7	0.221
107670	OO1	13.3	0.183
107670	M1	186.6	0.165
107670	J1	199.6	0.075
107670	Q1	164.6	0.082
107670	2Q1	229.1	0.053
107670	P1	189.7	0.336
107670	2SM2	101.2	0.122
107670	M3	85.3	0.094
107670	L2	260	0.461
107670	2MK3	194.4	0.293
107670	M8	190.9	0.044
107670	MS4	189.6	0.034
107671	M2	241.1	5.377
107671	S2	252.1	1.052
107671	N2	219.2	1.047
107671	K1	145.9	1.022
107671	M4	216	0.105
107671	O1	125.3	0.343
107671	M6	203.4	0.385
107671	MK3	175.5	0.201
107671	S4	107.5	0.028
107671	MN4	206.7	0.071
107671	S6	255.3	0.011
107671	2N2	130.2	0.226
107671	OO1	12.9	0.182
107671	M1	187.6	0.164
107671	J1	197.8	0.071
107671	Q1	164.2	0.082
107671	2Q1	233.1	0.052
107671	P1	187.9	0.327
107671	2SM2	100.8	0.12
107671	M3	86.1	0.093
107671	L2	259.6	0.468
107671	2MK3	194.8	0.294
107671	M8	189.9	0.04
107671	MS4	195.5	0.029
107672	M2	241	5.354
107672	S2	252.3	1.041
107672	N2	219.5	1.037
107672	K1	145.1	1.031
107672	M4	220.8	0.104
107672	O1	125.6	0.336
107672	M6	204.3	0.383
107672	MK3	175.6	0.21
107672	S4	105.6	0.028
107672	MN4	210.4	0.071
107672	S6	255.9	0.015
107672	2N2	129.3	0.232
107672	OO1	12.9	0.183
107672	M1	189	0.165
107672	J1	192.1	0.064
107672	Q1	164.3	0.084
107672	2Q1	234.1	0.05
107672	P1	187.8	0.301
107672	2SM2	99.7	0.118
107672	M3	85.2	0.093
107672	L2	259.7	0.469
107672	2MK3	195.5	0.296
107672	M8	189.5	0.037
107672	MS4	202.6	0.027
107673	M2	241	5.328
107673	S2	252.4	1.03
107673	N2	219.8	1.028
107673	K1	145.1	1.032
107673	M4	224.2	0.104
107673	O1	125.7	0.331
107673	M6	205.1	0.382
107673	MK3	175.5	0.215
107673	S4	105.2	0.027
107673	MN4	215.5	0.069
107673	S6	260.9	0.016
107673	2N2	128.7	0.24
107673	OO1	12.2	0.181
107673	M1	190.1	0.163
107673	J1	188	0.061
107673	Q1	165	0.086
107673	2Q1	233.8	0.049
107673	P1	186.7	0.289
107673	2SM2	99.8	0.116
107673	M3	85.3	0.093
107673	L2	259.6	0.473
107673	2MK3	196	0.297
107673	M8	187.9	0.035
107673	MS4	209.8	0.023
107674	M2	240.9	5.303
107674	S2	252.6	1.02
107674	N2	220.2	1.018
107674	K1	145.5	1.031
107674	M4	226.8	0.106
107674	O1	126.3	0.331
107674	M6	206.2	0.38
107674	MK3	174.3	0.221
107674	S4	101.4	0.028
107674	MN4	221.3	0.07
107674	S6	261.8	0.019
107674	2N2	127.3	0.246
107674	OO1	10.1	0.178
107674	M1	191	0.163
107674	J1	184	0.058
107674	Q1	164.1	0.086
107674	2Q1	236	0.045
107674	P1	184.6	0.283
107674	2SM2	98.9	0.113
107674	M3	85.6	0.092
107674	L2	259.8	0.477
107674	2MK3	196.6	0.299
107674	M8	184.4	0.033
107674	MS4	215.8	0.022
107675	M2	240.9	5.276
107675	S2	252.7	1.007
107675	N2	220.5	1.007
107675	K1	145.2	1.043
107675	M4	227.9	0.109
107675	O1	126.7	0.329
107675	M6	207.6	0.376
107675	MK3	173.5	0.225
107675	S4	99.3	0.028
107675	MN4	224.3	0.071
107675	S6	264.1	0.021
107675	2N2	126.8	0.254
107675	OO1	9.2	0.176
107675	M1	193	0.16
107675	J1	177.9	0.053
107675	Q1	161.7	0.089
107675	2Q1	240.2	0.042
107675	P1	182.4	0.263
107675	2SM2	98.8	0.114
107675	M3	84.7	0.093
107675	L2	260	0.482
107675	2MK3	197.1	0.3
107675	M8	181.4	0.027
107675	MS4	217	0.023
107676	M2	240.9	5.249
107676	S2	252.7	0.993
107676	N2	220.9	0.995
107676	K1	145.4	1.055
107676	M4	228.2	0.114
107676	O1	127.9	0.33
107676	M6	209.1	0.373
107676	MK3	171.7	0.231
107676	S4	101.9	0.027
107676	MN4	226.7	0.069
107676	S6	261.4	0.023
107676	2N2	125.5	0.26
107676	OO1	7.4	0.172
107676	M1	195.2	0.16
107676	J1	171.7	0.052
107676	Q1	158.5	0.089
107676	2Q1	245.1	0.042
107676	P1	178.9	0.252
107676	2SM2	100.7	0.113
107676	M3	84.9	0.095
107676	L2	260	0.487
107676	2MK3	198.4	0.302
107676	M8	178.5	0.023
107676	MS4	212.9	0.025
107677	M2	241.1	5.21
107677	S2	253	0.964
107677	N2	221.6	0.981
107677	K1	145	1.05
107677	M4	225.2	0.124
107677	O1	130.5	0.314
107677	M6	210	0.363
107677	MK3	167.2	0.24
107677	S4	95.3	0.026
107677	MN4	224.8	0.066
107677	S6	270.9	0.029
107677	2N2	124.3	0.254
107677	OO1	9	0.179
107677	M1	197.7	0.158
107677	J1	162.5	0.05
107677	Q1	158.1	0.092
107677	2Q1	245.3	0.052
107677	P1	180.4	0.225
107677	2SM2	103	0.116
107677	M3	83.8	0.096
107677	L2	260	0.496
107677	2MK3	197.2	0.3
107677	M8	178.4	0.022
107677	MS4	226.3	0.031
107678	M2	241.4	5.073
107678	S2	252.3	0.968
107678	N2	221.9	0.947
107678	K1	153	0.854
107678	M4	227.3	0.178
107678	O1	136.1	0.274
107678	M6	211.1	0.356
107678	MK3	161	0.311
107678	S4	79.7	0.032
107678	MN4	226.7	0.085
107678	S6	275.9	0.022
107678	2N2	129.5	0.253
107678	OO1	1.9	0.157
107678	M1	189.2	0.145
107678	J1	182.1	0.031
107678	Q1	166.2	0.092
107678	2Q1	191.8	0.031
107678	P1	181.6	0.365
107678	2SM2	97.9	0.102
107678	M3	84.6	0.091
107678	L2	260.7	0.491
107678	2MK3	187.7	0.306
107678	M8	153.1	0.029
107678	MS4	220.9	0.036
107679	M2	319.6	1.38
107679	S2	350.8	0.342
107679	N2	289.3	0.281
107679	K1	201.4	0.927
107679	M4	152.1	0.061
107679	O1	183.2	0.42
107679	M6	81.2	0.024
107679	MK3	63.2	0.179
107679	S4	233.3	0.005
107679	MN4	147.9	0.021
107679	NU2	290.7	0.051
107679	S6	2.7	0.004
107679	MU2	214.6	0.051
107679	2N2	234.7	0.057
107679	OO1	211.8	0.07
107679	LDA2	68.1	0.016
107679	M1	251.2	0.069
107679	J1	289.2	0.042
107679	RHO1	343.3	0.004
107679	Q1	189.3	0.09
107679	2Q1	74.5	0.039
107679	P1	206.5	0.195
107679	2SM2	245.8	0.004
107679	M3	48.7	0.037
107679	L2	0.3	0.058
107679	2MK3	12.6	0.09
107679	K2	36	0.092
107679	M8	274.6	0.03
107679	MS4	162	0.072
107680	M2	319.5	1.41
107680	S2	349.4	0.354
107680	N2	289	0.3
107680	K1	204.2	0.972
107680	M4	168.3	0.061
107680	O1	186	0.453
107680	M6	73.6	0.018
107680	MK3	68.5	0.185
107680	S4	222.8	0.004
107680	MN4	159.2	0.022
107680	NU2	294.1	0.049
107680	S6	347	0.004
107680	MU2	229.1	0.059
107680	2N2	225.8	0.054
107680	OO1	223.5	0.074
107680	LDA2	58.4	0.01
107680	M1	250.1	0.053
107680	J1	277.8	0.042
107680	RHO1	328.1	0.006
107680	Q1	186.2	0.088
107680	2Q1	73	0.037
107680	P1	206.7	0.215
107680	2SM2	314.9	0.006
107680	M3	44.6	0.041
107680	L2	10.5	0.053
107680	2MK3	25.1	0.089
107680	K2	37.2	0.093
107680	M8	277.7	0.028
107680	MS4	168.2	0.062
107681	M2	319.3	1.421
107681	S2	348.2	0.366
107681	N2	288.5	0.316
107681	K1	207	0.993
107681	M4	181.8	0.061
107681	O1	188.8	0.477
107681	M6	54.4	0.011
107681	MK3	73.8	0.186
107681	MN4	162.9	0.024
107681	NU2	293.8	0.048
107681	S6	329.9	0.006
107681	MU2	240.9	0.065
107681	2N2	219.3	0.052
107681	OO1	235.2	0.073
107681	LDA2	54.7	0.01
107681	M1	245.7	0.041
107681	J1	264.2	0.047
107681	RHO1	341.5	0.007
107681	Q1	187.1	0.085
107681	2Q1	68.9	0.039
107681	P1	208.9	0.235
107681	2SM2	333.8	0.01
107681	M3	43.1	0.045
107681	L2	16.2	0.048
107681	2MK3	35.8	0.086
107681	K2	39.6	0.092
107681	M8	277.6	0.025
107681	MS4	171.9	0.046
107682	M2	319.3	1.432
107682	S2	347.4	0.378
107682	N2	288.1	0.329
107682	K1	209.2	1.011
107682	M4	192.5	0.062
107682	O1	190.6	0.498
107682	M6	24.2	0.006
107682	MK3	78.3	0.185
107682	MN4	167.2	0.025
107682	NU2	292.5	0.046
107682	S6	320.5	0.006
107682	MU2	248.2	0.07
107682	2N2	213.9	0.049
107682	OO1	245.3	0.074
107682	LDA2	54.7	0.013
107682	M1	240	0.034
107682	J1	252.8	0.054
107682	RHO1	343.7	0.009
107682	Q1	187.5	0.083
107682	2Q1	61.5	0.04
107682	P1	211.1	0.255
107682	2SM2	342.2	0.012
107682	M3	42.2	0.046
107682	L2	19	0.043
107682	2MK3	44.2	0.082
107682	K2	42.9	0.094
107682	M8	273.9	0.021
107682	MS4	174.4	0.031
107683	M2	319.6	1.45
107683	S2	347.3	0.389
107683	N2	288	0.34
107683	K1	211.2	1.031
107683	M4	200.4	0.063
107683	O1	191.4	0.517
107683	M6	5.8	0.004
107683	MK3	82	0.181
107683	S4	12.7	0.004
107683	MN4	171.5	0.025
107683	NU2	291.3	0.044
107683	S6	313.5	0.007
107683	MU2	252.9	0.074
107683	2N2	207.4	0.048
107683	OO1	251.8	0.078
107683	LDA2	52.4	0.019
107683	M1	236.3	0.029
107683	J1	244.7	0.061
107683	RHO1	331.2	0.011
107683	Q1	186	0.082
107683	2Q1	50.3	0.038
107683	P1	212.3	0.275
107683	2SM2	348.9	0.014
107683	M3	40.1	0.046
107683	L2	19	0.04
107683	2MK3	50.8	0.08
107683	K2	44.9	0.097
107683	M8	267.4	0.019
107683	MS4	180.8	0.018
107684	M2	320	1.473
107684	S2	347.7	0.4
107684	N2	288.1	0.349
107684	K1	212.8	1.055
107684	M4	207.3	0.061
107684	O1	191.7	0.535
107684	MK3	85.3	0.172
107684	S4	28	0.006
107684	MN4	173.4	0.024
107684	NU2	290	0.043
107684	S6	310.1	0.008
107684	MU2	255.7	0.075
107684	2N2	202.6	0.05
107684	OO1	255.6	0.082
107684	LDA2	54.7	0.025
107684	M1	233.5	0.026
107684	J1	238.6	0.067
107684	RHO1	314.6	0.012
107684	Q1	182.3	0.08
107684	2Q1	37.1	0.035
107684	P1	213	0.296
107684	2SM2	351.1	0.014
107684	M3	36.4	0.046
107684	L2	17.2	0.039
107684	2MK3	56.5	0.078
107684	K2	45.9	0.101
107684	M8	263.4	0.017
107684	MS4	197.9	0.007
107685	M2	320.5	1.501
107685	S2	348.4	0.412
107685	N2	288.6	0.355
107685	K1	214.2	1.081
107685	M4	213.9	0.058
107685	O1	191.8	0.55
107685	M6	195.3	0.004
107685	MK3	88.1	0.163
107685	S4	33.9	0.007
107685	MN4	173.5	0.023
107685	NU2	288.2	0.042
107685	S6	319.2	0.007
107685	MU2	257.3	0.073
107685	2N2	198.7	0.053
107685	OO1	259	0.087
107685	LDA2	55.6	0.031
107685	M1	230.3	0.023
107685	J1	233.8	0.072
107685	RHO1	304.2	0.014
107685	Q1	178.8	0.081
107685	2Q1	22.8	0.033
107685	P1	213.5	0.317
107685	2SM2	348.9	0.013
107685	M3	32.8	0.045
107685	L2	14.5	0.04
107685	2MK3	60.6	0.078
107685	K2	45.8	0.107
107685	M8	261.2	0.016
107685	MS4	318.8	0.006
107686	M2	321.1	1.531
107686	S2	349	0.423
107686	N2	289.2	0.36
107686	K1	215.4	1.106
107686	M4	221.8	0.055
107686	O1	191.6	0.564
107686	M6	190.6	0.008
107686	MK3	90.1	0.154
107686	S4	32.6	0.007
107686	MN4	174.4	0.022
107686	NU2	289.1	0.041
107686	S6	326.7	0.006
107686	MU2	257.2	0.07
107686	2N2	196.2	0.056
107686	OO1	262.2	0.089
107686	LDA2	56.3	0.036
107686	M1	225.9	0.021
107686	J1	228.9	0.076
107686	RHO1	299.7	0.014
107686	Q1	175.9	0.081
107686	2Q1	8.6	0.03
107686	P1	213.8	0.339
107686	2SM2	341.3	0.011
107686	M3	28.2	0.043
107686	L2	10.8	0.042
107686	2MK3	64.1	0.079
107686	K2	46	0.112
107686	M8	254.9	0.015
107686	MS4	343.3	0.016
107687	M2	321.5	1.562
107687	S2	349.6	0.431
107687	N2	290.1	0.363
107687	K1	216.4	1.13
107687	M4	230.2	0.053
107687	O1	191.4	0.576
107687	M6	189.5	0.011
107687	MK3	91.2	0.148
107687	S4	22.9	0.006
107687	MN4	176.6	0.02
107687	NU2	290.7	0.039
107687	S6	335.9	0.006
107687	MU2	255.2	0.067
107687	2N2	194.6	0.058
107687	OO1	264.9	0.09
107687	LDA2	57.5	0.041
107687	M1	218.8	0.019
107687	J1	223.8	0.079
107687	RHO1	300.2	0.013
107687	Q1	173.6	0.082
107687	2Q1	353.6	0.029
107687	P1	213.7	0.36
107687	2SM2	328.7	0.009
107687	M3	21.5	0.041
107687	L2	7	0.045
107687	2MK3	66.5	0.08
107687	K2	47.1	0.116
107687	M8	243.4	0.013
107687	MS4	349	0.026
107688	M2	321.9	1.59
107688	S2	350.2	0.438
107688	N2	291.1	0.365
107688	K1	217.2	1.153
107688	M4	237.5	0.052
107688	O1	191.2	0.587
107688	M6	189.5	0.013
107688	MK3	91.4	0.142
107688	S4	4.5	0.006
107688	MN4	181	0.019
107688	NU2	292.7	0.039
107688	S6	345.1	0.005
107688	MU2	250.9	0.066
107688	2N2	192.7	0.058
107688	OO1	266.4	0.09
107688	LDA2	57.4	0.045
107688	M1	208	0.016
107688	J1	218	0.08
107688	RHO1	305.7	0.013
107688	Q1	171.6	0.084
107688	2Q1	338.3	0.028
107688	P1	213.3	0.379
107688	2SM2	311.7	0.008
107688	M3	14.7	0.038
107688	L2	2.2	0.047
107688	2MK3	66.3	0.079
107688	K2	48.3	0.122
107688	M8	227	0.012
107688	MS4	350.7	0.036
107689	M2	322.3	1.615
107689	S2	350.5	0.442
107689	N2	292.3	0.365
107689	K1	217.9	1.176
107689	M4	243.1	0.052
107689	O1	191.3	0.596
107689	M6	189.8	0.014
107689	MK3	89.9	0.136
107689	S4	336	0.006
107689	MN4	185	0.018
107689	NU2	293.9	0.041
107689	S6	3.3	0.003
107689	MU2	245.6	0.066
107689	2N2	191.3	0.056
107689	OO1	266.7	0.088
107689	LDA2	56.6	0.046
107689	M1	188.4	0.013
107689	J1	211.3	0.083
107689	RHO1	308.4	0.015
107689	Q1	168.8	0.086
107689	2Q1	323.1	0.028
107689	P1	212.6	0.395
107689	2SM2	298.9	0.008
107689	M3	9.1	0.036
107689	L2	358.4	0.05
107689	2MK3	65	0.076
107689	K2	49.9	0.128
107689	M8	212	0.012
107689	MS4	350.7	0.045
107690	M2	322.5	1.635
107690	S2	350.7	0.444
107690	N2	293.4	0.365
107690	K1	218.5	1.196
107690	M4	248.6	0.051
107690	O1	191.5	0.604
107690	M6	189.3	0.015
107690	MK3	87	0.127
107690	S4	317.4	0.008
107690	MN4	186.1	0.018
107690	NU2	297	0.043
107690	MU2	241.4	0.067
107690	2N2	189.3	0.055
107690	OO1	267.9	0.085
107690	LDA2	56.3	0.046
107690	M1	158.5	0.012
107690	J1	205.3	0.086
107690	RHO1	306.2	0.015
107690	Q1	166.8	0.086
107690	2Q1	306.9	0.028
107690	P1	211.9	0.409
107690	2SM2	286.9	0.008
107690	M3	4.8	0.036
107690	L2	355.2	0.052
107690	2MK3	62.6	0.074
107690	K2	50.1	0.134
107690	M8	198.2	0.012
107690	MS4	350.1	0.051
107691	M2	322.8	1.646
107691	S2	350.8	0.445
107691	N2	294.4	0.364
107691	K1	219.1	1.212
107691	M4	253.5	0.05
107691	O1	191.8	0.612
107691	M6	188.7	0.017
107691	MK3	82.7	0.116
107691	S4	314.3	0.01
107691	MN4	188.9	0.019
107691	NU2	301.5	0.045
107691	MU2	238.5	0.069
107691	2N2	187.6	0.055
107691	OO1	270	0.081
107691	LDA2	55.4	0.046
107691	M1	132.2	0.014
107691	J1	200.9	0.09
107691	RHO1	297.4	0.012
107691	Q1	164.5	0.085
107691	2Q1	290.1	0.028
107691	P1	211.5	0.421
107691	2SM2	282.2	0.01
107691	M3	1.2	0.037
107691	L2	352.7	0.053
107691	2MK3	59.3	0.073
107691	K2	49.2	0.138
107691	M8	185	0.013
107691	MS4	350.2	0.056
107692	M2	323.1	1.649
107692	S2	350.7	0.446
107692	N2	295.3	0.363
107692	K1	219.8	1.222
107692	M4	258.3	0.048
107692	O1	192.2	0.62
107692	M6	189.7	0.019
107692	MK3	77.6	0.104
107692	S4	317.7	0.012
107692	MN4	190.3	0.019
107692	NU2	306.5	0.047
107692	S6	129.8	0.003
107692	MU2	237.4	0.07
107692	2N2	186	0.057
107692	OO1	273	0.075
107692	LDA2	54.2	0.047
107692	M1	118.4	0.018
107692	J1	198.5	0.095
107692	RHO1	288.2	0.01
107692	Q1	162.2	0.084
107692	2Q1	276.5	0.031
107692	P1	211.3	0.43
107692	2SM2	282.5	0.011
107692	M3	357.4	0.037
107692	L2	351.2	0.052
107692	2MK3	54.9	0.074
107692	K2	47.5	0.141
107692	M8	172	0.014
107692	MS4	350.6	0.059
107693	M2	323.4	1.645
107693	S2	350.4	0.446
107693	N2	296.1	0.363
107693	K1	220.4	1.229
107693	M4	263.2	0.046
107693	O1	192.6	0.627
107693	M6	194.2	0.02
107693	MK3	71.7	0.091
107693	S4	325.9	0.014
107693	MN4	189.7	0.018
107693	NU2	311.2	0.048
107693	S6	143.7	0.003
107693	MU2	236.7	0.07
107693	2N2	185.9	0.061
107693	OO1	277.8	0.07
107693	LDA2	53.2	0.047
107693	M1	110.7	0.023
107693	J1	197.4	0.097
107693	RHO1	265.2	0.009
107693	Q1	159.4	0.082
107693	2Q1	267.9	0.035
107693	P1	211.5	0.438
107693	2SM2	284.8	0.013
107693	M3	354.5	0.036
107693	L2	351	0.05
107693	2MK3	51.7	0.076
107693	K2	46.6	0.142
107693	M8	159.5	0.016
107693	MS4	350.2	0.059
107694	M2	323.6	1.633
107694	S2	350	0.445
107694	N2	296.8	0.361
107694	K1	221.1	1.233
107694	M4	268.7	0.043
107694	O1	193.1	0.633
107694	M6	202.5	0.022
107694	MK3	64.3	0.078
107694	S4	331.9	0.016
107694	MN4	186	0.016
107694	NU2	314.4	0.049
107694	MU2	236.2	0.067
107694	2N2	187.5	0.062
107694	OO1	285.2	0.066
107694	LDA2	52	0.046
107694	M1	108.8	0.026
107694	J1	197.1	0.097
107694	RHO1	235.9	0.008
107694	Q1	157.3	0.08
107694	2Q1	262.5	0.037
107694	P1	211.7	0.445
107694	2SM2	287.7	0.015
107694	M3	351.5	0.034
107694	L2	352.2	0.046
107694	2MK3	49.5	0.078
107694	K2	45.9	0.14
107694	M8	150.9	0.019
107694	MS4	349	0.058
107695	M2	323.8	1.61
107695	S2	349.8	0.438
107695	N2	297.8	0.355
107695	K1	221.5	1.237
107695	M4	274.5	0.04
107695	O1	193.3	0.633
107695	M6	207.9	0.021
107695	MK3	53.7	0.062
107695	S4	332.6	0.019
107695	MN4	193.4	0.016
107695	NU2	311.3	0.048
107695	MU2	231.5	0.061
107695	2N2	191.9	0.059
107695	OO1	295.1	0.066
107695	LDA2	46.8	0.042
107695	M1	99.6	0.031
107695	J1	195.7	0.099
107695	RHO1	176.8	0.008
107695	Q1	157.6	0.072
107695	2Q1	258.7	0.037
107695	P1	212	0.447
107695	2SM2	287	0.016
107695	M3	344.6	0.028
107695	L2	357.7	0.045
107695	2MK3	50	0.075
107695	K2	45.7	0.14
107695	M8	149.4	0.022
107695	MS4	345.5	0.058
107696	M2	287.9	3.024
107696	S2	308.9	0.606
107696	N2	258.8	0.724
107696	K1	173.3	1.378
107696	M4	257.8	0.173
107696	O1	150.1	0.877
107696	M6	327.2	0.007
107696	MK3	144.2	0.145
107696	S4	37.7	0.012
107696	MN4	222.6	0.077
107696	2N2	185.8	0.115
107696	OO1	77.7	0.089
107696	M1	262.9	0.115
107696	J1	212.8	0.047
107696	Q1	150.2	0.132
107696	2Q1	295.8	0.021
107696	P1	179.8	0.371
107696	2SM2	212.9	0.019
107696	M3	159	0.04
107696	L2	319.1	0.15
107696	2MK3	278	0.037
107696	M8	114.9	0.013
107696	MS4	252.8	0.073
107697	M2	287.8	3.023
107697	S2	308.8	0.601
107697	N2	258.2	0.717
107697	K1	173.6	1.365
107697	M4	258.6	0.175
107697	O1	149	0.859
107697	M6	20.2	0.01
107697	MK3	147.9	0.134
107697	S4	355.7	0.011
107697	MN4	224.3	0.077
107697	S6	223.9	0.004
107697	2N2	182.5	0.114
107697	OO1	76.2	0.104
107697	M1	261.3	0.111
107697	J1	209.2	0.047
107697	Q1	147.4	0.118
107697	2Q1	304.3	0.017
107697	P1	178.1	0.369
107697	2SM2	221.5	0.022
107697	M3	154	0.047
107697	L2	320.1	0.16
107697	2MK3	270.1	0.052
107697	M8	89	0.017
107697	MS4	259.6	0.075
107698	M2	288.2	2.847
107698	S2	310.1	0.532
107698	N2	257.7	0.663
107698	K1	173.1	1.244
107698	M4	249	0.166
107698	O1	144.9	0.783
107698	M6	305.1	0.029
107698	MK3	154.3	0.164
107698	S4	309.8	0.01
107698	MN4	222.8	0.072
107698	S6	270.4	0.004
107698	2N2	166.9	0.102
107698	OO1	77	0.106
107698	M1	271	0.105
107698	J1	205	0.036
107698	Q1	146	0.093
107698	2Q1	325.2	0.037
107698	P1	172.5	0.344
107698	2SM2	219.3	0.031
107698	M3	151.5	0.054
107698	L2	317.2	0.177
107698	2MK3	226.4	0.079
107698	M8	66.7	0.031
107698	MS4	245.8	0.087
107699	M2	283.5	1.569
107699	S2	312.4	0.327
107699	N2	261.2	0.346
107699	K1	187.1	0.651
107699	M4	164.6	0.099
107699	O1	170.4	0.235
107699	M6	333.6	0.076
107699	MK3	63.4	0.101
107699	S4	107.3	0.015
107699	MN4	163.3	0.03
107699	S6	168.9	0.008
107699	2N2	181.1	0.018
107699	OO1	77.2	0.028
107699	M1	192.1	0.025
107699	J1	200.6	0.045
107699	Q1	156.4	0.056
107699	2Q1	200.8	0.018
107699	P1	197.1	0.164
107699	2SM2	132.1	0.011
107699	M3	47.6	0.061
107699	L2	296.6	0.086
107699	2MK3	213.7	0.058
107699	K2	328.9	0.055
107699	M8	193.2	0.011
107699	MS4	177.5	0.104
107700	M2	283.4	1.961
107700	S2	312	0.4
107700	N2	259.3	0.431
107700	K1	188.6	0.872
107700	M4	173.1	0.088
107700	O1	172.7	0.319
107700	M6	328.6	0.094
107700	MK3	59.9	0.093
107700	S4	95.9	0.011
107700	MN4	157	0.021
107700	S6	144.7	0.011
107700	2N2	196.3	0.023
107700	OO1	52.1	0.038
107700	M1	191.9	0.034
107700	J1	198.7	0.035
107700	Q1	166.5	0.068
107700	2Q1	190.4	0.037
107700	P1	186.8	0.228
107700	2SM2	104.2	0.011
107700	M3	43.9	0.061
107700	L2	295.1	0.097
107700	2MK3	205.7	0.078
107700	K2	334.8	0.062
107700	M8	167.4	0.008
107700	MS4	175.1	0.111
107701	M2	283.5	1.919
107701	S2	311.5	0.386
107701	N2	258.6	0.414
107701	K1	188.5	0.886
107701	M4	184.6	0.071
107701	O1	172.5	0.328
107701	M6	327	0.098
107701	MK3	60.4	0.079
107701	S4	66.8	0.008
107701	MN4	163.1	0.014
107701	S6	149.2	0.012
107701	2N2	192	0.026
107701	OO1	34.4	0.032
107701	M1	184.5	0.026
107701	J1	175.3	0.02
107701	Q1	166.7	0.058
107701	2Q1	181.5	0.042
107701	P1	179.7	0.23
107701	2SM2	88.3	0.007
107701	M3	43	0.05
107701	L2	298.1	0.094
107701	2MK3	198.5	0.087
107701	K2	342.2	0.061
107701	M8	166.2	0.01
107701	MS4	174.8	0.1
107702	M2	278.3	1.038
107702	S2	297.6	0.205
107702	N2	259.1	0.223
107702	K1	186.9	0.456
107702	M4	200.8	0.088
107702	O1	161.5	0.205
107702	M6	330.4	0.051
107702	MK3	88.4	0.114
107702	S4	158.2	0.018
107702	MN4	178.5	0.04
107702	S6	190.3	0.007
107702	2N2	19	0.012
107702	OO1	26	0.037
107702	M1	188.3	0.032
107702	J1	178.5	0.025
107702	Q1	155	0.055
107702	2Q1	169.8	0.011
107702	P1	182.4	0.121
107702	2SM2	151.9	0.011
107702	M3	47.6	0.039
107702	L2	284	0.067
107702	2MK3	205.8	0.042
107702	K2	148.3	0.026
107702	M8	211.4	0.004
107702	MS4	190.1	0.099
107703	M2	278.6	1.312
107703	S2	299.5	0.241
107703	N2	258.8	0.284
107703	K1	188.4	0.608
107703	M4	199.6	0.127
107703	O1	162.9	0.257
107703	M6	323.9	0.07
107703	MK3	76.9	0.111
107703	S4	179.5	0.02
107703	MN4	177.5	0.045
107703	S6	167.9	0.01
107703	2N2	2.9	0.021
107703	OO1	39.2	0.044
107703	M1	197.7	0.04
107703	J1	169.8	0.021
107703	Q1	154.8	0.073
107703	2Q1	167.9	0.023
107703	P1	171.8	0.166
107703	2SM2	137.2	0.013
107703	M3	51.7	0.049
107703	L2	282.9	0.078
107703	2MK3	219.3	0.076
107703	K2	28.2	0.014
107703	M8	190.7	0.009
107703	MS4	191.8	0.126
107704	M2	278.3	1.314
107704	S2	300.1	0.24
107704	N2	257.7	0.28
107704	K1	187.5	0.623
107704	M4	203.9	0.135
107704	O1	159.8	0.268
107704	M6	329.3	0.064
107704	MK3	79.3	0.102
107704	S4	175.3	0.02
107704	MN4	191.9	0.047
107704	S6	175.7	0.013
107704	2N2	23.2	0.023
107704	OO1	42.8	0.031
107704	M1	193.8	0.03
107704	J1	136.2	0.021
107704	Q1	149.5	0.074
107704	2Q1	160	0.019
107704	P1	168	0.174
107704	2SM2	146.2	0.012
107704	M3	57.7	0.041
107704	L2	287.9	0.081
107704	2MK3	219.3	0.091
107704	K2	347.9	0.029
107704	M8	218.8	0.013
107704	MS4	193.3	0.12
107705	M2	326.1	1.207
107705	S2	355.2	0.335
107705	N2	295.9	0.292
107705	K1	221	0.916
107705	M4	45.8	0.034
107705	O1	190.4	0.477
107705	M6	4.1	0.025
107705	MK3	341.4	0.052
107705	S4	114.5	0.016
107705	MN4	131.8	0.01
107705	NU2	307.7	0.054
107705	S6	85.9	0.006
107705	MU2	236.4	0.038
107705	2N2	283.4	0.043
107705	OO1	133.5	0.014
107705	LDA2	70.1	0.004
107705	M1	160.5	0.071
107705	J1	222.3	0.094
107705	RHO1	82.4	0.031
107705	Q1	170.3	0.071
107705	2Q1	9.6	0.031
107705	P1	219.5	0.381
107705	2SM2	350.2	0.005
107705	M3	308.3	0.002
107705	L2	35.8	0.009
107705	2MK3	205.6	0.04
107705	K2	11.9	0.106
107705	M8	16	0.012
107705	MS4	72.4	0.036
107706	M2	326.3	1.291
107706	S2	355.5	0.36
107706	N2	296.1	0.311
107706	K1	219.9	0.982
107706	M4	33.5	0.039
107706	O1	188.3	0.515
107706	M6	7	0.022
107706	MK3	323.5	0.034
107706	S4	111.4	0.015
107706	NU2	316.8	0.057
107706	S6	92.2	0.009
107706	MU2	230.3	0.048
107706	2N2	285.9	0.04
107706	OO1	163.7	0.005
107706	LDA2	63.9	0.006
107706	M1	160.3	0.061
107706	J1	224.3	0.092
107706	RHO1	85.8	0.033
107706	Q1	164.6	0.073
107706	2Q1	17.6	0.03
107706	P1	217.2	0.386
107706	2SM2	330.7	0.007
107706	M3	310.1	0.008
107706	L2	48.4	0.013
107706	2MK3	194.6	0.039
107706	K2	14.9	0.113
107706	M8	33.5	0.013
107706	MS4	59.9	0.039
107707	M2	326.3	1.359
107707	S2	355.5	0.382
107707	N2	296.7	0.324
107707	K1	218.7	1.036
107707	M4	25.9	0.044
107707	O1	187.1	0.547
107707	M6	7	0.021
107707	MK3	291.6	0.023
107707	S4	105.2	0.015
107707	MN4	342.3	0.01
107707	NU2	321	0.059
107707	S6	96	0.011
107707	MU2	229.8	0.056
107707	2N2	280.1	0.039
107707	OO1	258.1	0.013
107707	LDA2	63.1	0.006
107707	M1	158.5	0.055
107707	J1	226.4	0.091
107707	RHO1	85.8	0.033
107707	Q1	159.6	0.078
107707	2Q1	22.2	0.029
107707	P1	214.8	0.385
107707	2SM2	318.6	0.008
107707	M3	319.8	0.012
107707	L2	48.4	0.016
107707	2MK3	180.9	0.038
107707	K2	17.1	0.118
107707	M8	49.2	0.014
107707	MS4	51.5	0.047
107708	M2	326.2	1.417
107708	S2	355.1	0.401
107708	N2	297.3	0.334
107708	K1	217.4	1.08
107708	M4	21.4	0.049
107708	O1	186.1	0.574
107708	M6	6.7	0.021
107708	MK3	243.8	0.022
107708	S4	98.7	0.014
107708	MN4	345.5	0.019
107708	NU2	322.5	0.06
107708	S6	100.6	0.012
107708	MU2	232.1	0.062
107708	2N2	267.8	0.04
107708	OO1	266.5	0.029
107708	LDA2	58.5	0.005
107708	M1	157.5	0.051
107708	J1	227.7	0.092
107708	RHO1	82.8	0.031
107708	Q1	157.1	0.086
107708	2Q1	22.7	0.027
107708	P1	212.4	0.382
107708	2SM2	307.2	0.008
107708	M3	325.2	0.015
107708	L2	45.6	0.018
107708	2MK3	163.4	0.039
107708	K2	18.4	0.12
107708	M8	58.9	0.016
107708	MS4	46.7	0.056
107709	M2	326.1	1.467
107709	S2	354.6	0.418
107709	N2	297.6	0.34
107709	K1	216.1	1.117
107709	M4	16.7	0.053
107709	O1	184.9	0.596
107709	M6	3.7	0.021
107709	MK3	209.2	0.031
107709	S4	95.1	0.013
107709	MN4	349.3	0.026
107709	NU2	322.1	0.062
107709	S6	109.1	0.013
107709	MU2	235.5	0.067
107709	2N2	254.4	0.045
107709	OO1	268.1	0.045
107709	LDA2	44.7	0.004
107709	M1	158.7	0.05
107709	J1	228.5	0.093
107709	RHO1	78.9	0.029
107709	Q1	157.2	0.096
107709	2Q1	21.3	0.026
107709	P1	210.1	0.378
107709	2SM2	297.4	0.009
107709	M3	328	0.017
107709	L2	41.4	0.02
107709	2MK3	145.7	0.045
107709	K2	19.4	0.122
107709	M8	62.3	0.018
107709	MS4	43.6	0.064
107710	M2	325.9	1.51
107710	S2	354	0.431
107710	N2	297.8	0.343
107710	K1	214.8	1.145
107710	M4	12.3	0.058
107710	O1	183.7	0.615
107710	M6	359.1	0.022
107710	MK3	190.9	0.044
107710	S4	97.3	0.012
107710	MN4	352.2	0.03
107710	NU2	320	0.065
107710	S6	115.1	0.013
107710	MU2	237.9	0.071
107710	2N2	244.9	0.052
107710	OO1	269.5	0.06
107710	LDA2	42	0.004
107710	M1	160.6	0.051
107710	J1	228.5	0.093
107710	RHO1	76.7	0.027
107710	Q1	158.4	0.105
107710	2Q1	17.4	0.026
107710	P1	208.2	0.37
107710	2SM2	293.3	0.009
107710	M3	331.7	0.02
107710	L2	35.4	0.021
107710	2MK3	132.6	0.056
107710	K2	20.9	0.123
107710	M8	63.1	0.019
107710	MS4	40.4	0.071
107711	M2	325.8	1.548
107711	S2	353.5	0.442
107711	N2	298.1	0.344
107711	K1	213.4	1.164
107711	M4	7.7	0.063
107711	O1	182.4	0.63
107711	M6	353.7	0.024
107711	MK3	182	0.059
107711	S4	98.6	0.011
107711	MN4	353.8	0.031
107711	NU2	317	0.066
107711	S6	118.2	0.011
107711	MU2	239.9	0.075
107711	2N2	238.4	0.059
107711	OO1	269.9	0.072
107711	LDA2	63	0.004
107711	M1	162	0.052
107711	J1	228.1	0.094
107711	RHO1	77.5	0.025
107711	Q1	159.6	0.115
107711	2Q1	13.4	0.027
107711	P1	206.8	0.362
107711	2SM2	285.5	0.01
107711	M3	334.1	0.021
107711	L2	26.1	0.022
107711	2MK3	124.8	0.07
107711	K2	23.1	0.125
107711	M8	62	0.018
107711	MS4	37.1	0.077
107712	M2	325.7	1.581
107712	S2	353.3	0.45
107712	N2	298.4	0.345
107712	K1	212.2	1.177
107712	M4	3.9	0.069
107712	O1	181.2	0.641
107712	M6	348.4	0.027
107712	MK3	176.6	0.074
107712	S4	94.1	0.009
107712	MN4	353.6	0.031
107712	NU2	313.6	0.066
107712	S6	127.8	0.009
107712	MU2	242.1	0.079
107712	2N2	232.2	0.066
107712	OO1	270.2	0.082
107712	LDA2	73.9	0.006
107712	M1	160.3	0.053
107712	J1	227.7	0.092
107712	RHO1	81.5	0.02
107712	Q1	159.9	0.123
107712	2Q1	9.4	0.026
107712	P1	205.8	0.354
107712	2SM2	280.2	0.011
107712	M3	335.6	0.021
107712	L2	16.8	0.023
107712	2MK3	119.4	0.083
107712	K2	25.2	0.129
107712	M8	63.2	0.017
107712	MS4	34.2	0.084
107713	M2	325.7	1.612
107713	S2	353	0.458
107713	N2	298.6	0.347
107713	K1	211.1	1.185
107713	M4	1.3	0.076
107713	O1	180.2	0.649
107713	M6	342.9	0.031
107713	MK3	173.2	0.086
107713	S4	94.8	0.006
107713	MN4	352.3	0.03
107713	NU2	310.9	0.064
107713	S6	149.3	0.007
107713	MU2	243.8	0.084
107713	2N2	227.5	0.072
107713	OO1	270.7	0.093
107713	LDA2	71.6	0.009
107713	M1	156.2	0.054
107713	J1	227.7	0.089
107713	RHO1	87.3	0.016
107713	Q1	160.1	0.129
107713	2Q1	4.7	0.026
107713	P1	205.1	0.347
107713	2SM2	272.9	0.013
107713	M3	333.3	0.019
107713	L2	12.1	0.025
107713	2MK3	114.1	0.095
107713	K2	26.4	0.133
107713	M8	68.3	0.015
107713	MS4	31.5	0.091
107714	M2	325.8	1.643
107714	S2	352.7	0.466
107714	N2	298.5	0.351
107714	K1	210.1	1.191
107714	M4	0.1	0.083
107714	O1	179.3	0.655
107714	M6	339.1	0.034
107714	MK3	171.5	0.096
107714	S4	97.9	0.003
107714	MN4	348	0.029
107714	NU2	308.8	0.062
107714	S6	174	0.007
107714	MU2	244.8	0.09
107714	2N2	223.9	0.077
107714	OO1	270	0.105
107714	LDA2	66.6	0.012
107714	M1	150.1	0.055
107714	J1	226.5	0.087
107714	RHO1	97.3	0.014
107714	Q1	161	0.132
107714	2Q1	0.1	0.027
107714	P1	204.5	0.341
107714	2SM2	268	0.016
107714	M3	327.6	0.017
107714	L2	11.7	0.028
107714	2MK3	108.9	0.107
107714	K2	27.2	0.134
107714	M8	76.7	0.013
107714	MS4	28.8	0.098
107715	M2	326	1.67
107715	S2	352.8	0.468
107715	N2	298.7	0.35
107715	K1	208.8	1.196
107715	M4	0.4	0.091
107715	O1	178	0.656
107715	M6	337.8	0.036
107715	MK3	171.3	0.102
107715	MN4	340	0.028
107715	NU2	303.5	0.064
107715	S6	178.6	0.008
107715	MU2	242.2	0.099
107715	2N2	222.1	0.076
107715	OO1	269.2	0.117
107715	LDA2	57.8	0.012
107715	M1	138.5	0.057
107715	J1	220.9	0.084
107715	RHO1	113.6	0.018
107715	Q1	163.4	0.128
107715	2Q1	353.1	0.028
107715	P1	204.4	0.332
107715	2SM2	265.9	0.019
107715	M3	307	0.015
107715	L2	18.9	0.038
107715	2MK3	104.1	0.119
107715	K2	29.9	0.135
107715	M8	93.1	0.012
107715	MS4	26.3	0.102
107716	M2	316.3	0.462
107716	S2	333.5	0.146
107716	N2	291.2	0.123
107716	K1	212.4	0.263
107716	M4	228.8	0.022
107716	O1	199.1	0.057
107716	M6	268.9	0.007
107716	MK3	92.7	0.073
107716	S4	261	0.004
107716	MN4	250.2	0.015
107716	S6	262.9	0.004
107716	2N2	232.2	0.011
107716	OO1	287.2	0.027
107716	M1	11.4	0.009
107716	J1	346.8	0.012
107716	Q1	69.4	0.025
107716	2Q1	59.7	0.021
107716	P1	195.2	0.058
107716	2SM2	245.8	0.01
107716	M3	85	0.019
107716	L2	15.5	0.018
107716	2MK3	75.4	0.028
107716	K2	68.3	0.02
107716	M8	264	0.008
107716	MS4	239.6	0.03
107717	M2	327	0.505
107717	S2	5.2	0.128
107717	N2	296.4	0.137
107717	K1	218.7	0.288
107717	M4	217.6	0.022
107717	O1	192.5	0.109
107717	M6	249.7	0.018
107717	MK3	89.8	0.046
107717	S4	234.2	0.003
107717	MN4	185.5	0.005
107717	S6	326.7	0.008
107717	2N2	251.6	0.016
107717	OO1	188.2	0.007
107717	M1	69.6	0.004
107717	J1	344.1	0.012
107717	Q1	63	0.029
107717	2Q1	83.4	0.026
107717	P1	218	0.078
107717	2SM2	234.6	0.025
107717	M3	58.2	0.008
107717	L2	30.5	0.029
107717	2MK3	87.4	0.038
107717	K2	44.5	0.086
107717	M8	46.1	0.001
107717	MS4	246.3	0.027
107718	M2	331.4	0.501
107718	S2	24	0.168
107718	N2	302.1	0.116
107718	K1	234.4	0.303
107718	M4	210.8	0.037
107718	O1	193.7	0.099
107718	M6	274.4	0.007
107718	MK3	69.7	0.06
107718	S4	183.1	0.008
107718	MN4	204.6	0.024
107718	S6	353.4	0.008
107718	2N2	271.2	0.008
107718	OO1	190.7	0.018
107718	M1	92.5	0.014
107718	J1	181.7	0.054
107718	Q1	11.3	0.019
107718	2Q1	24.3	0.043
107718	P1	212.1	0.142
107718	2SM2	162.8	0.006
107718	M3	91.8	0.019
107718	L2	63.1	0.023
107718	2MK3	41.1	0.04
107718	K2	12.9	0.073
107718	M8	60	0.009
107718	MS4	284.5	0.038
107719	M2	330.8	1.02
107719	S2	357.7	0.257
107719	N2	302.8	0.228
107719	K1	216.1	0.754
107719	M4	334.2	0.043
107719	O1	174.7	0.505
107719	M6	69.8	0.026
107719	MK3	228.8	0.1
107719	S4	68.1	0.019
107719	MN4	316.6	0.02
107719	NU2	316.8	0.063
107719	S6	90.2	0.008
107719	MU2	203.6	0.031
107719	2N2	285.7	0.036
107719	OO1	286.7	0.022
107719	LDA2	148.2	0.012
107719	M1	38.6	0.018
107719	J1	206.7	0.049
107719	RHO1	122.8	0.027
107719	Q1	137.6	0.084
107719	2Q1	304	0.02
107719	P1	213.4	0.271
107719	2SM2	303.1	0.014
107719	M3	76.7	0.016
107719	L2	23.1	0.03
107719	2MK3	158.1	0.064
107719	K2	38.9	0.061
107719	M8	45.6	0.01
107719	MS4	91.7	0.034
107720	M2	331.9	1.068
107720	S2	358.4	0.276
107720	N2	304.2	0.234
107720	K1	217.3	0.789
107720	M4	340	0.04
107720	O1	177.2	0.511
107720	M6	79.6	0.026
107720	MK3	221.7	0.084
107720	S4	72.8	0.02
107720	MN4	314.1	0.02
107720	NU2	318.9	0.062
107720	S6	97.5	0.007
107720	MU2	222.4	0.033
107720	2N2	271.4	0.038
107720	OO1	295.2	0.031
107720	LDA2	153.3	0.01
107720	M1	55.2	0.021
107720	J1	207.7	0.052
107720	RHO1	112.5	0.033
107720	Q1	141.8	0.079
107720	2Q1	327.4	0.024
107720	P1	214.5	0.284
107720	2SM2	303.3	0.015
107720	M3	60.1	0.014
107720	L2	26.5	0.033
107720	2MK3	148.5	0.063
107720	K2	39.5	0.059
107720	M8	40.5	0.009
107720	MS4	92.3	0.04
107721	M2	332.9	1.103
107721	S2	358.9	0.293
107721	N2	305.2	0.241
107721	K1	218.5	0.815
107721	M4	344.5	0.034
107721	O1	179.5	0.514
107721	M6	82	0.023
107721	MK3	206.1	0.072
107721	S4	74.7	0.021
107721	MN4	312.5	0.021
107721	NU2	319.9	0.058
107721	S6	91.9	0.005
107721	MU2	238.5	0.037
107721	2N2	261.5	0.042
107721	OO1	299.1	0.039
107721	LDA2	157.1	0.01
107721	M1	69.5	0.025
107721	J1	209.1	0.056
107721	RHO1	105.6	0.04
107721	Q1	147.7	0.073
107721	2Q1	341.2	0.03
107721	P1	215.3	0.295
107721	2SM2	302	0.014
107721	M3	40.8	0.015
107721	L2	31	0.035
107721	2MK3	139.2	0.068
107721	K2	39.1	0.053
107721	M8	31.3	0.007
107721	MS4	98.2	0.043
107722	M2	333.7	1.129
107722	S2	359.7	0.309
107722	N2	305.7	0.249
107722	K1	219.6	0.835
107722	M4	345.5	0.029
107722	O1	181.5	0.521
107722	M6	76.9	0.019
107722	MK3	186.8	0.07
107722	S4	73.2	0.021
107722	MN4	312.3	0.021
107722	NU2	321.7	0.052
107722	S6	82.4	0.004
107722	MU2	246.9	0.045
107722	2N2	256.1	0.046
107722	OO1	302.7	0.047
107722	LDA2	153.6	0.011
107722	M1	77.5	0.03
107722	J1	211.2	0.06
107722	RHO1	103.5	0.045
107722	Q1	154.6	0.066
107722	2Q1	349.2	0.037
107722	P1	215.9	0.302
107722	2SM2	305.4	0.01
107722	M3	31.7	0.018
107722	L2	34.4	0.037
107722	2MK3	133.1	0.075
107722	K2	37.1	0.045
107722	M8	7.6	0.005
107722	MS4	106	0.044
107723	M2	334.2	1.148
107723	S2	0.7	0.322
107723	N2	306	0.255
107723	K1	220.4	0.849
107723	M4	341.4	0.028
107723	O1	183.3	0.529
107723	M6	69.9	0.015
107723	MK3	171.5	0.077
107723	S4	71.8	0.019
107723	MN4	315.5	0.02
107723	NU2	321.3	0.047
107723	S6	72.7	0.004
107723	MU2	251.1	0.051
107723	2N2	251.6	0.051
107723	OO1	307.4	0.054
107723	LDA2	148	0.012
107723	M1	81.7	0.034
107723	J1	212.1	0.065
107723	RHO1	102.7	0.049
107723	Q1	161.8	0.062
107723	2Q1	352.3	0.042
107723	P1	216	0.306
107723	2SM2	307.3	0.005
107723	M3	31.6	0.02
107723	L2	39.6	0.039
107723	2MK3	129.7	0.081
107723	K2	34.4	0.036
107723	M8	330.3	0.005
107723	MS4	113.7	0.041
107724	M2	334.6	1.16
107724	S2	2	0.332
107724	N2	306	0.258
107724	K1	220.9	0.858
107724	M4	334.2	0.029
107724	O1	184.9	0.536
107724	M6	62.9	0.012
107724	MK3	162.3	0.085
107724	S4	71.3	0.017
107724	MN4	320.8	0.018
107724	NU2	317	0.043
107724	S6	68.8	0.002
107724	MU2	253.8	0.056
107724	2N2	248.3	0.057
107724	OO1	307.4	0.063
107724	LDA2	134.8	0.014
107724	M1	82.6	0.037
107724	J1	210.9	0.069
107724	RHO1	105	0.05
107724	Q1	166.2	0.062
107724	2Q1	354.1	0.046
107724	P1	215.6	0.306
107724	M3	34.4	0.019
107724	L2	46	0.038
107724	2MK3	128.9	0.086
107724	K2	30	0.029
107724	M8	308.2	0.007
107724	MS4	119.2	0.035
107725	M2	334.8	1.169
107725	S2	3.2	0.339
107725	N2	305.9	0.259
107725	K1	221.1	0.863
107725	M4	328.1	0.03
107725	O1	185.9	0.544
107725	M6	52.8	0.011
107725	MK3	156.5	0.093
107725	S4	70	0.014
107725	MN4	324.9	0.017
107725	NU2	310.4	0.042
107725	MU2	256.1	0.057
107725	2N2	245.8	0.061
107725	OO1	305.8	0.071
107725	LDA2	123.9	0.017
107725	M1	81.3	0.038
107725	J1	208.7	0.073
107725	RHO1	108.2	0.049
107725	Q1	169.8	0.062
107725	2Q1	355.2	0.049
107725	P1	214.9	0.303
107725	M3	37.3	0.016
107725	L2	54.7	0.037
107725	2MK3	129.7	0.09
107725	K2	21.9	0.027
107725	M8	304.8	0.009
107725	MS4	122.4	0.027
107726	M2	334.8	1.173
107726	S2	4.2	0.344
107726	N2	305.6	0.259
107726	K1	221	0.865
107726	M4	324.2	0.032
107726	O1	186.7	0.551
107726	M6	39.6	0.012
107726	MK3	152.9	0.098
107726	S4	66.2	0.01
107726	MN4	327.8	0.015
107726	NU2	303.7	0.042
107726	MU2	257.7	0.058
107726	2N2	244.3	0.065
107726	OO1	304.2	0.079
107726	LDA2	115.2	0.019
107726	M1	81.6	0.039
107726	J1	206.8	0.077
107726	RHO1	111.6	0.045
107726	Q1	171.5	0.061
107726	2Q1	356.2	0.053
107726	P1	214.2	0.299
107726	M3	40.9	0.013
107726	L2	65.3	0.037
107726	2MK3	130.7	0.094
107726	K2	10.6	0.027
107726	M8	302.5	0.009
107726	MS4	121.4	0.018
107727	M2	334.7	1.176
107727	S2	4.8	0.345
107727	N2	305.1	0.258
107727	K1	220.5	0.866
107727	M4	319.3	0.033
107727	O1	187.4	0.558
107727	M6	25.7	0.014
107727	MK3	150.8	0.099
107727	S4	60.5	0.008
107727	MN4	330.1	0.014
107727	NU2	298	0.043
107727	S6	254.6	0.003
107727	MU2	259.3	0.058
107727	2N2	242.3	0.069
107727	OO1	302.7	0.086
107727	LDA2	112.5	0.022
107727	M1	83.2	0.041
107727	J1	204	0.08
107727	RHO1	116.1	0.04
107727	Q1	173	0.06
107727	2Q1	356.4	0.054
107727	P1	213.3	0.294
107727	2SM2	47.3	0.003
107727	M3	51	0.01
107727	L2	72.9	0.037
107727	2MK3	132	0.097
107727	K2	6.8	0.028
107727	M8	303.5	0.009
107727	MS4	116.7	0.011
107728	M2	334.6	1.179
107728	S2	5	0.343
107728	N2	304.5	0.258
107728	K1	220	0.866
107728	M4	314.1	0.035
107728	O1	187.8	0.564
107728	M6	15.9	0.017
107728	MK3	150	0.101
107728	S4	52.7	0.007
107728	MN4	330	0.012
107728	NU2	295.2	0.045
107728	S6	266.2	0.004
107728	MU2	261.1	0.059
107728	2N2	240	0.072
107728	OO1	301.2	0.09
107728	LDA2	111.4	0.025
107728	M1	85.2	0.043
107728	J1	200.9	0.081
107728	RHO1	122.6	0.035
107728	Q1	173.4	0.058
107728	2Q1	357.2	0.056
107728	P1	212.3	0.29
107728	2SM2	45.5	0.004
107728	M3	61.3	0.009
107728	L2	77	0.038
107728	2MK3	132.5	0.098
107728	K2	11.3	0.03
107728	M8	305.3	0.007
107728	MS4	102.7	0.006
107729	M2	334.6	1.183
107729	S2	4.8	0.34
107729	N2	304.2	0.257
107729	K1	219.4	0.866
107729	M4	308.6	0.035
107729	O1	188.2	0.568
107729	M6	12	0.02
107729	MK3	149.7	0.1
107729	S4	47.8	0.008
107729	MN4	321.9	0.012
107729	NU2	294	0.047
107729	S6	275.8	0.005
107729	MU2	264.3	0.059
107729	2N2	237.9	0.076
107729	OO1	299.2	0.091
107729	LDA2	113.1	0.027
107729	M1	85.7	0.047
107729	J1	197.5	0.081
107729	RHO1	128.5	0.031
107729	Q1	172.5	0.058
107729	2Q1	357.9	0.057
107729	P1	211	0.286
107729	2SM2	49.7	0.006
107729	M3	73.2	0.01
107729	L2	77.5	0.041
107729	2MK3	131.8	0.096
107729	K2	16.6	0.029
107729	M8	304.6	0.006
107729	MS4	69.5	0.005
107730	M2	334.7	1.188
107730	S2	4.4	0.335
107730	N2	303.9	0.253
107730	K1	218.8	0.867
107730	M4	305.3	0.034
107730	O1	188.5	0.571
107730	M6	9.2	0.022
107730	MK3	149.8	0.096
107730	S4	48.6	0.009
107730	MN4	310.7	0.014
107730	NU2	294.4	0.05
107730	S6	270	0.006
107730	MU2	268.9	0.057
107730	2N2	236	0.083
107730	OO1	298.4	0.091
107730	LDA2	121.4	0.028
107730	M1	85	0.051
107730	J1	193.7	0.079
107730	RHO1	134	0.029
107730	Q1	172.5	0.056
107730	2Q1	359.4	0.057
107730	P1	209.5	0.281
107730	2SM2	51.7	0.007
107730	M3	90	0.012
107730	L2	77.7	0.046
107730	2MK3	130.4	0.092
107730	K2	21.9	0.027
107730	M8	298.5	0.006
107730	MS4	32.8	0.008
107731	M2	334.8	1.192
107731	S2	3.9	0.332
107731	N2	303.8	0.251
107731	K1	218.3	0.87
107731	M4	305.5	0.032
107731	O1	188.6	0.574
107731	M6	5.6	0.023
107731	MK3	149.8	0.09
107731	S4	44.9	0.011
107731	MN4	306.6	0.017
107731	NU2	294.9	0.052
107731	S6	252.1	0.005
107731	MU2	273.9	0.057
107731	2N2	235	0.089
107731	OO1	298.7	0.09
107731	LDA2	129.2	0.029
107731	M1	82.4	0.054
107731	J1	189.4	0.075
107731	RHO1	136.1	0.028
107731	Q1	173.3	0.056
107731	2Q1	1.6	0.059
107731	P1	208.4	0.276
107731	2SM2	46.9	0.009
107731	M3	104.7	0.014
107731	L2	78.9	0.05
107731	2MK3	128.6	0.087
107731	K2	28.7	0.026
107731	M8	280.9	0.004
107731	MS4	18	0.015
107732	M2	334.7	1.194
107732	S2	3.4	0.332
107732	N2	303.5	0.251
107732	K1	218.1	0.873
107732	M4	312.9	0.031
107732	O1	188.4	0.575
107732	M6	358.2	0.024
107732	MK3	149.8	0.084
107732	S4	36.6	0.011
107732	MN4	305.9	0.019
107732	NU2	297.1	0.052
107732	S6	224.2	0.005
107732	MU2	278.1	0.06
107732	2N2	234.1	0.092
107732	OO1	298.8	0.091
107732	LDA2	135	0.03
107732	M1	76.9	0.055
107732	J1	186.6	0.072
107732	RHO1	133.6	0.027
107732	Q1	176.2	0.056
107732	2Q1	1	0.062
107732	P1	207.6	0.271
107732	2SM2	37.1	0.01
107732	M3	117.1	0.016
107732	L2	82.7	0.052
107732	2MK3	127	0.08
107732	K2	31.7	0.027
107732	M8	239.1	0.003
107732	MS4	10.6	0.025
107733	M2	334.6	1.194
107733	S2	2.5	0.333
107733	N2	303.5	0.255
107733	K1	218.1	0.877
107733	M4	328.2	0.033
107733	O1	187.9	0.574
107733	M6	346.1	0.024
107733	MK3	148.9	0.078
107733	S4	25.4	0.011
107733	MN4	303	0.022
107733	NU2	299.4	0.053
107733	S6	201.3	0.005
107733	MU2	280.3	0.065
107733	2N2	232.8	0.093
107733	OO1	297.9	0.094
107733	LDA2	141.4	0.03
107733	M1	69.4	0.055
107733	J1	187	0.069
107733	RHO1	128.1	0.027
107733	Q1	181.3	0.059
107733	2Q1	358	0.066
107733	P1	207.8	0.267
107733	2SM2	24.4	0.009
107733	M3	132.8	0.019
107733	L2	85.6	0.056
107733	2MK3	126.6	0.074
107733	K2	32.3	0.025
107733	M8	184.4	0.004
107733	MS4	4	0.035
107734	M2	334.9	1.149
107734	S2	4.2	0.32
107734	N2	304.7	0.243
107734	K1	215.6	0.857
107734	M4	330	0.062
107734	O1	183.5	0.552
107734	M6	348	0.026
107734	MK3	176	0.076
107734	S4	8.4	0.013
107734	MN4	294.8	0.036
107734	NU2	292	0.057
107734	S6	184.8	0.005
107734	MU2	271.6	0.065
107734	2N2	228.5	0.077
107734	OO1	291.8	0.108
107734	LDA2	160.5	0.024
107734	M1	54.4	0.07
107734	J1	183.1	0.066
107734	RHO1	112.6	0.041
107734	Q1	190.1	0.055
107734	2Q1	357.3	0.074
107734	P1	209.6	0.235
107734	2SM2	345.2	0.004
107734	M3	182.5	0.03
107734	L2	77.2	0.06
107734	2MK3	149.9	0.075
107734	K2	23.1	0.039
107734	M8	213.8	0.007
107734	MS4	348	0.056
107735	M2	348	0.914
107735	S2	17.6	0.246
107735	N2	318.2	0.246
107735	K1	215.5	0.691
107735	M4	10.7	0.067
107735	O1	179.8	0.497
107735	M6	301.9	0.022
107735	MK3	205.8	0.12
107735	S4	359.1	0.017
107735	MN4	359.3	0.038
107735	S6	38.2	0.011
107735	2N2	287.2	0.065
107735	OO1	283.6	0.144
107735	M1	53	0.026
107735	J1	172.6	0.032
107735	Q1	145.8	0.073
107735	2Q1	94.6	0.026
107735	P1	225.6	0.232
107735	2SM2	350	0.028
107735	M3	297.4	0.012
107735	L2	113.8	0.068
107735	2MK3	183.9	0.083
107735	M8	237.4	0.01
107735	MS4	23.8	0.049
107736	M2	337.6	0.896
107736	S2	349.3	0.197
107736	N2	313.3	0.252
107736	K1	222	0.553
107736	M4	28.2	0.037
107736	O1	190.2	0.544
107736	M6	286.5	0.033
107736	MK3	260.1	0.072
107736	S4	134.8	0.01
107736	MN4	46.5	0.013
107736	S6	20.2	0.004
107736	2N2	271.5	0.053
107736	OO1	317.2	0.103
107736	M1	113.6	0.034
107736	J1	186.2	0.08
107736	Q1	139.2	0.084
107736	2Q1	4.3	0.051
107736	P1	237.4	0.378
107736	2SM2	71.7	0.014
107736	M3	217.4	0.008
107736	L2	135.9	0.022
107736	2MK3	171.9	0.062
107736	M8	275.8	0.012
107736	MS4	44.9	0.035
107737	M2	337.3	0.871
107737	S2	346.1	0.18
107737	N2	312.4	0.245
107737	K1	220.8	0.53
107737	M4	30.8	0.032
107737	O1	189.5	0.535
107737	M6	300.3	0.029
107737	MK3	249.2	0.098
107737	S4	96.7	0.027
107737	MN4	46.8	0.019
107737	S6	354.6	0.005
107737	2N2	266	0.041
107737	OO1	311.6	0.087
107737	M1	91.5	0.024
107737	J1	188.6	0.079
107737	Q1	136.3	0.092
107737	2Q1	353.7	0.051
107737	P1	239.7	0.365
107737	2SM2	53	0.018
107737	M3	157.5	0.02
107737	L2	127.3	0.02
107737	2MK3	192.4	0.07
107737	M8	274	0.019
107737	MS4	46.9	0.057
107738	M2	306.9	0.834
107738	S2	326.7	0.225
107738	N2	281.7	0.22
107738	K1	182.9	0.44
107738	M4	113.5	0.031
107738	O1	154	0.3
107738	M6	281.1	0.021
107738	MK3	266	0.13
107738	S4	58.4	0.008
107738	MN4	50.9	0.016
107738	S6	70.4	0.011
107738	2N2	80.8	0.017
107738	OO1	129.2	0.038
107738	M1	247	0.022
107738	J1	208.3	0.034
107738	Q1	143.6	0.044
107738	2Q1	237.8	0.013
107738	P1	198.6	0.128
107738	2SM2	255.6	0.01
107738	M3	269	0.019
107738	L2	346	0.043
107738	2MK3	269.7	0.08
107738	K2	336.6	0.123
107738	M8	263.7	0.004
107738	MS4	320.6	0.011
107739	M2	310.3	0.993
107739	S2	332.1	0.27
107739	N2	283.3	0.246
107739	K1	187	0.516
107739	M4	134.3	0.014
107739	O1	156.7	0.367
107739	M6	277.9	0.01
107739	MK3	275	0.106
107739	S4	102.6	0.006
107739	MN4	24.2	0.008
107739	S6	147.9	0.002
107739	2N2	170.8	0.021
107739	OO1	150	0.043
107739	M1	313.1	0.023
107739	J1	186.6	0.04
107739	Q1	161.7	0.053
107739	2Q1	224.3	0.013
107739	P1	189.5	0.174
107739	2SM2	270.1	0.013
107739	M3	260.7	0.021
107739	L2	353.7	0.054
107739	2MK3	294.5	0.066
107739	K2	334.3	0.141
107739	M8	14.8	0.002
107739	MS4	270.7	0.018
107740	M2	311	1.049
107740	S2	340.9	0.304
107740	N2	283.5	0.256
107740	K1	189.9	0.553
107740	M4	305.3	0.029
107740	O1	155.7	0.414
107740	M6	39	0.004
107740	MK3	221.7	0.057
107740	S4	259.4	0.015
107740	MN4	257.1	0.012
107740	S6	221.1	0.011
107740	2N2	183.3	0.055
107740	OO1	169.3	0.056
107740	M1	318.2	0.033
107740	J1	191.8	0.06
107740	Q1	166	0.058
107740	2Q1	223.8	0.02
107740	P1	183.6	0.24
107740	2SM2	294.2	0.011
107740	M3	268	0.027
107740	L2	345.3	0.06
107740	2MK3	0.6	0.02
107740	K2	328.1	0.174
107740	M8	144.1	0.003
107740	MS4	298.5	0.049
107741	M2	341.5	0.761
107741	S2	0.1	0.207
107741	N2	321	0.178
107741	K1	201.2	0.711
107741	M4	106.6	0.036
107741	O1	168.8	0.298
107741	M6	305.8	0.028
107741	MK3	267.9	0.034
107741	S4	16	0.027
107741	MN4	357.3	0.021
107741	S6	207.5	0.003
107741	2N2	276.5	0.067
107741	OO1	235.7	0.137
107741	M1	173.9	0.012
107741	J1	219.1	0.031
107741	Q1	127.7	0.102
107741	2Q1	5.5	0.041
107741	P1	142.6	0.107
107741	2SM2	355.3	0.014
107741	M3	25.2	0.032
107741	L2	55.6	0.082
107741	2MK3	153.4	0.043
107741	M8	141.7	0.004
107741	MS4	76.6	0.025
107742	M2	321.5	0.693
107742	S2	347.8	0.218
107742	N2	309.7	0.191
107742	K1	227.6	0.419
107742	M4	334.2	0.015
107742	O1	203.4	0.231
107742	M6	69.3	0.008
107742	MK3	54.3	0.065
107742	S4	132.9	0.014
107742	MN4	36.1	0.004
107742	S6	18.5	0.014
107742	2N2	184.2	0.023
107742	OO1	315.4	0.013
107742	M1	144	0.01
107742	J1	167.7	0.025
107742	Q1	182.8	0.047
107742	2Q1	116.4	0.019
107742	P1	220.8	0.163
107742	2SM2	2.4	0.006
107742	M3	97.5	0.015
107742	L2	287.8	0.02
107742	2MK3	54.9	0.028
107742	M8	332.8	0.017
107742	MS4	203.9	0.026
107743	M2	316.2	0.704
107743	S2	344.2	0.22
107743	N2	305.9	0.178
107743	K1	224.5	0.349
107743	M4	308.7	0.023
107743	O1	207.2	0.222
107743	M6	126.4	0.002
107743	MK3	51.8	0.037
107743	S4	122.6	0.01
107743	MN4	228.7	0.003
107743	S6	4.8	0.009
107743	2N2	170.4	0.03
107743	OO1	4.3	0.031
107743	M1	211.6	0.027
107743	J1	269	0.023
107743	Q1	191.6	0.045
107743	2Q1	136.2	0.022
107743	P1	228.6	0.185
107743	2SM2	326.9	0.015
107743	M3	100.4	0.021
107743	L2	294.9	0.045
107743	2MK3	53.1	0.025
107743	M8	307.6	0.017
107743	MS4	221.2	0.022
107744	M2	345.3	0.774
107744	S2	359.2	0.228
107744	N2	334.3	0.177
107744	K1	221.7	0.497
107744	M4	233.1	0.016
107744	O1	198.9	0.262
107744	M6	223.8	0.02
107744	MK3	36.5	0.049
107744	S4	341.7	0.009
107744	MN4	315.7	0.028
107744	S6	353.3	0.006
107744	2N2	344.6	0.018
107744	OO1	76.4	0.024
107744	M1	198.7	0.044
107744	J1	233.4	0.054
107744	Q1	177.2	0.045
107744	2Q1	31.3	0.016
107744	P1	238.1	0.141
107744	2SM2	230.8	0.007
107744	M3	216.7	0.018
107744	L2	31.6	0.052
107744	2MK3	10.8	0.082
107744	M8	147.4	0.014
107744	MS4	16.3	0.037
107745	M2	345.6	0.796
107745	S2	358.8	0.234
107745	N2	333.8	0.179
107745	K1	220.8	0.509
107745	M4	235	0.019
107745	O1	197.9	0.272
107745	M6	229.7	0.022
107745	MK3	34.8	0.052
107745	S4	336.7	0.01
107745	MN4	311.8	0.025
107745	S6	342.7	0.007
107745	2N2	342.4	0.02
107745	OO1	69.3	0.026
107745	M1	200.6	0.045
107745	J1	231.8	0.054
107745	Q1	179.4	0.047
107745	2Q1	32.6	0.017
107745	P1	240.8	0.139
107745	2SM2	233.1	0.008
107745	M3	213.6	0.02
107745	L2	34.6	0.054
107745	2MK3	11.7	0.084
107745	M8	143.9	0.014
107745	MS4	13.9	0.038
107746	M2	345.8	0.814
107746	S2	358.5	0.239
107746	N2	333.1	0.179
107746	K1	219.9	0.518
107746	M4	235.6	0.02
107746	O1	197.1	0.281
107746	M6	234.4	0.025
107746	MK3	33	0.055
107746	S4	338.4	0.011
107746	MN4	306.7	0.023
107746	S6	333.8	0.008
107746	2N2	341.9	0.022
107746	OO1	65.5	0.027
107746	M1	201.8	0.046
107746	J1	230.6	0.055
107746	Q1	180.7	0.05
107746	2Q1	37.7	0.017
107746	P1	243.2	0.137
107746	2SM2	238.9	0.009
107746	M3	208.5	0.023
107746	L2	36.9	0.056
107746	2MK3	11.8	0.085
107746	M8	144	0.012
107746	MS4	11.9	0.039
107747	M2	346	0.832
107747	S2	358.3	0.243
107747	N2	332.6	0.179
107747	K1	218.9	0.527
107747	M4	236.2	0.021
107747	O1	196.4	0.29
107747	M6	238.4	0.027
107747	MK3	32.4	0.058
107747	S4	339.5	0.011
107747	MN4	302.5	0.019
107747	S6	329.6	0.008
107747	2N2	339	0.024
107747	OO1	61.2	0.028
107747	M1	201.2	0.046
107747	J1	229	0.056
107747	Q1	181.3	0.053
107747	2Q1	44.6	0.018
107747	P1	245.4	0.134
107747	2SM2	242.6	0.011
107747	M3	201.6	0.027
107747	L2	38.9	0.057
107747	2MK3	12	0.086
107747	M8	147.3	0.011
107747	MS4	8.8	0.039
107748	M2	346.2	0.847
107748	S2	358.1	0.247
107748	N2	332.2	0.179
107748	K1	218	0.539
107748	M4	234.3	0.021
107748	O1	196.1	0.299
107748	M6	242.1	0.029
107748	MK3	31.9	0.061
107748	S4	337.8	0.012
107748	MN4	294.9	0.016
107748	S6	325.2	0.008
107748	2N2	337.3	0.026
107748	OO1	60.8	0.028
107748	M1	199.5	0.046
107748	J1	228.2	0.057
107748	Q1	182.3	0.056
107748	2Q1	50	0.019
107748	P1	247	0.13
107748	2SM2	243.2	0.012
107748	M3	196.2	0.029
107748	L2	41	0.058
107748	2MK3	12.3	0.088
107748	M8	150	0.009
107748	MS4	6.5	0.039
107749	M2	346.3	0.861
107749	S2	358.1	0.25
107749	N2	331.6	0.18
107749	K1	217.3	0.549
107749	M4	235.3	0.02
107749	O1	195.9	0.309
107749	M6	245.8	0.031
107749	MK3	31.8	0.064
107749	S4	332.5	0.012
107749	MN4	286.5	0.012
107749	S6	324.1	0.008
107749	2N2	333.3	0.027
107749	OO1	59	0.029
107749	M1	196.4	0.047
107749	J1	227.4	0.058
107749	Q1	183.2	0.059
107749	2Q1	55.6	0.018
107749	P1	248.3	0.128
107749	2SM2	245.8	0.013
107749	M3	190.4	0.032
107749	L2	42.6	0.059
107749	2MK3	12.2	0.09
107749	M8	149.3	0.009
107749	MS4	3.2	0.039
107750	M2	346.4	0.875
107750	S2	358	0.251
107750	N2	331.2	0.181
107750	K1	216.8	0.56
107750	M4	233.5	0.019
107750	O1	195.9	0.32
107750	M6	250.7	0.033
107750	MK3	30.5	0.068
107750	S4	330.9	0.013
107750	MN4	276.6	0.009
107750	S6	319.1	0.008
107750	2N2	330.8	0.028
107750	OO1	57.8	0.029
107750	M1	194.3	0.049
107750	J1	226.2	0.06
107750	Q1	184	0.063
107750	2Q1	60.1	0.018
107750	P1	249.6	0.126
107750	2SM2	246.2	0.015
107750	M3	185.6	0.034
107750	L2	45	0.061
107750	2MK3	11.8	0.091
107750	M8	149.1	0.007
107750	MS4	359.9	0.04
107751	M2	346.5	0.889
107751	S2	358.2	0.252
107751	N2	330.9	0.183
107751	K1	216.6	0.569
107751	M4	233.3	0.018
107751	O1	196.3	0.331
107751	M6	253.6	0.035
107751	MK3	29.5	0.071
107751	S4	324.7	0.014
107751	MN4	269.6	0.005
107751	S6	319.7	0.008
107751	2N2	327.8	0.03
107751	OO1	57.5	0.03
107751	M1	192.2	0.05
107751	J1	225.9	0.061
107751	Q1	183.2	0.064
107751	2Q1	68.2	0.017
107751	P1	250.9	0.128
107751	2SM2	241.8	0.015
107751	M3	181.1	0.037
107751	L2	47.4	0.063
107751	2MK3	11.6	0.091
107751	M8	145.2	0.006
107751	MS4	355.3	0.041
107752	M2	346.5	0.903
107752	S2	358.2	0.252
107752	N2	330.8	0.187
107752	K1	216.4	0.576
107752	M4	231	0.017
107752	O1	196.6	0.341
107752	M6	256	0.037
107752	MK3	27.9	0.075
107752	S4	319.2	0.014
107752	MN4	278.7	0.002
107752	S6	315.2	0.008
107752	2N2	322.5	0.032
107752	OO1	58.1	0.03
107752	M1	188.6	0.052
107752	J1	225.4	0.062
107752	Q1	182.8	0.067
107752	2Q1	77.8	0.016
107752	P1	253.1	0.13
107752	2SM2	241.7	0.017
107752	M3	175.8	0.038
107752	L2	48.6	0.065
107752	2MK3	11.7	0.089
107752	M8	147.1	0.006
107752	MS4	352	0.041
107753	M2	346.4	0.917
107753	S2	358.4	0.253
107753	N2	330.5	0.191
107753	K1	216.4	0.581
107753	M4	229.1	0.015
107753	O1	196.8	0.351
107753	M6	257.2	0.038
107753	MK3	25.8	0.078
107753	S4	313.4	0.013
107753	MN4	36.9	0.002
107753	S6	309.7	0.007
107753	2N2	317.1	0.034
107753	OO1	61.9	0.028
107753	M1	184.7	0.054
107753	J1	225.9	0.063
107753	Q1	181.7	0.069
107753	2Q1	88.8	0.016
107753	P1	255.9	0.133
107753	2SM2	241	0.018
107753	M3	171.6	0.041
107753	L2	49.8	0.068
107753	2MK3	11.7	0.087
107753	M8	156.3	0.006
107753	MS4	349.9	0.041
107754	M2	346.3	0.931
107754	S2	358.6	0.254
107754	N2	330.5	0.197
107754	K1	216.6	0.586
107754	M4	225	0.015
107754	O1	197.3	0.359
107754	M6	257.5	0.039
107754	MK3	24.2	0.082
107754	S4	307.5	0.012
107754	MN4	48.1	0.005
107754	S6	303.9	0.006
107754	2N2	311.9	0.037
107754	OO1	62.8	0.026
107754	M1	180.6	0.056
107754	J1	226.2	0.065
107754	Q1	180.9	0.071
107754	2Q1	99.7	0.015
107754	P1	258.5	0.138
107754	2SM2	239.7	0.019
107754	M3	166.6	0.043
107754	L2	50.4	0.07
107754	2MK3	11.3	0.084
107754	M8	166.7	0.005
107754	MS4	348.4	0.04
107755	M2	346.2	0.946
107755	S2	358.8	0.255
107755	N2	330.8	0.202
107755	K1	216.9	0.591
107755	M4	225.8	0.014
107755	O1	197.9	0.366
107755	M6	256.7	0.041
107755	MK3	22.8	0.085
107755	S4	296.8	0.011
107755	MN4	53.3	0.007
107755	S6	287.5	0.005
107755	2N2	306.1	0.04
107755	OO1	63.4	0.026
107755	M1	178	0.06
107755	J1	226.6	0.066
107755	Q1	179.6	0.074
107755	2Q1	113.9	0.015
107755	P1	260.8	0.144
107755	2SM2	237.4	0.019
107755	M3	162	0.044
107755	L2	49.7	0.071
107755	2MK3	11.3	0.082
107755	M8	172	0.005
107755	MS4	346.7	0.039
107756	M2	346	0.961
107756	S2	358.7	0.256
107756	N2	331	0.209
107756	K1	217.1	0.597
107756	M4	225.2	0.013
107756	O1	198.5	0.374
107756	M6	255	0.042
107756	MK3	21	0.086
107756	S4	283.8	0.011
107756	MN4	54.9	0.01
107756	S6	264.1	0.004
107756	2N2	300.9	0.044
107756	OO1	63.3	0.028
107756	M1	175.5	0.064
107756	J1	226.5	0.067
107756	Q1	178.3	0.076
107756	2Q1	123.4	0.016
107756	P1	263.1	0.147
107756	2SM2	233.9	0.019
107756	M3	158.4	0.045
107756	L2	48.7	0.07
107756	2MK3	12	0.08
107756	M8	177.6	0.006
107756	MS4	344.3	0.038
107757	M2	345.9	0.975
107757	S2	358.6	0.256
107757	N2	331.3	0.214
107757	K1	217.4	0.607
107757	M4	227.6	0.012
107757	O1	199.2	0.38
107757	M6	253.1	0.042
107757	MK3	19.8	0.087
107757	S4	267.5	0.01
107757	MN4	53.5	0.012
107757	S6	217.8	0.005
107757	2N2	296.3	0.048
107757	OO1	64.7	0.03
107757	M1	173.3	0.068
107757	J1	226.8	0.065
107757	Q1	177.2	0.078
107757	2Q1	135.8	0.018
107757	P1	264.9	0.149
107757	2SM2	231	0.019
107757	M3	154.4	0.045
107757	L2	46.9	0.069
107757	2MK3	13.3	0.077
107757	M8	177.2	0.005
107757	MS4	341.1	0.036
107758	M2	345.7	0.989
107758	S2	358.4	0.257
107758	N2	331.3	0.22
107758	K1	217.9	0.616
107758	M4	226.9	0.012
107758	O1	199.8	0.386
107758	M6	251.1	0.042
107758	MK3	18.5	0.088
107758	S4	252.4	0.011
107758	MN4	53.2	0.013
107758	S6	193.5	0.007
107758	2N2	292.9	0.052
107758	OO1	64.3	0.03
107758	M1	172.2	0.072
107758	J1	227.2	0.065
107758	Q1	176	0.081
107758	2Q1	144.9	0.02
107758	P1	266.2	0.153
107758	2SM2	228.4	0.018
107758	M3	149.3	0.044
107758	L2	44.8	0.067
107758	2MK3	16.5	0.075
107758	M8	165.6	0.005
107758	MS4	337	0.034
107759	M2	345.6	1.003
107759	S2	358	0.258
107759	N2	331.4	0.225
107759	K1	218.3	0.626
107759	M4	233.2	0.013
107759	O1	200.3	0.392
107759	M6	249.3	0.041
107759	MK3	17.6	0.089
107759	S4	242.9	0.013
107759	MN4	51.4	0.012
107759	S6	182	0.009
107759	2N2	290.4	0.056
107759	OO1	63.6	0.03
107759	M1	170.4	0.074
107759	J1	227.5	0.064
107759	Q1	175.2	0.084
107759	2Q1	148.1	0.024
107759	P1	267.4	0.156
107759	2SM2	226.2	0.017
107759	M3	144.2	0.041
107759	L2	41.7	0.063
107759	2MK3	20.5	0.074
107759	M8	151.6	0.005
107759	MS4	333.3	0.033
107760	M2	345.6	1.016
107760	S2	357.4	0.26
107760	N2	331.4	0.229
107760	K1	218.8	0.642
107760	M4	236.8	0.015
107760	O1	200.7	0.399
107760	M6	247.5	0.041
107760	MK3	17.2	0.089
107760	S4	237.1	0.015
107760	MN4	45.6	0.011
107760	S6	169.9	0.011
107760	2N2	288.6	0.06
107760	OO1	63.2	0.029
107760	M1	169.6	0.077
107760	J1	227.6	0.061
107760	Q1	174.2	0.087
107760	2Q1	151.7	0.028
107760	P1	267.2	0.157
107760	2SM2	225.3	0.017
107760	M3	138.4	0.039
107760	L2	37.6	0.06
107760	2MK3	25.9	0.073
107760	M8	141.4	0.004
107760	MS4	329.7	0.032
107761	M2	345.6	1.027
107761	S2	356.6	0.261
107761	N2	331.1	0.233
107761	K1	219.1	0.662
107761	M4	238.8	0.018
107761	O1	201.1	0.408
107761	M6	245.3	0.04
107761	MK3	17.8	0.089
107761	S4	233.4	0.018
107761	MN4	37.3	0.01
107761	S6	161.4	0.013
107761	2N2	286.2	0.063
107761	OO1	62.3	0.023
107761	M1	167.8	0.081
107761	J1	226.2	0.058
107761	Q1	173.5	0.091
107761	2Q1	155.2	0.034
107761	P1	266.4	0.153
107761	2SM2	224.5	0.017
107761	M3	131.4	0.036
107761	L2	31.2	0.056
107761	2MK3	31.9	0.074
107761	M8	145.3	0.004
107761	MS4	327.6	0.03
107762	M2	345.5	1.037
107762	S2	355.7	0.262
107762	N2	330.6	0.237
107762	K1	219.1	0.685
107762	M4	240.7	0.021
107762	O1	201.5	0.418
107762	M6	243.1	0.039
107762	MK3	19.2	0.087
107762	S4	230.4	0.02
107762	MN4	29.5	0.009
107762	S6	150.6	0.014
107762	2N2	284.3	0.067
107762	OO1	53.4	0.014
107762	M1	165.9	0.085
107762	J1	225.4	0.053
107762	Q1	172.9	0.094
107762	2Q1	155.4	0.041
107762	P1	265	0.144
107762	2SM2	222.4	0.016
107762	M3	122.7	0.033
107762	L2	23.3	0.053
107762	2MK3	38.5	0.075
107762	M8	158	0.004
107762	MS4	325.3	0.027
107763	M2	345.4	1.045
107763	S2	354.7	0.262
107763	N2	330.1	0.241
107763	K1	219	0.71
107763	M4	240.3	0.023
107763	O1	202.2	0.428
107763	M6	241.4	0.038
107763	MK3	22	0.084
107763	S4	226.5	0.021
107763	MN4	21.4	0.008
107763	S6	140	0.015
107763	2N2	282.1	0.071
107763	OO1	350.5	0.005
107763	M1	164.9	0.091
107763	J1	226.1	0.049
107763	Q1	171.3	0.095
107763	2Q1	156.2	0.049
107763	P1	263.1	0.136
107763	2SM2	220.7	0.014
107763	M3	110.1	0.029
107763	L2	13.9	0.052
107763	2MK3	45.2	0.075
107763	M8	171.6	0.004
107763	MS4	321.4	0.022
107764	M2	345.3	1.05
107764	S2	353.7	0.261
107764	N2	329.2	0.243
107764	K1	218.8	0.731
107764	M4	237.5	0.026
107764	O1	203.2	0.438
107764	M6	239	0.036
107764	MK3	25.4	0.082
107764	S4	223	0.022
107764	MN4	14.1	0.007
107764	S6	129.7	0.015
107764	2N2	280.4	0.077
107764	OO1	289.4	0.012
107764	M1	165.1	0.096
107764	J1	229.5	0.047
107764	Q1	169.4	0.095
107764	2Q1	154.9	0.056
107764	P1	261.2	0.13
107764	2SM2	220.2	0.011
107764	M3	93.4	0.027
107764	L2	4.6	0.053
107764	2MK3	52	0.075
107764	M8	176.9	0.004
107764	MS4	316	0.017
107765	M2	345.1	1.054
107765	S2	352.7	0.26
107765	N2	328.3	0.245
107765	K1	218.7	0.751
107765	M4	236.4	0.028
107765	O1	203.9	0.449
107765	M6	234.8	0.034
107765	MK3	29.8	0.078
107765	S4	219.8	0.022
107765	MN4	8.3	0.006
107765	S6	123.2	0.015
107765	2N2	278.6	0.082
107765	OO1	274.7	0.02
107765	M1	166.6	0.101
107765	J1	235.1	0.044
107765	Q1	165.6	0.094
107765	2Q1	155	0.062
107765	P1	258.7	0.125
107765	2SM2	223.4	0.007
107765	M3	74.6	0.028
107765	L2	357.1	0.054
107765	2MK3	60	0.075
107765	M8	173.7	0.005
107765	MS4	307.4	0.012
107766	M2	345	1.058
107766	S2	351.9	0.258
107766	N2	327.7	0.245
107766	K1	218.4	0.771
107766	M4	235.8	0.029
107766	O1	204.6	0.457
107766	M6	231.9	0.032
107766	MK3	33.9	0.075
107766	S4	218.9	0.023
107766	MN4	15	0.006
107766	S6	115.4	0.013
107766	2N2	277	0.087
107766	OO1	275.3	0.026
107766	M1	168.6	0.108
107766	J1	243	0.043
107766	Q1	161.4	0.093
107766	2Q1	153.9	0.069
107766	P1	255.2	0.118
107766	2SM2	225.6	0.003
107766	M3	56.5	0.032
107766	L2	351.6	0.057
107766	2MK3	68	0.074
107766	M8	172	0.006
107766	MS4	296.4	0.008
107767	M2	344.9	1.06
107767	S2	351.8	0.258
107767	N2	327	0.244
107767	K1	218.5	0.789
107767	M4	236.2	0.029
107767	O1	205.3	0.465
107767	M6	231.3	0.03
107767	MK3	38.5	0.074
107767	S4	211.4	0.022
107767	MN4	5.4	0.006
107767	S6	106.4	0.012
107767	2N2	275.6	0.092
107767	OO1	277.3	0.03
107767	M1	171.6	0.116
107767	J1	249	0.047
107767	Q1	157.9	0.092
107767	2Q1	153.5	0.076
107767	P1	250	0.114
107767	M3	42.3	0.036
107767	L2	346.5	0.058
107767	2MK3	75.4	0.074
107767	M8	175.5	0.007
107767	MS4	268.5	0.004
107768	M2	344.8	1.057
107768	S2	351.8	0.253
107768	N2	326.5	0.239
107768	K1	218.4	0.807
107768	M4	238.9	0.03
107768	O1	205.2	0.471
107768	M6	234.2	0.025
107768	MK3	45.9	0.071
107768	S4	194.4	0.018
107768	MN4	329.3	0.01
107768	S6	98	0.008
107768	2N2	273.8	0.093
107768	OO1	274.7	0.032
107768	M1	174.6	0.125
107768	J1	252.1	0.05
107768	Q1	154.4	0.087
107768	2Q1	151.2	0.078
107768	P1	241.8	0.11
107768	2SM2	24.6	0.005
107768	M3	27.7	0.037
107768	L2	342.4	0.061
107768	2MK3	83.8	0.071
107768	M8	173.7	0.01
107768	MS4	166.6	0.002
107769	M2	344	1.003
107769	S2	345	0.238
107769	N2	327.3	0.218
107769	K1	215	0.792
107769	M4	296.3	0.025
107769	O1	199.5	0.46
107769	M6	214.1	0.028
107769	MK3	11.9	0.038
107769	S4	156.5	0.017
107769	MN4	317.6	0.027
107769	S6	353.3	0.002
107769	2N2	264.5	0.076
107769	OO1	253	0.052
107769	M1	171.2	0.127
107769	J1	241	0.047
107769	Q1	138.9	0.08
107769	2Q1	143.9	0.072
107769	P1	234	0.092
107769	2SM2	17.9	0.012
107769	M3	357.8	0.035
107769	L2	343.1	0.07
107769	2MK3	90.2	0.038
107769	M8	141.4	0.007
107769	MS4	77.3	0.028
107770	M2	310.7	1.259
107770	S2	338.5	0.263
107770	N2	289.7	0.297
107770	K1	206.1	0.589
107770	M4	152.8	0.089
107770	O1	197.4	0.237
107770	M6	172.4	0.02
107770	MK3	355.4	0.056
107770	S4	167.6	0.013
107770	MN4	109.2	0.053
107770	S6	72.7	0.007
107770	2N2	236.9	0.08
107770	OO1	249.2	0.043
107770	M1	111.5	0.039
107770	J1	215.7	0.069
107770	Q1	233	0.018
107770	2Q1	216.5	0.025
107770	P1	212.2	0.199
107770	2SM2	255.8	0.024
107770	M3	60.6	0.018
107770	L2	341.9	0.078
107770	2MK3	9.1	0.062
107770	K2	29.1	0.132
107770	M8	251.2	0.011
107770	MS4	192.5	0.021
107771	M2	311	1.315
107771	S2	333.7	0.254
107771	N2	290.8	0.295
107771	K1	204.6	0.654
107771	M4	138.3	0.067
107771	O1	194.6	0.305
107771	M6	143.5	0.021
107771	MK3	347.1	0.037
107771	S4	186.3	0.008
107771	MN4	103.7	0.041
107771	S6	140.3	0.006
107771	2N2	235.3	0.072
107771	OO1	239.4	0.027
107771	M1	102.8	0.046
107771	J1	203.8	0.053
107771	Q1	239.1	0.036
107771	2Q1	225.7	0.018
107771	P1	193	0.188
107771	2SM2	235.8	0.036
107771	M3	81.8	0.028
107771	L2	344.8	0.093
107771	2MK3	11.6	0.048
107771	K2	27.9	0.113
107771	M8	252.8	0.012
107771	MS4	190	0.02
107772	M2	310.7	1.317
107772	S2	320.6	0.217
107772	N2	293.6	0.279
107772	K1	204.4	0.699
107772	M4	127.1	0.055
107772	O1	195.5	0.337
107772	M6	129.6	0.026
107772	MK3	313.4	0.018
107772	MN4	117	0.031
107772	S6	191.7	0.014
107772	2N2	224	0.065
107772	OO1	256.1	0.042
107772	M1	83.2	0.065
107772	J1	175.9	0.035
107772	Q1	244.4	0.04
107772	2Q1	213	0.005
107772	P1	178.3	0.19
107772	2SM2	249.3	0.029
107772	M3	90.2	0.031
107772	L2	344.6	0.1
107772	2MK3	11.9	0.018
107772	K2	56.7	0.115
107772	M8	236.7	0.008
107772	MS4	193.8	0.013
107773	M2	317.6	1.403
107773	S2	350.1	0.426
107773	N2	302.7	0.345
107773	K1	204.7	0.736
107773	M4	126.1	0.12
107773	O1	226	0.388
107773	M6	268.3	0.041
107773	MK3	303.4	0.071
107773	S4	356.9	0.021
107773	MN4	80.2	0.093
107773	S6	265.2	0.02
107773	2N2	240.3	0.112
107773	OO1	35	0.057
107773	M1	138.5	0.089
107773	J1	241.5	0.084
107773	Q1	208.5	0.087
107773	2Q1	116.3	0.105
107773	P1	216.1	0.196
107773	2SM2	299.9	0.028
107773	M3	108.8	0.032
107773	L2	327.5	0.064
107773	2MK3	239.6	0.054
107773	K2	302.6	0.149
107773	M8	61.9	0.019
107773	MS4	13.1	0.048
107774	M2	318.2	1.556
107774	S2	348.6	0.453
107774	N2	301.6	0.414
107774	K1	198.3	0.789
107774	M4	78.3	0.075
107774	O1	211.6	0.433
107774	M6	232	0.036
107774	MK3	244	0.082
107774	S4	16	0.027
107774	MN4	35.3	0.053
107774	S6	234.7	0.018
107774	2N2	228.7	0.102
107774	OO1	29	0.049
107774	M1	137.6	0.086
107774	J1	216.6	0.083
107774	Q1	189.4	0.07
107774	2Q1	129.4	0.079
107774	P1	222.3	0.137
107774	2SM2	335.2	0.014
107774	M3	87.3	0.019
107774	L2	332.3	0.06
107774	2MK3	185.7	0.061
107774	K2	289.6	0.071
107774	M8	18.7	0.005
107774	MS4	345.6	0.05
107775	M2	315.4	1.492
107775	S2	352.6	0.399
107775	N2	299.4	0.38
107775	K1	195	0.746
107775	M4	15.7	0.088
107775	O1	202.3	0.386
107775	M6	194	0.016
107775	MK3	221.4	0.15
107775	S4	344.3	0.028
107775	MN4	347.3	0.056
107775	S6	201.2	0.011
107775	2N2	231.9	0.079
107775	OO1	61.1	0.053
107775	M1	141.5	0.072
107775	J1	196.1	0.069
107775	Q1	165.2	0.072
107775	2Q1	153	0.047
107775	P1	226	0.109
107775	2SM2	323.8	0.025
107775	M3	218.3	0.016
107775	L2	324.4	0.081
107775	2MK3	219.1	0.085
107775	K2	346.1	0.121
107775	M8	200.6	0.016
107775	MS4	338.1	0.061
107776	M2	320.6	1.138
107776	S2	336	0.318
107776	N2	299.3	0.266
107776	K1	223.4	0.722
107776	M4	193.1	0.062
107776	O1	211.3	0.28
107776	M6	352.8	0.011
107776	MK3	37.7	0.073
107776	S4	97.6	0.027
107776	MN4	186.4	0.018
107776	S6	62.5	0.008
107776	2N2	276.9	0.049
107776	OO1	208.9	0.033
107776	M1	171	0.022
107776	J1	234.9	0.047
107776	Q1	169.7	0.037
107776	2Q1	281.7	0.027
107776	P1	224.9	0.285
107776	2SM2	197.4	0.018
107776	M3	161.5	0.026
107776	L2	10.6	0.027
107776	2MK3	15.5	0.018
107776	M8	319.2	0.004
107776	MS4	151.1	0.036
107777	M2	325.3	1.169
107777	S2	340.1	0.331
107777	N2	300.1	0.255
107777	K1	218	0.683
107777	M4	225.7	0.052
107777	O1	198.6	0.341
107777	M6	173.4	0.009
107777	MK3	64.1	0.039
107777	S4	294	0.013
107777	MN4	220.7	0.053
107777	S6	143.2	0.013
107777	2N2	160.7	0.012
107777	OO1	175	0.04
107777	M1	84.3	0.034
107777	J1	246.6	0.042
107777	Q1	150.2	0.039
107777	2Q1	309.5	0.032
107777	P1	233.7	0.288
107777	2SM2	227.1	0.023
107777	M3	177.9	0.065
107777	L2	21.6	0.056
107777	2MK3	320.4	0.04
107777	M8	142.1	0.015
107777	MS4	248.8	0.012
107778	M2	326	1.134
107778	S2	337.7	0.291
107778	N2	304	0.228
107778	K1	208.3	0.651
107778	M4	278.2	0.058
107778	O1	184.4	0.37
107778	M6	87.8	0.013
107778	MK3	155.1	0.024
107778	S4	296	0.019
107778	MN4	239	0.052
107778	S6	166.1	0.021
107778	2N2	110.3	0.04
107778	OO1	164.9	0.088
107778	M1	53	0.044
107778	J1	242.9	0.028
107778	Q1	136.1	0.054
107778	2Q1	347.9	0.03
107778	P1	239.2	0.24
107778	2SM2	252	0.039
107778	M3	178.8	0.073
107778	L2	5.3	0.076
107778	2MK3	275	0.042
107778	M8	196.2	0.017
107778	MS4	340.2	0.034
107779	M2	296.3	1.517
107779	S2	336.2	0.356
107779	N2	287.3	0.42
107779	K1	206.6	0.6
107779	M4	28.6	0.101
107779	O1	177.1	0.73
107779	M6	89.7	0.076
107779	MK3	245.9	0.283
107779	S4	314.1	0.035
107779	MN4	24.9	0.018
107779	S6	33	0.021
107779	2N2	257.4	0.067
107779	OO1	1.3	0.083
107779	M1	198.7	0.106
107779	J1	216.9	0.184
107779	Q1	174.8	0.14
107779	2Q1	115.1	0.02
107779	P1	243.5	0.343
107779	2SM2	106.2	0.05
107779	M3	63	0.06
107779	L2	200.7	0.12
107779	2MK3	247.9	0.236
107779	K2	321.9	0.331
107779	M8	241.3	0.04
107779	MS4	58.9	0.059
107780	M2	294.9	1.545
107780	S2	330.4	0.346
107780	N2	285.8	0.424
107780	K1	207.9	0.651
107780	M4	36.6	0.094
107780	O1	177.1	0.723
107780	M6	89.7	0.07
107780	MK3	236.9	0.269
107780	S4	304.9	0.036
107780	MN4	36.5	0.029
107780	S6	15.5	0.021
107780	2N2	271.9	0.093
107780	OO1	359.8	0.091
107780	M1	214.7	0.115
107780	J1	216.9	0.174
107780	Q1	183	0.13
107780	2Q1	270.1	0.007
107780	P1	236.4	0.362
107780	2SM2	103.5	0.053
107780	M3	42.4	0.075
107780	L2	195.8	0.14
107780	2MK3	237.4	0.217
107780	K2	319.2	0.277
107780	M8	247.6	0.04
107780	MS4	71.5	0.05
107781	M2	295.2	1.63
107781	S2	325.6	0.431
107781	N2	280.4	0.437
107781	K1	207.1	0.771
107781	M4	51.2	0.064
107781	O1	176.8	0.716
107781	M6	81.3	0.058
107781	MK3	225.4	0.247
107781	S4	330.9	0.014
107781	MN4	38.9	0.038
107781	S6	350.2	0.019
107781	2N2	276.4	0.143
107781	OO1	352.8	0.135
107781	M1	221.8	0.111
107781	J1	215.4	0.174
107781	Q1	189.6	0.114
107781	2Q1	272.9	0.052
107781	P1	228.3	0.378
107781	2SM2	79	0.049
107781	M3	21.9	0.064
107781	L2	197.7	0.155
107781	2MK3	219.8	0.204
107781	K2	290.4	0.244
107781	M8	245	0.014
107781	MS4	110.4	0.073
107782	M2	319.6	1.262
107782	S2	6.5	0.379
107782	N2	294.7	0.355
107782	K1	221.8	0.951
107782	M4	136.8	0.039
107782	O1	197.9	0.656
107782	M6	273.8	0.032
107782	MK3	156.7	0.034
107782	S4	162	0.005
107782	MN4	118.1	0.03
107782	S6	138.4	0.012
107782	2N2	260	0.083
107782	OO1	319.3	0.08
107782	M1	181.4	0.028
107782	J1	200.8	0.068
107782	Q1	177	0.121
107782	2Q1	344.8	0.016
107782	P1	241.1	0.282
107782	2SM2	114	0.019
107782	M3	64.2	0.041
107782	L2	64	0.032
107782	2MK3	129	0.048
107782	K2	343.7	0.175
107782	M8	152	0.012
107782	MS4	320.5	0.014
107783	M2	321.5	1.054
107783	S2	5.7	0.292
107783	N2	291.9	0.263
107783	K1	235.2	0.808
107783	M4	117	0.105
107783	O1	195.8	0.577
107783	M6	42.3	0.016
107783	MK3	229	0.166
107783	S4	249.7	0.029
107783	MN4	136.9	0.024
107783	S6	351.2	0.013
107783	2N2	191.3	0.024
107783	OO1	216.5	0.036
107783	M1	15.1	0.074
107783	J1	187.8	0.049
107783	Q1	141.7	0.101
107783	2Q1	39.4	0.027
107783	P1	236.5	0.308
107783	2SM2	290.1	0.014
107783	M3	114.5	0.021
107783	L2	344.6	0.066
107783	2MK3	234.8	0.117
107783	K2	322.4	0.219
107783	M8	207.1	0.026
107783	MS4	215.4	0.052
107784	M2	320	0.885
107784	S2	14.2	0.193
107784	N2	299	0.203
107784	K1	236.6	0.675
107784	M4	113.8	0.112
107784	O1	190.4	0.551
107784	M6	178.2	0.018
107784	MK3	236.9	0.142
107784	S4	294.5	0.037
107784	MN4	124.2	0.045
107784	S6	167.8	0.002
107784	2N2	177.2	0.049
107784	OO1	235.1	0.067
107784	M1	3.3	0.081
107784	J1	215.2	0.059
107784	Q1	148.9	0.073
107784	2Q1	21.7	0.042
107784	P1	224.7	0.287
107784	2SM2	227.8	0.019
107784	M3	90.8	0.047
107784	L2	340.2	0.067
107784	2MK3	238.1	0.149
107784	K2	350.3	0.16
107784	M8	247	0.037
107784	MS4	236.3	0.075
107785	M2	289.7	2.297
107785	S2	323.8	0.51
107785	N2	268.6	0.567
107785	K1	201.8	0.699
107785	M4	219.4	0.113
107785	O1	185	0.361
107785	M6	36	0.06
107785	MK3	45.3	0.092
107785	S4	215.1	0.022
107785	MN4	207.6	0.031
107785	S6	329.5	0.01
107785	2N2	252.7	0.104
107785	OO1	315.8	0.091
107785	M1	99.8	0.048
107785	J1	190.2	0.081
107785	Q1	193.2	0.051
107785	2Q1	336.5	0.036
107785	P1	226.2	0.366
107785	2SM2	212.1	0.007
107785	M3	113	0.077
107785	L2	279.7	0.07
107785	2MK3	251.7	0.108
107785	K2	338.7	0.234
107785	M8	337.8	0.016
107785	MS4	236.7	0.088
107786	M2	292.7	2.111
107786	S2	342.3	0.569
107786	N2	264.4	0.568
107786	K1	204.6	0.738
107786	M4	264	0.134
107786	O1	185.3	0.411
107786	M6	12.5	0.019
107786	MK3	99	0.155
107786	S4	251.2	0.011
107786	MN4	218.9	0.052
107786	2N2	239.5	0.115
107786	OO1	281.7	0.097
107786	M1	76.3	0.053
107786	J1	209	0.111
107786	Q1	189.1	0.03
107786	2Q1	264.8	0.045
107786	P1	227.6	0.411
107786	2SM2	193.9	0.023
107786	M3	71.7	0.053
107786	L2	235.1	0.056
107786	2MK3	176.6	0.035
107786	K2	329.8	0.378
107786	M8	19.5	0.019
107786	MS4	267.8	0.129
107787	M2	293.2	2.098
107787	S2	342.6	0.573
107787	N2	264.1	0.564
107787	K1	204.6	0.74
107787	M4	267.7	0.138
107787	O1	186.3	0.419
107787	M6	25.7	0.015
107787	MK3	99.2	0.163
107787	S4	244.5	0.014
107787	MN4	215.7	0.056
107787	S6	35	0.004
107787	2N2	238.9	0.12
107787	OO1	280.7	0.09
107787	M1	71.4	0.055
107787	J1	211.1	0.107
107787	Q1	191	0.025
107787	2Q1	264.2	0.044
107787	P1	228.2	0.411
107787	2SM2	195.5	0.022
107787	M3	68.2	0.055
107787	L2	236.6	0.051
107787	2MK3	164.6	0.036
107787	K2	329.9	0.37
107787	M8	19.3	0.018
107787	MS4	267.1	0.129
107788	M2	262.2	0.915
107788	S2	286.7	0.183
107788	N2	240	0.19
107788	K1	145.8	0.253
107788	M4	65	0.024
107788	O1	91	0.121
107788	M6	287.7	0.039
107788	MK3	285.1	0.1
107788	S4	203.7	0.012
107788	MN4	41.7	0.027
107788	S6	202.3	0.009
107788	2N2	163	0.042
107788	OO1	76	0.053
107788	M1	251.6	0.037
107788	J1	355.4	0.029
107788	Q1	250.6	0.027
107788	2Q1	219.7	0.017
107788	P1	117.8	0.097
107788	2SM2	168.3	0.021
107788	M3	29.9	0.021
107788	L2	269.7	0.104
107788	2MK3	257	0.071
107788	K2	329.6	0.109
107788	M8	231.1	0.002
107788	MS4	99.6	0.018
107789	M2	264.7	0.928
107789	S2	289	0.174
107789	N2	240.9	0.192
107789	K1	159.5	0.221
107789	M4	61.4	0.047
107789	O1	74.6	0.074
107789	M6	292.3	0.039
107789	MK3	306.6	0.104
107789	S4	189	0.005
107789	MN4	60.4	0.037
107789	S6	179.1	0.019
107789	2N2	192.3	0.035
107789	OO1	51.7	0.068
107789	M1	235.9	0.056
107789	J1	341.1	0.029
107789	Q1	256.7	0.046
107789	2Q1	211.2	0.032
107789	P1	146	0.102
107789	2SM2	179.9	0.022
107789	M3	20.1	0.022
107789	L2	273.7	0.1
107789	2MK3	255.9	0.058
107789	K2	330.6	0.108
107789	M8	114.7	0.002
107789	MS4	119.2	0.035
107790	M2	266.8	0.923
107790	S2	289.8	0.188
107790	N2	244	0.183
107790	K1	174.8	0.203
107790	M4	71.5	0.053
107790	O1	46.8	0.045
107790	M6	302	0.037
107790	MK3	318.1	0.106
107790	MN4	79.3	0.039
107790	S6	190.3	0.014
107790	2N2	190.2	0.026
107790	OO1	51.5	0.084
107790	M1	233.4	0.062
107790	J1	351.6	0.031
107790	Q1	261.3	0.056
107790	2Q1	215.5	0.043
107790	P1	160.6	0.125
107790	2SM2	197.4	0.022
107790	M3	30.3	0.021
107790	L2	278.6	0.095
107790	2MK3	252.8	0.058
107790	K2	322.1	0.09
107790	M8	125.9	0.006
107790	MS4	125.9	0.044
107791	M2	291.5	1.607
107791	S2	321.8	0.344
107791	N2	271.5	0.387
107791	K1	178.7	0.672
107791	M4	187.9	0.043
107791	O1	162.4	0.412
107791	M6	338.5	0.033
107791	MK3	183.8	0.059
107791	S4	140.3	0.006
107791	MN4	146	0.027
107791	S6	134.5	0.003
107791	2N2	243.2	0.025
107791	OO1	83.5	0.056
107791	M1	207	0.051
107791	J1	239.4	0.044
107791	Q1	152.9	0.076
107791	2Q1	188	0.015
107791	P1	207	0.157
107791	2SM2	177.5	0.013
107791	M3	184.7	0.006
107791	L2	304.1	0.124
107791	2MK3	266.1	0.07
107791	K2	327	0.138
107791	M8	187.2	0.01
107791	MS4	224.3	0.065
107792	M2	291.5	1.625
107792	S2	321.5	0.348
107792	N2	271.5	0.392
107792	K1	178.7	0.68
107792	M4	188.3	0.044
107792	O1	162.4	0.416
107792	M6	337.9	0.034
107792	MK3	183.5	0.059
107792	S4	141.6	0.006
107792	MN4	146.5	0.027
107792	S6	138.6	0.004
107792	2N2	244.3	0.026
107792	OO1	82.7	0.057
107792	M1	206.3	0.052
107792	J1	239.1	0.045
107792	Q1	152.6	0.077
107792	2Q1	187.9	0.014
107792	P1	206.6	0.159
107792	2SM2	176.7	0.013
107792	M3	183.5	0.005
107792	L2	304	0.126
107792	2MK3	266.6	0.071
107792	K2	326.6	0.138
107792	M8	187	0.01
107792	MS4	224.3	0.066
107793	M2	291.5	1.637
107793	S2	321.4	0.351
107793	N2	271.5	0.395
107793	K1	178.8	0.684
107793	M4	187.2	0.044
107793	O1	162.5	0.418
107793	M6	337.1	0.034
107793	MK3	183.9	0.059
107793	S4	140.7	0.006
107793	MN4	145.8	0.027
107793	S6	139.6	0.004
107793	2N2	244.1	0.026
107793	OO1	82.2	0.058
107793	M1	205.9	0.052
107793	J1	238.6	0.046
107793	Q1	152.6	0.078
107793	2Q1	187.7	0.015
107793	P1	206.2	0.16
107793	2SM2	174.3	0.013
107793	M3	188.8	0.005
107793	L2	303.7	0.126
107793	2MK3	266.3	0.072
107793	K2	326.8	0.139
107793	M8	186.2	0.01
107793	MS4	224.4	0.065
107794	M2	291.5	1.647
107794	S2	321.4	0.353
107794	N2	271.5	0.398
107794	K1	178.9	0.688
107794	M4	186.8	0.043
107794	O1	162.7	0.42
107794	M6	336.6	0.034
107794	MK3	185	0.059
107794	S4	142.8	0.006
107794	MN4	144.7	0.027
107794	S6	145.5	0.004
107794	2N2	243.9	0.026
107794	OO1	81.9	0.058
107794	M1	205.5	0.053
107794	J1	237.9	0.046
107794	Q1	152.8	0.078
107794	2Q1	187.8	0.014
107794	P1	205.6	0.162
107794	2SM2	173.7	0.013
107794	M3	189.7	0.005
107794	L2	303.4	0.127
107794	2MK3	266.3	0.073
107794	K2	326.5	0.14
107794	M8	184	0.01
107794	MS4	224.5	0.065
107795	M2	291.4	1.654
107795	S2	321.3	0.354
107795	N2	271.5	0.4
107795	K1	179	0.692
107795	M4	185.4	0.042
107795	O1	162.8	0.42
107795	M6	335.7	0.035
107795	MK3	185.8	0.058
107795	S4	143.9	0.006
107795	MN4	142	0.026
107795	S6	147.4	0.003
107795	2N2	242.7	0.026
107795	OO1	81.8	0.059
107795	M1	205.4	0.052
107795	J1	237.3	0.047
107795	Q1	152.8	0.079
107795	2Q1	184.5	0.015
107795	P1	205	0.162
107795	2SM2	173.1	0.013
107795	M3	196.2	0.004
107795	L2	303.2	0.128
107795	2MK3	266.6	0.075
107795	K2	326.4	0.14
107795	M8	184.1	0.011
107795	MS4	224.3	0.064
107796	M2	291.4	1.66
107796	S2	321.5	0.356
107796	N2	271.5	0.402
107796	K1	179.1	0.696
107796	M4	184.5	0.042
107796	O1	162.9	0.421
107796	M6	335.3	0.035
107796	MK3	187.1	0.058
107796	S4	147.7	0.005
107796	MN4	139.3	0.026
107796	S6	152.3	0.004
107796	2N2	241.5	0.026
107796	OO1	81.5	0.06
107796	M1	205.1	0.052
107796	J1	236.5	0.048
107796	Q1	153.2	0.079
107796	2Q1	182.2	0.015
107796	P1	204.3	0.162
107796	2SM2	172.5	0.012
107796	M3	204.4	0.004
107796	L2	302.6	0.129
107796	2MK3	266.9	0.077
107796	K2	326.2	0.142
107796	M8	184.3	0.011
107796	MS4	223.9	0.063
107797	M2	291.4	1.666
107797	S2	321.7	0.356
107797	N2	271.5	0.403
107797	K1	179.1	0.699
107797	M4	182.6	0.04
107797	O1	163	0.422
107797	M6	335.5	0.036
107797	MK3	188.7	0.059
107797	S4	147.2	0.005
107797	MN4	136.3	0.026
107797	S6	148.8	0.004
107797	2N2	240.7	0.026
107797	OO1	80.7	0.06
107797	M1	205	0.052
107797	J1	236.4	0.048
107797	Q1	153.4	0.079
107797	2Q1	180.1	0.016
107797	P1	203.4	0.162
107797	2SM2	172.1	0.012
107797	M3	218	0.004
107797	L2	302.4	0.129
107797	2MK3	267.1	0.078
107797	K2	326.7	0.145
107797	M8	182.8	0.011
107797	MS4	224	0.062
107798	M2	291.4	1.67
107798	S2	321.9	0.355
107798	N2	271.5	0.405
107798	K1	179.2	0.702
107798	M4	181.2	0.039
107798	O1	163.2	0.421
107798	M6	334.5	0.036
107798	MK3	190.4	0.059
107798	S4	146.1	0.005
107798	MN4	133.4	0.026
107798	S6	152.2	0.004
107798	2N2	238.6	0.026
107798	OO1	80.9	0.061
107798	M1	205.3	0.053
107798	J1	235.9	0.048
107798	Q1	153.6	0.078
107798	2Q1	178.3	0.016
107798	P1	202.3	0.162
107798	2SM2	172.1	0.012
107798	M3	229.2	0.004
107798	L2	302.1	0.129
107798	2MK3	267.2	0.079
107798	K2	326.7	0.147
107798	M8	181.7	0.012
107798	MS4	223.8	0.061
107799	M2	291.4	1.674
107799	S2	322.1	0.356
107799	N2	271.5	0.406
107799	K1	179.3	0.705
107799	M4	179.5	0.039
107799	O1	163.3	0.421
107799	M6	333.3	0.036
107799	MK3	191.4	0.059
107799	S4	143.8	0.005
107799	MN4	130.6	0.026
107799	S6	161.1	0.004
107799	2N2	236.4	0.025
107799	OO1	80.2	0.062
107799	M1	205.5	0.053
107799	J1	235.1	0.048
107799	Q1	154.4	0.078
107799	2Q1	176.9	0.017
107799	P1	201.5	0.162
107799	2SM2	174	0.012
107799	M3	235.8	0.004
107799	L2	301.8	0.13
107799	2MK3	267	0.081
107799	K2	326.5	0.149
107799	M8	181.8	0.012
107799	MS4	223.6	0.06
107800	M2	291.4	1.677
107800	S2	322.3	0.355
107800	N2	271.6	0.406
107800	K1	179.3	0.706
107800	M4	177.5	0.038
107800	O1	163.4	0.42
107800	M6	332.9	0.037
107800	MK3	192.5	0.059
107800	S4	141.8	0.005
107800	MN4	128.1	0.026
107800	S6	162.2	0.004
107800	2N2	235.1	0.025
107800	OO1	79.9	0.063
107800	M1	205.8	0.052
107800	J1	234.7	0.049
107800	Q1	154.7	0.078
107800	2Q1	176.1	0.017
107800	P1	201.1	0.161
107800	2SM2	174.3	0.012
107800	M3	242.7	0.004
107800	L2	301.6	0.131
107800	2MK3	267.2	0.082
107800	K2	326.9	0.151
107800	M8	181.8	0.012
107800	MS4	223.3	0.059
107801	M2	291.4	1.68
107801	S2	322.4	0.354
107801	N2	271.6	0.407
107801	K1	179.3	0.706
107801	M4	174.9	0.037
107801	O1	163.4	0.419
107801	M6	332.2	0.037
107801	MK3	193.6	0.06
107801	S4	137.2	0.006
107801	MN4	124.3	0.026
107801	S6	169.6	0.004
107801	2N2	233.3	0.025
107801	OO1	79.8	0.064
107801	M1	206.1	0.052
107801	J1	233.8	0.049
107801	Q1	155	0.077
107801	2Q1	176.3	0.018
107801	P1	200.5	0.161
107801	2SM2	176.6	0.012
107801	M3	255.1	0.004
107801	L2	301.5	0.132
107801	2MK3	266.9	0.084
107801	K2	327.3	0.153
107801	M8	180.3	0.012
107801	MS4	222.9	0.058
107802	M2	291.3	1.682
107802	S2	322.5	0.354
107802	N2	271.7	0.407
107802	K1	179.4	0.707
107802	M4	172.8	0.036
107802	O1	163.4	0.418
107802	M6	331.6	0.038
107802	MK3	193.9	0.061
107802	S4	133.3	0.006
107802	MN4	121.9	0.026
107802	S6	178.1	0.004
107802	2N2	231.8	0.026
107802	OO1	80	0.065
107802	M1	206.2	0.053
107802	J1	233.8	0.05
107802	Q1	154.6	0.077
107802	2Q1	176.3	0.018
107802	P1	200.2	0.161
107802	2SM2	179.5	0.011
107802	M3	256.2	0.005
107802	L2	301.4	0.133
107802	2MK3	267.1	0.084
107802	K2	327.4	0.154
107802	M8	181.1	0.013
107802	MS4	223.2	0.057
107803	M2	291.3	1.684
107803	S2	322.5	0.353
107803	N2	271.7	0.407
107803	K1	179.3	0.707
107803	M4	170.7	0.036
107803	O1	163.4	0.418
107803	M6	331.6	0.039
107803	MK3	193.5	0.063
107803	S4	133.9	0.006
107803	MN4	119.4	0.026
107803	S6	187.8	0.003
107803	2N2	231	0.026
107803	OO1	80	0.066
107803	M1	206.3	0.053
107803	J1	233.1	0.051
107803	Q1	154.9	0.077
107803	2Q1	176.2	0.018
107803	P1	199.8	0.16
107803	2SM2	181.5	0.011
107803	M3	257.7	0.005
107803	L2	301.7	0.133
107803	2MK3	267.1	0.086
107803	K2	327.7	0.154
107803	M8	181.7	0.014
107803	MS4	223.2	0.056
107804	M2	291.3	1.685
107804	S2	322.5	0.352
107804	N2	271.8	0.406
107804	K1	179.3	0.706
107804	M4	168.7	0.036
107804	O1	163.4	0.417
107804	M6	331.6	0.04
107804	MK3	192.9	0.064
107804	S4	130.8	0.006
107804	MN4	117.5	0.025
107804	S6	187.6	0.003
107804	2N2	230.6	0.026
107804	OO1	80	0.067
107804	M1	206.5	0.052
107804	J1	233.4	0.052
107804	Q1	154.7	0.077
107804	2Q1	176.3	0.018
107804	P1	199.5	0.158
107804	2SM2	184.3	0.011
107804	M3	261.2	0.005
107804	L2	301.8	0.134
107804	2MK3	267	0.087
107804	K2	327.8	0.155
107804	M8	182.2	0.014
107804	MS4	223.6	0.056
107805	M2	291.2	1.686
107805	S2	322.5	0.351
107805	N2	271.8	0.406
107805	K1	179.3	0.706
107805	M4	167.2	0.035
107805	O1	163.3	0.415
107805	M6	331.3	0.04
107805	MK3	192.7	0.065
107805	S4	131.9	0.005
107805	MN4	115.4	0.025
107805	S6	199.5	0.003
107805	2N2	231.1	0.026
107805	OO1	80	0.068
107805	M1	206	0.052
107805	J1	233.7	0.052
107805	Q1	154.5	0.077
107805	2Q1	176	0.019
107805	P1	199.2	0.158
107805	2SM2	186.4	0.01
107805	M3	262.7	0.005
107805	L2	301.9	0.134
107805	2MK3	266.5	0.087
107805	K2	327.9	0.155
107805	M8	182.7	0.015
107805	MS4	223.5	0.056
107806	M2	291.2	1.687
107806	S2	322.4	0.351
107806	N2	271.7	0.405
107806	K1	179.2	0.704
107806	M4	166.7	0.035
107806	O1	163.3	0.414
107806	M6	331.2	0.041
107806	MK3	191.6	0.065
107806	S4	129	0.005
107806	MN4	114	0.025
107806	S6	210.2	0.003
107806	2N2	230.8	0.026
107806	OO1	79.9	0.069
107806	M1	205.8	0.052
107806	J1	233.8	0.052
107806	Q1	153.9	0.077
107806	2Q1	176.5	0.019
107806	P1	199.1	0.157
107806	2SM2	189.1	0.01
107806	M3	257.9	0.006
107806	L2	301.9	0.135
107806	2MK3	266	0.088
107806	K2	327.9	0.155
107806	M8	183.7	0.016
107806	MS4	224.1	0.056
107807	M2	291.1	1.682
107807	S2	322.3	0.345
107807	N2	271.7	0.402
107807	K1	179.1	0.706
107807	M4	174.5	0.033
107807	O1	162.9	0.41
107807	M6	335.9	0.04
107807	MK3	191.2	0.071
107807	S4	121.5	0.007
107807	MN4	113.2	0.021
107807	2N2	229.8	0.023
107807	OO1	81.1	0.07
107807	M1	205.7	0.05
107807	J1	233.5	0.05
107807	Q1	153	0.076
107807	2Q1	175.9	0.018
107807	P1	197.6	0.153
107807	2SM2	198.1	0.01
107807	M3	241.7	0.009
107807	L2	302.2	0.137
107807	2MK3	262.6	0.09
107807	K2	329.1	0.157
107807	M8	192.6	0.017
107807	MS4	227.9	0.053
107808	M2	285.5	0.713
107808	S2	317.3	0.177
107808	N2	266.7	0.175
107808	K1	174.2	0.332
107808	M4	90	0.008
107808	O1	166.7	0.176
107808	M6	275.6	0.011
107808	MK3	240.5	0.019
107808	MN4	90.3	0.016
107808	S6	120.9	0.004
107808	2N2	208.1	0.025
107808	OO1	92.4	0.021
107808	M1	171.2	0.029
107808	J1	235.1	0.037
107808	Q1	135.2	0.03
107808	2Q1	110.5	0.017
107808	P1	202	0.05
107808	2SM2	177	0.008
107808	M3	61.7	0.006
107808	L2	298.1	0.057
107808	2MK3	257.9	0.025
107808	K2	306.6	0.065
107808	M8	94.5	0.003
107808	MS4	230.3	0.014
107809	M2	285.7	0.762
107809	S2	317.7	0.189
107809	N2	267.1	0.187
107809	K1	174.3	0.355
107809	M4	96	0.006
107809	O1	166.2	0.19
107809	M6	277.7	0.012
107809	MK3	238.5	0.019
107809	MN4	92.6	0.017
107809	S6	124.3	0.004
107809	2N2	207.3	0.027
107809	OO1	89.1	0.02
107809	M1	173.7	0.031
107809	J1	235.9	0.04
107809	Q1	134.2	0.032
107809	2Q1	109.3	0.017
107809	P1	202.4	0.055
107809	2SM2	178.2	0.009
107809	M3	65.7	0.006
107809	L2	298.7	0.061
107809	2MK3	259.7	0.026
107809	K2	306.9	0.07
107809	M8	91.6	0.003
107809	MS4	233.6	0.016
107810	M2	286	0.795
107810	S2	317.5	0.197
107810	N2	267.4	0.195
107810	K1	174.5	0.37
107810	M4	101.3	0.004
107810	O1	165.8	0.201
107810	M6	277.7	0.012
107810	MK3	235.4	0.019
107810	MN4	96.2	0.016
107810	S6	124.5	0.005
107810	2N2	206.1	0.027
107810	OO1	88	0.02
107810	M1	174.5	0.032
107810	J1	236	0.04
107810	Q1	133.7	0.033
107810	2Q1	107.9	0.016
107810	P1	201.9	0.058
107810	2SM2	179.2	0.009
107810	M3	74.3	0.006
107810	L2	299.1	0.063
107810	2MK3	262.1	0.027
107810	K2	306.4	0.072
107810	M8	89.1	0.003
107810	MS4	236.8	0.018
107811	M2	286.2	0.822
107811	S2	317.8	0.203
107811	N2	267.7	0.202
107811	K1	174.8	0.383
107811	M4	116.5	0.003
107811	O1	165.7	0.209
107811	M6	279	0.012
107811	MK3	232.6	0.018
107811	MN4	99.3	0.016
107811	S6	124.1	0.004
107811	2N2	204.1	0.027
107811	OO1	86.3	0.02
107811	M1	176.1	0.033
107811	J1	236.5	0.04
107811	Q1	134.7	0.034
107811	2Q1	106.2	0.015
107811	P1	200.7	0.061
107811	2SM2	179.5	0.009
107811	M3	82.9	0.006
107811	L2	299.5	0.066
107811	2MK3	264	0.028
107811	K2	307.4	0.074
107811	M8	82.7	0.002
107811	MS4	239.6	0.019
107812	M2	286.4	0.845
107812	S2	317.8	0.206
107812	N2	268.1	0.207
107812	K1	175	0.394
107812	M4	134.2	0.002
107812	O1	165.3	0.216
107812	M6	281.7	0.012
107812	MK3	229.3	0.018
107812	S4	5.1	0.001
107812	MN4	100.1	0.015
107812	S6	125.8	0.004
107812	2N2	201.5	0.027
107812	OO1	86.2	0.021
107812	M1	177.3	0.033
107812	J1	236.2	0.04
107812	Q1	136.8	0.035
107812	2Q1	101.8	0.014
107812	P1	200.9	0.064
107812	2SM2	177.1	0.009
107812	M3	88.9	0.005
107812	L2	299.9	0.067
107812	2MK3	266.2	0.029
107812	K2	308.4	0.076
107812	M8	77.7	0.002
107812	MS4	241.9	0.019
107813	M2	286.6	0.862
107813	S2	318	0.209
107813	N2	268.3	0.211
107813	K1	175.3	0.402
107813	M4	147.1	0.002
107813	O1	165.3	0.221
107813	M6	283	0.012
107813	MK3	228	0.018
107813	S4	15.1	0.002
107813	MN4	100.3	0.014
107813	S6	125.6	0.003
107813	2N2	200.5	0.027
107813	OO1	86.8	0.022
107813	M1	179.1	0.033
107813	J1	236	0.039
107813	Q1	139.4	0.035
107813	2Q1	98.4	0.013
107813	P1	201	0.066
107813	2SM2	175.5	0.009
107813	M3	100	0.004
107813	L2	300.2	0.069
107813	2MK3	268.2	0.03
107813	K2	310.3	0.078
107813	M8	77.1	0.001
107813	MS4	242.6	0.019
107814	M2	286.7	0.876
107814	S2	318.1	0.211
107814	N2	268.5	0.215
107814	K1	175.6	0.409
107814	M4	139.5	0.001
107814	O1	165.4	0.225
107814	M6	286.3	0.012
107814	MK3	227.6	0.018
107814	S4	17.7	0.003
107814	MN4	99	0.013
107814	S6	128.3	0.003
107814	2N2	198.6	0.027
107814	OO1	85.8	0.023
107814	M1	180.9	0.033
107814	J1	235.3	0.039
107814	Q1	142.1	0.036
107814	2Q1	97.5	0.012
107814	P1	201.2	0.067
107814	2SM2	173.9	0.009
107814	M3	113	0.003
107814	L2	300.3	0.069
107814	2MK3	269.6	0.031
107814	K2	312	0.079
107814	MS4	242.4	0.018
107815	M2	286.9	0.888
107815	S2	318.3	0.212
107815	N2	268.5	0.218
107815	K1	175.9	0.416
107815	M4	106.6	0.001
107815	O1	165.4	0.228
107815	M6	289.4	0.012
107815	MK3	228.3	0.019
107815	S4	23.5	0.004
107815	MN4	94.5	0.012
107815	S6	134.3	0.003
107815	2N2	197.8	0.027
107815	OO1	84.5	0.024
107815	M1	182.3	0.033
107815	J1	234.7	0.038
107815	Q1	144.3	0.037
107815	2Q1	93.8	0.011
107815	P1	201.5	0.068
107815	2SM2	172	0.01
107815	M3	135.9	0.002
107815	L2	300.5	0.07
107815	2MK3	269.4	0.032
107815	K2	313.8	0.081
107815	MS4	242.6	0.017
107816	M2	287	0.898
107816	S2	318.7	0.213
107816	N2	268.6	0.221
107816	K1	176.3	0.421
107816	M4	74.5	0.001
107816	O1	165.6	0.231
107816	M6	290.7	0.012
107816	MK3	229.5	0.02
107816	S4	18.7	0.004
107816	MN4	90.3	0.011
107816	S6	130.8	0.003
107816	2N2	198.1	0.028
107816	OO1	84.4	0.026
107816	M1	183.3	0.032
107816	J1	234.6	0.037
107816	Q1	145.8	0.038
107816	2Q1	94.9	0.01
107816	P1	201.6	0.07
107816	2SM2	171.1	0.01
107816	M3	161.3	0.002
107816	L2	300.2	0.07
107816	2MK3	269.4	0.033
107816	K2	316.4	0.083
107816	MS4	243.1	0.016
107817	M2	287.1	0.906
107817	S2	318.8	0.213
107817	N2	268.7	0.223
107817	K1	176.7	0.427
107817	M4	68.9	0.002
107817	O1	165.8	0.234
107817	M6	293.6	0.013
107817	MK3	230.6	0.022
107817	S4	17.8	0.004
107817	MN4	84.9	0.01
107817	S6	120.3	0.003
107817	2N2	198.6	0.028
107817	OO1	85.7	0.026
107817	M1	185.3	0.031
107817	J1	233.8	0.036
107817	Q1	148.1	0.039
107817	2Q1	94.9	0.009
107817	P1	201.3	0.072
107817	2SM2	173.3	0.01
107817	M3	181.8	0.002
107817	L2	300	0.07
107817	2MK3	269.8	0.034
107817	K2	317.9	0.084
107817	MS4	242.3	0.014
107818	M2	287.1	0.914
107818	S2	319.1	0.213
107818	N2	268.7	0.225
107818	K1	177.1	0.432
107818	M4	60.9	0.003
107818	O1	165.9	0.237
107818	M6	297	0.012
107818	MK3	231.5	0.023
107818	S4	16.6	0.004
107818	MN4	79.5	0.01
107818	S6	119.8	0.003
107818	2N2	198.6	0.028
107818	OO1	85.2	0.027
107818	M1	186	0.031
107818	J1	232.1	0.035
107818	Q1	149.4	0.04
107818	2Q1	96.5	0.008
107818	P1	200.3	0.072
107818	2SM2	173.7	0.009
107818	M3	196.6	0.002
107818	L2	299.7	0.07
107818	2MK3	269.8	0.035
107818	K2	320.2	0.086
107818	MS4	240.8	0.013
107819	M2	287.2	0.92
107819	S2	319.2	0.213
107819	N2	268.7	0.226
107819	K1	177.6	0.437
107819	M4	62.2	0.004
107819	O1	166.1	0.24
107819	M6	298.6	0.012
107819	MK3	231.9	0.024
107819	S4	15.6	0.004
107819	MN4	73.3	0.009
107819	S6	118	0.003
107819	2N2	199.4	0.029
107819	OO1	85.8	0.028
107819	M1	188.1	0.03
107819	J1	230.7	0.034
107819	Q1	151.1	0.041
107819	2Q1	99.5	0.008
107819	P1	199.6	0.074
107819	2SM2	178.1	0.009
107819	M3	221.8	0.003
107819	L2	299.2	0.07
107819	2MK3	269.6	0.036
107819	K2	321.3	0.087
107819	M8	166.9	0.001
107819	MS4	241.5	0.012
107820	M2	287.3	0.925
107820	S2	319.2	0.213
107820	N2	268.7	0.227
107820	K1	178	0.441
107820	M4	66	0.006
107820	O1	166.2	0.242
107820	M6	300.3	0.012
107820	MK3	232	0.025
107820	S4	15.4	0.004
107820	MN4	64.8	0.008
107820	S6	120.6	0.003
107820	2N2	199.3	0.029
107820	OO1	86.8	0.028
107820	M1	190.3	0.029
107820	J1	229.7	0.033
107820	Q1	152.7	0.042
107820	2Q1	97.6	0.007
107820	P1	199.4	0.076
107820	2SM2	182.3	0.009
107820	M3	228.8	0.003
107820	L2	299	0.07
107820	2MK3	269.3	0.037
107820	K2	322.6	0.089
107820	M8	174	0.001
107820	MS4	240.3	0.01
107821	M2	287.4	0.929
107821	S2	319.3	0.211
107821	N2	268.7	0.228
107821	K1	178.3	0.444
107821	M4	67.5	0.007
107821	O1	166.4	0.244
107821	M6	301.1	0.012
107821	MK3	231.4	0.027
107821	S4	17.5	0.004
107821	MN4	59	0.008
107821	S6	112.5	0.003
107821	2N2	201.2	0.029
107821	OO1	86.2	0.028
107821	M1	191.8	0.028
107821	J1	228.1	0.033
107821	Q1	153.4	0.042
107821	2Q1	99.6	0.007
107821	P1	199.3	0.078
107821	2SM2	186.4	0.008
107821	M3	242.7	0.003
107821	L2	298.9	0.07
107821	2MK3	268.5	0.037
107821	K2	324.7	0.09
107821	M8	177	0.002
107821	MS4	239.1	0.009
107822	M2	287.4	0.933
107822	S2	319.3	0.21
107822	N2	268.8	0.229
107822	K1	178.8	0.447
107822	M4	70.9	0.008
107822	O1	166.5	0.245
107822	M6	302	0.012
107822	MK3	230.7	0.028
107822	S4	25.2	0.004
107822	MN4	49.8	0.008
107822	S6	117.6	0.003
107822	2N2	202.1	0.029
107822	OO1	84.7	0.028
107822	M1	193.1	0.028
107822	J1	227	0.032
107822	Q1	154.8	0.043
107822	2Q1	100.1	0.007
107822	P1	198.6	0.081
107822	2SM2	191.6	0.009
107822	M3	248.3	0.004
107822	L2	299	0.07
107822	2MK3	267.8	0.038
107822	K2	325.7	0.091
107822	M8	185.7	0.002
107822	MS4	236.9	0.008
107823	M2	287.4	0.936
107823	S2	319.4	0.209
107823	N2	268.8	0.23
107823	K1	179.1	0.449
107823	M4	73.7	0.009
107823	O1	166.6	0.246
107823	M6	304.1	0.012
107823	MK3	228.7	0.03
107823	S4	21.3	0.003
107823	MN4	44.1	0.008
107823	S6	121	0.003
107823	2N2	203.3	0.028
107823	OO1	84.2	0.029
107823	M1	194.4	0.027
107823	J1	225.4	0.032
107823	Q1	155.8	0.043
107823	2Q1	101.7	0.007
107823	P1	198.6	0.083
107823	2SM2	197.7	0.008
107823	M3	257.7	0.004
107823	L2	299.5	0.07
107823	2MK3	266.4	0.039
107823	K2	326.6	0.092
107823	M8	193	0.002
107823	MS4	234.8	0.008
107824	M2	287.5	0.938
107824	S2	319.4	0.208
107824	N2	268.7	0.231
107824	K1	179.4	0.449
107824	M4	75.2	0.011
107824	O1	166.7	0.248
107824	M6	308.1	0.012
107824	MK3	227.7	0.031
107824	S4	33.3	0.004
107824	MN4	38.6	0.008
107824	S6	121.1	0.003
107824	2N2	205	0.028
107824	OO1	82.9	0.029
107824	M1	195.8	0.027
107824	J1	224.5	0.032
107824	Q1	156.2	0.043
107824	2Q1	107.6	0.007
107824	P1	199	0.086
107824	2SM2	198.1	0.009
107824	M3	251.4	0.005
107824	L2	299.8	0.07
107824	2MK3	266	0.039
107824	K2	327.2	0.093
107824	M8	200.3	0.003
107824	MS4	231.3	0.008
107825	M2	287.5	0.94
107825	S2	319.7	0.207
107825	N2	268.7	0.231
107825	K1	179.7	0.45
107825	M4	78.2	0.012
107825	O1	167	0.249
107825	M6	309.6	0.011
107825	MK3	226.3	0.033
107825	S4	37.7	0.004
107825	MN4	34.6	0.008
107825	S6	120.4	0.003
107825	2N2	206.8	0.028
107825	OO1	81.6	0.029
107825	M1	197.9	0.026
107825	J1	222.7	0.032
107825	Q1	157.7	0.044
107825	2Q1	115.3	0.007
107825	P1	199.4	0.088
107825	2SM2	200.8	0.009
107825	M3	256.7	0.005
107825	L2	299.7	0.07
107825	2MK3	264.8	0.041
107825	K2	327	0.094
107825	M8	197.5	0.003
107825	MS4	225.8	0.008
107826	M2	287.5	0.941
107826	S2	319.6	0.207
107826	N2	268.6	0.231
107826	K1	180.1	0.45
107826	M4	80	0.013
107826	O1	167.1	0.249
107826	M6	311.2	0.011
107826	MK3	224.8	0.035
107826	S4	43.2	0.004
107826	MN4	30.2	0.008
107826	S6	140	0.002
107826	2N2	209.4	0.027
107826	OO1	80.9	0.03
107826	M1	198.7	0.027
107826	J1	222.2	0.031
107826	Q1	158.4	0.045
107826	2Q1	123.5	0.007
107826	P1	199.7	0.092
107826	2SM2	204	0.009
107826	M3	255.5	0.006
107826	L2	300	0.069
107826	2MK3	263.2	0.042
107826	K2	326.7	0.093
107826	M8	205.1	0.004
107826	MS4	223.2	0.008
107827	M2	287.6	0.942
107827	S2	319.6	0.206
107827	N2	268.6	0.231
107827	K1	180.7	0.449
107827	M4	82.7	0.015
107827	O1	167.1	0.25
107827	M6	312.8	0.011
107827	MK3	223.8	0.036
107827	S4	43.7	0.003
107827	MN4	29.1	0.007
107827	S6	154.9	0.001
107827	2N2	213.1	0.027
107827	OO1	80.3	0.032
107827	M1	200.6	0.027
107827	J1	220.9	0.031
107827	Q1	158.8	0.045
107827	2Q1	133.6	0.007
107827	P1	199.8	0.097
107827	2SM2	203	0.009
107827	M3	256.3	0.006
107827	L2	300.1	0.069
107827	2MK3	262.2	0.043
107827	K2	326.4	0.094
107827	M8	205.3	0.004
107827	MS4	218.5	0.008
107828	M2	287.6	0.943
107828	S2	319.7	0.206
107828	N2	268.3	0.231
107828	K1	181.3	0.449
107828	M4	85.1	0.016
107828	O1	167.1	0.251
107828	M6	315.6	0.01
107828	MK3	222.7	0.038
107828	S4	43	0.003
107828	MN4	29	0.007
107828	2N2	216.6	0.026
107828	OO1	78.2	0.033
107828	M1	201.3	0.028
107828	J1	219.5	0.03
107828	Q1	159.6	0.045
107828	2Q1	142.9	0.008
107828	P1	199.4	0.101
107828	2SM2	204.8	0.009
107828	M3	255.8	0.008
107828	L2	300.1	0.069
107828	2MK3	260.8	0.045
107828	K2	325.9	0.095
107828	M8	212.7	0.005
107828	MS4	214.5	0.009
107829	M2	287.6	0.944
107829	S2	319.5	0.206
107829	N2	268.2	0.231
107829	K1	181.7	0.449
107829	M4	86.7	0.017
107829	O1	167	0.252
107829	M6	319.1	0.011
107829	MK3	220.9	0.04
107829	S4	37.8	0.003
107829	MN4	26.5	0.008
107829	2N2	220.8	0.025
107829	OO1	78.6	0.034
107829	M1	202.8	0.028
107829	J1	217.3	0.029
107829	Q1	161.1	0.046
107829	2Q1	150.7	0.009
107829	P1	199.6	0.105
107829	2SM2	205.7	0.009
107829	M3	256.8	0.009
107829	L2	299.9	0.068
107829	2MK3	260.5	0.046
107829	K2	324.9	0.094
107829	M8	215.7	0.005
107829	MS4	211.1	0.009
107830	M2	287.7	0.945
107830	S2	319.4	0.204
107830	N2	267.9	0.23
107830	K1	182.4	0.449
107830	M4	87.5	0.018
107830	O1	167.1	0.252
107830	M6	322.2	0.011
107830	MK3	219.4	0.042
107830	S4	29.1	0.002
107830	MN4	27.9	0.008
107830	2N2	224.8	0.025
107830	OO1	78.1	0.036
107830	M1	204.2	0.029
107830	J1	216.4	0.027
107830	Q1	162.9	0.047
107830	2Q1	158.6	0.009
107830	P1	198.9	0.109
107830	2SM2	206.3	0.009
107830	M3	256.6	0.01
107830	L2	299.7	0.068
107830	2MK3	260	0.049
107830	K2	325.1	0.094
107830	M8	214.5	0.006
107830	MS4	206.9	0.01
107831	M2	287.7	0.946
107831	S2	319.4	0.202
107831	N2	267.7	0.23
107831	K1	183	0.451
107831	M4	88.9	0.019
107831	O1	167.1	0.252
107831	M6	323.7	0.01
107831	MK3	217.8	0.044
107831	S4	23.2	0.002
107831	MN4	27.7	0.008
107831	S6	317.7	0.002
107831	2N2	231.1	0.024
107831	OO1	77.3	0.037
107831	M1	205.1	0.03
107831	J1	213.3	0.027
107831	Q1	164.3	0.048
107831	2Q1	165.3	0.01
107831	P1	198.2	0.114
107831	2SM2	207.9	0.009
107831	M3	257.5	0.011
107831	L2	299.7	0.067
107831	2MK3	260.2	0.051
107831	K2	325.7	0.094
107831	M8	217.4	0.006
107831	MS4	204.3	0.01
107832	M2	287.8	0.946
107832	S2	319.3	0.2
107832	N2	267.5	0.23
107832	K1	183.8	0.452
107832	M4	90.9	0.02
107832	O1	167	0.252
107832	M6	325.8	0.01
107832	MK3	216.4	0.046
107832	S4	17.6	0.002
107832	MN4	25.6	0.009
107832	S6	314.3	0.002
107832	2N2	236.2	0.023
107832	OO1	76.3	0.038
107832	M1	205.8	0.031
107832	J1	212.2	0.025
107832	Q1	165.4	0.049
107832	2Q1	172	0.011
107832	P1	197.5	0.119
107832	2SM2	212.6	0.008
107832	M3	258.7	0.012
107832	L2	299.5	0.067
107832	2MK3	259.7	0.054
107832	K2	326.5	0.094
107832	M8	217.5	0.007
107832	MS4	198.7	0.011
107833	M2	287.9	0.947
107833	S2	319.1	0.198
107833	N2	267.3	0.23
107833	K1	184.4	0.456
107833	M4	91.6	0.021
107833	O1	167	0.252
107833	M6	327.7	0.01
107833	MK3	216.2	0.048
107833	S4	18.8	0.001
107833	MN4	26.3	0.01
107833	S6	317.8	0.002
107833	2N2	241.6	0.022
107833	OO1	75.5	0.04
107833	M1	206.5	0.032
107833	J1	208.7	0.024
107833	Q1	165.9	0.05
107833	2Q1	179.4	0.013
107833	P1	196.1	0.123
107833	2SM2	218	0.007
107833	M3	258.2	0.012
107833	L2	299.7	0.067
107833	2MK3	260	0.057
107833	K2	327.4	0.093
107833	M8	221	0.008
107833	MS4	195.3	0.012
107834	M2	287.9	0.948
107834	S2	318.6	0.194
107834	N2	267.1	0.229
107834	K1	184.9	0.459
107834	M4	92.5	0.021
107834	O1	166.9	0.252
107834	M6	327.9	0.01
107834	MK3	216.4	0.051
107834	S4	341.2	0.001
107834	MN4	25.3	0.01
107834	S6	306.3	0.001
107834	2N2	249.3	0.021
107834	OO1	75.1	0.041
107834	M1	206.9	0.033
107834	J1	204.4	0.023
107834	Q1	166.7	0.051
107834	2Q1	184.5	0.015
107834	P1	194.7	0.127
107834	2SM2	226.8	0.006
107834	M3	254.8	0.013
107834	L2	300.1	0.066
107834	2MK3	259.5	0.061
107834	K2	329.6	0.092
107834	M8	221.9	0.009
107834	MS4	189	0.012
107835	M2	287.5	0.917
107835	S2	318.5	0.183
107835	N2	268.4	0.217
107835	K1	182.1	0.45
107835	M4	319.9	0.008
107835	O1	161.7	0.247
107835	M6	44.2	0.014
107835	MK3	208.6	0.089
107835	S4	41.6	0.002
107835	MN4	272.1	0.011
107835	S6	314.6	0.003
107835	2N2	259	0.012
107835	OO1	96	0.037
107835	M1	214.6	0.025
107835	J1	165.5	0.017
107835	Q1	161.5	0.047
107835	2Q1	174.4	0.013
107835	P1	193.2	0.116
107835	2SM2	260.8	0.008
107835	M3	205.2	0.022
107835	L2	304.4	0.074
107835	2MK3	243.8	0.078
107835	K2	326.8	0.108
107835	M8	232.2	0.014
107835	MS4	307.4	0.011
107836	M2	233	1.07
107836	S2	248.1	0.345
107836	N2	191	0.239
107836	K1	103.4	0.249
107836	M4	353.2	0.08
107836	O1	88.5	0.231
107836	M6	308	0.033
107836	MK3	216.8	0.177
107836	S4	54.3	0.01
107836	MN4	315.1	0.047
107836	S6	162.6	0.005
107836	2N2	105	0.102
107836	OO1	2.6	0.017
107836	M1	298.6	0.066
107836	J1	98.8	0.064
107836	Q1	150.8	0.018
107836	2Q1	326.2	0.059
107836	P1	126.1	0.19
107836	2SM2	186.3	0.01
107836	M3	142.2	0.057
107836	L2	275.7	0.048
107836	2MK3	217.1	0.155
107836	K2	215.5	0.178
107836	M8	313.7	0.005
107836	MS4	39.2	0.015
107837	M2	233	1.082
107837	S2	248.5	0.348
107837	N2	191.1	0.243
107837	K1	103.6	0.251
107837	M4	353.3	0.077
107837	O1	88.7	0.235
107837	M6	306.9	0.033
107837	MK3	217.6	0.177
107837	S4	56.2	0.01
107837	MN4	315.1	0.045
107837	S6	170.3	0.005
107837	2N2	105.4	0.104
107837	OO1	2.7	0.019
107837	M1	298	0.066
107837	J1	99.4	0.065
107837	Q1	146.6	0.019
107837	2Q1	326.4	0.059
107837	P1	126.4	0.194
107837	2SM2	183.7	0.01
107837	M3	143.5	0.059
107837	L2	276.6	0.05
107837	2MK3	217.3	0.157
107837	K2	216.1	0.181
107837	M8	323.7	0.004
107837	MS4	41	0.014
107838	M2	232.9	1.094
107838	S2	248.5	0.351
107838	N2	191.1	0.248
107838	K1	103.5	0.251
107838	M4	353.9	0.074
107838	O1	88.9	0.239
107838	M6	306.3	0.033
107838	MK3	218.4	0.177
107838	S4	61.1	0.01
107838	MN4	315.3	0.043
107838	S6	163.5	0.004
107838	2N2	105.1	0.106
107838	OO1	2.3	0.022
107838	M1	298	0.065
107838	J1	99.7	0.065
107838	Q1	145.4	0.019
107838	2Q1	326	0.059
107838	P1	126.8	0.197
107838	2SM2	180.5	0.009
107838	M3	144.2	0.059
107838	L2	277.7	0.051
107838	2MK3	217.6	0.16
107838	K2	216	0.184
107838	M8	332.8	0.003
107838	MS4	45.1	0.014
107839	M2	233	1.105
107839	S2	248.5	0.355
107839	N2	191.2	0.252
107839	K1	103.5	0.254
107839	M4	354.4	0.071
107839	O1	89.3	0.242
107839	M6	306.1	0.033
107839	MK3	219	0.178
107839	S4	59.9	0.01
107839	MN4	316.8	0.042
107839	S6	161.5	0.004
107839	2N2	105.3	0.108
107839	OO1	1.5	0.024
107839	M1	297.8	0.065
107839	J1	100.6	0.067
107839	Q1	145.7	0.019
107839	2Q1	326.3	0.059
107839	P1	126.8	0.199
107839	2SM2	178.4	0.009
107839	M3	144.8	0.06
107839	L2	278.2	0.053
107839	2MK3	218	0.162
107839	K2	215.6	0.187
107839	M8	4.9	0.002
107839	MS4	51.3	0.014
107840	M2	233	1.115
107840	S2	248.5	0.359
107840	N2	191.2	0.256
107840	K1	103.3	0.255
107840	M4	355.7	0.068
107840	O1	89.8	0.245
107840	M6	306.5	0.033
107840	MK3	219.9	0.178
107840	S4	61.4	0.011
107840	MN4	319.2	0.04
107840	S6	152.9	0.005
107840	2N2	105.4	0.11
107840	OO1	1.1	0.025
107840	M1	297.3	0.066
107840	J1	101.5	0.067
107840	Q1	144.3	0.019
107840	2Q1	326.3	0.059
107840	P1	127.2	0.201
107840	2SM2	176.6	0.008
107840	M3	145.3	0.062
107840	L2	278.9	0.055
107840	2MK3	218.5	0.163
107840	K2	215.2	0.19
107840	M8	45.3	0.003
107840	MS4	56	0.014
107841	M2	233	1.125
107841	S2	248.5	0.36
107841	N2	191.1	0.26
107841	K1	102.9	0.257
107841	M4	357.1	0.065
107841	O1	90.3	0.248
107841	M6	307.1	0.033
107841	MK3	220.9	0.179
107841	S4	59.7	0.011
107841	MN4	322.6	0.039
107841	S6	149.1	0.004
107841	2N2	105.5	0.113
107841	OO1	2.6	0.025
107841	M1	297	0.067
107841	J1	102.7	0.068
107841	Q1	142.9	0.019
107841	2Q1	326.8	0.06
107841	P1	127.5	0.202
107841	2SM2	176	0.008
107841	M3	145.1	0.064
107841	L2	278.8	0.057
107841	2MK3	219.1	0.165
107841	K2	215.4	0.193
107841	M8	67.3	0.004
107841	MS4	61.9	0.015
107842	M2	233.1	1.134
107842	S2	248.4	0.361
107842	N2	191.2	0.263
107842	K1	102.4	0.261
107842	M4	359	0.061
107842	O1	90.8	0.251
107842	M6	308.6	0.033
107842	MK3	221.9	0.179
107842	S4	54.3	0.011
107842	MN4	325.6	0.038
107842	S6	142.1	0.004
107842	2N2	105.9	0.115
107842	OO1	1.1	0.025
107842	M1	296.8	0.068
107842	J1	103.1	0.067
107842	Q1	142.3	0.019
107842	2Q1	327.2	0.061
107842	P1	127.6	0.202
107842	2SM2	175.8	0.008
107842	M3	145.2	0.065
107842	L2	278.7	0.059
107842	2MK3	219.7	0.165
107842	K2	215.6	0.194
107842	M8	83.3	0.005
107842	MS4	68.1	0.016
107843	M2	233.1	1.141
107843	S2	248.4	0.363
107843	N2	191.3	0.266
107843	K1	102	0.264
107843	M4	1.2	0.058
107843	O1	91.4	0.254
107843	M6	309.5	0.033
107843	MK3	222.9	0.179
107843	S4	52.7	0.012
107843	MN4	329.1	0.037
107843	S6	130.8	0.004
107843	2N2	106.6	0.117
107843	OO1	357.2	0.024
107843	M1	296.3	0.07
107843	J1	103.7	0.067
107843	Q1	144.2	0.019
107843	2Q1	327.8	0.063
107843	P1	127.7	0.201
107843	2SM2	171.3	0.008
107843	M3	145.7	0.067
107843	L2	278.9	0.06
107843	2MK3	220.4	0.167
107843	K2	216.1	0.197
107843	M8	91.6	0.006
107843	MS4	72	0.018
107844	M2	233.2	1.147
107844	S2	248.3	0.364
107844	N2	191.4	0.268
107844	K1	101.8	0.268
107844	M4	3.1	0.055
107844	O1	92	0.256
107844	M6	310.3	0.033
107844	MK3	223.6	0.18
107844	S4	47.1	0.013
107844	MN4	332.5	0.037
107844	S6	121.7	0.003
107844	2N2	106.9	0.118
107844	OO1	354.5	0.023
107844	M1	295.8	0.071
107844	J1	104.5	0.067
107844	Q1	146.8	0.019
107844	2Q1	327.7	0.064
107844	P1	127.6	0.201
107844	2SM2	167.1	0.008
107844	M3	146.1	0.068
107844	L2	279.4	0.062
107844	2MK3	220.9	0.168
107844	K2	216.2	0.199
107844	M8	103.3	0.006
107844	MS4	76	0.021
107845	M2	233.3	1.152
107845	S2	248.2	0.365
107845	N2	191.6	0.271
107845	K1	101.7	0.272
107845	M4	5	0.052
107845	O1	92.7	0.259
107845	M6	311.9	0.032
107845	MK3	224.2	0.18
107845	S4	44.5	0.013
107845	MN4	337	0.037
107845	S6	107.6	0.003
107845	2N2	107.3	0.118
107845	OO1	351.7	0.023
107845	M1	295.2	0.073
107845	J1	104.9	0.066
107845	Q1	148	0.018
107845	2Q1	328.5	0.065
107845	P1	127.2	0.2
107845	2SM2	166.2	0.007
107845	M3	146.2	0.07
107845	L2	280.1	0.063
107845	2MK3	221.6	0.169
107845	K2	216.5	0.2
107845	M8	109.5	0.007
107845	MS4	79.3	0.023
107846	M2	233.4	1.155
107846	S2	248.2	0.365
107846	N2	191.9	0.273
107846	K1	101.2	0.277
107846	M4	6.9	0.049
107846	O1	93	0.261
107846	M6	312.8	0.032
107846	MK3	224.7	0.18
107846	S4	40.1	0.014
107846	MN4	341.3	0.036
107846	S6	103.9	0.002
107846	2N2	108.1	0.119
107846	OO1	351.2	0.023
107846	M1	295	0.075
107846	J1	105.1	0.065
107846	Q1	149.8	0.018
107846	2Q1	328.4	0.067
107846	P1	127.4	0.197
107846	2SM2	153.9	0.007
107846	M3	146.5	0.071
107846	L2	280.2	0.066
107846	2MK3	222.2	0.17
107846	K2	216.7	0.201
107846	M8	116.3	0.007
107846	MS4	82.1	0.026
107847	M2	233.5	1.158
107847	S2	248.3	0.365
107847	N2	192.2	0.274
107847	K1	101	0.282
107847	M4	8.9	0.047
107847	O1	93.4	0.263
107847	M6	315.2	0.032
107847	MK3	225.2	0.18
107847	S4	40.7	0.014
107847	MN4	345.8	0.036
107847	S6	117.2	0.002
107847	2N2	109	0.119
107847	OO1	348.7	0.024
107847	M1	294.6	0.077
107847	J1	105.8	0.065
107847	Q1	148.9	0.018
107847	2Q1	328.3	0.068
107847	P1	127.1	0.194
107847	2SM2	142.2	0.006
107847	M3	146.5	0.073
107847	L2	280.8	0.067
107847	2MK3	222.7	0.171
107847	K2	216.8	0.203
107847	M8	121.7	0.007
107847	MS4	84.2	0.028
107848	M2	233.6	1.161
107848	S2	248.4	0.367
107848	N2	192.4	0.276
107848	K1	100.8	0.286
107848	M4	11.8	0.045
107848	O1	93.8	0.266
107848	M6	315.7	0.032
107848	MK3	225.4	0.18
107848	S4	37.9	0.015
107848	MN4	349.1	0.035
107848	2N2	109.9	0.119
107848	OO1	346.9	0.025
107848	M1	294.2	0.08
107848	J1	106.1	0.064
107848	Q1	148.7	0.017
107848	2Q1	328.6	0.07
107848	P1	127.1	0.191
107848	2SM2	123.7	0.007
107848	M3	146.6	0.074
107848	L2	281.2	0.069
107848	2MK3	223.2	0.172
107848	K2	216.6	0.206
107848	M8	126.2	0.007
107848	MS4	85.6	0.03
107849	M2	233.7	1.162
107849	S2	248.5	0.37
107849	N2	192.8	0.277
107849	K1	100.4	0.291
107849	M4	14	0.043
107849	O1	94.1	0.268
107849	M6	318.5	0.032
107849	MK3	225.6	0.18
107849	S4	33.3	0.016
107849	MN4	352.7	0.034
107849	S6	128	0.002
107849	2N2	111.1	0.119
107849	OO1	346.8	0.026
107849	M1	293.9	0.082
107849	J1	106.4	0.063
107849	Q1	147.6	0.017
107849	2Q1	329.3	0.071
107849	P1	127.1	0.187
107849	2SM2	108.7	0.008
107849	M3	146.9	0.076
107849	L2	282.3	0.071
107849	2MK3	223.5	0.174
107849	K2	216.2	0.208
107849	M8	133.9	0.007
107849	MS4	84.8	0.032
107850	M2	233.9	1.164
107850	S2	248.5	0.373
107850	N2	193.2	0.279
107850	K1	100	0.296
107850	M4	17.2	0.042
107850	O1	94.4	0.27
107850	M6	321.1	0.031
107850	MK3	225.7	0.181
107850	S4	30.3	0.015
107850	MN4	355	0.035
107850	S6	145.4	0.002
107850	2N2	112.3	0.119
107850	OO1	344.8	0.027
107850	M1	294	0.084
107850	J1	106.4	0.063
107850	Q1	144.4	0.017
107850	2Q1	329.4	0.072
107850	P1	127.2	0.184
107850	2SM2	102.2	0.009
107850	M3	146.6	0.077
107850	L2	283.2	0.073
107850	2MK3	223.8	0.176
107850	K2	215.6	0.211
107850	M8	142.2	0.006
107850	MS4	83.6	0.034
107851	M2	234.1	1.168
107851	S2	248.4	0.376
107851	N2	193.5	0.28
107851	K1	99.5	0.302
107851	M4	20.7	0.041
107851	O1	94.5	0.272
107851	M6	323.8	0.032
107851	MK3	226.1	0.183
107851	S4	26.5	0.016
107851	MN4	356.9	0.035
107851	S6	146.2	0.003
107851	2N2	113.4	0.119
107851	OO1	344.2	0.029
107851	M1	293.9	0.087
107851	J1	106.6	0.062
107851	Q1	140.8	0.016
107851	2Q1	330.3	0.074
107851	P1	127.3	0.179
107851	2SM2	98.5	0.01
107851	M3	146.7	0.079
107851	L2	284.4	0.075
107851	2MK3	224.2	0.179
107851	K2	214.8	0.214
107851	M8	152.7	0.006
107851	MS4	82.7	0.036
107852	M2	234.3	1.172
107852	S2	248.3	0.379
107852	N2	194.1	0.282
107852	K1	99.5	0.309
107852	M4	23.8	0.04
107852	O1	94.7	0.276
107852	M6	327.3	0.032
107852	MK3	226.6	0.185
107852	S4	18.4	0.016
107852	MN4	357.3	0.035
107852	S6	146.8	0.003
107852	2N2	114.4	0.118
107852	OO1	341.5	0.028
107852	M1	293.8	0.088
107852	J1	106.8	0.06
107852	Q1	138.1	0.016
107852	2Q1	331.2	0.076
107852	P1	127	0.176
107852	2SM2	98.9	0.012
107852	M3	146.5	0.081
107852	L2	284.9	0.076
107852	2MK3	224.7	0.183
107852	K2	214	0.216
107852	M8	159	0.007
107852	MS4	81.5	0.038
107853	M2	234.6	1.175
107853	S2	248.4	0.381
107853	N2	194.8	0.284
107853	K1	99.1	0.319
107853	M4	25.7	0.04
107853	O1	94.7	0.278
107853	M6	331.5	0.031
107853	MK3	226.6	0.19
107853	S4	15.6	0.015
107853	MN4	357.1	0.034
107853	S6	142.4	0.004
107853	2N2	114.9	0.117
107853	OO1	340.6	0.029
107853	M1	293.5	0.091
107853	J1	105.4	0.059
107853	Q1	138	0.017
107853	2Q1	332.4	0.077
107853	P1	126.6	0.169
107853	2SM2	96.6	0.012
107853	M3	146	0.084
107853	L2	285.5	0.078
107853	2MK3	225	0.188
107853	K2	213.4	0.218
107853	M8	170.3	0.007
107853	MS4	77.7	0.039
107854	M2	340.7	1.137
107854	S2	13.1	0.244
107854	N2	319.6	0.22
107854	K1	218.3	0.912
107854	M4	174.7	0.053
107854	O1	202.8	0.439
107854	M6	227.8	0.03
107854	MK3	237.7	0.091
107854	S4	244.9	0.039
107854	MN4	155.4	0.023
107854	NU2	279.3	0.058
107854	S6	114.9	0.009
107854	MU2	200.8	0.04
107854	2N2	318.9	0.036
107854	OO1	230.6	0.151
107854	LDA2	307.2	0.036
107854	M1	261	0.079
107854	J1	284	0.053
107854	RHO1	23.2	0.053
107854	Q1	194.7	0.1
107854	2Q1	163.9	0.039
107854	P1	230.5	0.243
107854	2SM2	218.6	0.014
107854	M3	3.9	0.061
107854	L2	17.8	0.071
107854	2MK3	247.5	0.063
107854	K2	349	0.045
107854	M8	134.7	0.017
107854	MS4	228.7	0.042
107855	M2	343.9	1.123
107855	S2	13	0.24
107855	N2	324.2	0.19
107855	K1	221.9	0.95
107855	M4	164.3	0.08
107855	O1	210.1	0.413
107855	M6	242.1	0.045
107855	MK3	269.3	0.104
107855	S4	249.3	0.026
107855	MN4	120.8	0.037
107855	NU2	271.5	0.067
107855	S6	80.6	0.013
107855	MU2	170	0.057
107855	2N2	32.7	0.021
107855	OO1	241.7	0.141
107855	LDA2	317.6	0.053
107855	M1	295.9	0.12
107855	J1	314.4	0.037
107855	RHO1	27.4	0.067
107855	Q1	215.1	0.112
107855	2Q1	187.7	0.02
107855	P1	230.9	0.219
107855	2SM2	261.8	0.029
107855	M3	344.1	0.077
107855	L2	25.8	0.098
107855	2MK3	289	0.1
107855	K2	338.9	0.044
107855	M8	191.7	0.02
107855	MS4	227.5	0.072
107856	M2	341.5	1.054
107856	S2	7.1	0.208
107856	N2	328.5	0.142
107856	K1	223.6	0.925
107856	M4	137.1	0.099
107856	O1	207.7	0.358
107856	M6	270.8	0.064
107856	MK3	301.7	0.156
107856	S4	250.4	0.012
107856	MN4	96.2	0.035
107856	NU2	287.8	0.086
107856	S6	121.2	0.01
107856	MU2	147.9	0.082
107856	2N2	100.7	0.048
107856	OO1	252.9	0.133
107856	LDA2	319.8	0.07
107856	M1	317.8	0.147
107856	J1	37.3	0.027
107856	RHO1	52.2	0.065
107856	Q1	231.8	0.113
107856	2Q1	268.1	0.016
107856	P1	224.8	0.195
107856	2SM2	265.1	0.054
107856	M3	335.8	0.091
107856	L2	33.9	0.115
107856	2MK3	312.2	0.181
107856	K2	10.8	0.035
107856	M8	180.8	0.021
107856	MS4	218.6	0.063
107857	M2	326.5	0.416
107857	S2	336.7	0.1
107857	N2	279.9	0.092
107857	K1	211.6	0.265
107857	M4	279	0.03
107857	O1	182.5	0.179
107857	M6	334.8	0.011
107857	MK3	194.3	0.054
107857	S4	98.2	0.014
107857	MN4	258.4	0.014
107857	S6	42.2	0.003
107857	2N2	182.7	0.02
107857	OO1	322.3	0.102
107857	M1	99.1	0.032
107857	J1	173.2	0.029
107857	Q1	183.7	0.013
107857	2Q1	347.7	0.033
107857	P1	189.6	0.14
107857	2SM2	189.1	0.012
107857	M3	102.6	0.013
107857	L2	88.4	0.028
107857	2MK3	146.8	0.038
107857	M8	279.4	0.003
107857	MS4	286.3	0.028
107858	M2	326.5	0.463
107858	S2	337.3	0.11
107858	N2	292.4	0.11
107858	K1	212.5	0.298
107858	M4	307.2	0.035
107858	O1	170.5	0.222
107858	M6	307.3	0.02
107858	MK3	183.3	0.055
107858	S4	345.7	0.003
107858	MN4	227.6	0.012
107858	S6	122.2	0.006
107858	2N2	171.1	0.017
107858	OO1	321.1	0.072
107858	M1	72.4	0.011
107858	J1	199.7	0.044
107858	Q1	167.3	0.027
107858	2Q1	331.6	0.044
107858	P1	183.8	0.139
107858	2SM2	114.6	0.02
107858	M3	120.6	0.022
107858	L2	87.4	0.02
107858	2MK3	142.1	0.053
107858	M8	240.4	0.005
107858	MS4	318.7	0.014
107859	M2	318.3	0.503
107859	S2	358.6	0.093
107859	N2	281.7	0.087
107859	K1	219.4	0.302
107859	M4	329.6	0.027
107859	O1	160	0.261
107859	M6	296.2	0.019
107859	MK3	140.8	0.045
107859	S4	296	0.011
107859	MN4	281.6	0.016
107859	S6	98	0.002
107859	2N2	177.7	0.036
107859	OO1	282.9	0.042
107859	M1	1.7	0.009
107859	J1	231.6	0.029
107859	Q1	139.6	0.048
107859	2Q1	317.9	0.031
107859	P1	151.5	0.091
107859	2SM2	58	0.031
107859	M3	161.3	0.013
107859	L2	357.5	0.018
107859	2MK3	105.4	0.058
107859	M8	240	0.007
107859	MS4	321.8	0.034
107860	M2	317.1	0.741
107860	S2	357.1	0.204
107860	N2	305.1	0.156
107860	K1	199.3	0.385
107860	M4	199.4	0.022
107860	O1	190	0.221
107860	M6	235.3	0.004
107860	MK3	71.7	0.041
107860	S4	328.5	0.008
107860	MN4	179.4	0.01
107860	S6	60.5	0.003
107860	2N2	318.2	0.019
107860	OO1	51.2	0.035
107860	M1	245.6	0.03
107860	J1	226.2	0.042
107860	Q1	188.1	0.035
107860	2Q1	250	0.022
107860	P1	231.9	0.12
107860	2SM2	353.7	0.013
107860	M3	216.9	0.007
107860	L2	328.2	0.008
107860	2MK3	63.8	0.023
107860	K2	30	0.033
107860	M8	156.5	0.001
107860	MS4	275.7	0.016
107861	M2	304.5	0.768
107861	S2	328.8	0.207
107861	N2	293.1	0.185
107861	K1	194.7	0.338
107861	M4	159.8	0.025
107861	O1	183	0.19
107861	M6	67	0.006
107861	MK3	22.4	0.035
107861	S4	200.2	0.015
107861	MN4	159.8	0.021
107861	S6	345.7	0.006
107861	2N2	346.7	0.038
107861	OO1	355.3	0.053
107861	M1	257.6	0.02
107861	J1	226.7	0.058
107861	Q1	182.6	0.041
107861	2Q1	252.4	0.014
107861	P1	244.7	0.092
107861	2SM2	175.5	0.034
107861	M3	172.6	0.009
107861	L2	318.3	0.03
107861	2MK3	0.9	0.016
107861	K2	340.6	0.069
107861	M8	246.5	0.003
107861	MS4	192.3	0.033
107862	M2	293.7	0.731
107862	S2	328.7	0.145
107862	N2	280.9	0.231
107862	K1	206.1	0.257
107862	M4	225.3	0.015
107862	O1	183.8	0.146
107862	M6	284.1	0.007
107862	MK3	80.3	0.021
107862	S4	148	0.01
107862	MN4	101.7	0.009
107862	S6	23.2	0.008
107862	2N2	305.7	0.018
107862	OO1	70.7	0.028
107862	M1	161.7	0.014
107862	J1	216.4	0.088
107862	Q1	112.9	0.022
107862	2Q1	246.1	0.016
107862	P1	237.7	0.146
107862	2SM2	136.9	0.032
107862	M3	24.8	0.022
107862	L2	247.1	0.039
107862	2MK3	151.4	0.005
107862	K2	357.6	0.165
107862	M8	209	0.005
107862	MS4	191.2	0.019
107863	M2	315.2	0.74
107863	S2	333.9	0.198
107863	N2	286.1	0.202
107863	K1	211.8	0.499
107863	M4	241.9	0.079
107863	O1	188.1	0.207
107863	M6	316.3	0.028
107863	MK3	180	0.143
107863	S4	38.7	0.004
107863	MN4	211.3	0.042
107863	S6	114.1	0.004
107863	2N2	228.4	0.067
107863	OO1	201.7	0.033
107863	M1	224.8	0.065
107863	J1	243.1	0.058
107863	Q1	178.4	0.08
107863	2Q1	113.7	0.053
107863	P1	207.5	0.172
107863	2SM2	321.2	0.02
107863	M3	74.6	0.059
107863	L2	178	0.027
107863	2MK3	85.1	0.072
107863	K2	302.8	0.084
107863	M8	175.5	0.003
107863	MS4	233.5	0.056
107864	M2	327.8	1.075
107864	S2	349.2	0.305
107864	N2	300.3	0.245
107864	K1	239.1	0.784
107864	M4	7.9	0.036
107864	O1	213.6	0.432
107864	M6	180.8	0.025
107864	MK3	104.4	0.114
107864	S4	154.2	0.019
107864	MN4	60.7	0.003
107864	S6	70.5	0.02
107864	2N2	173.7	0.122
107864	OO1	289.9	0.036
107864	M1	136.8	0.085
107864	J1	223.6	0.092
107864	Q1	157.5	0.075
107864	2Q1	1.9	0.057
107864	P1	213.1	0.268
107864	2SM2	110.1	0.028
107864	M3	232.9	0.019
107864	L2	33.1	0.032
107864	2MK3	32.7	0.117
107864	K2	48.7	0.06
107864	M8	148.4	0.011
107864	MS4	73.8	0.059
107865	M2	328.7	1.066
107865	S2	350.9	0.298
107865	N2	299.8	0.232
107865	K1	241.9	0.803
107865	M4	0.7	0.051
107865	O1	213.3	0.461
107865	M6	172.6	0.033
107865	MK3	107.1	0.083
107865	S4	145.2	0.02
107865	MN4	329.7	0.014
107865	S6	94.9	0.02
107865	2N2	174.9	0.125
107865	OO1	313.6	0.042
107865	M1	132.3	0.09
107865	J1	223.5	0.09
107865	Q1	147.5	0.076
107865	2Q1	352.2	0.064
107865	P1	213.8	0.269
107865	2SM2	118.1	0.027
107865	M3	241.9	0.022
107865	L2	29.2	0.047
107865	2MK3	28	0.1
107865	K2	64.3	0.055
107865	M8	156.6	0.008
107865	MS4	69.7	0.06
107866	M2	308.1	1.433
107866	S2	335.8	0.368
107866	N2	272.9	0.339
107866	K1	197.6	0.893
107866	M4	310.2	0.031
107866	O1	169.6	0.481
107866	M6	112.3	0.019
107866	MK3	137.1	0.063
107866	S4	141.1	0.018
107866	MN4	231.9	0.039
107866	S6	115.6	0.014
107866	2N2	169.1	0.085
107866	OO1	242.4	0.042
107866	M1	151.4	0.023
107866	J1	229.6	0.079
107866	Q1	137.8	0.067
107866	2Q1	10	0.055
107866	P1	197.9	0.224
107866	2SM2	346.9	0.015
107866	M3	3.1	0.011
107866	L2	18.5	0.011
107866	2MK3	101.5	0.016
107866	K2	7.4	0.121
107866	M8	244.7	0.008
107866	MS4	226.1	0.033
107867	M2	316.2	1.588
107867	S2	339.7	0.447
107867	N2	277.6	0.323
107867	K1	206.6	1.097
107867	M4	301.1	0.083
107867	O1	165.1	0.664
107867	M6	159.9	0.039
107867	MK3	159.7	0.167
107867	S4	323.5	0.008
107867	MN4	286.2	0.051
107867	S6	290.6	0.014
107867	2N2	158.6	0.128
107867	OO1	303	0.072
107867	M1	122.3	0.018
107867	J1	189.5	0.108
107867	Q1	129.1	0.105
107867	2Q1	296.8	0.087
107867	P1	207.6	0.333
107867	2SM2	238.2	0.03
107867	M3	92.2	0.035
107867	L2	49.7	0.063
107867	2MK3	60.3	0.035
107867	K2	40.8	0.106
107867	M8	93.6	0.023
107867	MS4	321.4	0.069
107868	M2	318.3	1.591
107868	S2	337.7	0.442
107868	N2	278.7	0.309
107868	K1	211.2	1.105
107868	M4	308.6	0.092
107868	O1	169.1	0.678
107868	M6	160	0.041
107868	MK3	156.7	0.198
107868	S4	326.5	0.009
107868	MN4	288.8	0.063
107868	S6	234.2	0.011
107868	2N2	154.1	0.128
107868	OO1	310.1	0.109
107868	M1	80.6	0.045
107868	J1	183.9	0.116
107868	Q1	121.3	0.091
107868	2Q1	294	0.101
107868	P1	206.8	0.357
107868	2SM2	234.1	0.041
107868	M3	88.7	0.034
107868	L2	40.6	0.101
107868	2MK3	49.5	0.029
107868	K2	55.6	0.108
107868	M8	84	0.022
107868	MS4	333.9	0.068
107869	M2	316.9	1.757
107869	S2	343.4	0.421
107869	N2	282.3	0.382
107869	K1	212.4	1.131
107869	M4	276.5	0.084
107869	O1	184.2	0.594
107869	M6	160	0.036
107869	MK3	122.9	0.082
107869	S4	226.3	0.007
107869	MN4	248.7	0.042
107869	S6	97	0.005
107869	2N2	178.5	0.101
107869	OO1	310.8	0.062
107869	M1	118.1	0.053
107869	J1	207.1	0.078
107869	Q1	156	0.095
107869	2Q1	331.1	0.017
107869	P1	199	0.311
107869	2SM2	234	0.017
107869	M3	337.6	0.011
107869	L2	348.4	0.034
107869	2MK3	51.8	0.041
107869	K2	344	0.135
107869	M8	282.4	0.011
107869	MS4	319	0.067
107870	M2	320.3	1.846
107870	S2	344.2	0.442
107870	N2	284.1	0.397
107870	K1	217.5	1.273
107870	M4	306.5	0.03
107870	O1	188.3	0.701
107870	M6	358.1	0.01
107870	MK3	15.5	0.041
107870	S4	216.4	0.008
107870	MN4	291.9	0.013
107870	S6	57.6	0.011
107870	2N2	180.8	0.102
107870	OO1	317.9	0.049
107870	M1	73.2	0.046
107870	J1	217.6	0.082
107870	Q1	163.3	0.075
107870	2Q1	293.2	0.046
107870	P1	202.8	0.32
107870	2SM2	323.9	0.016
107870	M3	351.3	0.02
107870	L2	15.6	0.044
107870	2MK3	10	0.016
107870	K2	352.2	0.128
107870	M8	282.7	0.012
107870	MS4	282.8	0.038
107871	M2	321.2	1.838
107871	S2	345.7	0.47
107871	N2	285.1	0.397
107871	K1	219	1.325
107871	M4	121.1	0.029
107871	O1	187.8	0.747
107871	M6	322.7	0.029
107871	MK3	353.1	0.116
107871	S4	225.3	0.015
107871	MN4	104	0.008
107871	S6	71.6	0.005
107871	2N2	166.7	0.077
107871	OO1	266.9	0.092
107871	M1	35.6	0.049
107871	J1	210.9	0.102
107871	Q1	179.1	0.061
107871	2Q1	281.7	0.062
107871	P1	205.7	0.327
107871	2SM2	341.4	0.019
107871	M3	310	0.014
107871	L2	22.7	0.052
107871	2MK3	302.8	0.018
107871	K2	12.4	0.137
107871	M8	229.4	0.019
107871	MS4	227	0.03
107872	M2	280.4	2.1
107872	S2	301.1	0.488
107872	N2	241.3	0.419
107872	K1	183.8	0.864
107872	M4	136.7	0.074
107872	O1	167.6	0.417
107872	M6	329.3	0.09
107872	MK3	338	0.07
107872	S4	333.4	0.006
107872	MN4	67.7	0.039
107872	S6	0	0.007
107872	2N2	294.8	0.004
107872	OO1	225.1	0.117
107872	M1	198.8	0.034
107872	J1	214.7	0.05
107872	Q1	155.4	0.055
107872	2Q1	129.3	0.045
107872	P1	175.6	0.256
107872	2SM2	202	0.029
107872	M3	352.1	0.049
107872	L2	328.7	0.099
107872	2MK3	205	0.121
107872	K2	303	0.189
107872	M8	241.1	0.024
107872	MS4	91.4	0.07
107873	M2	280.3	2.14
107873	S2	301.3	0.495
107873	N2	240.8	0.429
107873	K1	183.5	0.887
107873	M4	134.6	0.061
107873	O1	168.3	0.424
107873	M6	328.2	0.091
107873	MK3	338.3	0.07
107873	S4	314.1	0.011
107873	MN4	58.9	0.035
107873	S6	357.4	0.007
107873	2N2	207.8	0.004
107873	OO1	228.4	0.121
107873	M1	207.7	0.037
107873	J1	215	0.051
107873	Q1	170.8	0.053
107873	2Q1	121.3	0.044
107873	P1	175.3	0.258
107873	2SM2	197.6	0.029
107873	M3	349.5	0.054
107873	L2	328.3	0.098
107873	2MK3	203.6	0.124
107873	K2	304.5	0.192
107873	M8	239.4	0.025
107873	MS4	85.4	0.074
107874	M2	280.2	2.126
107874	S2	300.8	0.488
107874	N2	240.9	0.421
107874	K1	183.7	0.887
107874	M4	136	0.055
107874	O1	167.9	0.419
107874	M6	328.3	0.092
107874	MK3	344.8	0.07
107874	S4	305.5	0.011
107874	MN4	56.7	0.032
107874	S6	3.5	0.006
107874	2N2	189.1	0.01
107874	OO1	228.8	0.124
107874	M1	205.7	0.04
107874	J1	213.6	0.059
107874	Q1	174.3	0.052
107874	2Q1	121.9	0.043
107874	P1	176.7	0.251
107874	2SM2	191.8	0.029
107874	M3	354.8	0.055
107874	L2	329.6	0.1
107874	2MK3	204.6	0.124
107874	K2	303.6	0.19
107874	M8	247.8	0.025
107874	MS4	84.5	0.069
107875	M2	290.6	1.095
107875	S2	304.5	0.208
107875	N2	256.1	0.223
107875	K1	188.5	0.595
107875	M4	168.9	0.139
107875	O1	183.9	0.125
107875	M6	127.1	0.047
107875	MK3	36.6	0.219
107875	S4	73.2	0.007
107875	MN4	144.6	0.05
107875	S6	245.6	0.004
107875	2N2	111	0.08
107875	OO1	244.7	0.161
107875	M1	5.7	0.02
107875	J1	194.7	0.042
107875	Q1	54.1	0.012
107875	2Q1	160.4	0.042
107875	P1	219.8	0.084
107875	2SM2	139.6	0.009
107875	M3	356.8	0.059
107875	L2	346.8	0.084
107875	2MK3	285.9	0.163
107875	K2	6.3	0.094
107875	M8	93.9	0.026
107875	MS4	192.1	0.094
107876	M2	287.8	1.116
107876	S2	310.2	0.206
107876	N2	249.8	0.221
107876	K1	181.6	0.532
107876	M4	166.9	0.163
107876	O1	192.9	0.077
107876	M6	126	0.059
107876	MK3	38.1	0.288
107876	S4	163.3	0.004
107876	MN4	133.4	0.057
107876	S6	254.2	0.003
107876	2N2	128.1	0.055
107876	OO1	223.8	0.175
107876	M1	150.2	0.018
107876	J1	179.2	0.06
107876	Q1	125.1	0.034
107876	2Q1	183.6	0.016
107876	P1	209.5	0.105
107876	2SM2	135	0.014
107876	M3	4.9	0.039
107876	L2	337.3	0.091
107876	2MK3	289.9	0.184
107876	K2	6.4	0.115
107876	M8	73.7	0.025
107876	MS4	189.3	0.097
107877	M2	288.9	1.139
107877	S2	306.9	0.203
107877	N2	248.2	0.221
107877	K1	180.3	0.518
107877	M4	168.2	0.152
107877	O1	224.1	0.063
107877	M6	129.3	0.072
107877	MK3	36.8	0.282
107877	S4	232	0.012
107877	MN4	131.1	0.045
107877	S6	244.3	0.006
107877	2N2	118	0.041
107877	OO1	226.1	0.164
107877	M1	120.4	0.034
107877	J1	154	0.066
107877	Q1	122.6	0.057
107877	2Q1	273.6	0.026
107877	P1	207.1	0.133
107877	2SM2	159.8	0.02
107877	M3	13.3	0.027
107877	L2	339.1	0.117
107877	2MK3	289.9	0.2
107877	K2	356.5	0.099
107877	M8	54.4	0.025
107877	MS4	194.3	0.077
107878	M2	321.2	1.947
107878	S2	346.5	0.506
107878	N2	288.8	0.414
107878	K1	217.2	1.239
107878	M4	213.1	0.059
107878	O1	196.6	0.596
107878	M6	300.9	0.018
107878	MK3	92.5	0.128
107878	S4	154.6	0.016
107878	MN4	215	0.05
107878	S6	209.6	0.011
107878	2N2	186.2	0.16
107878	OO1	316.3	0.097
107878	M1	113.8	0.099
107878	J1	200	0.084
107878	Q1	157.9	0.058
107878	2Q1	332.9	0.073
107878	P1	199	0.41
107878	2SM2	217.3	0.017
107878	M3	82.3	0.038
107878	L2	16.9	0.032
107878	2MK3	18.8	0.045
107878	K2	29.7	0.129
107878	M8	306.1	0.018
107878	MS4	259.5	0.05
107879	M2	320.9	2.215
107879	S2	340.4	0.595
107879	N2	284.2	0.494
107879	K1	213.4	1.454
107879	M4	216.8	0.009
107879	O1	184.5	0.803
107879	M6	255.1	0.029
107879	MK3	56	0.148
107879	S4	8.5	0.016
107879	MN4	93.8	0.032
107879	S6	54.4	0.009
107879	2N2	174.1	0.135
107879	OO1	273.2	0.115
107879	M1	318.5	0.007
107879	J1	226.2	0.108
107879	Q1	184.5	0.101
107879	2Q1	276.2	0.025
107879	P1	205.6	0.42
107879	2SM2	264.1	0.012
107879	M3	49.8	0.022
107879	L2	26.1	0.056
107879	2MK3	14.2	0.131
107879	K2	25.4	0.164
107879	M8	136.3	0.013
107879	MS4	260.9	0.016
107880	M2	320.5	2.211
107880	S2	339.7	0.587
107880	N2	284.9	0.493
107880	K1	212.9	1.456
107880	M4	78.1	0.006
107880	O1	183	0.805
107880	M6	239.6	0.032
107880	MK3	53.8	0.128
107880	S4	358.1	0.018
107880	MN4	91.2	0.03
107880	S6	52.3	0.011
107880	2N2	172.8	0.136
107880	OO1	275.9	0.112
107880	M1	321.3	0.017
107880	J1	226.1	0.105
107880	Q1	185.2	0.101
107880	2Q1	271.6	0.023
107880	P1	204.3	0.413
107880	2SM2	275.6	0.011
107880	M3	26.8	0.017
107880	L2	20.2	0.054
107880	2MK3	16.6	0.123
107880	K2	22.8	0.162
107880	M8	131.8	0.011
107880	MS4	265.6	0.003
107881	M2	329.4	0.734
107881	S2	338.4	0.215
107881	N2	297.5	0.182
107881	K1	244.1	0.685
107881	M4	113.1	0.079
107881	O1	217.2	0.415
107881	M6	127.8	0.02
107881	MK3	32.9	0.191
107881	S4	89.5	0.01
107881	MN4	92.1	0.042
107881	S6	240.5	0.005
107881	2N2	172.7	0.105
107881	OO1	297.2	0.075
107881	M1	125.3	0.068
107881	J1	266.9	0.079
107881	Q1	201.7	0.054
107881	2Q1	35.9	0.041
107881	P1	212.2	0.157
107881	2SM2	173.3	0.022
107881	M3	323.4	0.022
107881	L2	333.4	0.016
107881	2MK3	6	0.141
107881	K2	55.3	0.101
107881	M8	55.1	0.013
107881	MS4	279.5	0.041
107882	M2	322	0.769
107882	S2	353.3	0.218
107882	N2	286.6	0.175
107882	K1	225.9	0.55
107882	M4	127.3	0.106
107882	O1	200.7	0.346
107882	M6	166	0.041
107882	MK3	45	0.144
107882	S4	251.2	0.013
107882	MN4	108.6	0.035
107882	S6	108.4	0.007
107882	2N2	217.1	0.096
107882	OO1	184.3	0.088
107882	M1	194.7	0.065
107882	J1	245.3	0.076
107882	Q1	198.7	0.088
107882	2Q1	48	0.046
107882	P1	198.6	0.191
107882	2SM2	37	0.003
107882	M3	354.4	0.021
107882	L2	260.1	0.025
107882	2MK3	339.6	0.094
107882	K2	27.9	0.115
107882	M8	9.5	0.01
107882	MS4	171.4	0.035
107883	M2	317.5	0.752
107883	S2	358.3	0.203
107883	N2	288.7	0.185
107883	K1	215.8	0.492
107883	M4	113.1	0.103
107883	O1	191	0.284
107883	M6	168.4	0.046
107883	MK3	62.2	0.15
107883	S4	262.2	0.014
107883	MN4	92.3	0.051
107883	S6	113.3	0.007
107883	2N2	209.2	0.086
107883	OO1	190.1	0.075
107883	M1	199.9	0.102
107883	J1	246.1	0.074
107883	Q1	188.1	0.117
107883	2Q1	45.3	0.077
107883	P1	196.2	0.2
107883	2SM2	46.8	0.008
107883	M3	306.9	0.034
107883	L2	248.2	0.05
107883	2MK3	356.5	0.091
107883	K2	38.2	0.118
107883	M8	325.7	0.009
107883	MS4	115.2	0.026
107884	M2	304.3	1.307
107884	S2	329.1	0.3
107884	N2	270.1	0.282
107884	K1	206.7	0.669
107884	M4	118	0.066
107884	O1	198.3	0.325
107884	M6	22.2	0.023
107884	MK3	11.2	0.131
107884	S4	219.7	0.014
107884	MN4	93.1	0.038
107884	S6	13.7	0.007
107884	2N2	145.1	0.076
107884	OO1	223.6	0.055
107884	M1	130.8	0.021
107884	J1	197.5	0.065
107884	Q1	174.8	0.071
107884	2Q1	311.2	0.044
107884	P1	199	0.209
107884	2SM2	80.4	0.008
107884	M3	10.3	0.018
107884	L2	351.3	0.021
107884	2MK3	325.1	0.058
107884	K2	333.8	0.108
107884	M8	100.3	0.006
107884	MS4	207.2	0.059
107885	M2	304.8	1.76
107885	S2	325.9	0.405
107885	N2	270.3	0.38
107885	K1	203.2	0.926
107885	M4	128.9	0.054
107885	O1	189	0.449
107885	M6	16	0.02
107885	MK3	6.2	0.129
107885	S4	212.1	0.003
107885	MN4	90.3	0.022
107885	S6	330.7	0.005
107885	2N2	136.4	0.076
107885	OO1	254.7	0.071
107885	M1	328.9	0.031
107885	J1	198.2	0.043
107885	Q1	186.5	0.076
107885	2Q1	296	0.029
107885	P1	198	0.249
107885	2SM2	155.7	0.008
107885	M3	34.2	0.023
107885	L2	353.4	0.044
107885	2MK3	299.7	0.087
107885	K2	340.5	0.142
107885	MS4	191.4	0.063
107886	M2	304.1	1.866
107886	S2	322.8	0.423
107886	N2	269.9	0.395
107886	K1	200	0.998
107886	M4	116.4	0.051
107886	O1	183	0.484
107886	M6	11.6	0.019
107886	MK3	356.6	0.107
107886	S4	318.9	0.004
107886	MN4	24.3	0.005
107886	2N2	132.6	0.079
107886	OO1	265.1	0.102
107886	M1	326.6	0.056
107886	J1	193.2	0.036
107886	Q1	191.3	0.071
107886	2Q1	257	0.015
107886	P1	195.9	0.258
107886	2SM2	147.5	0.018
107886	M3	33	0.027
107886	L2	348.9	0.062
107886	2MK3	286.8	0.099
107886	K2	341.4	0.161
107886	M8	187.1	0.005
107886	MS4	175	0.044
107887	M2	303.3	1.35
107887	S2	327.5	0.332
107887	N2	266.9	0.295
107887	K1	194.6	0.783
107887	M4	277.4	0.079
107887	O1	159.5	0.433
107887	M6	154.5	0.01
107887	MK3	168.5	0.117
107887	S4	282.9	0.006
107887	MN4	245.1	0.041
107887	S6	307.6	0.002
107887	2N2	116.3	0.041
107887	OO1	266.8	0.05
107887	M1	323	0.027
107887	J1	185.4	0.04
107887	Q1	140.1	0.061
107887	2Q1	248.5	0.015
107887	P1	193.6	0.197
107887	2SM2	208.4	0.01
107887	M3	73.3	0.023
107887	L2	0.9	0.032
107887	2MK3	180.8	0.007
107887	K2	330.6	0.11
107887	M8	70.8	0.01
107887	MS4	281.9	0.028
107888	M2	304	1.776
107888	S2	325.9	0.427
107888	N2	266.9	0.38
107888	K1	194.3	1
107888	M4	271	0.122
107888	O1	160.7	0.552
107888	M6	112.5	0.008
107888	MK3	154.8	0.144
107888	S4	302.3	0.004
107888	MN4	232.9	0.06
107888	S6	281.3	0.004
107888	2N2	112.6	0.044
107888	OO1	274.6	0.076
107888	M1	329.6	0.056
107888	J1	176.6	0.039
107888	Q1	150.3	0.058
107888	2Q1	220.1	0.014
107888	P1	193.1	0.248
107888	2SM2	175.6	0.015
107888	M3	72.8	0.024
107888	L2	359	0.053
107888	2MK3	301.5	0.008
107888	K2	330.2	0.139
107888	M8	43.6	0.014
107888	MS4	271.8	0.038
107889	M2	303.7	1.851
107889	S2	325.9	0.456
107889	N2	266.6	0.401
107889	K1	192.6	1.052
107889	M4	265.8	0.145
107889	O1	159.5	0.553
107889	M6	145	0.007
107889	MK3	145.2	0.194
107889	S4	5.3	0.005
107889	MN4	224.1	0.077
107889	S6	309.6	0.003
107889	2N2	109.9	0.042
107889	OO1	269.5	0.078
107889	M1	312.8	0.063
107889	J1	172.5	0.036
107889	Q1	152.9	0.053
107889	2Q1	186.6	0.024
107889	P1	192.8	0.272
107889	2SM2	177.9	0.026
107889	M3	42.1	0.025
107889	L2	358.9	0.045
107889	2MK3	82.1	0.029
107889	K2	331.4	0.153
107889	M8	28.1	0.018
107889	MS4	268.6	0.05
107890	M2	323.8	0.549
107890	S2	322.6	0.125
107890	N2	292.8	0.093
107890	K1	201.1	0.329
107890	M4	220.1	0.067
107890	O1	149	0.173
107890	M6	83.2	0.025
107890	MK3	115.8	0.073
107890	S4	209.3	0.008
107890	MN4	230	0.029
107890	S6	119.5	0.006
107890	2N2	236.1	0.044
107890	OO1	121.5	0.038
107890	M1	247.9	0.015
107890	J1	216.6	0.03
107890	Q1	118.8	0.037
107890	2Q1	253.2	0.007
107890	P1	212.7	0.116
107890	2SM2	158.2	0.046
107890	M3	238.6	0.021
107890	L2	331.1	0.032
107890	2MK3	55	0.036
107890	K2	350.5	0.049
107890	M8	9.7	0.015
107890	MS4	243.2	0.007
107891	M2	322.5	0.549
107891	S2	323.9	0.13
107891	N2	290	0.097
107891	K1	201.1	0.331
107891	M4	221.8	0.061
107891	O1	149.5	0.175
107891	M6	78.9	0.026
107891	MK3	116.6	0.073
107891	S4	198.8	0.009
107891	MN4	232.6	0.028
107891	S6	127.3	0.006
107891	2N2	236	0.041
107891	OO1	128.5	0.034
107891	M1	246.5	0.014
107891	J1	215	0.032
107891	Q1	117.7	0.038
107891	2Q1	286.6	0.009
107891	P1	211.9	0.113
107891	2SM2	156.6	0.045
107891	M3	239.1	0.022
107891	L2	327.8	0.028
107891	2MK3	59.9	0.035
107891	K2	349.4	0.051
107891	M8	11	0.017
107891	MS4	227.9	0.007
107892	M2	321.2	0.548
107892	S2	324.9	0.131
107892	N2	288	0.102
107892	K1	201.3	0.332
107892	M4	222.9	0.055
107892	O1	149.9	0.176
107892	M6	75	0.026
107892	MK3	116.4	0.072
107892	S4	193.5	0.011
107892	MN4	235	0.026
107892	S6	129.7	0.006
107892	2N2	235.9	0.038
107892	OO1	136.3	0.031
107892	M1	248.6	0.014
107892	J1	215.7	0.034
107892	Q1	117.8	0.038
107892	2Q1	297	0.013
107892	P1	211.2	0.108
107892	2SM2	154.4	0.043
107892	M3	238	0.022
107892	L2	324.4	0.025
107892	2MK3	63.7	0.034
107892	K2	349.1	0.051
107892	M8	12.4	0.019
107892	MS4	215.1	0.006
107893	M2	319.9	0.549
107893	S2	325.7	0.133
107893	N2	286.3	0.106
107893	K1	201.5	0.333
107893	M4	224	0.05
107893	O1	150.6	0.178
107893	M6	69.4	0.025
107893	MK3	115.9	0.071
107893	S4	191.6	0.012
107893	MN4	234.6	0.025
107893	S6	130.1	0.006
107893	2N2	235.1	0.035
107893	OO1	147.1	0.027
107893	M1	253.6	0.014
107893	J1	216.4	0.036
107893	Q1	119.2	0.037
107893	2Q1	300.8	0.017
107893	P1	210.6	0.103
107893	2SM2	152.6	0.042
107893	M3	239	0.023
107893	L2	321.3	0.022
107893	2MK3	67.6	0.032
107893	K2	348.6	0.052
107893	M8	11.9	0.02
107893	MS4	196.9	0.006
107894	M2	318.6	0.551
107894	S2	327.1	0.133
107894	N2	285.5	0.11
107894	K1	201.4	0.332
107894	M4	225	0.046
107894	O1	151.4	0.179
107894	M6	63.4	0.025
107894	MK3	115.8	0.069
107894	S4	189	0.014
107894	MN4	234.6	0.023
107894	S6	137.8	0.006
107894	2N2	234.1	0.031
107894	OO1	160.9	0.025
107894	M1	256	0.016
107894	J1	218	0.037
107894	Q1	122	0.036
107894	2Q1	304	0.021
107894	P1	209.9	0.1
107894	2SM2	151.3	0.04
107894	M3	238.1	0.022
107894	L2	318.8	0.02
107894	2MK3	70.2	0.03
107894	K2	350.2	0.052
107894	M8	10.3	0.019
107894	MS4	183.1	0.007
107895	M2	317.4	0.554
107895	S2	327.9	0.132
107895	N2	284.6	0.114
107895	K1	201.4	0.332
107895	M4	225.4	0.043
107895	O1	152.2	0.179
107895	M6	57	0.024
107895	MK3	115.3	0.068
107895	S4	187	0.015
107895	MN4	234	0.021
107895	S6	136.1	0.005
107895	2N2	231	0.027
107895	OO1	173.7	0.025
107895	M1	258.1	0.017
107895	J1	219.9	0.038
107895	Q1	125.2	0.035
107895	2Q1	306.8	0.024
107895	P1	209.5	0.097
107895	2SM2	149	0.039
107895	M3	237.9	0.021
107895	L2	318.1	0.019
107895	2MK3	73.1	0.028
107895	K2	351	0.052
107895	M8	7.9	0.019
107895	MS4	170.9	0.007
107896	M2	316.3	0.557
107896	S2	328.2	0.132
107896	N2	283.9	0.117
107896	K1	201.4	0.331
107896	M4	226.6	0.039
107896	O1	153.2	0.18
107896	M6	50.3	0.024
107896	MK3	114.9	0.066
107896	S4	188.5	0.016
107896	MN4	232	0.02
107896	S6	139.2	0.005
107896	2N2	226.2	0.022
107896	OO1	183.9	0.025
107896	M1	257.7	0.018
107896	J1	221	0.04
107896	Q1	128.9	0.034
107896	2Q1	309.8	0.026
107896	P1	209.3	0.093
107896	2SM2	147.2	0.037
107896	M3	237.6	0.02
107896	L2	317.5	0.018
107896	2MK3	74.9	0.026
107896	K2	352	0.053
107896	M8	4.4	0.018
107896	MS4	159.9	0.007
107897	M2	315.3	0.562
107897	S2	328.6	0.13
107897	N2	283.4	0.121
107897	K1	201.2	0.33
107897	M4	227.3	0.037
107897	O1	153.9	0.18
107897	M6	42.6	0.024
107897	MK3	115.1	0.065
107897	S4	189.5	0.016
107897	MN4	228.4	0.019
107897	S6	136	0.004
107897	2N2	217.4	0.018
107897	OO1	194.4	0.025
107897	M1	258.7	0.02
107897	J1	221.7	0.041
107897	Q1	134	0.032
107897	2Q1	311.2	0.028
107897	P1	208.7	0.091
107897	2SM2	146.5	0.035
107897	M3	236.7	0.018
107897	L2	317.7	0.017
107897	2MK3	78	0.024
107897	K2	353.1	0.053
107897	M8	358.7	0.018
107897	MS4	148.3	0.008
107898	M2	314.5	0.567
107898	S2	328.9	0.129
107898	N2	283.2	0.123
107898	K1	201	0.328
107898	M4	228.6	0.035
107898	O1	154.5	0.18
107898	M6	36.7	0.024
107898	MK3	115	0.064
107898	S4	189.5	0.016
107898	MN4	222.6	0.018
107898	S6	136.2	0.004
107898	2N2	205.6	0.015
107898	OO1	205.4	0.027
107898	M1	261.4	0.02
107898	J1	223.1	0.041
107898	Q1	138.7	0.031
107898	2Q1	312.4	0.029
107898	P1	208.7	0.089
107898	2SM2	146.1	0.034
107898	M3	237	0.016
107898	L2	319.6	0.018
107898	2MK3	81.1	0.022
107898	K2	354.9	0.053
107898	M8	354	0.018
107898	MS4	145.9	0.009
107899	M2	313.9	0.573
107899	S2	329.3	0.127
107899	N2	282.9	0.126
107899	K1	200.6	0.326
107899	M4	229.3	0.033
107899	O1	155.1	0.18
107899	M6	30.2	0.024
107899	MK3	115	0.062
107899	S4	192.5	0.014
107899	MN4	218	0.017
107899	S6	123.1	0.004
107899	2N2	184.1	0.012
107899	OO1	211.9	0.027
107899	M1	262.1	0.02
107899	J1	224.1	0.042
107899	Q1	143.1	0.029
107899	2Q1	314.7	0.03
107899	P1	208.5	0.088
107899	2SM2	145.8	0.031
107899	M3	234.7	0.013
107899	L2	321.8	0.018
107899	2MK3	87.5	0.019
107899	K2	356.8	0.052
107899	M8	348.9	0.018
107899	MS4	141.5	0.009
107900	M2	313.4	0.579
107900	S2	329.3	0.126
107900	N2	282.8	0.129
107900	K1	200.2	0.324
107900	M4	229.5	0.033
107900	O1	155.9	0.179
107900	M6	25	0.025
107900	MK3	115.3	0.06
107900	S4	195.9	0.013
107900	MN4	215.3	0.017
107900	S6	124.4	0.004
107900	2N2	158.8	0.012
107900	OO1	219.8	0.027
107900	M1	264.3	0.021
107900	J1	225	0.042
107900	Q1	148.1	0.028
107900	2Q1	316.6	0.031
107900	P1	208.1	0.088
107900	2SM2	144	0.029
107900	M3	235.5	0.009
107900	L2	322.7	0.018
107900	2MK3	95.1	0.017
107900	K2	359	0.054
107900	M8	342.8	0.018
107900	MS4	134.7	0.01
107901	M2	313.1	0.586
107901	S2	329.2	0.125
107901	N2	282.9	0.131
107901	K1	199.7	0.323
107901	M4	229.2	0.032
107901	O1	156.4	0.179
107901	M6	21	0.025
107901	MK3	114.8	0.058
107901	S4	195.5	0.012
107901	MN4	213	0.017
107901	S6	122.1	0.004
107901	2N2	138	0.014
107901	OO1	226.8	0.028
107901	M1	266.9	0.021
107901	J1	226.2	0.041
107901	Q1	153.3	0.028
107901	2Q1	319	0.031
107901	P1	208	0.087
107901	2SM2	143.1	0.026
107901	M3	236.1	0.006
107901	L2	326.8	0.019
107901	2MK3	103	0.015
107901	K2	0.5	0.055
107901	M8	337.7	0.018
107901	MS4	132.6	0.011
107902	M2	312.9	0.592
107902	S2	329.1	0.124
107902	N2	282.8	0.132
107902	K1	199	0.321
107902	M4	229.8	0.031
107902	O1	157.2	0.178
107902	M6	16.9	0.026
107902	MK3	114.5	0.056
107902	S4	197.6	0.011
107902	MN4	209.9	0.017
107902	S6	122.9	0.005
107902	2N2	125.6	0.017
107902	OO1	233.9	0.027
107902	M1	269.3	0.02
107902	J1	226.3	0.04
107902	Q1	159.4	0.026
107902	2Q1	322.5	0.031
107902	P1	207.8	0.088
107902	2SM2	141.5	0.024
107902	M3	226.1	0.002
107902	L2	331.2	0.02
107902	2MK3	116.4	0.013
107902	K2	1.9	0.053
107902	M8	332.8	0.018
107902	MS4	129	0.011
107903	M2	312.9	0.599
107903	S2	328.8	0.124
107903	N2	282.6	0.134
107903	K1	198.4	0.32
107903	M4	229.7	0.031
107903	O1	158.2	0.177
107903	M6	14	0.027
107903	MK3	113.9	0.053
107903	S4	201.8	0.01
107903	MN4	210.4	0.017
107903	S6	130.3	0.005
107903	2N2	117.1	0.02
107903	OO1	240.2	0.027
107903	M1	272.9	0.02
107903	J1	226.1	0.038
107903	Q1	163.5	0.026
107903	2Q1	325.8	0.031
107903	P1	207.3	0.089
107903	2SM2	138.9	0.022
107903	M3	79.8	0.002
107903	L2	336.8	0.021
107903	2MK3	134.1	0.011
107903	K2	3.1	0.054
107903	M8	328.2	0.018
107903	MS4	126.2	0.012
107904	M2	313	0.606
107904	S2	328.9	0.123
107904	N2	282.5	0.135
107904	K1	197.7	0.319
107904	M4	230.1	0.031
107904	O1	159.4	0.176
107904	M6	10.5	0.027
107904	MK3	112.8	0.051
107904	S4	205.4	0.009
107904	MN4	210.1	0.017
107904	S6	140	0.004
107904	2N2	111.6	0.023
107904	OO1	249.3	0.027
107904	M1	278.9	0.02
107904	J1	225.8	0.036
107904	Q1	168.5	0.024
107904	2Q1	328.8	0.029
107904	P1	206.8	0.09
107904	2SM2	135.7	0.019
107904	M3	75.7	0.006
107904	L2	340.2	0.022
107904	2MK3	160.4	0.01
107904	K2	4.9	0.052
107904	M8	325.8	0.018
107904	MS4	126.2	0.012
107905	M2	313.1	0.612
107905	S2	329.2	0.123
107905	N2	282.6	0.135
107905	K1	197.6	0.318
107905	M4	230.3	0.031
107905	O1	160.9	0.176
107905	M6	8	0.028
107905	MK3	110.3	0.048
107905	S4	210.3	0.008
107905	MN4	210.5	0.017
107905	S6	140.8	0.005
107905	2N2	108.8	0.026
107905	OO1	258	0.027
107905	M1	286.9	0.02
107905	J1	224.2	0.033
107905	Q1	172.7	0.023
107905	2Q1	332.2	0.028
107905	P1	206	0.091
107905	2SM2	131	0.016
107905	M3	71.4	0.009
107905	L2	344.3	0.023
107905	2MK3	183.5	0.01
107905	K2	5.9	0.05
107905	M8	322.7	0.017
107905	MS4	124.4	0.012
107906	M2	313.3	0.619
107906	S2	329.8	0.121
107906	N2	282.7	0.134
107906	K1	197.7	0.317
107906	M4	230.7	0.031
107906	O1	162.7	0.175
107906	M6	5.3	0.028
107906	MK3	107.6	0.045
107906	S4	215.1	0.008
107906	MN4	208.7	0.017
107906	S6	150.8	0.005
107906	2N2	106.4	0.028
107906	OO1	265.9	0.027
107906	M1	294.8	0.019
107906	J1	220.9	0.029
107906	Q1	178.2	0.021
107906	2Q1	334.4	0.026
107906	P1	204.4	0.09
107906	2SM2	124.5	0.013
107906	M3	70	0.013
107906	L2	347.2	0.025
107906	2MK3	198.8	0.011
107906	K2	7	0.047
107906	M8	319.8	0.017
107906	MS4	126	0.011
107907	M2	313.6	0.624
107907	S2	330.8	0.121
107907	N2	282.5	0.133
107907	K1	197.8	0.316
107907	M4	231.5	0.031
107907	O1	164.7	0.173
107907	M6	3.8	0.028
107907	MK3	103.9	0.043
107907	S4	224.8	0.007
107907	MN4	206.2	0.017
107907	S6	160.9	0.004
107907	2N2	103.8	0.031
107907	OO1	278	0.027
107907	M1	305.8	0.019
107907	J1	217.3	0.025
107907	Q1	183.2	0.02
107907	2Q1	338.7	0.024
107907	P1	203.1	0.089
107907	2SM2	119.1	0.011
107907	M3	71.1	0.016
107907	L2	349.5	0.025
107907	2MK3	213.8	0.013
107907	K2	10.3	0.044
107907	M8	318.4	0.018
107907	MS4	128.7	0.01
107908	M2	313.9	0.628
107908	S2	331.9	0.121
107908	N2	282.6	0.132
107908	K1	198	0.317
107908	M4	233.1	0.032
107908	O1	166.7	0.172
107908	M6	4.3	0.029
107908	MK3	100.4	0.042
107908	S4	229.7	0.008
107908	MN4	204.6	0.017
107908	S6	167.8	0.005
107908	2N2	101.7	0.033
107908	OO1	289	0.028
107908	M1	316	0.018
107908	J1	213.4	0.021
107908	Q1	187.7	0.019
107908	2Q1	340.1	0.023
107908	P1	202.5	0.089
107908	2SM2	108.2	0.008
107908	M3	70.9	0.017
107908	L2	354.3	0.026
107908	2MK3	226	0.014
107908	K2	12.2	0.041
107908	M8	315.7	0.017
107908	MS4	135.9	0.009
107909	M2	314.3	0.63
107909	S2	333.1	0.12
107909	N2	282.1	0.131
107909	K1	198.2	0.318
107909	M4	234.2	0.032
107909	O1	168.7	0.171
107909	M6	4.5	0.029
107909	MK3	97.7	0.041
107909	S4	236	0.007
107909	MN4	203.7	0.016
107909	S6	172.3	0.005
107909	2N2	100.7	0.034
107909	OO1	299.8	0.033
107909	M1	327.3	0.019
107909	J1	207	0.018
107909	Q1	191.3	0.017
107909	2Q1	340.3	0.021
107909	P1	201.8	0.089
107909	2SM2	96.9	0.006
107909	M3	70.5	0.019
107909	L2	358	0.025
107909	2MK3	234.1	0.016
107909	K2	13.2	0.036
107909	M8	313.7	0.018
107909	MS4	147.7	0.008
107910	M2	314.6	0.63
107910	S2	334.2	0.121
107910	N2	281.7	0.129
107910	K1	198.7	0.319
107910	M4	234.8	0.033
107910	O1	171.1	0.17
107910	M6	4.3	0.029
107910	MK3	94	0.041
107910	S4	238.8	0.006
107910	MN4	203.1	0.015
107910	S6	175	0.006
107910	2N2	101.6	0.035
107910	OO1	307.8	0.038
107910	M1	339.5	0.021
107910	J1	198.9	0.015
107910	Q1	195.2	0.016
107910	2Q1	340.2	0.02
107910	P1	199.7	0.087
107910	2SM2	67.2	0.004
107910	M3	69.3	0.02
107910	L2	4	0.025
107910	2MK3	240.6	0.017
107910	K2	13.6	0.033
107910	M8	312.1	0.018
107910	MS4	156.9	0.008
107911	M2	315	0.627
107911	S2	335.7	0.122
107911	N2	281.3	0.128
107911	K1	199.3	0.319
107911	M4	234.8	0.034
107911	O1	173.3	0.169
107911	M6	3.8	0.029
107911	MK3	90.9	0.04
107911	S4	246.2	0.005
107911	MN4	203.1	0.014
107911	S6	178.4	0.006
107911	2N2	102.4	0.036
107911	OO1	312.7	0.044
107911	M1	347.7	0.023
107911	J1	186.1	0.012
107911	Q1	198.9	0.015
107911	2Q1	337.7	0.018
107911	P1	198	0.086
107911	2SM2	27	0.004
107911	M3	68.1	0.02
107911	L2	10.9	0.025
107911	2MK3	248.9	0.018
107911	K2	14.5	0.029
107911	M8	310.8	0.019
107911	MS4	166.9	0.008
107912	M2	315.2	0.623
107912	S2	337	0.123
107912	N2	280.8	0.127
107912	K1	199.5	0.321
107912	M4	236.2	0.036
107912	O1	175.8	0.169
107912	M6	3	0.028
107912	MK3	88.6	0.04
107912	S4	268	0.002
107912	MN4	202	0.014
107912	S6	178.4	0.005
107912	2N2	104.4	0.037
107912	OO1	316.4	0.051
107912	M1	354.1	0.026
107912	J1	165.3	0.01
107912	Q1	202	0.015
107912	2Q1	330.3	0.016
107912	P1	197.1	0.084
107912	2SM2	355	0.005
107912	M3	67.9	0.021
107912	L2	17.4	0.025
107912	2MK3	255.5	0.019
107912	K2	10.7	0.026
107912	M8	311.2	0.019
107912	MS4	176.5	0.009
107913	M2	315.5	0.618
107913	S2	338.3	0.124
107913	N2	280.2	0.125
107913	K1	199.6	0.321
107913	M4	238.8	0.037
107913	O1	177.8	0.169
107913	M6	1.6	0.028
107913	MK3	86.6	0.04
107913	MN4	203.8	0.012
107913	S6	184.9	0.005
107913	2N2	106.9	0.038
107913	OO1	318	0.058
107913	M1	359.2	0.029
107913	J1	146.6	0.01
107913	Q1	203.1	0.014
107913	2Q1	323.1	0.015
107913	P1	195.6	0.084
107913	2SM2	340.9	0.008
107913	M3	66.9	0.021
107913	L2	24.5	0.025
107913	2MK3	263.2	0.02
107913	K2	5.8	0.024
107913	M8	313.6	0.021
107913	MS4	186.9	0.009
107914	M2	315.7	0.61
107914	S2	339.3	0.126
107914	N2	279.6	0.124
107914	K1	199.9	0.322
107914	M4	241.9	0.039
107914	O1	179.5	0.169
107914	M6	0.9	0.027
107914	MK3	85.5	0.038
107914	S4	55.4	0.002
107914	MN4	203	0.011
107914	S6	186.8	0.005
107914	2N2	109.6	0.038
107914	OO1	319.6	0.065
107914	M1	1.6	0.032
107914	J1	135	0.012
107914	Q1	204	0.013
107914	2Q1	311.1	0.014
107914	P1	194.3	0.082
107914	2SM2	336.6	0.01
107914	M3	65.9	0.022
107914	L2	30.9	0.025
107914	2MK3	269	0.022
107914	K2	357	0.023
107914	M8	316.8	0.021
107914	MS4	198.7	0.01
107915	M2	315.8	0.602
107915	S2	340.3	0.128
107915	N2	278.6	0.122
107915	K1	200	0.322
107915	M4	246.8	0.039
107915	O1	180.8	0.17
107915	M6	0.2	0.026
107915	MK3	85.3	0.035
107915	S4	71.6	0.004
107915	MN4	202	0.01
107915	S6	198.2	0.004
107915	2N2	113.3	0.037
107915	OO1	321	0.071
107915	M1	4	0.035
107915	J1	122.7	0.014
107915	Q1	211.4	0.014
107915	2Q1	299.1	0.014
107915	P1	192.8	0.081
107915	2SM2	333.7	0.013
107915	M3	65.1	0.023
107915	L2	36.3	0.025
107915	2MK3	273	0.024
107915	K2	347.9	0.023
107915	M8	320.3	0.022
107915	MS4	212	0.011
107916	M2	315.8	0.593
107916	S2	340.9	0.129
107916	N2	277.6	0.12
107916	K1	199.6	0.325
107916	M4	253.3	0.039
107916	O1	181.3	0.17
107916	M6	359.9	0.025
107916	MK3	86.7	0.031
107916	S4	79.1	0.006
107916	MN4	204.4	0.009
107916	S6	200.3	0.004
107916	2N2	116.1	0.038
107916	OO1	321.4	0.074
107916	M1	3.7	0.038
107916	J1	117.1	0.017
107916	Q1	216.1	0.014
107916	2Q1	289.1	0.014
107916	P1	192.9	0.08
107916	2SM2	332.7	0.014
107916	M3	61.7	0.024
107916	L2	42.5	0.026
107916	2MK3	274.4	0.026
107916	K2	338.7	0.023
107916	M8	324.1	0.022
107916	MS4	226	0.012
107917	M2	315.8	0.583
107917	S2	341.5	0.131
107917	N2	276.5	0.118
107917	K1	199.4	0.326
107917	M4	260.5	0.04
107917	O1	181.5	0.17
107917	M6	358.8	0.023
107917	MK3	90.2	0.025
107917	S4	87.7	0.007
107917	MN4	202.4	0.009
107917	S6	204.2	0.004
107917	2N2	116.5	0.037
107917	OO1	321.5	0.077
107917	M1	3.4	0.041
107917	J1	109.9	0.021
107917	Q1	221.4	0.013
107917	2Q1	272.9	0.013
107917	P1	192.3	0.077
107917	2SM2	331.9	0.016
107917	M3	58.5	0.024
107917	L2	48.7	0.026
107917	2MK3	273.4	0.028
107917	K2	330.1	0.025
107917	M8	327.8	0.022
107917	MS4	236.4	0.013
107918	M2	315.8	0.574
107918	S2	341.7	0.132
107918	N2	275.2	0.116
107918	K1	199	0.331
107918	M4	268.7	0.042
107918	O1	181.3	0.17
107918	M6	356.6	0.022
107918	MK3	97.6	0.018
107918	S4	93.7	0.007
107918	MN4	206.3	0.009
107918	S6	202.4	0.004
107918	2N2	115.7	0.038
107918	OO1	322.3	0.079
107918	M1	1.8	0.044
107918	J1	106	0.025
107918	Q1	228.3	0.011
107918	2Q1	258.2	0.012
107918	P1	193.1	0.074
107918	2SM2	328.7	0.017
107918	M3	55.7	0.025
107918	L2	55.4	0.026
107918	2MK3	270.4	0.029
107918	K2	322.3	0.026
107918	M8	331	0.021
107918	MS4	245.7	0.014
107919	M2	315.8	0.564
107919	S2	341.1	0.134
107919	N2	273.9	0.115
107919	K1	197.9	0.333
107919	M4	275.7	0.043
107919	O1	180.4	0.169
107919	M6	353.7	0.019
107919	MK3	124.1	0.01
107919	S4	95.9	0.008
107919	MN4	217.5	0.01
107919	S6	218.5	0.003
107919	2N2	113.8	0.038
107919	OO1	322.7	0.078
107919	M1	0.1	0.047
107919	J1	102.7	0.028
107919	Q1	244.4	0.01
107919	2Q1	239	0.013
107919	P1	194.1	0.073
107919	2SM2	325.3	0.018
107919	M3	54.5	0.026
107919	L2	60.8	0.027
107919	2MK3	267.6	0.031
107919	K2	317.5	0.029
107919	M8	332.8	0.021
107919	MS4	251	0.015
107920	M2	315.6	0.555
107920	S2	339.5	0.137
107920	N2	272.9	0.114
107920	K1	196.3	0.334
107920	M4	282.5	0.043
107920	O1	178.6	0.168
107920	M6	346.1	0.018
107920	MK3	186.9	0.01
107920	S4	100.3	0.008
107920	MN4	226.3	0.01
107920	S6	236.2	0.002
107920	2N2	113.4	0.036
107920	OO1	322	0.072
107920	M1	357	0.048
107920	J1	104	0.029
107920	Q1	262	0.01
107920	2Q1	222.5	0.016
107920	P1	196	0.073
107920	2SM2	321.1	0.018
107920	M3	53.5	0.027
107920	L2	64	0.028
107920	2MK3	264.6	0.034
107920	K2	315.3	0.033
107920	M8	334.8	0.019
107920	MS4	255.4	0.016
107921	M2	314.8	0.547
107921	S2	337.3	0.142
107921	N2	271.2	0.114
107921	K1	193.2	0.329
107921	M4	292.9	0.043
107921	O1	174.5	0.163
107921	M6	330.8	0.017
107921	MK3	221.4	0.02
107921	S4	109.2	0.008
107921	MN4	236.4	0.01
107921	S6	203.9	0.002
107921	2N2	114	0.033
107921	OO1	318.2	0.06
107921	M1	354.4	0.046
107921	J1	108.6	0.031
107921	Q1	258.6	0.011
107921	2Q1	207.5	0.018
107921	P1	197.9	0.076
107921	2SM2	315.5	0.016
107921	M3	52.5	0.027
107921	L2	66.4	0.028
107921	2MK3	263.3	0.037
107921	K2	318.4	0.04
107921	M8	339.2	0.017
107921	MS4	252.9	0.018
107922	M2	313.2	0.537
107922	S2	335.2	0.145
107922	N2	268.9	0.113
107922	K1	188.1	0.314
107922	M4	303.6	0.043
107922	O1	167.3	0.158
107922	M6	313.8	0.017
107922	MK3	232.9	0.032
107922	S4	109.9	0.009
107922	MN4	248.8	0.01
107922	S6	136.2	0.002
107922	2N2	120.8	0.028
107922	OO1	306.7	0.043
107922	M1	350.5	0.042
107922	J1	117.8	0.032
107922	Q1	247.7	0.015
107922	2Q1	193.5	0.018
107922	P1	196.5	0.086
107922	2SM2	308	0.013
107922	M3	52.7	0.026
107922	L2	66	0.026
107922	2MK3	263.9	0.038
107922	K2	323.9	0.049
107922	M8	343.7	0.014
107922	MS4	245.6	0.018
107923	M2	309.8	0.502
107923	S2	335	0.135
107923	N2	265.1	0.107
107923	K1	179.4	0.305
107923	M4	312.6	0.058
107923	O1	150.3	0.148
107923	M6	302.9	0.013
107923	MK3	246.4	0.062
107923	S4	127.5	0.008
107923	MN4	265.3	0.015
107923	S6	52	0.006
107923	2N2	119.6	0.026
107923	OO1	290.6	0.03
107923	M1	347.6	0.042
107923	J1	115.2	0.033
107923	Q1	235.1	0.015
107923	2Q1	187.8	0.02
107923	P1	194.7	0.08
107923	2SM2	327.6	0.008
107923	M3	53.1	0.021
107923	L2	58.1	0.021
107923	2MK3	250.9	0.042
107923	K2	335.3	0.059
107923	M8	333.9	0.011
107923	MS4	262.6	0.024
107924	M2	280.6	1.016
107924	S2	309.4	0.244
107924	N2	239.4	0.215
107924	K1	179.2	0.584
107924	M4	306	0.185
107924	O1	140.4	0.576
107924	M6	35.1	0.018
107924	MK3	209.5	0.341
107924	S4	342.9	0.014
107924	MN4	278.7	0.1
107924	S6	84.4	0.004
107924	2N2	75.2	0.064
107924	OO1	1.7	0.011
107924	M1	47.9	0.042
107924	J1	149.5	0.044
107924	Q1	95.2	0.122
107924	2Q1	242.8	0.05
107924	P1	158.2	0.159
107924	2SM2	239.2	0.017
107924	M3	204.7	0.04
107924	L2	22.5	0.033
107924	2MK3	172.8	0.163
107924	K2	300.6	0.188
107924	M8	5.6	0.016
107924	MS4	300.9	0.043
107925	M2	283.3	1.186
107925	S2	311.2	0.273
107925	N2	232.4	0.229
107925	K1	188.3	0.574
107925	M4	315.9	0.143
107925	O1	148.4	0.636
107925	M6	200.8	0.007
107925	MK3	207.1	0.375
107925	S4	356.7	0.012
107925	MN4	274.3	0.088
107925	S6	47.3	0.012
107925	2N2	45.1	0.065
107925	OO1	45.4	0.023
107925	M1	72.7	0.097
107925	J1	147.6	0.093
107925	Q1	94.5	0.146
107925	2Q1	234.1	0.084
107925	P1	168.2	0.172
107925	2SM2	224.3	0.053
107925	M3	222	0.038
107925	L2	18.4	0.08
107925	2MK3	179.1	0.174
107925	K2	296.4	0.209
107925	M8	346.7	0.022
107925	MS4	297.6	0.023
107926	M2	285.1	1.174
107926	S2	314.6	0.284
107926	N2	234.9	0.226
107926	K1	191.8	0.554
107926	M4	315.4	0.137
107926	O1	152.7	0.632
107926	M6	221.6	0.014
107926	MK3	204.5	0.382
107926	S4	353.3	0.011
107926	MN4	270	0.084
107926	S6	45.1	0.014
107926	2N2	28.8	0.064
107926	OO1	114.4	0.013
107926	M1	71.6	0.087
107926	J1	142.8	0.086
107926	Q1	102.4	0.138
107926	2Q1	229.9	0.091
107926	P1	172	0.19
107926	2SM2	228	0.051
107926	M3	203.3	0.043
107926	L2	15.1	0.075
107926	2MK3	174.3	0.175
107926	K2	295.9	0.225
107926	M8	355.1	0.023
107926	MS4	283.6	0.025
107927	M2	272.1	1.25
107927	S2	291.4	0.316
107927	N2	229.1	0.28
107927	K1	172.4	0.613
107927	M4	299.2	0.168
107927	O1	129.1	0.593
107927	M6	28.6	0.012
107927	MK3	217	0.433
107927	S4	203.1	0.007
107927	MN4	265.2	0.089
107927	S6	319	0.003
107927	2N2	45.6	0.072
107927	OO1	25.3	0.042
107927	M1	38.2	0.065
107927	J1	131.2	0.056
107927	Q1	84.5	0.13
107927	2Q1	222	0.055
107927	P1	153.6	0.152
107927	2SM2	274.2	0.016
107927	M3	131.6	0.056
107927	L2	356.8	0.045
107927	2MK3	190.1	0.221
107927	K2	300.6	0.207
107927	M8	231.7	0.007
107927	MS4	339	0.057
107928	M2	274.5	1.529
107928	S2	290.3	0.39
107928	N2	226.8	0.325
107928	K1	177.2	0.686
107928	M4	301.3	0.186
107928	O1	133.3	0.691
107928	M6	281.5	0.025
107928	MK3	211.6	0.484
107928	S4	141.9	0.016
107928	MN4	268.4	0.09
107928	S6	310.4	0.009
107928	2N2	29.5	0.096
107928	OO1	31.1	0.048
107928	M1	40.1	0.091
107928	J1	130.3	0.087
107928	Q1	86.4	0.153
107928	2Q1	230.6	0.077
107928	P1	159.8	0.163
107928	2SM2	253.4	0.035
107928	M3	148.1	0.039
107928	L2	9	0.098
107928	2MK3	184.9	0.221
107928	K2	291.6	0.27
107928	M8	291.8	0.015
107928	MS4	4.8	0.065
107929	M2	275.1	1.525
107929	S2	290.5	0.397
107929	N2	227.2	0.33
107929	K1	178.9	0.681
107929	M4	303.7	0.178
107929	O1	134.1	0.684
107929	M6	275.6	0.03
107929	MK3	212.3	0.485
107929	S4	142	0.02
107929	MN4	268.4	0.081
107929	S6	325.8	0.013
107929	2N2	29.9	0.103
107929	OO1	40.2	0.046
107929	M1	44.4	0.098
107929	J1	133.1	0.096
107929	Q1	87.8	0.155
107929	2Q1	236.2	0.085
107929	P1	161.6	0.166
107929	2SM2	256.8	0.036
107929	M3	157.8	0.037
107929	L2	12	0.101
107929	2MK3	184.5	0.22
107929	K2	293	0.278
107929	M8	294.5	0.015
107929	MS4	2.7	0.062
107930	M2	307.4	1.813
107930	S2	332.2	0.452
107930	N2	272.7	0.399
107930	K1	208.6	1.069
107930	M4	87.7	0.073
107930	O1	185.7	0.588
107930	M6	16.9	0.049
107930	MK3	356.4	0.054
107930	S4	272.2	0.011
107930	MN4	38.1	0.008
107930	2N2	163.1	0.081
107930	OO1	253.5	0.033
107930	M1	84.4	0.026
107930	J1	202.1	0.051
107930	Q1	167.7	0.072
107930	2Q1	342.7	0.018
107930	P1	197.8	0.299
107930	2SM2	162	0.008
107930	M3	291.8	0.013
107930	L2	0.4	0.043
107930	2MK3	317.3	0.018
107930	K2	343.6	0.126
107930	M8	237.5	0.011
107930	MS4	111.2	0.04
107931	M2	310.4	2.185
107931	S2	333.3	0.531
107931	N2	270.3	0.501
107931	K1	205.2	1.54
107931	M4	354.2	0.061
107931	O1	166.6	0.942
107931	MK3	225.9	0.111
107931	S4	336.5	0.019
107931	MN4	293.6	0.034
107931	S6	142.6	0.013
107931	2N2	134.1	0.047
107931	OO1	278.1	0.062
107931	M1	332.2	0.037
107931	J1	180.5	0.088
107931	Q1	136.9	0.112
107931	2Q1	192.6	0.041
107931	P1	200.4	0.396
107931	2SM2	229.9	0.02
107931	M3	71.2	0.016
107931	L2	49.8	0.04
107931	2MK3	217.5	0.056
107931	K2	313.4	0.23
107931	M8	317.4	0.005
107931	MS4	172.2	0.014
107932	M2	310.9	2.217
107932	S2	333.9	0.521
107932	N2	269.8	0.502
107932	K1	204.5	1.572
107932	M4	355.1	0.077
107932	O1	165.3	0.965
107932	M6	234.8	0.006
107932	MK3	236.5	0.131
107932	S4	332.5	0.021
107932	MN4	296.7	0.04
107932	S6	140.7	0.015
107932	2N2	126.4	0.049
107932	OO1	279.2	0.07
107932	M1	337.2	0.032
107932	J1	173.8	0.107
107932	Q1	138.9	0.123
107932	2Q1	208.2	0.036
107932	P1	200.3	0.417
107932	2SM2	232.8	0.024
107932	M3	150.6	0.003
107932	L2	42.3	0.05
107932	2MK3	209.3	0.076
107932	K2	308.5	0.256
107932	M8	291.8	0.006
107932	MS4	187.2	0.01
107933	M2	320.1	2.251
107933	S2	342.3	0.598
107933	N2	285.1	0.539
107933	K1	215.3	1.505
107933	M4	68.9	0.051
107933	O1	183.3	0.87
107933	M6	101.2	0.027
107933	MK3	324	0.028
107933	S4	31.3	0.015
107933	MN4	244.5	0.014
107933	S6	157.9	0.004
107933	2N2	178.5	0.14
107933	OO1	0.4	0.013
107933	M1	108.5	0.051
107933	J1	222.9	0.121
107933	Q1	146.1	0.075
107933	2Q1	273.3	0.03
107933	P1	197.8	0.413
107933	2SM2	34.3	0.012
107933	M3	291	0.018
107933	L2	76.9	0.021
107933	2MK3	125.4	0.021
107933	K2	350.4	0.216
107933	M8	111.4	0.009
107933	MS4	18.9	0.004
107934	M2	321	2.278
107934	S2	341.6	0.622
107934	N2	281.7	0.529
107934	K1	211.2	1.516
107934	M4	14.4	0.077
107934	O1	174.7	0.919
107934	M6	96.6	0.004
107934	MK3	236.2	0.074
107934	S4	356.3	0.01
107934	MN4	300.5	0.026
107934	S6	291.7	0.004
107934	2N2	177.4	0.092
107934	OO1	264.1	0.025
107934	M1	94.2	0.021
107934	J1	213	0.109
107934	Q1	143.6	0.106
107934	2Q1	231.4	0.017
107934	P1	196.7	0.412
107934	2SM2	291.7	0.026
107934	M3	169.3	0.016
107934	L2	53	0.034
107934	2MK3	114.8	0.021
107934	K2	340.8	0.23
107934	M8	230.6	0.003
107934	MS4	43.2	0.021
107935	M2	320	2.188
107935	S2	340	0.603
107935	N2	281	0.514
107935	K1	208.9	1.435
107935	M4	11.7	0.119
107935	O1	171.8	0.868
107935	M6	208	0.016
107935	MK3	270.8	0.114
107935	S4	327	0.016
107935	MN4	311	0.047
107935	S6	277	0.004
107935	2N2	164.8	0.074
107935	OO1	281.9	0.052
107935	M1	67.3	0.021
107935	J1	204.1	0.097
107935	Q1	143.7	0.107
107935	2Q1	218.7	0.012
107935	P1	195.9	0.394
107935	2SM2	298.8	0.022
107935	M3	168.4	0.031
107935	L2	37.8	0.032
107935	2MK3	237.9	0.044
107935	K2	349.6	0.25
107935	M8	328.3	0.011
107935	MS4	15.5	0.035
107936	M2	319.9	1.803
107936	S2	344.5	0.394
107936	N2	285.1	0.398
107936	K1	217.8	1.186
107936	M4	81.6	0.098
107936	O1	196.2	0.669
107936	M6	37.9	0.058
107936	MK3	340	0.139
107936	S4	292.7	0.047
107936	MN4	18.4	0.014
107936	S6	87.5	0.011
107936	2N2	165.6	0.135
107936	OO1	97.9	0.047
107936	M1	97.7	0.084
107936	J1	211.8	0.133
107936	Q1	155.3	0.072
107936	2Q1	292.7	0.061
107936	P1	204.3	0.315
107936	2SM2	252	0.01
107936	M3	247.1	0.046
107936	L2	358.6	0.023
107936	2MK3	164.5	0.041
107936	K2	316.9	0.169
107936	M8	215.6	0.029
107936	MS4	347.7	0.031
107937	M2	313.9	1.697
107937	S2	333.4	0.448
107937	N2	277	0.395
107937	K1	205.3	0.985
107937	M4	336.4	0.112
107937	O1	171.8	0.606
107937	M6	344.3	0.051
107937	MK3	164.3	0.073
107937	S4	218.4	0.003
107937	MN4	331.2	0.039
107937	S6	83.5	0.003
107937	2N2	182.9	0.087
107937	OO1	190.6	0.128
107937	M1	234.7	0.012
107937	J1	233	0.058
107937	Q1	154.6	0.085
107937	2Q1	131.7	0.022
107937	P1	192.2	0.28
107937	2SM2	256	0.018
107937	M3	50.2	0.025
107937	L2	46.3	0.04
107937	2MK3	62.8	0.082
107937	K2	315	0.157
107937	M8	323	0.014
107937	MS4	337.7	0.071
107938	M2	311.9	1.608
107938	S2	333.5	0.418
107938	N2	274.7	0.382
107938	K1	202.2	0.959
107938	M4	325.9	0.139
107938	O1	166.2	0.589
107938	M6	333.8	0.039
107938	MK3	178.2	0.095
107938	S4	95.7	0.008
107938	MN4	318.9	0.042
107938	S6	92.5	0.006
107938	2N2	180.1	0.077
107938	OO1	189.5	0.133
107938	M1	309.2	0.014
107938	J1	232.5	0.04
107938	Q1	153.9	0.08
107938	2Q1	146.3	0.028
107938	P1	195.1	0.251
107938	2SM2	241.1	0.018
107938	M3	33.7	0.022
107938	L2	25	0.043
107938	2MK3	64.5	0.054
107938	K2	324.9	0.14
107938	M8	352.2	0.022
107938	MS4	330.4	0.086
107939	M2	289.7	1.433
107939	S2	312.7	0.35
107939	N2	251.7	0.323
107939	K1	196.7	0.67
107939	M4	46.9	0.121
107939	O1	196.8	0.526
107939	M6	20.2	0.065
107939	MK3	329.1	0.38
107939	S4	90.7	0.015
107939	MN4	20.8	0.064
107939	S6	200.6	0.007
107939	2N2	84.9	0.082
107939	OO1	240.9	0.042
107939	M1	2.9	0.037
107939	J1	207.9	0.057
107939	Q1	184	0.073
107939	2Q1	260.9	0.059
107939	P1	189.2	0.18
107939	2SM2	357.3	0.013
107939	M3	196.1	0.025
107939	L2	338	0.054
107939	2MK3	277.9	0.17
107939	K2	341.8	0.219
107939	M8	112	0.033
107939	MS4	179.7	0.087
107940	M2	291	1.786
107940	S2	307.9	0.379
107940	N2	254	0.358
107940	K1	187.5	0.766
107940	M4	40.4	0.196
107940	O1	189.2	0.475
107940	M6	358.8	0.079
107940	MK3	300.3	0.374
107940	S4	176.5	0.009
107940	MN4	11.5	0.073
107940	S6	198.2	0.005
107940	2N2	62.5	0.083
107940	OO1	249.3	0.072
107940	M1	348.7	0.067
107940	J1	198.4	0.045
107940	Q1	218.1	0.048
107940	2Q1	212.1	0.045
107940	P1	187.1	0.188
107940	2SM2	283.6	0.007
107940	M3	196.9	0.059
107940	L2	340.7	0.113
107940	2MK3	261.7	0.182
107940	K2	324.3	0.239
107940	M8	91.7	0.042
107940	MS4	132.2	0.05
107941	M2	289.7	2.041
107941	S2	305	0.367
107941	N2	251	0.361
107941	K1	180.2	0.779
107941	M4	42	0.204
107941	O1	186.4	0.383
107941	M6	348.3	0.119
107941	MK3	281.9	0.424
107941	S4	301.9	0.007
107941	MN4	0.7	0.067
107941	S6	330	0.007
107941	2N2	19.1	0.083
107941	OO1	241.7	0.088
107941	M1	357.6	0.091
107941	J1	162	0.034
107941	Q1	264.5	0.053
107941	2Q1	194.2	0.047
107941	P1	178	0.199
107941	2SM2	243.5	0.015
107941	M3	194.5	0.083
107941	L2	332.1	0.184
107941	2MK3	238.9	0.201
107941	K2	308.8	0.206
107941	M8	91.7	0.053
107941	MS4	119.9	0.05
107942	M2	326.6	0.325
107942	S2	336.2	0.146
107942	N2	276.9	0.119
107942	K1	248.9	0.31
107942	M4	203.8	0.029
107942	O1	233.4	0.219
107942	M6	304.6	0.011
107942	MK3	111	0.073
107942	S4	32.4	0.022
107942	MN4	158.3	0.01
107942	S6	63.7	0.01
107942	2N2	150.8	0.092
107942	OO1	331.3	0.065
107942	M1	40.7	0.014
107942	J1	57	0.034
107942	Q1	174.8	0.056
107942	2Q1	309.2	0.049
107942	P1	209.1	0.105
107942	2SM2	156.5	0.003
107942	M3	230.5	0.021
107942	L2	98	0.04
107942	2MK3	55.3	0.074
107942	M8	74.7	0.01
107942	MS4	352.8	0.035
107943	M2	310.7	0.602
107943	S2	318.1	0.125
107943	N2	260.4	0.131
107943	K1	214.8	0.346
107943	M4	248.2	0.04
107943	O1	165.6	0.168
107943	M6	156.4	0.009
107943	MK3	356	0.084
107943	S4	49.4	0.039
107943	MN4	301.9	0.033
107943	S6	128	0.002
107943	2N2	86.6	0.07
107943	OO1	0.7	0.097
107943	M1	23.6	0.079
107943	J1	96.1	0.073
107943	Q1	81.3	0.072
107943	2Q1	191.1	0.083
107943	P1	184.4	0.166
107943	2SM2	6.8	0.022
107943	M3	110.7	0.036
107943	L2	42.5	0.059
107943	2MK3	317.7	0.078
107943	M8	133.6	0.012
107943	MS4	205.6	0.033
107944	M2	313.3	0.705
107944	S2	303.8	0.166
107944	N2	260.1	0.122
107944	K1	208.4	0.426
107944	M4	251.2	0.059
107944	O1	163.1	0.244
107944	M6	133.2	0.008
107944	MK3	84.2	0.026
107944	S4	35.6	0.032
107944	MN4	297.1	0.044
107944	S6	29.3	0.006
107944	2N2	102.4	0.04
107944	OO1	293.7	0.034
107944	M1	15.9	0.054
107944	J1	96.6	0.058
107944	Q1	104.5	0.068
107944	2Q1	185.6	0.067
107944	P1	188.6	0.196
107944	2SM2	174.8	0.005
107944	M3	218.4	0.008
107944	L2	5	0.072
107944	2MK3	340.6	0.069
107944	M8	148.3	0.019
107944	MS4	160.7	0.03
107945	M2	309	1.308
107945	S2	331.3	0.375
107945	N2	273.7	0.291
107945	K1	191.9	0.869
107945	M4	232.9	0.185
107945	O1	161.7	0.523
107945	M6	276.7	0.029
107945	MK3	137.7	0.188
107945	S4	287.4	0.012
107945	MN4	214.2	0.086
107945	S6	237.2	0.008
107945	2N2	131	0.043
107945	OO1	230.6	0.055
107945	M1	296.4	0.037
107945	J1	248.1	0.026
107945	Q1	125.5	0.085
107945	2Q1	169.4	0.066
107945	P1	184.8	0.186
107945	2SM2	97.7	0.015
107945	M3	106.8	0.047
107945	2MK3	76.3	0.102
107945	K2	303.7	0.137
107945	M8	242.1	0.012
107945	MS4	264	0.082
107946	M2	317.6	1.382
107946	S2	333.6	0.394
107946	N2	276.5	0.332
107946	K1	211.9	0.947
107946	M4	247.5	0.226
107946	O1	193.8	0.589
107946	M6	189.5	0.042
107946	MK3	135.8	0.309
107946	S4	216.8	0.015
107946	MN4	199.2	0.084
107946	S6	276.5	0.007
107946	2N2	124.7	0.122
107946	OO1	310.1	0.098
107946	M1	8.8	0.113
107946	J1	359.6	0.032
107946	Q1	92.2	0.046
107946	2Q1	247.3	0.044
107946	P1	198.2	0.218
107946	2SM2	141.5	0.013
107946	M3	61.4	0.04
107946	L2	63.6	0.072
107946	2MK3	77.8	0.117
107946	K2	311.9	0.119
107946	M8	317.9	0.011
107946	MS4	258.4	0.158
107947	M2	321.5	1.395
107947	S2	336.1	0.387
107947	N2	281	0.324
107947	K1	220.7	0.982
107947	M4	247.3	0.219
107947	O1	207.3	0.624
107947	M6	165	0.043
107947	MK3	134.2	0.349
107947	S4	152.4	0.012
107947	MN4	194.8	0.089
107947	S6	286.9	0.008
107947	2N2	118.3	0.179
107947	OO1	305.1	0.133
107947	M1	15.7	0.162
107947	J1	56.5	0.044
107947	Q1	58.8	0.023
107947	2Q1	264.2	0.066
107947	P1	208.1	0.224
107947	2SM2	164.1	0.026
107947	M3	55.3	0.029
107947	L2	56.2	0.102
107947	2MK3	78.3	0.106
107947	K2	334.6	0.104
107947	M8	349.6	0.019
107947	MS4	254.5	0.166
107948	M2	298.2	0.632
107948	S2	339.1	0.106
107948	N2	251.5	0.143
107948	K1	172.4	0.398
107948	M4	71	0.053
107948	O1	157.9	0.27
107948	M6	312.9	0.037
107948	MK3	274.4	0.072
107948	S4	45.5	0.007
107948	MN4	329.8	0.015
107948	S6	39.4	0.004
107948	2N2	243.8	0.051
107948	OO1	215.9	0.069
107948	M1	234.7	0.056
107948	J1	227.8	0.044
107948	Q1	176.3	0.073
107948	2Q1	153.4	0.004
107948	P1	202	0.177
107948	2SM2	283.4	0.017
107948	M3	336.7	0.012
107948	L2	339.1	0.031
107948	2MK3	206.8	0.025
107948	K2	207.3	0.055
107948	M8	42.8	0.005
107948	MS4	55	0.031
107949	M2	299.2	0.919
107949	S2	302	0.191
107949	N2	260.5	0.16
107949	K1	190.2	0.354
107949	M4	259.3	0.052
107949	O1	173.6	0.237
107949	M6	347.2	0.056
107949	MK3	158.9	0.032
107949	S4	122.3	0.006
107949	MN4	102.2	0.009
107949	S6	68.1	0.013
107949	2N2	294.7	0.024
107949	OO1	30.4	0.018
107949	M1	18.1	0.068
107949	J1	7.2	0.025
107949	Q1	11.3	0.018
107949	2Q1	257.4	0.032
107949	P1	153.5	0.099
107949	2SM2	41	0.017
107949	M3	137	0.051
107949	L2	332.2	0.083
107949	2MK3	189.6	0.045
107949	K2	289.1	0.093
107949	M8	250.3	0.004
107949	MS4	156.3	0.019
107950	M2	297.5	1.105
107950	S2	293.1	0.217
107950	N2	264	0.162
107950	K1	194.5	0.343
107950	M4	262	0.085
107950	O1	173	0.274
107950	M6	348.5	0.055
107950	MK3	145.1	0.045
107950	S4	135.2	0.012
107950	MN4	332.4	0.013
107950	S6	58	0.019
107950	2N2	13.5	0.028
107950	OO1	136.5	0.015
107950	M1	13.6	0.126
107950	J1	14.4	0.034
107950	Q1	321.6	0.043
107950	2Q1	274.5	0.035
107950	P1	128.3	0.085
107950	2SM2	75.3	0.016
107950	M3	144.6	0.047
107950	L2	342.4	0.123
107950	2MK3	194.4	0.065
107950	K2	290.2	0.144
107950	M8	280.3	0.007
107950	MS4	135.2	0.017
107951	M2	289.4	1.163
107951	S2	309.9	0.263
107951	N2	249.7	0.251
107951	K1	183.8	0.483
107951	M4	46.2	0.11
107951	O1	166.9	0.285
107951	M6	10.6	0.011
107951	MK3	311.7	0.128
107951	S4	298.4	0.004
107951	MN4	55.9	0.03
107951	S6	233.7	0.012
107951	2N2	237.6	0.031
107951	OO1	135.9	0.039
107951	M1	290.1	0.05
107951	J1	311.1	0.007
107951	Q1	189.9	0.034
107951	2Q1	138.6	0.027
107951	P1	174.2	0.1
107951	2SM2	254	0.019
107951	M3	75.2	0.007
107951	L2	317.8	0.05
107951	2MK3	267.1	0.059
107951	K2	301.1	0.146
107951	M8	314.6	0.022
107951	MS4	16.6	0.031
107952	M2	287.8	1.127
107952	S2	311.1	0.259
107952	N2	246.4	0.277
107952	K1	174.1	0.491
107952	M4	21	0.095
107952	O1	157.7	0.274
107952	M6	53.9	0.028
107952	MK3	301.7	0.135
107952	S4	351.4	0.015
107952	MN4	83.5	0.007
107952	S6	264.6	0.005
107952	2N2	152.4	0.002
107952	OO1	122	0.042
107952	M1	299.7	0.047
107952	J1	67.4	0.048
107952	Q1	117.8	0.008
107952	2Q1	139.2	0.047
107952	P1	163.8	0.127
107952	2SM2	281.3	0.015
107952	M3	77.9	0.028
107952	L2	310.5	0.042
107952	2MK3	263	0.115
107952	K2	312.2	0.145
107952	M8	333.4	0.024
107952	MS4	349.3	0.035
107953	M2	286.4	1.088
107953	S2	312.7	0.255
107953	N2	247.9	0.293
107953	K1	169.3	0.504
107953	M4	9.4	0.1
107953	O1	151.9	0.272
107953	M6	69.4	0.033
107953	MK3	294.7	0.13
107953	S4	357.3	0.023
107953	MN4	177.2	0.005
107953	S6	298.9	0.006
107953	2N2	81.9	0.035
107953	OO1	134.6	0.029
107953	M1	292.9	0.05
107953	J1	65.6	0.054
107953	Q1	36.4	0.005
107953	2Q1	137.5	0.058
107953	P1	165.3	0.127
107953	2SM2	320.2	0.02
107953	M3	78.3	0.031
107953	L2	292.9	0.023
107953	2MK3	262.7	0.127
107953	K2	317.7	0.159
107953	M8	348	0.026
107953	MS4	346.4	0.033
107954	M2	177.6	0.461
107954	S2	186.2	0.112
107954	N2	135.1	0.08
107954	K1	138.2	0.046
107954	M4	295.2	0.095
107954	O1	195.2	0.012
107954	M6	143.8	0.038
107954	MK3	80.2	0.011
107954	S4	169.3	0.018
107954	MN4	240.6	0.034
107954	2N2	299.6	0.008
107954	OO1	121.7	0.004
107954	M1	52.9	0.003
107954	J1	127.8	0.002
107954	Q1	177	0.009
107954	2Q1	296.5	0.013
107954	2SM2	3.7	0.011
107954	M3	106.9	0.013
107954	L2	219.8	0.026
107954	2MK3	72	0.015
107954	M8	283.5	0.007
107954	MS4	332.7	0.044
107955	M2	185.6	0.248
107955	S2	185.9	0.079
107955	N2	115	0.05
107955	K1	134.5	0.023
107955	M4	334	0.02
107955	O1	352.6	0.007
107955	M6	151.7	0.04
107955	MK3	52.1	0.02
107955	S4	78.8	0.001
107955	MN4	23.4	0.017
107955	S6	186.8	0.003
107955	2N2	18	0.018
107955	OO1	262.1	0.001
107955	M1	116.8	0.006
107955	J1	167.4	0.013
107955	Q1	174.4	0.003
107955	2Q1	155.1	0.004
107955	2SM2	55	0.006
107955	M3	24.2	0.015
107955	L2	341.1	0.014
107955	2MK3	337.8	0.017
107955	M8	178.6	0.005
107955	MS4	317.3	0.01
107956	M2	189.9	0.162
107956	S2	216.5	0.027
107956	N2	177	0.027
107956	K1	182.3	0.026
107956	M4	225.9	0.016
107956	O1	190	0.021
107956	M6	7	0.012
107956	MK3	346.4	0.004
107956	S4	155.9	0.008
107956	MN4	96.2	0.004
107956	S6	235.3	0.003
107956	2N2	54.4	0.01
107956	OO1	189	0.002
107956	M1	219.7	0.003
107956	J1	248.2	0.006
107956	Q1	225.8	0.004
107956	2Q1	216.3	0.004
107956	2SM2	308.7	0.006
107956	M3	59	0.004
107956	L2	148	0.035
107956	2MK3	333.7	0.003
107956	M8	87.7	0.005
107956	MS4	106.2	0.009
107957	M2	159.2	0.185
107957	S2	209.8	0.044
107957	N2	125.9	0.019
107957	K1	130.5	0.025
107957	M4	248	0.084
107957	O1	115.7	0.021
107957	M6	84.9	0.036
107957	S4	156.5	0.013
107957	NU2	130.4	0.004
107957	S6	259.8	0.009
107957	2N2	92.5	0.003
107957	OO1	145.2	0.001
107957	LDA2	182.7	0.001
107957	M1	123.1	0.002
107957	J1	137.8	0.002
107957	RHO1	109.5	0.001
107957	Q1	108.4	0.004
107957	T2	207.7	0.003
107957	2Q1	101.1	0.001
107957	P1	129.4	0.008
107957	L2	125.9	0.003
107957	K2	213.9	0.012
107957	M8	199.7	0.018
107958	M2	188.4	0.323
107958	S2	210.9	0.116
107958	N2	145.9	0.045
107958	K1	158.6	0.032
107958	M4	223.5	0.064
107958	O1	149.3	0.024
107958	M6	296.1	0.008
107958	S4	51.9	0.008
107958	NU2	151.6	0.009
107958	S6	242.9	0.004
107958	2N2	103.4	0.006
107958	OO1	167.8	0.001
107958	LDA2	198.9	0.002
107958	M1	154	0.002
107958	J1	163.2	0.002
107958	RHO1	145.4	0.001
107958	Q1	144.7	0.005
107958	T2	209.9	0.007
107958	R2	211.7	0.001
107958	2Q1	140.1	0.001
107958	P1	157.9	0.011
107958	L2	145.9	0.006
107958	K2	212.6	0.032
107958	M8	87.9	0.014
107959	M2	196.3	0.28
107959	S2	229.5	0.119
107959	N2	173.4	0.068
107959	K1	190.9	0.043
107959	M4	54.3	0.01
107959	O1	146	0.021
107959	M6	296.2	0.005
107959	S4	223.8	0.014
107959	NU2	176.5	0.013
107959	S6	269.2	0.001
107959	2N2	150.5	0.009
107959	OO1	235.7	0.001
107959	LDA2	211.7	0.002
107959	M1	168.5	0.001
107959	J1	213.1	0.002
107959	RHO1	126.8	0.001
107959	Q1	123.8	0.004
107959	T2	228.1	0.007
107959	R2	230.7	0.001
107959	2Q1	101.6	0.001
107959	P1	187.6	0.014
107959	L2	173.4	0.01
107959	K2	232.1	0.032
107959	M8	242.5	0.005
107960	M2	204.8	0.06
107960	S2	238.9	0.029
107960	N2	201.3	0.006
107960	K1	218.6	0.021
107960	M4	318.5	0.002
107960	O1	200.3	0.012
107960	M6	327.6	0.001
107960	MK3	247.3	0.005
107960	S4	224.1	0.003
107960	MN4	257.4	0.005
107960	S6	234.5	0.002
107960	2N2	125.1	0.005
107960	OO1	236.6	0.002
107960	M1	162.9	0.001
107960	J1	216.7	0.001
107960	Q1	198.8	0.004
107960	2Q1	249	0.004
107960	P1	200.4	0.01
107960	2SM2	129.4	0.006
107960	M3	302.7	0.002
107960	L2	305	0.014
107960	2MK3	229.5	0.004
107960	K2	224.5	0.012
107960	M8	347.3	0.002
107960	MS4	300.9	0.003
107961	M2	240.5	0.093
107961	S2	285.1	0.056
107961	N2	207.9	0.026
107961	K1	188.1	0.063
107961	M4	238.4	0.021
107961	O1	139.4	0.024
107961	M6	146.8	0.006
107961	MK3	147.3	0.004
107961	S4	187.6	0.005
107961	MN4	157.5	0.007
107961	S6	146.4	0.003
107961	2N2	271.6	0.011
107961	OO1	76.4	0.001
107961	M1	209.8	0.003
107961	J1	333.6	0.012
107961	Q1	45	0.008
107961	2Q1	7.9	0.01
107961	P1	75.3	0.035
107961	2SM2	148.2	0.011
107961	M3	23.8	0.004
107961	L2	4.1	0.004
107961	2MK3	112.4	0.011
107961	K2	229.2	0.028
107961	M8	200.5	0.003
107961	MS4	283	0.011
107962	M2	196.6	0.139
107962	S2	212.4	0.046
107962	N2	162.3	0.034
107962	K1	145.3	0.052
107962	M4	271.4	0.026
107962	O1	107.2	0.034
107962	M6	33.4	0.006
107962	S4	133	0.005
107962	NU2	166.9	0.007
107962	S6	27.2	0.002
107962	2N2	127.9	0.005
107962	OO1	183.5	0.001
107962	LDA2	204	0.001
107962	M1	126.3	0.002
107962	J1	164.2	0.003
107962	RHO1	90.9	0.001
107962	Q1	88.3	0.007
107962	T2	211.8	0.003
107962	2Q1	69.4	0.001
107962	P1	142.5	0.017
107962	L2	162.3	0.005
107962	K2	213.7	0.012
107962	M8	343.6	0.001
107963	M2	194.8	0.174
107963	S2	243.9	0.038
107963	N2	128.7	0.033
107963	K1	153.4	0.058
107963	M4	244.4	0.017
107963	O1	112.3	0.034
107963	M6	41.6	0.002
107963	S4	292	0.008
107963	NU2	137.6	0.006
107963	S6	82.6	0.002
107963	2N2	62.6	0.004
107963	OO1	194.6	0.001
107963	LDA2	217.6	0.001
107963	M1	132.9	0.002
107963	J1	173.8	0.003
107963	RHO1	94.7	0.001
107963	Q1	91.9	0.007
107963	T2	241.9	0.002
107963	2Q1	71.4	0.001
107963	P1	150.4	0.019
107963	L2	128.7	0.005
107963	K2	247.9	0.01
107963	M8	55.9	0.002
107964	M2	185.1	0.104
107964	S2	241	0.032
107964	N2	154.9	0.027
107964	K1	156.3	0.048
107964	M4	227.6	0.012
107964	O1	123.2	0.031
107964	M6	101.4	0.003
107964	S4	207.3	0.006
107964	NU2	159	0.005
107964	S6	216.2	0.003
107964	2N2	124.6	0.004
107964	OO1	189.3	0.001
107964	LDA2	211.1	0.001
107964	M1	139.8	0.002
107964	J1	172.6	0.002
107964	RHO1	109.1	0.001
107964	Q1	106.9	0.006
107964	T2	238.8	0.002
107964	2Q1	90.5	0.001
107964	P1	153.8	0.016
107964	L2	154.9	0.004
107964	K2	245.5	0.009
107965	M2	147.5	0.222
107965	S2	199.7	0.071
107965	N2	160.1	0.048
107965	K1	153.2	0.039
107965	M4	308.2	0.028
107965	O1	149.2	0.024
107965	M6	309.3	0.012
107965	S4	188.5	0.014
107965	NU2	158.4	0.009
107965	S6	304.2	0.002
107965	2N2	172.7	0.006
107965	OO1	157.2	0.001
107965	LDA2	171.8	0.002
107965	M1	151.2	0.002
107965	J1	155.2	0.002
107965	RHO1	147.5	0.001
107965	Q1	147.2	0.005
107965	T2	197.6	0.004
107965	R2	201.8	0.001
107965	2Q1	145.2	0.001
107965	P1	152.9	0.013
107965	L2	160.1	0.007
107965	K2	203.9	0.019
107965	M8	152.4	0.008
107966	M2	197	0.19
107966	S2	222.2	0.054
107966	N2	145.8	0.034
107966	K1	144.3	0.042
107966	M4	276.9	0.052
107966	O1	131.6	0.028
107966	M6	158.5	0.012
107966	S4	119.3	0.005
107966	NU2	152.7	0.007
107966	S6	309	0.003
107966	2N2	94.7	0.004
107966	OO1	157	0.001
107966	LDA2	208.7	0.001
107966	M1	138	0.002
107966	J1	150.6	0.002
107966	RHO1	126.2	0.001
107966	Q1	125.3	0.006
107966	T2	221.2	0.003
107966	2Q1	119.1	0.001
107966	P1	143.4	0.014
107966	L2	145.8	0.005
107966	K2	224.2	0.015
107966	M8	150.5	0.005
107967	M2	186.4	0.215
107967	S2	226.1	0.072
107967	N2	151.6	0.037
107967	K1	173.1	0.033
107967	M4	229.5	0.026
107967	O1	119.3	0.019
107967	M6	126.3	0.004
107967	S4	172.3	0.013
107967	NU2	156.3	0.007
107967	S6	102.2	0.004
107967	2N2	116.8	0.005
107967	OO1	226.9	0.001
107967	LDA2	204.8	0.002
107967	M1	146.2	0.001
107967	J1	199.8	0.002
107967	RHO1	96.3	0.001
107967	Q1	92.7	0.004
107967	T2	224.5	0.004
107967	R2	227.6	0.001
107967	2Q1	66	0.001
107967	P1	169.1	0.011
107967	L2	151.6	0.005
107967	K2	229.3	0.02
107967	M8	108.9	0.001
107968	M2	155.6	1.614
107968	S2	185.6	0.654
107968	N2	106.1	0.284
107968	K1	95.8	0.212
107968	M4	190.3	0.218
107968	O1	100.1	0.055
107968	M6	83.8	0.039
107968	MK3	80.1	0.118
107968	S4	162.5	0.059
107968	MN4	111.5	0.09
107968	S6	225.2	0.013
107968	2N2	277.6	0.059
107968	OO1	133.8	0.032
107968	M1	170.4	0.01
107968	J1	97.8	0.015
107968	Q1	135.6	0.025
107968	2Q1	143.8	0.015
107968	P1	156.9	0.03
107968	2SM2	190.1	0.022
107968	M3	136.5	0.028
107968	L2	228.8	0.138
107968	2MK3	81.9	0.075
107968	K2	175.6	0.249
107968	M8	284.6	0.017
107968	MS4	212.4	0.047
107969	M2	153.7	1.657
107969	S2	184.1	0.685
107969	N2	110	0.291
107969	K1	89.9	0.193
107969	M4	185.8	0.25
107969	O1	94.6	0.052
107969	M6	33	0.035
107969	MK3	81.7	0.107
107969	S4	164.5	0.069
107969	MN4	110.1	0.104
107969	S6	138.3	0.006
107969	2N2	281.4	0.069
107969	OO1	118.7	0.018
107969	M1	92.1	0.012
107969	J1	124.4	0.018
107969	Q1	130.8	0.024
107969	2Q1	253.7	0.009
107969	P1	150.2	0.054
107969	2SM2	263	0.012
107969	M3	142	0.012
107969	L2	220.4	0.128
107969	2MK3	85.6	0.068
107969	K2	174.7	0.264
107969	M8	129.2	0.009
107969	MS4	214.7	0.042
107970	M2	153.9	1.741
107970	S2	194.2	0.707
107970	N2	115.9	0.337
107970	K1	109.7	0.147
107970	M4	178.6	0.074
107970	O1	126.6	0.052
107970	M6	338	0.022
107970	MK3	39.8	0.109
107970	S4	163.9	0.079
107970	MN4	47	0.082
107970	S6	270	0.005
107970	2N2	197.4	0.057
107970	OO1	93.5	0.011
107970	M1	147.4	0.014
107970	J1	204.7	0.007
107970	Q1	205.7	0.01
107970	2Q1	99.6	0.014
107970	P1	117.7	0.076
107970	2SM2	258.4	0.033
107970	M3	65.1	0.015
107970	L2	185.3	0.094
107970	2MK3	47.2	0.084
107970	K2	187.5	0.303
107970	M8	54.5	0.037
107970	MS4	136.8	0.036
107971	M2	183.6	1.145
107971	S2	219.7	0.391
107971	N2	152.7	0.247
107971	K1	117.4	0.283
107971	M4	263.2	0.139
107971	O1	106.8	0.095
107971	M6	197.1	0.032
107971	MK3	209.8	0.038
107971	S4	180.6	0.03
107971	MN4	212.6	0.041
107971	S6	164.2	0.005
107971	2N2	75.7	0.065
107971	OO1	124.2	0.01
107971	M1	114.6	0.01
107971	J1	175.7	0.021
107971	Q1	104.3	0.016
107971	2Q1	319.3	0.019
107971	P1	343.7	0.015
107971	2SM2	45	0.011
107971	M3	206.6	0.004
107971	2MK3	217	0.038
107971	K2	222.4	0.105
107971	M8	32.3	0.006
107971	MS4	318.9	0.053
107972	M2	186.7	1.168
107972	S2	223.4	0.396
107972	N2	151.5	0.259
107972	K1	122.9	0.248
107972	M4	260.7	0.135
107972	O1	99.8	0.132
107972	M6	171.2	0.016
107972	MK3	167.5	0.042
107972	S4	172.7	0.035
107972	MN4	210.9	0.048
107972	S6	211.9	0.004
107972	2N2	44.2	0.057
107972	OO1	159.6	0.015
107972	M1	87.8	0.004
107972	J1	152.3	0.022
107972	Q1	96	0.024
107972	2Q1	301.7	0.018
107972	P1	165.6	0.059
107972	2SM2	47.8	0.007
107972	M3	175.2	0.008
107972	L2	304.7	0.024
107972	2MK3	149.7	0.037
107972	K2	223.1	0.117
107972	M8	5.2	0.016
107972	MS4	319.5	0.042
107973	M2	190.7	1.227
107973	S2	223	0.373
107973	N2	148	0.231
107973	K1	141.9	0.249
107973	M4	240.7	0.077
107973	O1	112.8	0.149
107973	M6	111.7	0.04
107973	MK3	84.3	0.077
107973	S4	201	0.033
107973	MN4	148.7	0.021
107973	S6	253.6	0.01
107973	2N2	230.8	0.023
107973	OO1	166.9	0.023
107973	M1	252.1	0.011
107973	J1	115.6	0.012
107973	Q1	55.6	0.017
107973	2Q1	169.1	0.021
107973	P1	140.2	0.105
107973	2SM2	81.2	0.006
107973	M3	168.1	0.029
107973	L2	213.6	0.098
107973	2MK3	86.8	0.064
107973	K2	220.5	0.125
107973	M8	171.5	0.034
107973	MS4	32.2	0.01
107974	M2	143.5	0.306
107974	S2	194.9	0.077
107974	N2	107	0.056
107974	K1	116.5	0.1
107974	M4	300.9	0.062
107974	O1	77.4	0.043
107974	M6	59.1	0.015
107974	MK3	248.5	0.01
107974	S4	144.9	0.013
107974	MN4	228.4	0.025
107974	S6	5.5	0.008
107974	2N2	21	0.011
107974	OO1	252.4	0.006
107974	M1	63.7	0.009
107974	J1	85.7	0.006
107974	Q1	228.7	0.005
107974	2Q1	324.9	0.006
107974	P1	28.5	0.043
107974	2SM2	357.7	0.021
107974	M3	299.7	0.02
107974	L2	42.6	0.021
107974	2MK3	115.1	0.003
107974	K2	210.1	0.03
107974	M8	112.4	0.005
107974	MS4	329.4	0.036
107975	M2	168.3	0.32
107975	S2	193.5	0.04
107975	N2	152.3	0.095
107975	K1	100.5	0.143
107975	M4	289.3	0.1
107975	O1	30.7	0.032
107975	M6	88.8	0.022
107975	MK3	173.8	0.036
107975	S4	115.1	0.003
107975	MN4	241.2	0.03
107975	S6	42.5	0.007
107975	2N2	346.8	0.006
107975	OO1	113.3	0.019
107975	M1	275	0.008
107975	J1	99.1	0.009
107975	Q1	38.1	0.002
107975	2Q1	120.6	0.014
107975	P1	358.5	0.036
107975	2SM2	310.6	0.015
107975	M3	136.7	0.015
107975	L2	91.2	0.035
107975	2MK3	129.7	0.033
107975	K2	299.6	0.031
107975	M8	224	0.007
107975	MS4	329.5	0.049
107976	M2	192.9	0.417
107976	S2	210	0.144
107976	N2	143.4	0.116
107976	K1	80.6	0.164
107976	M4	262.9	0.136
107976	O1	53.6	0.058
107976	M6	67.6	0.006
107976	MK3	161	0.058
107976	S4	191.4	0.021
107976	MN4	197.3	0.057
107976	S6	222.8	0.008
107976	2N2	258.8	0.02
107976	OO1	118.2	0.007
107976	M1	4.3	0.002
107976	J1	266	0.012
107976	Q1	308.8	0.007
107976	2Q1	262.6	0.012
107976	P1	299.9	0.08
107976	2SM2	12.9	0.005
107976	M3	169	0.027
107976	L2	211.2	0.082
107976	2MK3	141.2	0.059
107976	K2	191.4	0.051
107976	M8	222.2	0.009
107976	MS4	295.9	0.068
107977	M2	188.6	0.587
107977	S2	211.3	0.191
107977	N2	148.9	0.109
107977	K1	101.2	0.163
107977	M4	309.7	0.034
107977	O1	94.6	0.065
107977	M6	238	0.033
107977	MK3	278.3	0.019
107977	S4	179.9	0.004
107977	MN4	115.8	0.013
107977	S6	209.6	0.001
107977	2N2	314.8	0.007
107977	OO1	168.6	0.016
107977	M1	88.9	0.013
107977	J1	126.3	0.01
107977	Q1	35.4	0.009
107977	2Q1	40.4	0.031
107977	P1	267.1	0.022
107977	2SM2	236.8	0.024
107977	M3	40	0.014
107977	L2	200.1	0.056
107977	2MK3	223.1	0.036
107977	K2	203.2	0.038
107977	M8	62.8	0.022
107977	MS4	24.8	0.018
107978	M2	187	0.545
107978	S2	222	0.169
107978	N2	155.7	0.124
107978	K1	112.2	0.176
107978	M4	248.8	0.044
107978	O1	98.1	0.135
107978	M6	192.3	0.026
107978	MK3	72.4	0.036
107978	S4	154.4	0.015
107978	MN4	169.9	0.022
107978	S6	328.5	0.004
107978	2N2	69.5	0.037
107978	OO1	167	0.01
107978	M1	96	0.005
107978	J1	138.3	0.01
107978	Q1	70.1	0.016
107978	2Q1	82.7	0.014
107978	P1	187.9	0.018
107978	2SM2	328.1	0.023
107978	M3	111.1	0.03
107978	L2	251.2	0.02
107978	2MK3	124.8	0.025
107978	K2	245.8	0.035
107978	M8	231.3	0.019
107978	MS4	291.9	0.011
107979	M2	197.9	0.596
107979	S2	257.5	0.195
107979	N2	161.7	0.121
107979	K1	135	0.151
107979	M4	239.7	0.111
107979	O1	122.2	0.128
107979	M6	63	0.005
107979	MK3	101.8	0.042
107979	S4	152.4	0.003
107979	MN4	180.1	0.031
107979	S6	184	0.008
107979	2N2	89.9	0.04
107979	OO1	248.6	0.013
107979	M1	23.6	0.015
107979	J1	151.9	0.021
107979	Q1	74.5	0.028
107979	2Q1	88.2	0.008
107979	P1	193.6	0.071
107979	2SM2	357.8	0.029
107979	M3	138.9	0.028
107979	L2	330.9	0.01
107979	2MK3	109.1	0.046
107979	K2	262.9	0.093
107979	M8	248.2	0.021
107979	MS4	258.4	0.029
107980	M2	173.4	0.978
107980	S2	207.3	0.302
107980	N2	144.2	0.194
107980	K1	109.8	0.158
107980	M4	272.4	0.137
107980	O1	90.1	0.059
107980	M6	94.5	0.024
107980	MK3	119.4	0.02
107980	S4	174.9	0.028
107980	MN4	210	0.042
107980	S6	277.4	0.008
107980	2N2	54.5	0.025
107980	OO1	174.3	0.006
107980	M1	77.4	0.01
107980	J1	163.9	0.022
107980	Q1	85.2	0.015
107980	2Q1	230.6	0.003
107980	P1	131.1	0.047
107980	2SM2	38.4	0.022
107980	M3	132.1	0.008
107980	L2	240.7	0.037
107980	2MK3	118.5	0.02
107980	K2	207.3	0.079
107980	M8	186.7	0.007
107980	MS4	291.6	0.042
107981	M2	176.8	1.117
107981	S2	206.4	0.38
107981	N2	142.1	0.218
107981	K1	118.7	0.198
107981	M4	248.2	0.136
107981	O1	103.7	0.077
107981	M6	78.6	0.019
107981	MK3	145.8	0.031
107981	S4	170.5	0.03
107981	MN4	194.5	0.043
107981	S6	264.4	0.01
107981	2N2	18	0.046
107981	OO1	151.7	0.012
107981	M1	107.6	0.007
107981	J1	171.6	0.005
107981	Q1	80.8	0.011
107981	2Q1	209.6	0.012
107981	P1	101.2	0.047
107981	2SM2	34.2	0.016
107981	M3	193.7	0.009
107981	L2	237.9	0.071
107981	2MK3	157	0.024
107981	K2	199.7	0.105
107981	M8	131	0.01
107981	MS4	282.1	0.035
107982	M2	175.8	1.163
107982	S2	204.3	0.403
107982	N2	139.7	0.217
107982	K1	123.3	0.212
107982	M4	243.9	0.111
107982	O1	104	0.088
107982	M6	78.3	0.017
107982	MK3	156	0.019
107982	S4	187.2	0.037
107982	MN4	194.7	0.025
107982	S6	242.2	0.007
107982	2N2	25.9	0.052
107982	OO1	149.9	0.017
107982	M1	194.4	0.011
107982	J1	249.1	0.008
107982	Q1	12.7	0.011
107982	2Q1	149.8	0.01
107982	P1	106.5	0.055
107982	2SM2	70.6	0.014
107982	M3	179.6	0.029
107982	L2	199	0.041
107982	2MK3	198.5	0.009
107982	K2	189.8	0.113
107982	M8	49.3	0.006
107982	MS4	290.5	0.025
107983	M2	209.7	0.771
107983	S2	240.6	0.274
107983	N2	185.5	0.105
107983	K1	171.4	0.205
107983	M4	275.3	0.077
107983	O1	146.8	0.125
107983	M6	188.3	0.01
107983	MK3	170.7	0.016
107983	S4	219.2	0.021
107983	MN4	239.8	0.026
107983	S6	224.2	0.005
107983	2N2	168.7	0.019
107983	OO1	179.3	0.003
107983	M1	183.7	0.01
107983	J1	226.1	0.007
107983	Q1	128.4	0.022
107983	2Q1	5.1	0.007
107983	P1	180.5	0.059
107983	2SM2	177.2	0.019
107983	M3	256.3	0.014
107983	L2	236.3	0.039
107983	2MK3	131.1	0.008
107983	K2	226.7	0.085
107983	M8	273	0.001
107983	MS4	339.9	0.028
107984	M2	202.6	0.748
107984	S2	238.1	0.245
107984	N2	172.5	0.149
107984	K1	168	0.185
107984	M4	273.3	0.033
107984	O1	149.7	0.102
107984	M6	102.6	0.009
107984	MK3	12.4	0.018
107984	S4	214.4	0.015
107984	MN4	287.3	0.002
107984	S6	276.8	0.006
107984	2N2	80.5	0.017
107984	OO1	180.4	0.007
107984	M1	137.2	0.008
107984	J1	192.3	0.009
107984	Q1	87.9	0.01
107984	2Q1	315.5	0.011
107984	P1	194.1	0.055
107984	2SM2	36.1	0.016
107984	M3	164.6	0.01
107984	L2	217.5	0.042
107984	2MK3	39.7	0.008
107984	K2	232.1	0.064
107984	M8	100.3	0.004
107984	MS4	61.1	0.011
107985	M2	207.1	0.642
107985	S2	251	0.202
107985	N2	176.8	0.145
107985	K1	170.6	0.193
107985	M4	220.5	0.036
107985	O1	152.4	0.106
107985	M6	68.7	0.013
107985	MK3	54.1	0.027
107985	S4	184.8	0.016
107985	MN4	136.2	0.026
107985	S6	259.8	0.005
107985	2N2	62.1	0.029
107985	OO1	217	0.01
107985	M1	146.1	0.013
107985	J1	206.6	0.021
107985	Q1	91.7	0.013
107985	2Q1	10.9	0.017
107985	P1	164.8	0.058
107985	2SM2	349.6	0.011
107985	M3	93.5	0.019
107985	L2	44	0.027
107985	2MK3	17.4	0.025
107985	K2	255.4	0.053
107985	M8	287.4	0.003
107985	MS4	74.6	0.016
107986	M2	195.9	0.578
107986	S2	234.4	0.124
107986	N2	158.2	0.106
107986	K1	132.6	0.125
107986	M4	239.2	0.116
107986	O1	122.4	0.044
107986	M6	288.1	0.012
107986	MK3	230.8	0.023
107986	S4	228.6	0.014
107986	MN4	170	0.036
107986	S6	242.7	0.009
107986	2N2	322.1	0.041
107986	OO1	258.6	0.009
107986	M1	160.3	0.005
107986	J1	79.8	0.009
107986	Q1	191.6	0.013
107986	2Q1	131.3	0.016
107986	P1	209	0.017
107986	2SM2	245.3	0.006
107986	M3	189.8	0.007
107986	L2	318.1	0.048
107986	2MK3	189.5	0.023
107986	K2	150.6	0.042
107986	M8	112.6	0.012
107986	MS4	306.3	0.034
107987	M2	208.2	0.657
107987	S2	256.8	0.18
107987	N2	165.8	0.107
107987	K1	152.9	0.128
107987	M4	224.8	0.092
107987	O1	131.4	0.046
107987	M6	9.2	0.009
107987	MK3	181.4	0.033
107987	S4	259.8	0.021
107987	MN4	164.3	0.037
107987	S6	125	0.013
107987	2N2	292.3	0.054
107987	OO1	202.2	0.011
107987	M1	213.4	0.009
107987	J1	89.3	0.011
107987	Q1	105.8	0.019
107987	2Q1	137.4	0.009
107987	P1	229	0.038
107987	2SM2	241.8	0.033
107987	M3	157.7	0.013
107987	L2	328.9	0.031
107987	2MK3	155.5	0.015
107987	K2	33.4	0.008
107987	M8	158.7	0.005
107987	MS4	266.7	0.041
107988	M2	208.4	0.683
107988	S2	266.8	0.293
107988	N2	169.2	0.1
107988	K1	142.7	0.115
107988	M4	141.2	0.043
107988	O1	147.4	0.056
107988	M6	87.2	0.01
107988	MK3	108.7	0.022
107988	S4	244.6	0.021
107988	MN4	85.1	0.014
107988	S6	194.6	0.006
107988	2N2	318.3	0.026
107988	OO1	33.3	0.009
107988	M1	181.6	0.009
107988	J1	217.9	0.038
107988	Q1	190.4	0.011
107988	2Q1	186.5	0.022
107988	P1	185.5	0.096
107988	2SM2	330.2	0.017
107988	M3	116.7	0.011
107988	L2	262.4	0.05
107988	2MK3	52	0.027
107988	K2	320.8	0.041
107988	M8	48	0.009
107988	MS4	180.5	0.045
107989	M2	227.5	0.134
107989	S2	282.4	0.034
107989	N2	224.6	0.021
107989	K1	193	0.075
107989	M4	277.6	0.032
107989	O1	158.5	0.045
107989	M6	225.4	0.005
107989	MK3	223.5	0.017
107989	S4	278.5	0.008
107989	MN4	252.3	0.008
107989	S6	75.1	0.002
107989	2N2	2.9	0.005
107989	OO1	81.3	0.004
107989	M1	122.7	0.005
107989	J1	238.8	0.014
107989	Q1	138.7	0.013
107989	2Q1	68.8	0.002
107989	P1	169.8	0.022
107989	2SM2	253.9	0.007
107989	M3	230.1	0.002
107989	L2	246.1	0.014
107989	2MK3	170.8	0.011
107989	K2	146.6	0.006
107989	M8	4.1	0.003
107989	MS4	31.9	0.014
107990	M2	229	0.135
107990	S2	252.4	0.072
107990	N2	223.1	0.034
107990	K1	178.7	0.075
107990	M4	309.8	0.012
107990	O1	156.7	0.033
107990	M6	125.6	0.005
107990	MK3	95.7	0.008
107990	S4	279.9	0.007
107990	MN4	218	0.009
107990	S6	137	0.003
107990	2N2	7.9	0.007
107990	OO1	219.7	0.002
107990	M1	190.1	0.003
107990	J1	265	0.003
107990	Q1	105	0.005
107990	2Q1	342.5	0.007
107990	P1	206.5	0.019
107990	2SM2	152.8	0.008
107990	M3	204.9	0.009
107990	L2	276.9	0.007
107990	2MK3	54.2	0.006
107990	K2	289.2	0.038
107990	M8	193.7	0.002
107990	MS4	35.4	0.006
107991	M2	230.7	0.182
107991	S2	276.8	0.06
107991	N2	189.4	0.026
107991	K1	158	0.073
107991	M4	350.3	0.016
107991	O1	151.1	0.02
107991	M6	155.5	0.006
107991	MK3	276.8	0.006
107991	S4	249.8	0.006
107991	MN4	47.9	0.004
107991	S6	353	0.004
107991	2N2	316.8	0.004
107991	OO1	199	0.009
107991	M1	188.6	0.007
107991	J1	238.5	0.004
107991	Q1	335.2	0.002
107991	2Q1	166.1	0.012
107991	P1	238.2	0.039
107991	2SM2	113.4	0.013
107991	M3	69.1	0.01
107991	L2	166.7	0.01
107991	2MK3	274.2	0.004
107991	K2	269.6	0.007
107991	M8	4.6	0.003
107991	MS4	44.1	0.006
107992	M2	173.9	0.143
107992	S2	188.3	0.04
107992	N2	131.6	0.018
107992	K1	91.5	0.045
107992	M4	262.4	0.03
107992	O1	100.2	0.006
107992	M6	149.9	0.003
107992	MK3	221.8	0.008
107992	S4	199.8	0.006
107992	MN4	222	0.01
107992	2N2	168.1	0.007
107992	OO1	122.2	0.008
107992	M1	262.7	0.008
107992	J1	221.8	0.013
107992	Q1	148.4	0.019
107992	2Q1	95.3	0.001
107992	P1	254.4	0.037
107992	2SM2	129.9	0.038
107992	M3	264.8	0.005
107992	L2	7.7	0.019
107992	2MK3	72.1	0.011
107992	K2	210.4	0.015
107992	M8	43.3	0.002
107992	MS4	345.1	0.007
107993	M2	250.5	0.219
107993	S2	254.5	0.044
107993	N2	182.4	0.042
107993	K1	135.5	0.086
107993	M4	256.7	0.007
107993	O1	130.5	0.048
107993	M6	78	0.012
107993	MK3	166.7	0.023
107993	S4	239.3	0.009
107993	MN4	202.4	0.012
107993	S6	215.2	0.001
107993	2N2	302.3	0.012
107993	OO1	171.1	0.005
107993	M1	255	0.009
107993	J1	1.8	0.015
107993	Q1	79.7	0.005
107993	2Q1	104.7	0.007
107993	P1	185	0.049
107993	2SM2	167	0.018
107993	M3	122.2	0.004
107993	L2	45.2	0.016
107993	2MK3	75.7	0.009
107993	K2	226.1	0.042
107993	M8	142.3	0.001
107993	MS4	200.8	0.002
107994	M2	253.2	0.209
107994	S2	264	0.081
107994	N2	224.9	0.029
107994	K1	114.6	0.16
107994	M4	308.8	0.015
107994	O1	139.2	0.018
107994	M6	138	0.004
107994	MK3	28.5	0.011
107994	S4	275.7	0.013
107994	MN4	324.1	0.003
107994	S6	230.5	0.004
107994	2N2	228.9	0.009
107994	OO1	170	0.004
107994	M1	241.9	0.006
107994	J1	186.3	0.011
107994	Q1	62.9	0.015
107994	2Q1	226.6	0.024
107994	P1	230.1	0.054
107994	2SM2	169	0.011
107994	M3	332.5	0.005
107994	L2	143.5	0.012
107994	2MK3	5.2	0.007
107994	K2	278.9	0.049
107994	M8	258.8	0.004
107994	MS4	340.8	0.008
107995	M2	351.1	0.276
107995	S2	38.4	0.088
107995	N2	302.6	0.046
107995	K1	86.2	0.015
107995	M4	161.5	0.029
107995	O1	333.1	0.03
107995	M6	238.8	0.007
107995	MK3	205.5	0.006
107995	S4	165.2	0.003
107995	MN4	111.6	0.02
107995	S6	60.2	0.008
107995	2N2	55.9	0.015
107995	OO1	351.7	0.003
107995	M1	326.1	0.004
107995	J1	288.3	0.008
107995	Q1	277.7	0.008
107995	2Q1	212.5	0.005
107995	P1	297	0.03
107995	2SM2	315.6	0.019
107995	M3	163.2	0.003
107995	L2	98.4	0.008
107995	2MK3	154	0.006
107995	K2	27.8	0.005
107995	M8	251.8	0.001
107995	MS4	176.6	0.015
107996	M2	10	0.289
107996	S2	13	0.099
107996	N2	318.5	0.055
107996	K1	26.6	0.025
107996	M4	106.3	0.021
107996	O1	332.2	0.024
107996	M6	14.2	0.005
107996	MK3	147.2	0.004
107996	S4	54.4	0.008
107996	MN4	82.9	0.007
107996	S6	242.4	0.002
107996	2N2	137.9	0.012
107996	M1	228.8	0.006
107996	J1	180.7	0.004
107996	Q1	277.4	0.003
107996	2Q1	24.9	0.002
107996	P1	273.9	0.023
107996	2SM2	96.2	0.009
107996	M3	121.3	0.004
107996	L2	145.6	0.006
107996	2MK3	110.8	0.009
107996	K2	10.5	0.062
107996	M8	9.2	0.005
107996	MS4	221.2	0.016
107997	M2	12.4	0.33
107997	S2	44.1	0.127
107997	N2	355.1	0.066
107997	K1	269.3	0.093
107997	M4	86.2	0.047
107997	O1	302.8	0.018
107997	M6	7.6	0.009
107997	MK3	244.6	0.004
107997	S4	354.6	0.011
107997	MN4	81.6	0.013
107997	S6	253.7	0.007
107997	2N2	231.4	0.032
107997	OO1	18.1	0.006
107997	M1	68.4	0.01
107997	J1	326.6	0.022
107997	Q1	35.4	0.011
107997	2Q1	293.1	0.017
107997	P1	39	0.087
107997	2SM2	161.5	0.036
107997	M3	4.6	0.009
107997	L2	37.4	0.028
107997	2MK3	132	0.004
107997	K2	40.9	0.056
107997	M8	205.5	0.003
107997	MS4	175.5	0.021
107998	M2	196.8	0.835
107998	S2	217.3	0.325
107998	N2	155.8	0.116
107998	K1	209.2	0.157
107998	M4	289.1	0.04
107998	O1	183.3	0.058
107998	M6	197.5	0.034
107998	MK3	121.5	0.012
107998	S4	223.6	0.039
107998	MN4	279.9	0.015
107998	S6	185.4	0.011
107998	2N2	201.8	0.038
107998	OO1	282.9	0.009
107998	M1	303.6	0.002
107998	J1	321.2	0.005
107998	Q1	101.9	0.007
107998	2Q1	323.5	0.007
107998	P1	326.5	0.011
107998	2SM2	324.6	0.02
107998	M3	238.2	0.007
107998	L2	260.6	0.029
107998	2MK3	269	0.014
107998	K2	213.5	0.12
107998	M8	7.4	0.026
107998	MS4	77.8	0.024
107999	M2	206.8	0.773
107999	S2	234.8	0.225
107999	N2	179.7	0.141
107999	K1	212.3	0.128
107999	M4	197.9	0.056
107999	O1	205.6	0.095
107999	M6	184.4	0.008
107999	MK3	93.8	0.034
107999	S4	149.7	0.017
107999	MN4	102.7	0.016
107999	S6	243.9	0.007
107999	2N2	307.4	0.016
107999	OO1	191.6	0.011
107999	M1	192.4	0.005
107999	J1	201.4	0.012
107999	Q1	201.1	0.041
107999	2Q1	39.9	0.007
107999	P1	185	0.056
107999	2SM2	258	0.019
107999	M3	140.9	0.019
107999	L2	260.3	0.045
107999	2MK3	78.8	0.036
107999	K2	207.3	0.053
107999	M8	42.3	0.003
107999	MS4	23.3	0.007
108000	M2	206	0.195
108000	S2	237.3	0.074
108000	N2	216	0.065
108000	K1	157.3	0.05
108000	M4	219.4	0.045
108000	O1	164	0.024
108000	M6	190.2	0.002
108000	S4	168.7	0.01
108000	NU2	214.7	0.013
108000	S6	18.3	0.01
108000	2N2	225.9	0.009
108000	OO1	150.5	0.001
108000	LDA2	220.6	0.001
108000	M1	160.7	0.002
108000	J1	153.9	0.002
108000	RHO1	167	0.001
108000	Q1	167.4	0.005
108000	T2	236	0.004
108000	R2	238.5	0.001
108000	2Q1	170.7	0.001
108000	P1	157.8	0.017
108000	L2	216	0.009
108000	K2	239.8	0.02
108000	M8	180.4	0.003
108001	M2	222.1	0.412
108001	S2	257.2	0.151
108001	N2	208.6	0.118
108001	K1	150.4	0.052
108001	M4	153.6	0.046
108001	O1	152.7	0.026
108001	M6	174.6	0.007
108001	S4	110.2	0.007
108001	NU2	210.5	0.023
108001	S6	189.1	0.009
108001	2N2	195.2	0.016
108001	OO1	148.1	0.001
108001	LDA2	238.4	0.003
108001	M1	151.6	0.002
108001	J1	149.3	0.002
108001	RHO1	153.7	0.001
108001	Q1	153.8	0.005
108001	T2	255.8	0.009
108001	R2	258.5	0.001
108001	2Q1	155	0.001
108001	P1	150.6	0.017
108001	L2	208.6	0.017
108001	K2	260	0.041
108001	M8	2.8	0.005
108002	M2	168.2	0.476
108002	S2	212.1	0.324
108002	N2	48	0.038
108002	K1	213	0.052
108002	M4	342.5	0.025
108002	O1	174.1	0.034
108002	M6	58.5	0.007
108002	S4	235.5	0.04
108002	NU2	64.1	0.007
108002	S6	269.7	0.007
108002	2N2	287.7	0.005
108002	OO1	251.9	0.001
108002	LDA2	188.6	0.003
108002	M1	193.6	0.002
108002	J1	232.3	0.003
108002	RHO1	157.5	0.001
108002	Q1	154.9	0.007
108002	T2	210.3	0.019
108002	R2	213.8	0.003
108002	2Q1	135.6	0.001
108002	P1	210.1	0.017
108002	L2	48	0.005
108002	K2	215.6	0.088
108002	M8	252.9	0.001
108003	M2	220.4	0.183
108003	S2	244.4	0.037
108003	N2	189.2	0.073
108003	K1	276.2	0.051
108003	M4	283.1	0.025
108003	O1	247.3	0.042
108003	M6	337	0.003
108003	MK3	33.8	0.007
108003	S4	191.6	0.007
108003	MN4	217	0.005
108003	S6	219.3	0.003
108003	2N2	96.8	0.037
108003	OO1	47.2	0.005
108003	M1	252.8	0.009
108003	J1	182.4	0.004
108003	Q1	224.7	0.011
108003	2Q1	105	0.011
108003	P1	229.8	0.026
108003	2SM2	185.4	0.018
108003	M3	248.6	0.006
108003	L2	247.6	0.042
108003	2MK3	281.5	0.006
108003	K2	241.2	0.025
108003	M8	106.5	0.002
108003	MS4	22.3	0.016
108004	M2	205.9	0.184
108004	S2	218.3	0.029
108004	N2	209.6	0.025
108004	K1	246.4	0.051
108004	M4	289.5	0.028
108004	O1	227.6	0.026
108004	M6	314.7	0.001
108004	MK3	258.3	0.007
108004	S4	206.7	0.006
108004	MN4	230.4	0.011
108004	S6	238.2	0.002
108004	2N2	126.5	0.017
108004	OO1	289.7	0.001
108004	M1	317.2	0.005
108004	J1	255	0.003
108004	Q1	302.4	0.021
108004	2Q1	239.2	0.011
108004	P1	273	0.028
108004	2SM2	248.5	0.025
108004	M3	219.3	0.009
108004	L2	36	0.037
108004	2MK3	146.2	0.008
108004	K2	18.1	0.008
108004	M8	219.6	0.004
108004	MS4	20	0.013
108005	M2	173.1	0.337
108005	S2	230	0.147
108005	N2	154.4	0.046
108005	K1	222.6	0.057
108005	M4	286.3	0.02
108005	O1	324.4	0.002
108005	M6	253	0.004
108005	MK3	211.6	0.003
108005	S4	243.3	0.01
108005	MN4	277.8	0.008
108005	S6	337	0.001
108005	2N2	258.1	0.026
108005	OO1	49.3	0.002
108005	M1	319.8	0.012
108005	J1	316.2	0.01
108005	Q1	301	0.031
108005	2Q1	245.1	0.025
108005	P1	287.8	0.041
108005	2SM2	56	0.011
108005	M3	192.4	0.01
108005	L2	345	0.055
108005	2MK3	166.1	0.003
108005	K2	271.4	0.03
108005	M8	188.7	0.002
108005	MS4	27.8	0.002
108006	M2	218	0.216
108006	S2	247.2	0.076
108006	N2	196.7	0.04
108006	K1	236.7	0.027
108006	M4	250.6	0.017
108006	O1	208.2	0.024
108006	M6	116.8	0.006
108006	MK3	358.7	0.005
108006	S4	257	0.005
108006	MN4	172.3	0.007
108006	S6	107.2	0.004
108006	2N2	305.5	0.008
108006	OO1	64	0.003
108006	M1	210.5	0.009
108006	J1	240.8	0.008
108006	Q1	170.7	0.013
108006	2Q1	99	0.013
108006	P1	154.1	0.033
108006	2SM2	250.1	0.01
108006	M3	320.7	0.009
108006	L2	297.2	0.02
108006	2MK3	259.3	0.006
108006	K2	237	0.025
108006	MS4	90.3	0.005
108007	M2	206.7	0.175
108007	S2	242.3	0.043
108007	N2	187.4	0.037
108007	K1	182.5	0.025
108007	M4	330.4	0.017
108007	O1	157.4	0.022
108007	M6	239.1	0.002
108007	MK3	281.2	0.003
108007	S4	221.6	0.008
108007	MN4	273.6	0.008
108007	S6	96.6	0.002
108007	2N2	351.5	0.013
108007	OO1	219.1	0.005
108007	M1	85.2	0.001
108007	J1	153.9	0.005
108007	Q1	4.5	0.017
108007	2Q1	322	0.016
108007	P1	188.2	0.017
108007	2SM2	16.2	0.015
108007	M3	264.5	0.001
108007	L2	330.8	0.012
108007	2MK3	225.2	0.006
108007	K2	130	0.013
108007	M8	357.9	0.004
108007	MS4	75.8	0.008
108008	M2	189.8	0.206
108008	S2	215.6	0.099
108008	N2	149.6	0.026
108008	K1	175.1	0.047
108008	M4	274.6	0.023
108008	O1	111.4	0.03
108008	M6	312.7	0.006
108008	MK3	177.7	0.015
108008	S4	242	0.009
108008	MN4	258.1	0.008
108008	S6	322	0.004
108008	2N2	63.4	0.03
108008	OO1	201.3	0.022
108008	M1	33.3	0.016
108008	J1	85.1	0.005
108008	Q1	27.2	0.015
108008	2Q1	294.6	0.032
108008	P1	339.4	0.033
108008	2SM2	16.4	0.024
108008	M3	272.2	0.012
108008	L2	109.4	0.041
108008	2MK3	211.3	0.011
108008	K2	230.4	0.033
108008	M8	115	0.004
108008	MS4	16.7	0.007
108009	M2	187.4	0.137
108009	S2	249.2	0.066
108009	N2	182.1	0.019
108009	K1	170	0.018
108009	M4	110.1	0.024
108009	O1	252.9	0.007
108009	M6	238.7	0.016
108009	MK3	91.5	0.008
108009	S4	255.5	0.01
108009	MN4	63.5	0.017
108009	S6	135.8	0.003
108009	2N2	171.4	0.01
108009	OO1	202.1	0.011
108009	M1	276.9	0.005
108009	J1	104	0.006
108009	Q1	172.2	0.001
108009	2Q1	198.1	0.012
108009	P1	208.6	0.008
108009	2SM2	82.1	0.01
108009	M3	123.3	0.007
108009	L2	222.9	0.003
108009	2MK3	42	0.009
108009	K2	280.2	0.014
108009	M8	319	0.001
108009	MS4	134.5	0.011
108010	M2	225.8	0.104
108010	S2	271.2	0.056
108010	N2	239.4	0.025
108010	K1	171.8	0.069
108010	M4	284.8	0.032
108010	O1	157.5	0.024
108010	M6	320.4	0.011
108010	MK3	251.9	0.004
108010	S4	259.9	0.004
108010	MN4	247.5	0.012
108010	S6	271.3	0.002
108010	2N2	166.6	0.02
108010	OO1	268.5	0.008
108010	M1	358.6	0.004
108010	J1	166.5	0.014
108010	Q1	94.2	0.009
108010	2Q1	237	0.008
108010	P1	282.9	0.027
108010	2SM2	178	0.017
108010	M3	128.7	0.005
108010	L2	309.7	0.009
108010	2MK3	179.5	0.015
108010	K2	306.9	0.019
108010	M8	287.4	0.004
108010	MS4	9.4	0.004
108011	M2	236.6	0.305
108011	S2	271.5	0.107
108011	N2	182.2	0.045
108011	K1	227.2	0.061
108011	M4	245.9	0.052
108011	O1	208.3	0.022
108011	M6	288.9	0.008
108011	MK3	158.5	0.022
108011	S4	311.7	0.01
108011	MN4	221	0.019
108011	S6	43.2	0.002
108011	2N2	1.1	0.019
108011	OO1	4.8	0.013
108011	M1	150.2	0.003
108011	J1	330.3	0.008
108011	Q1	182.4	0.012
108011	2Q1	24.7	0.024
108011	P1	116.4	0.027
108011	2SM2	240.5	0.006
108011	M3	232.7	0.007
108011	L2	211.6	0.005
108011	2MK3	28.2	0.011
108011	K2	288	0.029
108011	M8	100.3	0.008
108011	MS4	286.2	0.025
108012	M2	200.1	0.662
108012	S2	234.3	0.227
108012	N2	184.4	0.118
108012	K1	168.9	0.132
108012	M4	249.8	0.115
108012	O1	135.2	0.073
108012	M6	342.1	0.041
108012	MK3	149.9	0.037
108012	S4	278.7	0.023
108012	MN4	224.8	0.053
108012	S6	200.9	0.01
108012	2N2	79.1	0.024
108012	OO1	156.9	0.004
108012	M1	158.6	0.009
108012	J1	181.5	0.014
108012	Q1	68	0.01
108012	2Q1	192.6	0.008
108012	P1	167	0.04
108012	2SM2	268.1	0.01
108012	M3	171.8	0.016
108012	L2	96.3	0.016
108012	2MK3	83.6	0.031
108012	K2	193.2	0.055
108012	M8	39	0.003
108012	MS4	280.2	0.045
108013	M2	188.9	0.486
108013	S2	233.4	0.159
108013	N2	158.9	0.065
108013	K1	200.8	0.077
108013	M4	186.3	0.099
108013	O1	148.6	0.012
108013	M6	255.5	0.03
108013	MK3	120.1	0.047
108013	S4	249.3	0.035
108013	MN4	155.8	0.03
108013	S6	218.7	0.008
108013	2N2	28.3	0.029
108013	OO1	6.5	0.009
108013	M1	264.4	0.011
108013	J1	350.8	0.006
108013	Q1	201	0.013
108013	2Q1	6.6	0.027
108013	P1	152	0.034
108013	2SM2	246.6	0.012
108013	M3	153.7	0.011
108013	L2	93.2	0.01
108013	2MK3	97.1	0.041
108013	K2	173.4	0.037
108013	M8	290	0.015
108013	MS4	211.7	0.067
108014	M2	175.9	0.395
108014	S2	220.2	0.125
108014	N2	150.1	0.06
108014	K1	274.1	0.09
108014	M4	152.8	0.164
108014	O1	302.8	0.051
108014	M6	226.4	0.049
108014	MK3	125.7	0.081
108014	S4	237.8	0.027
108014	MN4	122.2	0.043
108014	S6	173.2	0.004
108014	2N2	356.3	0.017
108014	OO1	321.9	0.01
108014	M1	284.5	0.018
108014	J1	351.7	0.025
108014	Q1	215.1	0.025
108014	2Q1	16.7	0.033
108014	P1	29.1	0.036
108014	2SM2	81.1	0.026
108014	M3	212.8	0.018
108014	L2	212	0.021
108014	2MK3	91.5	0.065
108014	K2	218.3	0.036
108014	M8	71.5	0.004
108014	MS4	181.2	0.086
108015	M2	217.8	1.12
108015	S2	248.6	0.342
108015	N2	196.7	0.183
108015	K1	203.8	0.23
108015	M4	268.3	0.116
108015	O1	187.3	0.133
108015	M6	354.3	0.052
108015	MK3	184.8	0.048
108015	S4	279.3	0.042
108015	MN4	233.6	0.044
108015	S6	324.7	0.008
108015	2N2	328.8	0.016
108015	OO1	248.2	0.011
108015	M1	214.4	0.011
108015	J1	226.1	0.003
108015	Q1	205.6	0.026
108015	2Q1	34.5	0.006
108015	P1	229.3	0.041
108015	2SM2	73.5	0.006
108015	M3	187.5	0.03
108015	L2	210.5	0.043
108015	2MK3	75.6	0.027
108015	K2	238.7	0.118
108015	M8	33.3	0.015
108015	MS4	277.1	0.045
108016	M2	220.1	1.187
108016	S2	251	0.377
108016	N2	195.5	0.19
108016	K1	203.6	0.221
108016	M4	258.4	0.124
108016	O1	188.6	0.125
108016	M6	337.2	0.046
108016	MK3	187.4	0.071
108016	S4	283.5	0.037
108016	MN4	225.7	0.044
108016	S6	338.3	0.006
108016	2N2	273.1	0.004
108016	OO1	259.3	0.015
108016	M1	227.3	0.012
108016	J1	212.4	0.004
108016	Q1	197.3	0.023
108016	2Q1	46.5	0.002
108016	P1	205.9	0.039
108016	2SM2	163.9	0.005
108016	M3	204.1	0.034
108016	L2	223.5	0.035
108016	2MK3	120.1	0.03
108016	K2	241.6	0.118
108016	M8	50.8	0.018
108016	MS4	279.1	0.045
108017	M2	223.8	1.259
108017	S2	254.9	0.431
108017	N2	196	0.201
108017	K1	201.8	0.201
108017	M4	244.2	0.151
108017	O1	194.4	0.091
108017	M6	300.9	0.059
108017	MK3	190.6	0.093
108017	S4	297.7	0.028
108017	MN4	218.1	0.05
108017	S6	298.9	0.004
108017	2N2	247	0.019
108017	OO1	276.5	0.02
108017	M1	226	0.01
108017	J1	182.4	0.009
108017	Q1	204.4	0.021
108017	2Q1	97.1	0.007
108017	P1	184	0.044
108017	2SM2	183.2	0.019
108017	M3	225.1	0.034
108017	L2	257.7	0.025
108017	2MK3	159.6	0.044
108017	K2	246.8	0.122
108017	M8	95.5	0.014
108017	MS4	276.7	0.057
108018	M2	229	1.216
108018	S2	262.9	0.384
108018	N2	205.9	0.201
108018	K1	195.5	0.209
108018	M4	291.9	0.227
108018	O1	182.8	0.125
108018	M6	326.4	0.114
108018	MK3	236.5	0.053
108018	S4	298.9	0.03
108018	MN4	258.9	0.069
108018	S6	294.8	0.003
108018	2N2	207.5	0.003
108018	OO1	252.8	0.014
108018	M1	215.5	0.011
108018	J1	252.4	0.006
108018	Q1	166.1	0.024
108018	2Q1	11.4	0.01
108018	P1	199	0.044
108018	2SM2	328	0.017
108018	M3	245.4	0.024
108018	L2	223.6	0.041
108018	2MK3	162.3	0.005
108018	K2	246.4	0.113
108018	M8	66.5	0.037
108018	MS4	330	0.077
108019	M2	229.7	1.316
108019	S2	260.9	0.435
108019	N2	202.7	0.211
108019	K1	195.8	0.22
108019	M4	290.9	0.233
108019	O1	180.5	0.136
108019	M6	323.9	0.125
108019	MK3	231.5	0.059
108019	S4	303.8	0.037
108019	MN4	256.3	0.077
108019	S6	330.2	0.005
108019	2N2	234.1	0.013
108019	OO1	250.9	0.015
108019	M1	228	0.009
108019	J1	192.6	0.004
108019	Q1	169.5	0.023
108019	2Q1	32.3	0.01
108019	P1	191	0.047
108019	2SM2	330.6	0.011
108019	M3	247.5	0.025
108019	L2	246.8	0.033
108019	2MK3	163.2	0.014
108019	K2	248.6	0.131
108019	M8	64.9	0.037
108019	MS4	328.1	0.077
108020	M2	229.6	1.371
108020	S2	258.8	0.476
108020	N2	197.1	0.214
108020	K1	196	0.218
108020	M4	286.7	0.239
108020	O1	179.2	0.134
108020	M6	323	0.139
108020	MK3	223.4	0.066
108020	S4	310.2	0.048
108020	MN4	251.4	0.085
108020	S6	357.1	0.008
108020	2N2	225	0.027
108020	OO1	249.9	0.012
108020	M1	238.1	0.007
108020	J1	158.9	0.01
108020	Q1	167	0.015
108020	2Q1	65.8	0.016
108020	P1	176.6	0.05
108020	2SM2	356.7	0.006
108020	M3	239.6	0.024
108020	L2	273.9	0.029
108020	2MK3	164.5	0.018
108020	K2	249.2	0.146
108020	M8	72	0.035
108020	MS4	320.7	0.08
108021	M2	219.5	0.089
108021	S2	261.1	0.046
108021	N2	199.2	0.026
108021	K1	217.3	0.013
108021	M4	113	0.006
108021	O1	149.3	0.005
108021	M6	125.9	0.003
108021	MK3	335.9	0.005
108021	S4	268.2	0.003
108021	MN4	63.2	0.006
108021	S6	328.3	0.002
108021	2N2	234.4	0.01
108021	OO1	86	0.002
108021	J1	337.2	0.004
108021	Q1	198.8	0.012
108021	2Q1	116.7	0.008
108021	2SM2	289.6	0.004
108021	M3	5.2	0.008
108021	L2	336.9	0.011
108021	2MK3	189.3	0.007
108021	M8	21.2	0.001
108021	MS4	87.4	0.006
108022	M2	204.7	0.164
108022	S2	245.6	0.077
108022	N2	162.7	0.041
108022	K1	205.2	0.025
108022	M4	282.8	0.01
108022	O1	159	0.019
108022	M6	65.6	0.004
108022	MK3	169.3	0.009
108022	S4	5.9	0.005
108022	MN4	205.4	0.007
108022	S6	187.1	0.003
108022	2N2	150.6	0.027
108022	OO1	172.3	0.001
108022	M1	302.2	0.002
108022	J1	18.7	0.004
108022	2Q1	334	0.009
108022	2SM2	110.6	0.008
108022	M3	213.1	0.005
108022	L2	231.7	0.024
108022	2MK3	65.4	0.009
108022	M8	227.3	0.001
108022	MS4	335.7	0.006
108023	M2	187	0.132
108023	S2	211.3	0.067
108023	N2	303.2	0.016
108023	K1	97.7	0.015
108023	M4	292.1	0.012
108023	O1	82	0.009
108023	M6	357.6	0.001
108023	MK3	216.3	0.006
108023	S4	294.8	0.008
108023	MN4	278	0.009
108023	S6	151.9	0.001
108023	2N2	279.5	0.021
108023	OO1	317.9	0.011
108023	M1	114.7	0.013
108023	J1	218.9	0.022
108023	Q1	64	0.019
108023	2Q1	157.6	0.021
108023	2SM2	30.7	0.011
108023	M3	209.3	0.01
108023	L2	140.6	0.003
108023	2MK3	195.2	0.01
108023	M8	173.4	0.002
108023	MS4	35.8	0.015
108024	M2	186.8	0.361
108024	S2	214.9	0.108
108024	N2	160.8	0.061
108024	K1	198.9	0.066
108024	M4	358.8	0.062
108024	O1	156.6	0.035
108024	M6	148.1	0.017
108024	MK3	44.4	0.006
108024	S4	258.4	0.005
108024	MN4	321.9	0.014
108024	S6	133.1	0.004
108024	2N2	148.2	0.028
108024	OO1	88	0.003
108024	M1	350.8	0.001
108024	J1	179.5	0.008
108024	Q1	201.6	0.003
108024	2Q1	210.2	0.004
108024	P1	267.9	0.028
108024	2SM2	96.9	0.014
108024	M3	120.3	0.009
108024	L2	162.1	0.016
108024	2MK3	28.2	0.014
108024	K2	187.8	0.035
108024	M8	284.3	0.005
108024	MS4	45.8	0.06
108025	M2	187.1	0.392
108025	S2	192.9	0.119
108025	N2	172.7	0.08
108025	K1	205.3	0.075
108025	M4	310.1	0.06
108025	O1	170.4	0.053
108025	M6	77.9	0.016
108025	MK3	283.2	0.016
108025	S4	31.9	0.006
108025	MN4	308.5	0.019
108025	S6	269.8	0.006
108025	2N2	221.8	0.01
108025	OO1	21.4	0.008
108025	M1	193.3	0.006
108025	J1	308.9	0.009
108025	Q1	188.3	0.024
108025	2Q1	239.2	0.007
108025	P1	299.8	0.02
108025	2SM2	205.1	0.019
108025	M3	180.3	0.014
108025	L2	210.4	0.045
108025	2MK3	235.3	0.019
108025	K2	216.4	0.08
108025	M8	89.7	0.001
108025	MS4	0	0.046
108026	M2	193.4	0.614
108026	S2	221.9	0.2
108026	N2	188.5	0.107
108026	K1	92	0.131
108026	M4	290.8	0.067
108026	O1	77.2	0.067
108026	M6	104.8	0.014
108026	MK3	258.4	0.013
108026	S4	287.9	0.007
108026	MN4	296.4	0.034
108026	S6	169.1	0.006
108026	2N2	189.8	0.026
108026	OO1	227.3	0.006
108026	M1	140.3	0.005
108026	J1	21.9	0.021
108026	Q1	303.3	0.006
108026	2Q1	183.7	0.011
108026	P1	107.7	0.078
108026	2SM2	67	0.017
108026	M3	253.9	0.017
108026	L2	234	0.035
108026	2MK3	175.9	0.03
108026	K2	225.2	0.059
108026	M8	335.1	0.008
108026	MS4	327.9	0.052
108027	M2	158.6	0.106
108027	S2	179.9	0.063
108027	N2	143.5	0.031
108027	K1	249.2	0.022
108027	M4	1.3	0.008
108027	O1	223.8	0.021
108027	M6	176.8	0.003
108027	MK3	79.8	0.004
108027	S4	214.8	0.008
108027	MN4	336.9	0.005
108027	S6	20.4	0.002
108027	2N2	287.4	0.01
108027	OO1	232.8	0.002
108027	M1	240.9	0.001
108027	J1	307.4	0.004
108027	Q1	223.5	0.005
108027	2Q1	233.2	0.001
108027	P1	54.2	0.005
108027	2SM2	275	0.013
108027	M3	184.7	0.005
108027	L2	283	0.002
108027	2MK3	174.3	0.001
108027	K2	285.8	0.021
108027	M8	171.8	0.001
108027	MS4	56.7	0.016
108028	M2	211.7	0.084
108028	S2	246.9	0.057
108028	N2	203.2	0.019
108028	K1	230.2	0.026
108028	M4	60.7	0.008
108028	O1	214.3	0.022
108028	M6	86.3	0.002
108028	MK3	192.1	0.005
108028	S4	273.2	0.005
108028	MN4	172.8	0.006
108028	S6	22.4	0.001
108028	2N2	162	0.006
108028	OO1	104.6	0.001
108028	J1	302.3	0.009
108028	Q1	195.5	0.008
108028	2Q1	285	0.001
108028	2SM2	353	0.015
108028	M3	264.4	0.002
108028	L2	26	0.006
108028	2MK3	79.8	0.003
108028	K2	69.4	0.026
108028	M8	214.9	0.002
108028	MS4	107.7	0.005
108029	M2	213.4	0.242
108029	S2	231.1	0.056
108029	N2	212.1	0.021
108029	K1	108.6	0.039
108029	M4	193.3	0.012
108029	O1	145.7	0.013
108029	M6	102.5	0.002
108029	MK3	141.5	0.009
108029	S4	157	0.001
108029	MN4	98.5	0.003
108029	S6	230.2	0.002
108029	2N2	204.6	0.018
108029	OO1	198.7	0.009
108029	M1	190.1	0.005
108029	J1	12.8	0.018
108029	Q1	92.9	0.016
108029	2Q1	339.1	0.015
108029	P1	129.9	0.032
108029	2SM2	195.5	0.02
108029	M3	91.7	0.001
108029	L2	312.1	0.006
108029	2MK3	100.7	0.008
108029	K2	248.4	0.033
108029	M8	121	0.005
108029	MS4	254.1	0.012
108030	M2	260.3	0.142
108030	S2	278.2	0.091
108030	N2	253	0.033
108030	K1	226.1	0.053
108030	M4	329.2	0.017
108030	O1	180.6	0.04
108030	M6	131.3	0.003
108030	MK3	345.7	0.005
108030	S4	197.6	0.003
108030	MN4	289.7	0.003
108030	S6	157.2	0.002
108030	2N2	313.6	0.007
108030	OO1	186.8	0.003
108030	M1	223.1	0.003
108030	J1	219.2	0.006
108030	Q1	168.5	0.009
108030	2Q1	232.3	0.003
108030	P1	285.8	0.016
108030	2SM2	35.3	0.013
108030	M3	101.7	0.001
108030	L2	43.8	0.003
108030	2MK3	212.4	0.002
108030	K2	37.8	0.03
108030	M8	354.3	0.001
108030	MS4	13.2	0.01
108031	M2	251.5	0.236
108031	S2	262.3	0.111
108031	N2	234.6	0.055
108031	K1	214.2	0.043
108031	M4	303.1	0.045
108031	O1	188.2	0.037
108031	M6	244	0.004
108031	MK3	26.5	0.006
108031	S4	23.6	0.01
108031	MN4	281.4	0.022
108031	S6	65.3	0.002
108031	2N2	259.9	0.036
108031	OO1	142.8	0.006
108031	M1	230.1	0.002
108031	J1	200.4	0.009
108031	Q1	143	0.01
108031	2Q1	117.6	0.008
108031	P1	233.9	0.01
108031	2SM2	315.4	0.013
108031	M3	45.8	0.006
108031	L2	342.7	0.013
108031	2MK3	190.3	0.001
108031	K2	333.5	0.034
108031	M8	243.5	0.003
108031	MS4	351.1	0.032
108032	M2	188.1	0.472
108032	S2	174.4	0.141
108032	N2	182.3	0.066
108032	K1	43.9	0.025
108032	M4	101.9	0.046
108032	O1	356.6	0.018
108032	M6	15.5	0.014
108032	MK3	70.2	0.006
108032	S4	300.9	0.01
108032	MN4	89.6	0.026
108032	S6	168.7	0.006
108032	2N2	195.4	0.037
108032	OO1	159.7	0.01
108032	M1	6.2	0.003
108032	J1	268.7	0.012
108032	Q1	65.1	0.007
108032	2Q1	283	0.001
108032	P1	8.9	0.022
108032	2SM2	11.3	0.023
108032	M3	328.5	0.014
108032	L2	139.5	0.036
108032	2MK3	278.9	0.024
108032	K2	241.7	0.127
108032	M8	277.9	0.009
108032	MS4	145.9	0.032
108033	M2	237.7	0.043
108033	S2	249.4	0.013
108033	N2	269.9	0.006
108033	K1	230.3	0.01
108033	M4	288.8	0.008
108033	O1	205	0.018
108033	M6	183.2	0.003
108033	MK3	64.9	0.004
108033	S4	236.5	0.004
108033	MN4	298.7	0.003
108033	S6	133.5	0.002
108033	2N2	230.5	0.002
108033	OO1	64.2	0.002
108033	M1	182.1	0.001
108033	J1	205.8	0.004
108033	Q1	164.2	0.004
108033	2Q1	231.8	0.001
108033	2SM2	169.2	0.007
108033	M3	109.2	0.007
108033	L2	163.9	0.004
108033	2MK3	116.2	0.004
108033	MS4	61.8	0.002
108034	M2	253.8	0.168
108034	S2	276.5	0.071
108034	N2	243.1	0.024
108034	K1	201	0.033
108034	M4	55.7	0.01
108034	O1	152.2	0.015
108034	M6	316.8	0.001
108034	MK3	60.1	0.005
108034	S4	171	0.006
108034	MN4	303.1	0.006
108034	S6	337.3	0.003
108034	2N2	268.3	0.015
108034	OO1	236.7	0.005
108034	M1	144.1	0.005
108034	J1	76	0.001
108034	Q1	65.6	0.011
108034	2Q1	78.8	0.011
108034	2SM2	122.5	0.005
108034	M3	227.1	0.003
108034	L2	108.1	0.007
108034	2MK3	333.7	0.004
108034	M8	183.5	0.002
108034	MS4	71.5	0.011
108035	M2	250.7	0.185
108035	S2	269.2	0.077
108035	N2	267.2	0.034
108035	K1	206.8	0.042
108035	M4	57	0.012
108035	O1	142.3	0.023
108035	M6	64.8	0.004
108035	MK3	38.7	0.004
108035	S4	161.7	0.003
108035	MN4	211	0.007
108035	S6	180.5	0.002
108035	2N2	257.1	0.033
108035	OO1	246.2	0.004
108035	M1	195.2	0.005
108035	J1	114.3	0.005
108035	Q1	165.6	0.012
108035	2Q1	99.8	0.012
108035	2SM2	290.1	0.01
108035	M3	161.6	0.002
108035	L2	178.9	0.008
108035	2MK3	340.2	0.006
108035	M8	110.5	0.004
108035	MS4	62.4	0.01
108036	M2	89.9	0.131
108036	S2	115.9	0.042
108036	N2	98.4	0.034
108036	K1	106	0.018
108036	M4	218.3	0.016
108036	O1	20.7	0.015
108036	M6	221.2	0.005
108036	MK3	211.1	0.008
108036	S4	88	0.002
108036	MN4	224.1	0.01
108036	S6	228.9	0.005
108036	2N2	64.2	0.017
108036	OO1	298.1	0.001
108036	M1	9.7	0.001
108036	J1	100.9	0.007
108036	Q1	146.4	0.007
108036	2Q1	264.9	0.007
108036	2SM2	311.8	0.018
108036	M3	211.9	0.002
108036	L2	148.7	0.011
108036	2MK3	278.2	0.003
108036	M8	31.2	0.002
108036	MS4	227.9	0.013
108037	M2	29.1	0.15
108037	S2	91.7	0.065
108037	N2	2	0.043
108037	K1	66.3	0.002
108037	M4	67.9	0.022
108037	O1	101.7	0.01
108037	M6	3.7	0.008
108037	MK3	99.3	0.006
108037	S4	285	0.007
108037	MN4	136.4	0.009
108037	S6	183.7	0.008
108037	2N2	97.3	0.01
108037	OO1	258.2	0.007
108037	M1	7.1	0.005
108037	J1	253.2	0.008
108037	Q1	84.9	0.004
108037	2Q1	280.4	0.011
108037	2SM2	200.6	0.013
108037	M3	178.3	0.008
108037	L2	58	0.009
108037	2MK3	326.9	0.009
108037	M8	53.7	0.004
108037	MS4	147.9	0.014
108038	M2	350.2	0.273
108038	S2	17	0.081
108038	N2	359.7	0.058
108038	K1	250.6	0.027
108038	M4	337.6	0.011
108038	O1	258.7	0.036
108038	M6	79	0.006
108038	MK3	352.4	0.016
108038	S4	213.6	0.004
108038	MN4	327.9	0.015
108038	S6	343.5	0.004
108038	2N2	314.1	0.051
108038	OO1	338.6	0.008
108038	M1	227.1	0.011
108038	J1	145.1	0.015
108038	Q1	118.2	0.005
108038	2Q1	244.9	0.008
108038	2SM2	263.4	0.019
108038	M3	303.8	0.003
108038	L2	127	0.006
108038	2MK3	312.1	0.003
108038	M8	131	0.006
108038	MS4	102.6	0.01
108039	M2	179.7	0.158
108039	S2	213.9	0.053
108039	N2	166.4	0.034
108039	K1	184.2	0.008
108039	M4	177.9	0.006
108039	O1	163.2	0.003
108039	M6	326.3	0.003
108039	MK3	222.9	0.002
108039	S4	188.2	0.003
108039	MN4	126.4	0.002
108039	S6	324.2	0.006
108039	2N2	137.1	0.009
108039	OO1	98.4	0.006
108039	M1	251	0.003
108039	J1	138.1	0.004
108039	Q1	180.1	0.006
108039	2Q1	220.7	0.003
108039	2SM2	79	0.012
108039	M3	232.7	0.002
108039	L2	155.1	0.027
108039	2MK3	209.4	0.002
108039	MS4	250.2	0.003
108040	M2	198.1	0.214
108040	S2	240.3	0.083
108040	N2	175.9	0.045
108040	K1	157.8	0.031
108040	M4	140.9	0.008
108040	O1	122.3	0.012
108040	M6	14	0.005
108040	MK3	193.5	0.006
108040	S4	88.5	0.001
108040	MN4	106.4	0.005
108040	S6	21.7	0.001
108040	2N2	156.9	0.008
108040	OO1	216	0.004
108040	M1	119.3	0.003
108040	J1	208.6	0.003
108040	Q1	85	0.004
108040	2Q1	301	0.016
108040	2SM2	66.4	0.012
108040	M3	282.1	0.003
108040	L2	232.7	0.027
108040	2MK3	191.4	0.005
108040	M8	73.9	0.005
108040	MS4	228.1	0.002
108041	M2	265	0.475
108041	S2	311.2	0.159
108041	N2	267.9	0.11
108041	K1	174.1	0.043
108041	M4	302.5	0.019
108041	O1	182.1	0.034
108041	M6	250.8	0.008
108041	MK3	355.6	0.012
108041	S4	178.9	0.016
108041	MN4	304	0.016
108041	S6	175.6	0.011
108041	2N2	236.9	0.054
108041	OO1	203.3	0.009
108041	M1	199.5	0.007
108041	J1	254.3	0.006
108041	Q1	95.1	0.009
108041	2Q1	69.4	0.007
108041	2SM2	221.2	0.02
108041	M3	16	0.014
108041	L2	342.7	0.034
108041	2MK3	13.3	0.016
108041	M8	221	0.007
108041	MS4	28.7	0.008
108042	M2	181.7	0.28
108042	S2	233.2	0.057
108042	N2	155.1	0.059
108042	K1	49.2	0.055
108042	M4	128.2	0.034
108042	O1	130.2	0.034
108042	M6	86.2	0.01
108042	MK3	123.7	0.01
108042	S4	160.8	0.002
108042	MN4	159.7	0.018
108042	S6	73.1	0.003
108042	2N2	131.9	0.042
108042	OO1	66.3	0.003
108042	M1	36.6	0.009
108042	J1	45.8	0.022
108042	Q1	12.1	0.005
108042	2Q1	359.3	0.015
108042	P1	62.7	0.05
108042	2SM2	205.8	0.01
108042	M3	43.6	0.011
108042	L2	216.7	0.01
108042	2MK3	68	0.013
108042	K2	171	0.054
108042	M8	243.3	0.008
108042	MS4	143.9	0.017
108043	M2	203.6	0.37
108043	S2	201.4	0.121
108043	N2	176.3	0.074
108043	K1	175.5	0.055
108043	M4	49.6	0.051
108043	O1	171	0.028
108043	M6	213.7	0.008
108043	MK3	197	0.005
108043	S4	202.6	0.005
108043	MN4	57.5	0.023
108043	S6	249.4	0.002
108043	2N2	171.5	0.037
108043	OO1	3.7	0.009
108043	M1	147.3	0.015
108043	J1	62.2	0.007
108043	Q1	3.1	0.007
108043	2Q1	113.8	0.003
108043	P1	294	0.016
108043	2SM2	38	0.01
108043	M3	281.9	0.011
108043	L2	213.4	0.016
108043	2MK3	329.4	0.014
108043	K2	233.4	0.062
108043	M8	251.8	0.003
108043	MS4	69.4	0.043
108044	M2	200.5	0.327
108044	S2	277	0.079
108044	N2	180	0.065
108044	K1	173.9	0.112
108044	M4	313.2	0.062
108044	O1	195.4	0.028
108044	M6	125.4	0.008
108044	MK3	238.4	0.017
108044	S4	204.1	0.006
108044	MN4	281.4	0.018
108044	S6	31.4	0.008
108044	2N2	47.2	0.004
108044	OO1	209.9	0.013
108044	M1	206.6	0.009
108044	J1	185.1	0.014
108044	Q1	62.9	0.006
108044	2Q1	248.2	0.013
108044	P1	147.8	0.046
108044	2SM2	220	0.013
108044	M3	206.9	0.005
108044	L2	240.3	0.032
108044	2MK3	314	0.007
108044	K2	179.1	0.078
108044	M8	266.8	0.006
108044	MS4	31.3	0.041
108045	M2	54.5	0.402
108045	S2	75.7	0.151
108045	N2	97.5	0.082
108045	K1	314	1.003
108045	M4	340.4	0.082
108045	O1	302.3	0.775
108045	M6	54	0.021
108045	MK3	70.1	0.093
108045	S4	146.8	0.051
108045	MN4	299.2	0.043
108045	S6	149.8	0.011
108045	2N2	140.7	0.01
108045	OO1	291.4	0.045
108045	M1	47	0.004
108045	J1	356.6	0.022
108045	Q1	284.3	0.189
108045	2Q1	219.9	0.005
108045	P1	327.6	0.331
108045	2SM2	176	0.027
108045	M3	126.2	0.031
108045	L2	288.1	0.011
108045	2MK3	14.6	0.075
108045	K2	36.5	0.117
108045	M8	157.6	0.008
108045	MS4	16.1	0.051
108046	M2	56.4	0.486
108046	S2	76.1	0.209
108046	N2	94.6	0.082
108046	K1	317.7	1.224
108046	M4	338.6	0.117
108046	O1	304.8	0.947
108046	M6	52.5	0.031
108046	MK3	83.1	0.124
108046	S4	145.1	0.052
108046	MN4	307.9	0.055
108046	S6	137.8	0.012
108046	2N2	179.6	0.03
108046	OO1	312.8	0.056
108046	M1	134.6	0.013
108046	J1	12.8	0.017
108046	Q1	281.1	0.231
108046	2Q1	45.3	0.011
108046	P1	327.2	0.355
108046	2SM2	196.5	0.034
108046	M3	123.4	0.034
108046	L2	324.1	0.011
108046	2MK3	23.9	0.088
108046	K2	55.3	0.135
108046	M8	195.2	0.006
108046	MS4	15.7	0.052
108047	M2	48.7	0.503
108047	S2	79	0.222
108047	N2	97.2	0.079
108047	K1	320.9	1.241
108047	M4	344.3	0.104
108047	O1	305.2	0.986
108047	M6	61.5	0.038
108047	MK3	95.7	0.149
108047	S4	156.9	0.044
108047	MN4	308.3	0.061
108047	S6	147.8	0.01
108047	2N2	272.9	0.021
108047	OO1	309.2	0.057
108047	M1	139	0.021
108047	J1	65.5	0.008
108047	Q1	283.2	0.225
108047	2Q1	116.7	0.012
108047	P1	320.1	0.322
108047	2SM2	219	0.023
108047	M3	134	0.043
108047	L2	354.7	0.023
108047	2MK3	35.2	0.107
108047	K2	62.9	0.142
108047	M8	187.7	0.016
108047	MS4	1.7	0.062
108048	M2	75.8	0.113
108048	S2	96.1	0.074
108048	N2	125.9	0.026
108048	K1	326.9	0.191
108048	M4	38.1	0.021
108048	O1	296.2	0.158
108048	M6	53.9	0.009
108048	MK3	25.1	0.015
108048	S4	157.4	0.012
108048	MN4	313.9	0.008
108048	S6	143.9	0.008
108048	2N2	38.8	0.027
108048	OO1	278.4	0.023
108048	M1	42.6	0.013
108048	J1	352.9	0.01
108048	Q1	288.1	0.054
108048	2Q1	25.7	0.006
108048	2SM2	55.5	0.002
108048	M3	54.2	0.01
108048	L2	17.2	0.007
108048	2MK3	294.7	0.019
108048	M8	163.2	0.008
108048	MS4	43	0.025
108049	M2	83.3	0.115
108049	S2	113.8	0.094
108049	N2	134.1	0.032
108049	K1	335.4	0.326
108049	M4	35.9	0.033
108049	O1	306.6	0.246
108049	M6	110	0.011
108049	MK3	44.9	0.023
108049	S4	155.2	0.022
108049	MN4	324.7	0.02
108049	S6	186.9	0.002
108049	2N2	46.7	0.008
108049	OO1	321.5	0.022
108049	M1	11.9	0.003
108049	J1	346.7	0.011
108049	Q1	290.9	0.066
108049	2Q1	58.5	0.003
108049	2SM2	245.5	0.012
108049	M3	92.5	0.021
108049	L2	38.5	0.001
108049	2MK3	331.4	0.016
108049	M8	197.3	0.01
108049	MS4	51.2	0.023
108050	M2	80.5	0.117
108050	S2	122	0.053
108050	N2	98.6	0.019
108050	K1	350.7	0.315
108050	M4	8.5	0.028
108050	O1	318.6	0.271
108050	M6	78.3	0.002
108050	MK3	113.8	0.009
108050	S4	156.7	0.009
108050	MN4	338.4	0.015
108050	S6	159.5	0.002
108050	2N2	136.8	0.004
108050	OO1	359.1	0.029
108050	M1	254.3	0.005
108050	J1	336.5	0.014
108050	Q1	281.4	0.053
108050	2Q1	63.6	0.011
108050	2SM2	87.3	0.005
108050	M3	290.1	0.003
108050	L2	292.5	0.006
108050	2MK3	78.5	0.018
108050	M8	231.3	0.005
108050	MS4	42.6	0.017
108051	M2	46.6	0.168
108051	S2	75.9	0.096
108051	N2	112.8	0.016
108051	K1	335.4	0.304
108051	M4	341.6	0.032
108051	O1	298.4	0.213
108051	M6	71.5	0.015
108051	MK3	70.4	0.03
108051	S4	113.1	0.021
108051	MN4	292.9	0.009
108051	S6	158.5	0.007
108051	2N2	347.1	0.016
108051	OO1	251.5	0.027
108051	M1	300.2	0.004
108051	J1	291	0.018
108051	Q1	274.2	0.074
108051	2Q1	152.8	0.012
108051	P1	105.6	0.062
108051	2SM2	204.2	0.018
108051	M3	27.4	0.009
108051	L2	340.4	0.009
108051	2MK3	354.1	0.012
108051	K2	92.5	0.014
108051	M8	141.7	0.009
108051	MS4	47.1	0.028
108052	M2	59.5	0.172
108052	S2	98.9	0.077
108052	N2	136.5	0.027
108052	K1	322	0.36
108052	M4	351.8	0.021
108052	O1	300.1	0.259
108052	M6	44.5	0.018
108052	MK3	64.4	0.033
108052	S4	122.1	0.029
108052	MN4	284.2	0.017
108052	S6	166.6	0.006
108052	2N2	48.6	0.019
108052	OO1	275.1	0.034
108052	M1	33.2	0.002
108052	J1	57.3	0.003
108052	Q1	282	0.071
108052	2Q1	190.9	0.014
108052	P1	357.3	0.043
108052	2SM2	159.4	0.017
108052	M3	44.3	0.017
108052	L2	351.5	0.012
108052	2MK3	357.1	0.01
108052	K2	29.7	0.027
108052	M8	163.3	0.001
108052	MS4	55.6	0.034
108053	M2	52.7	0.148
108053	S2	78.5	0.059
108053	N2	92.3	0.041
108053	K1	314.6	0.373
108053	M4	350.9	0.041
108053	O1	303.7	0.329
108053	M6	33.2	0.018
108053	MK3	90.4	0.05
108053	S4	141.1	0.019
108053	MN4	312.3	0.024
108053	S6	112.2	0.009
108053	2N2	73.4	0.01
108053	OO1	319.4	0.035
108053	M1	220.7	0.004
108053	J1	52.9	0.005
108053	Q1	284	0.068
108053	2Q1	315.4	0.007
108053	P1	306.1	0.121
108053	2SM2	262.9	0.01
108053	M3	97.7	0.024
108053	L2	352.5	0.016
108053	2MK3	39.5	0.046
108053	K2	56.1	0.064
108053	M8	225.2	0.005
108053	MS4	10.1	0.019
108054	M2	57.1	0.11
108054	S2	105.7	0.068
108054	N2	111	0.038
108054	K1	329.8	0.291
108054	M4	40.5	0.015
108054	O1	313.5	0.232
108054	M6	214.7	0.006
108054	MK3	167.5	0.012
108054	S4	120.8	0.014
108054	MN4	359.8	0.012
108054	S6	17.6	0.002
108054	2N2	327	0.02
108054	OO1	14.9	0.002
108054	M1	265.2	0.009
108054	J1	321	0.011
108054	Q1	284.7	0.062
108054	2Q1	203.9	0.019
108054	P1	332.9	0.069
108054	2SM2	355.5	0.005
108054	M3	343.5	0.005
108054	L2	34.8	0.01
108054	2MK3	117.5	0.026
108054	K2	295.9	0.008
108054	M8	59.5	0.002
108054	MS4	26.1	0.027
108055	M2	68.9	0.129
108055	S2	118.3	0.088
108055	N2	115.9	0.038
108055	K1	329.2	0.331
108055	M4	28.6	0.021
108055	O1	314.8	0.276
108055	M6	167.7	0.004
108055	MK3	105	0.015
108055	S4	186.9	0.01
108055	MN4	34.3	0.011
108055	S6	313.1	0.001
108055	2N2	324.1	0.007
108055	OO1	307	0.012
108055	M1	189.7	0.01
108055	J1	319.9	0.009
108055	Q1	290.9	0.072
108055	2Q1	169.4	0.009
108055	P1	312.9	0.086
108055	2SM2	306.2	0.013
108055	M3	344.4	0.006
108055	L2	282.3	0.001
108055	2MK3	88.2	0.032
108055	K2	153.2	0.004
108055	M8	291.5	0.001
108055	MS4	26.7	0.016
108056	M2	69.5	0.125
108056	S2	108.1	0.063
108056	N2	125.8	0.029
108056	K1	335.8	0.379
108056	M4	353.8	0.023
108056	O1	315	0.288
108056	M6	62.7	0.016
108056	MK3	87.9	0.044
108056	S4	181.9	0.014
108056	MN4	325.2	0.008
108056	S6	101.9	0.004
108056	2N2	190.3	0.004
108056	OO1	303.8	0.025
108056	M1	126.8	0.024
108056	J1	258.4	0.011
108056	Q1	289.8	0.066
108056	2Q1	181.9	0.006
108056	P1	341.4	0.065
108056	2SM2	158.7	0.015
108056	M3	107.7	0.012
108056	L2	283.5	0.011
108056	2MK3	46.9	0.043
108056	K2	55.3	0.035
108056	M8	182.6	0.004
108056	MS4	57.4	0.019
108057	M2	23.5	0.087
108057	S2	62.5	0.061
108057	N2	63.2	0.012
108057	K1	253.2	0.141
108057	M4	303.1	0.027
108057	O1	228.4	0.12
108057	M6	46.4	0.017
108057	MK3	43.8	0.046
108057	S4	120.7	0.018
108057	MN4	284.9	0.015
108057	S6	145.3	0.003
108057	2N2	102.9	0.027
108057	OO1	283.1	0.029
108057	M1	335.2	0.01
108057	J1	323.8	0.02
108057	Q1	206.1	0.014
108057	2Q1	267.3	0.007
108057	2SM2	165	0.003
108057	M3	140.5	0.008
108057	L2	153.7	0.009
108057	2MK3	350.3	0.044
108057	M8	309.2	0.003
108057	MS4	43.8	0.006
108058	M2	51.7	0.095
108058	S2	88.5	0.097
108058	N2	125.9	0.018
108058	K1	302.3	0.208
108058	M4	323.4	0.035
108058	O1	282.2	0.164
108058	M6	66.2	0.014
108058	MK3	47	0.071
108058	S4	158.5	0.026
108058	MN4	272.9	0.026
108058	S6	149.9	0.007
108058	2N2	111.2	0.044
108058	OO1	329.1	0.029
108058	M1	71.1	0.016
108058	J1	310.6	0.01
108058	Q1	242.7	0.034
108058	2Q1	340.3	0.017
108058	2SM2	181.6	0.014
108058	M3	89.5	0.01
108058	L2	201.7	0.011
108058	2MK3	347.8	0.064
108058	M8	177.3	0.005
108058	MS4	81.6	0.009
108059	M2	63.8	0.067
108059	S2	106.7	0.105
108059	N2	188.8	0.006
108059	K1	332.9	0.276
108059	M4	330.5	0.055
108059	O1	301.1	0.225
108059	M6	73.7	0.016
108059	MK3	78.3	0.079
108059	S4	145.3	0.028
108059	MN4	305.1	0.031
108059	S6	10.5	0.002
108059	2N2	126.1	0.032
108059	OO1	341.2	0.034
108059	M1	132.7	0.017
108059	J1	242.7	0.02
108059	Q1	237.9	0.022
108059	2Q1	327.1	0.011
108059	2SM2	188.1	0.02
108059	M3	72.9	0.029
108059	L2	181.9	0.013
108059	2MK3	351.2	0.062
108059	M8	182	0.007
108059	MS4	50.7	0.02
108060	M2	60.3	0.119
108060	S2	106.9	0.084
108060	N2	95.7	0.028
108060	K1	334.6	0.294
108060	M4	321.7	0.03
108060	O1	312.9	0.246
108060	M6	94.9	0.011
108060	MK3	92.9	0.043
108060	S4	166.5	0.018
108060	MN4	285	0.025
108060	S6	98.4	0.002
108060	2N2	112.2	0.017
108060	OO1	332.9	0.019
108060	M1	75.2	0.014
108060	J1	300.9	0.005
108060	Q1	265.8	0.05
108060	2Q1	29	0.013
108060	2SM2	187.5	0.007
108060	M3	177.3	0.009
108060	L2	351.8	0.004
108060	2MK3	53.5	0.025
108060	M8	259.5	0.004
108060	MS4	74	0.02
108061	M2	58.5	0.13
108061	S2	106.6	0.083
108061	N2	101.3	0.011
108061	K1	334.6	0.314
108061	M4	357	0.045
108061	O1	312	0.263
108061	M6	94.4	0.008
108061	MK3	99.5	0.058
108061	S4	183.8	0.023
108061	MN4	327.6	0.022
108061	S6	6.5	0.005
108061	2N2	208.4	0.03
108061	OO1	329.4	0.019
108061	M1	13.4	0.012
108061	J1	49.4	0.019
108061	Q1	285.6	0.05
108061	2Q1	264.4	0.009
108061	2SM2	283.1	0.003
108061	M3	179.1	0.012
108061	L2	144.3	0.006
108061	2MK3	20.4	0.043
108061	M8	186.3	0.008
108061	MS4	37.8	0.024
108062	M2	78.2	0.134
108062	S2	115.8	0.102
108062	N2	99.5	0.025
108062	K1	342.7	0.371
108062	M4	31.5	0.032
108062	O1	311.7	0.283
108062	M6	68.8	0.008
108062	MK3	80.6	0.03
108062	S4	194.2	0.019
108062	MN4	343.5	0.024
108062	S6	259.2	0.011
108062	2N2	268.2	0.005
108062	OO1	312.9	0.014
108062	M1	278.7	0.005
108062	J1	343.4	0.01
108062	Q1	298.9	0.078
108062	2Q1	42	0.004
108062	2SM2	228.4	0.02
108062	M3	204	0.013
108062	L2	173.9	0.005
108062	2MK3	22.8	0.03
108062	M8	152.8	0.01
108062	MS4	36	0.02
108063	M2	73.6	0.1
108063	S2	103.9	0.087
108063	N2	162.3	0.017
108063	K1	333	0.222
108063	M4	351.9	0.031
108063	O1	304	0.169
108063	M6	138.6	0.008
108063	MK3	91	0.026
108063	S4	177.9	0.018
108063	MN4	308.4	0.018
108063	S6	223.9	0.007
108063	2N2	27.6	0.014
108063	OO1	355.2	0.008
108063	M1	39.6	0.012
108063	J1	38.6	0.019
108063	Q1	313.7	0.027
108063	2Q1	27.7	0.015
108063	2SM2	160.5	0.008
108063	M3	146.2	0.009
108063	L2	251.3	0.001
108063	2MK3	16.1	0.025
108063	M8	262.6	0.004
108063	MS4	35.3	0.012
108064	M2	204.9	1.948
108064	S2	245.6	0.703
108064	N2	184.7	0.418
108064	K1	183.3	0.255
108064	M4	53.7	0.245
108064	O1	168.1	0.152
108064	M6	24.3	0.108
108064	S4	97.4	0.01
108064	NU2	187.5	0.081
108064	S6	166.5	0.006
108064	2N2	164.5	0.056
108064	OO1	198.4	0.007
108064	LDA2	223.9	0.014
108064	M1	175.7	0.011
108064	J1	190.8	0.012
108064	RHO1	161.7	0.006
108064	Q1	160.6	0.029
108064	T2	244	0.041
108064	R2	247.2	0.006
108064	2Q1	153.2	0.004
108064	P1	182.2	0.084
108064	L2	184.7	0.06
108064	K2	248.9	0.191
108064	M8	289.2	0.041
108065	M2	204.6	2.317
108065	S2	245.2	0.813
108065	N2	184.2	0.462
108065	K1	181.3	0.295
108065	M4	54.2	0.302
108065	O1	162.4	0.164
108065	M6	23.6	0.115
108065	S4	107.2	0.007
108065	NU2	187	0.09
108065	S6	179.6	0.006
108065	2N2	163.8	0.061
108065	OO1	200.3	0.007
108065	LDA2	223.5	0.016
108065	M1	171.9	0.012
108065	J1	190.7	0.013
108065	RHO1	154.3	0.006
108065	Q1	153	0.032
108065	T2	243.6	0.048
108065	R2	246.8	0.007
108065	2Q1	143.6	0.004
108065	P1	180	0.098
108065	L2	184.2	0.066
108065	K2	248.5	0.221
108065	M8	296.5	0.06
108066	M2	202.7	2.508
108066	S2	240.3	0.853
108066	N2	178.1	0.456
108066	K1	173.7	0.285
108066	M4	68.1	0.36
108066	O1	136.1	0.144
108066	M6	344.4	0.077
108066	S4	227.9	0.022
108066	NU2	181.4	0.088
108066	S6	218.1	0.006
108066	2N2	153.5	0.061
108066	OO1	211.2	0.006
108066	LDA2	220.2	0.018
108066	M1	154.9	0.01
108066	J1	192.3	0.011
108066	RHO1	120	0.005
108066	Q1	117.5	0.028
108066	T2	238.8	0.05
108066	R2	241.8	0.007
108066	2Q1	98.9	0.004
108066	P1	170.9	0.094
108066	L2	178.1	0.065
108066	K2	243.3	0.232
108066	M8	313.8	0.087
108067	M2	203.5	1.829
108067	S2	242.2	0.604
108067	N2	182.9	0.355
108067	K1	191.9	0.224
108067	M4	261.1	0.293
108067	O1	185	0.193
108067	M6	33.5	0.09
108067	S4	16.2	0.031
108067	NU2	185.7	0.069
108067	S6	225.1	0.017
108067	2N2	162.2	0.047
108067	OO1	198.7	0.008
108067	LDA2	221.5	0.013
108067	M1	188.5	0.014
108067	J1	195.3	0.015
108067	RHO1	182.1	0.007
108067	Q1	181.6	0.037
108067	T2	242.1	0.036
108067	R2	242.1	0.005
108067	2Q1	178.2	0.005
108067	P1	191.9	0.074
108067	L2	224.2	0.051
108067	K2	242.1	0.164
108067	M8	187.2	0.055
108068	M2	203.4	2.036
108068	S2	241.9	0.664
108068	N2	182.9	0.395
108068	K1	192.1	0.245
108068	M4	261.7	0.312
108068	O1	184.3	0.207
108068	M6	37.8	0.108
108068	S4	12.4	0.028
108068	NU2	185.7	0.077
108068	S6	224.8	0.017
108068	2N2	162.3	0.053
108068	OO1	199.8	0.009
108068	LDA2	221.3	0.014
108068	M1	188.2	0.015
108068	J1	195.9	0.016
108068	RHO1	181.1	0.008
108068	Q1	180.5	0.04
108068	T2	241.8	0.039
108068	R2	241.8	0.005
108068	2Q1	176.6	0.005
108068	P1	192.1	0.081
108068	L2	224	0.057
108068	K2	241.8	0.181
108068	M8	188.3	0.064
108069	M2	203.1	2.222
108069	S2	241.2	0.718
108069	N2	182.7	0.431
108069	K1	192.2	0.259
108069	M4	259.8	0.336
108069	O1	182.2	0.209
108069	M6	39.9	0.121
108069	S4	352.4	0.027
108069	NU2	185.5	0.084
108069	S6	200.7	0.017
108069	2N2	162.4	0.057
108069	OO1	202.3	0.009
108069	LDA2	220.8	0.016
108069	M1	187.3	0.015
108069	J1	197.2	0.016
108069	RHO1	178	0.008
108069	Q1	177.2	0.04
108069	T2	241.2	0.042
108069	R2	241.1	0.006
108069	2Q1	172.3	0.005
108069	P1	192.3	0.086
108069	L2	223.5	0.062
108069	K2	241.1	0.195
108069	M8	186.9	0.072
108070	M2	128	5.484
108070	S2	158.8	1.637
108070	N2	105.8	1.115
108070	K1	127.2	0.187
108070	M4	239.8	0.354
108070	O1	117.8	0.094
108070	M6	241.7	0.325
108070	S4	241.9	0.03
108070	NU2	108.8	0.216
108070	S6	341.3	0.016
108070	2N2	83.5	0.148
108070	OO1	136.7	0.004
108070	LDA2	142.3	0.038
108070	M1	122.5	0.007
108070	J1	131.9	0.007
108070	RHO1	113.8	0.004
108070	Q1	113.1	0.018
108070	T2	157.5	0.097
108070	R2	160	0.013
108070	2Q1	108.5	0.002
108070	P1	126.6	0.062
108070	L2	105.8	0.159
108070	K2	161.2	0.445
108070	M8	3.9	0.025
108071	M2	128	5.499
108071	S2	158.8	1.638
108071	N2	105.7	1.117
108071	K1	128.2	0.187
108071	M4	240.1	0.353
108071	O1	118.8	0.092
108071	M6	242	0.325
108071	S4	241.1	0.029
108071	NU2	108.8	0.217
108071	S6	338.5	0.017
108071	2N2	83.4	0.149
108071	OO1	137.6	0.004
108071	LDA2	142.4	0.038
108071	M1	123.5	0.007
108071	J1	132.9	0.007
108071	RHO1	114.8	0.003
108071	Q1	114.1	0.018
108071	T2	157.6	0.097
108071	R2	160	0.013
108071	2Q1	109.5	0.002
108071	P1	127.5	0.062
108071	L2	105.7	0.16
108071	K2	161.3	0.445
108071	M8	2.7	0.023
108072	M2	128.1	5.506
108072	S2	158.8	1.637
108072	N2	105.8	1.118
108072	K1	129.4	0.186
108072	M4	240.3	0.353
108072	O1	119.8	0.091
108072	M6	242.1	0.323
108072	S4	235.3	0.028
108072	NU2	108.8	0.217
108072	S6	331.1	0.017
108072	2N2	83.6	0.149
108072	OO1	139	0.004
108072	LDA2	142.4	0.039
108072	M1	124.6	0.006
108072	J1	134.1	0.007
108072	RHO1	115.7	0.003
108072	Q1	115	0.018
108072	T2	157.6	0.097
108072	R2	160	0.013
108072	2Q1	110.3	0.002
108072	P1	128.7	0.062
108072	L2	105.8	0.16
108072	K2	161.3	0.445
108072	M8	3.1	0.023
108073	M2	143.6	1.132
108073	S2	175.3	0.343
108073	N2	114.6	0.207
108073	K1	129.5	0.131
108073	M4	18.5	0.045
108073	O1	214.3	0.068
108073	M6	242.2	0.067
108073	S4	164.7	0.025
108073	NU2	118.6	0.04
108073	S6	240.4	0.007
108073	2N2	85.7	0.028
108073	OO1	44.6	0.003
108073	LDA2	158.3	0.008
108073	M1	171.9	0.005
108073	J1	87.4	0.005
108073	RHO1	250.7	0.003
108073	Q1	256.3	0.013
108073	T2	174	0.02
108073	R2	176.5	0.003
108073	2Q1	298.4	0.002
108073	P1	135.9	0.043
108073	L2	114.6	0.03
108073	K2	177.8	0.093
108073	M8	149.7	0.021
108074	M2	143.7	1.091
108074	S2	173.3	0.333
108074	N2	110	0.211
108074	K1	122.9	0.112
108074	M4	9.6	0.073
108074	O1	226.1	0.058
108074	M6	253.8	0.069
108074	S4	149.8	0.025
108074	NU2	114.6	0.041
108074	S6	235.8	0.009
108074	2N2	76.3	0.028
108074	OO1	19.7	0.002
108074	LDA2	157.4	0.008
108074	M1	174.5	0.004
108074	J1	71.7	0.005
108074	RHO1	270.4	0.002
108074	Q1	277.2	0.011
108074	T2	172.1	0.02
108074	R2	174.4	0.003
108074	2Q1	328.4	0.002
108074	P1	130.7	0.037
108074	L2	110	0.03
108074	K2	175.7	0.091
108074	M8	144.5	0.027
108075	M2	194.6	0.807
108075	S2	213.6	0.175
108075	N2	150.7	0.177
108075	K1	301.3	0.228
108075	M4	338.7	0.038
108075	O1	260.8	0.209
108075	M6	331.8	0.018
108075	S4	125.5	0.002
108075	NU2	156.6	0.034
108075	S6	43.4	0.004
108075	2N2	106.8	0.024
108075	OO1	341.9	0.009
108075	LDA2	203.5	0.006
108075	M1	281.1	0.015
108075	J1	321.5	0.016
108075	RHO1	243.4	0.008
108075	Q1	240.6	0.04
108075	T2	212.9	0.01
108075	R2	214.3	0.001
108075	2Q1	220.5	0.005
108075	P1	298.3	0.075
108075	L2	150.7	0.025
108075	K2	215.1	0.048
108075	M8	223.8	0.013
108076	M2	193.6	0.864
108076	S2	215	0.186
108076	N2	153.7	0.184
108076	K1	299	0.235
108076	M4	324	0.017
108076	O1	259.8	0.217
108076	M6	23.3	0.009
108076	S4	117.5	0.005
108076	NU2	159.1	0.036
108076	S6	353	0.006
108076	2N2	113.8	0.024
108076	OO1	338.3	0.009
108076	LDA2	203.5	0.006
108076	M1	279.4	0.015
108076	J1	318.5	0.017
108076	RHO1	243	0.008
108076	Q1	240.3	0.042
108076	T2	214.1	0.011
108076	R2	215.8	0.001
108076	2Q1	220.8	0.006
108076	P1	296.1	0.078
108076	L2	153.7	0.026
108076	K2	216.7	0.051
108076	M8	126.5	0.006
108077	M2	203.9	1.153
108077	S2	234.5	0.401
108077	N2	177.3	0.239
108077	K1	171.7	0.385
108077	M4	344.1	0.088
108077	O1	140.9	0.242
108077	M6	218.6	0.02
108077	S4	325.9	0.011
108077	NU2	181	0.046
108077	S6	315.5	0.002
108077	2N2	150.8	0.032
108077	OO1	202.5	0.01
108077	LDA2	218.2	0.008
108077	M1	156.3	0.017
108077	J1	187	0.019
108077	RHO1	127.8	0.009
108077	Q1	125.7	0.047
108077	T2	233.3	0.024
108077	R2	235.7	0.003
108077	2Q1	110.4	0.006
108077	P1	169.4	0.127
108077	L2	177.4	0.034
108077	K2	237	0.109
108077	M8	330.9	0.022
108078	M2	120.8	1.026
108078	S2	147	0.29
108078	N2	96	0.17
108078	K1	52.7	0.026
108078	M4	68.1	0.074
108078	O1	75.9	0.014
108078	M6	274.1	0.07
108078	S4	266.3	0.008
108078	NU2	99.3	0.033
108078	S6	295.3	0.007
108078	2N2	71.2	0.023
108078	OO1	29.6	0.001
108078	LDA2	132.9	0.007
108078	M1	64.3	0.001
108078	J1	41.2	0.001
108078	RHO1	85.9	0.001
108078	Q1	87.4	0.003
108078	T2	145.9	0.017
108078	R2	147.9	0.002
108078	P1	54.5	0.009
108078	L2	96	0.024
108078	K2	149	0.079
108078	M8	178.1	0.02
108079	M2	122.1	0.988
108079	S2	148	0.292
108079	N2	96.7	0.165
108079	K1	100.6	0.027
108079	M4	26.8	0.122
108079	O1	31.9	0.009
108079	M6	276.7	0.083
108079	S4	164.1	0.008
108079	NU2	100.2	0.032
108079	S6	21.8	0.011
108079	2N2	71.4	0.022
108079	LDA2	134.1	0.007
108079	M1	66.3	0.001
108079	J1	134.6	0.001
108079	Q1	357.9	0.002
108079	T2	146.9	0.017
108079	R2	148.9	0.002
108079	P1	95.5	0.009
108079	L2	96.7	0.024
108079	K2	150	0.079
108079	M8	160.9	0.026
108080	M2	124.3	0.944
108080	S2	151.1	0.287
108080	N2	103.1	0.159
108080	K1	227.1	0.02
108080	M4	26.4	0.128
108080	O1	117.7	0.015
108080	M6	275.6	0.086
108080	S4	133.6	0.015
108080	NU2	106	0.031
108080	S6	84.5	0.013
108080	2N2	81.8	0.021
108080	OO1	336.4	0.001
108080	LDA2	136.8	0.007
108080	M1	172.4	0.001
108080	J1	281.3	0.001
108080	RHO1	70.8	0.001
108080	Q1	63.4	0.003
108080	T2	150	0.017
108080	R2	152	0.002
108080	P1	218.9	0.007
108080	L2	103.1	0.023
108080	K2	153.2	0.078
108080	M8	165.9	0.03
108081	M2	125.4	1.803
108081	S2	153.8	0.505
108081	N2	105.6	0.3
108081	K1	107.7	0.029
108081	M4	164.3	0.046
108081	O1	135.4	0.018
108081	M6	258.7	0.188
108081	S4	149.8	0.01
108081	NU2	108.3	0.058
108081	S6	189.3	0.003
108081	2N2	85.8	0.04
108081	OO1	80.1	0.001
108081	LDA2	138.6	0.013
108081	M1	121.6	0.001
108081	J1	94	0.001
108081	RHO1	147.3	0.001
108081	Q1	149.1	0.004
108081	T2	152.6	0.03
108081	R2	154.8	0.004
108081	P1	109.8	0.009
108081	L2	105.6	0.043
108081	K2	156	0.137
108081	M8	296.3	0.005
108082	M2	125.4	2.159
108082	S2	154.4	0.624
108082	N2	105.9	0.362
108082	K1	100.8	0.041
108082	M4	139.9	0.019
108082	O1	129.3	0.024
108082	M6	264.7	0.187
108082	S4	219.1	0.006
108082	NU2	108.5	0.07
108082	S6	302.8	0.006
108082	2N2	86.4	0.048
108082	OO1	72.3	0.001
108082	LDA2	138.9	0.015
108082	M1	115	0.002
108082	J1	86.6	0.002
108082	RHO1	141.5	0.001
108082	Q1	143.4	0.005
108082	T2	153.2	0.037
108082	R2	155.5	0.005
108082	2Q1	157.5	0.001
108082	P1	102.9	0.013
108082	L2	105.9	0.052
108082	K2	156.7	0.17
108082	M8	275.2	0.006
108083	M2	126.9	2.006
108083	S2	155.3	0.528
108083	N2	110.7	0.309
108083	K1	197.7	0.094
108083	M4	33.6	0.105
108083	O1	246.4	0.079
108083	M6	248.2	0.145
108083	S4	72	0.021
108083	NU2	112.9	0.06
108083	S6	227.2	0.002
108083	2N2	94.4	0.041
108083	OO1	149.1	0.003
108083	LDA2	140.1	0.014
108083	M1	222.1	0.006
108083	J1	173.6	0.006
108083	RHO1	267.4	0.003
108083	Q1	270.6	0.015
108083	T2	154.1	0.031
108083	R2	156.3	0.004
108083	2Q1	294.7	0.002
108083	P1	201.4	0.031
108083	L2	110.7	0.044
108083	K2	157.5	0.144
108083	M8	235	0.033
108084	M2	152.1	0.649
108084	S2	180.6	0.189
108084	N2	128.9	0.123
108084	K1	167.4	0.036
108084	M4	149.3	0.072
108084	O1	138.5	0.026
108084	M6	339.6	0.018
108084	S4	336.8	0.008
108084	NU2	132.1	0.024
108084	S6	271	0.003
108084	2N2	105.8	0.016
108084	OO1	196.4	0.001
108084	LDA2	165.4	0.005
108084	M1	153	0.002
108084	J1	181.8	0.002
108084	RHO1	126.1	0.001
108084	Q1	124.1	0.005
108084	T2	179.4	0.011
108084	R2	181.7	0.002
108084	2Q1	109.8	0.001
108084	P1	165.3	0.012
108084	L2	128.9	0.018
108084	K2	182.9	0.052
108084	M8	315.1	0.023
108085	M2	151.4	0.671
108085	S2	178	0.187
108085	N2	129.5	0.13
108085	K1	161.9	0.034
108085	M4	163.1	0.052
108085	O1	140.9	0.026
108085	M6	338.9	0.013
108085	S4	340.3	0.008
108085	NU2	132.5	0.025
108085	S6	289.7	0.002
108085	2N2	107.6	0.017
108085	OO1	182.9	0.001
108085	LDA2	163.8	0.005
108085	M1	151.4	0.002
108085	J1	172.3	0.002
108085	RHO1	132	0.001
108085	Q1	130.5	0.005
108085	T2	177	0.011
108085	R2	179	0.001
108085	2Q1	120.1	0.001
108085	P1	160.4	0.011
108085	L2	129.5	0.019
108085	K2	180.2	0.051
108085	M8	321.8	0.023
108086	M2	145.8	0.603
108086	S2	169.7	0.166
108086	N2	124.1	0.115
108086	K1	124.2	0.024
108086	M4	109.9	0.067
108086	O1	59.7	0.006
108086	M6	124.6	0.018
108086	S4	28.9	0.008
108086	NU2	127	0.022
108086	S6	358.4	0.003
108086	2N2	102.4	0.015
108086	LDA2	156.9	0.004
108086	J1	156.2	0.001
108086	Q1	27.7	0.001
108086	T2	168.8	0.01
108086	R2	170.6	0.001
108086	P1	119.4	0.008
108086	L2	124.1	0.016
108086	K2	171.6	0.045
108086	M8	338.2	0.021
108087	M2	181.4	0.428
108087	S2	215.1	0.114
108087	N2	173.1	0.071
108087	K1	250.9	0.082
108087	M4	206	0.055
108087	O1	210.4	0.073
108087	M6	250.6	0.017
108087	S4	278.8	0.004
108087	NU2	174.3	0.014
108087	S6	184.8	0.002
108087	2N2	164.8	0.009
108087	OO1	291.5	0.003
108087	LDA2	197.1	0.003
108087	M1	230.7	0.005
108087	J1	271.1	0.006
108087	RHO1	193	0.003
108087	Q1	190.3	0.014
108087	T2	213.7	0.007
108087	R2	216.4	0.001
108087	2Q1	170.2	0.002
108087	P1	247.9	0.027
108087	L2	173.1	0.01
108087	K2	217.8	0.031
108087	M8	242.5	0.012
108088	M2	196.3	0.495
108088	S2	230.4	0.159
108088	N2	169.6	0.069
108088	K1	269.3	0.089
108088	M4	221	0.043
108088	O1	228.3	0.078
108088	M6	216.7	0.015
108088	S4	281.6	0.003
108088	NU2	173.3	0.013
108088	S6	75.6	0.005
108088	2N2	143	0.009
108088	OO1	310.3	0.003
108088	LDA2	212.1	0.003
108088	M1	248.8	0.006
108088	J1	289.6	0.006
108088	RHO1	210.8	0.003
108088	Q1	208	0.015
108088	T2	229	0.009
108088	R2	231.7	0.001
108088	2Q1	187.7	0.002
108088	P1	266.3	0.029
108088	L2	169.6	0.01
108088	K2	233.1	0.043
108088	M8	208	0.007
108089	M2	202.4	0.51
108089	S2	237.3	0.16
108089	N2	168	0.067
108089	K1	283.7	0.096
108089	M4	221.6	0.035
108089	O1	240.3	0.08
108089	M6	195.9	0.017
108089	S4	41.2	0.004
108089	NU2	172.6	0.013
108089	S6	126.9	0.004
108089	2N2	133.5	0.009
108089	OO1	327.2	0.003
108089	LDA2	218.6	0.004
108089	M1	262	0.006
108089	J1	305.3	0.006
108089	RHO1	221.8	0.003
108089	Q1	218.8	0.015
108089	T2	235.9	0.009
108089	R2	238.6	0.001
108089	2Q1	197.3	0.002
108089	P1	280.5	0.032
108089	L2	168	0.01
108089	K2	240.1	0.043
108089	M8	170.8	0.009
108090	M2	205.6	1.622
108090	S2	239	0.558
108090	N2	185.9	0.31
108090	K1	193.2	0.274
108090	M4	251.7	0.342
108090	O1	180.1	0.191
108090	M6	335.8	0.055
108090	S4	324.3	0.019
108090	NU2	188.6	0.06
108090	S6	1	0.006
108090	2N2	166.2	0.041
108090	OO1	206.3	0.008
108090	LDA2	221.2	0.011
108090	M1	186.7	0.014
108090	J1	199.7	0.015
108090	RHO1	174.5	0.007
108090	Q1	173.6	0.037
108090	T2	237.7	0.033
108090	R2	240.3	0.004
108090	2Q1	167.1	0.005
108090	P1	192.3	0.091
108090	L2	185.9	0.044
108090	K2	241.7	0.152
108090	M8	77.4	0.044
108091	M2	128.7	1.173
108091	S2	146.7	0.329
108091	N2	110	0.279
108091	K1	86.2	0.11
108091	M4	9.6	0.124
108091	O1	49.3	0.057
108091	M6	108.4	0.018
108091	MK3	255	0.017
108091	S4	316.6	0.019
108091	MN4	311.1	0.056
108091	S6	33.3	0.007
108091	2N2	111.7	0.069
108091	OO1	60	0.01
108091	M1	96.3	0.007
108091	J1	108.5	0.004
108091	Q1	308.5	0.008
108091	2Q1	187.5	0.009
108091	P1	324.9	0.046
108091	2SM2	112.7	0.032
108091	M3	174.6	0.018
108091	L2	39	0.024
108091	2MK3	268	0.018
108091	K2	184.8	0.028
108091	M8	183.6	0.016
108091	MS4	350.6	0.036
108092	M2	181.6	0.86
108092	S2	204.2	0.35
108092	N2	154.9	0.147
108092	K1	93.6	0.234
108092	M4	237.4	0.017
108092	O1	73.5	0.155
108092	M6	281.9	0.034
108092	MK3	346.6	0.008
108092	S4	197.8	0.007
108092	MN4	150.2	0.017
108092	S6	39	0.003
108092	2N2	77.9	0.056
108092	OO1	41.3	0.006
108092	M1	269.3	0.033
108092	J1	44.6	0.015
108092	Q1	90.6	0.01
108092	2Q1	247.1	0.003
108092	P1	344.8	0.039
108092	2SM2	327	0.02
108092	M3	229.6	0.038
108092	L2	190.3	0.099
108092	2MK3	37.7	0.011
108092	K2	158.3	0.118
108092	M8	3	0.015
108092	MS4	6.7	0.022
108093	M2	182.7	0.777
108093	S2	206	0.287
108093	N2	150.8	0.128
108093	K1	83.9	0.2
108093	M4	140.1	0.045
108093	O1	73.3	0.125
108093	M6	255.3	0.044
108093	MK3	13.5	0.028
108093	S4	163.6	0.008
108093	MN4	127.7	0.025
108093	S6	16	0.009
108093	2N2	80	0.065
108093	OO1	28.2	0.008
108093	M1	273.4	0.023
108093	J1	72.2	0.024
108093	Q1	104.8	0.01
108093	2Q1	137	0.002
108093	P1	290.4	0.057
108093	2SM2	353.8	0.019
108093	M3	233.8	0.025
108093	L2	200.4	0.085
108093	2MK3	7.9	0.027
108093	K2	170	0.102
108093	M8	6.9	0.004
108093	MS4	118.7	0.024
108094	M2	146.7	2.509
108094	S2	171.3	0.774
108094	N2	120.6	0.531
108094	K1	85.8	0.267
108094	M4	343.2	0.406
108094	O1	64.7	0.173
108094	M6	23.8	0.046
108094	MK3	257.5	0.09
108094	S4	277.4	0.008
108094	MN4	324.9	0.138
108094	S6	341.1	0.017
108094	2N2	82.4	0.125
108094	OO1	21.8	0.012
108094	M1	273.4	0.008
108094	J1	59.6	0.014
108094	Q1	53.6	0.026
108094	2Q1	25.2	0.005
108094	P1	282.8	0.03
108094	2SM2	75.3	0.04
108094	M3	222	0.043
108094	L2	162.9	0.116
108094	2MK3	212.2	0.03
108094	K2	160	0.199
108094	M8	115.5	0.037
108094	MS4	349.2	0.201
108095	M2	150.9	1.836
108095	S2	182	0.625
108095	N2	135.2	0.355
108095	K1	97.2	0.371
108095	M4	259.3	0.258
108095	O1	69.3	0.248
108095	M6	23.3	0.117
108095	MK3	195.3	0.072
108095	S4	165	0.022
108095	MN4	246.4	0.077
108095	S6	213.1	0.009
108095	2N2	84.7	0.098
108095	OO1	53.5	0.03
108095	M1	297	0.027
108095	J1	92.5	0.008
108095	Q1	72.8	0.041
108095	2Q1	287.6	0.036
108095	P1	355.5	0.036
108095	2SM2	352.7	0.023
108095	M3	225.7	0.025
108095	L2	173.9	0.122
108095	2MK3	126.3	0.053
108095	K2	167	0.221
108095	M8	110.3	0.026
108095	MS4	271.9	0.153
108096	M2	149	1.514
108096	S2	175.8	0.553
108096	N2	135.3	0.294
108096	K1	97.8	0.33
108096	M4	318.7	0.179
108096	O1	72.7	0.211
108096	M6	55.3	0.205
108096	MK3	245.7	0.032
108096	S4	168.2	0.05
108096	MN4	323	0.072
108096	S6	212.7	0.015
108096	2N2	108.2	0.096
108096	OO1	61.8	0.027
108096	M1	223.4	0.015
108096	J1	135.7	0.026
108096	Q1	61.1	0.034
108096	2Q1	282	0.025
108096	P1	2.9	0.051
108096	2SM2	76.1	0.065
108096	M3	205.4	0.028
108096	L2	166.7	0.041
108096	2MK3	172.8	0.021
108096	K2	167.5	0.14
108096	M8	119.6	0.068
108096	MS4	301.9	0.1
108097	M2	147.3	3.045
108097	S2	174.2	1.128
108097	N2	119.4	0.581
108097	K1	89.3	0.318
108097	M4	135.1	0.21
108097	O1	74.6	0.236
108097	M6	16.5	0.122
108097	MK3	295.3	0.021
108097	S4	122.7	0.012
108097	MN4	128.1	0.05
108097	S6	69.7	0.009
108097	2N2	87.6	0.223
108097	OO1	6.6	0.007
108097	M1	62.2	0.011
108097	J1	84.8	0.014
108097	Q1	83.1	0.009
108097	2Q1	258.1	0.017
108097	2SM2	80.6	0.045
108097	M3	229.2	0.028
108097	L2	147.5	0.152
108097	2MK3	99	0.03
108097	K2	129.3	0.348
108097	M8	318	0.046
108097	MS4	109.2	0.056
108098	M2	146.1	3.017
108098	S2	178.6	0.916
108098	N2	123	0.577
108098	K1	105.3	0.5
108098	M4	197.5	0.068
108098	O1	75	0.314
108098	M6	315.4	0.062
108098	MK3	25.7	0.023
108098	S4	270.1	0.009
108098	MN4	119.4	0.022
108098	S6	340	0.019
108098	2N2	97.2	0.222
108098	OO1	32.6	0.034
108098	M1	249	0.02
108098	J1	322.8	0.032
108098	Q1	133.9	0.032
108098	2Q1	294.1	0.063
108098	P1	52.1	0.127
108098	2SM2	72.9	0.048
108098	M3	249.6	0.041
108098	L2	159	0.123
108098	2MK3	24.9	0.07
108098	K2	166.8	0.325
108098	M8	224.7	0.024
108098	MS4	194.3	0.072
108099	M2	145.8	2.554
108099	S2	181.9	0.798
108099	N2	122.3	0.478
108099	K1	106.3	0.432
108099	M4	11.6	0.145
108099	O1	78.2	0.278
108099	M6	31.4	0.078
108099	MK3	337.1	0.057
108099	S4	303	0.012
108099	MN4	13.7	0.078
108099	S6	285.3	0.038
108099	2N2	108.9	0.203
108099	OO1	21.4	0.022
108099	M1	213.8	0.018
108099	J1	310.9	0.023
108099	Q1	145.8	0.015
108099	2Q1	311.7	0.045
108099	P1	59.7	0.097
108099	2SM2	85.2	0.055
108099	M3	305.8	0.043
108099	L2	158.2	0.107
108099	2MK3	343.9	0.082
108099	K2	171.6	0.296
108099	M8	152.7	0.073
108099	MS4	13.6	0.082
108100	M2	157.6	1.753
108100	S2	190.6	0.562
108100	N2	133.1	0.383
108100	K1	108.7	0.237
108100	M4	246.7	0.015
108100	O1	82.2	0.142
108100	M6	290.6	0.04
108100	MK3	235.7	0.007
108100	S4	234.2	0.013
108100	MN4	119.5	0.005
108100	S6	165.1	0.005
108100	2N2	106.6	0.113
108100	OO1	80.5	0.018
108100	M1	287.2	0.034
108100	J1	109.6	0.012
108100	Q1	72.5	0.023
108100	2Q1	287.3	0.025
108100	P1	304.7	0.01
108100	2SM2	40.8	0.019
108100	M3	242.9	0.052
108100	L2	177.7	0.06
108100	2MK3	13.8	0.008
108100	K2	181	0.165
108100	M8	276.3	0.027
108100	MS4	292.8	0.033
108101	M2	160.4	1.954
108101	S2	191.4	0.659
108101	N2	134.7	0.437
108101	K1	116.9	0.28
108101	M4	282.2	0.073
108101	O1	93.6	0.18
108101	M6	2.3	0.036
108101	MK3	215.1	0.039
108101	S4	217	0.014
108101	MN4	211.4	0.039
108101	S6	149.8	0.009
108101	2N2	105.4	0.125
108101	OO1	96.4	0.025
108101	M1	308.6	0.033
108101	J1	352.9	0.004
108101	Q1	81.7	0.039
108101	2Q1	310.6	0.037
108101	P1	67.8	0.015
108101	2SM2	32.3	0.023
108101	M3	230.9	0.066
108101	L2	190.7	0.083
108101	2MK3	127	0.003
108101	K2	182.1	0.195
108101	M8	24	0.006
108101	MS4	272.8	0.061
108102	M2	161.8	1.966
108102	S2	192.3	0.666
108102	N2	136.1	0.444
108102	K1	118.8	0.289
108102	M4	297.8	0.077
108102	O1	96.8	0.181
108102	M6	32.7	0.042
108102	MK3	214	0.035
108102	S4	194.1	0.015
108102	MN4	212.7	0.035
108102	S6	152.4	0.01
108102	2N2	101.7	0.128
108102	OO1	97.1	0.028
108102	M1	304.9	0.032
108102	J1	321.4	0.003
108102	Q1	84.2	0.042
108102	2Q1	311	0.039
108102	P1	37.6	0.02
108102	2SM2	34.3	0.027
108102	M3	224.9	0.062
108102	L2	196.8	0.085
108102	K2	184.8	0.206
108102	M8	41.7	0.004
108102	MS4	272.5	0.062
108103	M2	177.7	2.067
108103	S2	209.9	0.625
108103	N2	159.3	0.46
108103	K1	142.2	0.302
108103	M4	191.9	0.143
108103	O1	122	0.217
108103	M6	51.8	0.054
108103	MK3	138.9	0.046
108103	S4	182.7	0.012
108103	MN4	159.7	0.056
108103	S6	312.2	0.005
108103	2N2	144.6	0.093
108103	OO1	170.4	0.017
108103	M1	136.6	0.006
108103	J1	160.4	0.026
108103	Q1	106.6	0.042
108103	2Q1	126.8	0.002
108103	P1	155.8	0.068
108103	2SM2	95.5	0.006
108103	M3	271.5	0.048
108103	L2	200.4	0.064
108103	2MK3	93.7	0.038
108103	K2	214.9	0.179
108103	M8	117	0.012
108103	MS4	207.3	0.08
108104	M2	178	1.916
108104	S2	214.7	0.618
108104	N2	156.1	0.457
108104	K1	141.9	0.291
108104	M4	102	0.051
108104	O1	121.4	0.177
108104	M6	160.3	0.049
108104	MK3	254.1	0.041
108104	S4	228.9	0.025
108104	MN4	304.5	0.008
108104	S6	300.8	0.007
108104	2N2	152.1	0.123
108104	OO1	172.7	0.011
108104	M1	118.8	0.017
108104	J1	152.5	0.019
108104	Q1	102.8	0.031
108104	2Q1	296.1	0.004
108104	P1	168	0.028
108104	2SM2	92.8	0.013
108104	M3	228.5	0.004
108104	L2	228.3	0.047
108104	2MK3	261.5	0.019
108104	K2	218.1	0.195
108104	M8	130.7	0.013
108104	MS4	313.7	0.005
108105	M2	177.7	1.907
108105	S2	215.7	0.62
108105	N2	155.6	0.46
108105	K1	146	0.289
108105	M4	64.3	0.059
108105	O1	119.2	0.185
108105	M6	144.6	0.05
108105	MK3	274.2	0.045
108105	S4	223.1	0.018
108105	MN4	346.8	0.02
108105	S6	241.8	0.007
108105	2N2	151	0.121
108105	OO1	193.3	0.012
108105	M1	118.5	0.014
108105	J1	149	0.014
108105	Q1	102.9	0.023
108105	P1	157.2	0.047
108105	2SM2	87.8	0.011
108105	M3	249.8	0.009
108105	L2	223.6	0.044
108105	2MK3	265.8	0.022
108105	K2	218.5	0.198
108105	M8	129	0.012
108105	MS4	1.5	0.006
108106	M2	270.8	0.217
108106	S2	288.2	0.087
108106	N2	247.1	0.065
108106	K1	40.2	0.038
108106	M4	223.4	0.04
108106	O1	224.9	0.009
108106	M6	249.4	0.029
108106	MK3	268.4	0.014
108106	S4	271.5	0.004
108106	MN4	185	0.024
108106	S6	102.4	0.005
108106	2N2	281	0.025
108106	OO1	144.7	0.007
108106	M1	320	0.004
108106	J1	144.9	0.006
108106	Q1	97.5	0.006
108106	2Q1	339.1	0.005
108106	P1	266.8	0.041
108106	2SM2	352.4	0.009
108106	M3	191.5	0.002
108106	L2	313.9	0.017
108106	2MK3	138	0.006
108106	K2	252	0.037
108106	M8	245.3	0.021
108106	MS4	288.3	0.021
108107	M2	268.4	0.12
108107	S2	340.6	0.075
108107	N2	210.9	0.046
108107	K1	249	0.018
108107	M4	259.6	0.078
108107	O1	158.4	0.012
108107	M6	233.6	0.024
108107	MK3	288.7	0.014
108107	S4	38.3	0.012
108107	MN4	207.9	0.039
108107	S6	190.2	0.003
108107	2N2	134.9	0.018
108107	OO1	219.5	0.003
108107	M1	185.7	0.002
108107	J1	126.7	0.012
108107	Q1	125.8	0.004
108107	2Q1	35	0.01
108107	P1	109.2	0.015
108107	2SM2	203.8	0.01
108107	M3	65.3	0.006
108107	L2	333.6	0.01
108107	2MK3	132.5	0.008
108107	K2	319.6	0.048
108107	M8	187.8	0.008
108107	MS4	302.4	0.021
108108	M2	196.6	0.311
108108	S2	221.7	0.1
108108	N2	177.5	0.071
108108	K1	205.6	0.057
108108	M4	319.3	0.031
108108	O1	183.5	0.063
108108	M6	252.4	0.006
108108	S4	356.3	0.003
108108	NU2	180.1	0.014
108108	S6	56.8	0.005
108108	2N2	158.4	0.009
108108	OO1	227.6	0.003
108108	LDA2	208.2	0.002
108108	M1	194.6	0.004
108108	J1	216.5	0.005
108108	RHO1	174.1	0.002
108108	Q1	172.6	0.012
108108	T2	220.6	0.006
108108	R2	222.6	0.001
108108	2Q1	161.7	0.002
108108	P1	204	0.019
108108	L2	177.5	0.01
108108	K2	223.6	0.027
108108	M8	252.7	0.009
108109	M2	200	0.32
108109	S2	227.8	0.11
108109	N2	167.3	0.074
108109	K1	187.3	0.057
108109	M4	251.7	0.011
108109	O1	172.1	0.049
108109	M6	144	0.011
108109	S4	332.4	0.009
108109	NU2	171.7	0.014
108109	S6	128.2	0.001
108109	2N2	134.7	0.01
108109	OO1	202.5	0.002
108109	LDA2	212.9	0.002
108109	M1	179.7	0.003
108109	J1	194.8	0.004
108109	RHO1	165.7	0.002
108109	Q1	164.6	0.009
108109	T2	226.7	0.007
108109	R2	228.9	0.001
108109	2Q1	157.1	0.001
108109	P1	186.2	0.019
108109	L2	167.3	0.011
108109	K2	230.1	0.03
108109	M8	218.2	0.002
108110	M2	199.2	0.301
108110	S2	229.6	0.106
108110	N2	165.6	0.059
108110	K1	169.6	0.076
108110	M4	252.6	0.013
108110	O1	140.9	0.055
108110	M6	243.2	0.005
108110	S4	260.4	0.005
108110	NU2	170.1	0.011
108110	S6	330.7	0.004
108110	2N2	131.9	0.008
108110	OO1	198.3	0.002
108110	LDA2	213.4	0.002
108110	M1	155.2	0.004
108110	J1	183.8	0.004
108110	RHO1	128.6	0.002
108110	Q1	126.7	0.011
108110	T2	228.4	0.006
108110	R2	230.7	0.001
108110	2Q1	112.4	0.001
108110	P1	167.5	0.025
108110	L2	165.6	0.008
108110	K2	232	0.029
108110	M8	45.6	0.004
108111	M2	221	0.398
108111	S2	250.8	0.158
108111	N2	204.5	0.108
108111	K1	213	0.068
108111	M4	183.9	0.033
108111	O1	190.2	0.053
108111	M6	255.4	0.02
108111	S4	298.5	0.01
108111	NU2	206.8	0.021
108111	S6	238.9	0.002
108111	2N2	188.1	0.014
108111	OO1	235.8	0.002
108111	LDA2	234.9	0.003
108111	M1	201.6	0.004
108111	J1	224.3	0.004
108111	RHO1	180.5	0.002
108111	Q1	178.9	0.01
108111	T2	249.6	0.009
108111	R2	252	0.001
108111	2Q1	167.6	0.001
108111	P1	211.4	0.022
108111	L2	204.5	0.015
108111	K2	253.2	0.043
108111	M8	325.9	0.007
108112	M2	187.5	0.312
108112	S2	233.1	0.099
108112	N2	186	0.074
108112	K1	141.3	0.047
108112	M4	335.1	0.021
108112	O1	114.9	0.036
108112	M6	174.2	0.023
108112	S4	115.8	0.004
108112	NU2	186.2	0.014
108112	S6	166.2	0.014
108112	2N2	184.5	0.01
108112	OO1	167.7	0.002
108112	LDA2	208.7	0.002
108112	M1	128.1	0.003
108112	J1	154.4	0.003
108112	RHO1	103.6	0.001
108112	Q1	101.8	0.007
108112	T2	231.2	0.006
108112	R2	234.8	0.001
108112	2Q1	88.7	0.001
108112	P1	139.4	0.016
108112	L2	186	0.011
108112	K2	236.7	0.027
108112	M8	227.3	0.006
108113	M2	196.6	0.41
108113	S2	240.1	0.158
108113	N2	173.3	0.148
108113	K1	106.5	0.068
108113	M4	334.2	0.03
108113	O1	52	0.045
108113	M6	42.3	0.021
108113	S4	174.1	0.009
108113	NU2	176.5	0.029
108113	S6	27.1	0.014
108113	2N2	150.1	0.02
108113	OO1	160.9	0.002
108113	LDA2	216.8	0.003
108113	M1	79.3	0.003
108113	J1	133.5	0.004
108113	RHO1	28.7	0.002
108113	Q1	25	0.009
108113	T2	238.3	0.009
108113	R2	241.8	0.001
108113	2Q1	358	0.001
108113	P1	102.4	0.023
108113	L2	173.3	0.021
108113	K2	243.6	0.043
108113	M8	177.3	0.019
108114	M2	193.5	0.46
108114	S2	221.2	0.16
108114	N2	175.1	0.123
108114	K1	131.5	0.026
108114	M4	49.6	0.072
108114	O1	291.4	0.01
108114	M6	82.5	0.006
108114	S4	14	0.017
108114	NU2	177.6	0.024
108114	S6	277.5	0.002
108114	2N2	156.8	0.016
108114	LDA2	206.4	0.003
108114	M1	211.4	0.001
108114	J1	52.1	0.001
108114	Q1	10.7	0.002
108114	T2	220	0.009
108114	R2	222.2	0.001
108114	P1	143.5	0.008
108114	L2	175.1	0.018
108114	K2	223.4	0.043
108114	M8	281.9	0.014
108115	M2	192.3	0.44
108115	S2	225.2	0.165
108115	N2	178.4	0.111
108115	K1	139	0.059
108115	M4	337.9	0.026
108115	O1	122.8	0.037
108115	M6	253.7	0.021
108115	S4	351	0.014
108115	NU2	180.3	0.022
108115	S6	228.7	0.013
108115	2N2	164.4	0.015
108115	OO1	155.2	0.002
108115	LDA2	207.6	0.003
108115	M1	130.9	0.003
108115	J1	147	0.003
108115	RHO1	115.9	0.001
108115	Q1	114.8	0.007
108115	T2	223.9	0.01
108115	R2	226.4	0.001
108115	2Q1	106.7	0.001
108115	P1	137.8	0.019
108115	L2	178.4	0.016
108115	K2	227.8	0.045
108115	M8	119.9	0.015
108116	M2	187	0.494
108116	S2	221.3	0.184
108116	N2	149.1	0.128
108116	K1	151.7	0.04
108116	M4	200.7	0.033
108116	O1	117.9	0.017
108116	M6	24.8	0.017
108116	S4	274.8	0.017
108116	NU2	154.2	0.025
108116	S6	54.4	0.008
108116	2N2	111.1	0.017
108116	OO1	185.5	0.001
108116	LDA2	203	0.003
108116	M1	134.8	0.001
108116	J1	168.5	0.001
108116	RHO1	103.5	0.001
108116	Q1	101.2	0.003
108116	T2	219.9	0.011
108116	R2	222.6	0.001
108116	P1	149.2	0.013
108116	L2	149.1	0.018
108116	K2	224.1	0.05
108116	M8	277.2	0.008
108117	M2	179.6	0.964
108117	S2	210.6	0.268
108117	N2	166.2	0.148
108117	K1	176	0.117
108117	M4	291.1	0.107
108117	O1	152.5	0.066
108117	M6	61.9	0.042
108117	S4	34.3	0.002
108117	NU2	168	0.029
108117	S6	321.3	0.018
108117	2N2	152.8	0.02
108117	OO1	199.4	0.003
108117	LDA2	194	0.007
108117	M1	164.3	0.005
108117	J1	187.6	0.005
108117	RHO1	142.6	0.003
108117	Q1	140.9	0.013
108117	T2	209.3	0.016
108117	R2	211.7	0.002
108117	2Q1	129.3	0.002
108117	P1	174.2	0.039
108117	L2	166.2	0.021
108117	K2	213	0.073
108117	M8	152.8	0.016
108118	M2	181.7	1.186
108118	S2	217.1	0.339
108118	N2	172.9	0.219
108118	K1	171.8	0.128
108118	M4	257.1	0.064
108118	O1	154	0.109
108118	M6	50.5	0.021
108118	S4	172.7	0.008
108118	NU2	174.1	0.042
108118	S6	348.7	0.011
108118	2N2	164	0.029
108118	OO1	189.7	0.005
108118	LDA2	198.1	0.008
108118	M1	162.9	0.008
108118	J1	180.7	0.009
108118	RHO1	146.3	0.004
108118	Q1	145.1	0.021
108118	T2	215.6	0.02
108118	R2	218.4	0.003
108118	2Q1	136.3	0.003
108118	P1	170.5	0.042
108118	L2	172.9	0.031
108118	K2	219.9	0.092
108118	M8	170	0.017
108119	M2	175	1.074
108119	S2	222.6	0.439
108119	N2	152.6	0.264
108119	K1	177.7	0.125
108119	M4	13	0.118
108119	O1	168.2	0.092
108119	M6	307.8	0.032
108119	S4	0.3	0.013
108119	NU2	155.6	0.051
108119	S6	98.1	0.015
108119	2N2	130.2	0.035
108119	OO1	187.3	0.004
108119	LDA2	197.1	0.008
108119	M1	173	0.007
108119	J1	182.5	0.007
108119	RHO1	164.1	0.003
108119	Q1	163.4	0.018
108119	T2	220.7	0.026
108119	R2	224.4	0.004
108119	2Q1	158.7	0.002
108119	P1	177.1	0.041
108119	L2	152.6	0.038
108119	K2	226.4	0.12
108119	M8	270.2	0.018
108120	M2	194.6	0.171
108120	S2	228.8	0.057
108120	N2	174.2	0.034
108120	K1	182.9	0.024
108120	M4	38.8	0.012
108120	O1	140.5	0.017
108120	M6	189.7	0.004
108120	S4	249.7	0.004
108120	NU2	177	0.007
108120	S6	255.9	0.003
108120	2N2	153.9	0.005
108120	OO1	225.3	0.001
108120	LDA2	210.5	0.001
108120	M1	161.7	0.001
108120	J1	204	0.001
108120	RHO1	122.4	0.001
108120	Q1	119.5	0.003
108120	T2	227.4	0.003
108120	P1	179.8	0.008
108120	L2	174.2	0.005
108120	K2	231.5	0.016
108120	M8	272.1	0.001
108121	M2	198.5	0.135
108121	S2	230.1	0.065
108121	N2	175.2	0.041
108121	K1	187.1	0.02
108121	M4	220.6	0.006
108121	O1	171.1	0.018
108121	M6	93.6	0.002
108121	S4	11.3	0.001
108121	NU2	178.4	0.008
108121	S6	150.9	0.002
108121	2N2	151.9	0.005
108121	OO1	203.1	0.001
108121	LDA2	213.2	0.001
108121	M1	179.2	0.001
108121	J1	195.1	0.001
108121	RHO1	164.3	0.001
108121	Q1	163.2	0.004
108121	T2	228.8	0.004
108121	R2	231.3	0.001
108121	P1	186	0.007
108121	L2	175.2	0.006
108121	K2	232.6	0.018
108121	M8	198.5	0.003
108122	M2	193.9	0.157
108122	S2	228.4	0.07
108122	N2	145	0.026
108122	K1	218.9	0.028
108122	M4	314	0.016
108122	O1	204.6	0.019
108122	M6	20.9	0.003
108122	S4	297.8	0.002
108122	NU2	151.6	0.005
108122	S6	276.4	0.004
108122	2N2	96.1	0.004
108122	OO1	233.2	0.001
108122	LDA2	209.9	0.001
108122	M1	211.7	0.001
108122	J1	226	0.002
108122	RHO1	198.5	0.001
108122	Q1	197.5	0.004
108122	T2	227	0.004
108122	R2	229.7	0.001
108122	P1	217.9	0.009
108122	L2	145	0.004
108122	K2	231.1	0.019
108122	M8	217.4	0.002
108123	M2	210.4	0.711
108123	S2	246	0.212
108123	N2	196.1	0.136
108123	K1	196.8	0.104
108123	M4	309.3	0.201
108123	O1	179.5	0.068
108123	M6	323.2	0.05
108123	S4	70.8	0.023
108123	NU2	198	0.026
108123	S6	29.4	0.013
108123	2N2	181.7	0.018
108123	OO1	214	0.003
108123	LDA2	227	0.005
108123	M1	188.2	0.005
108123	J1	205.3	0.005
108123	RHO1	172.2	0.003
108123	Q1	171	0.013
108123	T2	244.5	0.013
108123	R2	247.3	0.002
108123	2Q1	162.5	0.002
108123	P1	195.5	0.034
108123	L2	196.1	0.019
108123	K2	248.8	0.058
108123	M8	198.1	0.03
108124	M2	209.1	0.826
108124	S2	245.3	0.243
108124	N2	194.8	0.163
108124	K1	194.6	0.116
108124	M4	288.9	0.208
108124	O1	175.4	0.082
108124	M6	316.8	0.065
108124	S4	70.7	0.021
108124	NU2	196.8	0.032
108124	S6	13.7	0.01
108124	2N2	180.5	0.022
108124	OO1	213.8	0.004
108124	LDA2	226	0.006
108124	M1	185	0.006
108124	J1	204.1	0.006
108124	RHO1	167.2	0.003
108124	Q1	165.9	0.016
108124	T2	243.9	0.014
108124	R2	246.7	0.002
108124	2Q1	156.3	0.002
108124	P1	193.2	0.038
108124	L2	194.8	0.023
108124	K2	248.2	0.066
108124	M8	183.3	0.035
108125	M2	204.2	1.174
108125	S2	236.6	0.397
108125	N2	180.9	0.24
108125	K1	191.3	0.188
108125	M4	248.1	0.317
108125	O1	178.6	0.126
108125	M6	283.1	0.058
108125	S4	295.1	0.022
108125	NU2	184.1	0.046
108125	S6	229	0.009
108125	2N2	157.6	0.032
108125	OO1	204	0.005
108125	LDA2	219.3	0.008
108125	M1	184.9	0.009
108125	J1	197.6	0.01
108125	RHO1	173.2	0.005
108125	Q1	172.3	0.025
108125	T2	235.3	0.023
108125	R2	237.8	0.003
108125	2Q1	166	0.003
108125	P1	190.4	0.062
108125	L2	180.9	0.034
108125	K2	239.2	0.108
108125	M8	106.9	0.034
108126	M2	175.1	1.261
108126	S2	205.2	0.406
108126	N2	157.5	0.222
108126	K1	149.2	0.148
108126	M4	236.7	0.082
108126	O1	148.5	0.081
108126	M6	257.1	0.061
108126	MK3	236	0.05
108126	S4	169.4	0.01
108126	MN4	231	0.022
108126	S6	125	0.013
108126	2N2	138.1	0.048
108126	OO1	307.6	0.004
108126	M1	179	0.007
108126	J1	170.3	0.017
108126	Q1	183.2	0.029
108126	2Q1	291.8	0.008
108126	P1	148.4	0.048
108126	2SM2	125.1	0.004
108126	M3	266.5	0.013
108126	L2	172.5	0.033
108126	2MK3	171.3	0.011
108126	K2	192.8	0.115
108126	M8	129.3	0.039
108126	MS4	272.2	0.041
108127	M2	175.5	1.464
108127	S2	206.5	0.417
108127	N2	163.8	0.253
108127	K1	167	0.195
108127	M4	218.8	0.036
108127	O1	147.4	0.099
108127	M6	205.7	0.033
108127	MK3	209	0.041
108127	S4	260	0.01
108127	MN4	255.1	0.024
108127	S6	76.1	0.01
108127	2N2	85.5	0.008
108127	OO1	108.6	0.011
108127	M1	192.9	0.002
108127	J1	179.5	0.028
108127	Q1	202.4	0.009
108127	2Q1	335.4	0.01
108127	P1	145.2	0.04
108127	2SM2	63	0.017
108127	M3	267.8	0.038
108127	L2	170.7	0.083
108127	2MK3	119.5	0.01
108127	K2	182.4	0.139
108127	M8	122.6	0.037
108127	MS4	288.3	0.02
108128	M2	179.9	1.334
108128	S2	214.6	0.376
108128	N2	166.7	0.255
108128	K1	169.8	0.23
108128	M4	136.5	0.102
108128	O1	131.1	0.067
108128	M6	209.8	0.014
108128	MK3	135.5	0.036
108128	S4	273.8	0.02
108128	MN4	114.8	0.046
108128	S6	327.4	0.012
108128	2N2	267.6	0.05
108128	OO1	64.6	0.018
108128	M1	32.4	0.011
108128	J1	175.3	0.023
108128	Q1	308.1	0.009
108128	2Q1	135.6	0.01
108128	P1	134.7	0.056
108128	2SM2	217.1	0.017
108128	M3	265.5	0.052
108128	L2	171.9	0.05
108128	2MK3	43.2	0.023
108128	K2	186.1	0.141
108128	M8	93.6	0.032
108128	MS4	155.5	0.059
108129	M2	195.3	0.231
108129	S2	228.5	0.083
108129	N2	186.6	0.062
108129	K1	149.1	0.04
108129	M4	232.5	0.042
108129	O1	97.1	0.006
108129	M6	107.7	0.013
108129	S4	117.3	0.004
108129	NU2	187.8	0.012
108129	S6	344.9	0.003
108129	2N2	177.9	0.008
108129	LDA2	210.7	0.002
108129	Q1	71.2	0.001
108129	T2	227.1	0.005
108129	R2	229.7	0.001
108129	P1	145.2	0.013
108129	L2	186.6	0.009
108129	K2	231.1	0.022
108129	M8	256.4	0.013
108130	M2	191.1	0.199
108130	S2	224.4	0.078
108130	N2	182.7	0.062
108130	K1	142	0.037
108130	M4	216.1	0.027
108130	O1	91.2	0.013
108130	M6	73.9	0.008
108130	S4	220.4	0.001
108130	NU2	183.9	0.012
108130	S6	54.6	0.002
108130	2N2	174.4	0.008
108130	OO1	192.8	0.001
108130	LDA2	206.6	0.001
108130	M1	116.6	0.001
108130	J1	167.2	0.001
108130	Q1	66	0.003
108130	T2	223.1	0.005
108130	R2	225.7	0.001
108130	P1	138.2	0.012
108130	L2	182.7	0.009
108130	K2	227.1	0.021
108130	M8	263.2	0.01
108131	M2	196.6	0.39
108131	S2	242.1	0.129
108131	N2	193.3	0.084
108131	K1	185	0.061
108131	M4	243.2	0.075
108131	O1	197.2	0.044
108131	M6	64.7	0.024
108131	S4	98.3	0.012
108131	NU2	193.8	0.016
108131	S6	144.1	0.006
108131	2N2	190.1	0.011
108131	OO1	172.8	0.002
108131	LDA2	217.7	0.003
108131	M1	191.1	0.003
108131	J1	179	0.003
108131	RHO1	202.5	0.002
108131	Q1	203.2	0.008
108131	T2	240.3	0.008
108131	R2	243.9	0.001
108131	2Q1	209.3	0.001
108131	P1	186	0.02
108131	L2	193.3	0.012
108131	K2	245.8	0.035
108131	M8	126.6	0.022
108132	M2	179.3	1.055
108132	S2	207.5	0.307
108132	N2	159.4	0.206
108132	K1	148.1	0.166
108132	M4	126.8	0.111
108132	O1	122.6	0.054
108132	M6	153.7	0.078
108132	MK3	95.1	0.043
108132	S4	188.3	0.016
108132	MN4	82	0.05
108132	S6	43	0.006
108132	2N2	170.2	0.042
108132	OO1	306.3	0.015
108132	M1	143.1	0.018
108132	J1	87.8	0.015
108132	Q1	38.2	0.011
108132	2Q1	85.1	0.034
108132	P1	262.6	0.035
108132	2SM2	92	0.004
108132	M3	195.1	0.021
108132	L2	195	0.046
108132	2MK3	42.8	0.067
108132	K2	193.6	0.1
108132	M8	186	0.016
108132	MS4	182.6	0.057
108133	M2	172.2	1.046
108133	S2	210.7	0.298
108133	N2	156.5	0.182
108133	K1	156.2	0.137
108133	M4	108.6	0.177
108133	O1	98	0.058
108133	M6	89.7	0.136
108133	MK3	77.9	0.059
108133	S4	273.2	0.021
108133	MN4	85.7	0.065
108133	S6	349.9	0.005
108133	2N2	131.8	0.057
108133	OO1	316.4	0.008
108133	M1	167.7	0.016
108133	J1	61.3	0.021
108133	Q1	58.7	0.029
108133	2Q1	101	0.017
108133	P1	293	0.027
108133	2SM2	341.5	0.017
108133	M3	174.5	0.028
108133	L2	273.5	0.017
108133	2MK3	38.3	0.088
108133	K2	202.7	0.075
108133	M8	146.8	0.06
108133	MS4	176.7	0.062
108134	M2	164.5	1.07
108134	S2	195.5	0.312
108134	N2	142.3	0.18
108134	K1	157.4	0.147
108134	M4	78.6	0.158
108134	O1	86.8	0.072
108134	M6	32.9	0.095
108134	MK3	62.9	0.041
108134	S4	261.4	0.03
108134	MN4	106.5	0.072
108134	S6	266.9	0.003
108134	2N2	114.5	0.049
108134	OO1	42	0.004
108134	M1	170.4	0.021
108134	J1	76.7	0.023
108134	Q1	80.8	0.026
108134	2Q1	77.7	0.01
108134	P1	315.3	0.039
108134	2SM2	5.8	0.023
108134	M3	216	0.036
108134	L2	317	0.026
108134	2MK3	32.9	0.069
108134	K2	180.1	0.076
108134	M8	137.8	0.097
108134	MS4	191.3	0.059
108135	M2	158.2	2.187
108135	S2	187.9	0.617
108135	N2	146.1	0.413
108135	K1	140.8	0.245
108135	M4	165.4	0.137
108135	O1	126.6	0.125
108135	M6	353.2	0.115
108135	MK3	125	0.027
108135	S4	177.6	0.012
108135	MN4	132.9	0.072
108135	S6	335.1	0.005
108135	2N2	81.5	0.055
108135	OO1	173.7	0.015
108135	M1	155.1	0.018
108135	J1	194.6	0.013
108135	Q1	125.1	0.029
108135	2Q1	21.8	0.002
108135	P1	146	0.053
108135	2SM2	334.5	0.023
108135	M3	215.5	0.04
108135	L2	185.9	0.107
108135	2MK3	30.7	0.037
108135	K2	175.9	0.21
108135	M8	180.5	0.068
108135	MS4	205.9	0.094
108136	M2	156.2	2.328
108136	S2	191.3	0.697
108136	N2	140.3	0.468
108136	K1	142.9	0.274
108136	M4	218.5	0.105
108136	O1	126	0.145
108136	M6	352.2	0.063
108136	MK3	323.9	0.019
108136	S4	168.8	0.029
108136	MN4	258.7	0.021
108136	S6	306.5	0.004
108136	2N2	126.7	0.04
108136	OO1	187	0.017
108136	M1	142.3	0.014
108136	J1	170.3	0.015
108136	Q1	117.5	0.033
108136	2Q1	340.9	0.011
108136	P1	148.7	0.063
108136	2SM2	347.1	0.027
108136	M3	238.9	0.04
108136	L2	142	0.098
108136	2MK3	316	0.04
108136	K2	175	0.233
108136	M8	141.5	0.067
108136	MS4	272.1	0.017
108137	M2	153.6	2.079
108137	S2	199.1	0.807
108137	N2	130.6	0.412
108137	K1	148	0.265
108137	M4	214.5	0.324
108137	O1	131.2	0.113
108137	M6	11.2	0.111
108137	MK3	272.8	0.054
108137	S4	118.1	0.025
108137	MN4	213.5	0.15
108137	S6	95.6	0.012
108137	2N2	150	0.152
108137	OO1	122.3	0.02
108137	M1	211.6	0.004
108137	J1	171	0.032
108137	Q1	71	0.01
108137	2Q1	64.7	0.023
108137	P1	145.8	0.09
108137	2SM2	306.9	0.042
108137	M3	258.3	0.053
108137	L2	66.4	0.137
108137	2MK3	229.7	0.074
108137	K2	186.7	0.217
108137	M8	99.5	0.094
108137	MS4	313.1	0.096
108138	M2	175.3	0.558
108138	S2	220	0.192
108138	N2	165.4	0.128
108138	K1	177.9	0.138
108138	M4	288.4	0.14
108138	O1	155.4	0.053
108138	M6	238.5	0.007
108138	MK3	262.6	0.092
108138	S4	131.9	0.015
108138	MN4	269.8	0.016
108138	S6	300.2	0.003
108138	2N2	244.2	0.064
108138	OO1	57.7	0.006
108138	M1	141.8	0.006
108138	J1	156.9	0.025
108138	Q1	75.3	0.01
108138	2Q1	128.9	0.028
108138	P1	110.6	0.056
108138	2SM2	205.1	0.012
108138	M3	266.9	0.046
108138	L2	342.7	0.045
108138	2MK3	234.4	0.073
108138	K2	193.4	0.014
108138	M8	283	0.007
108138	MS4	21.8	0.022
108139	M2	200	0.818
108139	S2	224.4	0.283
108139	N2	175.6	0.123
108139	K1	166	0.121
108139	M4	239.6	0.134
108139	O1	187.3	0.067
108139	M6	206.9	0.031
108139	MK3	206.7	0.084
108139	S4	252.7	0.026
108139	MN4	182.4	0.036
108139	S6	48.7	0.004
108139	2N2	120.6	0.03
108139	OO1	153	0.006
108139	M1	220.8	0.013
108139	J1	173	0.02
108139	Q1	111.5	0.02
108139	2Q1	132.7	0.018
108139	P1	201.1	0.061
108139	2SM2	293.8	0.02
108139	M3	259.8	0.027
108139	L2	281.3	0.09
108139	2MK3	180.7	0.056
108139	K2	216.7	0.077
108139	M8	208.4	0.048
108139	MS4	257.4	0.074
108140	M2	194.6	0.763
108140	S2	230.3	0.205
108140	N2	208.5	0.104
108140	K1	166.1	0.143
108140	M4	76.3	0.098
108140	O1	186.9	0.043
108140	M6	81.3	0.072
108140	MK3	54.5	0.065
108140	S4	256.8	0.025
108140	MN4	52.5	0.065
108140	S6	60.5	0.001
108140	2N2	55.8	0.029
108140	OO1	32.7	0.004
108140	M1	267.9	0.005
108140	J1	5.9	0.01
108140	Q1	307	0.008
108140	2Q1	280.7	0.01
108140	P1	254	0.063
108140	2SM2	111.1	0.007
108140	M3	104.8	0.013
108140	L2	237.1	0.103
108140	2MK3	11.1	0.046
108140	K2	215.4	0.067
108140	M8	29.9	0.005
108140	MS4	127	0.022
108141	M2	151	0.484
108141	S2	190.3	0.167
108141	N2	133.5	0.102
108141	K1	169.3	0.037
108141	M4	198.4	0.06
108141	O1	138.5	0.053
108141	M6	212.2	0.03
108141	MK3	24	0.019
108141	S4	141.2	0.011
108141	MN4	336.1	0.007
108141	S6	146.6	0.006
108141	2N2	143.2	0.017
108141	OO1	108.5	0.007
108141	M1	273.5	0.003
108141	J1	209.7	0.01
108141	Q1	124.2	0.009
108141	2Q1	194.2	0.014
108141	P1	133.8	0.02
108141	2SM2	334.2	0.02
108141	M3	119.8	0.019
108141	L2	66.4	0.04
108141	2MK3	296.1	0.02
108141	K2	176.7	0.044
108141	M8	239.4	0.02
108141	MS4	210.6	0.018
108142	M2	150.7	0.432
108142	S2	190	0.15
108142	N2	123.4	0.096
108142	K1	173.1	0.06
108142	M4	97.2	0.047
108142	O1	159.3	0.047
108142	M6	218.2	0.038
108142	MK3	326.5	0.035
108142	S4	74.5	0.009
108142	MN4	106.4	0.013
108142	S6	89.5	0.005
108142	2N2	213.5	0.007
108142	OO1	70.3	0.008
108142	M1	191.8	0.006
108142	J1	6.6	0.007
108142	Q1	106.2	0.012
108142	2Q1	247.6	0.007
108142	P1	199.7	0.017
108142	2SM2	348	0.01
108142	M3	294.3	0.007
108142	L2	94.1	0.022
108142	2MK3	325	0.026
108142	K2	211.8	0.04
108142	M8	187.6	0.017
108142	MS4	136.6	0.032
108143	M2	138	0.341
108143	S2	185.7	0.135
108143	N2	121.3	0.044
108143	K1	206.9	0.063
108143	M4	66.6	0.136
108143	O1	174.1	0.047
108143	M6	96.4	0.018
108143	MK3	253	0.043
108143	S4	229.8	0.006
108143	MN4	73.1	0.076
108143	S6	221.1	0.003
108143	2N2	179.5	0.018
108143	OO1	98.8	0.009
108143	M1	192.2	0.003
108143	J1	117.4	0.012
108143	Q1	100.8	0.01
108143	2Q1	99.9	0.004
108143	P1	208	0.019
108143	2SM2	313.2	0.019
108143	M3	288.7	0.022
108143	L2	10.6	0.043
108143	2MK3	146.4	0.025
108143	K2	189.3	0.038
108143	M8	243	0.005
108143	MS4	139.3	0.05
108144	M2	135.1	0.772
108144	S2	183.1	0.154
108144	N2	122.4	0.196
108144	K1	210.7	0.072
108144	M4	44.6	0.131
108144	O1	209.8	0.028
108144	M6	140.9	0.108
108144	MK3	13.8	0.044
108144	S4	269.3	0.017
108144	MN4	58.2	0.045
108144	S6	27.9	0.01
108144	2N2	166.6	0.022
108144	OO1	93.3	0.014
108144	M1	211.2	0.002
108144	J1	182.5	0.019
108144	Q1	115	0.005
108144	2Q1	165.4	0.003
108144	P1	308.2	0.011
108144	2SM2	10.8	0.022
108144	M3	168.2	0.016
108144	L2	58.3	0.185
108144	2MK3	348.9	0.031
108144	K2	114	0.075
108144	M8	160.3	0.032
108144	MS4	93.4	0.028
108145	M2	125.2	0.537
108145	S2	254.3	0.106
108145	N2	115.5	0.17
108145	K1	215.3	0.077
108145	M4	68.8	0.094
108145	O1	187.7	0.048
108145	M6	126.8	0.088
108145	MK3	356.6	0.033
108145	S4	275.1	0.013
108145	MN4	59.2	0.049
108145	S6	329.2	0.017
108145	2N2	167.8	0.073
108145	OO1	57.5	0.015
108145	M1	207	0.008
108145	J1	148.6	0.026
108145	Q1	104.5	0.015
108145	2Q1	239.4	0.012
108145	P1	218.4	0.006
108145	2SM2	327	0.036
108145	M3	358	0.008
108145	L2	35.1	0.227
108145	2MK3	293.2	0.029
108145	K2	58.9	0.082
108145	M8	127.5	0.028
108145	MS4	214	0.019
108146	M2	128.5	0.43
108146	S2	258.1	0.177
108146	N2	105.8	0.129
108146	K1	206.2	0.078
108146	M4	112	0.064
108146	O1	192.2	0.09
108146	M6	130	0.057
108146	MK3	283.9	0.021
108146	S4	257	0.031
108146	MN4	25.8	0.033
108146	S6	15.6	0.015
108146	2N2	173.3	0.101
108146	OO1	52.3	0.013
108146	M1	176.1	0.005
108146	J1	147.9	0.019
108146	Q1	152.5	0.025
108146	2Q1	219.3	0.024
108146	P1	197.3	0.039
108146	2SM2	331.7	0.049
108146	M3	323	0.038
108146	L2	20.1	0.238
108146	2MK3	262.9	0.05
108146	K2	26.5	0.076
108146	M8	88.2	0.003
108146	MS4	238.9	0.046
108147	M2	191.7	0.265
108147	S2	234.8	0.083
108147	N2	185.6	0.048
108147	K1	159.3	0.105
108147	M4	236.7	0.074
108147	O1	104.8	0.044
108147	M6	6.5	0.022
108147	MK3	201.4	0.032
108147	S4	184.8	0.009
108147	MN4	216.2	0.023
108147	S6	266.3	0.009
108147	2N2	213.2	0.012
108147	OO1	283.3	0.003
108147	M1	166.2	0.012
108147	J1	105.3	0.005
108147	Q1	72.2	0.014
108147	2Q1	105.4	0.014
108147	P1	199.2	0.03
108147	2SM2	171.6	0.008
108147	M3	285.1	0.016
108147	L2	233.8	0.026
108147	2MK3	119.1	0.008
108147	K2	217.7	0.034
108147	M8	58.7	0.018
108147	MS4	285	0.027
108148	M2	172.2	0.212
108148	S2	214.6	0.067
108148	N2	162.2	0.043
108148	K1	165.1	0.062
108148	M4	207.9	0.07
108148	O1	128.9	0.035
108148	M6	80.1	0.021
108148	MK3	166.4	0.017
108148	S4	229.5	0.006
108148	MN4	192.6	0.027
108148	S6	272.5	0.003
108148	2N2	132.6	0.008
108148	OO1	265.6	0.003
108148	M1	160.8	0.002
108148	J1	247.8	0.008
108148	Q1	170.8	0.007
108148	2Q1	121.3	0.006
108148	P1	184.2	0.045
108148	2SM2	209.5	0.01
108148	M3	259.1	0.016
108148	L2	340.1	0.024
108148	2MK3	210.9	0.007
108148	K2	216.5	0.009
108148	M8	319.9	0.017
108148	MS4	260.3	0.051
108149	M2	161.8	0.239
108149	S2	210	0.135
108149	N2	137.8	0.078
108149	K1	146.7	0.028
108149	M4	198.9	0.118
108149	O1	117.4	0.029
108149	M6	15.2	0.053
108149	MK3	106.6	0.068
108149	S4	258.8	0.011
108149	MN4	206.3	0.038
108149	S6	50.7	0.003
108149	2N2	196.4	0.028
108149	OO1	60.3	0.005
108149	M1	168.9	0.004
108149	J1	151.7	0.009
108149	Q1	79.2	0.015
108149	2Q1	38.3	0.008
108149	P1	151.3	0.06
108149	2SM2	148.6	0.006
108149	M3	172.1	0.029
108149	L2	278.9	0.016
108149	2MK3	22.4	0.042
108149	K2	208.6	0.05
108149	M8	214.5	0.019
108149	MS4	249.3	0.056
108150	M2	173.4	0.313
108150	S2	207.1	0.131
108150	N2	147.7	0.045
108150	K1	169	0.07
108150	M4	208.7	0.034
108150	O1	113.8	0.058
108150	M6	18.1	0.015
108150	S4	90.4	0.002
108150	NU2	151.2	0.009
108150	S6	217.5	0.001
108150	2N2	122	0.006
108150	OO1	224.3	0.002
108150	LDA2	189	0.002
108150	M1	141.4	0.004
108150	J1	196.4	0.005
108150	RHO1	90.1	0.002
108150	Q1	86.4	0.011
108150	T2	205.7	0.008
108150	R2	208.4	0.001
108150	2Q1	59	0.001
108150	P1	164.9	0.023
108150	L2	147.7	0.006
108150	K2	209.8	0.036
108150	M8	33.9	0.006
108151	M2	180.7	0.309
108151	S2	208.7	0.137
108151	N2	165.8	0.042
108151	K1	185.4	0.07
108151	M4	255.9	0.035
108151	O1	125.6	0.071
108151	M6	48.1	0.024
108151	S4	120.1	0.009
108151	NU2	167.8	0.008
108151	S6	166.7	0.011
108151	2N2	150.9	0.006
108151	OO1	245.2	0.003
108151	LDA2	193.7	0.002
108151	M1	155.5	0.005
108151	J1	215.1	0.006
108151	RHO1	99.9	0.003
108151	Q1	95.9	0.014
108151	T2	207.6	0.008
108151	R2	209.8	0.001
108151	2Q1	66.2	0.002
108151	P1	181	0.023
108151	L2	165.8	0.006
108151	K2	211	0.037
108151	M8	189.3	0.003
108152	M2	180.8	0.308
108152	S2	209.3	0.166
108152	N2	197.1	0.041
108152	K1	193.2	0.084
108152	M4	247.8	0.048
108152	O1	141	0.096
108152	M6	58.7	0.033
108152	S4	102.4	0.01
108152	NU2	195	0.008
108152	S6	191.6	0.009
108152	2N2	213.4	0.005
108152	OO1	245.4	0.004
108152	LDA2	194.1	0.002
108152	M1	167.1	0.007
108152	J1	219.1	0.008
108152	RHO1	118.7	0.004
108152	Q1	115.1	0.019
108152	T2	208.1	0.01
108152	R2	210.3	0.001
108152	2Q1	89.2	0.003
108152	P1	189.3	0.028
108152	L2	197.1	0.006
108152	K2	211.5	0.045
108152	M8	208.6	0.013
108153	M2	188.8	0.707
108153	S2	220.6	0.207
108153	N2	162.1	0.119
108153	K1	169.3	0.128
108153	M4	226.7	0.058
108153	O1	156.7	0.086
108153	M6	95.5	0.011
108153	MK3	198.4	0.024
108153	S4	305	0.006
108153	MN4	170.1	0.027
108153	S6	265.1	0.001
108153	2N2	149.4	0.004
108153	OO1	193.6	0.006
108153	M1	164.2	0.008
108153	J1	214.6	0.007
108153	Q1	131	0.01
108153	2Q1	267.3	0.009
108153	P1	157.6	0.015
108153	2SM2	127.4	0.005
108153	M3	242.9	0.009
108153	L2	218.2	0.021
108153	2MK3	148.5	0.012
108153	K2	221.3	0.055
108153	M8	81.3	0.01
108153	MS4	277.2	0.028
108154	M2	188.5	0.829
108154	S2	225.2	0.26
108154	N2	158.6	0.136
108154	K1	172.8	0.148
108154	M4	219	0.062
108154	O1	155.5	0.093
108154	M6	44.3	0.019
108154	MK3	187.9	0.025
108154	S4	265.3	0.005
108154	MN4	170.1	0.021
108154	S6	303.3	0.001
108154	2N2	196.3	0.004
108154	OO1	193.3	0.006
108154	M1	164.4	0.008
108154	J1	207	0.009
108154	Q1	140.3	0.011
108154	2Q1	255.7	0.009
108154	P1	154.9	0.029
108154	2SM2	31.1	0.004
108154	M3	254.1	0.011
108154	L2	217.1	0.018
108154	2MK3	149.3	0.013
108154	K2	218.3	0.084
108154	M8	72.4	0.013
108154	MS4	248.3	0.034
108155	M2	188.2	0.847
108155	S2	225.4	0.299
108155	N2	154.3	0.135
108155	K1	176.6	0.153
108155	M4	216.7	0.035
108155	O1	156.5	0.089
108155	M6	28.4	0.021
108155	MK3	188.7	0.016
108155	S4	292.9	0.004
108155	MN4	268.5	0.008
108155	S6	319.6	0.001
108155	2N2	156.5	0.003
108155	OO1	217.2	0.007
108155	M1	180.1	0.005
108155	J1	183.3	0.007
108155	Q1	130.2	0.011
108155	2Q1	286	0.007
108155	P1	142.7	0.042
108155	2SM2	39.3	0.005
108155	M3	259.9	0.009
108155	L2	293.2	0.012
108155	2MK3	123.2	0.004
108155	K2	207.4	0.101
108155	M8	44.9	0.002
108155	MS4	226	0.028
108156	M2	193.5	0.303
108156	S2	180.6	0.076
108156	N2	182.9	0.058
108156	K1	172.8	0.047
108156	M4	221.4	0.032
108156	O1	126.8	0.025
108156	M6	81.5	0.005
108156	MK3	166.4	0.012
108156	S4	100.4	0.005
108156	MN4	140.8	0.009
108156	S6	358.3	0.001
108156	2N2	344.5	0.01
108156	OO1	153.3	0.005
108156	M1	107.3	0.007
108156	J1	203.2	0.005
108156	Q1	83.9	0.004
108156	2Q1	234.2	0.007
108156	P1	120	0.017
108156	2SM2	94.6	0.011
108156	M3	221.7	0.012
108156	L2	261.9	0.033
108156	2MK3	134.8	0.004
108156	K2	10.3	0.038
108156	M8	133.2	0.002
108156	MS4	253.7	0.014
108157	M2	195.8	0.312
108157	S2	242.4	0.081
108157	N2	165.3	0.055
108157	K1	210	0.07
108157	M4	219.3	0.029
108157	O1	147.1	0.031
108157	M6	132	0.008
108157	MK3	186.8	0.016
108157	S4	11.8	0.002
108157	MN4	164	0.004
108157	S6	287.9	0.003
108157	2N2	287.2	0.004
108157	OO1	145.5	0.002
108157	M1	159.1	0.002
108157	J1	148.8	0.006
108157	Q1	244.4	0.005
108157	2Q1	260.9	0.006
108157	P1	137.1	0.06
108157	2SM2	72.5	0.011
108157	M3	301.1	0.007
108157	L2	210.1	0.019
108157	2MK3	185.3	0.011
108157	K2	267.4	0.041
108157	M8	178	0.003
108157	MS4	228.8	0.016
108158	M2	196.9	0.259
108158	S2	257.5	0.136
108158	N2	153.1	0.054
108158	K1	180	0.05
108158	M4	56.9	0.024
108158	O1	177.3	0.04
108158	M6	221.4	0.011
108158	MK3	340.1	0.008
108158	S4	237.6	0.009
108158	MN4	50.3	0.005
108158	S6	134.4	0.002
108158	2N2	87.2	0.003
108158	OO1	311.2	0.004
108158	M1	272.2	0.002
108158	J1	217	0.007
108158	Q1	198.6	0.006
108158	2Q1	31	0.005
108158	P1	264.4	0.021
108158	2SM2	295.2	0.01
108158	M3	65.2	0.002
108158	L2	108.1	0.03
108158	2MK3	254.7	0.005
108158	K2	222.3	0.083
108158	M8	273.1	0.006
108158	MS4	140	0.006
108159	M2	193.9	0.846
108159	S2	228.2	0.251
108159	N2	177.2	0.133
108159	K1	170.4	0.144
108159	M4	229.7	0.067
108159	O1	146.2	0.073
108159	M6	24.4	0.034
108159	MK3	185	0.009
108159	S4	152.1	0.004
108159	MN4	177.8	0.01
108159	S6	293.7	0.006
108159	2N2	110.8	0.012
108159	OO1	207.4	0.006
108159	M1	164.3	0.003
108159	J1	190	0.006
108159	Q1	145.1	0.01
108159	2Q1	312.4	0.007
108159	P1	170.6	0.041
108159	2SM2	6.9	0.002
108159	M3	312.4	0.007
108159	L2	192.4	0.033
108159	2MK3	39.1	0.007
108159	K2	212	0.062
108159	M8	102.1	0.013
108159	MS4	247.5	0.023
108160	M2	197.2	0.877
108160	S2	230.2	0.268
108160	N2	176.8	0.139
108160	K1	174.9	0.153
108160	M4	249.2	0.032
108160	O1	150.7	0.076
108160	M6	62.2	0.029
108160	S4	181.2	0.001
108160	MN4	167.6	0.009
108160	S6	299.1	0.007
108160	2N2	144.8	0.009
108160	OO1	215.7	0.007
108160	M1	192.4	0.002
108160	J1	172.7	0.005
108160	Q1	130.7	0.011
108160	2Q1	299.1	0.004
108160	P1	166.7	0.042
108160	2SM2	320.6	0.002
108160	M3	301.7	0.004
108160	L2	220.7	0.026
108160	2MK3	47.9	0.007
108160	K2	216	0.068
108160	M8	225.6	0.009
108160	MS4	265.2	0.013
108161	M2	289.2	0.181
108161	S2	13.6	0.029
108161	N2	255.9	0.057
108161	K1	79.5	0.013
108161	M4	209.9	0.067
108161	O1	162.9	0.003
108161	M6	101.3	0.023
108161	MK3	150.9	0.024
108161	S4	18.4	0.01
108161	MN4	189.8	0.041
108161	S6	136.9	0.002
108161	2N2	47.9	0.038
108161	OO1	189.3	0.002
108161	M1	62.1	0.003
108161	J1	224.5	0.006
108161	Q1	138.4	0.004
108161	2Q1	63.8	0.005
108161	P1	329	0.021
108161	2SM2	77	0.022
108161	M3	215.1	0.003
108161	L2	177.1	0.052
108161	2MK3	152	0.017
108161	K2	60.1	0.048
108161	M8	345.9	0.006
108161	MS4	257.3	0.042
108162	M2	292.2	0.228
108162	S2	307.7	0.1
108162	N2	235.3	0.029
108162	K1	251.4	0.019
108162	M4	188.3	0.069
108162	O1	290.2	0.013
108162	M6	155.7	0.023
108162	MK3	131.4	0.02
108162	S4	334.1	0.002
108162	MN4	99.1	0.024
108162	S6	11.1	0.006
108162	2N2	304.9	0.02
108162	OO1	203.8	0.005
108162	M1	128	0.001
108162	J1	146.9	0.007
108162	Q1	119.6	0.003
108162	2Q1	67.1	0.008
108162	P1	27.9	0.015
108162	2SM2	102	0.023
108162	M3	212.6	0.008
108162	L2	324.3	0.024
108162	2MK3	124.5	0.015
108162	K2	258.6	0.036
108162	M8	320	0.003
108162	MS4	170.5	0.041
108163	M2	231.9	0.08
108163	S2	243.3	0.112
108163	N2	241.5	0.04
108163	K1	176	0.05
108163	M4	286.7	0.021
108163	O1	184.5	0.024
108163	M6	269.8	0.005
108163	MK3	205.9	0.012
108163	S4	113	0.007
108163	MN4	196.1	0.007
108163	S6	63.3	0.007
108163	2N2	301.2	0.033
108163	OO1	326.6	0.002
108163	M1	174.5	0.004
108163	J1	125.5	0.001
108163	Q1	170.2	0.007
108163	2Q1	57.9	0.002
108163	P1	203.9	0.03
108163	2SM2	194.9	0.017
108163	M3	195.4	0.005
108163	L2	62.1	0.087
108163	2MK3	176.4	0.004
108163	K2	4.1	0.058
108163	M8	181.5	0.002
108163	MS4	325.2	0.012
108164	M2	200	0.185
108164	S2	286	0.102
108164	N2	193.6	0.014
108164	K1	213.8	0.033
108164	M4	165.1	0.019
108164	O1	184.5	0.009
108164	M6	176.6	0.003
108164	MK3	344.6	0.002
108164	S4	18.4	0.013
108164	MN4	165.7	0.011
108164	S6	292.1	0.002
108164	2N2	36.9	0.014
108164	OO1	218.2	0.005
108164	M1	159.1	0.004
108164	J1	82.2	0.004
108164	Q1	257.5	0.008
108164	2Q1	220.9	0.007
108164	P1	304.3	0.028
108164	2SM2	20.3	0.009
108164	M3	235.7	0.006
108164	L2	134.5	0.043
108164	K2	84.7	0.05
108164	M8	62	0.006
108164	MS4	241.9	0.016
108165	M2	148.6	0.809
108165	S2	177.5	0.237
108165	N2	123.1	0.13
108165	K1	109.5	0.106
108165	M4	129.3	0.222
108165	O1	68.6	0.047
108165	M6	65.4	0.07
108165	MK3	93.7	0.043
108165	S4	197.4	0.007
108165	MN4	107.6	0.057
108165	S6	260.6	0.006
108165	2N2	123.5	0.024
108165	OO1	283.6	0.003
108165	M1	208.5	0.003
108165	J1	15.2	0.015
108165	Q1	33.7	0.005
108165	2Q1	335.7	0.01
108165	P1	173.7	0.016
108165	2SM2	103	0.01
108165	M3	202.1	0.011
108165	L2	163.9	0.006
108165	2MK3	52.1	0.018
108165	K2	171.3	0.077
108165	M8	318.9	0.033
108165	MS4	164.2	0.083
108166	M2	158.6	0.881
108166	S2	179.8	0.281
108166	N2	121.3	0.158
108166	K1	104.8	0.09
108166	M4	116.1	0.135
108166	O1	90.6	0.06
108166	M6	35.2	0.118
108166	MK3	318.2	0.001
108166	S4	137.5	0.003
108166	MN4	92	0.05
108166	S6	9.5	0.005
108166	2N2	138.5	0.043
108166	OO1	154.7	0.007
108166	M1	181.5	0.005
108166	J1	26.4	0.018
108166	Q1	84.6	0.006
108166	2Q1	324.5	0.012
108166	P1	140.1	0.049
108166	2SM2	117	0.018
108166	M3	231.1	0.006
108166	L2	284.3	0.035
108166	2MK3	278.1	0.009
108166	K2	168.7	0.095
108166	M8	345.8	0.052
108166	MS4	158.9	0.058
108167	M2	160.7	0.897
108167	S2	184	0.307
108167	N2	130.7	0.151
108167	K1	139.2	0.077
108167	M4	70.8	0.102
108167	O1	123.9	0.061
108167	M6	21.1	0.124
108167	MK3	257.4	0.047
108167	S4	145.8	0.013
108167	MN4	74.3	0.042
108167	S6	335	0.002
108167	2N2	150.3	0.066
108167	OO1	194.2	0.008
108167	M1	159.9	0.001
108167	J1	30.5	0.001
108167	Q1	85	0.01
108167	2Q1	261.1	0.006
108167	P1	118.1	0.058
108167	2SM2	131.8	0.021
108167	M3	317.2	0.003
108167	L2	239.9	0.035
108167	2MK3	260.1	0.026
108167	K2	176.1	0.101
108167	M8	336.6	0.043
108167	MS4	117.7	0.034
108168	M2	160.3	0.579
108168	S2	180.4	0.174
108168	N2	133.8	0.177
108168	K1	107.8	0.037
108168	M4	120.2	0.042
108168	O1	193.1	0.016
108168	M6	185	0.03
108168	S4	174.9	0.016
108168	NU2	137.4	0.034
108168	S6	252.9	0.007
108168	2N2	107.3	0.024
108168	OO1	22.5	0.001
108168	LDA2	169.7	0.004
108168	M1	150.5	0.001
108168	J1	65.5	0.001
108168	RHO1	229.8	0.001
108168	Q1	235.5	0.003
108168	T2	179.6	0.01
108168	R2	181.1	0.001
108168	P1	114.3	0.012
108168	L2	133.8	0.025
108168	K2	182	0.047
108168	M8	17.8	0.021
108169	M2	161	0.483
108169	S2	180.1	0.151
108169	N2	129.3	0.169
108169	K1	122.9	0.017
108169	M4	172.9	0.064
108169	O1	233.3	0.049
108169	M6	182.6	0.011
108169	S4	277.1	0.011
108169	NU2	133.6	0.033
108169	S6	250.1	0.006
108169	2N2	97.5	0.022
108169	OO1	12.6	0.002
108169	LDA2	169.9	0.003
108169	M1	178.1	0.003
108169	J1	68.2	0.004
108169	RHO1	280.7	0.002
108169	Q1	288	0.009
108169	T2	179.3	0.009
108169	R2	180.8	0.001
108169	2Q1	342.7	0.001
108169	P1	131.2	0.006
108169	L2	129.3	0.024
108169	K2	181.6	0.041
108169	M8	344.8	0.012
108170	M2	141.6	0.31
108170	S2	204.5	0.114
108170	N2	99.8	0.092
108170	K1	229.7	0.02
108170	M4	162.5	0.055
108170	O1	203.9	0.019
108170	M6	98.5	0.014
108170	S4	177.9	0.014
108170	NU2	105.5	0.018
108170	S6	196.3	0.003
108170	2N2	58	0.012
108170	OO1	255.4	0.001
108170	LDA2	170.8	0.002
108170	M1	216.8	0.001
108170	J1	242.4	0.001
108170	RHO1	192.9	0.001
108170	Q1	191.1	0.004
108170	T2	201.9	0.007
108170	R2	206.9	0.001
108170	P1	227.8	0.007
108170	L2	99.8	0.013
108170	K2	209.5	0.031
108170	M8	277.5	0.003
108171	M2	139.9	0.989
108171	S2	177.6	0.377
108171	N2	138.4	0.211
108171	K1	24	0.346
108171	M4	319.1	0.202
108171	O1	358.4	0.131
108171	M6	207.6	0.03
108171	MK3	199	0.088
108171	S4	45.6	0.03
108171	MN4	308.9	0.068
108171	S6	220.8	0.003
108171	2N2	14.7	0.048
108171	OO1	108.1	0.025
108171	M1	326.1	0.013
108171	J1	43	0.013
108171	Q1	347.1	0.031
108171	2Q1	258.8	0.052
108171	P1	85.8	0.117
108171	2SM2	9	0.027
108171	M3	203	0.027
108171	L2	112.7	0.075
108171	2MK3	137	0.036
108171	K2	175	0.11
108171	M8	358.6	0.014
108171	MS4	24.5	0.119
108172	M2	137.1	1.049
108172	S2	167.5	0.414
108172	N2	130.3	0.208
108172	K1	20.7	0.387
108172	M4	336.1	0.199
108172	O1	353.4	0.147
108172	M6	235.2	0.034
108172	MK3	223	0.062
108172	S4	34.9	0.028
108172	MN4	304	0.051
108172	S6	242.1	0.006
108172	2N2	51.5	0.024
108172	OO1	112.2	0.029
108172	M1	278.1	0.015
108172	J1	11.7	0.027
108172	Q1	315.4	0.037
108172	2Q1	256.3	0.043
108172	P1	76.5	0.127
108172	2SM2	350.2	0.04
108172	M3	209.5	0.018
108172	L2	85.5	0.056
108172	2MK3	75.1	0.026
108172	K2	161	0.159
108172	M8	185.4	0.007
108172	MS4	30.2	0.135
108173	M2	136.2	1.097
108173	S2	160.1	0.408
108173	N2	125.4	0.19
108173	K1	23.2	0.402
108173	M4	332.8	0.198
108173	O1	341	0.179
108173	M6	208.8	0.048
108173	MK3	248	0.057
108173	S4	24.2	0.033
108173	MN4	289.2	0.04
108173	S6	146.7	0.013
108173	2N2	91.5	0.036
108173	OO1	113.5	0.044
108173	M1	257.8	0.02
108173	J1	356.4	0.045
108173	Q1	283.1	0.054
108173	2Q1	265.2	0.051
108173	P1	48.9	0.134
108173	2SM2	9.4	0.034
108173	M3	257.4	0.011
108173	L2	133.2	0.027
108173	2MK3	5.3	0.04
108173	K2	151.6	0.169
108173	M8	84.2	0.007
108173	MS4	26.5	0.136
108174	M2	151.1	1.758
108174	S2	178.8	0.599
108174	N2	130.4	0.352
108174	K1	123.8	0.279
108174	M4	166.4	0.168
108174	O1	99	0.119
108174	M6	8.4	0.046
108174	MK3	137.9	0.034
108174	S4	221.6	0.012
108174	MN4	171.6	0.041
108174	S6	34.6	0.003
108174	2N2	143.8	0.071
108174	OO1	213.9	0.004
108174	M1	96.7	0.007
108174	J1	94.3	0.022
108174	Q1	80.9	0.022
108174	2Q1	243.6	0.01
108174	P1	111.3	0.044
108174	2SM2	166.6	0.019
108174	M3	222	0.051
108174	L2	244.9	0.021
108174	2MK3	80.1	0.018
108174	K2	164.4	0.186
108174	M8	157.2	0.013
108174	MS4	211.6	0.105
108175	M2	152.7	2.025
108175	S2	178.7	0.663
108175	N2	133	0.386
108175	K1	121.6	0.335
108175	M4	155.9	0.19
108175	O1	99.9	0.141
108175	M6	276.8	0.015
108175	MK3	111.8	0.035
108175	S4	224.4	0.01
108175	MN4	156	0.073
108175	S6	349.4	0.004
108175	2N2	144.1	0.079
108175	OO1	229.5	0.007
108175	M1	79.2	0.004
108175	J1	91	0.029
108175	Q1	82.6	0.029
108175	2Q1	222.2	0.015
108175	P1	131.7	0.052
108175	2SM2	144.6	0.023
108175	M3	204	0.052
108175	L2	183	0.049
108175	2MK3	53.2	0.033
108175	K2	163.9	0.211
108175	M8	248.9	0.017
108175	MS4	203.7	0.1
108176	M2	155.4	2.172
108176	S2	178.9	0.757
108176	N2	133.2	0.427
108176	K1	121.3	0.361
108176	M4	161.5	0.219
108176	O1	103.5	0.152
108176	M6	202.4	0.043
108176	MK3	129.5	0.042
108176	S4	226	0.022
108176	MN4	151.5	0.101
108176	S6	309.9	0.008
108176	2N2	148.3	0.118
108176	OO1	250.8	0.006
108176	M1	69.7	0.007
108176	J1	85.1	0.023
108176	Q1	77.1	0.028
108176	2Q1	221.5	0.01
108176	P1	132.9	0.06
108176	2SM2	137.6	0.029
108176	M3	208.6	0.063
108176	L2	198.3	0.045
108176	2MK3	76.2	0.04
108176	K2	168.9	0.25
108176	M8	290.5	0.04
108176	MS4	209.4	0.115
108177	M2	176.8	0.71
108177	S2	211.8	0.212
108177	N2	158.8	0.131
108177	K1	139	0.116
108177	M4	161.9	0.042
108177	O1	125.1	0.068
108177	M6	336.7	0.022
108177	MK3	56.2	0.029
108177	S4	165.7	0.009
108177	MN4	135.4	0.016
108177	S6	305	0.004
108177	2N2	37.4	0.001
108177	OO1	145.5	0.003
108177	M1	124.1	0.004
108177	J1	105.4	0.009
108177	Q1	95.6	0.002
108177	2Q1	326.1	0.001
108177	P1	143	0.025
108177	2SM2	14.2	0.01
108177	M3	155.8	0.015
108177	L2	147	0.015
108177	2MK3	11.1	0.022
108177	K2	192.8	0.056
108177	M8	62.8	0.013
108177	MS4	161.1	0.029
108178	M2	188.5	0.653
108178	S2	219.4	0.216
108178	N2	153.6	0.12
108178	K1	164.3	0.107
108178	M4	342.2	0.033
108178	O1	144.3	0.068
108178	M6	346.6	0.01
108178	MK3	244.6	0.026
108178	S4	188.3	0.008
108178	MN4	304.9	0.007
108178	S6	315.7	0.005
108178	2N2	179.1	0.012
108178	OO1	110.9	0.001
108178	M1	66.4	0.003
108178	J1	81.3	0.01
108178	Q1	175	0.009
108178	2Q1	354.7	0.004
108178	P1	162.1	0.04
108178	2SM2	326.9	0.011
108178	M3	202.4	0.011
108178	L2	313.6	0.034
108178	2MK3	217.9	0.021
108178	K2	207.1	0.056
108178	M8	151.3	0.011
108178	MS4	64.7	0.019
108179	M2	200.8	0.444
108179	S2	232.2	0.172
108179	N2	184.3	0.077
108179	K1	210.4	0.139
108179	M4	270.2	0.027
108179	O1	175.3	0.099
108179	M6	164.3	0.028
108179	MK3	246.7	0.059
108179	S4	336.3	0.004
108179	MN4	252.4	0.009
108179	S6	269.8	0.006
108179	2N2	281.6	0.012
108179	OO1	224.7	0.001
108179	M1	225.3	0.004
108179	J1	195.3	0.01
108179	Q1	158.5	0.023
108179	2Q1	133.2	0.018
108179	P1	174.1	0.074
108179	2SM2	253.6	0.014
108179	M3	343.9	0.021
108179	L2	274	0.019
108179	2MK3	190.8	0.025
108179	K2	249.4	0.053
108179	M8	252.3	0.002
108179	MS4	302.7	0.024
108180	M2	189.7	0.378
108180	S2	220.9	0.139
108180	N2	156	0.067
108180	K1	149.3	0.068
108180	M4	148.3	0.013
108180	O1	148.8	0.053
108180	M6	191.6	0.015
108180	MK3	298.2	0.015
108180	S4	246.3	0.003
108180	MN4	72.9	0.004
108180	S6	137.6	0.001
108180	2N2	50.6	0.009
108180	OO1	256	0.008
108180	M1	177.2	0.004
108180	J1	143.3	0.007
108180	Q1	123.1	0.011
108180	2Q1	316.2	0.014
108180	P1	174.4	0.023
108180	2SM2	343.3	0.002
108180	M3	4.1	0.01
108180	L2	255.7	0.026
108180	2MK3	247.7	0.007
108180	K2	211.3	0.042
108180	M8	266.2	0.007
108180	MS4	139.1	0.009
108181	M2	191.9	0.438
108181	S2	220.7	0.15
108181	N2	162.9	0.071
108181	K1	158.2	0.08
108181	M4	128.1	0.044
108181	O1	130.6	0.052
108181	M6	225.9	0.014
108181	MK3	56	0.008
108181	S4	349.5	0.005
108181	MN4	59.4	0.016
108181	S6	41.5	0.004
108181	2N2	284.2	0.001
108181	OO1	190.7	0.01
108181	M1	185.5	0.006
108181	J1	158.5	0.006
108181	Q1	82	0.012
108181	2Q1	313.6	0.009
108181	P1	111.7	0.021
108181	2SM2	101.9	0.008
108181	M3	174.9	0.008
108181	L2	280.6	0.023
108181	2MK3	188.9	0.005
108181	K2	216.3	0.04
108181	M8	15.4	0.01
108181	MS4	122.5	0.021
108182	M2	194.7	0.468
108182	S2	226.8	0.163
108182	N2	167.2	0.087
108182	K1	169.8	0.072
108182	M4	86.4	0.041
108182	O1	133	0.052
108182	M6	328.4	0.006
108182	MK3	41.3	0.019
108182	S4	107.2	0.011
108182	MN4	68.6	0.013
108182	S6	321.3	0.001
108182	2N2	354.7	0.007
108182	OO1	188.8	0.005
108182	M1	100.5	0.004
108182	J1	164.9	0.013
108182	Q1	46.9	0.006
108182	2Q1	242.8	0.009
108182	P1	187.7	0.031
108182	2SM2	96.8	0.01
108182	M3	211.7	0.002
108182	L2	106.8	0.014
108182	2MK3	50.2	0.014
108182	K2	204.9	0.043
108182	M8	57.2	0.009
108182	MS4	105.8	0.015
108183	M2	171.4	0.461
108183	S2	212.4	0.1
108183	N2	139.7	0.093
108183	K1	102.7	0.059
108183	M4	44.8	0.04
108183	O1	77.4	0.047
108183	M6	108.7	0.031
108183	MK3	129.5	0.015
108183	S4	317.8	0.002
108183	MN4	352.8	0.016
108183	S6	298	0.002
108183	2N2	293.5	0.013
108183	OO1	116.4	0.003
108183	M1	63.4	0.003
108183	J1	11.7	0.004
108183	Q1	17.4	0.006
108183	2Q1	64.9	0.005
108183	P1	166.6	0.012
108183	2SM2	341.3	0.008
108183	M3	254.8	0.004
108183	L2	242.9	0.022
108183	2MK3	166.5	0.007
108183	K2	261	0.052
108183	M8	166.4	0.016
108183	MS4	47	0.017
108184	M2	186.4	0.406
108184	S2	212.9	0.163
108184	N2	162.5	0.077
108184	K1	129.7	0.044
108184	M4	99.3	0.042
108184	O1	115.9	0.029
108184	M6	235.2	0.011
108184	MK3	173.1	0.004
108184	S4	139.5	0.003
108184	MN4	65.8	0.02
108184	S6	329.1	0.002
108184	2N2	45.3	0.01
108184	OO1	85.5	0.005
108184	M1	155.3	0.006
108184	J1	340.9	0.004
108184	Q1	196	0.009
108184	2Q1	62.4	0.008
108184	P1	200.5	0.041
108184	2SM2	1.2	0.003
108184	M3	112.2	0.001
108184	L2	264.3	0.027
108184	2MK3	196.4	0.006
108184	K2	178.6	0.047
108184	M8	17.7	0.007
108184	MS4	130.1	0.024
108185	M2	219.6	0.337
108185	S2	263	0.117
108185	N2	196	0.046
108185	K1	209	0.131
108185	M4	242.5	0.042
108185	O1	173.7	0.087
108185	M6	217.1	0.016
108185	MK3	177.5	0.023
108185	S4	213.9	0.01
108185	MN4	207.4	0.024
108185	S6	17	0.002
108185	2N2	249.2	0.027
108185	OO1	221.4	0.017
108185	M1	268.7	0.005
108185	J1	108.3	0.013
108185	Q1	123.9	0.014
108185	2Q1	226.2	0.019
108185	P1	144.1	0.047
108185	2SM2	95.4	0.011
108185	M3	338.3	0.004
108185	L2	344.8	0.024
108185	2MK3	178.9	0.021
108185	K2	259.6	0.051
108185	M8	154	0.004
108185	MS4	248.9	0.024
108186	M2	37.1	0.242
108186	S2	73.3	0.1
108186	N2	20.4	0.042
108186	K1	27.4	0.081
108186	M4	118.8	0.024
108186	O1	353.9	0.056
108186	M6	325.6	0.023
108186	MK3	86.3	0.026
108186	S4	64.4	0.004
108186	MN4	77.8	0.004
108186	S6	126.8	0.002
108186	2N2	275.7	0.004
108186	OO1	103.9	0.001
108186	M1	25	0.005
108186	J1	53.7	0.012
108186	Q1	338.8	0.012
108186	2Q1	271.7	0.004
108186	P1	7.2	0.028
108186	2SM2	84.2	0.004
108186	M3	89.8	0.006
108186	L2	142	0.012
108186	2MK3	74.2	0.009
108186	K2	52.4	0.037
108186	M8	58.7	0.008
108186	MS4	71.4	0.006
108187	M2	39.5	0.282
108187	S2	71.3	0.106
108187	N2	2.9	0.052
108187	K1	23.9	0.07
108187	M4	132.6	0.028
108187	O1	354.1	0.048
108187	M6	321.5	0.021
108187	MK3	57.3	0.012
108187	S4	12.8	0.001
108187	MN4	85.9	0.014
108187	S6	181	0.003
108187	2N2	124.5	0.008
108187	OO1	179	0.001
108187	M1	8.1	0.003
108187	J1	46.8	0.006
108187	Q1	348.6	0.012
108187	2Q1	240.2	0.004
108187	P1	16.1	0.029
108187	2SM2	342.5	0.004
108187	M3	103.5	0.007
108187	L2	160.7	0.015
108187	2MK3	55.7	0.009
108187	K2	58.3	0.037
108187	M8	76.6	0.005
108187	MS4	135.3	0.011
108188	M2	38.1	0.297
108188	S2	64.9	0.118
108188	N2	2.5	0.063
108188	K1	16.6	0.063
108188	M4	146.6	0.02
108188	O1	351.1	0.042
108188	M6	327.3	0.021
108188	MK3	15.1	0.008
108188	S4	85.6	0.002
108188	MN4	105.2	0.014
108188	S6	159.2	0.003
108188	2N2	170.3	0.015
108188	OO1	10.3	0.001
108188	M1	16.9	0.003
108188	J1	38.5	0.004
108188	Q1	357.6	0.007
108188	2Q1	254.8	0.002
108188	P1	20.2	0.025
108188	2SM2	321.5	0.004
108188	M3	111.3	0.005
108188	L2	199.7	0.01
108188	2MK3	52.9	0.007
108188	K2	45.2	0.034
108188	M8	31.1	0.004
108188	MS4	175.9	0.01
108189	M2	207.8	0.225
108189	S2	245.2	0.085
108189	N2	204.8	0.022
108189	K1	186.4	0.078
108189	M4	19.6	0.006
108189	O1	162.1	0.029
108189	M6	340.3	0.004
108189	S4	51.6	0.003
108189	NU2	205.2	0.004
108189	S6	5.3	0.004
108189	2N2	201.7	0.003
108189	OO1	210.8	0.001
108189	LDA2	225.2	0.002
108189	M1	174.3	0.002
108189	J1	198.5	0.002
108189	RHO1	151.7	0.001
108189	Q1	150	0.006
108189	T2	243.7	0.005
108189	R2	246.7	0.001
108189	2Q1	137.9	0.001
108189	P1	184.7	0.026
108189	L2	204.8	0.003
108189	K2	248.2	0.023
108189	M8	167.9	0.001
108190	M2	212.8	0.213
108190	S2	227.8	0.08
108190	N2	193.4	0.038
108190	K1	202.8	0.062
108190	M4	258.7	0.038
108190	O1	194.4	0.047
108190	M6	237.5	0.002
108190	S4	190.2	0.011
108190	NU2	196	0.007
108190	S6	198.4	0.001
108190	2N2	173.9	0.005
108190	OO1	211.2	0.002
108190	LDA2	219.8	0.001
108190	M1	198.6	0.003
108190	J1	207	0.004
108190	RHO1	190.8	0.002
108190	Q1	190.2	0.009
108190	T2	227.2	0.005
108190	R2	228.4	0.001
108190	2Q1	186	0.001
108190	P1	202.2	0.02
108190	L2	193.4	0.005
108190	K2	229	0.022
108190	M8	257.4	0.003
108191	M2	195	0.266
108191	S2	258.2	0.094
108191	N2	166.5	0.069
108191	K1	196.9	0.044
108191	M4	139.2	0.009
108191	O1	193	0.038
108191	M6	55.4	0.001
108191	S4	322.8	0.005
108191	NU2	170.3	0.013
108191	S6	202.4	0.003
108191	2N2	137.9	0.009
108191	OO1	200.7	0.002
108191	LDA2	224.4	0.002
108191	M1	195	0.003
108191	J1	198.8	0.003
108191	RHO1	191.4	0.001
108191	Q1	191.1	0.007
108191	T2	255.7	0.006
108191	R2	260.7	0.001
108191	2Q1	189.2	0.001
108191	P1	196.6	0.015
108191	L2	166.5	0.01
108191	K2	263.3	0.026
108191	M8	232.7	0.003
108192	M2	213.2	1.233
108192	S2	236.2	0.41
108192	N2	187.1	0.222
108192	K1	181.9	0.259
108192	M4	264	0.07
108192	O1	171.1	0.154
108192	M6	161.5	0.083
108192	MK3	226.4	0.054
108192	S4	345.4	0.005
108192	MN4	258.8	0.027
108192	S6	313.6	0.005
108192	2N2	212.2	0.067
108192	OO1	256.5	0.006
108192	M1	236.4	0.008
108192	J1	145.1	0.018
108192	Q1	145	0.02
108192	2Q1	102.8	0.007
108192	P1	184.1	0.079
108192	2SM2	231.2	0.016
108192	M3	234.3	0.013
108192	L2	281.3	0.05
108192	2MK3	177	0.045
108192	K2	229.2	0.124
108192	M8	188.3	0.009
108192	MS4	325.6	0.034
108193	M2	213.3	1.369
108193	S2	236.5	0.449
108193	N2	189.8	0.237
108193	K1	183.1	0.282
108193	M4	257.1	0.078
108193	O1	168.3	0.171
108193	M6	158.8	0.097
108193	MK3	219.2	0.057
108193	S4	348	0.008
108193	MN4	233.6	0.032
108193	S6	331.2	0.006
108193	2N2	206.1	0.063
108193	OO1	198.1	0.006
108193	M1	206	0.007
108193	J1	162.2	0.017
108193	Q1	160	0.03
108193	2Q1	265.8	0.006
108193	P1	188.6	0.078
108193	2SM2	212.5	0.017
108193	M3	255.3	0.021
108193	L2	276.1	0.067
108193	2MK3	169.4	0.054
108193	K2	230.7	0.137
108193	M8	196.2	0.009
108193	MS4	315.1	0.057
108194	M2	215	1.407
108194	S2	237	0.457
108194	N2	192.4	0.231
108194	K1	182.4	0.301
108194	M4	251.6	0.07
108194	O1	167.5	0.171
108194	M6	156.1	0.098
108194	MK3	216.4	0.054
108194	S4	333	0.007
108194	MN4	233.6	0.026
108194	S6	347.3	0.008
108194	2N2	208.3	0.073
108194	OO1	183	0.007
108194	M1	188.5	0.006
108194	J1	149.9	0.017
108194	Q1	155.4	0.026
108194	2Q1	283.4	0.009
108194	P1	198.1	0.08
108194	2SM2	202.6	0.018
108194	M3	261.8	0.023
108194	L2	285.9	0.074
108194	2MK3	171.7	0.058
108194	K2	227.8	0.137
108194	M8	206.8	0.011
108194	MS4	320.2	0.046
108195	M2	154.1	1.683
108195	S2	186.1	0.464
108195	N2	146.1	0.269
108195	K1	152.6	0.208
108195	M4	159.9	0.064
108195	O1	141	0.144
108195	M6	320.9	0.126
108195	MK3	10.8	0.034
108195	S4	119.5	0.005
108195	MN4	125.2	0.014
108195	S6	332.6	0.013
108195	2N2	48.9	0.045
108195	OO1	187.3	0.011
108195	M1	157.5	0.007
108195	J1	169.8	0.007
108195	Q1	147.5	0.023
108195	2Q1	175.1	0.003
108195	P1	143.5	0.069
108195	2SM2	52.8	0.01
108195	M3	98.2	0.009
108195	L2	159.6	0.105
108195	2MK3	331.6	0.052
108195	K2	171.7	0.14
108195	M8	221.6	0.01
108195	MS4	218.7	0.04
108196	M2	153.4	2.189
108196	S2	185.5	0.602
108196	N2	147	0.352
108196	K1	147.5	0.268
108196	M4	147.5	0.048
108196	O1	137.1	0.178
108196	M6	322.5	0.165
108196	MK3	2.7	0.052
108196	MN4	104.1	0.018
108196	S6	317	0.019
108196	2N2	41.6	0.062
108196	OO1	178	0.014
108196	M1	163.6	0.008
108196	J1	188.4	0.004
108196	Q1	147.7	0.028
108196	2Q1	185.9	0.011
108196	P1	150.8	0.106
108196	2SM2	34.5	0.009
108196	M3	92.7	0.012
108196	L2	158	0.131
108196	2MK3	327.4	0.071
108196	K2	170.3	0.18
108196	M8	184.4	0.016
108196	MS4	214.2	0.042
108197	M2	155.3	2.423
108197	S2	186.2	0.659
108197	N2	147.6	0.385
108197	K1	150.6	0.289
108197	M4	313.5	0.012
108197	O1	134.8	0.18
108197	M6	326.1	0.165
108197	MK3	358.9	0.074
108197	MN4	36.4	0.006
108197	S6	318	0.022
108197	2N2	45.1	0.064
108197	OO1	174.7	0.017
108197	M1	162	0.01
108197	J1	207.5	0.006
108197	Q1	145.7	0.029
108197	2Q1	210.5	0.011
108197	P1	142.3	0.1
108197	2SM2	44	0.018
108197	M3	97.1	0.014
108197	L2	157	0.132
108197	2MK3	326.9	0.082
108197	K2	167.4	0.198
108197	M8	185.1	0.013
108197	MS4	248.2	0.022
108198	M2	259.1	0.243
108198	S2	302.3	0.09
108198	N2	229.8	0.047
108198	K1	215.8	0.136
108198	M4	135.4	0.015
108198	O1	204	0.084
108198	M6	275.6	0.005
108198	S4	359.8	0.006
108198	NU2	233.7	0.009
108198	S6	153.5	0.004
108198	2N2	200.4	0.006
108198	OO1	227.6	0.004
108198	LDA2	279.2	0.002
108198	M1	209.9	0.006
108198	J1	221.6	0.007
108198	RHO1	199	0.003
108198	Q1	198.2	0.016
108198	T2	300.5	0.005
108198	R2	303.9	0.001
108198	2Q1	192.4	0.002
108198	P1	214.9	0.045
108198	L2	229.8	0.007
108198	K2	305.7	0.025
108198	M8	164.2	0.004
108199	M2	303.3	0.498
108199	S2	333.6	0.162
108199	N2	279.3	0.123
108199	K1	266.5	0.062
108199	M4	227.3	0.009
108199	O1	262.2	0.067
108199	M6	199.3	0.041
108199	S4	333.3	0.015
108199	NU2	282.5	0.024
108199	S6	188.2	0.006
108199	2N2	255.2	0.016
108199	OO1	270.7	0.003
108199	LDA2	317.4	0.003
108199	M1	264.4	0.005
108199	J1	268.6	0.005
108199	RHO1	260.4	0.003
108199	Q1	260.1	0.013
108199	T2	332.3	0.01
108199	R2	334.7	0.001
108199	2Q1	258	0.002
108199	P1	266.2	0.021
108199	L2	279.3	0.018
108199	K2	336	0.044
108199	M8	73.8	0.017
108200	M2	310.5	0.568
108200	S2	342.2	0.192
108200	N2	279.7	0.119
108200	K1	262.9	0.097
108200	M4	54.8	0.048
108200	O1	248.9	0.064
108200	M6	174.9	0.04
108200	S4	121.5	0.007
108200	NU2	283.9	0.023
108200	S6	278.4	0.003
108200	2N2	249	0.016
108200	OO1	276.8	0.003
108200	LDA2	325.2	0.004
108200	M1	255.9	0.005
108200	J1	269.7	0.005
108200	RHO1	243	0.002
108200	Q1	242	0.012
108200	T2	340.9	0.011
108200	R2	343.4	0.002
108200	2Q1	235.1	0.002
108200	P1	261.9	0.032
108200	L2	279.7	0.017
108200	K2	344.7	0.052
108200	M8	176.3	0.003
108201	M2	309.5	0.686
108201	S2	341.2	0.246
108201	N2	276.5	0.173
108201	K1	267.8	0.151
108201	M4	44.3	0.042
108201	O1	232.8	0.078
108201	M6	42.8	0.011
108201	S4	86.3	0.011
108201	NU2	280.9	0.034
108201	S6	293.6	0.01
108201	2N2	243.4	0.023
108201	OO1	302.7	0.003
108201	LDA2	324.3	0.005
108201	M1	250.3	0.006
108201	J1	285.1	0.006
108201	RHO1	217.9	0.003
108201	Q1	215.5	0.015
108201	T2	339.9	0.015
108201	R2	342.4	0.002
108201	2Q1	198.2	0.002
108201	P1	265.2	0.05
108201	L2	276.5	0.025
108201	K2	343.8	0.067
108201	M8	158.1	0.011
108202	M2	163.4	0.593
108202	S2	193.1	0.187
108202	N2	141.8	0.129
108202	K1	124.3	0.112
108202	M4	184.1	0.028
108202	O1	102.8	0.08
108202	M6	347.8	0.032
108202	S4	149.4	0.007
108202	NU2	144.7	0.025
108202	S6	0.5	0.003
108202	2N2	120.2	0.017
108202	OO1	145.8	0.003
108202	LDA2	177.2	0.004
108202	M1	113.6	0.006
108202	J1	134.9	0.006
108202	RHO1	93.7	0.003
108202	Q1	92.2	0.015
108202	T2	191.9	0.011
108202	R2	194.3	0.001
108202	2Q1	81.6	0.002
108202	P1	122.7	0.037
108202	L2	141.8	0.018
108202	K2	195.5	0.051
108202	M8	325.4	0.002
108203	M2	166.3	0.66
108203	S2	192.4	0.223
108203	N2	141.9	0.155
108203	K1	125.3	0.136
108203	M4	211.7	0.043
108203	O1	100.3	0.085
108203	M6	349.3	0.014
108203	S4	103.9	0.01
108203	NU2	145.2	0.03
108203	S6	294.3	0.006
108203	2N2	117.5	0.021
108203	OO1	150.4	0.004
108203	LDA2	178.4	0.005
108203	M1	112.8	0.006
108203	J1	137.8	0.007
108203	RHO1	89.6	0.003
108203	Q1	87.9	0.016
108203	T2	191.3	0.013
108203	R2	193.3	0.002
108203	2Q1	75.5	0.002
108203	P1	123.5	0.045
108203	L2	141.9	0.022
108203	K2	194.4	0.061
108203	M8	357.4	0.011
108204	M2	169.9	0.796
108204	S2	194.4	0.273
108204	N2	138	0.188
108204	K1	129.4	0.176
108204	M4	204.8	0.049
108204	O1	98.9	0.104
108204	M6	155.5	0.017
108204	S4	95.1	0.011
108204	NU2	142.3	0.037
108204	S6	43.1	0.003
108204	2N2	106.2	0.025
108204	OO1	160	0.004
108204	LDA2	181.3	0.006
108204	M1	114.2	0.007
108204	J1	144.6	0.008
108204	RHO1	85.9	0.004
108204	Q1	83.8	0.02
108204	T2	193.4	0.016
108204	R2	195.3	0.002
108204	2Q1	68.6	0.003
108204	P1	127.2	0.058
108204	L2	138	0.027
108204	K2	196.4	0.074
108204	M8	71.6	0.019
108205	M2	154.5	0.34
108205	S2	166.6	0.074
108205	N2	120.4	0.077
108205	K1	63	0.061
108205	M4	181	0.025
108205	O1	32.5	0.019
108205	M6	359.8	0.007
108205	S4	337.5	0.014
108205	NU2	125	0.015
108205	S6	102.1	0.004
108205	2N2	86.2	0.01
108205	OO1	93.5	0.001
108205	LDA2	160.2	0.002
108205	M1	47.7	0.001
108205	J1	78.1	0.001
108205	RHO1	19.4	0.001
108205	Q1	17.3	0.004
108205	T2	166.1	0.004
108205	R2	167	0.001
108205	P1	60.8	0.02
108205	L2	120.4	0.011
108205	K2	167.5	0.02
108205	M8	248	0.011
108206	M2	148.5	0.374
108206	S2	174.6	0.128
108206	N2	122.2	0.098
108206	K1	82.9	0.096
108206	M4	144.1	0.02
108206	O1	48.7	0.039
108206	M6	25.2	0.014
108206	S4	251.1	0.009
108206	NU2	125.8	0.019
108206	S6	110.6	0.009
108206	2N2	95.9	0.013
108206	OO1	117.2	0.002
108206	LDA2	160.7	0.003
108206	M1	65.8	0.003
108206	J1	99.9	0.003
108206	RHO1	34.1	0.001
108206	Q1	31.7	0.008
108206	T2	173.6	0.008
108206	R2	175.6	0.001
108206	2Q1	14.7	0.001
108206	P1	80.4	0.032
108206	L2	122.2	0.014
108206	K2	176.7	0.035
108206	M8	138.2	0.007
108207	M2	144.8	0.434
108207	S2	182.2	0.207
108207	N2	113.8	0.085
108207	K1	81.1	0.167
108207	M4	33.5	0.048
108207	O1	53.3	0.056
108207	M6	152.8	0.004
108207	S4	163	0.022
108207	NU2	118	0.016
108207	S6	145.2	0.008
108207	2N2	82.8	0.011
108207	OO1	108.9	0.002
108207	LDA2	162.2	0.003
108207	M1	67.2	0.004
108207	J1	94.9	0.004
108207	RHO1	41.4	0.002
108207	Q1	39.5	0.011
108207	T2	180.7	0.012
108207	R2	183.6	0.002
108207	2Q1	25.8	0.001
108207	P1	79.1	0.055
108207	L2	113.8	0.012
108207	K2	185.2	0.056
108207	M8	12	0.004
108208	M2	144.4	1.133
108208	S2	177.1	0.437
108208	N2	117.5	0.26
108208	K1	84	0.2
108208	M4	205.2	0.024
108208	O1	51.7	0.099
108208	M6	207.8	0.028
108208	S4	301	0.014
108208	NU2	121.2	0.051
108208	S6	209.7	0.003
108208	2N2	90.7	0.035
108208	OO1	116.3	0.004
108208	LDA2	159.6	0.008
108208	M1	67.9	0.007
108208	J1	100	0.008
108208	RHO1	37.9	0.004
108208	Q1	35.7	0.019
108208	T2	175.8	0.026
108208	R2	178.4	0.003
108208	2Q1	19.7	0.003
108208	P1	81.6	0.066
108208	L2	117.5	0.037
108208	K2	179.7	0.119
108208	M8	50.7	0.026
108209	M2	149	1.289
108209	S2	176.2	0.479
108209	N2	121.6	0.262
108209	K1	83	0.262
108209	M4	107.3	0.004
108209	O1	64.4	0.125
108209	M6	244.7	0.026
108209	S4	295.9	0.008
108209	NU2	125.3	0.051
108209	S6	115.5	0.002
108209	2N2	94.2	0.035
108209	OO1	101.7	0.005
108209	LDA2	161.6	0.009
108209	M1	73.7	0.009
108209	J1	92.3	0.01
108209	RHO1	56.4	0.005
108209	Q1	55.1	0.024
108209	T2	175.1	0.028
108209	R2	177.2	0.004
108209	2Q1	45.8	0.003
108209	P1	81.7	0.087
108209	L2	121.6	0.038
108209	K2	178.3	0.13
108209	M8	7	0.015
108210	M2	154.6	1.323
108210	S2	177.1	0.48
108210	N2	124.8	0.236
108210	K1	86.2	0.268
108210	M4	96	0.073
108210	O1	83.9	0.131
108210	M6	71.4	0.021
108210	S4	27.4	0.008
108210	NU2	128.9	0.046
108210	S6	244.4	0.012
108210	2N2	95	0.031
108210	OO1	88.5	0.006
108210	LDA2	165.1	0.009
108210	M1	85.1	0.009
108210	J1	87.3	0.01
108210	RHO1	83	0.005
108210	Q1	82.8	0.025
108210	T2	176.2	0.028
108210	R2	178	0.004
108210	2Q1	81.7	0.003
108210	P1	86.1	0.089
108210	L2	124.8	0.034
108210	K2	178.9	0.13
108210	M8	264.3	0.043
108211	M2	50.1	0.243
108211	S2	91.5	0.093
108211	N2	16.9	0.063
108211	K1	313	0.076
108211	M4	30	0.046
108211	O1	276.7	0.057
108211	M6	96.8	0.014
108211	S4	206.4	0.008
108211	NU2	21.4	0.012
108211	S6	338.8	0.001
108211	2N2	343.8	0.008
108211	OO1	349.3	0.002
108211	LDA2	69.3	0.002
108211	M1	294.8	0.004
108211	J1	331	0.004
108211	RHO1	261.1	0.002
108211	Q1	258.7	0.011
108211	T2	89.8	0.006
108211	R2	93	0.001
108211	2Q1	240.6	0.001
108211	P1	310.3	0.025
108211	L2	16.9	0.009
108211	K2	94.8	0.025
108211	M8	317.6	0.007
108212	M2	68.1	0.247
108212	S2	101.1	0.096
108212	N2	41	0.062
108212	K1	353.3	0.093
108212	M4	72.9	0.016
108212	O1	325.6	0.051
108212	M6	219.5	0.005
108212	S4	268.4	0.008
108212	NU2	44.6	0.012
108212	S6	74.3	0.004
108212	2N2	13.8	0.008
108212	OO1	20.9	0.002
108212	LDA2	83.4	0.002
108212	M1	339.4	0.004
108212	J1	7	0.004
108212	RHO1	313.8	0.002
108212	Q1	311.9	0.01
108212	T2	99.7	0.006
108212	R2	102.3	0.001
108212	2Q1	298.2	0.001
108212	P1	351.2	0.031
108212	L2	41	0.009
108212	K2	103.7	0.026
108212	M8	225.7	0.002
108213	M2	78.7	0.261
108213	S2	116.5	0.083
108213	N2	69.2	0.039
108213	K1	28.3	0.099
108213	M4	250.1	0.029
108213	O1	13.6	0.063
108213	M6	54.2	0.011
108213	S4	46.4	0.017
108213	NU2	70.5	0.008
108213	S6	73.8	0.003
108213	2N2	59.6	0.005
108213	OO1	42.9	0.003
108213	LDA2	96.3	0.002
108213	M1	20.9	0.004
108213	J1	35.5	0.005
108213	RHO1	7.4	0.002
108213	Q1	6.3	0.012
108213	T2	115	0.005
108213	R2	118	0.001
108213	2Q1	359.1	0.002
108213	P1	27.2	0.033
108213	L2	69.2	0.006
108213	K2	119.5	0.023
108213	M8	189.8	0.007
108214	M2	42.4	0.36
108214	S2	77.2	0.16
108214	N2	8.3	0.098
108214	K1	314.2	0.104
108214	M4	75	0.076
108214	O1	296	0.074
108214	M6	163.1	0.035
108214	S4	184.3	0.032
108214	NU2	12.9	0.019
108214	S6	173.7	0.005
108214	2N2	334.2	0.013
108214	OO1	332.4	0.003
108214	LDA2	58.6	0.003
108214	M1	305.1	0.005
108214	J1	323.2	0.006
108214	RHO1	288.2	0.003
108214	Q1	286.9	0.014
108214	T2	75.7	0.009
108214	R2	78.5	0.001
108214	2Q1	277.9	0.002
108214	P1	312.9	0.034
108214	L2	8.3	0.014
108214	K2	79.9	0.043
108214	M8	268.2	0.007
108215	M2	62.1	0.48
108215	S2	96.3	0.179
108215	N2	24.5	0.122
108215	K1	357.8	0.171
108215	M4	129.6	0.078
108215	O1	330.3	0.1
108215	M6	190.5	0.022
108215	S4	265.6	0.021
108215	NU2	29.6	0.024
108215	S6	82.9	0.007
108215	2N2	346.9	0.016
108215	OO1	25.4	0.004
108215	LDA2	78	0.003
108215	M1	344.1	0.007
108215	J1	11.5	0.008
108215	RHO1	318.5	0.004
108215	Q1	316.6	0.019
108215	T2	94.9	0.011
108215	R2	97.6	0.001
108215	2Q1	303	0.003
108215	P1	355.8	0.057
108215	L2	24.5	0.017
108215	K2	99	0.049
108215	M8	102.1	0.002
108216	M2	72.9	0.53
108216	S2	120.8	0.152
108216	N2	52.7	0.083
108216	K1	8.3	0.231
108216	M4	113.9	0.021
108216	O1	2.3	0.129
108216	M6	94.9	0.046
108216	S4	294.3	0.01
108216	NU2	55.4	0.016
108216	S6	342.1	0.01
108216	2N2	32.4	0.011
108216	OO1	14.2	0.006
108216	LDA2	95.2	0.004
108216	M1	5.3	0.009
108216	J1	11.2	0.01
108216	RHO1	359.8	0.005
108216	Q1	359.4	0.025
108216	T2	118.8	0.009
108216	R2	122.6	0.001
108216	2Q1	356.4	0.003
108216	P1	7.9	0.077
108216	L2	52.7	0.012
108216	K2	124.6	0.041
108216	M8	170.1	0.01
108217	M2	64.8	1.129
108217	S2	100.3	0.411
108217	N2	36.7	0.222
108217	K1	1.3	0.425
108217	M4	95.8	0.086
108217	O1	336	0.261
108217	M6	27.4	0.014
108217	S4	205.3	0.025
108217	NU2	40.5	0.043
108217	S6	157.7	0.006
108217	2N2	8.6	0.03
108217	OO1	26.6	0.011
108217	LDA2	81.3	0.008
108217	M1	348.7	0.019
108217	J1	13.9	0.021
108217	RHO1	325.2	0.01
108217	Q1	323.5	0.051
108217	T2	98.8	0.024
108217	R2	101.6	0.003
108217	2Q1	310.9	0.007
108217	P1	359.5	0.141
108217	L2	36.7	0.032
108217	K2	103.1	0.112
108217	M8	57.4	0.004
108218	M2	65.5	1.192
108218	S2	99.8	0.424
108218	N2	38.9	0.237
108218	K1	0	0.426
108218	M4	99	0.076
108218	O1	333	0.27
108218	M6	27	0.019
108218	S4	219.4	0.025
108218	NU2	42.5	0.046
108218	S6	190.4	0.002
108218	2N2	12.3	0.031
108218	OO1	27	0.012
108218	LDA2	81.4	0.008
108218	M1	346.5	0.019
108218	J1	13.4	0.021
108218	RHO1	321.5	0.01
108218	Q1	319.6	0.052
108218	T2	98.4	0.025
108218	R2	101.1	0.003
108218	2Q1	306.2	0.007
108218	P1	358	0.141
108218	L2	38.9	0.034
108218	K2	102.5	0.115
108218	M8	140.2	0.005
108219	M2	66.9	1.248
108219	S2	100.9	0.447
108219	N2	37.4	0.25
108219	K1	357.9	0.436
108219	M4	77.2	0.057
108219	O1	330.2	0.283
108219	M6	30.6	0.027
108219	S4	214.7	0.02
108219	NU2	41.4	0.048
108219	S6	42.5	0.002
108219	2N2	7.9	0.033
108219	OO1	25.6	0.012
108219	LDA2	82.7	0.009
108219	M1	344.1	0.02
108219	J1	11.6	0.022
108219	RHO1	318.4	0.011
108219	Q1	316.5	0.055
108219	T2	99.5	0.026
108219	R2	102.2	0.004
108219	2Q1	302.8	0.007
108219	P1	355.9	0.144
108219	L2	37.4	0.036
108219	K2	103.6	0.122
108219	M8	214	0.004
108220	M2	201.9	0.583
108220	S2	223.9	0.193
108220	N2	173.1	0.121
108220	K1	156.5	0.223
108220	M4	69.4	0.03
108220	O1	140.6	0.114
108220	M6	197.9	0.013
108220	S4	181.4	0.016
108220	NU2	177	0.023
108220	S6	302.8	0.007
108220	2N2	144.4	0.016
108220	OO1	172.3	0.005
108220	LDA2	212.1	0.004
108220	M1	148.5	0.008
108220	J1	164.3	0.009
108220	RHO1	133.8	0.004
108220	Q1	132.7	0.022
108220	T2	223	0.011
108220	R2	224.7	0.002
108220	2Q1	124.9	0.003
108220	P1	155.3	0.074
108220	L2	173.1	0.017
108220	K2	225.6	0.053
108220	M8	20.6	0.013
108221	M2	202.5	0.612
108221	S2	226.6	0.185
108221	N2	180.4	0.153
108221	K1	159.3	0.242
108221	M4	28	0.032
108221	O1	141.8	0.159
108221	M6	177.2	0.019
108221	S4	183.7	0.017
108221	NU2	183.4	0.03
108221	S6	310	0.006
108221	2N2	158.4	0.02
108221	OO1	176.9	0.007
108221	LDA2	213.7	0.004
108221	M1	150.6	0.011
108221	J1	168.1	0.013
108221	RHO1	134.3	0.006
108221	Q1	133	0.031
108221	T2	225.6	0.011
108221	R2	227.5	0.001
108221	2Q1	124.3	0.004
108221	P1	158.1	0.08
108221	L2	180.4	0.022
108221	K2	228.5	0.05
108221	M8	32.9	0.005
108222	M2	200.7	0.65
108222	S2	228.1	0.188
108222	N2	184.5	0.164
108222	K1	159.6	0.241
108222	M4	358.4	0.05
108222	O1	139.3	0.173
108222	M6	186.3	0.017
108222	S4	204.7	0.013
108222	NU2	186.7	0.032
108222	S6	297	0.007
108222	2N2	168.3	0.022
108222	OO1	179.9	0.007
108222	LDA2	213.4	0.005
108222	M1	149.5	0.012
108222	J1	169.7	0.014
108222	RHO1	130.7	0.007
108222	Q1	129.3	0.033
108222	T2	227	0.011
108222	R2	229.1	0.002
108222	2Q1	119.2	0.004
108222	P1	158.2	0.08
108222	L2	184.5	0.024
108222	K2	230.3	0.051
108222	M8	1.1	0.01
108223	M2	152.5	0.094
108223	S2	180.4	0.016
108223	N2	87.3	0.006
108223	K1	187.2	0.016
108223	M4	136.1	0.008
108223	O1	169	0.011
108223	M6	321.5	0.001
108223	MK3	304.9	0.007
108223	S4	160.2	0.006
108223	MN4	128.9	0.007
108223	S6	45.7	0.003
108223	2N2	333.6	0.013
108223	OO1	325.6	0.004
108223	M1	127.6	0.002
108223	J1	186.6	0.006
108223	Q1	50.1	0.005
108223	2Q1	19.7	0.01
108223	2SM2	334.4	0.009
108223	M3	107.8	0.005
108223	L2	330.1	0.012
108223	2MK3	266.5	0.004
108223	M8	259.1	0.001
108223	MS4	151.8	0.011
108224	M2	188.9	0.103
108224	S2	237.9	0.026
108224	N2	131.8	0.023
108224	K1	201.6	0.042
108224	M4	131.3	0.018
108224	O1	185	0.026
108224	M6	83	0.005
108224	MK3	41.2	0.006
108224	S4	288.1	0.001
108224	MN4	95.1	0.004
108224	S6	192.6	0.003
108224	2N2	207.7	0.013
108224	OO1	164	0.006
108224	M1	9.1	0.007
108224	J1	152.9	0.014
108224	Q1	315.4	0.006
108224	2Q1	124.6	0.002
108224	2SM2	241.7	0.006
108224	M3	130.7	0.006
108224	L2	155.5	0.002
108224	2MK3	306.1	0.011
108224	M8	47.9	0.003
108224	MS4	178.3	0.011
108225	M2	175.9	0.228
108225	S2	231.4	0.061
108225	N2	159.1	0.039
108225	K1	106	0.064
108225	M4	320.8	0.009
108225	O1	73.3	0.028
108225	M6	220.6	0.004
108225	MK3	129.9	0.001
108225	S4	0	0.002
108225	MN4	271.3	0.003
108225	S6	276.6	0.008
108225	2N2	159.2	0.002
108225	OO1	74.6	0.011
108225	M1	114	0.017
108225	J1	352.9	0.022
108225	Q1	217	0.002
108225	2Q1	92.7	0.006
108225	2SM2	332	0.024
108225	M3	4.9	0.002
108225	L2	251.5	0.019
108225	2MK3	113.7	0.012
108225	M8	123.6	0.005
108225	MS4	18.7	0.012
108226	M2	142.1	0.188
108226	S2	230.4	0.013
108226	N2	145.5	0.024
108226	K1	136.7	0.053
108226	M4	137	0.012
108226	O1	114.4	0.024
108226	M6	208.6	0.013
108226	MK3	56.1	0.02
108226	S4	73.3	0.003
108226	MN4	70	0.007
108226	S6	165.6	0.003
108226	2N2	102.3	0.021
108226	OO1	133.8	0.003
108226	M1	237.7	0.006
108226	J1	110.5	0.01
108226	Q1	132.8	0.013
108226	2Q1	231.1	0.003
108226	2SM2	43	0.005
108226	M3	236.2	0.01
108226	L2	38.6	0.019
108226	2MK3	11.9	0.015
108226	M8	166.4	0.004
108226	MS4	55.2	0.005
108227	M2	159.2	0.13
108227	S2	219	0.025
108227	N2	118.8	0.028
108227	K1	190.5	0.047
108227	M4	267.9	0.012
108227	O1	163.2	0.038
108227	M6	216.9	0.009
108227	MK3	305.1	0.01
108227	S4	25.4	0.004
108227	MN4	154.6	0.002
108227	S6	74.2	0.002
108227	2N2	41	0.009
108227	OO1	83.8	0.003
108227	M1	191	0.004
108227	J1	54.9	0.013
108227	Q1	124	0.004
108227	2Q1	16.5	0.005
108227	2SM2	290.9	0.009
108227	M3	241.3	0.01
108227	L2	141.3	0.018
108227	2MK3	282.9	0.007
108227	M8	359	0.002
108227	MS4	347.8	0.008
108228	M2	168.9	0.168
108228	S2	196.1	0.05
108228	N2	109.8	0.005
108228	K1	196.6	0.052
108228	M4	297.2	0.012
108228	O1	178.3	0.063
108228	M6	224	0.009
108228	MK3	249.6	0.023
108228	S4	306.9	0.013
108228	MN4	137.6	0.003
108228	S6	6.4	0.002
108228	2N2	221	0.006
108228	OO1	267.5	0.012
108228	M1	296.7	0.007
108228	J1	137.2	0.009
108228	Q1	259.6	0.011
108228	2Q1	139.6	0.003
108228	2SM2	10.8	0.008
108228	M3	144.3	0.003
108228	L2	252.2	0.002
108228	2MK3	239.5	0.017
108228	M8	359.2	0.006
108228	MS4	213.2	0.011
108229	M2	55.7	0.054
108229	S2	132.3	0.039
108229	N2	0.4	0.017
108229	K1	357.7	0.004
108229	M4	221.5	0.005
108229	O1	127.8	0.004
108229	M6	169.5	0.025
108229	MK3	279.9	0.011
108229	S4	126.6	0.005
108229	MN4	270	0.012
108229	S6	252.6	0.003
108229	2N2	74.5	0.005
108229	OO1	30.6	0.002
108229	M1	114.4	0.001
108229	J1	144	0.01
108229	Q1	27	0.002
108229	2Q1	192.2	0.003
108229	2SM2	180.9	0.005
108229	M3	9.8	0.003
108229	L2	194.4	0.032
108229	2MK3	227.6	0.006
108229	M8	80.2	0.012
108229	MS4	89.9	0.021
108230	M2	141.7	0.248
108230	S2	151.9	0.072
108230	N2	27.8	0.005
108230	K1	58.2	0.023
108230	M4	278.7	0.01
108230	O1	301.9	0.005
108230	M6	192.1	0.018
108230	MK3	350	0.008
108230	S4	80.9	0.003
108230	MN4	333.4	0.006
108230	S6	305.4	0.007
108230	2N2	122.1	0.021
108230	OO1	183.6	0.002
108230	M1	115.3	0.004
108230	J1	214.1	0.012
108230	Q1	90.3	0.005
108230	2Q1	260.5	0.003
108230	2SM2	283	0.012
108230	M3	337.2	0.001
108230	L2	181.2	0.071
108230	2MK3	228.8	0.002
108230	M8	319.9	0.005
108230	MS4	357.6	0.006
108231	M2	150.7	0.405
108231	S2	204.6	0.07
108231	N2	122.8	0.062
108231	K1	132.3	0.049
108231	M4	79.2	0.055
108231	O1	58.7	0.004
108231	M6	71.7	0.014
108231	MK3	60.3	0.026
108231	S4	267.1	0.009
108231	MN4	77.5	0.015
108231	S6	275.8	0.004
108231	2N2	120.1	0.009
108231	OO1	160.1	0.003
108231	M1	8.2	0.004
108231	J1	138.5	0.007
108231	Q1	319.9	0.01
108231	2Q1	308.1	0.006
108231	2SM2	356.7	0.003
108231	M3	177.3	0.02
108231	L2	87.5	0.055
108231	2MK3	25.1	0.02
108231	M8	138.9	0.003
108231	MS4	134.9	0.02
108232	M2	114.8	3.563
108232	S2	141.3	0.95
108232	N2	69.1	0.488
108232	K1	90.8	0.28
108232	M4	93	0.11
108232	O1	82.2	0.136
108232	M6	193.8	0.367
108232	MK3	39.9	0.086
108232	MN4	22.3	0.031
108232	S6	171.6	0.013
108232	2N2	97.9	0.201
108232	OO1	137.1	0.013
108232	M1	187.8	0.013
108232	Q1	68.2	0.005
108232	2Q1	303.4	0.016
108232	P1	81.7	0.043
108232	2SM2	60	0.038
108232	M3	176.6	0.059
108232	L2	133.5	0.194
108232	2MK3	347.6	0.114
108232	K2	129.9	0.33
108232	M8	183.1	0.036
108232	MS4	120.6	0.034
108233	M2	114.5	4.349
108233	S2	143.8	1.117
108233	N2	72.5	0.568
108233	K1	88.1	0.339
108233	M4	54.1	0.401
108233	O1	84.6	0.147
108233	M6	196.5	0.391
108233	MK3	23.7	0.131
108233	S4	267	0.008
108233	MN4	19.3	0.074
108233	S6	236	0.016
108233	2N2	101.5	0.221
108233	OO1	162.9	0.014
108233	M1	190	0.023
108233	J1	319	0.011
108233	Q1	344	0.008
108233	2Q1	279.8	0.025
108233	P1	87.6	0.05
108233	2SM2	38.3	0.034
108233	M3	172.7	0.092
108233	L2	136.7	0.245
108233	2MK3	343	0.142
108233	K2	134.3	0.341
108233	M8	121.5	0.092
108233	MS4	103.8	0.112
108234	M2	114.9	4.494
108234	S2	143.8	1.149
108234	N2	75	0.592
108234	K1	88.3	0.352
108234	M4	51.2	0.383
108234	O1	80.9	0.145
108234	M6	197	0.436
108234	MK3	21.1	0.128
108234	S4	239.6	0.005
108234	MN4	16.1	0.075
108234	S6	228.7	0.019
108234	2N2	104	0.233
108234	OO1	161.2	0.017
108234	M1	184.9	0.023
108234	J1	309.2	0.015
108234	Q1	354.5	0.01
108234	2Q1	279.2	0.029
108234	P1	74.4	0.039
108234	2SM2	42.8	0.025
108234	M3	175.5	0.097
108234	L2	143.7	0.292
108234	2MK3	339.7	0.149
108234	K2	132.5	0.348
108234	M8	127.2	0.105
108234	MS4	105.5	0.104
108235	M2	172.2	1.489
108235	S2	219	0.47
108235	N2	125.6	0.211
108235	K1	124.9	0.199
108235	M4	52.7	0.201
108235	O1	100.6	0.111
108235	M6	213.3	0.019
108235	MK3	9.2	0.098
108235	S4	222.6	0.023
108235	MN4	36.3	0.059
108235	S6	350.1	0.002
108235	2N2	66.2	0.067
108235	OO1	168.4	0.011
108235	M1	121.1	0.007
108235	J1	144.3	0.011
108235	Q1	69	0.023
108235	2Q1	34.6	0.013
108235	P1	145.1	0.063
108235	2SM2	56	0.01
108235	M3	23.5	0.023
108235	L2	251.1	0.013
108235	2MK3	342.5	0.063
108235	K2	212.9	0.128
108235	M8	183.4	0.022
108235	MS4	136.2	0.128
108236	M2	169.3	0.919
108236	S2	204.6	0.306
108236	N2	145.4	0.149
108236	K1	143.8	0.13
108236	M4	259.3	0.03
108236	O1	102	0.079
108236	M6	154.7	0.027
108236	MK3	272.7	0.02
108236	S4	130	0.004
108236	MN4	326.5	0.018
108236	S6	149.5	0.009
108236	2N2	354.2	0.057
108236	OO1	40.2	0.009
108236	M1	199.6	0.006
108236	J1	68.5	0.023
108236	Q1	65.2	0.002
108236	2Q1	12.2	0.012
108236	P1	122.9	0.045
108236	2SM2	3	0.022
108236	M3	276	0.028
108236	L2	207.2	0.045
108236	2MK3	264.6	0.022
108236	K2	195.2	0.077
108236	M8	48.3	0.022
108236	MS4	321.7	0.019
108237	M2	161.3	0.743
108237	S2	178.1	0.249
108237	N2	135.1	0.159
108237	K1	179.9	0.142
108237	M4	180.8	0.104
108237	O1	142	0.08
108237	M6	310.2	0.041
108237	MK3	170.1	0.018
108237	S4	21.9	0.02
108237	MN4	175.4	0.053
108237	S6	132.7	0.005
108237	2N2	94.2	0.047
108237	OO1	158.8	0.028
108237	M1	57.5	0.011
108237	J1	221.4	0.038
108237	Q1	184.3	0.017
108237	2Q1	8.2	0.005
108237	P1	43.9	0.03
108237	2SM2	9.5	0.014
108237	M3	186.4	0.034
108237	L2	167.9	0.043
108237	2MK3	116.4	0.019
108237	K2	154.5	0.113
108237	M8	266.3	0.018
108237	MS4	273.5	0.045
108238	M2	209.7	0.12
108238	S2	241.6	0.095
108238	N2	183.6	0.023
108238	K1	193.8	0.042
108238	M4	206.7	0.01
108238	O1	204.1	0.025
108238	M6	133.6	0.016
108238	MK3	296.4	0.006
108238	S4	132.8	0.005
108238	MN4	194.2	0.008
108238	S6	222	0.004
108238	2N2	354.2	0.002
108238	OO1	142.3	0.008
108238	M1	229.3	0.006
108238	J1	318.5	0.011
108238	Q1	155	0.016
108238	2Q1	4	0.009
108238	P1	234	0.006
108238	2SM2	9.3	0.006
108238	M3	285.6	0.004
108238	L2	167.6	0.025
108238	2MK3	143.5	0.006
108238	K2	331	0.016
108238	M8	110.9	0.012
108238	MS4	248.2	0.01
108239	M2	221.3	0.307
108239	S2	267.4	0.181
108239	N2	179.5	0.044
108239	K1	186.9	0.098
108239	M4	218.5	0.017
108239	O1	201.4	0.034
108239	M6	191.9	0.009
108239	MK3	322.6	0.005
108239	S4	341.9	0.006
108239	MN4	265.6	0.009
108239	S6	52.9	0.001
108239	2N2	329.7	0.028
108239	OO1	212.3	0.013
108239	M1	141.9	0.002
108239	J1	336.9	0.009
108239	Q1	132.7	0.01
108239	2Q1	336.3	0.005
108239	P1	235.7	0.048
108239	2SM2	4.5	0.004
108239	M3	279.6	0.008
108239	L2	159.9	0.018
108239	2MK3	299.1	0.005
108239	K2	40.5	0.035
108239	M8	338.1	0.003
108239	MS4	264.3	0.026
108240	M2	215	0.356
108240	S2	267.5	0.142
108240	N2	190.3	0.047
108240	K1	242	0.06
108240	M4	89.3	0.026
108240	O1	191.5	0.056
108240	M6	290	0.009
108240	MK3	57.2	0.024
108240	S4	164.9	0.005
108240	MN4	357.4	0.014
108240	S6	77.6	0.004
108240	2N2	113.1	0.014
108240	OO1	338	0.002
108240	M1	181.3	0.01
108240	J1	266.2	0.017
108240	Q1	247.3	0.009
108240	2Q1	119.1	0.017
108240	P1	184.9	0.018
108240	2SM2	142.6	0.011
108240	M3	4.5	0.01
108240	L2	140.2	0.007
108240	2MK3	9	0.01
108240	K2	114.6	0.008
108240	M8	229.1	0.003
108240	MS4	120	0.024
108241	M2	226.5	0.357
108241	S2	270.4	0.152
108241	N2	207.1	0.061
108241	K1	191.9	0.047
108241	M4	283.1	0.054
108241	O1	208.7	0.019
108241	M6	203.3	0.012
108241	MK3	239.3	0.015
108241	S4	20.7	0.01
108241	MN4	248.5	0.029
108241	S6	177.7	0.003
108241	2N2	123	0.01
108241	OO1	171.2	0.007
108241	M1	332.9	0.004
108241	J1	256.5	0.007
108241	Q1	108	0.012
108241	2Q1	212.6	0.012
108241	2SM2	154.6	0.018
108241	M3	338.4	0.016
108241	L2	249.9	0.01
108241	2MK3	231.2	0.015
108241	M8	14.7	0.005
108241	MS4	317.5	0.054
108242	M2	204.4	0.354
108242	S2	244.4	0.158
108242	N2	207.9	0.066
108242	K1	222.8	0.039
108242	M4	161	0.025
108242	O1	177.2	0.032
108242	M6	333	0.009
108242	MK3	165.2	0.006
108242	S4	240.3	0.005
108242	MN4	93.1	0.011
108242	S6	217.8	0.004
108242	2N2	320.6	0.027
108242	OO1	237.3	0.008
108242	M1	244.4	0.003
108242	J1	94.1	0.006
108242	Q1	144.1	0.012
108242	2Q1	9.4	0.007
108242	2SM2	4.7	0.019
108242	M3	239.4	0.007
108242	L2	40.6	0.01
108242	2MK3	100.5	0.01
108242	M8	48.8	0.009
108242	MS4	210.1	0.037
108243	M2	166.5	0.333
108243	S2	198.7	0.158
108243	N2	91	0.056
108243	K1	108.4	0.022
108243	M4	146.9	0.036
108243	O1	1.8	0.01
108243	M6	122.8	0.03
108243	MK3	119.3	0.006
108243	S4	189.1	0.017
108243	MN4	21.3	0.006
108243	S6	224.4	0.008
108243	2N2	103.3	0.052
108243	OO1	327.7	0.006
108243	M1	283.1	0.007
108243	J1	128.9	0.003
108243	Q1	6.6	0.014
108243	2Q1	196.3	0.008
108243	2SM2	235.1	0.013
108243	M3	215.8	0.009
108243	L2	189.7	0.039
108243	2MK3	173.5	0.002
108243	M8	276.2	0.006
108243	MS4	152.7	0.019
108244	M2	152.2	1.063
108244	S2	184.8	0.377
108244	N2	142.3	0.177
108244	K1	115.1	0.076
108244	M4	130.2	0.232
108244	O1	108.3	0.045
108244	M6	191.4	0.011
108244	MK3	95.7	0.039
108244	S4	157.6	0.018
108244	MN4	114.8	0.072
108244	S6	8.1	0.007
108244	2N2	86.2	0.063
108244	OO1	275.1	0.011
108244	M1	107.4	0.003
108244	J1	48.3	0.015
108244	Q1	200	0.012
108244	2Q1	359.5	0.012
108244	2SM2	149.6	0.024
108244	M3	172.2	0.031
108244	L2	195.5	0.123
108244	2MK3	55.3	0.041
108244	M8	234.9	0.018
108244	MS4	172.8	0.159
108245	M2	161.6	1.121
108245	S2	192.1	0.38
108245	N2	144.1	0.191
108245	K1	115.5	0.077
108245	M4	133.5	0.228
108245	O1	103.7	0.058
108245	M6	94.7	0.013
108245	MK3	106.6	0.033
108245	S4	207.3	0.026
108245	MN4	97.4	0.084
108245	S6	316.4	0.007
108245	2N2	110.4	0.098
108245	OO1	292.7	0.013
108245	M1	356.9	0.015
108245	J1	71.3	0.019
108245	Q1	184.7	0.013
108245	2Q1	323.3	0.015
108245	2SM2	86.5	0.023
108245	M3	185.1	0.024
108245	L2	205	0.093
108245	2MK3	57.6	0.031
108245	M8	283.2	0.013
108245	MS4	180.1	0.168
108246	M2	171.6	0.933
108246	S2	202.1	0.416
108246	N2	144.3	0.121
108246	K1	101.4	0.031
108246	M4	115.3	0.159
108246	O1	104.2	0.037
108246	M6	219.1	0.003
108246	MK3	71.8	0.034
108246	S4	257.6	0.028
108246	MN4	84.2	0.06
108246	S6	28.6	0.004
108246	2N2	160.9	0.053
108246	OO1	16.6	0.019
108246	M1	343.4	0.03
108246	J1	162.5	0.032
108246	Q1	122.6	0.011
108246	2Q1	218.9	0.033
108246	2SM2	294.6	0.005
108246	M3	204.2	0.023
108246	L2	301.5	0.069
108246	2MK3	55.5	0.042
108246	M8	42.1	0.017
108246	MS4	186.1	0.117
108247	M2	4.1	0.131
108247	S2	56.4	0.041
108247	N2	354	0.032
108247	K1	260.5	0.011
108247	M4	44.1	0.017
108247	O1	167.3	0.003
108247	M6	319.4	0.019
108247	MK3	220.5	0.017
108247	S4	193.5	0.012
108247	MN4	171.5	0.022
108247	S6	169.9	0.011
108247	2N2	257.4	0.026
108247	OO1	30	0.005
108247	M1	125.2	0.003
108247	J1	100.8	0.004
108247	Q1	114.6	0.005
108247	2Q1	306.5	0.002
108247	2SM2	56.3	0.003
108247	M3	318.5	0.009
108247	L2	296.4	0.028
108247	2MK3	181.3	0.02
108247	M8	81	0.005
108247	MS4	281.5	0.012
108248	M2	182.1	0.324
108248	S2	215.2	0.168
108248	N2	150	0.046
108248	K1	207.6	0.041
108248	M4	146.6	0.062
108248	O1	158.9	0.016
108248	M6	235.8	0.016
108248	MK3	286.8	0.013
108248	S4	253.7	0.024
108248	MN4	145.7	0.029
108248	S6	331	0.01
108248	2N2	153.9	0.037
108248	OO1	349.6	0.007
108248	M1	144.6	0.013
108248	J1	107.3	0.008
108248	Q1	115.6	0.008
108248	2Q1	84	0.006
108248	2SM2	327.1	0.034
108248	M3	185.8	0.013
108248	L2	12.8	0.043
108248	2MK3	197.8	0.004
108248	M8	283	0.005
108248	MS4	190.6	0.069
108249	M2	179.4	0.842
108249	S2	210.1	0.341
108249	N2	162.4	0.14
108249	K1	154.8	0.048
108249	M4	183.7	0.075
108249	O1	85.4	0.041
108249	M6	249.3	0.009
108249	MK3	176.1	0.032
108249	S4	272.5	0.024
108249	MN4	151.2	0.018
108249	S6	186	0.007
108249	2N2	144.1	0.02
108249	OO1	72	0.006
108249	M1	336.9	0.01
108249	J1	148	0.019
108249	Q1	59.2	0.009
108249	2Q1	288.6	0.012
108249	2SM2	181.6	0.01
108249	M3	259.4	0.025
108249	L2	210.2	0.057
108249	2MK3	102.2	0.018
108249	M8	351.1	0.012
108249	MS4	255.2	0.078
108250	M2	166.2	1.002
108250	S2	186.8	0.293
108250	N2	151.8	0.17
108250	K1	150.2	0.144
108250	M4	7.6	0.093
108250	O1	131.5	0.075
108250	M6	185.9	0.015
108250	MK3	311.5	0.025
108250	S4	316.5	0.032
108250	MN4	70.8	0.026
108250	S6	248	0.015
108250	2N2	130.9	0.043
108250	OO1	188.7	0.012
108250	M1	191.1	0.009
108250	J1	56.5	0.008
108250	Q1	158.7	0.022
108250	2Q1	188.5	0.009
108250	P1	152	0.038
108250	2SM2	151.2	0.039
108250	M3	247.2	0.022
108250	L2	156	0.017
108250	2MK3	313.5	0.02
108250	K2	160.1	0.131
108250	M8	10.9	0.009
108250	MS4	8.2	0.059
108251	M2	167.2	1.073
108251	S2	187	0.316
108251	N2	157.6	0.18
108251	K1	163.1	0.123
108251	M4	326.3	0.082
108251	O1	154	0.072
108251	M6	104.1	0.031
108251	MK3	258.6	0.028
108251	S4	304.1	0.022
108251	MN4	210	0.008
108251	S6	240.2	0.013
108251	2N2	92.7	0.088
108251	OO1	218.3	0.012
108251	M1	187.1	0.009
108251	J1	179.2	0.006
108251	Q1	172.9	0.03
108251	2Q1	117.4	0.009
108251	P1	151.1	0.03
108251	2SM2	146.3	0.045
108251	M3	271.7	0.02
108251	L2	180	0.021
108251	2MK3	331.9	0.005
108251	K2	181.5	0.115
108251	M8	70.7	0.012
108251	MS4	332.3	0.071
108252	M2	158.8	0.968
108252	S2	175	0.401
108252	N2	143.3	0.149
108252	K1	191.8	0.092
108252	M4	237.4	0.125
108252	O1	190.1	0.064
108252	M6	173.3	0.028
108252	MK3	298.2	0.013
108252	S4	58.9	0.041
108252	MN4	236.8	0.092
108252	S6	103.9	0.004
108252	2N2	211.1	0.046
108252	OO1	239.2	0.007
108252	M1	42.9	0.007
108252	J1	228.1	0.021
108252	Q1	190.5	0.022
108252	2Q1	334.1	0.002
108252	P1	209.5	0.03
108252	2SM2	290	0.054
108252	M3	240.6	0.036
108252	L2	143.4	0.052
108252	2MK3	167.9	0.035
108252	K2	225.1	0.151
108252	M8	288.9	0.024
108252	MS4	299	0.079
108253	M2	259.4	0.108
108253	S2	315.4	0.042
108253	N2	208.8	0.026
108253	K1	163	0.012
108253	M4	130.9	0.076
108253	O1	176.8	0.008
108253	M6	17.7	0.025
108253	MK3	53.7	0.018
108253	S4	97.6	0.012
108253	MN4	108.3	0.026
108253	S6	352.6	0.007
108253	2N2	131.4	0.01
108253	OO1	321.3	0.01
108253	M1	53.1	0.005
108253	J1	287.4	0.006
108253	Q1	86.3	0.008
108253	2Q1	1.4	0.011
108253	2SM2	265.3	0.004
108253	M3	183.3	0.011
108253	L2	356.2	0.023
108253	2MK3	55.9	0.018
108253	M8	144	0.009
108253	MS4	175.1	0.055
108254	M2	200.5	0.347
108254	S2	233.7	0.134
108254	N2	182.9	0.059
108254	K1	177	0.023
108254	M4	358.2	0.079
108254	O1	145	0.01
108254	M6	195.2	0.007
108254	MK3	5.1	0.016
108254	S4	329	0.015
108254	MN4	332.4	0.033
108254	S6	150	0.006
108254	2N2	133.1	0.064
108254	OO1	332.9	0.004
108254	M1	115	0.011
108254	J1	199.4	0.007
108254	Q1	62.7	0.007
108254	2Q1	89.5	0.013
108254	2SM2	104.9	0.016
108254	M3	228.7	0.004
108254	L2	97	0.028
108254	2MK3	338.6	0.021
108254	M8	270.3	0.013
108254	MS4	33.9	0.062
108255	M2	170.9	0.487
108255	S2	209.8	0.216
108255	N2	161	0.086
108255	K1	200.3	0.027
108255	M4	255.8	0.044
108255	O1	121.9	0.023
108255	M6	189.7	0.03
108255	MK3	77.3	0.008
108255	S4	290.6	0.016
108255	MN4	262.9	0.019
108255	S6	145.1	0.015
108255	2N2	343	0.011
108255	OO1	233.2	0.01
108255	M1	304.4	0.013
108255	J1	149.5	0.013
108255	Q1	188.6	0.013
108255	2Q1	259.6	0.02
108255	2SM2	193.8	0.011
108255	M3	325.8	0.009
108255	L2	181.6	0.074
108255	2MK3	178	0.01
108255	M8	274.9	0.013
108255	MS4	295.1	0.058
108256	M2	169.4	0.082
108256	S2	231.7	0.022
108256	N2	159.2	0.028
108256	K1	140.3	0.005
108256	M4	81.9	0.082
108256	O1	229.1	0.01
108256	M6	14.3	0.014
108256	MK3	71.4	0.034
108256	S4	119.4	0.002
108256	MN4	62.7	0.038
108256	S6	102.2	0.007
108256	2N2	159.4	0.015
108256	OO1	249.8	0.003
108256	M1	144	0.009
108256	J1	213.4	0.001
108256	Q1	265.1	0.004
108256	2Q1	220.6	0.006
108256	2SM2	7.1	0.005
108256	M3	107.9	0.007
108256	L2	167.8	0.004
108256	2MK3	78.3	0.015
108256	M8	144.7	0.001
108256	MS4	123.3	0.036
108257	M2	182.9	0.391
108257	S2	233.1	0.083
108257	N2	162	0.104
108257	K1	125.7	0.027
108257	M4	137.1	0.105
108257	O1	143.9	0.011
108257	M6	47.9	0.024
108257	MK3	92.3	0.06
108257	S4	300.3	0.003
108257	MN4	114.1	0.051
108257	S6	8.4	0.003
108257	2N2	202.2	0.018
108257	OO1	201.9	0.003
108257	M1	320.4	0.003
108257	J1	147.1	0.01
108257	Q1	252.8	0.007
108257	2Q1	215.5	0.004
108257	2SM2	1.5	0.008
108257	M3	32.5	0.008
108257	L2	256.5	0.013
108257	2MK3	80.7	0.033
108257	M8	6.1	0.018
108257	MS4	168.6	0.039
108258	M2	201.4	0.68
108258	S2	227.7	0.173
108258	N2	166.3	0.116
108258	K1	174.2	0.143
108258	M4	197.5	0.13
108258	O1	191.7	0.057
108258	M6	199.5	0.028
108258	MK3	158.7	0.094
108258	S4	280.8	0.009
108258	MN4	151.5	0.048
108258	S6	115.4	0.003
108258	2N2	25.9	0.028
108258	OO1	225.2	0.006
108258	M1	33.7	0.006
108258	J1	121.8	0.002
108258	Q1	78.1	0.008
108258	2Q1	330.4	0.015
108258	2SM2	260	0.018
108258	M3	147.5	0.007
108258	L2	227.8	0.032
108258	2MK3	115	0.045
108258	M8	123	0.002
108258	MS4	216.4	0.064
108259	M2	176.2	0.478
108259	S2	225.2	0.135
108259	N2	144.2	0.132
108259	K1	218.7	0.023
108259	M4	112.8	0.06
108259	O1	186.4	0.027
108259	M6	47.6	0.01
108259	MK3	81.1	0.017
108259	S4	89.1	0.013
108259	MN4	91.5	0.017
108259	S6	304.8	0.001
108259	2N2	158.2	0.047
108259	OO1	123.5	0.011
108259	M1	167	0.009
108259	J1	168.4	0.013
108259	Q1	225.3	0.012
108259	2Q1	151.6	0.008
108259	2SM2	46.6	0.011
108259	M3	223.7	0.009
108259	L2	207	0.031
108259	2MK3	80.3	0.013
108259	M8	271.2	0.005
108259	MS4	201.5	0.039
108260	M2	190.7	0.426
108260	S2	244.3	0.136
108260	N2	168.2	0.109
108260	K1	212.5	0.078
108260	M4	91	0.023
108260	O1	202.2	0.057
108260	M6	304.9	0.023
108260	MK3	116.1	0.018
108260	S4	203.3	0.003
108260	MN4	45	0.009
108260	S6	318.2	0.004
108260	2N2	169.9	0.056
108260	M1	193.1	0.007
108260	J1	147.3	0.014
108260	Q1	201.9	0.012
108260	2Q1	165.1	0.018
108260	2SM2	87.1	0.001
108260	M3	184.6	0.021
108260	L2	165.4	0.031
108260	2MK3	85.8	0.014
108260	M8	268.7	0.012
108260	MS4	154.4	0.017
108261	M2	226.7	0.379
108261	S2	259.7	0.102
108261	N2	216.6	0.076
108261	K1	184.5	0.093
108261	M4	296.1	0.009
108261	O1	201.9	0.028
108261	M6	290.5	0.009
108261	MK3	161.7	0.043
108261	S4	300.8	0.01
108261	MN4	288.3	0.008
108261	S6	187.3	0.008
108261	2N2	333.1	0.015
108261	OO1	292.8	0.021
108261	M1	15.3	0.008
108261	J1	264.2	0.007
108261	Q1	53.1	0.016
108261	2Q1	247.4	0.009
108261	2SM2	220.2	0.019
108261	M3	142.8	0.009
108261	L2	320.1	0.013
108261	2MK3	124.7	0.029
108261	M8	299	0.006
108261	MS4	350.5	0.014
108262	M2	175.5	0.237
108262	S2	201.2	0.053
108262	N2	144.2	0.051
108262	K1	175.5	0.017
108262	M4	187.5	0.005
108262	O1	156.2	0.018
108262	M6	254.3	0.004
108262	MK3	160.3	0.015
108262	S4	277.5	0.01
108262	MN4	137.8	0.01
108262	S6	242.6	0.005
108262	2N2	92.9	0.027
108262	OO1	101.3	0.004
108262	M1	163	0.011
108262	J1	166.7	0.012
108262	Q1	119.8	0.007
108262	2Q1	142.5	0.005
108262	2SM2	217.7	0.001
108262	M3	195.9	0.004
108262	L2	226.2	0.027
108262	2MK3	151.2	0.016
108262	M8	199.5	0.004
108262	MS4	239.8	0.004
108263	M2	196.6	0.205
108263	S2	250.9	0.06
108263	N2	174.4	0.065
108263	K1	207.1	0.029
108263	M4	84.2	0.011
108263	O1	186.2	0.025
108263	M6	29.6	0.003
108263	MK3	122.2	0.005
108263	S4	76.6	0.007
108263	MN4	62.6	0.021
108263	S6	250.4	0.004
108263	2N2	178.1	0.015
108263	OO1	52.3	0.005
108263	M1	115.3	0.004
108263	J1	118.6	0.008
108263	Q1	151.5	0.011
108263	2Q1	179.1	0.011
108263	2SM2	258.8	0.004
108263	M3	348.3	0.008
108263	L2	189.7	0.02
108263	2MK3	90.4	0.007
108263	M8	170	0.006
108263	MS4	144.4	0.017
108264	M2	227.9	0.286
108264	S2	215.7	0.076
108264	N2	200.8	0.062
108264	K1	164	0.046
108264	M4	94.4	0.033
108264	O1	9.6	0.008
108264	M6	297.7	0.014
108264	MK3	100.5	0.018
108264	S4	182.9	0.009
108264	MN4	102.1	0.009
108264	S6	17.1	0.01
108264	2N2	206.6	0.025
108264	OO1	252.5	0.018
108264	M1	325.8	0.007
108264	J1	225.1	0.012
108264	Q1	325.4	0.022
108264	2Q1	302.6	0.004
108264	2SM2	82.1	0.018
108264	M3	102.5	0.015
108264	L2	357.5	0.027
108264	2MK3	126.1	0.011
108264	M8	47.2	0.009
108264	MS4	103.9	0.01
108265	M2	216.1	0.118
108265	S2	235.3	0.024
108265	N2	193.2	0.042
108265	K1	206.8	0.025
108265	M4	317.8	0.011
108265	O1	192.6	0.022
108265	M6	29.8	0.006
108265	MK3	121.3	0.007
108265	S4	281.6	0.003
108265	MN4	306.1	0.006
108265	S6	242	0.003
108265	2N2	256.9	0.008
108265	OO1	17.9	0.004
108265	M1	28.9	0.007
108265	J1	201	0.008
108265	Q1	136.4	0.014
108265	2Q1	156.4	0.008
108265	2SM2	126.7	0.014
108265	M3	99.3	0.008
108265	L2	174.3	0.011
108265	2MK3	72.7	0.005
108265	M8	171.4	0.003
108265	MS4	344.3	0.006
108266	M2	222.5	0.189
108266	S2	256.5	0.057
108266	N2	181.1	0.071
108266	K1	214.4	0.016
108266	M4	210.8	0.023
108266	O1	113.5	0.005
108266	M6	150.4	0.004
108266	MK3	174.9	0.016
108266	S4	122	0.007
108266	MN4	127.7	0.006
108266	S6	72.9	0.001
108266	2N2	184.8	0.013
108266	OO1	157.8	0.008
108266	M1	209.9	0.01
108266	J1	125	0.006
108266	Q1	264.8	0.022
108266	2Q1	199.7	0.009
108266	2SM2	344.4	0.022
108266	M3	145.6	0.009
108266	L2	137	0.009
108266	2MK3	149.4	0.022
108266	MS4	237.8	0.006
108267	M2	140.1	0.235
108267	S2	157.7	0.081
108267	N2	89.4	0.089
108267	K1	114	0.011
108267	M4	74.8	0.033
108267	O1	1.1	0.008
108267	M6	304.9	0.011
108267	MK3	113.7	0.024
108267	S4	67.8	0.009
108267	MN4	145.5	0.025
108267	S6	117	0.001
108267	2N2	114.6	0.04
108267	OO1	62.2	0.007
108267	M1	161.4	0.011
108267	J1	275	0.007
108267	Q1	114.5	0.009
108267	2Q1	123.5	0.005
108267	P1	332.9	0.001
108267	2SM2	60.3	0.004
108267	M3	242.2	0.01
108267	L2	156.6	0.018
108267	2MK3	140	0.005
108267	K2	83	0.037
108267	M8	89.4	0.008
108267	MS4	152.7	0.008
108268	M2	199.4	0.472
108268	S2	250	0.233
108268	N2	170.3	0.179
108268	K1	168	0.097
108268	M4	292.6	0.159
108268	O1	165.9	0.102
108268	M6	321.4	0.078
108268	MK3	263.1	0.076
108268	S4	34	0.016
108268	MN4	255	0.07
108268	S6	341.3	0.003
108268	2N2	131.7	0.084
108268	OO1	167.3	0.013
108268	M1	244.7	0.013
108268	J1	107	0.006
108268	Q1	134.2	0.011
108268	2Q1	46.5	0.018
108268	P1	247.1	0.085
108268	2SM2	26.7	0.021
108268	M3	146	0.005
108268	L2	142.6	0.079
108268	2MK3	220.9	0.066
108268	K2	235.6	0.067
108268	M8	331.2	0.015
108268	MS4	326.6	0.09
108269	M2	228.7	1.227
108269	S2	251.6	0.365
108269	N2	209.7	0.226
108269	K1	202.7	0.191
108269	M4	268.6	0.263
108269	O1	178.3	0.133
108269	M6	259.5	0.06
108269	MK3	223.6	0.117
108269	S4	305.6	0.01
108269	MN4	242.8	0.076
108269	S6	126	0.007
108269	2N2	245.1	0.034
108269	OO1	266.7	0.017
108269	M1	348.7	0.008
108269	J1	153.3	0.02
108269	Q1	165.6	0.029
108269	2Q1	266.1	0.017
108269	P1	165.9	0.082
108269	2SM2	184.4	0.026
108269	M3	294.7	0.018
108269	L2	281.8	0.116
108269	2MK3	175.2	0.055
108269	K2	228.9	0.126
108269	M8	288.7	0.018
108269	MS4	303.7	0.13
108270	M2	104.6	0.139
108270	S2	160.6	0.04
108270	N2	89.5	0.019
108270	K1	159.8	0.021
108270	M4	27.3	0.056
108270	O1	85.8	0.021
108270	M6	53.9	0.016
108270	MK3	73.1	0.019
108270	S4	216.6	0.004
108270	MN4	328.8	0.015
108270	S6	22.2	0.002
108270	2N2	55.2	0.014
108270	OO1	17	0.005
108270	M1	123.3	0.004
108270	J1	191.4	0.006
108270	Q1	66.3	0.004
108270	2Q1	200.9	0.002
108270	2SM2	119.8	0.005
108270	M3	88.4	0.003
108270	L2	126.4	0.02
108270	2MK3	36.3	0.014
108270	M8	26.8	0.004
108270	MS4	54.6	0.026
108271	M2	192.2	0.163
108271	S2	214.6	0.053
108271	N2	159.3	0.057
108271	K1	159	0.033
108271	M4	260.9	0.025
108271	O1	101.1	0.014
108271	M6	146.2	0.014
108271	MK3	171.1	0.026
108271	S4	194.1	0.004
108271	MN4	183.5	0.021
108271	S6	203.7	0.004
108271	2N2	84.4	0.017
108271	OO1	197.7	0.001
108271	M1	141	0.005
108271	J1	107.4	0.006
108271	Q1	228.6	0.003
108271	2Q1	281.4	0.003
108271	2SM2	49.6	0.01
108271	M3	124.1	0.004
108271	L2	317.4	0.004
108271	2MK3	165	0.013
108271	M8	204.8	0.006
108271	MS4	256.1	0.02
108272	M2	214.5	0.308
108272	S2	244.8	0.097
108272	N2	211.2	0.102
108272	K1	114.8	0.058
108272	M4	198.9	0.078
108272	O1	67.7	0.028
108272	M6	255	0.028
108272	MK3	86.4	0.032
108272	S4	3.9	0.006
108272	MN4	137.7	0.014
108272	S6	260.2	0.002
108272	2N2	265.4	0.042
108272	OO1	170.6	0.008
108272	M1	185	0.006
108272	J1	50	0.012
108272	Q1	313.7	0.014
108272	2Q1	306.9	0.007
108272	2SM2	339.2	0.005
108272	M3	272	0.019
108272	L2	25.9	0.011
108272	2MK3	17.4	0.027
108272	M8	233.3	0.008
108272	MS4	251.3	0.043
108273	M2	216.1	0.249
108273	S2	236.6	0.063
108273	N2	181.8	0.047
108273	K1	183.2	0.077
108273	M4	338.1	0.031
108273	O1	163	0.037
108273	M6	328.5	0.006
108273	MK3	243	0.018
108273	S4	15.9	0.005
108273	MN4	28.1	0.007
108273	S6	358.7	0.002
108273	2N2	162.5	0.015
108273	OO1	174.2	0.007
108273	M1	273.5	0.005
108273	J1	88.3	0.008
108273	Q1	147.1	0.012
108273	2Q1	313.6	0.006
108273	2SM2	220	0.012
108273	M3	327	0.013
108273	L2	331.4	0.008
108273	2MK3	326.4	0.004
108273	M8	146.9	0.002
108273	MS4	4.7	0.019
108274	M2	209.3	0.221
108274	S2	244.8	0.051
108274	N2	182.1	0.046
108274	K1	170.6	0.071
108274	M4	281.4	0.02
108274	O1	165.3	0.03
108274	M6	356.5	0.014
108274	MK3	229.2	0.024
108274	S4	242.6	0.003
108274	MN4	307.7	0.01
108274	S6	80.4	0.003
108274	2N2	199.5	0.025
108274	OO1	297.1	0.005
108274	M1	208.5	0.012
108274	J1	205.2	0.008
108274	Q1	137.9	0.002
108274	2Q1	116.8	0.007
108274	2SM2	271.5	0.012
108274	M3	290.1	0.008
108274	L2	99.8	0.005
108274	2MK3	186.5	0.007
108274	M8	135.2	0.002
108274	MS4	330.4	0.01
108275	M2	197.5	0.152
108275	S2	233.6	0.053
108275	N2	183	0.031
108275	K1	163.6	0.062
108275	M4	150.7	0.02
108275	O1	145.2	0.029
108275	M6	335.7	0.02
108275	MK3	255.3	0.008
108275	S4	239.8	0.002
108275	MN4	200.5	0.005
108275	S6	135.8	0.007
108275	2N2	45.5	0.007
108275	OO1	255.4	0.003
108275	M1	148.4	0.006
108275	J1	233.1	0.006
108275	Q1	6.9	0.003
108275	2Q1	248.4	0.009
108275	2SM2	318.2	0.011
108275	M3	316.9	0.01
108275	L2	215.6	0.013
108275	2MK3	172.2	0.005
108275	M8	181.7	0.006
108275	MS4	180.7	0.014
108276	M2	247.1	0.209
108276	S2	278.1	0.076
108276	N2	235.1	0.061
108276	K1	183.8	0.079
108276	M4	20.3	0.021
108276	O1	144.7	0.053
108276	M6	354.1	0.027
108276	MK3	285.3	0.038
108276	S4	105.1	0.007
108276	MN4	1.6	0.018
108276	S6	155.9	0.003
108276	2N2	219.5	0.023
108276	OO1	292.4	0.004
108276	M1	203.6	0.018
108276	J1	88.7	0.003
108276	Q1	150.4	0.013
108276	2Q1	13.2	0.006
108276	2SM2	305.5	0.014
108276	M3	309.1	0.012
108276	L2	96.6	0.03
108276	2MK3	298.7	0.016
108276	M8	48.4	0.003
108276	MS4	33.6	0.007
108277	M2	247	0.212
108277	S2	278.4	0.083
108277	N2	239.9	0.05
108277	K1	185	0.106
108277	M4	342.1	0.015
108277	O1	152.4	0.057
108277	M6	1.6	0.024
108277	MK3	291.4	0.041
108277	S4	27.3	0.006
108277	MN4	324.3	0.015
108277	S6	172	0.003
108277	2N2	271.9	0.011
108277	OO1	252.1	0.003
108277	M1	151.3	0.017
108277	J1	121.9	0.008
108277	Q1	118.2	0.018
108277	2Q1	57.4	0.006
108277	2SM2	250.5	0.013
108277	M3	260.7	0.004
108277	L2	118.4	0.018
108277	2MK3	290.5	0.018
108277	M8	79.5	0.002
108277	MS4	353.8	0.01
108278	M2	217.4	0.154
108278	S2	254.6	0.026
108278	N2	142.8	0.038
108278	K1	148.9	0.134
108278	M4	281.2	0.031
108278	O1	141.5	0.091
108278	M6	325.4	0.032
108278	MK3	228	0.037
108278	S4	260.7	0.007
108278	MN4	259.6	0.013
108278	S6	245.3	0.007
108278	2N2	85.9	0.028
108278	OO1	177.9	0.009
108278	M1	69.4	0.036
108278	J1	103.4	0.013
108278	Q1	97.8	0.047
108278	2Q1	122.8	0.024
108278	2SM2	154.8	0.015
108278	M3	193.8	0.023
108278	L2	303.3	0.052
108278	2MK3	227.3	0.027
108278	M8	85.5	0.006
108278	MS4	330.1	0.013
108279	M2	123.6	0.193
108279	S2	120.5	0.047
108279	N2	75.9	0.07
108279	K1	13.7	0.03
108279	M4	239.9	0.02
108279	O1	271	0.021
108279	M6	171.9	0.009
108279	MK3	134.7	0.031
108279	S4	60.2	0.007
108279	MN4	215.7	0.018
108279	S6	80.7	0.008
108279	2N2	255.3	0.026
108279	OO1	300.6	0.005
108279	M1	208.3	0.007
108279	J1	331.6	0.006
108279	Q1	158.8	0.009
108279	2Q1	100.4	0.008
108279	2SM2	18.1	0.009
108279	M3	105.6	0.006
108279	L2	202.1	0.016
108279	2MK3	2.7	0.007
108279	M8	211.5	0.003
108279	MS4	353.5	0.007
108280	M2	205.4	0.167
108280	S2	251.6	0.055
108280	N2	207.7	0.019
108280	K1	105.7	0.021
108280	M4	303.8	0.028
108280	O1	225.6	0.007
108280	M6	176.7	0.012
108280	MK3	164.5	0.012
108280	S4	69.4	0.009
108280	MN4	247.4	0.022
108280	S6	230	0.003
108280	2N2	111	0.014
108280	OO1	209.5	0.006
108280	M1	330.9	0.011
108280	J1	259.1	0.003
108280	Q1	100.3	0.005
108280	2Q1	49.7	0.018
108280	2SM2	262.2	0.007
108280	M3	199.7	0.004
108280	L2	295.2	0.022
108280	2MK3	105.3	0.015
108280	M8	309	0.004
108280	MS4	27.6	0.021
108281	M2	191	0.246
108281	S2	262.3	0.071
108281	N2	148	0.063
108281	K1	329.3	0.003
108281	M4	122.3	0.057
108281	O1	239	0.021
108281	M6	55.6	0.008
108281	MK3	96.8	0.016
108281	S4	184.1	0.011
108281	MN4	50.3	0.029
108281	S6	114.9	0.01
108281	2N2	136.5	0.046
108281	OO1	60.1	0.002
108281	M1	231.6	0.009
108281	J1	99.1	0.013
108281	Q1	218.7	0.019
108281	2Q1	42.3	0.013
108281	2SM2	181.6	0.008
108281	M3	119.9	0.014
108281	L2	122.7	0.016
108281	2MK3	126.1	0.011
108281	M8	83.9	0.003
108281	MS4	176.9	0.036
108282	M2	221.9	0.237
108282	S2	319.1	0.085
108282	N2	193.5	0.035
108282	K1	238.8	0.024
108282	M4	218.9	0.013
108282	O1	206.6	0.046
108282	M6	125.9	0.028
108282	MK3	66.7	0.018
108282	S4	251.9	0.005
108282	MN4	99.5	0.015
108282	S6	38.1	0.001
108282	2N2	115.4	0.049
108282	OO1	13.1	0.005
108282	M1	243.3	0.011
108282	J1	78.2	0.007
108282	Q1	175.1	0.028
108282	2Q1	14.2	0.026
108282	2SM2	89.9	0.046
108282	M3	261.7	0.015
108282	L2	169.9	0.003
108282	2MK3	137.5	0.028
108282	M8	315.5	0.009
108282	MS4	229.9	0.02
108283	M2	199.7	0.261
108283	S2	252.8	0.087
108283	N2	132.1	0.051
108283	K1	136	0.03
108283	M4	284.2	0.023
108283	O1	153.7	0.035
108283	M6	255	0.033
108283	MK3	150.9	0.027
108283	S4	122.2	0.015
108283	MN4	201.8	0.029
108283	S6	109.2	0.006
108283	2N2	150.8	0.033
108283	OO1	204.6	0.011
108283	M1	346.8	0.01
108283	J1	257.1	0.015
108283	Q1	272.3	0.02
108283	2Q1	32	0.016
108283	2SM2	49.2	0.014
108283	M3	289.5	0.004
108283	L2	97.8	0.013
108283	2MK3	58.1	0.019
108283	M8	157.1	0.008
108283	MS4	331.9	0.02
108284	M2	190.3	0.416
108284	S2	205.6	0.12
108284	N2	146.7	0.104
108284	K1	130.6	0.036
108284	M4	341.3	0.02
108284	O1	152.5	0.014
108284	M6	308.6	0.037
108284	MK3	110	0.025
108284	S4	268.9	0.005
108284	MN4	285.5	0.021
108284	S6	7.3	0.008
108284	2N2	153.7	0.027
108284	OO1	266.6	0.005
108284	M1	285.7	0.012
108284	J1	353.6	0.005
108284	Q1	102	0.008
108284	2Q1	164.6	0.004
108284	2SM2	185.8	0.012
108284	M3	142.3	0.012
108284	L2	236.4	0.015
108284	2MK3	132.4	0.013
108284	M8	252.4	0.013
108284	MS4	230.1	0.014
108285	M2	193	0.485
108285	S2	202.8	0.115
108285	N2	146.1	0.123
108285	K1	127.7	0.057
108285	M4	342.1	0.007
108285	O1	152.2	0.012
108285	M6	232.5	0.015
108285	MK3	103.7	0.017
108285	S4	35	0.011
108285	MN4	318.6	0.026
108285	S6	257.5	0.011
108285	2N2	85.6	0.031
108285	OO1	284.1	0.002
108285	M1	249.3	0.01
108285	J1	26.9	0.005
108285	Q1	188.7	0.01
108285	2Q1	193.9	0.01
108285	2SM2	296	0.012
108285	M3	24.2	0.01
108285	L2	240.7	0.037
108285	2MK3	112.2	0.025
108285	M8	224.7	0.009
108285	MS4	4.2	0.006
108286	M2	199.5	0.662
108286	S2	221.8	0.178
108286	N2	178.6	0.186
108286	K1	152.5	0.059
108286	M4	61.5	0.069
108286	O1	257.9	0.025
108286	M6	118	0.03
108286	MK3	80.4	0.031
108286	S4	71.5	0.024
108286	MN4	47.6	0.05
108286	S6	0.8	0.004
108286	2N2	244.2	0.051
108286	OO1	102.3	0.015
108286	M1	248.4	0.035
108286	J1	317.7	0.01
108286	Q1	12.4	0.012
108286	2Q1	167.2	0.009
108286	2SM2	315.3	0.024
108286	M3	320.7	0.03
108286	L2	200.5	0.028
108286	2MK3	53.6	0.022
108286	M8	37	0.015
108286	MS4	66.3	0.061
108287	M2	156.3	1.347
108287	S2	161.8	0.442
108287	N2	120.8	0.32
108287	K1	68.4	0.095
108287	M4	9.3	0.101
108287	O1	79.9	0.037
108287	M6	345.2	0.046
108287	MK3	111.7	0.054
108287	S4	277.8	0.02
108287	MN4	272.9	0.055
108287	S6	75.6	0.011
108287	2N2	83.3	0.076
108287	OO1	64.1	0.013
108287	M1	247.3	0.022
108287	J1	328.3	0.009
108287	Q1	83	0.019
108287	2Q1	77	0.018
108287	P1	148.7	0.021
108287	2SM2	35.5	0.027
108287	M3	267.9	0.004
108287	L2	206.8	0.075
108287	2MK3	68.3	0.042
108287	K2	131.4	0.157
108287	M8	214.1	0.015
108287	MS4	301.9	0.045
108288	M2	158.7	1.49
108288	S2	167.1	0.468
108288	N2	123.3	0.343
108288	K1	66.9	0.1
108288	M4	325.1	0.133
108288	O1	70.7	0.021
108288	M6	359.7	0.006
108288	MK3	128.9	0.056
108288	S4	274.8	0.019
108288	MN4	264.1	0.084
108288	S6	87.1	0.015
108288	2N2	73.3	0.084
108288	OO1	58.9	0.017
108288	M1	231.3	0.029
108288	J1	352.3	0.03
108288	Q1	71.2	0.021
108288	2Q1	95.7	0.017
108288	P1	132.7	0.04
108288	2SM2	60.3	0.017
108288	M3	294.6	0.015
108288	L2	221.9	0.11
108288	2MK3	78.8	0.057
108288	K2	149.2	0.148
108288	M8	72.1	0.03
108288	MS4	277.4	0.067
108289	M2	158	1.192
108289	S2	172.8	0.408
108289	N2	109.1	0.281
108289	K1	24.2	0.086
108289	M4	311.2	0.069
108289	O1	196.4	0.043
108289	M6	189.9	0.045
108289	MK3	128.8	0.065
108289	S4	167.7	0.022
108289	MN4	192.5	0.04
108289	S6	110.6	0.023
108289	2N2	42.7	0.093
108289	OO1	103.8	0.014
108289	M1	193.4	0.042
108289	J1	13.5	0.021
108289	Q1	269.4	0.035
108289	2Q1	286.1	0.033
108289	P1	169.8	0.062
108289	2SM2	168	0.009
108289	M3	307.4	0.02
108289	L2	188.4	0.058
108289	2MK3	85.8	0.037
108289	K2	152.8	0.098
108289	M8	263.5	0.005
108289	MS4	219.4	0.097
108290	M2	147.6	0.294
108290	S2	255.5	0.013
108290	N2	84.1	0.055
108290	K1	57.1	0.007
108290	M4	269	0.024
108290	O1	155.3	0.006
108290	M6	24.4	0.046
108290	MK3	53.3	0.033
108290	S4	198.5	0.013
108290	MN4	135.5	0.018
108290	S6	304.9	0.008
108290	2N2	354.5	0.028
108290	OO1	78	0.006
108290	M1	171.1	0.01
108290	J1	247.6	0.007
108290	Q1	343.6	0.012
108290	2Q1	333.6	0.008
108290	2SM2	272.8	0.005
108290	M3	138.7	0.004
108290	L2	139.2	0.027
108290	2MK3	330	0.011
108290	M8	154.6	0.022
108290	MS4	142.6	0.011
108291	M2	157.5	0.521
108291	S2	217.7	0.051
108291	N2	102.9	0.104
108291	K1	61.1	0.029
108291	M4	246.6	0.087
108291	O1	129.5	0.025
108291	M6	32.7	0.056
108291	MK3	112.7	0.033
108291	S4	220.1	0.01
108291	MN4	181.3	0.038
108291	S6	304	0.013
108291	2N2	70.7	0.038
108291	OO1	261.2	0.005
108291	M1	91.5	0.004
108291	J1	50.2	0.008
108291	Q1	29.5	0.011
108291	2Q1	70.5	0.008
108291	2SM2	56.6	0.022
108291	M3	261.7	0.017
108291	L2	203.6	0.026
108291	2MK3	40	0.013
108291	M8	168.9	0.026
108291	MS4	178.5	0.03
108292	M2	172.4	0.675
108292	S2	191.9	0.15
108292	N2	116.6	0.124
108292	K1	261.9	0.008
108292	M4	259.2	0.067
108292	O1	200.1	0.031
108292	M6	75.3	0.062
108292	MK3	74.2	0.059
108292	S4	218.2	0.034
108292	MN4	175	0.053
108292	S6	310.6	0.024
108292	2N2	314.5	0.011
108292	OO1	31.6	0.006
108292	M1	237.3	0.02
108292	J1	291.2	0.003
108292	Q1	139.3	0.015
108292	2Q1	148	0.02
108292	2SM2	226.2	0.022
108292	M3	226.6	0.011
108292	L2	219.6	0.03
108292	2MK3	57.7	0.029
108292	M8	182.6	0.025
108292	MS4	174.4	0.048
108293	M2	180	0.385
108293	S2	201.1	0.108
108293	N2	157.5	0.151
108293	K1	130.2	0.06
108293	M4	31.8	0.136
108293	O1	83.5	0.027
108293	M6	209.2	0.034
108293	MK3	287.5	0.019
108293	S4	236.9	0.035
108293	MN4	340.3	0.027
108293	S6	219.1	0.021
108293	2N2	101.7	0.053
108293	OO1	48.5	0.004
108293	M1	226.4	0.014
108293	J1	152.4	0.006
108293	Q1	229.5	0.004
108293	2Q1	158.2	0.017
108293	2SM2	258.9	0.033
108293	M3	135.6	0.01
108293	L2	214.8	0.015
108293	2MK3	153.4	0.021
108293	M8	175.1	0.017
108293	MS4	112.1	0.031
108294	M2	140.7	0.093
108294	S2	177.9	0.046
108294	N2	16.7	0.012
108294	K1	145.1	0.028
108294	M4	290.3	0.005
108294	O1	84.7	0.006
108294	M6	202.8	0.005
108294	MK3	207	0.002
108294	S4	352.1	0.003
108294	MN4	278	0.013
108294	S6	67.7	0.002
108294	2N2	222.6	0.014
108294	OO1	199.9	0.002
108294	M1	336.1	0.005
108294	J1	349.2	0.008
108294	Q1	230.6	0.011
108294	2Q1	157	0.01
108294	2SM2	165	0.01
108294	M3	302.8	0.014
108294	L2	195.2	0.006
108294	2MK3	252.7	0.012
108294	M8	80.1	0.002
108294	MS4	345.9	0.006
108295	M2	200.5	0.225
108295	S2	230.5	0.062
108295	N2	169.2	0.085
108295	K1	150.1	0.047
108295	M4	245.4	0.034
108295	O1	191.3	0.004
108295	M6	31.2	0.009
108295	MK3	240.3	0.019
108295	S4	112.5	0.011
108295	MN4	113.8	0.004
108295	S6	45	0.002
108295	2N2	145.3	0.024
108295	OO1	333.3	0.004
108295	M1	151.9	0.005
108295	J1	138.5	0.018
108295	Q1	183.9	0.009
108295	2Q1	258.2	0.005
108295	2SM2	252	0.019
108295	M3	220	0.009
108295	L2	328.1	0.015
108295	2MK3	254.7	0.003
108295	M8	79	0.005
108295	MS4	32.1	0.013
108296	M2	171.9	0.175
108296	S2	258.9	0.039
108296	N2	154.7	0.028
108296	K1	193.6	0.04
108296	M4	312.7	0.032
108296	O1	5.6	0.009
108296	M6	328.6	0.008
108296	MK3	62.1	0.017
108296	S4	130.1	0.007
108296	MN4	167.9	0.004
108296	S6	165.4	0.006
108296	2N2	192.7	0.024
108296	OO1	86.7	0.009
108296	M1	110.2	0.017
108296	J1	256.9	0.009
108296	Q1	350.1	0.003
108296	2Q1	329.8	0.003
108296	2SM2	16.6	0.006
108296	M3	296.8	0.006
108296	L2	161.2	0.019
108296	2MK3	41.8	0.01
108296	M8	145.8	0.004
108296	MS4	335	0.005
108297	M2	196.8	0.181
108297	S2	258.3	0.047
108297	N2	206.7	0.032
108297	K1	206.8	0.075
108297	M4	222.4	0.023
108297	O1	159	0.01
108297	M6	355.9	0.011
108297	MK3	172.4	0.011
108297	S4	86.9	0.008
108297	MN4	202.9	0.007
108297	S6	37.7	0.004
108297	2N2	160.8	0.025
108297	OO1	85.3	0.007
108297	M1	144.7	0.03
108297	J1	247.7	0.013
108297	Q1	87	0.016
108297	2Q1	49.7	0.006
108297	2SM2	351.3	0.006
108297	M3	154.2	0.008
108297	L2	196.6	0.018
108297	2MK3	11.3	0.013
108297	M8	109.2	0.003
108297	MS4	292.3	0.015
108298	M2	245.7	0.271
108298	S2	339.4	0.07
108298	N2	214.5	0.092
108298	K1	108.1	0.011
108298	M4	165.5	0.064
108298	O1	205.2	0.024
108298	M6	16.7	0.007
108298	MK3	203.9	0.011
108298	S4	20	0.006
108298	MN4	105.9	0.027
108298	S6	45.1	0.003
108298	2N2	25	0.045
108298	OO1	327.9	0.006
108298	M1	207.5	0.014
108298	J1	137.1	0.008
108298	Q1	351.5	0.015
108298	2Q1	158.2	0.018
108298	2SM2	209.9	0.015
108298	M3	319.7	0.017
108298	L2	25.3	0.026
108298	2MK3	167.7	0.012
108298	M8	82.9	0.002
108298	MS4	253.6	0.038
108299	M2	206.3	0.27
108299	S2	266.8	0.107
108299	N2	175.9	0.057
108299	K1	174	0.095
108299	M4	172.3	0.018
108299	O1	139.5	0.05
108299	M6	287	0.026
108299	MK3	42.9	0.017
108299	S4	180.1	0.02
108299	MN4	182	0.017
108299	S6	152.6	0.009
108299	2N2	94	0.07
108299	OO1	53.3	0.011
108299	M1	108.6	0.036
108299	J1	243.4	0.02
108299	Q1	39.4	0.037
108299	2Q1	178	0.021
108299	2SM2	296.4	0.018
108299	M3	343	0.018
108299	L2	161.8	0.019
108299	2MK3	294.6	0.012
108299	M8	106.3	0.011
108299	MS4	223.5	0.017
108300	M2	221.8	0.395
108300	S2	269.7	0.092
108300	N2	176.1	0.094
108300	K1	181.7	0.082
108300	M4	164.4	0.038
108300	O1	172.6	0.032
108300	M6	348.5	0.008
108300	MK3	52.1	0.004
108300	S4	210.5	0.003
108300	MN4	86.2	0.019
108300	S6	356	0.003
108300	2N2	339.5	0.037
108300	OO1	52.1	0.01
108300	M1	98.3	0.014
108300	J1	276.5	0.005
108300	Q1	69.7	0.02
108300	2Q1	160.5	0.012
108300	2SM2	164.7	0.022
108300	M3	281.4	0.026
108300	L2	258	0.014
108300	2MK3	211.9	0.017
108300	M8	340.2	0.011
108300	MS4	194.6	0.023
108301	M2	202.2	0.302
108301	S2	257	0.088
108301	N2	188.7	0.069
108301	K1	244.1	0.066
108301	M4	236.7	0.028
108301	O1	173.5	0.031
108301	M6	254.5	0.004
108301	MK3	166.9	0.024
108301	S4	24.4	0.007
108301	MN4	213.2	0.025
108301	S6	351.7	0.004
108301	2N2	128.9	0.039
108301	OO1	268.3	0.011
108301	M1	276.8	0.015
108301	J1	196.5	0.014
108301	Q1	231.8	0.012
108301	2Q1	24.2	0.017
108301	2SM2	241	0.027
108301	M3	126.9	0.009
108301	L2	98.2	0.031
108301	2MK3	224.6	0.013
108301	M8	33.7	0.003
108301	MS4	282.2	0.015
108302	M2	220.1	0.316
108302	S2	272.5	0.063
108302	N2	156.2	0.064
108302	K1	226.6	0.075
108302	M4	255.9	0.011
108302	O1	215	0.027
108302	M6	14.9	0.006
108302	MK3	68	0.018
108302	S4	315.4	0.005
108302	MN4	184	0.024
108302	S6	80	0.005
108302	2N2	335.6	0.037
108302	OO1	188.2	0.006
108302	M1	258	0.006
108302	J1	171.7	0.027
108302	Q1	171.1	0.016
108302	2Q1	212.1	0.013
108302	2SM2	190.9	0.018
108302	M3	180.4	0.013
108302	L2	309.8	0.029
108302	2MK3	72.3	0.012
108302	M8	181.2	0.004
108302	MS4	321.6	0.015
108303	M2	198.4	0.284
108303	S2	252.7	0.09
108303	N2	165.1	0.066
108303	K1	177.6	0.056
108303	M4	152.5	0.007
108303	O1	154.3	0.037
108303	M6	302.4	0.01
108303	MK3	176.1	0.014
108303	S4	109.8	0.006
108303	MN4	144.3	0.004
108303	S6	315.7	0.001
108303	2N2	24	0.006
108303	OO1	234.8	0.007
108303	M1	101.1	0.005
108303	J1	196.9	0.006
108303	Q1	230.1	0.007
108303	2Q1	322	0.007
108303	2SM2	317.1	0.003
108303	M3	182.7	0.004
108303	L2	231.7	0.013
108303	2MK3	116.9	0.008
108303	M8	125.6	0.004
108303	MS4	153	0.008
108304	M2	166.5	0.309
108304	S2	234.7	0.087
108304	N2	122.1	0.037
108304	K1	106.2	0.068
108304	M4	57.4	0.025
108304	O1	136.2	0.026
108304	M6	312	0.003
108304	MK3	173.7	0.018
108304	S4	235.3	0.007
108304	MN4	12.3	0.033
108304	S6	311.9	0.003
108304	2N2	118.8	0.025
108304	OO1	20.4	0.013
108304	M1	126.7	0.011
108304	J1	295.5	0.023
108304	Q1	14.3	0.028
108304	2Q1	101.3	0.022
108304	2SM2	61.9	0.009
108304	M3	250.6	0.01
108304	L2	138	0.027
108304	M8	152.9	0.004
108304	MS4	127.6	0.033
108305	M2	160.6	3.592
108305	S2	198.2	1.042
108305	N2	128.2	0.688
108305	K1	148.9	0.295
108305	M4	244	0.068
108305	O1	134.1	0.148
108305	M6	340.5	0.225
108305	MK3	129.6	0.089
108305	S4	274.3	0.007
108305	MN4	254.6	0.04
108305	2N2	168.2	0.091
108305	OO1	159.3	0.007
108305	M1	176.4	0.007
108305	J1	159.8	0.019
108305	Q1	114	0.041
108305	2Q1	200.6	0.012
108305	P1	122.5	0.101
108305	2SM2	59.5	0.025
108305	M3	194.3	0.035
108305	L2	183.3	0.183
108305	2MK3	351.5	0.053
108305	K2	186	0.299
108305	M8	94.4	0.042
108305	MS4	311.9	0.049
108306	M2	161.3	3.713
108306	S2	196.5	1.046
108306	N2	127.7	0.703
108306	K1	151.8	0.297
108306	M4	265.3	0.064
108306	O1	134.8	0.151
108306	M6	348.7	0.249
108306	MK3	119.1	0.098
108306	S4	243.8	0.013
108306	MN4	252.3	0.051
108306	2N2	174	0.134
108306	OO1	113.5	0.004
108306	M1	135.2	0.008
108306	J1	155.1	0.019
108306	Q1	111.9	0.045
108306	2Q1	244.8	0.009
108306	P1	112.7	0.11
108306	2SM2	62.9	0.022
108306	M3	199.3	0.034
108306	L2	184.4	0.206
108306	2MK3	1.4	0.071
108306	K2	183	0.313
108306	M8	121.6	0.057
108306	MS4	276.4	0.042
108307	M2	161.6	3.718
108307	S2	194.1	1.008
108307	N2	126.4	0.704
108307	K1	147.5	0.301
108307	M4	275.3	0.032
108307	O1	129.3	0.156
108307	M6	351.5	0.256
108307	MK3	101.9	0.104
108307	S4	232.5	0.022
108307	MN4	261.7	0.051
108307	2N2	184	0.175
108307	OO1	142.6	0.008
108307	J1	146.8	0.021
108307	Q1	103.3	0.037
108307	P1	118.1	0.095
108307	2SM2	74.6	0.032
108307	M3	194	0.04
108307	L2	187.1	0.221
108307	2MK3	6.6	0.099
108307	K2	177.3	0.315
108307	M8	130.3	0.042
108307	MS4	249.1	0.021
108308	M2	134.5	0.514
108308	S2	124.2	0.097
108308	N2	52.4	0.09
108308	K1	106.9	0.031
108308	M4	56.6	0.224
108308	O1	145.4	0.042
108308	M6	310.3	0.054
108308	MK3	51.8	0.088
108308	S4	112.9	0.014
108308	MN4	37.3	0.066
108308	S6	102.4	0.006
108308	2N2	176.7	0.146
108308	OO1	248.3	0.01
108308	M1	293.1	0.025
108308	J1	291.3	0.01
108308	Q1	352.6	0.016
108308	2Q1	180.2	0.018
108308	2SM2	71.2	0.006
108308	M3	242.2	0.027
108308	L2	175.1	0.068
108308	2MK3	37.5	0.083
108308	M8	175.5	0.03
108308	MS4	129.7	0.138
108309	M2	135.5	0.949
108309	S2	173.7	0.241
108309	N2	81.9	0.169
108309	K1	112	0.145
108309	M4	97.7	0.139
108309	O1	90.9	0.109
108309	M6	356.6	0.062
108309	MK3	57.1	0.095
108309	S4	158.2	0.015
108309	MN4	71	0.06
108309	S6	251.5	0.002
108309	2N2	204.6	0.102
108309	OO1	222.7	0.011
108309	M1	321.5	0.026
108309	J1	38.6	0.003
108309	Q1	0.8	0.028
108309	2Q1	115.6	0.033
108309	2SM2	152.3	0.011
108309	M3	322.6	0.001
108309	L2	189.2	0.038
108309	2MK3	9.8	0.063
108309	M8	250	0.029
108309	MS4	140.6	0.098
108310	M2	125	0.819
108310	S2	188.5	0.265
108310	N2	78.3	0.151
108310	K1	122.9	0.17
108310	M4	78.3	0.147
108310	O1	99.2	0.115
108310	M6	4.2	0.101
108310	MK3	59.7	0.112
108310	S4	204.3	0.009
108310	MN4	20.9	0.067
108310	S6	283.9	0.015
108310	2N2	217.8	0.05
108310	OO1	261.5	0.017
108310	M1	327.3	0.032
108310	J1	61.5	0.014
108310	Q1	27.5	0.019
108310	2Q1	119.8	0.029
108310	2SM2	83.3	0.019
108310	M3	30.3	0.02
108310	L2	43.5	0.012
108310	2MK3	341.6	0.054
108310	M8	316.8	0.035
108310	MS4	106.9	0.057
108311	M2	209.7	0.844
108311	S2	251.1	0.305
108311	N2	181.7	0.21
108311	K1	175.6	0.156
108311	M4	11.7	0.051
108311	O1	133.8	0.048
108311	M6	289.9	0.015
108311	MK3	343.6	0.057
108311	S4	197	0.007
108311	MN4	334.9	0.024
108311	S6	156.4	0.006
108311	2N2	83.6	0.123
108311	OO1	70.4	0.014
108311	M1	139.6	0.048
108311	J1	206.1	0.036
108311	Q1	117.4	0.016
108311	2Q1	329.1	0.024
108311	P1	192.5	0.059
108311	2SM2	325.6	0.032
108311	M3	303.1	0.059
108311	L2	216	0.069
108311	2MK3	240.7	0.011
108311	K2	273.2	0.023
108311	M8	117.3	0.024
108311	MS4	69.1	0.059
108312	M2	211.8	0.927
108312	S2	247.9	0.3
108312	N2	186.8	0.26
108312	K1	175.8	0.223
108312	M4	4.1	0.054
108312	O1	173.1	0.13
108312	M6	215.8	0.027
108312	MK3	331.1	0.086
108312	S4	147.4	0.017
108312	MN4	29.8	0.033
108312	S6	200.4	0.014
108312	2N2	85	0.15
108312	OO1	46.2	0.008
108312	M1	91.5	0.042
108312	J1	177.7	0.033
108312	Q1	121.8	0.002
108312	2Q1	308.3	0.038
108312	P1	174.1	0.094
108312	2SM2	285	0.037
108312	M3	287.9	0.062
108312	L2	162.8	0.072
108312	2MK3	265.7	0.05
108312	K2	238.9	0.07
108312	M8	157.5	0.018
108312	MS4	50	0.083
108313	M2	220.9	1
108313	S2	254.8	0.355
108313	N2	186.9	0.326
108313	K1	190.6	0.256
108313	M4	15.8	0.115
108313	O1	183.1	0.162
108313	M6	177	0.051
108313	MK3	319.4	0.11
108313	S4	84.9	0.032
108313	MN4	1.7	0.062
108313	S6	253.7	0.01
108313	2N2	53.6	0.112
108313	OO1	307.8	0.023
108313	M1	74.5	0.079
108313	J1	154	0.053
108313	Q1	21.8	0.035
108313	2Q1	279	0.037
108313	P1	161.4	0.082
108313	2SM2	246.4	0.039
108313	M3	246	0.055
108313	L2	130.1	0.055
108313	2MK3	268.6	0.085
108313	K2	261.6	0.09
108313	M8	193.5	0.021
108313	MS4	18.8	0.116
108314	M2	180.8	0.825
108314	S2	228	0.222
108314	N2	137.5	0.182
108314	K1	163.5	0.126
108314	M4	6.2	0.072
108314	O1	113	0.055
108314	M6	56.4	0.07
108314	MK3	234.8	0.052
108314	S4	156.4	0.016
108314	MN4	336.8	0.017
108314	S6	266.3	0.01
108314	2N2	343.1	0.022
108314	OO1	4.2	0.018
108314	M1	35.8	0.02
108314	J1	108.7	0.022
108314	Q1	104.2	0.021
108314	2Q1	248.3	0.027
108314	2SM2	150.1	0.009
108314	M3	128.1	0.023
108314	L2	231.9	0.05
108314	2MK3	173.5	0.058
108314	M8	119	0.005
108314	MS4	42.1	0.07
108315	M2	183	0.814
108315	S2	241.1	0.208
108315	N2	151.2	0.142
108315	K1	124.7	0.221
108315	M4	239.4	0.034
108315	O1	70.4	0.106
108315	M6	13.8	0.031
108315	MK3	218.8	0.109
108315	S4	38.6	0.013
108315	MN4	165.4	0.03
108315	S6	296.5	0.006
108315	2N2	102.5	0.026
108315	OO1	354.6	0.009
108315	M1	86	0.011
108315	J1	61.4	0.022
108315	Q1	2	0.008
108315	2Q1	251.4	0.006
108315	2SM2	94.3	0.027
108315	M3	194.1	0.018
108315	L2	280.1	0.047
108315	2MK3	148.2	0.049
108315	M8	70.5	0.017
108315	MS4	264.7	0.05
108316	M2	181.6	0.832
108316	S2	226.7	0.245
108316	N2	147.6	0.132
108316	K1	102.1	0.356
108316	M4	218	0.098
108316	O1	51.9	0.127
108316	M6	272.4	0.015
108316	MK3	172.5	0.09
108316	S4	227.3	0.009
108316	MN4	161.6	0.03
108316	S6	181.3	0.007
108316	2N2	100.3	0.04
108316	OO1	124.5	0.012
108316	M1	353.8	0.028
108316	J1	215.5	0.014
108316	Q1	3.7	0.042
108316	2Q1	130.9	0.003
108316	2SM2	142.9	0.014
108316	M3	332.9	0.005
108316	L2	208.2	0.024
108316	2MK3	117.7	0.058
108316	M8	92.5	0.012
108316	MS4	230.5	0.083
108317	M2	162.8	0.109
108317	S2	216	0.036
108317	N2	132.9	0.023
108317	K1	203.3	0.056
108317	M4	72	0.016
108317	O1	168.5	0.036
108317	M6	348.3	0.011
108317	MK3	149.8	0.004
108317	S4	84.3	0.004
108317	MN4	54.3	0.005
108317	S6	82.3	0.003
108317	2N2	76.6	0.013
108317	OO1	147.4	0.007
108317	M1	145.4	0.002
108317	J1	297.8	0.007
108317	Q1	137.5	0.007
108317	2Q1	71.4	0.006
108317	2SM2	260.1	0.003
108317	M3	32.3	0.007
108317	L2	110.9	0.005
108317	2MK3	182.6	0.007
108317	M8	324.9	0.004
108317	MS4	105	0.008
108318	M2	208.6	0.208
108318	S2	239.7	0.051
108318	N2	170.2	0.035
108318	K1	236	0.109
108318	M4	250.5	0.015
108318	O1	200.9	0.077
108318	M6	201.7	0.014
108318	MK3	258.7	0.035
108318	S4	132.3	0.001
108318	MN4	284.5	0.007
108318	S6	216.7	0.006
108318	2N2	58.2	0.024
108318	OO1	279.4	0.005
108318	M1	137.7	0.005
108318	J1	178.5	0.007
108318	Q1	182.2	0.019
108318	2SM2	30.4	0.002
108318	M3	164.7	0.01
108318	L2	303	0.024
108318	2MK3	207.2	0.009
108318	M8	132.6	0.001
108318	MS4	309	0.009
108319	M2	215.7	0.3
108319	S2	245.3	0.097
108319	N2	160.6	0.079
108319	K1	252.4	0.128
108319	M4	299.6	0.052
108319	O1	202.7	0.079
108319	M6	112.6	0.002
108319	MK3	281.3	0.016
108319	S4	298.8	0.004
108319	MN4	256.7	0.027
108319	S6	226.6	0.003
108319	2N2	110.1	0.012
108319	OO1	302.4	0.012
108319	M1	196.6	0.019
108319	J1	183	0.014
108319	Q1	203.1	0.033
108319	2Q1	284.4	0.012
108319	2SM2	166	0.014
108319	M3	168.8	0.011
108319	L2	300.9	0.004
108319	2MK3	257.5	0.01
108319	M8	315.6	0.005
108319	MS4	312.9	0.024
108320	M2	212	0.636
108320	S2	235.8	0.111
108320	N2	174.5	0.111
108320	K1	200.2	0.147
108320	M4	99.3	0.062
108320	O1	196.9	0.073
108320	M6	102.4	0.036
108320	MK3	107.4	0.068
108320	S4	209.8	0.018
108320	MN4	18.7	0.037
108320	S6	308.2	0.013
108320	2N2	231.7	0.033
108320	OO1	278.3	0.017
108320	M1	1.3	0.019
108320	J1	227	0.009
108320	Q1	84.3	0.011
108320	2Q1	179.6	0.025
108320	P1	350	0.018
108320	2SM2	56.9	0.007
108320	M3	273.8	0.012
108320	L2	246.7	0.04
108320	2MK3	56.7	0.083
108320	K2	204.9	0.044
108320	M8	192.2	0.005
108320	MS4	165	0.015
108321	M2	214.2	0.911
108321	S2	244	0.244
108321	N2	174.1	0.191
108321	K1	192.2	0.22
108321	M4	77.8	0.138
108321	O1	202.6	0.091
108321	M6	283.1	0.013
108321	MK3	78.8	0.086
108321	S4	136.5	0.011
108321	MN4	34.3	0.055
108321	S6	236.6	0.002
108321	2N2	121.8	0.046
108321	OO1	249.3	0.016
108321	M1	187.7	0.003
108321	J1	285.5	0.012
108321	Q1	194.4	0.015
108321	2Q1	133.9	0.02
108321	P1	221.5	0.08
108321	2SM2	283.8	0.007
108321	M3	353	0.007
108321	L2	194.1	0.031
108321	2MK3	63.9	0.082
108321	K2	223.9	0.083
108321	M8	304.4	0.017
108321	MS4	132.4	0.072
108322	M2	216.4	1.093
108322	S2	245.8	0.326
108322	N2	180	0.241
108322	K1	193.5	0.265
108322	M4	47.9	0.193
108322	O1	189.1	0.09
108322	M6	251.2	0.032
108322	MK3	56.1	0.105
108322	S4	131.7	0.02
108322	MN4	24.2	0.063
108322	2N2	84.7	0.048
108322	OO1	282.5	0.012
108322	M1	180.4	0.015
108322	J1	247.1	0.006
108322	Q1	197	0.028
108322	2Q1	59.4	0.03
108322	P1	195.2	0.114
108322	2SM2	233.7	0.027
108322	M3	29.8	0.024
108322	L2	220.1	0.016
108322	2MK3	53.1	0.075
108322	K2	221.7	0.116
108322	M8	292.6	0.025
108322	MS4	110.2	0.134
108323	M2	198.7	2.301
108323	S2	230.1	0.661
108323	N2	161.1	0.423
108323	K1	171.5	0.439
108323	M4	22.2	0.352
108323	O1	142.3	0.254
108323	M6	68	0.087
108323	MK3	13.6	0.26
108323	S4	146.3	0.049
108323	MN4	347.4	0.129
108323	S6	28.5	0.016
108323	2N2	174.3	0.093
108323	OO1	227.5	0.018
108323	M1	157.1	0.016
108323	J1	208.1	0.029
108323	Q1	115.3	0.048
108323	2Q1	95.8	0.026
108323	P1	168	0.154
108323	2SM2	23.2	0.026
108323	M3	353.5	0.035
108323	L2	213	0.14
108323	2MK3	346.9	0.222
108323	K2	207	0.173
108323	M8	265.6	0.048
108323	MS4	72.7	0.225
108324	M2	199.3	2.252
108324	S2	234.9	0.714
108324	N2	169.1	0.459
108324	K1	177.7	0.514
108324	M4	29.3	0.389
108324	O1	147.6	0.189
108324	M6	35	0.03
108324	MK3	22	0.253
108324	S4	156.3	0.053
108324	MN4	352.2	0.149
108324	S6	17.5	0.015
108324	2N2	137.4	0.068
108324	OO1	187.6	0.026
108324	M1	154.8	0.035
108324	J1	172.8	0.016
108324	Q1	140.9	0.059
108324	2Q1	103.5	0.031
108324	P1	197.2	0.126
108324	2SM2	27.7	0.031
108324	M3	355.7	0.062
108324	L2	218.9	0.098
108324	2MK3	351.3	0.162
108324	K2	215.9	0.208
108324	M8	252.4	0.046
108324	MS4	85.1	0.246
108325	M2	200.2	2.012
108325	S2	239.6	0.701
108325	N2	177.3	0.479
108325	K1	178.7	0.561
108325	M4	32.9	0.356
108325	O1	158.7	0.128
108325	M6	278.3	0.064
108325	MK3	31.3	0.184
108325	S4	181.2	0.047
108325	MN4	7.7	0.142
108325	S6	25.1	0.01
108325	2N2	80.8	0.089
108325	OO1	167.5	0.037
108325	M1	166.1	0.034
108325	J1	116	0.022
108325	Q1	154.7	0.069
108325	2Q1	101.7	0.029
108325	P1	234.2	0.163
108325	2SM2	60.1	0.032
108325	M3	19.7	0.084
108325	L2	243.8	0.037
108325	2MK3	351.7	0.075
108325	K2	221.4	0.227
108325	M8	138.6	0.005
108325	MS4	100.2	0.228
108326	M2	154.6	0.321
108326	S2	209.1	0.114
108326	N2	102.3	0.057
108326	K1	174.4	0.028
108326	M4	317.4	0.046
108326	O1	121.5	0.016
108326	M6	87.5	0.018
108326	MK3	351.9	0.015
108326	S4	62.9	0.003
108326	MN4	287.4	0.014
108326	S6	111.4	0.003
108326	2N2	139.7	0.015
108326	OO1	137.6	0.006
108326	M1	81.4	0.007
108326	J1	173.1	0.009
108326	Q1	29.1	0.003
108326	2Q1	31.5	0.005
108326	2SM2	81.5	0.019
108326	M3	240.8	0.01
108326	L2	250.8	0.016
108326	2MK3	242.7	0.01
108326	M8	47.5	0.008
108326	MS4	23	0.045
108327	M2	134.2	0.201
108327	S2	171.7	0.11
108327	N2	94	0.039
108327	K1	136.1	0.026
108327	M4	149.7	0.022
108327	O1	113	0.026
108327	M6	49	0.021
108327	MK3	145.4	0.015
108327	S4	262.3	0.001
108327	MN4	105.3	0.01
108327	S6	135.3	0.002
108327	2N2	351.4	0.03
108327	OO1	186.6	0.003
108327	M1	62.2	0.011
108327	J1	127.6	0.007
108327	Q1	109.5	0.008
108327	2Q1	14	0.014
108327	2SM2	61.9	0.006
108327	M3	238.5	0.005
108327	L2	149.3	0.013
108327	2MK3	256	0.003
108327	M8	218.5	0.008
108327	MS4	214.1	0.027
108328	M2	176.6	0.293
108328	S2	223.4	0.13
108328	N2	131.7	0.064
108328	K1	80.9	0.044
108328	M4	162.9	0.02
108328	O1	19	0.028
108328	M6	92	0.011
108328	MK3	50.3	0.002
108328	S4	284.3	0.009
108328	MN4	107.7	0.013
108328	S6	128.7	0.003
108328	2N2	279	0.028
108328	OO1	113.2	0.009
108328	M1	266.2	0.011
108328	J1	22.1	0.008
108328	Q1	168.5	0.002
108328	2Q1	328.8	0.006
108328	2SM2	251.6	0.015
108328	M3	209.5	0.002
108328	L2	52	0.002
108328	2MK3	108.1	0.009
108328	M8	123.8	0.006
108328	MS4	200.9	0.01
108329	M2	189.2	1.524
108329	S2	221.8	0.5
108329	N2	158.9	0.249
108329	K1	153.7	0.18
108329	M4	275.3	0.082
108329	O1	152.4	0.066
108329	M6	229.3	0.057
108329	MK3	219.1	0.02
108329	S4	47	0.053
108329	MN4	233.3	0.033
108329	S6	285.5	0.015
108329	2N2	61	0.103
108329	OO1	205.3	0.012
108329	M1	187.9	0.012
108329	J1	114.8	0.007
108329	Q1	174.8	0.012
108329	2Q1	322.9	0.023
108329	P1	160.9	0.051
108329	2SM2	12.4	0.059
108329	M3	288.8	0.033
108329	L2	203.1	0.04
108329	2MK3	98.8	0.052
108329	K2	215.3	0.204
108329	M8	134.9	0.04
108329	MS4	340.3	0.079
108330	M2	197.2	1.644
108330	S2	225.1	0.621
108330	N2	158.2	0.308
108330	K1	166	0.208
108330	M4	312.3	0.071
108330	O1	161.2	0.093
108330	M6	250.5	0.051
108330	MK3	263.6	0.015
108330	S4	325.5	0.013
108330	MN4	197.4	0.03
108330	S6	59.1	0.009
108330	2N2	222.5	0.01
108330	OO1	6.9	0.005
108330	M1	35.3	0.013
108330	J1	105.2	0.029
108330	Q1	145.4	0.016
108330	2Q1	277.5	0.005
108330	P1	132.1	0.041
108330	2SM2	97.2	0.03
108330	M3	262.8	0.028
108330	L2	186.6	0.014
108330	2MK3	135.6	0.017
108330	K2	224.6	0.118
108330	M8	80.8	0.014
108330	MS4	337.7	0.044
108331	M2	202.3	1.679
108331	S2	232.2	0.607
108331	N2	169	0.315
108331	K1	161.2	0.246
108331	M4	358.9	0.042
108331	O1	147	0.089
108331	M6	264	0.018
108331	MK3	186.3	0.03
108331	S4	247.9	0.028
108331	MN4	111.7	0.021
108331	S6	77.5	0.015
108331	2N2	214.1	0.037
108331	OO1	136.8	0.015
108331	M1	93.3	0.012
108331	J1	128.5	0.018
108331	Q1	117.5	0.019
108331	2Q1	192.4	0.01
108331	P1	188.1	0.078
108331	2SM2	172.3	0.024
108331	M3	257.7	0.024
108331	L2	166.3	0.017
108331	2MK3	201.4	0.032
108331	K2	196.2	0.111
108331	M8	45	0.017
108331	MS4	25.8	0.016
108332	M2	159.7	1.261
108332	S2	188.6	0.476
108332	N2	120	0.209
108332	K1	138.9	0.093
108332	M4	126.2	0.314
108332	O1	99.7	0.084
108332	M6	105	0.075
108332	MK3	112	0.063
108332	S4	149.1	0.051
108332	MN4	70.1	0.067
108332	S6	176.3	0.032
108332	2N2	205.1	0.166
108332	OO1	39.4	0.018
108332	M1	221.8	0.01
108332	J1	93	0.016
108332	Q1	51.6	0.018
108332	2Q1	197.5	0.041
108332	2SM2	110.2	0.089
108332	M3	237.7	0.017
108332	L2	218.2	0.03
108332	2MK3	91.4	0.071
108332	M8	165.4	0.033
108332	MS4	158.1	0.235
108333	M2	166.2	1.28
108333	S2	185.8	0.489
108333	N2	124.1	0.234
108333	K1	141.9	0.109
108333	M4	163.7	0.301
108333	O1	94.7	0.061
108333	M6	107.7	0.079
108333	MK3	144.9	0.09
108333	S4	138.5	0.08
108333	MN4	102.7	0.095
108333	S6	138	0.063
108333	2N2	216.1	0.271
108333	OO1	36.3	0.025
108333	M1	321.1	0.02
108333	J1	61.9	0.019
108333	Q1	0.4	0.024
108333	2Q1	192.3	0.063
108333	2SM2	118.4	0.098
108333	M3	342.4	0.015
108333	L2	271.1	0.025
108333	2MK3	110.4	0.087
108333	M8	135.9	0.065
108333	MS4	172.7	0.235
108334	M2	173	1.326
108334	S2	180.3	0.604
108334	N2	116.8	0.287
108334	K1	145.5	0.183
108334	M4	169.1	0.273
108334	O1	102.6	0.058
108334	M6	97.5	0.075
108334	MK3	178.5	0.081
108334	S4	144.5	0.082
108334	MN4	119.1	0.136
108334	S6	150.3	0.079
108334	2N2	223.5	0.483
108334	OO1	26.5	0.071
108334	M1	23.8	0.013
108334	J1	101.3	0.034
108334	Q1	351.8	0.039
108334	2Q1	199.3	0.074
108334	2SM2	124.1	0.075
108334	M3	338.7	0.005
108334	L2	308.2	0.052
108334	2MK3	130.3	0.06
108334	M8	111.4	0.107
108334	MS4	188.3	0.274
108335	M2	214.8	3.402
108335	S2	247.1	1.11
108335	N2	186	0.54
108335	K1	183.7	0.482
108335	M4	7.3	0.132
108335	O1	169.1	0.302
108335	M6	159.4	0.104
108335	MK3	272.5	0.024
108335	S4	238.2	0.018
108335	MN4	341.6	0.032
108335	S6	106.3	0.008
108335	2N2	130.3	0.095
108335	OO1	246.9	0.029
108335	M1	252.9	0.012
108335	J1	204.1	0.021
108335	Q1	155	0.039
108335	2Q1	100.6	0.02
108335	P1	183.6	0.13
108335	2SM2	49.7	0.073
108335	M3	310.6	0.042
108335	L2	231.3	0.104
108335	2MK3	20.2	0.035
108335	K2	240.4	0.326
108335	M8	237.6	0.009
108335	MS4	53.6	0.074
108336	M2	213.6	4.059
108336	S2	245.4	1.348
108336	N2	185.5	0.658
108336	K1	186.2	0.581
108336	M4	354.2	0.172
108336	O1	168.4	0.347
108336	M6	153.6	0.123
108336	MK3	257.2	0.056
108336	S4	179.7	0.01
108336	MN4	313.8	0.046
108336	S6	177.3	0.013
108336	2N2	126.2	0.114
108336	OO1	233.7	0.032
108336	M1	194	0.017
108336	J1	179.3	0.038
108336	Q1	146.1	0.055
108336	2Q1	79.8	0.016
108336	P1	194.5	0.156
108336	2SM2	55	0.085
108336	M3	317.2	0.056
108336	L2	224.6	0.115
108336	2MK3	353.6	0.028
108336	K2	244	0.391
108336	M8	208.9	0.017
108336	MS4	30.7	0.094
108337	M2	213.7	4.082
108337	S2	249	1.389
108337	N2	188.1	0.685
108337	K1	179.8	0.56
108337	M4	78.8	0.117
108337	O1	157.6	0.282
108337	M6	176.9	0.112
108337	MK3	223.8	0.067
108337	S4	143.2	0.052
108337	MN4	76.5	0.045
108337	S6	94.8	0.011
108337	2N2	87.9	0.142
108337	OO1	184.5	0.014
108337	M1	180.4	0.013
108337	J1	201.2	0.031
108337	Q1	161.8	0.054
108337	2Q1	351.1	0.031
108337	P1	183.6	0.193
108337	2SM2	42.6	0.041
108337	M3	302.2	0.04
108337	L2	220	0.089
108337	2MK3	199.7	0.034
108337	K2	235.1	0.393
108337	M8	42.9	0.038
108337	MS4	155.2	0.139
108338	M2	197.8	0.175
108338	S2	236.8	0.071
108338	N2	170.8	0.026
108338	K1	182.8	0.005
108338	M4	220	0.004
108338	O1	129.7	0.009
108338	M6	170.1	0.004
108338	MK3	307	0.007
108338	S4	328.7	0.001
108338	MN4	330.9	0.005
108338	S6	224.4	0.003
108338	2N2	70.2	0.01
108338	OO1	285.3	0.003
108338	M1	262.6	0.003
108338	J1	292.5	0.002
108338	Q1	114.4	0.004
108338	2Q1	68	0.001
108338	2SM2	7.2	0.015
108338	M3	318.2	0.009
108338	L2	154.2	0.008
108338	2MK3	63	0.003
108338	M8	96	0.002
108338	MS4	186.6	0.006
108339	M2	204.4	0.153
108339	S2	253.6	0.076
108339	N2	157.4	0.021
108339	K1	168.5	0.014
108339	M4	68.9	0.039
108339	O1	128.1	0.006
108339	M6	149.8	0.008
108339	MK3	168.4	0.003
108339	S4	144	0.004
108339	MN4	38.4	0.012
108339	S6	19.7	0.002
108339	2N2	342.8	0.003
108339	OO1	209.1	0.002
108339	M1	54.3	0.005
108339	J1	254.5	0.002
108339	2Q1	127.4	0.001
108339	2SM2	163.8	0.006
108339	M3	279.4	0.001
108339	L2	120.5	0.008
108339	2MK3	17.9	0.004
108339	M8	11.3	0.004
108339	MS4	109.9	0.026
108340	M2	221.1	0.227
108340	S2	294.3	0.079
108340	N2	194.9	0.026
108340	K1	244.3	0.011
108340	M4	249.2	0.025
108340	O1	228	0.013
108340	M6	350.3	0.003
108340	MK3	78.1	0.003
108340	S4	107	0.01
108340	MN4	216.3	0.01
108340	S6	9.1	0.007
108340	2N2	125.8	0.035
108340	OO1	306.7	0.004
108340	M1	184.5	0.003
108340	J1	63	0.001
108340	Q1	204.8	0.008
108340	2Q1	187.9	0.001
108340	2SM2	81.2	0.025
108340	M3	344.9	0.007
108340	L2	191.7	0.01
108340	2MK3	312.6	0.006
108340	M8	168.5	0.007
108340	MS4	344.6	0.016
108341	M2	91.5	0.288
108341	S2	140.1	0.186
108341	N2	43.1	0.019
108341	K1	14.1	0.03
108341	M4	90.1	0.074
108341	O1	281.4	0.026
108341	M6	108.1	0.039
108341	MK3	66.1	0.02
108341	S4	337.6	0.018
108341	MN4	339.3	0.02
108341	S6	251.6	0.008
108341	2N2	338.4	0.062
108341	OO1	55.5	0.008
108341	M1	42.2	0.003
108341	J1	16.6	0.005
108341	Q1	95.2	0.004
108341	2Q1	159.1	0.02
108341	P1	158.5	0.005
108341	2SM2	177.6	0.016
108341	M3	191.1	0.007
108341	L2	102.2	0.017
108341	2MK3	349.5	0.027
108341	K2	240.2	0.019
108341	M8	198.2	0.008
108341	MS4	166.6	0.026
108342	M2	117.8	0.608
108342	S2	145.7	0.247
108342	N2	59.6	0.067
108342	K1	20.5	0.078
108342	M4	240.1	0.069
108342	O1	345.9	0.037
108342	M6	182.1	0.021
108342	MK3	141.2	0.037
108342	S4	258	0.022
108342	MN4	119.7	0.023
108342	S6	13.2	0.009
108342	2N2	87.9	0.054
108342	OO1	105.1	0.009
108342	M1	3.4	0.004
108342	J1	56.1	0.022
108342	Q1	24.8	0.016
108342	2Q1	129.3	0.018
108342	P1	24	0.014
108342	2SM2	82.2	0.022
108342	M3	176	0.008
108342	L2	144.2	0.027
108342	2MK3	71.6	0.032
108342	K2	153.5	0.063
108342	M8	254.4	0.014
108342	MS4	271.3	0.076
108343	M2	124.9	0.816
108343	S2	132.9	0.161
108343	N2	59.5	0.121
108343	K1	332	0.139
108343	M4	249.8	0.122
108343	O1	329	0.054
108343	M6	231.1	0.05
108343	MK3	126.6	0.058
108343	S4	188.6	0.031
108343	MN4	103.6	0.026
108343	S6	56.9	0.012
108343	2N2	132.1	0.156
108343	OO1	204.8	0.022
108343	M1	289.1	0.012
108343	J1	44.6	0.008
108343	Q1	307.2	0.008
108343	2Q1	343.6	0.019
108343	P1	336.5	0.073
108343	2SM2	4.8	0.062
108343	M3	335	0.007
108343	L2	160.5	0.086
108343	2MK3	73.9	0.068
108343	K2	169.1	0.131
108343	M8	334	0.009
108343	MS4	267.4	0.051
108344	M2	199.4	0.404
108344	S2	235.4	0.167
108344	N2	187.4	0.064
108344	K1	189.9	0.094
108344	M4	239.3	0.033
108344	O1	175.4	0.091
108344	M6	231.9	0.028
108344	MK3	206.6	0.065
108344	S4	289.8	0.006
108344	MN4	277.6	0.011
108344	S6	31.6	0.002
108344	2N2	262.7	0.023
108344	OO1	255.4	0.011
108344	M1	168	0.005
108344	J1	162	0.015
108344	Q1	197.5	0.024
108344	2Q1	298.9	0.006
108344	P1	205.1	0.055
108344	2SM2	191	0.009
108344	M3	129.4	0.014
108344	L2	272.6	0.02
108344	2MK3	207.6	0.053
108344	K2	235.2	0.045
108344	M8	28.1	0.01
108344	MS4	279.7	0.04
108345	M2	202.3	0.499
108345	S2	231.2	0.186
108345	N2	183.5	0.084
108345	K1	185.5	0.118
108345	M4	225.8	0.068
108345	O1	160.1	0.074
108345	M6	212.5	0.035
108345	MK3	187.2	0.053
108345	S4	349.8	0.004
108345	MN4	225.5	0.025
108345	S6	7	0.004
108345	2N2	176.1	0.011
108345	OO1	194.1	0.013
108345	M1	91.9	0.007
108345	J1	160.3	0.011
108345	Q1	192.1	0.024
108345	2Q1	76.3	0.005
108345	P1	150.6	0.024
108345	2SM2	105.5	0.005
108345	M3	169.5	0.005
108345	L2	256.8	0.02
108345	2MK3	172	0.035
108345	K2	223.3	0.056
108345	M8	16.8	0.007
108345	MS4	250.2	0.039
108346	M2	197.9	0.579
108346	S2	222.4	0.175
108346	N2	179	0.104
108346	K1	176.8	0.103
108346	M4	229.1	0.099
108346	O1	160.1	0.059
108346	M6	177.6	0.029
108346	MK3	175.3	0.041
108346	S4	353.5	0.002
108346	MN4	223.5	0.034
108346	S6	309.6	0.005
108346	2N2	146.7	0.026
108346	OO1	163.3	0.007
108346	M1	352.3	0.004
108346	J1	232.6	0.005
108346	Q1	182.6	0.017
108346	2Q1	26.8	0.001
108346	P1	171.2	0.019
108346	2SM2	24.9	0.003
108346	M3	278.1	0.006
108346	L2	220	0.025
108346	2MK3	146.3	0.026
108346	K2	216.8	0.043
108346	M8	104.8	0.004
108346	MS4	243.5	0.042
108347	M2	193.3	0.816
108347	S2	228	0.281
108347	N2	173.7	0.184
108347	K1	104.5	0.156
108347	M4	23.2	0.079
108347	O1	52	0.089
108347	M6	62.1	0.015
108347	MK3	236.7	0.033
108347	S4	351.7	0.011
108347	MN4	327.8	0.03
108347	S6	225	0.003
108347	2N2	184.4	0.038
108347	OO1	258.7	0.016
108347	M1	11.6	0.01
108347	J1	135.6	0.012
108347	MSF	219.2	0.109
108347	MF	232.6	0.036
108347	Q1	73.7	0.015
108347	2Q1	102.6	0.012
108347	P1	71.7	0.03
108347	2SM2	98.8	0.007
108347	M3	27.8	0.017
108347	L2	182.2	0.024
108347	2MK3	127	0.013
108347	K2	217.5	0.091
108347	M8	233.1	0.011
108347	MS4	55.1	0.026
108348	M2	209	0.789
108348	S2	245.2	0.269
108348	N2	191	0.153
108348	K1	126.8	0.136
108348	M4	272.4	0.034
108348	O1	93.8	0.112
108348	M6	354.8	0.024
108348	MK3	134	0.021
108348	S4	18.4	0.013
108348	MN4	277.8	0.022
108348	S6	196	0.006
108348	2N2	236	0.031
108348	OO1	257.6	0.004
108348	M1	56.1	0.013
108348	J1	181.4	0.013
108348	MSF	50	0.081
108348	MF	44.1	0.053
108348	Q1	93.8	0.014
108348	2Q1	118.8	0.004
108348	P1	99.8	0.046
108348	2SM2	34.5	0.002
108348	M3	258.5	0.021
108348	L2	212.2	0.066
108348	2MK3	95.4	0.032
108348	K2	248.8	0.099
108348	M8	274.1	0.016
108348	MS4	355.1	0.025
108349	M2	200.1	0.675
108349	S2	232.7	0.216
108349	N2	172.3	0.128
108349	K1	155.3	0.116
108349	M4	208.4	0.07
108349	O1	136	0.086
108349	M6	37.6	0.018
108349	MK3	154.1	0.058
108349	S4	249.2	0.004
108349	MN4	151.2	0.012
108349	S6	134.7	0.003
108349	2N2	153	0.033
108349	OO1	29.3	0.013
108349	M1	183.4	0.007
108349	J1	128.6	0.012
108349	MSF	12	0.072
108349	MF	276.1	0.015
108349	Q1	114.7	0.018
108349	2Q1	291.4	0.008
108349	P1	172.7	0.017
108349	2SM2	212.9	0.007
108349	M3	332.4	0.007
108349	L2	112.7	0.011
108349	2MK3	92.7	0.05
108349	K2	212.6	0.057
108349	M8	255.8	0.016
108349	MS4	247.3	0.047
108350	M2	205.8	1.699
108350	S2	228.7	0.531
108350	N2	179.4	0.277
108350	K1	140.5	0.182
108350	M4	135.8	0.267
108350	O1	94.4	0.1
108350	M6	265.6	0.062
108350	MK3	126	0.069
108350	S4	203	0.033
108350	MN4	89.7	0.104
108350	S6	252.5	0.013
108350	2N2	132.8	0.082
108350	OO1	266.8	0.013
108350	M1	17.2	0.007
108350	J1	97.8	0.019
108350	MSF	35.2	0.149
108350	MF	53.6	0.046
108350	Q1	118.1	0.016
108350	2Q1	342.8	0.004
108350	P1	128.1	0.029
108350	2SM2	325.5	0.007
108350	M3	326.7	0.039
108350	L2	256.8	0.073
108350	2MK3	133.3	0.048
108350	K2	212	0.159
108350	M8	130.8	0.041
108350	MS4	164	0.196
108351	M2	210.8	1.937
108351	S2	233	0.633
108351	N2	180.9	0.332
108351	K1	149.3	0.207
108351	M4	123.6	0.337
108351	O1	106	0.106
108351	M6	245.1	0.057
108351	MK3	112.5	0.035
108351	S4	200.3	0.042
108351	MN4	86.9	0.12
108351	S6	251.9	0.016
108351	2N2	152.6	0.106
108351	OO1	299.3	0.019
108351	M1	85.8	0.004
108351	J1	91	0.024
108351	MSF	37.3	0.196
108351	MF	46.4	0.052
108351	Q1	154.9	0.01
108351	2Q1	45.4	0.016
108351	P1	130.5	0.048
108351	M3	345	0.029
108351	L2	271.1	0.079
108351	2MK3	147.6	0.042
108351	K2	219.9	0.188
108351	M8	105.2	0.048
108351	MS4	156.4	0.217
108352	M2	212.5	1.939
108352	S2	234	0.601
108352	N2	185	0.328
108352	K1	159.4	0.195
108352	M4	124.4	0.386
108352	O1	123.4	0.101
108352	M6	297.8	0.056
108352	MK3	146.6	0.039
108352	S4	183	0.059
108352	MN4	88.5	0.129
108352	S6	323	0.014
108352	2N2	150	0.112
108352	OO1	296	0.033
108352	M1	79.9	0.012
108352	J1	56.7	0.029
108352	MSF	42.1	0.155
108352	MF	99.4	0.037
108352	Q1	185.8	0.038
108352	2Q1	353.4	0.035
108352	P1	113.1	0.032
108352	2SM2	143.8	0.03
108352	M3	9.7	0.027
108352	L2	250.2	0.127
108352	2MK3	143.5	0.031
108352	K2	219	0.2
108352	M8	88.1	0.049
108352	MS4	153	0.285
108353	M2	211.6	1.893
108353	S2	247.2	0.585
108353	N2	198.3	0.357
108353	K1	175.3	0.23
108353	M4	32	0.178
108353	O1	162.8	0.158
108353	M6	176.5	0.151
108353	MK3	330.7	0.054
108353	S4	106.7	0.011
108353	MN4	344.4	0.087
108353	S6	316.6	0.005
108353	2N2	182.5	0.02
108353	OO1	196.2	0.038
108353	M1	196.1	0.02
108353	J1	270.5	0.017
108353	MSF	62.4	0.031
108353	MF	55	0.012
108353	Q1	175.6	0.044
108353	2Q1	257.9	0.025
108353	P1	217.9	0.056
108353	2SM2	80.8	0.026
108353	M3	214.9	0.023
108353	L2	195.6	0.075
108353	2MK3	334	0.016
108353	K2	236.3	0.135
108353	M8	292.7	0.038
108353	MS4	52.6	0.154
108354	M2	215.3	2.274
108354	S2	250	0.718
108354	N2	197.9	0.424
108354	K1	183.8	0.304
108354	M4	17.7	0.303
108354	O1	169.9	0.194
108354	M6	184.2	0.174
108354	MK3	288	0.09
108354	S4	84.4	0.023
108354	MN4	351.5	0.102
108354	S6	48.5	0.008
108354	2N2	185.3	0.048
108354	OO1	211.2	0.023
108354	M1	233.7	0.013
108354	J1	217.8	0.017
108354	MSF	43.5	0.045
108354	MF	75.9	0.014
108354	Q1	177.2	0.043
108354	2Q1	353.3	0.014
108354	P1	175.7	0.051
108354	2SM2	89.6	0.024
108354	M3	241.9	0.019
108354	L2	207.4	0.1
108354	2MK3	299	0.036
108354	K2	238.3	0.176
108354	M8	302	0.057
108354	MS4	49.1	0.182
108355	M2	217	2.303
108355	S2	253.4	0.782
108355	N2	196	0.464
108355	K1	192.3	0.323
108355	M4	22.8	0.459
108355	O1	162.4	0.196
108355	M6	213.4	0.115
108355	MK3	267.7	0.139
108355	S4	341.9	0.02
108355	MN4	3.6	0.13
108355	S6	183.1	0.012
108355	2N2	223	0.071
108355	OO1	98.5	0.003
108355	M1	86.7	0.004
108355	J1	120.4	0.007
108355	MSF	25.4	0.134
108355	MF	33.1	0.052
108355	Q1	172.7	0.033
108355	2Q1	316.6	0.01
108355	P1	177.4	0.119
108355	2SM2	54.9	0.029
108355	M3	309.9	0.017
108355	L2	193.2	0.089
108355	2MK3	320.2	0.026
108355	K2	241.6	0.211
108355	M8	343.5	0.11
108355	MS4	58.8	0.217
108356	M2	182.1	0.976
108356	S2	263.2	0.376
108356	N2	193.4	0.261
108356	K1	198.2	0.198
108356	M4	223.3	0.157
108356	O1	172.7	0.164
108356	M6	67.6	0.204
108356	MK3	48.2	0.023
108356	S4	25.9	0.042
108356	MN4	222.6	0.061
108356	S6	12.6	0.008
108356	2N2	300.2	0.143
108356	OO1	145.1	0.03
108356	M1	189.1	0.012
108356	J1	214.2	0.039
108356	MSF	210.8	0.11
108356	MF	250.9	0.019
108356	Q1	142.2	0.026
108356	2Q1	191.8	0.033
108356	P1	192.3	0.075
108356	2SM2	22.6	0.065
108356	M3	204.7	0.027
108356	L2	128.5	0.201
108356	2MK3	354.7	0.086
108356	K2	272.6	0.074
108356	M8	146.5	0.044
108356	MS4	291.5	0.116
108357	M2	189.5	1.17
108357	S2	252	0.403
108357	N2	192.3	0.267
108357	K1	192.8	0.232
108357	M4	234.2	0.142
108357	O1	180.2	0.184
108357	M6	51.4	0.191
108357	MK3	313.5	0.025
108357	S4	28.6	0.038
108357	MN4	227.6	0.044
108357	S6	30.7	0.013
108357	2N2	309.9	0.088
108357	OO1	147.8	0.028
108357	M1	212.7	0.005
108357	J1	224.6	0.031
108357	MSF	211.6	0.201
108357	MF	234.1	0.052
108357	Q1	163.1	0.038
108357	2Q1	211.4	0.023
108357	P1	202.5	0.07
108357	2SM2	26.4	0.048
108357	M3	234.1	0.028
108357	L2	138.6	0.152
108357	2MK3	343.4	0.072
108357	K2	251.3	0.076
108357	M8	149.1	0.052
108357	MS4	297	0.09
108358	M2	203	1.157
108358	S2	235.6	0.317
108358	N2	182.6	0.209
108358	K1	187.1	0.228
108358	M4	218.1	0.158
108358	O1	190.4	0.116
108358	M6	33.5	0.134
108358	MK3	186.6	0.087
108358	S4	318.4	0.025
108358	MN4	183	0.067
108358	S6	2.7	0.018
108358	2N2	112.7	0.045
108358	OO1	50.1	0.014
108358	M1	336	0.015
108358	J1	156.3	0.032
108358	MSF	233.6	0.18
108358	MF	212.6	0.043
108358	Q1	51.5	0.009
108358	2Q1	141.4	0.016
108358	P1	161.7	0.056
108358	2SM2	116	0.052
108358	M3	290.2	0.05
108358	L2	191.8	0.062
108358	2MK3	21	0.034
108358	K2	213.8	0.075
108358	M8	171.4	0.07
108358	MS4	255	0.12
108359	M2	165.5	2.524
108359	S2	198.4	0.732
108359	N2	148.1	0.418
108359	K1	144.2	0.229
108359	M4	196.4	0.066
108359	O1	126.3	0.119
108359	M6	15.8	0.166
108359	MK3	120.3	0.066
108359	S4	267.8	0.017
108359	MN4	184.6	0.035
108359	S6	324.5	0.005
108359	2N2	91.5	0.073
108359	OO1	191.4	0.009
108359	M1	165.3	0.005
108359	J1	159.6	0.005
108359	MSF	339.6	0.017
108359	MF	340.2	0.027
108359	Q1	132.4	0.022
108359	2Q1	302.5	0.007
108359	P1	131.7	0.052
108359	2SM2	71.5	0.031
108359	M3	247.3	0.032
108359	L2	164.4	0.166
108359	2MK3	24.4	0.062
108359	K2	185.9	0.229
108359	M8	2.6	0.018
108359	MS4	281.2	0.022
108360	M2	165.1	2.759
108360	S2	198	0.765
108360	N2	149.4	0.446
108360	K1	145	0.227
108360	M4	38.9	0.025
108360	O1	125.9	0.11
108360	M6	6.4	0.172
108360	MK3	112.7	0.065
108360	S4	262.3	0.023
108360	MN4	126.8	0.019
108360	S6	284.5	0.005
108360	2N2	70.5	0.065
108360	OO1	190.2	0.013
108360	M1	174.2	0.006
108360	J1	104.3	0.004
108360	MSF	327.5	0.018
108360	MF	321.5	0.029
108360	Q1	120.1	0.024
108360	P1	132.7	0.051
108360	2SM2	69.3	0.034
108360	M3	255.2	0.041
108360	L2	170.1	0.183
108360	2MK3	21	0.071
108360	K2	184.1	0.237
108360	M8	220.4	0.007
108360	MS4	206.9	0.005
108361	M2	165.1	2.612
108361	S2	197.8	0.628
108361	N2	153.5	0.369
108361	K1	147.4	0.189
108361	M4	53.7	0.156
108361	O1	145.7	0.072
108361	M6	349.5	0.146
108361	MK3	84.5	0.119
108361	S4	233.5	0.029
108361	MN4	82.6	0.095
108361	2N2	32	0.09
108361	OO1	195.2	0.032
108361	M1	226.7	0.005
108361	J1	175.7	0.008
108361	MSF	232.3	0.034
108361	MF	294.7	0.043
108361	Q1	150.2	0.011
108361	2Q1	278.5	0.008
108361	P1	155.5	0.054
108361	2SM2	60.3	0.04
108361	M3	289.5	0.045
108361	L2	175.7	0.217
108361	2MK3	22.4	0.112
108361	K2	178.4	0.191
108361	M8	147.9	0.037
108361	MS4	153.6	0.074
108362	M2	213.1	1.459
108362	S2	240.9	0.357
108362	N2	185.7	0.209
108362	K1	187.3	0.139
108362	M4	309.5	0.134
108362	O1	208	0.083
108362	M6	178.9	0.156
108362	MK3	224.2	0.05
108362	S4	3.5	0.063
108362	MN4	254.4	0.056
108362	S6	253.2	0.012
108362	2N2	126.6	0.077
108362	OO1	317.9	0.009
108362	M1	324.5	0.007
108362	J1	196	0.011
108362	MSF	213.5	0.206
108362	MF	202.5	0.088
108362	Q1	195.3	0.012
108362	2Q1	116.3	0.018
108362	P1	137.6	0.043
108362	2SM2	117	0.067
108362	M3	52.1	0.025
108362	L2	200	0.155
108362	2MK3	93.8	0.063
108362	K2	200.7	0.093
108362	M8	351	0.027
108362	MS4	347.2	0.121
108363	M2	225.2	1.545
108363	S2	257.5	0.454
108363	N2	194.5	0.282
108363	K1	142.8	0.168
108363	M4	142.1	0.108
108363	O1	157.8	0.093
108363	M6	126.6	0.028
108363	MK3	181	0.015
108363	S4	33.2	0.03
108363	MN4	163.5	0.032
108363	S6	283.3	0.004
108363	2N2	197.7	0.086
108363	OO1	222.8	0.023
108363	M1	237.8	0.006
108363	J1	351.9	0.02
108363	MSF	77.9	0.064
108363	MF	165.7	0.034
108363	Q1	232.6	0.017
108363	P1	171.9	0.046
108363	2SM2	143.7	0.047
108363	M3	32	0.021
108363	L2	200.9	0.107
108363	2MK3	102.6	0.057
108363	K2	222.8	0.12
108363	M8	281.5	0.03
108363	MS4	158	0.029
108364	M2	218.1	1.559
108364	S2	249.2	0.46
108364	N2	193.6	0.299
108364	K1	158.3	0.164
108364	M4	265.2	0.188
108364	O1	148.1	0.103
108364	M6	285.4	0.026
108364	MK3	197.6	0.083
108364	S4	97.5	0.014
108364	MN4	266.4	0.042
108364	S6	289.9	0.013
108364	2N2	181.6	0.035
108364	OO1	251.8	0.016
108364	M1	186.5	0.006
108364	J1	340.7	0.007
108364	MSF	204.3	0.013
108364	MF	260	0.005
108364	Q1	199	0.025
108364	2Q1	284.4	0.017
108364	P1	191.8	0.035
108364	2SM2	157	0.027
108364	M3	19.9	0.015
108364	L2	221.5	0.103
108364	2MK3	166.6	0.056
108364	K2	235.3	0.103
108364	M8	206.7	0.043
108364	MS4	314	0.071
108365	M2	214.4	1.473
108365	S2	256.4	0.414
108365	N2	197.5	0.298
108365	K1	191.4	0.171
108365	M4	218.7	0.025
108365	O1	204.4	0.108
108365	M6	232.5	0.015
108365	MK3	203.7	0.072
108365	S4	332.7	0.026
108365	MN4	108.6	0.04
108365	S6	357.5	0.008
108365	2N2	195	0.052
108365	OO1	327.8	0.01
108365	M1	307.5	0.011
108365	J1	179.9	0.008
108365	MSF	205.8	0.128
108365	MF	211.8	0.063
108365	Q1	218.3	0.013
108365	2Q1	66.9	0.014
108365	P1	191.4	0.03
108365	2SM2	48.7	0.03
108365	M3	359.4	0.024
108365	L2	167	0.059
108365	2MK3	117.7	0.027
108365	K2	206.8	0.072
108365	M8	315.9	0.031
108365	MS4	262	0.053
108366	M2	235.8	0.514
108366	S2	269.9	0.156
108366	N2	210.7	0.077
108366	K1	254.4	0.046
108366	M4	358.2	0.104
108366	O1	235.5	0.062
108366	M6	187.9	0.031
108366	MK3	208.8	0.061
108366	S4	222.8	0.007
108366	MN4	291.9	0.018
108366	S6	192.4	0.006
108366	2N2	199.7	0.035
108366	OO1	226.7	0.007
108366	M1	203.3	0.005
108366	J1	238.6	0.007
108366	MSF	206.7	0.052
108366	MF	74.4	0.015
108366	Q1	195.5	0.009
108366	2Q1	30.2	0.01
108366	P1	297.5	0.011
108366	2SM2	207.3	0.018
108366	M3	101.4	0.021
108366	L2	203.6	0.044
108366	2MK3	148.2	0.044
108366	K2	242.9	0.055
108366	M8	201.9	0.015
108366	MS4	44.5	0.048
108367	M2	215	0.627
108367	S2	249.8	0.223
108367	N2	185.2	0.128
108367	K1	117	0.143
108367	M4	40.6	0.008
108367	O1	84.5	0.094
108367	M6	299.1	0.009
108367	MK3	182.3	0.027
108367	S4	299.6	0.012
108367	MN4	267.2	0.018
108367	S6	328.1	0.001
108367	2N2	171.7	0.036
108367	OO1	106.6	0.019
108367	M1	18.2	0.018
108367	J1	305.1	0.017
108367	MSF	62.4	0.085
108367	MF	197.2	0.024
108367	Q1	56.4	0.025
108367	2Q1	347	0.022
108367	P1	102.5	0.069
108367	2SM2	220.2	0.016
108367	M3	308.3	0.008
108367	L2	201.8	0.04
108367	2MK3	120.9	0.031
108367	K2	238.8	0.042
108367	M8	51.6	0.022
108367	MS4	300.7	0.023
108368	M2	224.9	1.246
108368	S2	266	0.355
108368	N2	210.7	0.237
108368	K1	134.7	0.038
108368	M4	185.9	0.019
108368	O1	278.2	0.038
108368	M6	88.6	0.018
108368	MK3	165	0.017
108368	S4	215.7	0.002
108368	MN4	267.1	0.02
108368	S6	249.5	0.002
108368	2N2	220	0.014
108368	OO1	101	0.009
108368	M1	183.4	0.006
108368	J1	171.7	0.013
108368	MSF	75.9	0.066
108368	MF	54.9	0.056
108368	Q1	243.6	0.008
108368	2Q1	159.7	0.017
108368	P1	18	0.02
108368	2SM2	90.9	0.025
108368	M3	58.8	0.01
108368	L2	204.6	0.089
108368	2MK3	94	0.01
108368	K2	241.2	0.11
108368	M8	74	0.016
108368	MS4	182.2	0.005
108369	M2	239.7	0.808
108369	S2	273.3	0.263
108369	N2	222	0.162
108369	K1	201.4	0.121
108369	M4	317.7	0.073
108369	O1	179.3	0.065
108369	M6	54	0.012
108369	MK3	205.1	0.043
108369	S4	207.3	0.009
108369	MN4	19.4	0.008
108369	S6	13.8	0.008
108369	2N2	291.5	0.017
108369	OO1	241.8	0.012
108369	M1	257.3	0.011
108369	J1	240.2	0.019
108369	MSF	215.7	0.088
108369	MF	203.6	0.025
108369	Q1	165.7	0.018
108369	2Q1	250.7	0.018
108369	P1	231.4	0.038
108369	2SM2	74.6	0.023
108369	M3	0.4	0.01
108369	L2	12.6	0.009
108369	2MK3	163.1	0.048
108369	K2	263	0.056
108369	M8	302	0.006
108369	MS4	110	0.01
108370	M2	242	0.798
108370	S2	284.3	0.215
108370	N2	223.9	0.177
108370	K1	210.1	0.173
108370	M4	209	0.045
108370	O1	185.1	0.096
108370	M6	243.6	0.007
108370	MK3	177.8	0.026
108370	S4	130.7	0.022
108370	MN4	169.1	0.035
108370	S6	250.9	0.008
108370	2N2	236	0.012
108370	OO1	255.8	0.011
108370	M1	182.3	0.008
108370	J1	160.5	0.003
108370	MSF	0.1	0.074
108370	MF	351.5	0.021
108370	Q1	240.4	0.019
108370	2Q1	122.1	0.028
108370	P1	176.5	0.093
108370	2SM2	289.3	0.006
108370	M3	345.6	0.025
108370	L2	251.8	0.047
108370	2MK3	124.2	0.048
108370	K2	254.7	0.044
108370	M8	186.1	0.028
108370	MS4	314.4	0.021
108371	M2	182.2	0.938
108371	S2	214	0.292
108371	N2	158	0.154
108371	K1	190.7	0.07
108371	M4	357.1	0.21
108371	O1	220.9	0.093
108371	M6	49.5	0.027
108371	MK3	247.9	0.124
108371	S4	327.7	0.02
108371	MN4	309	0.078
108371	S6	11	0.009
108371	2N2	167.1	0.043
108371	OO1	249.3	0.031
108371	M1	207.1	0.008
108371	J1	350.8	0.015
108371	MSF	239.9	0.138
108371	MF	284.4	0.009
108371	Q1	209.6	0.026
108371	2Q1	240.6	0.03
108371	P1	308.9	0.023
108371	2SM2	130.8	0.024
108371	M3	95.2	0.018
108371	L2	179.3	0.061
108371	2MK3	206.1	0.037
108371	K2	203.4	0.099
108371	M8	248.8	0.012
108371	MS4	30.5	0.113
108372	M2	192.4	1.121
108372	S2	221.9	0.379
108372	N2	165.3	0.204
108372	K1	182	0.132
108372	M4	345.3	0.233
108372	O1	199.2	0.133
108372	M6	103.7	0.087
108372	MK3	246.5	0.14
108372	S4	286	0.022
108372	MN4	302.8	0.078
108372	S6	212.4	0.007
108372	2N2	183.8	0.048
108372	OO1	243.2	0.038
108372	M1	210.3	0.017
108372	J1	21.3	0.037
108372	MSF	245.3	0.192
108372	MF	264.6	0.041
108372	Q1	214.1	0.052
108372	2Q1	284.6	0.02
108372	P1	24.2	0.036
108372	2SM2	166.3	0.033
108372	M3	100.2	0.016
108372	L2	194.1	0.035
108372	2MK3	206.3	0.05
108372	K2	208.3	0.134
108372	M8	321.8	0.007
108372	MS4	9.7	0.107
108373	M2	203	1.225
108373	S2	219	0.389
108373	N2	164.4	0.208
108373	K1	178.9	0.153
108373	M4	346.8	0.302
108373	O1	189.6	0.115
108373	M6	137.8	0.127
108373	MK3	245.9	0.118
108373	S4	252.3	0.036
108373	MN4	325.6	0.077
108373	S6	208.1	0.012
108373	2N2	144.1	0.081
108373	OO1	257.6	0.032
108373	M1	280.6	0.013
108373	J1	30.5	0.041
108373	MSF	276	0.139
108373	MF	332.8	0.058
108373	Q1	216.4	0.047
108373	2Q1	339.2	0.036
108373	P1	56.1	0.087
108373	2SM2	161	0.049
108373	M3	37.3	0.019
108373	L2	271.6	0.088
108373	2MK3	190.5	0.04
108373	K2	198.7	0.118
108373	M8	312.9	0.019
108373	MS4	2.9	0.083
108374	M2	161.6	1.935
108374	S2	169	0.512
108374	N2	124.7	0.439
108374	K1	161.9	0.675
108374	M4	134.3	0.201
108374	O1	150.2	0.474
108374	M6	348.3	0.077
108374	MK3	94.7	0.278
108374	S4	325.7	0.023
108374	MN4	93.6	0.088
108374	2N2	90.1	0.05
108374	OO1	159.5	0.047
108374	M1	187.2	0.023
108374	J1	230	0.037
108374	Q1	131.7	0.1
108374	2Q1	359.8	0.006
108374	P1	155.7	0.281
108374	2SM2	331.9	0.018
108374	M3	260.5	0.013
108374	L2	173	0.102
108374	2MK3	58.7	0.103
108374	K2	163.5	0.23
108374	M8	44.9	0.028
108374	MS4	149.7	0.062
108375	M2	163.2	2.221
108375	S2	171.9	0.582
108375	N2	123.7	0.486
108375	K1	158.6	0.721
108375	M4	72	0.055
108375	O1	145.5	0.484
108375	M6	87.9	0.02
108375	MK3	41.1	0.135
108375	S4	303.7	0.031
108375	MN4	68.8	0.029
108375	S6	232.6	0.007
108375	2N2	76.3	0.04
108375	OO1	149.1	0.044
108375	M1	196.9	0.041
108375	J1	159.2	0.02
108375	Q1	140	0.117
108375	2Q1	109.9	0.025
108375	P1	152.6	0.214
108375	2SM2	355.1	0.034
108375	M3	136.8	0.032
108375	L2	191.1	0.098
108375	2MK3	17.7	0.111
108375	K2	161.2	0.257
108375	M8	307.9	0.014
108375	MS4	87.7	0.017
108376	M2	165.4	2.359
108376	S2	179.6	0.578
108376	N2	123.2	0.501
108376	K1	157	0.762
108376	M4	4.5	0.117
108376	O1	145.2	0.456
108376	M6	109.3	0.066
108376	MK3	359.5	0.199
108376	S4	317.3	0.011
108376	MN4	330.2	0.033
108376	S6	255	0.008
108376	2N2	53.8	0.016
108376	OO1	201	0.05
108376	M1	206.7	0.022
108376	J1	127.9	0.036
108376	Q1	137.7	0.106
108376	2Q1	132.6	0.027
108376	P1	160.3	0.189
108376	2SM2	34	0.047
108376	M3	122.5	0.051
108376	L2	209.7	0.119
108376	2MK3	5.8	0.179
108376	K2	172.8	0.221
108376	M8	293.8	0.034
108376	MS4	23.6	0.052
108377	M2	162.4	1.769
108377	S2	172.8	0.424
108377	N2	124.1	0.391
108377	K1	158.9	0.499
108377	M4	346	0.114
108377	O1	136.2	0.223
108377	M6	26.5	0.051
108377	MK3	9.6	0.179
108377	S4	332.8	0.003
108377	MN4	309.9	0.044
108377	S6	127.8	0.005
108377	2N2	150.5	0.045
108377	OO1	170.8	0.022
108377	M1	199	0.034
108377	J1	208.3	0.029
108377	Q1	121.2	0.037
108377	2Q1	109.6	0.043
108377	P1	157.1	0.168
108377	2SM2	37.2	0.015
108377	M3	68.5	0.01
108377	L2	182.9	0.077
108377	2MK3	358.5	0.142
108377	K2	152	0.171
108377	M8	23.7	0.006
108377	MS4	336.8	0.05
108378	M2	162	2.071
108378	S2	171.5	0.48
108378	N2	124	0.456
108378	K1	157.6	0.612
108378	M4	355.8	0.233
108378	O1	142	0.264
108378	M6	102.2	0.049
108378	MK3	6.1	0.204
108378	S4	359.3	0.01
108378	MN4	310.6	0.077
108378	S6	81	0.008
108378	2N2	144.4	0.029
108378	OO1	205.1	0.007
108378	M1	222.2	0.012
108378	J1	172.2	0.024
108378	Q1	139.3	0.045
108378	2Q1	81.4	0.035
108378	P1	176.9	0.202
108378	2SM2	326.4	0.013
108378	M3	141.8	0.033
108378	L2	191.2	0.086
108378	2MK3	10.6	0.12
108378	K2	157.1	0.171
108378	M8	223.6	0.022
108378	MS4	357.5	0.083
108379	M2	160.7	2.024
108379	S2	183.6	0.455
108379	N2	125.1	0.471
108379	K1	156.6	0.625
108379	M4	348.5	0.278
108379	O1	154.9	0.242
108379	M6	131.6	0.07
108379	MK3	358	0.167
108379	S4	333.6	0.012
108379	MN4	292.9	0.093
108379	S6	269.7	0.006
108379	2N2	350.1	0.018
108379	OO1	237.4	0.054
108379	M1	25	0.019
108379	J1	174.3	0.029
108379	Q1	158.1	0.07
108379	2Q1	3.1	0.005
108379	P1	197.6	0.266
108379	2SM2	343	0.034
108379	M3	143.5	0.056
108379	L2	212.3	0.084
108379	2MK3	3.4	0.092
108379	K2	204.8	0.15
108379	M8	225.4	0.031
108379	MS4	6	0.111
108380	M2	156.5	1.84
108380	S2	174.6	0.384
108380	N2	124.1	0.404
108380	K1	155.4	0.491
108380	M4	286.6	0.19
108380	O1	142.9	0.186
108380	M6	332.1	0.065
108380	MK3	325.7	0.165
108380	MN4	262.6	0.093
108380	S6	85.2	0.013
108380	2N2	247	0.016
108380	OO1	138.2	0.046
108380	M1	235	0.032
108380	J1	142.2	0.005
108380	Q1	181.6	0.039
108380	2Q1	105.7	0.035
108380	P1	161.4	0.141
108380	2SM2	19.9	0.014
108380	M3	234.2	0.036
108380	L2	176.2	0.085
108380	2MK3	344.7	0.186
108380	K2	169.7	0.15
108380	M8	41.5	0.013
108380	MS4	321.8	0.082
108381	M2	158	2.121
108381	S2	169.2	0.484
108381	N2	122.3	0.455
108381	K1	155.5	0.637
108381	M4	345.8	0.162
108381	O1	146	0.322
108381	M6	18.1	0.067
108381	MK3	356.2	0.174
108381	S4	343.4	0.014
108381	MN4	326.2	0.051
108381	S6	17.1	0.011
108381	2N2	283.6	0.015
108381	OO1	173.3	0.035
108381	M1	159.7	0.01
108381	J1	191.1	0.032
108381	Q1	143.9	0.068
108381	2Q1	85.9	0.012
108381	P1	178.8	0.185
108381	2SM2	7.6	0.019
108381	M3	165.3	0.015
108381	L2	185.2	0.101
108381	2MK3	4.3	0.148
108381	K2	164	0.16
108381	M8	134.5	0.029
108381	MS4	2.4	0.051
108382	M2	157.9	1.954
108382	S2	169.5	0.418
108382	N2	123.3	0.416
108382	K1	158.5	0.592
108382	M4	352.8	0.175
108382	O1	148	0.294
108382	M6	33.5	0.045
108382	MK3	356.4	0.172
108382	S4	346.9	0.011
108382	MN4	313.1	0.063
108382	S6	9.4	0.008
108382	2N2	58	0.012
108382	OO1	213.4	0.043
108382	M1	145.9	0.013
108382	J1	202.1	0.045
108382	Q1	139.3	0.074
108382	2Q1	63	0.011
108382	P1	177.1	0.193
108382	2SM2	8	0.003
108382	M3	100.1	0.007
108382	L2	190.3	0.1
108382	2MK3	2.4	0.123
108382	K2	165.6	0.104
108382	M8	152.3	0.026
108382	MS4	17.2	0.052
108383	M2	136.8	0.953
108383	S2	152.2	0.265
108383	N2	108.2	0.217
108383	K1	150.2	0.309
108383	M4	128.2	0.032
108383	O1	139.9	0.202
108383	M6	209.9	0.043
108383	MK3	340.3	0.07
108383	S4	275.5	0.009
108383	MN4	97.5	0.021
108383	S6	145.6	0.004
108383	2N2	129.7	0.045
108383	OO1	95	0.022
108383	M1	195.1	0.018
108383	J1	225.2	0.037
108383	Q1	123.3	0.025
108383	2Q1	112.8	0.004
108383	P1	154.2	0.062
108383	2SM2	295.8	0.008
108383	M3	213.3	0.017
108383	L2	116	0.039
108383	2MK3	308.7	0.043
108383	K2	138.7	0.117
108383	M8	228.9	0.014
108383	MS4	235.4	0.022
108384	M2	142.3	1.417
108384	S2	156.6	0.333
108384	N2	113.9	0.293
108384	K1	155.1	0.426
108384	M4	231.8	0.017
108384	O1	147.4	0.274
108384	M6	288.1	0.052
108384	MK3	322.5	0.125
108384	S4	299.7	0.009
108384	MN4	116.7	0.014
108384	S6	101.8	0.005
108384	2N2	164.1	0.017
108384	OO1	178.2	0.013
108384	M1	215.4	0.012
108384	J1	222.7	0.039
108384	Q1	112.6	0.046
108384	2Q1	201.3	0.012
108384	P1	156.5	0.103
108384	2SM2	308	0.009
108384	M3	217.9	0.006
108384	L2	156.8	0.066
108384	2MK3	314.5	0.107
108384	K2	142.9	0.122
108384	M8	2.6	0.009
108384	MS4	245.6	0.019
108385	M2	141.3	1.485
108385	S2	158.7	0.328
108385	N2	111.3	0.296
108385	K1	156.7	0.445
108385	M4	352.4	0.048
108385	O1	152.4	0.269
108385	M6	308.6	0.057
108385	MK3	322.4	0.151
108385	S4	346.5	0.012
108385	MN4	339	0.027
108385	S6	108.7	0.003
108385	2N2	172.2	0.017
108385	OO1	196.9	0.016
108385	M1	216.2	0.011
108385	J1	191.9	0.036
108385	Q1	133.9	0.039
108385	2Q1	198	0.018
108385	P1	168.4	0.125
108385	2SM2	310.4	0.019
108385	M3	203.5	0.007
108385	L2	154.4	0.07
108385	2MK3	319.8	0.123
108385	K2	148.7	0.108
108385	M8	48.6	0.015
108385	MS4	54.2	0.005
108386	M2	137.4	1.455
108386	S2	156.4	0.367
108386	N2	106.7	0.329
108386	K1	154.2	0.363
108386	M4	115.5	0.02
108386	O1	148	0.286
108386	M6	245	0.025
108386	MK3	315.7	0.073
108386	S4	343.6	0.009
108386	MN4	69.7	0.008
108386	S6	323.5	0.003
108386	2N2	104.1	0.055
108386	OO1	243.4	0.005
108386	M1	188.8	0.019
108386	J1	200.8	0.037
108386	Q1	130	0.05
108386	2Q1	237.1	0.021
108386	P1	140.6	0.14
108386	2SM2	11.5	0.015
108386	M3	232.8	0.007
108386	L2	131.2	0.066
108386	2MK3	308	0.074
108386	K2	134.8	0.136
108386	M8	194.9	0.004
108386	MS4	216	0.039
108387	M2	140.2	1.992
108387	S2	159.5	0.482
108387	N2	108.7	0.419
108387	K1	152.9	0.509
108387	M4	314.3	0.063
108387	O1	146.5	0.327
108387	M6	314.1	0.063
108387	MK3	320.6	0.172
108387	S4	344.3	0.012
108387	MN4	288.5	0.026
108387	S6	253.9	0.008
108387	2N2	141.2	0.054
108387	OO1	195	0.026
108387	M1	180	0.024
108387	J1	213.4	0.046
108387	Q1	123.1	0.061
108387	2Q1	131.8	0.017
108387	P1	156.8	0.173
108387	2SM2	349.8	0.029
108387	M3	291.6	0.007
108387	L2	146.7	0.097
108387	2MK3	313	0.159
108387	K2	148.3	0.151
108387	M8	83.4	0.023
108387	MS4	254.8	0.029
108388	M2	139.5	2.125
108388	S2	157.3	0.48
108388	N2	107.4	0.432
108388	K1	152.1	0.54
108388	M4	302.5	0.115
108388	O1	144.6	0.312
108388	M6	316.3	0.068
108388	MK3	321.7	0.229
108388	S4	41.1	0.01
108388	MN4	279	0.045
108388	S6	247.5	0.011
108388	2N2	142.9	0.058
108388	OO1	146.4	0.029
108388	M1	181.5	0.04
108388	J1	206.7	0.037
108388	Q1	117	0.066
108388	2Q1	97.5	0.031
108388	P1	159.9	0.18
108388	2SM2	332.7	0.023
108388	M3	269.1	0.006
108388	L2	148.9	0.102
108388	2MK3	315.6	0.182
108388	K2	143.9	0.163
108388	M8	108	0.026
108388	MS4	286.6	0.037
108389	M2	127.6	1.196
108389	S2	147	0.295
108389	N2	96.5	0.26
108389	K1	146	0.274
108389	M4	170	0.043
108389	O1	147.3	0.214
108389	M6	251.8	0.021
108389	MK3	277.1	0.072
108389	S4	283.3	0.005
108389	MN4	124.5	0.025
108389	S6	11.1	0.002
108389	2N2	110.9	0.037
108389	OO1	90.5	0.022
108389	M1	173.6	0.028
108389	J1	205.3	0.026
108389	Q1	128.6	0.057
108389	2Q1	100.6	0.016
108389	P1	155.4	0.113
108389	2SM2	1.2	0.027
108389	M3	342.2	0.041
108389	L2	120.8	0.065
108389	2MK3	295	0.095
108389	K2	123.3	0.098
108389	M8	210.4	0.011
108389	MS4	215.1	0.024
108390	M2	130.8	1.491
108390	S2	143.5	0.359
108390	N2	95.7	0.304
108390	K1	143.8	0.326
108390	M4	206.2	0.071
108390	O1	142.7	0.25
108390	M6	292.2	0.079
108390	MK3	280.1	0.092
108390	S4	339.3	0.004
108390	MN4	152.3	0.042
108390	S6	277.6	0.004
108390	2N2	142.9	0.054
108390	OO1	113.1	0.033
108390	M1	177.3	0.039
108390	J1	199.8	0.035
108390	Q1	125.9	0.07
108390	2Q1	89	0.028
108390	P1	152.9	0.167
108390	2SM2	340	0.018
108390	M3	357.5	0.041
108390	L2	136.4	0.085
108390	2MK3	292	0.128
108390	K2	121.3	0.148
108390	M8	354.3	0.012
108390	MS4	225.3	0.04
108391	M2	128.9	1.447
108391	S2	139.4	0.346
108391	N2	92.6	0.31
108391	K1	145.7	0.287
108391	M4	195.9	0.121
108391	O1	146.4	0.265
108391	M6	299.1	0.102
108391	MK3	250.4	0.075
108391	S4	75.5	0.005
108391	MN4	158	0.065
108391	S6	256.9	0.007
108391	2N2	131.5	0.061
108391	OO1	80.9	0.044
108391	M1	174.9	0.043
108391	J1	200.8	0.043
108391	Q1	124.9	0.069
108391	2Q1	52.9	0.029
108391	P1	140.8	0.178
108391	2SM2	2	0.011
108391	M3	10	0.041
108391	L2	136	0.073
108391	2MK3	287.1	0.115
108391	K2	110.9	0.164
108391	M8	338.6	0.008
108391	MS4	236.3	0.07
108392	M2	146.5	1.14
108392	S2	165.9	0.284
108392	N2	112.7	0.251
108392	K1	150.5	0.281
108392	M4	263.3	0.022
108392	O1	138.7	0.162
108392	M6	282.3	0.048
108392	MK3	0	0.047
108392	S4	319.6	0.012
108392	MN4	105.5	0.003
108392	S6	163.4	0.006
108392	2N2	153.4	0.043
108392	OO1	150.8	0.017
108392	M1	166.4	0.027
108392	J1	193.1	0.013
108392	Q1	110.7	0.04
108392	2Q1	110.6	0.019
108392	P1	157.2	0.129
108392	2SM2	331.1	0.01
108392	M3	314.3	0.019
108392	L2	145.9	0.069
108392	2MK3	330.7	0.057
108392	K2	167.6	0.094
108392	M8	18	0.014
108392	MS4	180.1	0.02
108393	M2	149.6	1.733
108393	S2	162.2	0.367
108393	N2	116.6	0.351
108393	K1	147.3	0.411
108393	M4	228.6	0.038
108393	O1	134.6	0.22
108393	M6	337.4	0.068
108393	MK3	14.7	0.092
108393	S4	57.1	0.008
108393	MN4	192.3	0.015
108393	S6	200.8	0.003
108393	2N2	193.5	0.046
108393	OO1	165.3	0.031
108393	M1	210.9	0.011
108393	J1	194.2	0.016
108393	Q1	115.7	0.043
108393	2Q1	60.3	0.008
108393	P1	154.1	0.141
108393	2SM2	335.6	0.01
108393	M3	340.2	0.011
108393	L2	166.2	0.112
108393	2MK3	351.8	0.13
108393	K2	150	0.129
108393	M8	74.7	0.018
108393	MS4	261.6	0.044
108394	M2	149.7	1.855
108394	S2	167	0.373
108394	N2	116.2	0.406
108394	K1	148.6	0.577
108394	M4	326	0.066
108394	O1	132.1	0.297
108394	M6	355.8	0.065
108394	MK3	342.7	0.076
108394	S4	290.1	0.003
108394	MN4	240.3	0.022
108394	S6	342.6	0.011
108394	2N2	123.9	0.014
108394	OO1	171.9	0.033
108394	M1	262.7	0.009
108394	J1	195.8	0.022
108394	Q1	117.2	0.049
108394	2Q1	338.7	0.018
108394	P1	142.1	0.123
108394	2SM2	51.4	0.022
108394	M3	197.3	0.03
108394	L2	166.4	0.099
108394	2MK3	349	0.12
108394	K2	161.7	0.135
108394	M8	191.4	0.013
108394	MS4	337.5	0.059
108395	M2	145.8	1.423
108395	S2	165.2	0.338
108395	N2	113	0.312
108395	K1	152.5	0.391
108395	M4	309.2	0.062
108395	O1	132.6	0.183
108395	M6	287.5	0.03
108395	MK3	338.8	0.107
108395	S4	134.9	0.003
108395	MN4	275.5	0.028
108395	S6	227.9	0.003
108395	2N2	160	0.036
108395	OO1	187.2	0.029
108395	M1	231.3	0.014
108395	J1	202.1	0.015
108395	Q1	134.6	0.029
108395	2Q1	123.7	0.012
108395	P1	150.2	0.098
108395	2SM2	320.1	0.009
108395	M3	284.2	0.007
108395	L2	145.5	0.065
108395	2MK3	333.5	0.09
108395	K2	163.1	0.118
108395	M8	143.1	0.02
108395	MS4	293.1	0.017
108396	M2	147.3	1.856
108396	S2	165	0.413
108396	N2	114.1	0.387
108396	K1	150.1	0.486
108396	M4	273.3	0.077
108396	O1	136.4	0.259
108396	M6	328.4	0.058
108396	MK3	359.9	0.08
108396	S4	17.3	0.007
108396	MN4	251.1	0.022
108396	S6	141.3	0.008
108396	2N2	177.5	0.03
108396	OO1	187.9	0.031
108396	M1	253.9	0.014
108396	J1	181.5	0.028
108396	Q1	143.3	0.044
108396	2Q1	79.8	0.012
108396	P1	148.7	0.144
108396	2SM2	326.8	0.018
108396	M3	211.7	0.006
108396	L2	161.2	0.098
108396	2MK3	344.5	0.121
108396	K2	162.8	0.142
108396	M8	126.5	0.026
108396	MS4	274.6	0.043
108397	M2	148.4	1.907
108397	S2	164.3	0.377
108397	N2	118.7	0.403
108397	K1	143.8	0.603
108397	M4	345.8	0.038
108397	O1	136.5	0.268
108397	M6	353.1	0.037
108397	MK3	4	0.128
108397	S4	95.7	0.008
108397	MN4	339.1	0.006
108397	2N2	126	0.065
108397	OO1	171	0.047
108397	M1	280.4	0.023
108397	J1	162.8	0.018
108397	Q1	147.2	0.038
108397	2Q1	203.1	0.006
108397	P1	168.7	0.08
108397	2SM2	17.6	0.013
108397	M3	192.5	0.047
108397	L2	168.4	0.104
108397	2MK3	352.4	0.121
108397	K2	140.3	0.104
108397	M8	180.9	0.011
108397	MS4	305.6	0.047
108398	M2	140.3	1.441
108398	S2	144.4	0.135
108398	K1	149.5	0.445
108398	M4	161.9	0.129
108398	O1	143.7	0.273
108398	M6	265.3	0.062
108398	MK3	161.4	0.015
108398	S4	314.2	0.011
108398	S6	183.4	0.004
108398	2N2	153.5	0.099
108398	OO1	174.3	0.025
108398	2Q1	238.3	0.03
108398	2SM2	296.4	0.023
108398	2MK3	21.6	0.083
108398	M8	357.1	0.027
108398	MS4	163.2	0.028
108399	M2	143.9	1.707
108399	S2	163	0.17
108399	K1	140.2	0.52
108399	M4	176.1	0.086
108399	O1	135.7	0.275
108399	M6	306.6	0.072
108399	MK3	65.7	0.052
108399	S4	59.2	0.009
108399	2N2	135.3	0.093
108399	OO1	191.7	0.027
108399	2Q1	168.6	0.013
108399	2SM2	252.8	0.01
108399	2MK3	5.8	0.108
108399	M8	43.8	0.031
108399	MS4	277.5	0.042
108400	M2	143.4	1.775
108400	S2	177.3	0.16
108400	K1	139.4	0.57
108400	M4	315.1	0.054
108400	O1	127.5	0.271
108400	M6	331.3	0.077
108400	MK3	357.1	0.049
108400	S4	87.5	0.005
108400	S6	257.2	0.005
108400	2N2	132.6	0.143
108400	OO1	203.4	0.052
108400	2Q1	111.1	0.016
108400	2SM2	47.3	0.017
108400	2MK3	2.6	0.108
108400	M8	44.1	0.015
108400	MS4	298.5	0.029
108401	M2	136.3	0.59
108401	S2	157.5	0.126
108401	N2	100.9	0.133
108401	K1	122.8	0.125
108401	M4	30.5	0.023
108401	O1	68.9	0.075
108401	M6	180.5	0.011
108401	MK3	17.4	0.06
108401	S4	198.5	0.01
108401	MN4	28.9	0.009
108401	S6	125.1	0.001
108401	2N2	120.2	0.021
108401	OO1	111.4	0.021
108401	M1	164.1	0.008
108401	J1	154.9	0.013
108401	Q1	41.7	0.007
108401	2Q1	39.5	0.008
108401	P1	146.6	0.055
108401	2SM2	280	0.009
108401	M3	275	0.003
108401	L2	133.2	0.027
108401	2MK3	318.7	0.056
108401	K2	114.5	0.052
108401	M8	130.2	0.004
108401	MS4	250.8	0.028
108402	M2	135.9	0.84
108402	S2	155.1	0.149
108402	N2	100.9	0.18
108402	K1	117.8	0.166
108402	M4	16.4	0.012
108402	O1	70	0.103
108402	M6	322.1	0.014
108402	MK3	21	0.079
108402	S4	186.8	0.009
108402	MN4	61.4	0.007
108402	S6	200.4	0.003
108402	2N2	151.3	0.051
108402	OO1	105.5	0.037
108402	M1	180	0.02
108402	J1	167.2	0.014
108402	Q1	41.4	0.013
108402	2Q1	66.7	0.015
108402	P1	141.5	0.087
108402	2SM2	260.1	0.009
108402	M3	339.9	0.01
108402	L2	142.2	0.055
108402	2MK3	315.4	0.09
108402	K2	106.9	0.072
108402	M8	73.5	0.012
108402	MS4	269.6	0.05
108403	M2	137.5	1.06
108403	S2	149	0.174
108403	N2	101.5	0.221
108403	K1	107	0.231
108403	M4	297.2	0.064
108403	O1	63.6	0.13
108403	M6	16.5	0.046
108403	MK3	15.8	0.07
108403	S4	156.5	0.02
108403	MN4	235.9	0.012
108403	S6	295.8	0.005
108403	2N2	169.3	0.085
108403	OO1	115.8	0.065
108403	M1	196	0.037
108403	J1	149.9	0.012
108403	Q1	42.5	0.014
108403	2Q1	86.1	0.022
108403	P1	142.9	0.126
108403	2SM2	111.1	0.006
108403	M3	358.1	0.016
108403	L2	153.3	0.091
108403	2MK3	327.3	0.135
108403	K2	108.3	0.123
108403	M8	124	0.031
108403	MS4	294	0.074
108404	M2	166.6	1.247
108404	S2	188.5	0.21
108404	N2	133.4	0.277
108404	K1	163.4	0.445
108404	M4	185.8	0.046
108404	O1	161.2	0.254
108404	M6	314.2	0.055
108404	MK3	57.2	0.032
108404	S4	336.5	0.008
108404	MN4	159.3	0.015
108404	S6	204	0.005
108404	2N2	267.3	0.032
108404	OO1	163.1	0.054
108404	M1	320.7	0.024
108404	J1	184.2	0.012
108404	Q1	122.9	0.021
108404	2Q1	309.2	0.015
108404	P1	172.5	0.083
108404	2SM2	63.6	0.006
108404	M3	350.5	0.009
108404	L2	189.1	0.073
108404	2MK3	9	0.105
108404	K2	175.5	0.064
108404	M8	341.4	0.019
108404	MS4	329.8	0.011
108405	M2	165.6	1.337
108405	S2	177.3	0.282
108405	N2	130.3	0.279
108405	K1	167.9	0.43
108405	M4	27.7	0.081
108405	O1	145	0.199
108405	M6	30.6	0.041
108405	MK3	23.8	0.132
108405	MN4	6.6	0.033
108405	S6	110.6	0.006
108405	2N2	172.9	0.013
108405	OO1	192.6	0.036
108405	M1	259.6	0.01
108405	J1	205.9	0.021
108405	Q1	126.4	0.037
108405	2Q1	82.5	0.01
108405	P1	164.8	0.132
108405	2SM2	92.5	0.012
108405	M3	6.9	0.007
108405	L2	195.6	0.059
108405	2MK3	16.9	0.114
108405	K2	167.1	0.114
108405	M8	156.5	0.018
108405	MS4	21.1	0.018
108406	M2	162.8	1.374
108406	S2	179.4	0.288
108406	N2	129.4	0.283
108406	K1	165.5	0.521
108406	M4	51.6	0.142
108406	O1	147.1	0.18
108406	M6	75.8	0.04
108406	MK3	22.6	0.191
108406	S4	254.2	0.011
108406	MN4	47.9	0.053
108406	S6	88.9	0.014
108406	2N2	109.7	0.037
108406	OO1	215.7	0.048
108406	M1	316.8	0.014
108406	J1	95.5	0.019
108406	Q1	122.5	0.035
108406	2Q1	102.3	0.012
108406	P1	179.2	0.143
108406	2SM2	346.5	0.014
108406	M3	276.7	0.03
108406	L2	178.4	0.052
108406	2MK3	13	0.091
108406	K2	191.1	0.1
108406	M8	206	0.027
108406	MS4	77.5	0.032
108407	M2	154.2	1.268
108407	S2	167.6	0.27
108407	N2	124.1	0.298
108407	K1	150.2	0.339
108407	M4	134.5	0.141
108407	O1	138.3	0.202
108407	M6	320.5	0.089
108407	MK3	75.3	0.131
108407	S4	1.6	0.015
108407	MN4	82	0.055
108407	S6	290.2	0.005
108407	2N2	183.7	0.031
108407	OO1	138.2	0.044
108407	M1	222.4	0.026
108407	J1	248.3	0.037
108407	Q1	153.3	0.027
108407	2Q1	181.6	0.016
108407	P1	153.6	0.12
108407	2SM2	253.8	0.006
108407	M3	286.2	0.023
108407	L2	156.4	0.076
108407	2MK3	352	0.106
108407	K2	152.5	0.085
108407	M8	135.4	0.03
108407	MS4	249.2	0.028
108408	M2	156	1.369
108408	S2	167.7	0.304
108408	N2	121.3	0.331
108408	K1	160.3	0.353
108408	M4	148.1	0.019
108408	O1	143	0.199
108408	M6	340.7	0.094
108408	MK3	43	0.108
108408	MN4	49.1	0.027
108408	S6	297	0.012
108408	2N2	192.8	0.037
108408	OO1	138.3	0.036
108408	M1	216.1	0.029
108408	J1	239.2	0.037
108408	Q1	151.5	0.031
108408	2Q1	114.7	0.012
108408	P1	149.6	0.15
108408	2SM2	254.8	0.012
108408	M3	256.9	0.02
108408	L2	157	0.069
108408	2MK3	340.9	0.124
108408	K2	145.4	0.113
108408	M8	128.9	0.036
108408	MS4	313.9	0.041
108409	M2	156.4	1.391
108409	S2	169.5	0.3
108409	N2	121	0.336
108409	K1	161	0.323
108409	M4	322.3	0.058
108409	O1	138.3	0.167
108409	M6	3.7	0.098
108409	MK3	26	0.143
108409	S4	224.2	0.014
108409	MN4	343.3	0.03
108409	S6	305.5	0.01
108409	2N2	202.9	0.032
108409	OO1	125.7	0.027
108409	M1	208.3	0.033
108409	J1	238.4	0.034
108409	Q1	143.7	0.027
108409	2Q1	105.1	0.028
108409	P1	148.2	0.168
108409	2SM2	245.8	0.028
108409	M3	244.7	0.02
108409	L2	158.5	0.068
108409	2MK3	346.8	0.149
108409	K2	155.5	0.117
108409	M8	133.6	0.035
108409	MS4	334.7	0.05
108410	M2	119.5	0.246
108410	S2	213.1	0.074
108410	N2	80.9	0.043
108410	K1	90.2	0.064
108410	M4	220.9	0.004
108410	O1	211.8	0.089
108410	M6	260	0.016
108410	MK3	1	0.031
108410	S4	335.5	0.006
108410	MN4	326.4	0.019
108410	S6	76.5	0.007
108410	2N2	296.2	0.015
108410	OO1	122.9	0.043
108410	M1	146.4	0.076
108410	J1	251.2	0.043
108410	Q1	214.7	0.044
108410	2Q1	241.4	0.029
108410	2SM2	206	0.02
108410	M3	189	0.014
108410	L2	170.5	0.012
108410	2MK3	319.9	0.028
108410	M8	0.6	0.014
108410	MS4	142.4	0.017
108411	M2	147.6	0.363
108411	S2	153.5	0.088
108411	N2	129.1	0.086
108411	K1	160.3	0.104
108411	M4	19.4	0.017
108411	O1	95.8	0.025
108411	M6	261.1	0.01
108411	MK3	8.1	0.041
108411	S4	88.6	0.009
108411	MN4	59.7	0.005
108411	S6	332.2	0.01
108411	2N2	172.7	0.042
108411	OO1	358.8	0.011
108411	M1	296.5	0.029
108411	J1	291.9	0.028
108411	Q1	13	0.023
108411	2Q1	243.7	0.007
108411	2SM2	83	0.015
108411	M3	221.5	0.008
108411	L2	56.1	0.023
108411	2MK3	13.1	0.021
108411	M8	194.8	0.011
108411	MS4	146	0.036
108412	M2	150.4	0.356
108412	S2	144.7	0.134
108412	N2	157.4	0.082
108412	K1	180.6	0.194
108412	M4	357.9	0.023
108412	O1	76.5	0.029
108412	M6	302.1	0.01
108412	MK3	341.3	0.036
108412	S4	168.1	0.005
108412	MN4	342.6	0.017
108412	S6	316.5	0.011
108412	2N2	192.4	0.056
108412	OO1	346.9	0.071
108412	M1	259.3	0.083
108412	J1	245.1	0.048
108412	Q1	326.9	0.021
108412	2Q1	300.9	0.012
108412	2SM2	102.3	0.026
108412	M3	116.2	0.006
108412	L2	60.8	0.028
108412	2MK3	286.4	0.017
108412	M8	180.4	0.023
108412	MS4	78.1	0.002
108413	M2	96.1	0.125
108413	S2	187.6	0.02
108413	N2	42.7	0.037
108413	K1	31	0.028
108413	M4	306	0.031
108413	O1	238.9	0.017
108413	M6	164.5	0.014
108413	MK3	270.5	0.023
108413	S4	329.4	0.012
108413	MN4	273.7	0.02
108413	S6	206.9	0.005
108413	2N2	131.7	0.011
108413	OO1	170	0.009
108413	M1	227	0.012
108413	J1	321.1	0.009
108413	Q1	242.7	0.002
108413	2Q1	69.3	0.011
108413	2SM2	174.1	0.003
108413	M3	116.6	0.009
108413	L2	85.9	0.011
108413	2MK3	333.5	0.019
108413	M8	273.8	0.001
108413	MS4	325.6	0.034
108414	M2	128.3	0.251
108414	S2	164.9	0.06
108414	N2	101.6	0.067
108414	K1	124.1	0.064
108414	M4	79.4	0.011
108414	O1	123.6	0.046
108414	M6	167.4	0.007
108414	MK3	2.8	0.03
108414	S4	147.7	0.002
108414	MN4	41	0.009
108414	S6	199.6	0.002
108414	2N2	50.5	0.016
108414	OO1	113.5	0.017
108414	M1	93.4	0.011
108414	J1	252.4	0.009
108414	Q1	83.6	0.013
108414	2Q1	352.5	0.007
108414	2SM2	133.4	0.003
108414	M3	162.6	0.007
108414	L2	126.3	0.018
108414	2MK3	350.8	0.016
108414	M8	249.8	0.007
108414	MS4	241.9	0.006
108415	M2	137	0.358
108415	S2	130.9	0.053
108415	N2	92.9	0.066
108415	K1	157.5	0.161
108415	M4	77	0.032
108415	O1	111	0.073
108415	M6	348.6	0.014
108415	MK3	27	0.034
108415	S4	218.5	0.009
108415	MN4	48.3	0.014
108415	S6	226.6	0.003
108415	2N2	256.9	0.025
108415	OO1	246.2	0.01
108415	M1	290.7	0.009
108415	J1	181.5	0.007
108415	Q1	67.7	0.023
108415	2Q1	270.5	0.005
108415	2SM2	5.1	0.008
108415	M3	304.1	0.015
108415	L2	182.7	0.028
108415	2MK3	353.3	0.049
108415	M8	227.3	0.004
108415	MS4	117.5	0.022
108416	M2	134.7	0.218
108416	S2	157.1	0.069
108416	N2	110.2	0.046
108416	K1	151.9	0.047
108416	M4	319.7	0.011
108416	O1	137.3	0.058
108416	M6	255.4	0.008
108416	MK3	329.7	0.026
108416	S4	257.7	0.004
108416	MN4	19.7	0.006
108416	S6	330.9	0.001
108416	2N2	355.7	0.011
108416	OO1	204.4	0.009
108416	M1	194.4	0.018
108416	J1	218.9	0.007
108416	Q1	111.5	0.021
108416	2Q1	257.4	0.009
108416	P1	110	0.005
108416	2SM2	329.7	0.011
108416	M3	241.5	0.005
108416	L2	84.2	0.012
108416	2MK3	298.8	0.02
108416	K2	201.6	0.011
108416	M8	173.5	0.002
108416	MS4	57.8	0.007
108417	M2	141.3	0.263
108417	S2	160.6	0.056
108417	N2	118.7	0.039
108417	K1	144.7	0.075
108417	M4	59.6	0.015
108417	O1	124.4	0.04
108417	M6	157.8	0.009
108417	MK3	28.1	0.017
108417	S4	284.1	0.004
108417	MN4	35.8	0.004
108417	S6	133.8	0.001
108417	2N2	104.7	0.012
108417	OO1	249.5	0.007
108417	M1	66	0.003
108417	J1	222.3	0.005
108417	Q1	127.5	0.008
108417	2Q1	318.8	0.004
108417	P1	176.3	0.009
108417	2SM2	291.9	0.002
108417	M3	228.1	0.005
108417	L2	171.9	0.007
108417	2MK3	347.5	0.012
108417	K2	129.2	0.032
108417	M8	8.6	0.005
108417	MS4	80.2	0.007
108418	M2	135.4	0.262
108418	S2	118.3	0.054
108418	N2	114.6	0.04
108418	K1	144.2	0.07
108418	M4	114.7	0.025
108418	O1	129.6	0.018
108418	M6	164.2	0.008
108418	MK3	74.7	0.029
108418	S4	356.4	0.003
108418	MN4	60.4	0.004
108418	S6	90.3	0.005
108418	2N2	54.1	0.007
108418	OO1	230.4	0.01
108418	M1	8.9	0.008
108418	J1	206	0.009
108418	Q1	271.3	0.008
108418	2Q1	121.5	0.008
108418	P1	99	0.01
108418	2SM2	345.4	0.005
108418	M3	261.4	0.008
108418	L2	197.4	0.012
108418	2MK3	336.3	0.014
108418	K2	180.4	0.042
108418	M8	102.5	0.004
108418	MS4	116.7	0.011
108419	M2	129.3	0.847
108419	S2	143	0.185
108419	N2	104.8	0.13
108419	K1	139.1	0.191
108419	M4	335.3	0.057
108419	O1	128.8	0.139
108419	M6	264.6	0.011
108419	MK3	359.8	0.071
108419	S4	338.5	0.007
108419	MN4	310.8	0.02
108419	S6	115.1	0.005
108419	2N2	89.6	0.037
108419	OO1	208.7	0.029
108419	M1	198.2	0.008
108419	J1	195.3	0.015
108419	Q1	118.8	0.017
108419	2Q1	64.6	0.009
108419	P1	111.3	0.053
108419	2SM2	337.7	0.013
108419	M3	286.1	0.007
108419	L2	155.5	0.026
108419	2MK3	315.3	0.088
108419	K2	142.3	0.076
108419	M8	200.3	0.002
108419	MS4	347.1	0.031
108420	M2	129.2	0.987
108420	S2	145.3	0.21
108420	N2	106.9	0.145
108420	K1	136.4	0.219
108420	M4	328.6	0.074
108420	O1	133.5	0.138
108420	M6	201.6	0.011
108420	MK3	356.4	0.113
108420	S4	350.2	0.008
108420	MN4	315.3	0.026
108420	S6	122.5	0.007
108420	2N2	95.1	0.049
108420	OO1	213.9	0.025
108420	M1	206.5	0.008
108420	J1	195.9	0.012
108420	Q1	157.4	0.015
108420	2Q1	74.6	0.014
108420	P1	123.5	0.052
108420	2SM2	349.8	0.013
108420	M3	239.5	0.014
108420	L2	148.4	0.034
108420	2MK3	305.5	0.127
108420	K2	138.7	0.095
108420	M8	141.3	0.009
108420	MS4	343.8	0.045
108421	M2	147.6	1.254
108421	S2	163.5	0.304
108421	N2	125.7	0.224
108421	K1	159	0.359
108421	M4	203.1	0.017
108421	O1	139.9	0.217
108421	M6	308	0.016
108421	MK3	35.9	0.017
108421	S4	291.1	0.004
108421	MN4	130.9	0.009
108421	2N2	90.9	0.044
108421	OO1	180.5	0.027
108421	M1	155.8	0.017
108421	J1	191	0.024
108421	Q1	133.2	0.038
108421	2Q1	35.4	0.008
108421	P1	149.8	0.093
108421	2SM2	317.6	0.008
108421	M3	8	0.008
108421	L2	149.8	0.027
108421	2MK3	322.6	0.053
108421	K2	161	0.082
108421	M8	217.8	0.004
108421	MS4	219.2	0.021
108422	M2	149.8	1.798
108422	S2	163.9	0.411
108422	N2	125.9	0.286
108422	K1	155.2	0.475
108422	M4	131.8	0.022
108422	O1	137.4	0.287
108422	M6	357.4	0.068
108422	MK3	48.7	0.076
108422	MN4	43.5	0.005
108422	2N2	105.8	0.084
108422	OO1	217.2	0.022
108422	M1	198.5	0.014
108422	J1	189.8	0.016
108422	Q1	117.5	0.041
108422	2Q1	78.6	0.006
108422	P1	139.2	0.119
108422	2SM2	330.3	0.015
108422	M3	117.2	0.005
108422	L2	175.2	0.04
108422	2MK3	332.7	0.093
108422	K2	155.3	0.128
108422	M8	246.9	0.012
108422	MS4	194.3	0.037
108423	M2	150.5	1.869
108423	S2	163.3	0.415
108423	N2	125.7	0.3
108423	K1	154.6	0.522
108423	M4	74.1	0.043
108423	O1	139.4	0.313
108423	M6	10.7	0.07
108423	MK3	42.8	0.08
108423	S4	163.5	0.005
108423	MN4	9.6	0.018
108423	S6	280.7	0.007
108423	2N2	102	0.073
108423	OO1	218	0.023
108423	M1	227	0.007
108423	J1	146.5	0.019
108423	Q1	128.7	0.042
108423	2Q1	110.7	0.003
108423	P1	136.7	0.128
108423	2SM2	324.3	0.007
108423	M3	174.8	0.018
108423	L2	175	0.038
108423	2MK3	329.6	0.102
108423	K2	159.5	0.143
108423	M8	226.4	0.009
108423	MS4	198.9	0.01
108424	M2	120.6	0.209
108424	S2	142.3	0.034
108424	N2	94.3	0.03
108424	K1	126.6	0.043
108424	M4	30.5	0.027
108424	O1	88.4	0.022
108424	M6	235.4	0.006
108424	MK3	4	0.027
108424	S4	197.3	0.001
108424	MN4	348.6	0.007
108424	S6	242.4	0.001
108424	2N2	78.6	0.013
108424	OO1	151.3	0.005
108424	M1	134.8	0.005
108424	J1	241.8	0.004
108424	Q1	96.4	0.007
108424	2Q1	319.9	0.003
108424	P1	134.3	0.032
108424	2SM2	328.7	0.001
108424	M3	345	0.002
108424	L2	128.7	0.007
108424	2MK3	314.5	0.021
108424	K2	112.1	0.015
108424	M8	176.3	0.002
108424	MS4	53	0.009
108425	M2	158	1.506
108425	S2	168.1	0.32
108425	N2	132.2	0.252
108425	K1	165.3	0.534
108425	M4	141.1	0.071
108425	O1	146.3	0.309
108425	M6	341.4	0.017
108425	MK3	108.6	0.076
108425	S4	358.5	0.009
108425	MN4	73	0.016
108425	S6	354.1	0.005
108425	2N2	108.5	0.051
108425	OO1	209.8	0.029
108425	M1	200.4	0.017
108425	J1	220.5	0.022
108425	Q1	137.9	0.044
108425	2Q1	162.2	0.003
108425	P1	162	0.172
108425	2SM2	263.1	0.016
108425	M3	69.1	0.01
108425	L2	168.6	0.049
108425	2MK3	44.3	0.045
108425	K2	163.9	0.115
108425	M8	337.5	0.012
108425	MS4	194.9	0.034
108426	M2	159.5	1.95
108426	S2	169.9	0.387
108426	N2	130.1	0.31
108426	K1	158.7	0.575
108426	M4	58.7	0.027
108426	O1	145.6	0.362
108426	M6	17.3	0.079
108426	MK3	40	0.104
108426	S4	148.8	0.007
108426	MN4	10.2	0.025
108426	S6	53.9	0.004
108426	2N2	141	0.077
108426	OO1	231	0.03
108426	M1	237.1	0.023
108426	J1	248.2	0.017
108426	Q1	139.3	0.043
108426	2Q1	39.3	0.017
108426	P1	154.3	0.178
108426	2SM2	355.3	0.011
108426	M3	327.3	0.006
108426	L2	186.9	0.059
108426	2MK3	359.9	0.126
108426	K2	152.3	0.178
108426	M8	270.4	0.018
108426	MS4	200.5	0.04
108427	M2	161.4	2.105
108427	S2	169.7	0.403
108427	N2	127.1	0.315
108427	K1	156.9	0.569
108427	M4	14	0.068
108427	O1	150.7	0.379
108427	M6	19.2	0.107
108427	MK3	27.9	0.168
108427	S4	157.1	0.007
108427	MN4	4.3	0.038
108427	S6	201.8	0.005
108427	2N2	156.4	0.109
108427	OO1	271.6	0.022
108427	M1	259.1	0.017
108427	J1	129.2	0.003
108427	Q1	131.7	0.043
108427	2Q1	78.9	0.006
108427	P1	148.9	0.174
108427	2SM2	59.2	0.017
108427	M3	282.9	0.005
108427	L2	209.9	0.073
108427	2MK3	359.1	0.183
108427	K2	145.2	0.197
108427	M8	297.6	0.015
108427	MS4	173.7	0.032
108428	M2	151.8	0.632
108428	S2	168.4	0.143
108428	N2	132.2	0.108
108428	K1	174.1	0.251
108428	M4	208.5	0.032
108428	O1	164.5	0.18
108428	M6	238.6	0.011
108428	MK3	238.8	0.049
108428	S4	57.6	0.011
108428	MN4	159.4	0.016
108428	S6	81.9	0.003
108428	2N2	88.8	0.025
108428	OO1	188.5	0.016
108428	M1	105.2	0.016
108428	J1	195	0.023
108428	Q1	162	0.042
108428	2Q1	275.5	0.005
108428	P1	167.7	0.097
108428	2SM2	288.6	0.011
108428	M3	306.7	0.007
108428	L2	185.5	0.016
108428	2MK3	230	0.031
108428	K2	116.8	0.027
108428	M8	71	0.004
108428	MS4	234.4	0.011
108429	M2	157.9	0.847
108429	S2	175.1	0.181
108429	N2	133.6	0.131
108429	K1	167.5	0.33
108429	M4	207.1	0.012
108429	O1	154.3	0.189
108429	M6	323.6	0.019
108429	MK3	306.7	0.013
108429	S4	118.5	0.002
108429	MN4	219.2	0.009
108429	S6	18.2	0.002
108429	2N2	135.2	0.027
108429	OO1	164.7	0.008
108429	M1	40.9	0.013
108429	J1	136.8	0.008
108429	Q1	140.8	0.028
108429	2Q1	121.7	0.011
108429	P1	161.5	0.117
108429	2SM2	293.3	0.008
108429	M3	8	0.013
108429	L2	200	0.026
108429	2MK3	340.7	0.033
108429	K2	132.3	0.04
108429	M8	111.4	0.005
108429	MS4	37.2	0.002
108430	M2	163.8	0.972
108430	S2	184.5	0.221
108430	N2	138.1	0.174
108430	K1	163.7	0.381
108430	M4	122.2	0.022
108430	O1	150.1	0.211
108430	M6	8	0.03
108430	MK3	102.9	0.044
108430	S4	208	0.004
108430	MN4	161.5	0.005
108430	S6	226.4	0.005
108430	2N2	195	0.025
108430	OO1	139.2	0.008
108430	M1	12.6	0.037
108430	J1	92.8	0.015
108430	Q1	127	0.031
108430	2Q1	170.1	0.013
108430	P1	148.8	0.147
108430	2SM2	110.5	0.003
108430	M3	41.1	0.015
108430	L2	213.4	0.02
108430	2MK3	15.2	0.06
108430	K2	160.7	0.022
108430	M8	254.6	0.004
108430	MS4	200.2	0.013
108431	M2	134.7	0.215
108431	S2	182.8	0.055
108431	N2	104	0.047
108431	K1	201.5	0.079
108431	M4	150.1	0.009
108431	O1	162	0.066
108431	M6	327.7	0.003
108431	MK3	115.2	0.018
108431	S4	24.6	0.004
108431	MN4	73.9	0.002
108431	S6	161.6	0.002
108431	2N2	196.3	0.01
108431	OO1	200.2	0.008
108431	M1	24.8	0.014
108431	J1	200	0.012
108431	Q1	177.7	0.026
108431	2Q1	117.5	0.003
108431	P1	174.2	0.039
108431	2SM2	25.5	0.002
108431	M3	289.9	0.006
108431	L2	154.3	0.019
108431	2MK3	32.7	0.012
108431	M8	231.6	0.002
108431	MS4	18.3	0.003
108432	M2	149.4	0.198
108432	S2	177.8	0.061
108432	N2	123.4	0.046
108432	K1	165.7	0.13
108432	M4	78	0.005
108432	O1	120.2	0.072
108432	M6	356.8	0.002
108432	MK3	275.7	0.007
108432	S4	155.7	0.002
108432	MN4	183.3	0.001
108432	S6	350.1	0.002
108432	2N2	167.3	0.01
108432	OO1	211.7	0.028
108432	M1	355.7	0.014
108432	J1	158.4	0.024
108432	Q1	114.8	0.032
108432	2Q1	106.3	0.01
108432	P1	123.3	0.071
108432	2SM2	278.5	0.004
108432	M3	31.2	0.006
108432	L2	141.1	0.008
108432	2MK3	45	0.014
108432	M8	134.8	0.003
108432	MS4	92.5	0.006
108433	M2	156.1	0.187
108433	S2	163.6	0.031
108433	N2	185.2	0.023
108433	K1	117.3	0.259
108433	M4	263.9	0.013
108433	O1	80.3	0.13
108433	M6	288.2	0.002
108433	MK3	233.2	0.026
108433	S4	176.1	0.004
108433	MN4	151.2	0.004
108433	S6	302.1	0.005
108433	2N2	31.4	0.03
108433	OO1	349.3	0.016
108433	M1	132.4	0.025
108433	J1	270	0.009
108433	Q1	43.9	0.044
108433	2Q1	87.2	0.006
108433	P1	94.6	0.086
108433	2SM2	334.5	0.003
108433	M3	345.9	0.007
108433	L2	283.4	0.021
108433	2MK3	179	0.01
108433	M8	321.6	0.003
108433	MS4	174.5	0.013
108434	M2	130.7	0.157
108434	S2	156.5	0.054
108434	N2	158.5	0.02
108434	K1	151.7	0.135
108434	M4	168	0.003
108434	O1	109.5	0.085
108434	M6	311.6	0.005
108434	MK3	273.4	0.001
108434	S4	260	0.002
108434	MN4	106	0.003
108434	S6	249.8	0.001
108434	2N2	137.9	0.009
108434	OO1	262	0.014
108434	M1	346.7	0.004
108434	J1	220.7	0.011
108434	Q1	93.2	0.012
108434	2Q1	122.4	0.01
108434	P1	140.6	0.056
108434	2SM2	286.1	0.01
108434	M3	157.3	0.004
108434	L2	270.6	0.006
108434	2MK3	330.7	0.01
108434	M8	259.3	0.001
108434	MS4	198.5	0.001
108435	M2	146	0.182
108435	S2	184.4	0.052
108435	N2	135.4	0.021
108435	K1	132.3	0.202
108435	M4	42.9	0.005
108435	O1	87.3	0.09
108435	M6	29.7	0.002
108435	MK3	22.5	0.002
108435	S4	317.7	0.006
108435	MN4	314.5	0.004
108435	S6	342	0.001
108435	2N2	346.5	0.01
108435	OO1	115.8	0.012
108435	M1	296.5	0.013
108435	J1	96.7	0.003
108435	Q1	84.2	0.023
108435	2Q1	104.2	0.008
108435	P1	129	0.076
108435	2SM2	198.7	0.002
108435	M3	227.3	0.005
108435	L2	172.6	0.007
108435	2MK3	18.2	0.003
108435	M8	90.2	0.001
108436	M2	144.3	0.195
108436	S2	221.7	0.046
108436	N2	93.8	0.06
108436	K1	105.8	0.153
108436	M4	356.5	0.012
108436	O1	83.7	0.058
108436	M6	50.7	0.004
108436	MK3	50.2	0.019
108436	S4	63.9	0.003
108436	MN4	288.4	0.003
108436	S6	29.2	0.001
108436	2N2	111.8	0.02
108436	OO1	4.9	0.016
108436	M1	118.8	0.028
108436	J1	113.8	0.019
108436	Q1	25.6	0.037
108436	2Q1	139.4	0.002
108436	P1	60.8	0.089
108436	2SM2	103.4	0.014
108436	M3	8.2	0.012
108436	L2	101.6	0.027
108436	2MK3	294.7	0.004
108436	M8	60.4	0.004
108436	MS4	22.3	0.004
108437	M2	154.8	1.143
108437	S2	180	0.242
108437	N2	133.9	0.266
108437	K1	150.7	0.23
108437	M4	57.9	0.069
108437	O1	154.3	0.099
108437	M6	259.5	0.009
108437	MK3	39.5	0.181
108437	S4	1.1	0.009
108437	MN4	42.1	0.036
108437	S6	194.2	0.008
108437	2N2	203.7	0.018
108437	OO1	145.4	0.041
108437	M1	295.2	0.019
108437	J1	297.3	0.009
108437	Q1	165.4	0.03
108437	2Q1	206	0.013
108437	P1	135.4	0.065
108437	2SM2	312.9	0.003
108437	M3	205.6	0.009
108437	L2	155	0.094
108437	2MK3	2.1	0.16
108437	K2	172.6	0.094
108437	M8	273.8	0.017
108437	MS4	97.1	0.033
108438	M2	161.9	1.265
108438	S2	187.1	0.265
108438	N2	141	0.283
108438	K1	163.3	0.26
108438	M4	26.6	0.096
108438	O1	167.9	0.135
108438	M6	27	0.03
108438	MK3	35	0.217
108438	S4	35.1	0.006
108438	MN4	19.5	0.05
108438	S6	193.7	0.006
108438	2N2	247.1	0.014
108438	OO1	147.2	0.04
108438	M1	292.7	0.022
108438	J1	265.6	0.013
108438	Q1	174.1	0.034
108438	2Q1	171.7	0.014
108438	P1	142.1	0.063
108438	2SM2	13.1	0.006
108438	M3	162.5	0.013
108438	L2	163.8	0.097
108438	2MK3	6.4	0.183
108438	K2	180.2	0.091
108438	M8	270.5	0.009
108438	MS4	76.6	0.038
108439	M2	164.5	1.232
108439	S2	189	0.261
108439	N2	141.8	0.268
108439	K1	167.8	0.268
108439	M4	28.3	0.135
108439	O1	182	0.136
108439	M6	54.9	0.038
108439	MK3	35	0.247
108439	S4	117.4	0.006
108439	MN4	22.9	0.072
108439	S6	191.1	0.005
108439	2N2	322.9	0.01
108439	OO1	157.1	0.032
108439	M1	294	0.009
108439	J1	266.4	0.01
108439	Q1	181	0.033
108439	2Q1	135.2	0.017
108439	P1	152.5	0.083
108439	2SM2	60	0.006
108439	M3	151.7	0.01
108439	L2	173.4	0.087
108439	2MK3	10.9	0.214
108439	K2	191.9	0.095
108439	M8	181	0.004
108439	MS4	80.8	0.059
108440	M2	165.5	1.21
108440	S2	189.5	0.274
108440	N2	145.6	0.286
108440	K1	152.2	0.262
108440	M4	212	0.086
108440	O1	151.2	0.133
108440	M6	2.2	0.022
108440	MK3	48.4	0.051
108440	S4	18.9	0.002
108440	MN4	184.1	0.045
108440	S6	230.4	0.002
108440	2N2	285.5	0.014
108440	OO1	137.1	0.035
108440	M1	181.1	0.005
108440	J1	253.1	0.022
108440	Q1	137.8	0.032
108440	2Q1	143.5	0.022
108440	P1	128.8	0.069
108440	2SM2	4.8	0.012
108440	M3	110.3	0.016
108440	L2	180.2	0.085
108440	2MK3	1.5	0.11
108440	K2	175.5	0.086
108440	M8	357	0.003
108440	MS4	227.6	0.023
108441	M2	167.3	1.388
108441	S2	191.3	0.307
108441	N2	147.2	0.327
108441	K1	151	0.297
108441	M4	217.4	0.097
108441	O1	149.3	0.15
108441	M6	39.9	0.03
108441	MK3	48	0.07
108441	S4	6.8	0.004
108441	MN4	187	0.049
108441	2N2	293.9	0.018
108441	OO1	138	0.039
108441	M1	213	0.007
108441	J1	252.5	0.023
108441	Q1	144.7	0.037
108441	2Q1	153.6	0.025
108441	P1	130	0.078
108441	2SM2	15.3	0.015
108441	M3	120.4	0.02
108441	L2	180.2	0.096
108441	2MK3	8.7	0.133
108441	K2	177.8	0.093
108441	M8	230.6	0.002
108441	MS4	233.1	0.026
108442	M2	169	1.498
108442	S2	192.4	0.321
108442	N2	149	0.348
108442	K1	148.7	0.326
108442	M4	226.1	0.108
108442	O1	145.3	0.174
108442	M6	59.5	0.026
108442	MK3	52.3	0.083
108442	S4	343.7	0.006
108442	MN4	197.5	0.055
108442	2N2	288.1	0.02
108442	OO1	132.4	0.028
108442	M1	198.4	0.014
108442	J1	243	0.015
108442	Q1	146.2	0.038
108442	2Q1	166.9	0.023
108442	P1	138.8	0.1
108442	2SM2	16.9	0.013
108442	M3	131.6	0.023
108442	L2	179.6	0.098
108442	2MK3	12.7	0.146
108442	K2	175.8	0.102
108442	M8	270.9	0.009
108442	MS4	246	0.02
108443	M2	152.5	0.654
108443	S2	171.2	0.138
108443	N2	129.7	0.16
108443	K1	156.5	0.156
108443	M4	28.1	0.033
108443	O1	147.1	0.063
108443	M6	337.6	0.023
108443	MK3	29.8	0.102
108443	S4	0.4	0.001
108443	MN4	11.4	0.021
108443	S6	120.4	0.003
108443	2N2	210.2	0.009
108443	OO1	117.4	0.009
108443	M1	260.6	0.016
108443	J1	202.2	0.012
108443	Q1	158.2	0.012
108443	2Q1	132.7	0.01
108443	P1	165.6	0.035
108443	2SM2	331	0.006
108443	M3	136.9	0.01
108443	L2	157.9	0.047
108443	2MK3	353.3	0.074
108443	K2	151.4	0.052
108443	M8	128	0.009
108443	MS4	23	0.014
108444	M2	154.5	0.775
108444	S2	178.4	0.146
108444	N2	131	0.166
108444	K1	157	0.206
108444	M4	30.8	0.044
108444	O1	165.3	0.098
108444	M6	346.8	0.012
108444	MK3	23.9	0.102
108444	S4	354.3	0.005
108444	MN4	24.7	0.026
108444	S6	121.9	0.002
108444	2N2	312.4	0.008
108444	OO1	86.5	0.015
108444	M1	272.7	0.01
108444	J1	200.2	0.017
108444	Q1	167	0.021
108444	2Q1	175.1	0.013
108444	P1	166.3	0.049
108444	2SM2	343.2	0.005
108444	M3	102.5	0.009
108444	L2	155.6	0.043
108444	2MK3	358.4	0.107
108444	K2	159.9	0.03
108444	M8	175.1	0.006
108444	MS4	6.5	0.026
108445	M2	168.3	1.189
108445	S2	189.2	0.278
108445	N2	147	0.258
108445	K1	148.3	0.321
108445	M4	231.3	0.073
108445	O1	136.1	0.163
108445	M6	10.2	0.038
108445	MK3	108.2	0.031
108445	S4	22.8	0.003
108445	MN4	189.6	0.03
108445	NU2	131.1	0.057
108445	S6	339.9	0.001
108445	MU2	293.2	0.016
108445	2N2	147.9	0.03
108445	OO1	151.3	0.014
108445	LDA2	142.8	0.022
108445	M1	262.6	0.004
108445	J1	269.6	0.011
108445	RHO1	354.7	0.003
108445	Q1	116.2	0.033
108445	2Q1	166.2	0.023
108445	P1	132.9	0.074
108445	2SM2	346.5	0.011
108445	M3	73.4	0.009
108445	L2	188	0.04
108445	2MK3	10.6	0.06
108445	K2	161.8	0.089
108445	M8	147.5	0.005
108445	MS4	255.6	0.038
108446	M2	169.3	1.27
108446	S2	190	0.298
108446	N2	147.7	0.272
108446	K1	147.9	0.341
108446	M4	244.1	0.067
108446	O1	133.4	0.168
108446	M6	31.1	0.039
108446	MK3	79.1	0.03
108446	S4	348	0.004
108446	MN4	198.2	0.031
108446	NU2	136.6	0.062
108446	MU2	295.3	0.015
108446	2N2	149	0.032
108446	OO1	133.6	0.017
108446	LDA2	140.1	0.021
108446	M1	241.9	0.003
108446	J1	273.6	0.015
108446	RHO1	351.1	0.008
108446	Q1	112.9	0.037
108446	2Q1	171.8	0.024
108446	P1	133.1	0.086
108446	2SM2	349.8	0.01
108446	M3	85	0.013
108446	L2	188	0.045
108446	2MK3	8.8	0.073
108446	K2	162.2	0.099
108446	M8	211.7	0.006
108446	MS4	268.1	0.033
108447	M2	169.8	1.313
108447	S2	190.2	0.303
108447	N2	148.2	0.273
108447	K1	148	0.356
108447	M4	261.7	0.071
108447	O1	135.9	0.166
108447	M6	48.1	0.038
108447	MK3	61.5	0.025
108447	S4	343.9	0.005
108447	MN4	215.6	0.036
108447	NU2	142.9	0.065
108447	MU2	290.4	0.016
108447	2N2	145.2	0.028
108447	OO1	121.6	0.02
108447	LDA2	147.4	0.021
108447	M1	5.1	0.002
108447	J1	280.9	0.014
108447	RHO1	349.6	0.007
108447	Q1	112.4	0.036
108447	2Q1	184	0.021
108447	P1	134.5	0.092
108447	2SM2	356.7	0.007
108447	M3	79.2	0.015
108447	L2	189.3	0.05
108447	2MK3	8.1	0.082
108447	K2	167.1	0.107
108447	M8	219.3	0.005
108447	MS4	293.2	0.033
108448	M2	165.3	0.909
108448	S2	182.1	0.211
108448	N2	146.4	0.22
108448	K1	155.8	0.269
108448	M4	246.5	0.088
108448	O1	152.8	0.144
108448	M6	11.2	0.023
108448	MK3	236	0.046
108448	S4	302.8	0.005
108448	MN4	218	0.047
108448	S6	242.2	0.003
108448	2N2	113.6	0.021
108448	OO1	135.7	0.02
108448	M1	93.3	0.013
108448	J1	210.9	0.01
108448	Q1	126.8	0.027
108448	2Q1	167.4	0.019
108448	P1	149.8	0.059
108448	2SM2	322.1	0.004
108448	M3	18	0.019
108448	L2	205.8	0.04
108448	2MK3	343.4	0.023
108448	K2	176.2	0.065
108448	M8	67	0.006
108448	MS4	263.7	0.046
108449	M2	167.3	1.097
108449	S2	185.7	0.258
108449	N2	148	0.269
108449	K1	155.3	0.327
108449	M4	246.3	0.109
108449	O1	149.2	0.175
108449	M6	27.8	0.039
108449	MK3	228.8	0.045
108449	S4	307.8	0.004
108449	MN4	216.8	0.063
108449	2N2	107.6	0.031
108449	OO1	147.1	0.029
108449	M1	101.2	0.014
108449	J1	193.2	0.012
108449	Q1	131.5	0.033
108449	2Q1	181.7	0.016
108449	P1	153.7	0.07
108449	2SM2	337.4	0.004
108449	M3	9.7	0.022
108449	L2	194.7	0.047
108449	2MK3	1.8	0.036
108449	K2	182.2	0.083
108449	M8	132.5	0.008
108449	MS4	274	0.047
108450	M2	168.5	1.198
108450	S2	188.5	0.279
108450	N2	147.5	0.291
108450	K1	155.8	0.374
108450	M4	246.5	0.114
108450	O1	149.3	0.208
108450	M6	41.1	0.044
108450	MK3	230	0.059
108450	S4	319.1	0.002
108450	MN4	221.1	0.068
108450	S6	134.6	0.002
108450	2N2	114.4	0.043
108450	OO1	160.5	0.039
108450	M1	157.9	0.014
108450	J1	190.2	0.015
108450	Q1	133.9	0.046
108450	2Q1	230.7	0.005
108450	P1	164.7	0.083
108450	2SM2	19.8	0.007
108450	M3	5.7	0.032
108450	L2	180.3	0.056
108450	2MK3	355.8	0.038
108450	K2	187.1	0.084
108450	M8	165.6	0.011
108450	MS4	292.9	0.041
108451	M2	141.2	0.844
108451	S2	162.8	0.168
108451	N2	118	0.199
108451	K1	142.7	0.186
108451	M4	194.9	0.035
108451	O1	123.1	0.108
108451	M6	311.8	0.035
108451	MK3	338.9	0.04
108451	S4	325.8	0.008
108451	MN4	148.8	0.02
108451	S6	108.8	0.001
108451	2N2	268.5	0.012
108451	OO1	144.2	0.018
108451	M1	277.3	0.011
108451	J1	180.6	0.011
108451	Q1	138.6	0.022
108451	2Q1	173	0.007
108451	P1	148.8	0.054
108451	2SM2	344.5	0.008
108451	M3	42.1	0.023
108451	L2	142.9	0.061
108451	2MK3	322.9	0.068
108451	K2	127.3	0.061
108451	M8	345.3	0.004
108451	MS4	251.8	0.021
108452	M2	149.3	0.929
108452	S2	170.1	0.212
108452	N2	129.3	0.221
108452	K1	155.3	0.265
108452	M4	222	0.037
108452	O1	142.1	0.148
108452	M6	294	0.02
108452	MK3	283	0.009
108452	S4	333.3	0.003
108452	MN4	197.8	0.022
108452	S6	294.4	0.001
108452	2N2	169.3	0.015
108452	OO1	166.4	0.018
108452	M1	223.2	0.009
108452	J1	179.9	0.016
108452	Q1	141.7	0.026
108452	2Q1	138.3	0.01
108452	P1	160.8	0.071
108452	2SM2	295.1	0.005
108452	M3	32.3	0.016
108452	L2	152.1	0.039
108452	2MK3	313.2	0.04
108452	K2	154.3	0.056
108452	M8	346.4	0.004
108452	MS4	260.3	0.024
108453	M2	151.8	1.214
108453	S2	170.1	0.257
108453	N2	129.7	0.286
108453	K1	151	0.332
108453	M4	220.2	0.055
108453	O1	133.4	0.196
108453	M6	343.8	0.037
108453	MK3	316.7	0.026
108453	S4	342.4	0.001
108453	MN4	185.9	0.033
108453	S6	51.4	0.002
108453	2N2	141.8	0.012
108453	OO1	177.2	0.03
108453	M1	243.3	0.021
108453	J1	154.2	0.028
108453	Q1	139	0.039
108453	2Q1	240.5	0.005
108453	P1	163.5	0.092
108453	2SM2	355	0.009
108453	M3	39.2	0.027
108453	L2	153.3	0.067
108453	2MK3	328.8	0.072
108453	K2	144.2	0.076
108453	M8	95.2	0.008
108453	MS4	271.2	0.035
108454	M2	173.8	0.87
108454	S2	191.7	0.205
108454	N2	152.5	0.214
108454	K1	177.8	0.366
108454	M4	130.1	0.064
108454	O1	154.6	0.206
108454	M6	6.1	0.023
108454	MK3	82	0.041
108454	S4	357.2	0.004
108454	MN4	108.7	0.043
108454	S6	349.4	0.003
108454	2N2	198.2	0.024
108454	OO1	159.9	0.025
108454	M1	238.1	0.032
108454	J1	200.8	0.028
108454	Q1	137.4	0.045
108454	2Q1	202.2	0.012
108454	P1	179.3	0.116
108454	2SM2	18.4	0.004
108454	M3	357.4	0.005
108454	L2	186.8	0.037
108454	2MK3	307.4	0.025
108454	K2	177	0.046
108454	M8	153.9	0.015
108454	MS4	191.6	0.032
108455	M2	177.7	1.157
108455	S2	194.6	0.267
108455	N2	154.8	0.281
108455	K1	176.1	0.479
108455	M4	143.6	0.057
108455	O1	153.9	0.272
108455	M6	18	0.027
108455	MK3	86.4	0.06
108455	S4	30.2	0.004
108455	MN4	125.8	0.046
108455	S6	302.2	0.001
108455	2N2	181.8	0.013
108455	OO1	177	0.034
108455	M1	240.2	0.032
108455	J1	192.8	0.031
108455	Q1	141.3	0.054
108455	2Q1	188.2	0.011
108455	P1	175.3	0.144
108455	2SM2	22.1	0.013
108455	M3	61	0.003
108455	L2	198.1	0.059
108455	2MK3	358.9	0.03
108455	K2	192.7	0.074
108455	M8	182	0.014
108455	MS4	225.3	0.026
108456	M2	182.4	1.35
108456	S2	199.2	0.305
108456	N2	161.3	0.316
108456	K1	177.1	0.553
108456	M4	140.2	0.069
108456	O1	153.9	0.301
108456	M6	63.4	0.009
108456	MK3	77.3	0.106
108456	S4	258.4	0.002
108456	MN4	127.5	0.038
108456	S6	196.3	0.005
108456	2N2	90.7	0.034
108456	OO1	196	0.026
108456	M1	187.3	0.006
108456	J1	185.8	0.037
108456	Q1	133.7	0.06
108456	2Q1	195.9	0.02
108456	P1	170.5	0.169
108456	2SM2	8.9	0.014
108456	M3	193.9	0.021
108456	L2	210.1	0.071
108456	2MK3	46.4	0.068
108456	K2	210	0.132
108456	M8	256.1	0.007
108456	MS4	258.3	0.02
108457	M2	178.5	1.022
108457	S2	191.7	0.231
108457	N2	156	0.244
108457	K1	178.1	0.45
108457	M4	216.1	0.063
108457	O1	168.1	0.3
108457	M6	358.6	0.021
108457	MK3	233.4	0.044
108457	S4	32.4	0.008
108457	MN4	193	0.018
108457	S6	34.3	0.003
108457	2N2	115	0.016
108457	OO1	188	0.038
108457	M1	283.9	0.022
108457	J1	199.2	0.03
108457	Q1	169.1	0.065
108457	2Q1	162.9	0.006
108457	P1	189.1	0.133
108457	2SM2	322.7	0.008
108457	M3	25.8	0.029
108457	L2	196.7	0.046
108457	2MK3	307	0.024
108457	K2	179.1	0.064
108457	M8	184.5	0.006
108457	MS4	231.4	0.028
108458	M2	184	1.299
108458	S2	195.3	0.271
108458	N2	162.6	0.299
108458	K1	180	0.539
108458	M4	247.9	0.066
108458	O1	170.2	0.362
108458	M6	62.2	0.034
108458	MK3	274.9	0.027
108458	S4	31.8	0.007
108458	MN4	234.6	0.022
108458	S6	98.6	0.002
108458	2N2	69	0.048
108458	OO1	190	0.04
108458	M1	6.7	0.013
108458	J1	177.3	0.022
108458	Q1	164.3	0.07
108458	2Q1	250.9	0.007
108458	P1	186.8	0.149
108458	2SM2	311.3	0.011
108458	M3	65	0.023
108458	L2	211.5	0.07
108458	2MK3	38.1	0.047
108458	K2	191.5	0.09
108458	M8	187.2	0.01
108458	MS4	242.6	0.012
108459	M2	192.1	1.463
108459	S2	204.6	0.275
108459	N2	169.8	0.334
108459	K1	184.3	0.612
108459	M4	274.7	0.019
108459	O1	170.5	0.341
108459	M6	98.8	0.056
108459	MK3	71.4	0.057
108459	S4	49.9	0.003
108459	MN4	166.8	0.005
108459	S6	219.4	0.005
108459	2N2	63.9	0.1
108459	OO1	234.3	0.061
108459	M1	50.4	0.078
108459	J1	96.6	0.024
108459	Q1	144.5	0.067
108459	2Q1	246.6	0.03
108459	P1	174.6	0.165
108459	2SM2	29.9	0.011
108459	M3	232.5	0.007
108459	L2	227.4	0.095
108459	2MK3	60.7	0.121
108459	K2	223.3	0.111
108459	M8	239.7	0.004
108459	MS4	94.9	0.037
108460	M2	181.2	1.473
108460	S2	201.1	0.331
108460	N2	161.1	0.366
108460	K1	182.9	0.59
108460	M4	198.6	0.079
108460	O1	178.1	0.356
108460	M6	17	0.055
108460	MK3	45.4	0.053
108460	S4	72.3	0.01
108460	MN4	166.2	0.043
108460	S6	163.9	0.005
108460	2N2	350.2	0.018
108460	OO1	189.6	0.038
108460	M1	274.7	0.021
108460	J1	193.2	0.023
108460	Q1	175.5	0.054
108460	2Q1	223.7	0.023
108460	P1	184.3	0.212
108460	2SM2	21.9	0.017
108460	M3	32.9	0.018
108460	L2	197.3	0.079
108460	2MK3	345.2	0.07
108460	K2	204.1	0.085
108460	M8	119.7	0.029
108460	MS4	318.5	0.014
108461	M2	188.5	1.94
108461	S2	206.2	0.388
108461	N2	164.1	0.463
108461	K1	180.8	0.731
108461	M4	252.5	0.029
108461	O1	173.1	0.385
108461	M6	73.3	0.069
108461	MK3	52.5	0.089
108461	S4	301.9	0.008
108461	MN4	190.4	0.027
108461	S6	180.1	0.006
108461	2N2	57.9	0.074
108461	OO1	184.2	0.075
108461	M1	21.9	0.038
108461	J1	183	0.015
108461	Q1	165.6	0.075
108461	2Q1	237.3	0.023
108461	P1	186.8	0.205
108461	2SM2	61.2	0.01
108461	M3	166.4	0.024
108461	L2	215.7	0.138
108461	2MK3	44.8	0.134
108461	K2	210	0.139
108461	M8	186.3	0.02
108461	MS4	11.8	0.043
108462	M2	190.2	2.025
108462	S2	208	0.369
108462	N2	165.4	0.491
108462	K1	174	0.773
108462	M4	38.1	0.072
108462	O1	175.8	0.332
108462	M6	100.1	0.039
108462	MK3	49	0.128
108462	S4	339.9	0.008
108462	MN4	313.3	0.03
108462	S6	218.7	0.008
108462	2N2	81.1	0.107
108462	OO1	211.9	0.077
108462	M1	38.8	0.035
108462	J1	250.6	0.016
108462	Q1	142.4	0.06
108462	2Q1	214.2	0.032
108462	P1	203.6	0.196
108462	2SM2	69.2	0.033
108462	M3	160.7	0.03
108462	L2	225.9	0.11
108462	2MK3	56	0.164
108462	K2	226.1	0.131
108462	M8	277.4	0.019
108462	MS4	24.2	0.032
108463	M2	174.4	0.884
108463	S2	197.6	0.155
108463	N2	153.8	0.212
108463	K1	166.3	0.299
108463	M4	204.2	0.075
108463	O1	163.2	0.139
108463	M6	15.6	0.041
108463	MK3	115.6	0.059
108463	S4	226.8	0.006
108463	MN4	168.7	0.046
108463	S6	180.5	0.003
108463	2N2	352.9	0.037
108463	OO1	163.3	0.023
108463	M1	331.6	0.02
108463	J1	296.6	0.007
108463	Q1	122	0.026
108463	2Q1	182.5	0.008
108463	P1	179.5	0.076
108463	2SM2	157.2	0.006
108463	M3	64.3	0.025
108463	L2	201.2	0.064
108463	2MK3	14.5	0.082
108463	K2	186.3	0.047
108463	M8	227.6	0.004
108463	MS4	280.3	0.033
108464	M2	205	1.082
108464	S2	222.7	0.235
108464	N2	183.5	0.263
108464	K1	192.9	0.443
108464	M4	292.2	0.105
108464	O1	181.6	0.296
108464	M6	91.8	0.019
108464	MK3	268.8	0.093
108464	S4	226.1	0.008
108464	MN4	266.1	0.048
108464	S6	189	0.004
108464	2N2	98.1	0.009
108464	OO1	181.2	0.041
108464	M1	237	0.014
108464	J1	215.7	0.023
108464	Q1	173.4	0.065
108464	2Q1	232	0.025
108464	P1	191.4	0.132
108464	2SM2	76	0.017
108464	M3	76.2	0.022
108464	L2	228	0.066
108464	2MK3	37.3	0.029
108464	K2	197.6	0.063
108464	M8	237.7	0.008
108464	MS4	336.3	0.036
108465	M2	208.2	1.365
108465	S2	221.8	0.282
108465	N2	186.6	0.33
108465	K1	194.4	0.557
108465	M4	300.3	0.109
108465	O1	181.7	0.356
108465	M6	124.3	0.035
108465	MK3	274.4	0.098
108465	S4	281.6	0.006
108465	MN4	285.1	0.056
108465	S6	229.7	0.002
108465	2N2	84.8	0.057
108465	OO1	216.1	0.054
108465	M1	78	0.007
108465	J1	189.5	0.025
108465	Q1	177.4	0.079
108465	2Q1	250.2	0.03
108465	P1	190.5	0.172
108465	2SM2	89.2	0.012
108465	M3	107.5	0.025
108465	L2	242.1	0.088
108465	2MK3	78.9	0.041
108465	K2	213.3	0.086
108465	M8	259.4	0.01
108465	MS4	332.3	0.026
108466	M2	210.4	1.574
108466	S2	223	0.3
108466	N2	187.8	0.361
108466	K1	195.7	0.679
108466	M4	288.9	0.061
108466	O1	182.8	0.386
108466	M6	159.9	0.031
108466	MK3	282.4	0.029
108466	S4	24.2	0.02
108466	MN4	270.1	0.052
108466	S6	275.1	0.007
108466	2N2	91.2	0.104
108466	OO1	230.6	0.094
108466	M1	58.1	0.03
108466	J1	172.1	0.036
108466	Q1	186.4	0.087
108466	2Q1	256.5	0.03
108466	P1	187.5	0.192
108466	2SM2	277.9	0.003
108466	M3	144.3	0.018
108466	L2	251.8	0.094
108466	2MK3	103.9	0.072
108466	K2	219	0.085
108466	MS4	238.4	0.022
108467	M2	218.5	0.894
108467	S2	230.2	0.19
108467	N2	193.8	0.204
108467	K1	202.3	0.377
108467	M4	299.4	0.042
108467	O1	189.4	0.239
108467	M6	59.9	0.013
108467	MK3	335.6	0.025
108467	S4	303.9	0.003
108467	MN4	280.8	0.028
108467	S6	64.6	0.002
108467	2N2	29.3	0.019
108467	OO1	205.7	0.035
108467	J1	164.8	0.018
108467	Q1	185.7	0.051
108467	2Q1	226.5	0.022
108467	P1	201.1	0.113
108467	2SM2	117.3	0.007
108467	M3	118.9	0.014
108467	L2	263.4	0.063
108467	2MK3	30.9	0.022
108467	K2	191.7	0.061
108467	M8	206.9	0.008
108467	MS4	4.6	0.021
108468	M2	220	1.016
108468	S2	228	0.207
108468	N2	197.1	0.226
108468	K1	202.1	0.421
108468	M4	307.5	0.057
108468	O1	187.9	0.254
108468	M6	94.9	0.018
108468	MK3	335.8	0.015
108468	S4	353.4	0.006
108468	MN4	283.8	0.035
108468	2N2	51.2	0.033
108468	OO1	217	0.042
108468	M1	54.8	0.005
108468	J1	165	0.025
108468	Q1	189.1	0.057
108468	2Q1	227.5	0.026
108468	P1	202	0.118
108468	2SM2	116.1	0.002
108468	M3	131	0.018
108468	L2	266.8	0.076
108468	2MK3	74.9	0.035
108468	K2	199.8	0.079
108468	M8	223.4	0.011
108468	MS4	1.1	0.018
108469	M2	221.7	1.12
108469	S2	226.3	0.222
108469	N2	200.4	0.242
108469	K1	201.6	0.454
108469	M4	314.5	0.065
108469	O1	186.4	0.26
108469	M6	119.7	0.024
108469	MK3	356.6	0.004
108469	S4	359.3	0.01
108469	MN4	283.5	0.04
108469	S6	239.3	0.002
108469	2N2	65.4	0.052
108469	OO1	223.9	0.048
108469	M1	46.3	0.014
108469	J1	161.5	0.031
108469	Q1	191.3	0.06
108469	2Q1	232.4	0.032
108469	P1	203.3	0.12
108469	M3	139.4	0.021
108469	L2	269.2	0.087
108469	2MK3	93.5	0.058
108469	K2	210	0.1
108469	M8	238.4	0.011
108469	MS4	3.6	0.014
108470	M2	223.5	1.218
108470	S2	225.1	0.236
108470	N2	203.8	0.257
108470	K1	200.8	0.485
108470	M4	319.8	0.066
108470	O1	184.8	0.258
108470	M6	137	0.026
108470	MK3	135.3	0.01
108470	S4	0	0.014
108470	MN4	281.8	0.044
108470	S6	252.3	0.003
108470	2N2	75.5	0.076
108470	OO1	225.1	0.056
108470	M1	43.9	0.025
108470	J1	152.4	0.036
108470	Q1	190	0.061
108470	2Q1	237.9	0.041
108470	P1	203.6	0.125
108470	2SM2	296.9	0.005
108470	M3	146.1	0.02
108470	L2	271.3	0.094
108470	2MK3	102.9	0.086
108470	K2	220.2	0.123
108470	M8	255.7	0.006
108470	MS4	23.1	0.009
108471	M2	225	1.31
108471	S2	224.7	0.245
108471	N2	206.8	0.275
108471	K1	199.4	0.524
108471	M4	323.4	0.06
108471	O1	183.3	0.249
108471	M6	155.5	0.026
108471	MK3	132.7	0.025
108471	S4	7.7	0.018
108471	MN4	278.2	0.041
108471	S6	293.1	0.002
108471	2N2	83.8	0.101
108471	OO1	224.8	0.073
108471	M1	42	0.041
108471	J1	139.5	0.043
108471	Q1	185.1	0.061
108471	2Q1	243.9	0.054
108471	P1	205.9	0.13
108471	2SM2	294.5	0.007
108471	M3	147.6	0.014
108471	L2	271.2	0.098
108471	2MK3	108	0.113
108471	K2	229.8	0.143
108471	M8	324.5	0.002
108471	MS4	95.6	0.007
108472	M2	225.6	1.388
108472	S2	225.3	0.255
108472	N2	207.3	0.295
108472	K1	197.4	0.574
108472	M4	334.2	0.039
108472	O1	181.9	0.236
108472	M6	170.7	0.033
108472	MK3	124.9	0.042
108472	S4	26.1	0.021
108472	MN4	277.3	0.028
108472	2N2	91.9	0.122
108472	OO1	224.7	0.095
108472	M1	41.4	0.06
108472	J1	136.1	0.052
108472	Q1	180.1	0.061
108472	2Q1	247.7	0.066
108472	P1	209.1	0.137
108472	2SM2	292.2	0.009
108472	M3	189.6	0.004
108472	L2	269.9	0.1
108472	2MK3	111.5	0.128
108472	K2	239.9	0.161
108472	M8	62.1	0.003
108472	MS4	149.8	0.019
108473	M2	225.6	1.423
108473	S2	224.4	0.287
108473	N2	205.2	0.298
108473	K1	197.4	0.606
108473	M4	70.8	0.045
108473	O1	182.3	0.213
108473	M6	167.7	0.042
108473	MK3	111	0.073
108473	S4	41.5	0.027
108473	MN4	27.4	0.01
108473	S6	282.2	0.003
108473	2N2	106.6	0.135
108473	OO1	221.3	0.108
108473	M1	50.2	0.078
108473	J1	136.3	0.062
108473	Q1	188.3	0.043
108473	2Q1	245.6	0.071
108473	P1	194.6	0.155
108473	2SM2	318.2	0.021
108473	M3	272.5	0.024
108473	L2	265.1	0.099
108473	2MK3	117.1	0.136
108473	K2	247	0.199
108473	M8	132.2	0.007
108473	MS4	168.3	0.047
108474	M2	223.3	0.989
108474	S2	249.9	0.214
108474	N2	199.1	0.238
108474	K1	211.4	0.47
108474	M4	247.2	0.048
108474	O1	205.3	0.317
108474	M6	73.2	0.043
108474	MK3	57.7	0.066
108474	S4	186	0.011
108474	MN4	229.5	0.02
108474	S6	32.5	0.004
108474	2N2	1.5	0.04
108474	OO1	235.8	0.03
108474	M1	75.4	0.005
108474	J1	204.1	0.019
108474	Q1	201.1	0.06
108474	2Q1	289.3	0.008
108474	P1	208.1	0.148
108474	2SM2	126.6	0.018
108474	M3	114.6	0.026
108474	L2	242.9	0.064
108474	2MK3	35.5	0.1
108474	K2	224.9	0.064
108474	M8	153.1	0.013
108474	MS4	74.9	0.021
108475	M2	227.9	1.421
108475	S2	247.9	0.249
108475	N2	204.6	0.328
108475	K1	208.8	0.573
108475	M4	348	0.021
108475	O1	204	0.341
108475	M6	147.6	0.051
108475	MK3	98.7	0.096
108475	MN4	290.4	0.013
108475	S6	337.6	0.003
108475	2N2	71.6	0.06
108475	OO1	212.4	0.04
108475	M1	38.9	0.02
108475	J1	196.1	0.014
108475	Q1	194.9	0.067
108475	2Q1	256.1	0.027
108475	P1	207.1	0.174
108475	2SM2	176.7	0.009
108475	M3	143.6	0.027
108475	L2	248.6	0.103
108475	2MK3	73.8	0.138
108475	K2	237.7	0.097
108475	M8	83.1	0.004
108475	MS4	112.4	0.029
108476	M2	231.9	1.583
108476	S2	246.9	0.265
108476	N2	208.4	0.37
108476	K1	210.5	0.619
108476	M4	95.8	0.035
108476	O1	202.9	0.326
108476	M6	172	0.038
108476	MK3	109.4	0.137
108476	S4	277.1	0.008
108476	MN4	302.8	0.012
108476	2N2	81.5	0.071
108476	OO1	223.6	0.047
108476	M1	29.7	0.021
108476	J1	222.7	0.012
108476	Q1	192.6	0.057
108476	2Q1	261.7	0.051
108476	P1	211.5	0.188
108476	2SM2	180.4	0.008
108476	M3	185.4	0.038
108476	L2	256.5	0.117
108476	2MK3	94.9	0.155
108476	K2	244.1	0.111
108476	M8	95	0.024
108476	MS4	116	0.04
108477	M2	197.2	1.293
108477	S2	221.6	0.259
108477	N2	174.1	0.307
108477	K1	187.3	0.416
108477	M4	212	0.117
108477	O1	182.1	0.23
108477	M6	81.1	0.06
108477	MK3	126.9	0.224
108477	S4	19.3	0.003
108477	MN4	186.7	0.068
108477	S6	215.8	0.004
108477	2N2	296	0.019
108477	OO1	155.9	0.043
108477	M1	25.1	0.01
108477	J1	298.2	0.011
108477	Q1	185.7	0.043
108477	2Q1	186.8	0.015
108477	P1	185.3	0.115
108477	2SM2	329.1	0.011
108477	M3	29.8	0.029
108477	L2	201.6	0.114
108477	2MK3	51.7	0.143
108477	K2	236.1	0.064
108477	M8	96.9	0.008
108477	MS4	331.9	0.01
108478	M2	198.2	1.652
108478	S2	222.4	0.308
108478	N2	175.4	0.377
108478	K1	186	0.478
108478	M4	200.6	0.154
108478	O1	185.9	0.235
108478	M6	103.9	0.081
108478	MK3	128.2	0.287
108478	S4	12.4	0.003
108478	MN4	183.2	0.104
108478	S6	194.4	0.005
108478	2N2	340.6	0.019
108478	OO1	181.9	0.047
108478	M1	354.8	0.013
108478	J1	275	0.019
108478	Q1	179.8	0.041
108478	2Q1	189.8	0.026
108478	P1	177.9	0.133
108478	2SM2	332.2	0.008
108478	M3	66.2	0.03
108478	L2	209.1	0.154
108478	2MK3	64	0.191
108478	K2	225.5	0.082
108478	M8	343.5	0.01
108478	MS4	299.6	0.022
108479	M2	198	1.806
108479	S2	222.3	0.34
108479	N2	174.3	0.408
108479	K1	182.6	0.485
108479	M4	197.6	0.188
108479	O1	190.8	0.23
108479	M6	107.1	0.093
108479	MK3	130	0.305
108479	S4	26.2	0.01
108479	MN4	182.7	0.127
108479	S6	179.7	0.005
108479	2N2	6.3	0.015
108479	OO1	194.4	0.049
108479	M1	343.8	0.014
108479	J1	260.4	0.021
108479	Q1	175	0.042
108479	2Q1	188.6	0.033
108479	P1	171.4	0.145
108479	2SM2	17	0.009
108479	M3	95.8	0.037
108479	L2	212.3	0.169
108479	2MK3	70.5	0.209
108479	K2	222.2	0.091
108479	M8	318.3	0.011
108479	MS4	291.7	0.033
108480	M2	230	1.419
108480	S2	256.8	0.237
108480	N2	208.4	0.348
108480	K1	214.3	0.687
108480	M4	337.6	0.062
108480	O1	207	0.461
108480	M6	194.2	0.052
108480	MK3	313.2	0.048
108480	S4	180.6	0.014
108480	MN4	306.4	0.044
108480	S6	71.2	0.009
108480	2N2	72.7	0.103
108480	OO1	228.2	0.093
108480	M1	70.2	0.055
108480	J1	181.6	0.02
108480	Q1	213.6	0.087
108480	2Q1	30.1	0.024
108480	P1	208.7	0.154
108480	2SM2	74.6	0.024
108480	M3	119.8	0.016
108480	L2	244.6	0.11
108480	2MK3	65.9	0.124
108480	K2	258.7	0.096
108480	M8	57.3	0.028
108480	MS4	81.9	0.094
108481	M2	236.5	1.688
108481	S2	255.9	0.249
108481	N2	215.5	0.402
108481	K1	216.2	0.687
108481	M4	340	0.043
108481	O1	209.9	0.358
108481	M6	135.3	0.024
108481	MK3	109	0.095
108481	S4	287.5	0.009
108481	MN4	304.3	0.02
108481	S6	84.9	0.006
108481	2N2	77.5	0.113
108481	OO1	226.1	0.09
108481	M1	68.7	0.041
108481	J1	217.2	0.016
108481	Q1	212.6	0.072
108481	2Q1	291.7	0.027
108481	P1	209.8	0.192
108481	2SM2	143	0.012
108481	M3	175	0.024
108481	L2	258.1	0.133
108481	2MK3	87.2	0.175
108481	K2	249.7	0.113
108481	M8	107	0.022
108481	MS4	104.4	0.073
108482	M2	240.8	1.788
108482	S2	255.6	0.254
108482	N2	218.1	0.405
108482	K1	215.5	0.66
108482	M4	8.8	0.036
108482	O1	209.3	0.307
108482	M6	119.7	0.028
108482	MK3	118.1	0.172
108482	S4	23.6	0.01
108482	MN4	298.4	0.024
108482	S6	206.3	0.003
108482	2N2	85.4	0.107
108482	OO1	235.8	0.081
108482	M1	71.6	0.03
108482	J1	251.4	0.014
108482	Q1	197	0.052
108482	2Q1	265.4	0.042
108482	P1	216.2	0.213
108482	2SM2	167	0.017
108482	M3	192.7	0.05
108482	L2	266.2	0.145
108482	2MK3	104.1	0.196
108482	K2	247.8	0.119
108482	M8	189.2	0.023
108482	MS4	130.3	0.047
108483	M2	235.3	1.682
108483	S2	248.3	0.315
108483	N2	213.1	0.324
108483	K1	214	0.686
108483	M4	73.4	0.078
108483	O1	203	0.362
108483	M6	151.1	0.05
108483	MK3	87.3	0.149
108483	S4	233.9	0.009
108483	MN4	38.9	0.036
108483	NU2	213.6	0.091
108483	S6	335.4	0.007
108483	MU2	37.2	0.089
108483	2N2	138.2	0.036
108483	OO1	293.7	0.032
108483	LDA2	259.4	0.035
108483	M1	53.1	0.028
108483	J1	284.8	0.012
108483	RHO1	244.7	0.027
108483	Q1	189.9	0.034
108483	2Q1	240.3	0.045
108483	P1	209.3	0.213
108483	2SM2	161.4	0.016
108483	M3	159.8	0.047
108483	L2	261.9	0.098
108483	2MK3	73.2	0.182
108483	K2	228.6	0.143
108483	M8	112.8	0.009
108483	MS4	93.5	0.063
108484	M2	239.7	1.977
108484	S2	248.4	0.345
108484	N2	215.6	0.361
108484	K1	216.8	0.768
108484	M4	90.3	0.116
108484	O1	205.7	0.402
108484	M6	209.3	0.051
108484	MK3	100.6	0.161
108484	S4	152.6	0.007
108484	MN4	45.1	0.041
108484	NU2	225.9	0.108
108484	S6	307.8	0.005
108484	MU2	61.5	0.111
108484	2N2	139	0.047
108484	OO1	288.7	0.043
108484	LDA2	242.1	0.042
108484	M1	73	0.042
108484	J1	290	0.005
108484	RHO1	237.4	0.021
108484	Q1	180.7	0.039
108484	2Q1	255.1	0.048
108484	P1	207.9	0.234
108484	2SM2	139.5	0.017
108484	M3	184.4	0.052
108484	L2	278.4	0.124
108484	2MK3	92.1	0.195
108484	K2	235.4	0.194
108484	M8	102.9	0.004
108484	MS4	104.5	0.078
108485	M2	242.4	2.205
108485	S2	250.5	0.35
108485	N2	214.6	0.393
108485	K1	217.5	0.793
108485	M4	98.5	0.123
108485	O1	209.1	0.395
108485	M6	229.8	0.075
108485	MK3	126.9	0.206
108485	S4	90.7	0.004
108485	MN4	43.5	0.041
108485	NU2	232.9	0.111
108485	MU2	74.1	0.154
108485	2N2	146.3	0.049
108485	OO1	280.9	0.059
108485	LDA2	228.7	0.059
108485	M1	65.4	0.048
108485	J1	307.3	0.01
108485	RHO1	154.2	0.013
108485	Q1	206.6	0.048
108485	2Q1	251.2	0.044
108485	P1	211.8	0.246
108485	2SM2	123.6	0.02
108485	M3	204.6	0.075
108485	L2	288.1	0.156
108485	2MK3	110.5	0.248
108485	K2	244.3	0.201
108485	M8	111.5	0.008
108485	MS4	107	0.082
108486	M2	243.6	0.987
108486	S2	263.9	0.261
108486	N2	207.2	0.218
108486	K1	217.9	0.512
108486	M4	220.1	0.117
108486	O1	188.2	0.292
108486	M6	86.6	0.024
108486	MK3	224.6	0.047
108486	S4	345.7	0.006
108486	MN4	198.5	0.057
108486	S6	201.5	0.005
108486	2N2	70.6	0.027
108486	OO1	10.4	0.029
108486	M1	72.6	0.038
108486	J1	285.6	0.017
108486	Q1	171	0.031
108486	2Q1	178.5	0.027
108486	P1	216.4	0.111
108486	2SM2	154.4	0.017
108486	M3	319.8	0.017
108486	L2	299	0.024
108486	2MK3	314.5	0.018
108486	K2	212.9	0.035
108486	M8	158.7	0.024
108486	MS4	238.9	0.084
108487	M2	232	0.877
108487	S2	260.3	0.179
108487	N2	195.6	0.177
108487	K1	221.8	0.467
108487	M4	320.3	0.156
108487	O1	200.3	0.338
108487	M6	137.2	0.071
108487	MK3	329	0.055
108487	S4	38.2	0.013
108487	MN4	277.7	0.057
108487	S6	229.1	0.002
108487	2N2	274.1	0.02
108487	OO1	310.4	0.028
108487	M1	141.3	0.015
108487	J1	282.2	0.022
108487	Q1	176.8	0.05
108487	2Q1	215.3	0.024
108487	P1	223.1	0.103
108487	2SM2	56.1	0.013
108487	M3	37.9	0.018
108487	L2	249.4	0.044
108487	2MK3	336.3	0.075
108487	K2	193.3	0.075
108487	M8	260.9	0.039
108487	MS4	343.5	0.099
108488	M2	234.4	1.076
108488	S2	243.5	0.181
108488	N2	192.7	0.196
108488	K1	221.7	0.468
108488	M4	12.7	0.204
108488	O1	204.6	0.365
108488	M6	203.9	0.056
108488	MK3	18	0.077
108488	S4	62	0.024
108488	MN4	329.1	0.093
108488	2N2	305.6	0.047
108488	OO1	337.6	0.02
108488	M1	160	0.038
108488	J1	184.8	0.02
108488	Q1	176.7	0.064
108488	2Q1	249.5	0.018
108488	P1	202.2	0.114
108488	2SM2	71.3	0.03
108488	M3	145.9	0.033
108488	L2	282.2	0.089
108488	2MK3	35.6	0.093
108488	K2	218.8	0.093
108488	M8	17.5	0.011
108488	MS4	33.4	0.129
108489	M2	246.5	0.771
108489	S2	242.7	0.147
108489	N2	211.9	0.148
108489	K1	225.7	0.295
108489	M4	159.1	0.089
108489	O1	210.2	0.165
108489	M6	194.9	0.014
108489	MK3	158.5	0.073
108489	S4	143.5	0.008
108489	MN4	98.6	0.032
108489	S6	218.7	0.003
108489	2N2	0	0.019
108489	OO1	347.8	0.01
108489	M1	108.7	0.011
108489	J1	203.9	0.011
108489	Q1	223	0.024
108489	2Q1	227.8	0.013
108489	P1	219.6	0.071
108489	2SM2	83.7	0.014
108489	M3	202.9	0.027
108489	L2	303	0.06
108489	2MK3	111.4	0.085
108489	K2	280.9	0.1
108489	M8	165.4	0.009
108489	MS4	141.1	0.047
108490	M2	255.6	0.993
108490	S2	260.6	0.209
108490	N2	216.2	0.173
108490	K1	222.8	0.429
108490	M4	43.6	0.04
108490	O1	218.7	0.297
108490	M6	188.5	0.024
108490	MK3	106.5	0.046
108490	S4	170.4	0.018
108490	MN4	67.8	0.021
108490	S6	35.6	0.002
108490	2N2	41	0.031
108490	OO1	40.9	0.049
108490	M1	116.5	0.031
108490	J1	243	0.012
108490	Q1	173.7	0.037
108490	2Q1	250.8	0.031
108490	P1	201.4	0.139
108490	2SM2	97.6	0.027
108490	M3	142.4	0.031
108490	L2	308.3	0.072
108490	2MK3	82.1	0.097
108490	K2	288.5	0.124
108490	M8	351.9	0.006
108490	MS4	87.1	0.047
108491	M2	260.8	1.279
108491	S2	264.5	0.249
108491	N2	219.2	0.228
108491	K1	226	0.506
108491	M4	127.1	0.061
108491	O1	217.8	0.3
108491	M6	182.2	0.022
108491	MK3	152.8	0.105
108491	S4	165.9	0.012
108491	MN4	93.4	0.031
108491	S6	63.3	0.007
108491	2N2	5.7	0.053
108491	OO1	26.4	0.053
108491	M1	105.3	0.027
108491	J1	239.6	0.009
108491	Q1	198.3	0.037
108491	2Q1	215.4	0.027
108491	P1	211.1	0.146
108491	2SM2	98.9	0.019
108491	M3	193.1	0.043
108491	L2	316.4	0.106
108491	2MK3	115.8	0.126
108491	K2	286.8	0.113
108491	M8	225.1	0.006
108491	MS4	133.4	0.054
108492	M2	263.1	1.372
108492	S2	271.4	0.25
108492	N2	221.9	0.249
108492	K1	224.6	0.521
108492	M4	103.4	0.053
108492	O1	216.4	0.324
108492	M6	85.6	0.011
108492	MK3	168.2	0.091
108492	S4	117	0.013
108492	MN4	56.2	0.026
108492	S6	43.3	0.006
108492	2N2	3.8	0.068
108492	OO1	22.5	0.062
108492	M1	112.1	0.037
108492	J1	106	0.007
108492	Q1	209.3	0.043
108492	2Q1	239.4	0.036
108492	P1	205.4	0.155
108492	2SM2	81.5	0.013
108492	M3	207.8	0.051
108492	L2	320	0.115
108492	2MK3	124	0.139
108492	K2	273.9	0.098
108492	M8	144.3	0.022
108492	MS4	122.7	0.059
108493	M2	265.9	1.027
108493	S2	269.4	0.173
108493	N2	225.7	0.196
108493	K1	229.2	0.393
108493	M4	229.1	0.044
108493	O1	220.8	0.219
108493	M6	232.4	0.046
108493	MK3	194	0.141
108493	S4	301.3	0.005
108493	MN4	214.4	0.023
108493	S6	321.3	0.004
108493	2N2	330.5	0.065
108493	OO1	1.5	0.062
108493	M1	322.8	0.009
108493	J1	312.3	0.015
108493	Q1	201.9	0.023
108493	2Q1	215.9	0.023
108493	P1	223.5	0.107
108493	2SM2	169	0.015
108493	M3	200.6	0.034
108493	L2	317.7	0.085
108493	2MK3	131.2	0.115
108493	K2	292.7	0.096
108493	M8	329.3	0.022
108493	MS4	180.4	0.003
108494	M2	268.5	1.309
108494	S2	267.2	0.229
108494	N2	229.4	0.244
108494	K1	230	0.495
108494	M4	221.3	0.043
108494	O1	224.4	0.295
108494	M6	270.2	0.058
108494	MK3	209.7	0.152
108494	S4	353.9	0.007
108494	MN4	193.8	0.017
108494	S6	254.4	0.007
108494	2N2	347	0.087
108494	OO1	5.7	0.078
108494	M1	28.8	0.003
108494	J1	288.4	0.014
108494	Q1	210.3	0.026
108494	2Q1	256	0.031
108494	P1	216.1	0.126
108494	2SM2	135.3	0.015
108494	M3	221.4	0.037
108494	L2	324.7	0.116
108494	2MK3	140.5	0.135
108494	K2	302.5	0.116
108494	M8	324	0.019
108494	MS4	106.7	0.031
108495	M2	270.1	1.389
108495	S2	273.1	0.245
108495	N2	230.9	0.263
108495	K1	232.8	0.532
108495	M4	174.6	0.035
108495	O1	223.9	0.304
108495	M6	327.2	0.028
108495	MK3	207	0.128
108495	S4	85	0.012
108495	MN4	156.5	0.011
108495	2N2	0.8	0.08
108495	OO1	359.4	0.076
108495	M1	54.4	0.028
108495	J1	285.3	0.014
108495	Q1	220.3	0.04
108495	2Q1	261.6	0.049
108495	P1	202.3	0.123
108495	2SM2	125.6	0.018
108495	M3	253.4	0.033
108495	L2	326.6	0.118
108495	2MK3	148.5	0.125
108495	K2	296.5	0.121
108495	M8	245.6	0.018
108495	MS4	140.7	0.04
108496	M2	275.6	1.196
108496	S2	290.1	0.199
108496	N2	233.9	0.226
108496	K1	237	0.496
108496	M4	151.4	0.034
108496	O1	222.5	0.297
108496	M6	262.5	0.053
108496	MK3	171.5	0.097
108496	S4	188.6	0.011
108496	MN4	138.5	0.011
108496	S6	352.4	0.004
108496	2N2	338.7	0.054
108496	OO1	352.5	0.037
108496	M1	115.4	0.023
108496	J1	311.5	0.014
108496	Q1	204.7	0.048
108496	2Q1	230	0.029
108496	P1	230.8	0.141
108496	2SM2	126.4	0.011
108496	M3	219.5	0.042
108496	L2	318.4	0.099
108496	2MK3	127.3	0.121
108496	K2	274.5	0.091
108496	M8	210.3	0.005
108496	MS4	122.9	0.017
108497	M2	276.8	1.535
108497	S2	290.5	0.28
108497	N2	235.7	0.284
108497	K1	236.3	0.589
108497	M4	179.8	0.037
108497	O1	222.2	0.362
108497	M6	288	0.057
108497	MK3	191.5	0.137
108497	S4	167.3	0.009
108497	MN4	148.4	0.014
108497	S6	302.5	0.005
108497	2N2	340.7	0.077
108497	OO1	344.6	0.047
108497	M1	106.9	0.034
108497	J1	355.3	0.013
108497	Q1	206.8	0.059
108497	2Q1	246	0.044
108497	P1	219	0.157
108497	2SM2	145.7	0.015
108497	M3	229.8	0.069
108497	L2	321.1	0.13
108497	2MK3	139.4	0.183
108497	K2	288	0.09
108497	M8	161	0.003
108497	MS4	125.6	0.033
108498	M2	278.7	1.763
108498	S2	290.5	0.32
108498	N2	238.6	0.332
108498	K1	235.9	0.646
108498	M4	237.4	0.016
108498	O1	223.3	0.388
108498	M6	320.9	0.044
108498	MK3	208.5	0.144
108498	S4	122	0.011
108498	MN4	214	0.012
108498	S6	51.5	0.006
108498	2N2	343.8	0.087
108498	OO1	1.8	0.052
108498	M1	104.8	0.051
108498	J1	1.4	0.011
108498	Q1	207.3	0.057
108498	2Q1	240.8	0.057
108498	P1	215.4	0.166
108498	2SM2	150	0.017
108498	M3	235	0.069
108498	L2	329	0.145
108498	2MK3	149.3	0.207
108498	K2	303.1	0.123
108498	M8	144.2	0.007
108498	MS4	121.3	0.059
108499	M2	278.2	1.106
108499	S2	291.4	0.198
108499	N2	237.3	0.192
108499	K1	237.6	0.465
108499	M4	97.4	0.031
108499	O1	222.8	0.308
108499	M6	296.3	0.052
108499	MK3	159.3	0.078
108499	S4	177.2	0.006
108499	MN4	62.6	0.004
108499	2N2	357.2	0.057
108499	OO1	10.1	0.035
108499	M1	115.8	0.027
108499	J1	311.2	0.016
108499	Q1	194.5	0.039
108499	2Q1	247	0.029
108499	P1	228	0.139
108499	2SM2	118.7	0.013
108499	M3	200.5	0.048
108499	L2	320.3	0.098
108499	2MK3	119.9	0.122
108499	K2	289.1	0.077
108499	M8	322.2	0.002
108499	MS4	123.1	0.045
108500	M2	277.5	1.3
108500	S2	292	0.221
108500	N2	235.1	0.236
108500	K1	236.8	0.51
108500	M4	127.3	0.035
108500	O1	221.3	0.331
108500	M6	295.1	0.064
108500	MK3	173.1	0.106
108500	S4	213.5	0.006
108500	MN4	95.4	0.007
108500	2N2	348.4	0.076
108500	OO1	359.8	0.04
108500	M1	115.3	0.029
108500	J1	301.8	0.016
108500	Q1	197.4	0.044
108500	2Q1	232.6	0.03
108500	P1	224.1	0.145
108500	2SM2	118.4	0.022
108500	M3	212.6	0.061
108500	L2	322.1	0.115
108500	2MK3	128.9	0.152
108500	K2	279.6	0.091
108500	M8	254.8	0.009
108500	MS4	116.7	0.042
108501	M2	277.1	1.376
108501	S2	292.1	0.232
108501	N2	234.4	0.255
108501	K1	235.5	0.524
108501	M4	152.2	0.044
108501	O1	221	0.335
108501	M6	286.7	0.068
108501	MK3	180.7	0.121
108501	S4	263.7	0.007
108501	MN4	114.7	0.013
108501	S6	211.8	0.003
108501	2N2	346.6	0.083
108501	OO1	0.9	0.048
108501	M1	105.8	0.025
108501	J1	282	0.015
108501	Q1	200.7	0.047
108501	2Q1	217.9	0.033
108501	P1	218.6	0.15
108501	2SM2	116.6	0.026
108501	M3	220.6	0.072
108501	L2	321.5	0.127
108501	2MK3	133.9	0.169
108501	K2	282.5	0.094
108501	M8	254.7	0.018
108501	MS4	122.9	0.037
108502	M2	289.6	0.941
108502	S2	309.7	0.156
108502	N2	249.7	0.168
108502	K1	240.4	0.378
108502	M4	102	0.015
108502	O1	226.9	0.228
108502	M6	338.6	0.038
108502	MK3	189.6	0.07
108502	S4	208.3	0.006
108502	MN4	30.7	0.009
108502	2N2	353.8	0.04
108502	OO1	23	0.034
108502	M1	122.2	0.029
108502	J1	342.6	0.003
108502	Q1	204.7	0.028
108502	2Q1	246.9	0.032
108502	P1	229.1	0.104
108502	2SM2	143.8	0.008
108502	M3	232	0.035
108502	L2	338.5	0.079
108502	2MK3	141	0.098
108502	K2	281.1	0.073
108502	M8	112.3	0.003
108502	MS4	140	0.039
108503	M2	291.9	1.389
108503	S2	311.2	0.234
108503	N2	250.5	0.248
108503	K1	244.4	0.564
108503	M4	115.8	0.04
108503	O1	228.1	0.347
108503	M6	351.8	0.052
108503	MK3	191.1	0.096
108503	S4	191.4	0.007
108503	MN4	40.4	0.013
108503	S6	43	0.003
108503	2N2	3.6	0.07
108503	OO1	9.9	0.056
108503	M1	119.5	0.037
108503	J1	304.3	0.008
108503	Q1	207.2	0.046
108503	2Q1	240.4	0.041
108503	P1	230.9	0.149
108503	2SM2	140.5	0.015
108503	M3	241.5	0.057
108503	L2	342.2	0.12
108503	2MK3	146.1	0.141
108503	K2	286	0.102
108503	M8	71.5	0.003
108503	MS4	143.8	0.056
108504	M2	292.3	1.479
108504	S2	310	0.254
108504	N2	251.1	0.268
108504	K1	245	0.606
108504	M4	166.4	0.032
108504	O1	228.6	0.374
108504	M6	344.2	0.048
108504	MK3	204.3	0.113
108504	S4	218.8	0.004
108504	MN4	107.1	0.007
108504	2N2	6.8	0.075
108504	OO1	14	0.064
108504	M1	118.6	0.034
108504	J1	302.2	0.014
108504	Q1	210.7	0.05
108504	2Q1	238.4	0.036
108504	P1	233.6	0.159
108504	2SM2	140.9	0.022
108504	M3	250.5	0.058
108504	L2	343.4	0.126
108504	2MK3	152.6	0.15
108504	K2	291.2	0.109
108504	MS4	150.1	0.041
108505	M2	297.2	0.996
108505	S2	313.3	0.188
108505	N2	256.2	0.172
108505	K1	248	0.426
108505	M4	124.3	0.037
108505	O1	234	0.277
108505	M6	357.6	0.022
108505	MK3	190.4	0.053
108505	S4	212	0.002
108505	MN4	74.7	0.012
108505	2N2	6.2	0.046
108505	OO1	27.7	0.029
108505	M1	118.2	0.027
108505	J1	317.3	0.007
108505	Q1	209.1	0.038
108505	2Q1	246.9	0.028
108505	P1	239.6	0.115
108505	2SM2	136.1	0.012
108505	M3	242.6	0.034
108505	L2	344.4	0.088
108505	2MK3	151.1	0.104
108505	K2	300.7	0.069
108505	M8	142.9	0.004
108505	MS4	150.7	0.039
108506	M2	296.7	1.2
108506	S2	310.7	0.214
108506	N2	255.2	0.212
108506	K1	248.2	0.502
108506	M4	107.3	0.023
108506	O1	232.5	0.333
108506	M6	0	0.04
108506	MK3	204.9	0.075
108506	S4	225.2	0.002
108506	MN4	48	0.012
108506	2N2	8	0.06
108506	OO1	20.8	0.038
108506	M1	118.9	0.031
108506	J1	317.1	0.011
108506	Q1	206.1	0.044
108506	2Q1	248.7	0.035
108506	P1	238.2	0.13
108506	2SM2	137.6	0.019
108506	M3	246.6	0.041
108506	L2	344.1	0.101
108506	2MK3	156	0.124
108506	K2	300	0.099
108506	M8	76.6	0.007
108506	MS4	146.6	0.038
108507	M2	296	1.275
108507	S2	309.8	0.222
108507	N2	255.6	0.229
108507	K1	247.7	0.534
108507	M4	133.6	0.015
108507	O1	230.8	0.352
108507	M6	357.6	0.043
108507	MK3	206.6	0.092
108507	S4	244.8	0.002
108507	MN4	58.6	0.011
108507	2N2	8.3	0.065
108507	OO1	16.4	0.047
108507	M1	117.8	0.033
108507	J1	326.9	0.011
108507	Q1	209	0.044
108507	2Q1	247.9	0.038
108507	P1	237	0.137
108507	2SM2	141.1	0.022
108507	M3	247.5	0.044
108507	L2	344.9	0.107
108507	2MK3	157.7	0.133
108507	K2	300.9	0.108
108507	M8	84.2	0.004
108507	MS4	152.6	0.041
108508	M2	295.9	0.911
108508	S2	314	0.15
108508	N2	255.8	0.157
108508	K1	248.9	0.36
108508	M4	171.9	0.023
108508	O1	233.4	0.234
108508	M6	342.3	0.031
108508	MK3	205.2	0.068
108508	S4	243	0.003
108508	MN4	103.9	0.008
108508	S6	153.2	0.003
108508	2N2	1	0.044
108508	OO1	19.5	0.033
108508	M1	111.3	0.018
108508	J1	327.5	0.007
108508	Q1	222.6	0.034
108508	2Q1	240.3	0.023
108508	P1	241.6	0.085
108508	2SM2	154.1	0.015
108508	M3	244.4	0.033
108508	L2	344.4	0.072
108508	2MK3	151.7	0.106
108508	K2	294.6	0.094
108508	M8	178.4	0.002
108508	MS4	164.7	0.027
108509	M2	295.8	1.114
108509	S2	314.1	0.181
108509	N2	254.2	0.194
108509	K1	248.4	0.442
108509	M4	189.1	0.028
108509	O1	232.5	0.274
108509	M6	352.5	0.04
108509	MK3	210.2	0.095
108509	S4	253.6	0.003
108509	MN4	121.2	0.007
108509	S6	158.8	0.003
108509	2N2	3	0.056
108509	OO1	16.8	0.046
108509	M1	110.6	0.021
108509	J1	315	0.008
108509	Q1	220.9	0.037
108509	2Q1	231.5	0.029
108509	P1	241.5	0.109
108509	2SM2	154.8	0.02
108509	M3	250.4	0.041
108509	L2	345.1	0.087
108509	2MK3	156.9	0.134
108509	K2	300.2	0.115
108509	M8	113.8	0.005
108509	MS4	175.2	0.028
108510	M2	296.3	1.195
108510	S2	313.8	0.195
108510	N2	253.8	0.209
108510	K1	249.1	0.48
108510	M4	179.4	0.027
108510	O1	231.8	0.285
108510	M6	3	0.046
108510	MK3	214.4	0.101
108510	S4	256.9	0.003
108510	MN4	101.2	0.009
108510	S6	150.7	0.002
108510	2N2	2.1	0.061
108510	OO1	18.1	0.047
108510	M1	108.3	0.023
108510	J1	321	0.007
108510	Q1	221.5	0.039
108510	2Q1	232.3	0.032
108510	P1	241.8	0.118
108510	2SM2	153.4	0.022
108510	M3	253.6	0.041
108510	L2	346.8	0.095
108510	2MK3	158.6	0.139
108510	K2	302.7	0.121
108510	M8	102.4	0.009
108510	MS4	170	0.029
108511	M2	280.6	1.025
108511	S2	304.6	0.178
108511	N2	243	0.178
108511	K1	242.7	0.451
108511	M4	48.3	0.061
108511	O1	222.5	0.289
108511	M6	323.8	0.025
108511	MK3	186.8	0.029
108511	S4	112.5	0.009
108511	MN4	349.8	0.022
108511	S6	86.2	0.006
108511	2N2	337	0.033
108511	OO1	17.3	0.03
108511	M1	112.9	0.033
108511	J1	349.3	0.009
108511	Q1	198.4	0.042
108511	2Q1	251.9	0.032
108511	P1	239.9	0.104
108511	2SM2	147.2	0.013
108511	M3	207.5	0.024
108511	L2	319.9	0.074
108511	2MK3	118.7	0.101
108511	K2	280.7	0.077
108511	M8	121.6	0.011
108511	MS4	108.7	0.053
108512	M2	283	1.353
108512	S2	301.4	0.233
108512	N2	243.2	0.254
108512	K1	240.1	0.552
108512	M4	102.2	0.058
108512	O1	222.1	0.356
108512	M6	335.5	0.05
108512	MK3	190.9	0.077
108512	S4	171.1	0.009
108512	MN4	51.4	0.022
108512	S6	80.2	0.004
108512	2N2	357.6	0.062
108512	OO1	12	0.054
108512	M1	114.5	0.031
108512	J1	304.3	0.005
108512	Q1	199.4	0.052
108512	2Q1	238.8	0.032
108512	P1	234	0.137
108512	2SM2	142.8	0.016
108512	M3	239.3	0.042
108512	L2	329.7	0.105
108512	2MK3	133.3	0.128
108512	K2	273.7	0.106
108512	M8	96.5	0.007
108512	MS4	114.9	0.057
108513	M2	284.3	1.402
108513	S2	303.1	0.241
108513	N2	242.8	0.263
108513	K1	239.8	0.575
108513	M4	120.4	0.058
108513	O1	220.4	0.365
108513	M6	333.5	0.044
108513	MK3	193.3	0.091
108513	S4	181.7	0.011
108513	MN4	60.4	0.028
108513	S6	101.7	0.004
108513	2N2	1.9	0.076
108513	OO1	12.7	0.052
108513	M1	112.5	0.032
108513	J1	273	0.006
108513	Q1	206.5	0.055
108513	2Q1	226.9	0.028
108513	P1	233	0.142
108513	2SM2	131.5	0.015
108513	M3	250.4	0.05
108513	L2	331.8	0.113
108513	2MK3	140.7	0.129
108513	K2	268.8	0.125
108513	MS4	119.2	0.053
108514	M2	282	0.887
108514	S2	300.9	0.161
108514	N2	243.8	0.155
108514	K1	243.7	0.338
108514	M4	137	0.019
108514	O1	226	0.212
108514	M6	292.2	0.019
108514	MK3	188.2	0.064
108514	S4	251.4	0.003
108514	MN4	101.3	0.004
108514	S6	111.1	0.002
108514	2N2	341	0.046
108514	OO1	33	0.034
108514	M1	111	0.014
108514	J1	308.3	0.007
108514	Q1	207.9	0.028
108514	2Q1	232.1	0.022
108514	P1	229.5	0.089
108514	2SM2	136.1	0.018
108514	M3	228	0.032
108514	L2	330.5	0.069
108514	2MK3	130.6	0.1
108514	K2	287.5	0.067
108514	M8	173.9	0.007
108514	MS4	126.6	0.014
108515	M2	281.9	1.218
108515	S2	298.7	0.2
108515	N2	242	0.217
108515	K1	243.4	0.448
108515	M4	179.5	0.031
108515	O1	225.5	0.287
108515	M6	331.1	0.049
108515	MK3	188	0.113
108515	S4	216.3	0.006
108515	MN4	130.7	0.004
108515	S6	102	0.003
108515	2N2	341.5	0.065
108515	OO1	18.3	0.055
108515	M1	106.5	0.023
108515	J1	307	0.006
108515	Q1	210.3	0.039
108515	2Q1	245.2	0.027
108515	P1	233.4	0.111
108515	2SM2	145.1	0.021
108515	M3	231.5	0.054
108515	L2	328.4	0.096
108515	2MK3	135.7	0.149
108515	K2	281.8	0.107
108515	M8	190.4	0.006
108515	MS4	156.2	0.033
108516	M2	283.5	1.331
108516	S2	301.3	0.214
108516	N2	242.3	0.245
108516	K1	244.8	0.487
108516	M4	153	0.034
108516	O1	224.1	0.322
108516	M6	353.9	0.058
108516	MK3	191.2	0.115
108516	S4	168.9	0.006
108516	MN4	30.6	0.016
108516	S6	80	0.005
108516	2N2	347.1	0.078
108516	OO1	18.3	0.053
108516	M1	101.5	0.035
108516	J1	348.2	0.011
108516	Q1	202.6	0.047
108516	2Q1	250.4	0.039
108516	P1	235.8	0.109
108516	2SM2	146.9	0.017
108516	M3	234.4	0.061
108516	L2	330.3	0.109
108516	2MK3	141.3	0.159
108516	K2	279.9	0.124
108516	M8	177.5	0.006
108516	MS4	146.9	0.056
108517	M2	289.6	0.747
108517	S2	310	0.104
108517	N2	251.8	0.133
108517	K1	246.6	0.26
108517	M4	190.8	0.025
108517	O1	231.5	0.169
108517	M6	331.5	0.025
108517	MK3	205.9	0.063
108517	S4	205.9	0.004
108517	MN4	178	0.006
108517	S6	115.5	0.002
108517	2N2	348	0.034
108517	OO1	22.9	0.032
108517	M1	121.4	0.013
108517	J1	328.5	0.004
108517	Q1	214.2	0.022
108517	2Q1	241	0.02
108517	P1	236.4	0.059
108517	2SM2	153.3	0.015
108517	M3	240.2	0.026
108517	L2	336.2	0.062
108517	2MK3	148.5	0.095
108517	K2	280.3	0.082
108517	M8	266.8	0.005
108517	MS4	172.9	0.016
108518	M2	288.2	0.985
108518	S2	308.7	0.152
108518	N2	249.7	0.178
108518	K1	242.6	0.329
108518	M4	237.4	0.025
108518	O1	227.9	0.211
108518	M6	341.3	0.04
108518	MK3	210.4	0.098
108518	S4	229	0.004
108518	MN4	251.3	0.004
108518	S6	158.5	0.003
108518	2N2	348.5	0.049
108518	OO1	7.2	0.042
108518	M1	98.9	0.017
108518	J1	303.3	0.006
108518	Q1	212.9	0.025
108518	2Q1	237.5	0.022
108518	P1	232.9	0.078
108518	2SM2	148.6	0.018
108518	M3	249.6	0.04
108518	L2	335.4	0.08
108518	2MK3	156.6	0.125
108518	K2	278.1	0.091
108518	M8	322.1	0.005
108518	MS4	187.5	0.011
108519	M2	287.8	1.082
108519	S2	306.8	0.169
108519	N2	248.6	0.198
108519	K1	239.3	0.366
108519	M4	269.8	0.02
108519	O1	224.1	0.226
108519	M6	352.6	0.042
108519	MK3	213.5	0.104
108519	S4	221.3	0.005
108519	MN4	339	0.008
108519	S6	165.8	0.003
108519	2N2	350	0.056
108519	OO1	11.6	0.045
108519	M1	95.9	0.02
108519	J1	275.4	0.012
108519	Q1	198.3	0.029
108519	2Q1	234.7	0.026
108519	P1	224.9	0.096
108519	2SM2	137.6	0.024
108519	M3	256.1	0.043
108519	L2	336.7	0.087
108519	2MK3	162.4	0.13
108519	K2	280.2	0.098
108519	M8	26.2	0.004
108519	MS4	192.3	0.013
108520	M2	281.6	1.383
108520	S2	300.4	0.329
108520	N2	273.5	0.344
108520	K1	80.7	0.116
108520	M4	195.2	0.102
108520	O1	88.7	0.046
108520	M6	285.6	0.122
108520	MK3	351.4	0.025
108520	S4	252.4	0.043
108520	MN4	191.7	0.048
108520	S6	123.8	0.006
108520	2N2	330.8	0.037
108520	OO1	123.2	0.013
108520	M1	125.4	0.019
108520	J1	39.7	0.013
108520	Q1	116.4	0.01
108520	2Q1	191.7	0.01
108520	2SM2	315.2	0.007
108520	M3	358.4	0.029
108520	L2	269.1	0.038
108520	2MK3	310	0.019
108520	M8	221.3	0.03
108520	MS4	174.9	0.029
108521	M2	281.7	1.707
108521	S2	300.5	0.395
108521	N2	273.7	0.408
108521	K1	79.9	0.144
108521	M4	192.6	0.124
108521	O1	82.1	0.058
108521	M6	288.1	0.154
108521	MK3	354.4	0.029
108521	S4	251	0.05
108521	MN4	188.6	0.06
108521	S6	117.9	0.009
108521	2N2	339.8	0.029
108521	OO1	139.4	0.01
108521	M1	133.5	0.019
108521	J1	29.9	0.017
108521	Q1	125.5	0.01
108521	2Q1	184.7	0.01
108521	2SM2	204.7	0.005
108521	M3	353.6	0.038
108521	L2	267.3	0.06
108521	2MK3	301.3	0.026
108521	M8	220.3	0.038
108521	MS4	178.5	0.038
108522	M2	41.8	0.876
108522	S2	71.7	0.162
108522	N2	12.4	0.212
108522	K1	214	0.144
108522	M4	195.5	0.09
108522	O1	234	0.11
108522	M6	235	0.136
108522	MK3	3.9	0.024
108522	S4	164	0.012
108522	MN4	179.6	0.052
108522	S6	142.7	0.006
108522	2N2	24.7	0.017
108522	OO1	220.5	0.016
108522	M1	248.1	0.031
108522	J1	286.7	0.014
108522	Q1	236.3	0.033
108522	2Q1	246.1	0.006
108522	P1	253.6	0.048
108522	2SM2	25.5	0.011
108522	M3	330.1	0.022
108522	L2	53.5	0.049
108522	2MK3	244.3	0.006
108522	K2	69.9	0.089
108522	M8	10.5	0.022
108522	MS4	209.3	0.021
108523	M2	39	1.434
108523	S2	63.6	0.203
108523	N2	8.5	0.297
108523	K1	188.2	0.099
108523	M4	312.3	0.179
108523	O1	196	0.069
108523	M6	8.1	0.063
108523	MK3	108.1	0.081
108523	S4	270.2	0.007
108523	MN4	289.1	0.083
108523	S6	356.5	0.009
108523	2N2	356.8	0.022
108523	OO1	140.4	0.01
108523	M1	227.7	0.004
108523	J1	86.6	0.012
108523	Q1	213.9	0.035
108523	2Q1	81.6	0.012
108523	P1	155.3	0.048
108523	2SM2	284.4	0.013
108523	M3	182.5	0.046
108523	L2	66.8	0.143
108523	2MK3	101.2	0.078
108523	K2	37.4	0.065
108523	M8	286.2	0.032
108523	MS4	322.9	0.022
108524	M2	48.1	1.391
108524	S2	67.7	0.148
108524	N2	10.9	0.244
108524	K1	202.7	0.132
108524	M4	42.4	0.04
108524	O1	207.4	0.13
108524	M6	8.7	0.129
108524	MK3	163.5	0.052
108524	S4	326.5	0.012
108524	MN4	33.3	0.011
108524	S6	176.5	0.003
108524	2N2	175.9	0.029
108524	OO1	162.8	0.014
108524	M1	17.3	0.016
108524	J1	86.6	0.032
108524	Q1	176.7	0.039
108524	2Q1	29	0.007
108524	P1	138.4	0.023
108524	2SM2	175.6	0.005
108524	M3	145.5	0.061
108524	L2	75.6	0.2
108524	2MK3	112.8	0.075
108524	K2	65.2	0.053
108524	M8	45.5	0.03
108524	MS4	209.2	0.027
108525	M2	65.9	1.106
108525	S2	92.3	0.127
108525	N2	38.6	0.223
108525	K1	212.5	0.098
108525	M4	344	0.054
108525	O1	210.3	0.063
108525	M6	30.2	0.053
108525	MK3	83.5	0.016
108525	S4	13.6	0.01
108525	MN4	293.2	0.031
108525	S6	150.3	0.002
108525	2N2	39.8	0.013
108525	OO1	234.8	0.011
108525	M1	347.6	0.009
108525	J1	160.7	0.008
108525	Q1	233.6	0.016
108525	2Q1	289.3	0.002
108525	P1	196.1	0.062
108525	2SM2	301.1	0.014
108525	M3	256.4	0.007
108525	L2	78.7	0.098
108525	2MK3	127.3	0.02
108525	K2	100.5	0.039
108525	M8	2	0.021
108525	MS4	264.7	0.01
108526	M2	64.2	1.141
108526	S2	90.8	0.15
108526	N2	33.8	0.236
108526	K1	211.7	0.111
108526	M4	143.1	0.094
108526	O1	213.7	0.095
108526	M6	75.6	0.022
108526	MK3	159.2	0.025
108526	S4	44.7	0.002
108526	MN4	111.2	0.035
108526	S6	213.4	0.001
108526	2N2	36	0.026
108526	OO1	240.8	0.01
108526	M1	312	0.01
108526	J1	194.7	0.004
108526	Q1	227.3	0.021
108526	2Q1	276.4	0.003
108526	P1	204.4	0.067
108526	2SM2	39.9	0.003
108526	M3	223.9	0.008
108526	L2	81.3	0.092
108526	2MK3	138.6	0.03
108526	K2	91.5	0.057
108526	M8	236.7	0.02
108526	MS4	169.2	0.019
108527	M2	66.9	1.135
108527	S2	90.6	0.145
108527	N2	33.2	0.208
108527	K1	214.3	0.141
108527	M4	155.9	0.125
108527	O1	214.1	0.116
108527	M6	164	0.026
108527	MK3	164.9	0.028
108527	S4	135.7	0.006
108527	MN4	114.3	0.064
108527	S6	99.2	0.002
108527	2N2	108.6	0.022
108527	OO1	208.6	0.011
108527	M1	315.6	0.015
108527	J1	90.3	0.008
108527	Q1	208.4	0.029
108527	2Q1	231.7	0.006
108527	P1	200.6	0.033
108527	2SM2	64.4	0.002
108527	M3	171.9	0.014
108527	L2	79.2	0.136
108527	2MK3	138.4	0.029
108527	K2	89.4	0.062
108527	M8	277.9	0.03
108527	MS4	176.2	0.016
108528	M2	311.7	0.476
108528	S2	353.2	0.062
108528	N2	298.1	0.096
108528	K1	90.2	0.037
108528	M4	120.2	0.101
108528	O1	119.8	0.049
108528	M6	316.1	0.048
108528	MK3	271.5	0.028
108528	S4	10.4	0.011
108528	MN4	117.4	0.063
108528	S6	307.5	0.011
108528	2N2	342.3	0.015
108528	OO1	153	0.016
108528	M1	197.3	0.009
108528	J1	134.7	0.012
108528	Q1	241.4	0.014
108528	2Q1	57.3	0.014
108528	2SM2	239.9	0.011
108528	M3	225.6	0.004
108528	L2	307.6	0.009
108528	2MK3	303.1	0.03
108528	M8	132.6	0.032
108528	MS4	160.6	0.051
108529	M2	337.3	0.65
108529	S2	13.6	0.099
108529	N2	345.6	0.113
108529	K1	105.6	0.045
108529	M4	159.6	0.181
108529	O1	115.8	0.059
108529	M6	314.9	0.074
108529	MK3	299.2	0.064
108529	S4	48.7	0.006
108529	MN4	147.9	0.084
108529	S6	330.7	0.012
108529	2N2	39.3	0.02
108529	OO1	165.5	0.024
108529	M1	207.7	0.014
108529	J1	165	0.004
108529	Q1	219.4	0.015
108529	2Q1	151.5	0.008
108529	2SM2	334.3	0.024
108529	M3	227.9	0.016
108529	L2	105.2	0.037
108529	2MK3	321.8	0.059
108529	M8	94.1	0.024
108529	MS4	174.9	0.053
108530	M2	9.2	0.93
108530	S2	355.8	0.089
108530	N2	7.7	0.142
108530	K1	179.6	0.064
108530	M4	226.7	0.197
108530	O1	182.1	0.054
108530	M6	200.3	0.085
108530	MK3	77.8	0.016
108530	S4	84.8	0.008
108530	MN4	236.6	0.036
108530	S6	305.6	0.014
108530	2N2	318.1	0.093
108530	OO1	214	0.006
108530	M1	241.5	0.002
108530	J1	314.4	0.014
108530	Q1	182.9	0.042
108530	2Q1	348.1	0.01
108530	2SM2	294.9	0.031
108530	M3	15.6	0.013
108530	L2	28.9	0.069
108530	2MK3	40.9	0.079
108530	M8	44.3	0.092
108530	MS4	105	0.028
108531	M2	354	1.913
108531	S2	22.9	0.229
108531	N2	330.4	0.376
108531	K1	152	0.202
108531	M4	358.7	0.043
108531	O1	171.1	0.165
108531	M6	190.6	0.101
108531	MK3	48.8	0.018
108531	S4	305.9	0.019
108531	MN4	13.7	0.033
108531	NU2	321.3	0.07
108531	S6	289.4	0.014
108531	MU2	24.6	0.053
108531	2N2	9.3	0.018
108531	OO1	110.4	0.022
108531	LDA2	8.6	0.065
108531	M1	218	0.007
108531	RHO1	232.2	0.02
108531	Q1	173.2	0.033
108531	2Q1	16.6	0.008
108531	P1	169.8	0.075
108531	2SM2	342	0.034
108531	M3	182.3	0.027
108531	L2	349.1	0.115
108531	2MK3	146	0.017
108531	K2	34.4	0.1
108531	M8	6	0.032
108531	MS4	89.1	0.044
108532	M2	356.9	2.008
108532	S2	19.6	0.236
108532	N2	330.3	0.401
108532	K1	155.7	0.21
108532	M4	11.1	0.131
108532	O1	172.9	0.173
108532	M6	223.6	0.114
108532	MK3	121.2	0.019
108532	S4	331.8	0.025
108532	MN4	8.8	0.035
108532	NU2	332.8	0.075
108532	S6	307.5	0.006
108532	MU2	53.5	0.026
108532	2N2	201.4	0.005
108532	OO1	113.7	0.023
108532	LDA2	40.6	0.069
108532	M1	196.6	0.004
108532	J1	133.6	0.012
108532	RHO1	247.9	0.021
108532	Q1	157.8	0.033
108532	2Q1	354.3	0.013
108532	P1	164.2	0.076
108532	2SM2	359.8	0.026
108532	M3	189.8	0.028
108532	L2	15.7	0.14
108532	2MK3	146.5	0.033
108532	K2	42	0.1
108532	M8	292.3	0.027
108532	MS4	99.4	0.039
108533	M2	358.4	2.018
108533	S2	17.9	0.243
108533	N2	330.8	0.415
108533	K1	157.3	0.214
108533	M4	23.8	0.184
108533	O1	175.1	0.173
108533	M6	241.8	0.106
108533	MK3	149.3	0.027
108533	S4	347.3	0.03
108533	MN4	359	0.045
108533	NU2	337	0.075
108533	S6	287.3	0.004
108533	MU2	44.1	0.01
108533	2N2	223.1	0.012
108533	OO1	118.7	0.029
108533	LDA2	59.3	0.063
108533	M1	191.6	0.003
108533	J1	140.3	0.014
108533	RHO1	248.5	0.018
108533	Q1	157.4	0.037
108533	2Q1	340.3	0.017
108533	P1	162.2	0.075
108533	2SM2	3.1	0.018
108533	M3	185	0.027
108533	L2	29.3	0.141
108533	2MK3	147.6	0.041
108533	K2	46.5	0.099
108533	M8	279.9	0.047
108533	MS4	100.4	0.035
108534	M2	69.5	1.165
108534	S2	102.4	0.118
108534	N2	57	0.18
108534	K1	231	0.116
108534	M4	338.9	0.138
108534	O1	234.8	0.081
108534	M6	17.3	0.09
108534	MK3	112.3	0.039
108534	S4	50.9	0.022
108534	MN4	318.8	0.024
108534	S6	211.2	0.01
108534	2N2	353.1	0.027
108534	OO1	279.3	0.014
108534	M1	27.8	0.011
108534	J1	41.7	0.005
108534	Q1	227.8	0.006
108534	2Q1	36.4	0.003
108534	2SM2	59.3	0.017
108534	M3	200.5	0.014
108534	L2	75	0.093
108534	2MK3	105.6	0.048
108534	M8	336.2	0.042
108534	MS4	1	0.008
108535	M2	72.3	1.24
108535	S2	102.3	0.135
108535	N2	59.1	0.198
108535	K1	232.3	0.13
108535	M4	278.7	0.04
108535	O1	231.2	0.103
108535	M6	32.1	0.091
108535	MK3	96.3	0.02
108535	S4	62.4	0.014
108535	MN4	189.2	0.017
108535	S6	1.6	0.007
108535	2N2	19.1	0.025
108535	OO1	245.2	0.024
108535	M1	26	0.009
108535	J1	36.5	0.009
108535	Q1	232.7	0.015
108535	2Q1	18.7	0.003
108535	2SM2	101.2	0.007
108535	M3	228.7	0.024
108535	L2	76.5	0.067
108535	2MK3	101.1	0.031
108535	M8	82.8	0.026
108535	MS4	257.3	0.013
108536	M2	72.4	1.398
108536	S2	97.3	0.135
108536	N2	56.7	0.193
108536	K1	232.2	0.139
108536	M4	176	0.051
108536	O1	221	0.124
108536	M6	57.9	0.038
108536	MK3	90.7	0.027
108536	S4	41.8	0.008
108536	MN4	171.7	0.012
108536	S6	347.3	0.009
108536	2N2	12.5	0.043
108536	OO1	190.9	0.016
108536	M1	64.4	0.01
108536	J1	177.9	0.002
108536	Q1	258.6	0.015
108536	2Q1	357.7	0.003
108536	2SM2	180.5	0.009
108536	M3	229.4	0.028
108536	L2	90.4	0.088
108536	2MK3	112.9	0.04
108536	M8	92.9	0.024
108536	MS4	279.6	0.008
108537	M2	25.6	1.217
108537	S2	51.9	0.155
108537	N2	4.7	0.221
108537	K1	203.3	0.131
108537	M4	245.8	0.111
108537	O1	211.9	0.081
108537	M6	234.8	0.098
108537	MK3	12.4	0.012
108537	S4	319.7	0.02
108537	MN4	221	0.022
108537	S6	84.1	0.003
108537	2N2	10.5	0.019
108537	OO1	298.3	0.014
108537	M1	27.9	0.017
108537	J1	66.2	0.025
108537	Q1	186.8	0.017
108537	2Q1	224.5	0.011
108537	2SM2	318.6	0.01
108537	M3	173.7	0.026
108537	L2	32.2	0.061
108537	2MK3	32.1	0.014
108537	M8	34	0.03
108537	MS4	327.1	0.021
108538	M2	28.5	1.579
108538	S2	50.4	0.183
108538	N2	7.4	0.248
108538	K1	206.6	0.158
108538	M4	328.1	0.1
108538	O1	204.7	0.116
108538	M6	261.2	0.139
108538	MK3	67.1	0.035
108538	S4	325.9	0.015
108538	MN4	271.1	0.028
108538	S6	217	0.002
108538	2N2	348.4	0.043
108538	OO1	230	0.019
108538	M1	33.3	0.013
108538	J1	79.6	0.016
108538	Q1	235.7	0.012
108538	2Q1	227.6	0.009
108538	2SM2	31.9	0.005
108538	M3	160.3	0.018
108538	L2	46.1	0.078
108538	2MK3	34.9	0.022
108538	M8	296.3	0.053
108538	MS4	0.4	0.019
108539	M2	33.1	1.847
108539	S2	56.5	0.212
108539	N2	14.6	0.293
108539	K1	211.3	0.181
108539	M4	353.4	0.158
108539	O1	202.8	0.124
108539	M6	261.4	0.054
108539	MK3	96.8	0.063
108539	S4	331.4	0.013
108539	MN4	290.1	0.046
108539	S6	249.6	0.01
108539	2N2	355.1	0.051
108539	OO1	212.9	0.026
108539	M1	65	0.013
108539	J1	102.5	0.008
108539	Q1	234	0.022
108539	2Q1	19.3	0.003
108539	2SM2	77.8	0.015
108539	M3	174.1	0.023
108539	L2	49.8	0.086
108539	2MK3	98.1	0.041
108539	M8	295.7	0.064
108539	MS4	331.1	0.026
108540	M2	255.6	0.303
108540	S2	247.3	0.081
108540	N2	257.9	0.063
108540	K1	34.6	0.606
108540	M4	140.5	0.04
108540	O1	26.9	0.532
108540	M6	195.2	0.007
108540	MK3	178.9	0.013
108540	S4	307.2	0.015
108540	MN4	107.7	0.017
108540	S6	65.2	0.007
108540	2N2	184.6	0.023
108540	OO1	48	0.174
108540	M1	289.9	0.034
108540	J1	36.6	0.064
108540	Q1	36.9	0.068
108540	2Q1	297.4	0.119
108540	P1	1.5	0.263
108540	2SM2	36.8	0.021
108540	M3	162.4	0.026
108540	L2	300.5	0.016
108540	2MK3	128.4	0.033
108540	M8	350.3	0.003
108540	MS4	137.2	0.039
108541	M2	279.8	0.28
108541	S2	286.4	0.11
108541	N2	282.5	0.076
108541	K1	32.8	0.661
108541	M4	159.8	0.047
108541	O1	25.1	0.654
108541	M6	132	0.003
108541	MK3	300.2	0.034
108541	S4	320.3	0.021
108541	MN4	159.6	0.017
108541	S6	126.7	0.006
108541	2N2	211.9	0.04
108541	OO1	36.1	0.193
108541	M1	297.7	0.017
108541	J1	33.5	0.052
108541	Q1	39.3	0.102
108541	2Q1	309.7	0.104
108541	P1	21.9	0.357
108541	2SM2	51	0.044
108541	M3	81.8	0.01
108541	L2	338.2	0.038
108541	2MK3	232	0.008
108541	K2	292.2	0.052
108541	M8	327.4	0.002
108541	MS4	196.6	0.037
108542	M2	55.3	0.074
108542	S2	74.7	0.01
108542	N2	53.2	0.025
108542	K1	119.4	0.242
108542	M4	48.5	0.006
108542	O1	89.4	0.229
108542	M6	308.5	0.001
108542	MK3	183.4	0.006
108542	S4	197.5	0.002
108542	MN4	264.2	0.002
108542	S6	156.1	0.004
108542	2N2	184.4	0.025
108542	OO1	129.7	0.045
108542	M1	152.2	0.027
108542	J1	90	0.023
108542	Q1	79.9	0.067
108542	2Q1	250.4	0.023
108542	P1	101.8	0.044
108542	2SM2	190.3	0.01
108542	M3	308	0.004
108542	L2	26.8	0.013
108542	2MK3	93.5	0.019
108542	M8	16.7	0.002
108542	MS4	145	0.004
108543	M2	285.6	0.236
108543	S2	6.6	0.022
108543	N2	256.6	0.08
108543	K1	12	0.335
108543	M4	144.6	0.052
108543	O1	341.8	0.375
108543	M6	349.8	0.021
108543	MK3	243.3	0.088
108543	S4	341.1	0.015
108543	MN4	113.4	0.038
108543	S6	298.8	0.008
108543	2N2	105.1	0.015
108543	OO1	23	0.126
108543	M1	206.1	0.047
108543	J1	43	0.045
108543	Q1	311.6	0.089
108543	2Q1	91.7	0.026
108543	P1	351.3	0.246
108543	2SM2	290	0.016
108543	M3	128.6	0.014
108543	L2	333.7	0.021
108543	2MK3	210.6	0.047
108543	M8	162.5	0.007
108543	MS4	148.2	0.039
108544	M2	268.2	0.308
108544	S2	278.8	0.084
108544	N2	255.6	0.071
108544	K1	2.6	0.522
108544	M4	143.6	0.039
108544	O1	354.3	0.522
108544	M6	10	0.005
108544	MK3	224.3	0.023
108544	S4	273	0.008
108544	MN4	127	0.019
108544	NU2	287.6	0.009
108544	MU2	137	0.016
108544	2N2	123	0.038
108544	OO1	349.6	0.048
108544	LDA2	306.7	0.004
108544	S1	17.9	0.039
108544	M1	325.5	0.028
108544	J1	351.5	0.019
108544	RHO1	3	0.02
108544	Q1	337.9	0.113
108544	T2	350.2	0.015
108544	R2	214.4	0.023
108544	2Q1	235.8	0.016
108544	P1	18.6	0.138
108544	2SM2	31.3	0.007
108544	M3	107	0.013
108544	L2	299.6	0.022
108544	2MK3	176.2	0.008
108544	K2	274.1	0.078
108544	M8	158.1	0.004
108544	MS4	155.6	0.015
108545	M2	276.4	0.323
108545	S2	250	0.05
108545	N2	271.4	0.098
108545	K1	21	0.556
108545	M4	150.7	0.026
108545	O1	1.3	0.523
108545	M6	312.3	0.01
108545	MK3	145.4	0.033
108545	S4	14.9	0.019
108545	MN4	124.4	0.015
108545	S6	172.4	0.008
108545	2N2	148.5	0.043
108545	OO1	23.7	0.139
108545	M1	184.6	0.044
108545	J1	9.6	0.037
108545	Q1	350.8	0.111
108545	2Q1	39.9	0.076
108545	P1	8.6	0.23
108545	2SM2	343.5	0.008
108545	M3	130.5	0.012
108545	L2	320.4	0.034
108545	2MK3	128	0.018
108545	M8	164	0.004
108545	MS4	162.5	0.026
108546	M2	209.1	0.091
108546	S2	184.6	0.026
108546	N2	193	0.024
108546	K1	321	0.163
108546	M4	26.3	0.006
108546	O1	310.5	0.145
108546	M6	149.7	0.009
108546	MK3	15.3	0.011
108546	S4	246.3	0.007
108546	MN4	301.4	0.006
108546	S6	45.7	0.021
108546	2N2	123	0.003
108546	OO1	343.9	0.019
108546	M1	170	0.023
108546	J1	0.5	0.02
108546	Q1	301.1	0.025
108546	2Q1	110	0.013
108546	P1	348.6	0.026
108546	2SM2	88.8	0.003
108546	M3	12.5	0.003
108546	L2	279	0.007
108546	2MK3	318.9	0.008
108546	M8	11	0.002
108546	MS4	251	0.005
108547	M2	234.8	0.121
108547	S2	174.6	0.018
108547	N2	235.2	0.042
108547	K1	8.7	0.278
108547	M4	5.8	0.007
108547	O1	349.6	0.262
108547	M6	180.4	0.01
108547	MK3	40.1	0.02
108547	S4	295.2	0.016
108547	MN4	284.4	0.002
108547	S6	42.4	0.02
108547	2N2	112	0.015
108547	OO1	52.9	0.078
108547	M1	250.1	0.037
108547	J1	54.3	0.009
108547	Q1	331.3	0.072
108547	2Q1	344.5	0.01
108547	P1	354.1	0.121
108547	2SM2	336.3	0.006
108547	M3	24	0.008
108547	L2	288.4	0.023
108547	2MK3	348.6	0.019
108547	M8	67.6	0.001
108547	MS4	275.3	0.004
108548	M2	248.7	0.384
108548	S2	239.8	0.186
108548	N2	241.7	0.091
108548	K1	4.5	0.717
108548	M4	144.1	0.052
108548	O1	343.1	0.68
108548	M6	23.5	0.018
108548	MK3	284	0.025
108548	S4	7.3	0.005
108548	MN4	106.9	0.023
108548	S6	264.6	0.009
108548	2N2	113.6	0.087
108548	OO1	2.1	0.065
108548	M1	325.9	0.063
108548	J1	1.4	0.057
108548	Q1	325.7	0.167
108548	2Q1	272.3	0.055
108548	P1	49	0.17
108548	2SM2	176.7	0.009
108548	M3	331	0.007
108548	L2	303.1	0.016
108548	2MK3	279.3	0.032
108548	K2	299.2	0.165
108548	M8	3.7	0.003
108548	MS4	195.4	0.02
108549	M2	246.3	0.307
108549	S2	242.8	0.139
108549	N2	240.4	0.083
108549	K1	4.7	0.593
108549	M4	134.2	0.044
108549	O1	342.2	0.557
108549	M6	22	0.012
108549	MK3	283.3	0.026
108549	S4	324	0.003
108549	MN4	98.4	0.01
108549	S6	241.1	0.004
108549	2N2	108.4	0.063
108549	OO1	355.7	0.051
108549	M1	319.8	0.046
108549	J1	14.5	0.047
108549	Q1	325.6	0.144
108549	2Q1	284.3	0.052
108549	P1	50.4	0.134
108549	2SM2	124	0.01
108549	M3	23.3	0.008
108549	L2	285.1	0.007
108549	2MK3	245.2	0.019
108549	K2	294.7	0.126
108549	M8	70.2	0.003
108549	MS4	173.8	0.019
108550	M2	265.9	0.413
108550	S2	338.3	0.086
108550	N2	252.3	0.185
108550	K1	355.8	0.882
108550	M4	158.4	0.042
108550	O1	339	0.887
108550	M6	41.7	0.009
108550	MK3	286.6	0.08
108550	S4	323.3	0.022
108550	MN4	136.9	0.045
108550	S6	18.3	0.026
108550	2N2	26.4	0.035
108550	OO1	41.2	0.175
108550	M1	286	0.083
108550	J1	1.1	0.107
108550	Q1	318.6	0.301
108550	2Q1	69.6	0.086
108550	P1	357.6	0.381
108550	2SM2	253	0.038
108550	M3	269.7	0.012
108550	L2	344.5	0.023
108550	2MK3	264.6	0.038
108550	M8	178.1	0.01
108550	MS4	190.1	0.027
108551	M2	257.5	0.518
108551	S2	307.1	0.042
108551	N2	248.7	0.204
108551	K1	354.4	1.058
108551	M4	105.8	0.061
108551	O1	338	1.016
108551	MK3	258.3	0.063
108551	S4	323.7	0.024
108551	MN4	108.5	0.037
108551	S6	32.3	0.026
108551	2N2	53.6	0.055
108551	OO1	30.7	0.218
108551	M1	266.1	0.109
108551	J1	3.8	0.148
108551	Q1	316	0.306
108551	2Q1	60.2	0.098
108551	P1	358.7	0.455
108551	2SM2	277.5	0.048
108551	M3	199.7	0.008
108551	L2	282.3	0.033
108551	2MK3	247.5	0.021
108551	M8	117.4	0.008
108551	MS4	124.3	0.033
108552	M2	252.5	0.542
108552	S2	268.2	0.032
108552	N2	246.2	0.196
108552	K1	351.8	1.081
108552	M4	90.1	0.067
108552	O1	336.2	1.032
108552	M6	200.7	0.013
108552	MK3	237.9	0.04
108552	S4	321.9	0.029
108552	MN4	94.8	0.03
108552	S6	34.7	0.029
108552	2N2	55.7	0.068
108552	OO1	27.2	0.218
108552	M1	260.9	0.113
108552	J1	4	0.165
108552	Q1	316.2	0.3
108552	2Q1	56.5	0.1
108552	P1	358.2	0.483
108552	2SM2	280.5	0.053
108552	M3	136.6	0.006
108552	L2	279.3	0.036
108552	2MK3	257.2	0.011
108552	M8	71.8	0.008
108552	MS4	109	0.038
108553	M2	246.2	0.432
108553	S2	245.2	0.14
108553	N2	234.3	0.1
108553	K1	353.7	0.754
108553	M4	106.1	0.033
108553	O1	345.3	0.704
108553	M6	84.5	0.008
108553	MK3	206.9	0.022
108553	S4	235.2	0.011
108553	MN4	91.3	0.015
108553	NU2	270.6	0.019
108553	S6	10.8	0.003
108553	MU2	132.6	0.012
108553	2N2	104.1	0.046
108553	OO1	14	0.056
108553	LDA2	134.6	0.005
108553	S1	177.6	0.037
108553	M1	342.7	0.044
108553	J1	11.7	0.047
108553	MM	356.9	0.041
108553	SSA	323.6	0.022
108553	SA	58.8	0.085
108553	MSF	14.6	0.03
108553	MF	341.7	0.045
108553	RHO1	350.8	0.019
108553	Q1	327.6	0.168
108553	T2	283.5	0.011
108553	R2	194.9	0.008
108553	2Q1	230.9	0.023
108553	P1	2.7	0.212
108553	2SM2	355	0.008
108553	M3	75.7	0.006
108553	L2	252.1	0.019
108553	2MK3	263.1	0.007
108553	K2	257.6	0.117
108553	M8	236.9	0.003
108553	MS4	118.2	0.023
108554	M2	262.3	0.156
108554	S2	257.7	0.043
108554	N2	262.1	0.032
108554	K1	4.3	0.258
108554	M4	93.5	0.036
108554	O1	2.8	0.216
108554	M6	324.7	0.01
108554	MK3	140.4	0.014
108554	S4	84.5	0.006
108554	S6	211.7	0.005
108554	2N2	174.3	0.024
108554	OO1	142.6	0.004
108554	M1	324.4	0.015
108554	J1	161.8	0.006
108554	Q1	347.8	0.06
108554	2Q1	261.8	0.018
108554	P1	6	0.064
108554	2SM2	127.5	0.012
108554	M3	123	0.004
108554	L2	287.8	0.009
108554	2MK3	110.4	0.032
108554	M8	186.6	0.002
108554	MS4	98.4	0.013
108555	M2	4.4	0.575
108555	S2	43.9	0.122
108555	N2	322.3	0.104
108555	K1	272.4	0.326
108555	M4	155	0.041
108555	O1	246	0.199
108555	M6	321	0.011
108555	MK3	45.2	0.023
108555	S4	44.3	0.007
108555	MN4	82.1	0.014
108555	S6	102.4	0.004
108555	2N2	315.4	0.033
108555	OO1	52	0.028
108555	M1	247.1	0.016
108555	J1	255.8	0.026
108555	Q1	212.9	0.029
108555	2Q1	244.5	0.034
108555	P1	265.2	0.09
108555	2SM2	302.7	0.015
108555	M3	150.3	0.003
108555	L2	24.7	0.02
108555	2MK3	3	0.007
108555	K2	45.6	0.071
108555	M8	343	0.001
108555	MS4	137.5	0.011
108556	M2	16.9	0.753
108556	S2	77.4	0.149
108556	N2	330.8	0.163
108556	K1	258.5	0.281
108556	M4	283.1	0.027
108556	O1	240.9	0.213
108556	M6	82	0.001
108556	MK3	144.5	0.032
108556	S4	225.9	0.006
108556	MN4	246	0.008
108556	S6	55.6	0.006
108556	2N2	8.7	0.037
108556	OO1	21.5	0.019
108556	M1	251.3	0.023
108556	J1	250.3	0.033
108556	Q1	235.8	0.041
108556	2Q1	228.4	0.021
108556	P1	253	0.127
108556	2SM2	271.2	0.016
108556	M3	334.9	0.02
108556	L2	76.9	0.026
108556	2MK3	70.2	0.021
108556	K2	111.7	0.031
108556	M8	207.6	0.006
108556	MS4	208	0.018
108557	M2	16.4	0.676
108557	S2	57.4	0.11
108557	N2	325.4	0.143
108557	K1	264.2	0.333
108557	M4	327.5	0.054
108557	O1	222.3	0.21
108557	M6	141.5	0.009
108557	MK3	213.1	0.033
108557	S4	179.9	0.013
108557	MN4	262.4	0.016
108557	S6	188.6	0.009
108557	2N2	352.4	0.028
108557	OO1	290.4	0.011
108557	M1	283.2	0.015
108557	J1	240	0.036
108557	Q1	197.3	0.032
108557	2Q1	266.3	0.037
108557	P1	246.3	0.078
108557	2SM2	7.7	0.03
108557	M3	342.2	0.002
108557	L2	245.2	0.041
108557	2MK3	122.5	0.011
108557	K2	137.4	0.016
108557	M8	7.8	0.002
108557	MS4	27.4	0.012
108558	M2	22.6	1.267
108558	S2	78	0.269
108558	N2	340.2	0.335
108558	K1	285.1	0.846
108558	M4	66.8	0.006
108558	O1	261.2	0.559
108558	M6	131.3	0.009
108558	MK3	52.1	0.011
108558	S4	140.9	0.004
108558	MN4	225.4	0.015
108558	2N2	313.4	0.05
108558	OO1	303.8	0.008
108558	M1	300.8	0.035
108558	J1	271.8	0.076
108558	Q1	248.6	0.102
108558	2Q1	245.6	0.026
108558	P1	274.4	0.254
108558	2SM2	266.7	0.007
108558	M3	98.9	0.008
108558	L2	326.1	0.043
108558	2MK3	309.6	0.009
108558	K2	73.9	0.083
108558	M8	341.9	0.004
108558	MS4	133.5	0.011
108559	M2	27.1	1.765
108559	S2	80.6	0.349
108559	N2	342	0.428
108559	K1	285.8	1.103
108559	M4	115	0.036
108559	O1	260.7	0.752
108559	M6	38	0.012
108559	MK3	45.3	0.015
108559	S4	84.1	0.005
108559	MN4	70	0.004
108559	S6	161.8	0.003
108559	2N2	319.2	0.099
108559	OO1	326.8	0.032
108559	M1	293.3	0.051
108559	J1	258.2	0.084
108559	Q1	250.1	0.142
108559	2Q1	246.2	0.039
108559	P1	276	0.308
108559	2SM2	276.3	0.02
108559	M3	316.2	0.009
108559	L2	268.7	0.01
108559	2MK3	319.9	0.038
108559	K2	75.2	0.136
108559	MS4	95.2	0.037
108560	M2	29.4	2.045
108560	S2	81.1	0.36
108560	N2	340.4	0.483
108560	K1	281.7	1.149
108560	M4	14	0.038
108560	O1	257	0.801
108560	M6	3.7	0.023
108560	MK3	201.2	0.085
108560	S4	182.1	0.016
108560	MN4	323.8	0.008
108560	S6	57.4	0.006
108560	2N2	321.5	0.103
108560	OO1	303.9	0.061
108560	M1	287	0.063
108560	J1	276.6	0.044
108560	Q1	245.3	0.172
108560	2Q1	222.3	0.032
108560	P1	279.4	0.307
108560	2SM2	356.8	0.022
108560	M3	44	0.045
108560	L2	123.7	0.038
108560	2MK3	158.6	0.056
108560	K2	91.9	0.139
108560	M8	146	0.004
108560	MS4	52.2	0.052
108561	M2	4.2	2.573
108561	S2	54.9	0.487
108561	N2	313.9	0.62
108561	K1	250.1	0.975
108561	M4	226.5	0.075
108561	O1	228.4	0.719
108561	M6	263.4	0.067
108561	MK3	73.4	0.096
108561	S4	51.3	0.026
108561	MN4	78.7	0.04
108561	2N2	241.9	0.173
108561	OO1	190.6	0.029
108561	M1	306.6	0.038
108561	J1	223.2	0.08
108561	Q1	230.7	0.099
108561	2Q1	319.9	0.004
108561	P1	234.8	0.237
108561	2SM2	27.5	0.026
108561	M3	306.8	0.03
108561	L2	97.3	0.165
108561	2MK3	12.6	0.092
108561	K2	48.1	0.176
108561	M8	102.4	0.01
108561	MS4	307.9	0.082
108562	M2	5	3.272
108562	S2	56.5	0.609
108562	N2	315	0.781
108562	K1	249.8	1.214
108562	M4	236.7	0.025
108562	O1	226.9	0.879
108562	M6	268.9	0.092
108562	MK3	59.6	0.096
108562	S4	53.9	0.029
108562	MN4	39.2	0.056
108562	S6	150.9	0.004
108562	2N2	239.4	0.218
108562	OO1	178.6	0.038
108562	M1	304.5	0.046
108562	J1	214.1	0.099
108562	Q1	226.5	0.12
108562	P1	233.2	0.282
108562	2SM2	357.8	0.034
108562	M3	305.7	0.046
108562	L2	102.6	0.242
108562	2MK3	2.9	0.119
108562	K2	50.8	0.21
108562	M8	159.3	0.008
108562	MS4	315.1	0.071
108563	M2	5.4	3.367
108563	S2	58.3	0.611
108563	N2	315.8	0.793
108563	K1	249.3	1.217
108563	M4	330	0.038
108563	O1	225.9	0.865
108563	M6	264.7	0.089
108563	MK3	40.1	0.089
108563	S4	56.4	0.033
108563	MN4	11.7	0.07
108563	2N2	238.4	0.229
108563	OO1	173.5	0.037
108563	M1	306.1	0.043
108563	J1	213.8	0.103
108563	Q1	228.9	0.121
108563	P1	231.2	0.276
108563	2SM2	337.6	0.037
108563	M3	301.5	0.039
108563	L2	102.8	0.266
108563	2MK3	350.2	0.115
108563	K2	46.3	0.227
108563	M8	174.7	0.009
108563	MS4	333.5	0.072
108564	M2	3.9	0.813
108564	S2	58.7	0.193
108564	N2	329.1	0.139
108564	K1	305.1	0.333
108564	M4	275.5	0.01
108564	O1	267.3	0.309
108564	M6	49.1	0.005
108564	MK3	146.5	0.071
108564	S4	260.6	0.025
108564	MN4	84.3	0.006
108564	S6	82.3	0.008
108564	2N2	250.6	0.064
108564	OO1	72.8	0.013
108564	M1	203.6	0.021
108564	J1	287.5	0.06
108564	Q1	263.7	0.033
108564	2Q1	202.6	0.069
108564	P1	276.2	0.188
108564	2SM2	174.6	0.013
108564	M3	13.3	0.024
108564	L2	282.7	0.019
108564	2MK3	71.9	0.038
108564	K2	74.4	0.063
108564	M8	137.3	0.005
108564	MS4	43.1	0.032
108565	M2	16.5	0.86
108565	S2	89.4	0.151
108565	N2	343.5	0.185
108565	K1	301.6	0.393
108565	M4	318.1	0.039
108565	O1	260.8	0.322
108565	M6	277.3	0.006
108565	MK3	115.6	0.072
108565	S4	237.1	0.014
108565	MN4	186.3	0.009
108565	S6	168	0.004
108565	2N2	248.8	0.045
108565	OO1	88.4	0.019
108565	M1	249	0.016
108565	J1	297.4	0.072
108565	Q1	250	0.046
108565	2Q1	206	0.049
108565	P1	274	0.246
108565	2SM2	31.1	0.011
108565	M3	347.2	0.015
108565	L2	268.9	0.034
108565	2MK3	36.2	0.042
108565	K2	106.6	0.042
108565	M8	152.8	0.01
108565	MS4	343	0.035
108566	M2	36.3	1.066
108566	S2	60.6	0.078
108566	N2	346.7	0.243
108566	K1	288.9	0.504
108566	M4	292.7	0.011
108566	O1	263.2	0.373
108566	M6	251.8	0.019
108566	MK3	48.3	0.06
108566	S4	236.7	0.002
108566	MN4	81.6	0.017
108566	S6	247.2	0.002
108566	2N2	350.9	0.038
108566	OO1	17.7	0.026
108566	M1	273.7	0.013
108566	J1	308.3	0.031
108566	Q1	232.1	0.072
108566	2Q1	239.9	0.023
108566	P1	287.5	0.236
108566	2SM2	17.6	0.042
108566	M3	267.8	0.021
108566	L2	99.9	0.032
108566	2MK3	24.8	0.048
108566	K2	3.6	0.069
108566	M8	238.2	0.008
108566	MS4	194.2	0.013
108567	M2	11.2	0.674
108567	S2	94.7	0.179
108567	N2	349.5	0.119
108567	K1	282.7	0.498
108567	M4	44.9	0.037
108567	O1	253.5	0.228
108567	M6	269.1	0.008
108567	MK3	339.4	0.033
108567	S4	294.8	0.015
108567	MN4	213.2	0.017
108567	S6	326.5	0.002
108567	2N2	270.3	0.048
108567	OO1	67	0.047
108567	M1	233.7	0.009
108567	J1	227.2	0.043
108567	Q1	222.1	0.046
108567	2Q1	171.9	0.007
108567	P1	222.2	0.069
108567	2SM2	185.8	0.018
108567	M3	103.3	0.021
108567	L2	355.8	0.062
108567	2MK3	37	0.016
108567	K2	141.2	0.044
108567	M8	31.5	0.005
108567	MS4	111.1	0.012
108568	M2	18.4	0.774
108568	S2	76.2	0.186
108568	N2	342.6	0.155
108568	K1	262.4	0.532
108568	M4	333.1	0.02
108568	O1	240.2	0.258
108568	M6	179.9	0.011
108568	MK3	88.3	0.018
108568	S4	119.6	0.004
108568	MN4	260.2	0.009
108568	S6	96.2	0.004
108568	2N2	333.2	0.011
108568	OO1	36.2	0.047
108568	M1	242.9	0.011
108568	J1	213.4	0.046
108568	Q1	225.4	0.03
108568	2Q1	34.3	0.013
108568	P1	277	0.125
108568	2SM2	68.4	0.011
108568	M3	326.1	0.017
108568	L2	312	0.041
108568	2MK3	40.9	0.023
108568	K2	79.8	0.048
108568	M8	289	0.004
108568	MS4	64.3	0.008
108569	M2	22	0.781
108569	S2	71.7	0.164
108569	N2	327.8	0.169
108569	K1	257.5	0.47
108569	M4	267.2	0.017
108569	O1	239.2	0.256
108569	MK3	334.8	0.009
108569	S4	152.7	0.012
108569	MN4	359.4	0.006
108569	S6	119	0.006
108569	2N2	327.1	0.024
108569	OO1	345.8	0.031
108569	M1	255.2	0.024
108569	J1	147.5	0.039
108569	Q1	284.3	0.068
108569	2Q1	91.4	0.043
108569	P1	279.1	0.167
108569	2SM2	16.9	0.034
108569	M3	240.2	0.016
108569	L2	205.7	0.023
108569	2MK3	307.9	0.024
108569	K2	60.6	0.041
108569	M8	171.1	0.004
108569	MS4	62.9	0.02
108570	M2	30.5	1.987
108570	S2	79.8	0.355
108570	N2	346.6	0.457
108570	K1	266	1.189
108570	M4	140.7	0.095
108570	O1	238.7	0.643
108570	M6	257.7	0.033
108570	MK3	29.6	0.15
108570	S4	76.5	0.008
108570	MN4	119.3	0.039
108570	S6	117.5	0.015
108570	2N2	323.9	0.159
108570	OO1	44.2	0.071
108570	M1	200.9	0.019
108570	J1	216.8	0.12
108570	Q1	237.4	0.072
108570	2Q1	146.9	0.061
108570	P1	260.5	0.368
108570	2SM2	198.8	0.016
108570	M3	265.3	0.052
108570	L2	121.2	0.023
108570	2MK3	30.2	0.107
108570	K2	69.9	0.186
108570	M8	144.2	0.009
108570	MS4	165.3	0.01
108571	M2	31	2.664
108571	S2	82.7	0.503
108571	N2	345.7	0.596
108571	K1	267.4	1.579
108571	M4	118	0.148
108571	O1	240.7	0.843
108571	M6	299.2	0.025
108571	MK3	25.7	0.168
108571	S4	52.5	0.025
108571	MN4	89.2	0.044
108571	S6	96.6	0.01
108571	2N2	330.3	0.198
108571	OO1	49.3	0.101
108571	M1	209.4	0.027
108571	J1	217	0.158
108571	Q1	240.8	0.097
108571	2Q1	149.1	0.08
108571	P1	257.8	0.473
108571	2SM2	163.1	0.012
108571	M3	258.5	0.048
108571	L2	112.3	0.047
108571	2MK3	31.5	0.126
108571	K2	77.4	0.245
108571	M8	47.8	0.008
108571	MS4	94.3	0.05
108572	M2	33.5	2.912
108572	S2	88.3	0.565
108572	N2	347.3	0.641
108572	K1	270.4	1.71
108572	M4	106.6	0.168
108572	O1	243.9	0.931
108572	M6	359.7	0.028
108572	MK3	21.7	0.149
108572	S4	42.1	0.042
108572	MN4	78.7	0.046
108572	S6	327.3	0.011
108572	2N2	331.3	0.209
108572	OO1	51.6	0.129
108572	M1	188.4	0.032
108572	J1	220.8	0.184
108572	Q1	247.7	0.099
108572	2Q1	163.7	0.082
108572	P1	254.6	0.519
108572	2SM2	93.9	0.008
108572	M3	236.4	0.037
108572	L2	117.8	0.062
108572	2MK3	45.6	0.11
108572	K2	93.9	0.226
108572	M8	293.2	0.014
108572	MS4	84.8	0.07
108573	M2	320.2	3.784
108573	S2	17.5	0.551
108573	N2	283.3	0.623
108573	K1	223.5	1.122
108573	M4	216.1	0.2
108573	O1	213.3	0.733
108573	M6	64.6	0.313
108573	MK3	263.1	0.191
108573	S4	187.9	0.018
108573	MN4	209.9	0.056
108573	S6	197.7	0.008
108573	2N2	222.2	0.238
108573	OO1	314.7	0.11
108573	M1	283.7	0.038
108573	J1	123.9	0.055
108573	Q1	233.3	0.079
108573	2Q1	167.9	0.033
108573	P1	210.5	0.209
108573	2SM2	247.3	0.026
108573	M3	137.6	0.048
108573	L2	341.8	0.269
108573	2MK3	238.1	0.318
108573	K2	307.8	0.166
108573	M8	355.4	0.129
108573	MS4	195.1	0.121
108574	M2	320.2	4.707
108574	S2	17.4	0.668
108574	N2	284.6	0.798
108574	K1	223.1	1.386
108574	M4	224.1	0.24
108574	O1	213.2	0.924
108574	M6	66.1	0.354
108574	MK3	257.5	0.226
108574	S4	188.8	0.026
108574	MN4	214.8	0.082
108574	2N2	222.4	0.289
108574	OO1	306.2	0.139
108574	M1	276.8	0.053
108574	J1	126.6	0.058
108574	Q1	235.3	0.104
108574	2Q1	156.8	0.038
108574	P1	212.1	0.297
108574	2SM2	269.4	0.033
108574	M3	140.3	0.055
108574	L2	341	0.299
108574	2MK3	237.8	0.371
108574	K2	297.1	0.206
108574	M8	356.8	0.152
108574	MS4	203.1	0.142
108575	M2	320	4.834
108575	S2	16.4	0.733
108575	N2	284	0.818
108575	K1	222.8	1.333
108575	M4	211.6	0.19
108575	O1	216	0.949
108575	M6	64.3	0.347
108575	MK3	271.6	0.271
108575	S4	183.1	0.035
108575	MN4	208.5	0.064
108575	2N2	222	0.276
108575	OO1	303.4	0.116
108575	M1	284.1	0.06
108575	J1	128.6	0.046
108575	Q1	237.7	0.103
108575	2Q1	133.9	0.015
108575	P1	210.6	0.395
108575	2SM2	292.3	0.062
108575	M3	137.7	0.07
108575	L2	340.3	0.313
108575	2MK3	242.8	0.396
108575	K2	302.8	0.202
108575	M8	357.6	0.153
108575	MS4	197.3	0.169
108576	M2	312.9	0.112
108576	S2	307.6	0.031
108576	N2	280	0.03
108576	K1	108.5	0.079
108576	M4	318.1	0.012
108576	O1	35.6	0.038
108576	M6	50.2	0.004
108576	MK3	197.1	0.016
108576	S4	160	0.006
108576	MN4	86.8	0.001
108576	S6	308.4	0.005
108576	2N2	243.3	0.001
108576	OO1	277.4	0.008
108576	M1	20.8	0.004
108576	J1	30.8	0.011
108576	Q1	237.6	0.012
108576	2Q1	238.2	0.017
108576	2SM2	155.1	0.017
108576	M3	103.5	0.014
108576	L2	334.5	0.031
108576	2MK3	325.7	0.004
108576	M8	70.4	0.002
108576	MS4	316.1	0.002
108577	M2	313.4	0.097
108577	S2	357.5	0.025
108577	N2	247.6	0.025
108577	K1	122.1	0.07
108577	M4	292.6	0.004
108577	O1	26.4	0.044
108577	M6	64	0.008
108577	MK3	224.3	0.015
108577	S4	127.4	0.003
108577	MN4	250.3	0.005
108577	S6	45	0.003
108577	2N2	155.8	0.008
108577	OO1	91.7	0.005
108577	M1	57.6	0.009
108577	J1	143.2	0.003
108577	Q1	151.9	0.008
108577	2Q1	323.2	0.012
108577	2SM2	69.5	0.006
108577	M3	15	0.015
108577	L2	353.7	0.018
108577	2MK3	163	0.005
108577	M8	40.5	0.003
108577	MS4	141.1	0.001
108578	M2	318.1	0.092
108578	S2	337	0.024
108578	N2	254.7	0.022
108578	K1	132.4	0.066
108578	M4	294.6	0.002
108578	O1	21.6	0.029
108578	M6	34.1	0.003
108578	MK3	232.1	0.015
108578	S4	92	0.01
108578	MN4	266.4	0.005
108578	S6	222	0.003
108578	2N2	136	0.013
108578	OO1	333.1	0.003
108578	M1	80.7	0.009
108578	J1	120	0.007
108578	Q1	78.4	0.011
108578	2Q1	239.1	0.006
108578	2SM2	105.8	0.003
108578	M3	53.7	0.012
108578	L2	351.5	0.014
108578	2MK3	116.8	0.009
108578	M8	31.4	0.005
108578	MS4	319.4	0.006
108579	M2	345.7	3.251
108579	S2	46.6	0.605
108579	N2	301.6	0.531
108579	K1	243.8	0.987
108579	M4	245.3	0.111
108579	O1	226.6	0.704
108579	M6	148.8	0.183
108579	MK3	356.9	0.22
108579	S4	288.4	0.015
108579	MN4	193.6	0.015
108579	S6	181.3	0.011
108579	2N2	272.3	0.214
108579	OO1	333.4	0.026
108579	M1	274.3	0.018
108579	J1	185.3	0.073
108579	Q1	247	0.103
108579	2Q1	106.4	0.063
108579	P1	219.5	0.293
108579	2SM2	331.6	0.021
108579	M3	222.1	0.044
108579	L2	28.5	0.18
108579	2MK3	314.2	0.185
108579	K2	31.7	0.157
108579	M8	45.5	0.021
108579	MS4	289.4	0.123
108580	M2	345.5	3.731
108580	S2	43.4	0.695
108580	N2	301.9	0.621
108580	K1	244	1.153
108580	M4	239	0.114
108580	O1	226.8	0.821
108580	M6	151.8	0.189
108580	MK3	0.7	0.241
108580	S4	304	0.015
108580	MN4	179.2	0.011
108580	S6	162.8	0.012
108580	2N2	273.3	0.232
108580	OO1	328.9	0.024
108580	M1	269.9	0.026
108580	J1	187.1	0.076
108580	Q1	243.6	0.12
108580	2Q1	110.8	0.06
108580	P1	220.2	0.333
108580	2SM2	322.4	0.02
108580	M3	223.2	0.049
108580	L2	29.8	0.201
108580	2MK3	317.8	0.2
108580	K2	23.8	0.192
108580	M8	14.5	0.012
108580	MS4	290.6	0.136
108581	M2	344.6	3.899
108581	S2	41.3	0.665
108581	N2	301.9	0.662
108581	K1	245	1.232
108581	M4	199.3	0.134
108581	O1	228.3	0.898
108581	M6	150.4	0.2
108581	MK3	12.4	0.297
108581	S4	318.2	0.015
108581	MN4	113.1	0.04
108581	S6	141.7	0.015
108581	2N2	275.3	0.233
108581	OO1	319.3	0.013
108581	M1	272	0.03
108581	J1	200.2	0.081
108581	Q1	240.7	0.14
108581	2Q1	112.1	0.057
108581	P1	218.1	0.329
108581	2SM2	279.3	0.014
108581	M3	234.6	0.062
108581	L2	29.6	0.219
108581	2MK3	325.7	0.215
108581	K2	11.5	0.187
108581	M8	328.9	0.009
108581	MS4	289.2	0.147
108582	M2	351.4	2.701
108582	S2	39	0.531
108582	N2	307.1	0.552
108582	K1	239.9	0.887
108582	M4	3.3	0.176
108582	O1	217.5	0.627
108582	M6	237.5	0.069
108582	MK3	326	0.084
108582	MN4	329.8	0.073
108582	S6	323.1	0.005
108582	2N2	245.7	0.167
108582	OO1	108.1	0.011
108582	M1	291.6	0.027
108582	J1	205.3	0.063
108582	Q1	228.2	0.108
108582	2Q1	1.6	0.01
108582	P1	227.6	0.236
108582	2SM2	329.4	0.015
108582	M3	228.8	0.046
108582	L2	53.4	0.187
108582	2MK3	314.5	0.143
108582	K2	14.9	0.218
108582	M8	254.1	0.045
108582	MS4	18.9	0.026
108583	M2	352.3	3.464
108583	S2	39.1	0.685
108583	N2	308.6	0.699
108583	K1	239	1.123
108583	M4	347.9	0.304
108583	O1	215	0.782
108583	M6	245.3	0.126
108583	MK3	296.7	0.086
108583	S4	350.6	0.007
108583	MN4	312.8	0.122
108583	S6	313.8	0.007
108583	2N2	243.1	0.215
108583	OO1	95.8	0.012
108583	M1	289.4	0.033
108583	J1	202.8	0.075
108583	Q1	226.4	0.133
108583	2Q1	339.4	0.012
108583	P1	227.6	0.308
108583	2SM2	333.9	0.016
108583	M3	225.4	0.054
108583	L2	57.3	0.242
108583	2MK3	308.9	0.165
108583	K2	16.3	0.275
108583	M8	237.8	0.048
108583	MS4	28.5	0.09
108584	M2	353	3.604
108584	S2	39.6	0.744
108584	N2	308.4	0.75
108584	K1	237.7	1.138
108584	M4	339.3	0.417
108584	O1	210	0.76
108584	M6	244.4	0.145
108584	MK3	275.2	0.143
108584	S4	6.6	0.009
108584	MN4	305.2	0.174
108584	2N2	243.2	0.209
108584	OO1	122.1	0.026
108584	M1	293.2	0.022
108584	J1	220	0.075
108584	Q1	222.1	0.134
108584	2Q1	317	0.03
108584	P1	225.6	0.33
108584	2SM2	313.6	0.038
108584	M3	197.7	0.06
108584	L2	61.6	0.22
108584	2MK3	295.3	0.176
108584	K2	14.8	0.275
108584	M8	230.8	0.052
108584	MS4	32.3	0.148
108585	M2	343.3	3.752
108585	S2	33	0.579
108585	N2	301.3	0.599
108585	K1	232.5	1.037
108585	M4	333	0.287
108585	O1	222.5	0.758
108585	M6	174	0.133
108585	MK3	309.9	0.217
108585	S4	261.9	0.041
108585	MN4	289.2	0.088
108585	2N2	245	0.288
108585	OO1	314.2	0.028
108585	M1	324.9	0.039
108585	J1	174.7	0.069
108585	Q1	246.9	0.116
108585	2Q1	39.6	0.04
108585	P1	239.2	0.388
108585	2SM2	77	0.011
108585	M3	221.5	0.063
108585	L2	21.1	0.216
108585	2MK3	294.6	0.334
108585	K2	352.1	0.24
108585	M8	168.9	0.081
108585	MS4	287.9	0.052
108586	M2	343.5	4.315
108586	S2	31.7	0.656
108586	N2	300.7	0.693
108586	K1	232.7	1.187
108586	M4	328.7	0.338
108586	O1	222.3	0.879
108586	M6	181.2	0.174
108586	MK3	312	0.221
108586	S4	262.9	0.049
108586	MN4	289	0.104
108586	S6	324.5	0.006
108586	2N2	246	0.343
108586	OO1	318.6	0.036
108586	M1	318.2	0.04
108586	J1	173.3	0.073
108586	Q1	247	0.136
108586	2Q1	53.6	0.04
108586	P1	238.5	0.458
108586	2SM2	149.3	0.012
108586	M3	229.8	0.067
108586	L2	21.7	0.26
108586	2MK3	296.8	0.372
108586	K2	349.9	0.288
108586	M8	161.8	0.105
108586	MS4	304.2	0.065
108587	M2	343.9	4.529
108587	S2	33.6	0.701
108587	N2	301	0.789
108587	K1	231.3	1.251
108587	M4	317.4	0.453
108587	O1	220.2	0.892
108587	M6	189.7	0.221
108587	MK3	296.2	0.209
108587	S4	267.8	0.048
108587	MN4	286.3	0.116
108587	S6	317	0.012
108587	2N2	239.8	0.308
108587	OO1	340.3	0.044
108587	M1	314.7	0.032
108587	J1	189	0.076
108587	Q1	242.2	0.17
108587	2Q1	32.3	0.047
108587	P1	240.1	0.482
108587	2SM2	162.5	0.017
108587	M3	232.7	0.069
108587	L2	25.9	0.222
108587	2MK3	293.4	0.362
108587	K2	350	0.258
108587	M8	158.3	0.097
108587	MS4	338.1	0.108
108588	M2	310.8	2.182
108588	S2	353.7	0.322
108588	N2	255.4	0.529
108588	K1	241.5	0.843
108588	M4	43	0.058
108588	O1	209.4	0.716
108588	M6	127.5	0.168
108588	MK3	318.1	0.189
108588	S4	149.1	0.029
108588	MN4	333.5	0.094
108588	2N2	188.6	0.182
108588	OO1	147.6	0.102
108588	M1	296.2	0.042
108588	J1	185.3	0.121
108588	Q1	222.9	0.106
108588	2Q1	5.5	0.09
108588	P1	208.6	0.146
108588	2SM2	347.7	0.029
108588	M3	178.3	0.105
108588	L2	18	0.318
108588	2MK3	260.8	0.252
108588	K2	336.6	0.232
108588	M8	161.5	0.012
108588	MS4	176	0.138
108589	M2	310.8	2.241
108589	S2	353.3	0.33
108589	N2	255.2	0.543
108589	K1	241.4	0.853
108589	M4	33	0.037
108589	O1	209.3	0.729
108589	M6	127.9	0.179
108589	MK3	317	0.188
108589	S4	144	0.029
108589	MN4	333	0.084
108589	S6	140.4	0.003
108589	2N2	189.2	0.192
108589	OO1	146.8	0.109
108589	M1	297.5	0.042
108589	J1	184.9	0.125
108589	Q1	223.1	0.104
108589	2Q1	6	0.095
108589	P1	206	0.149
108589	2SM2	346	0.027
108589	M3	177.8	0.105
108589	L2	18.5	0.327
108589	2MK3	259.5	0.254
108589	K2	335.7	0.241
108589	M8	144.3	0.014
108589	MS4	180.5	0.14
108590	M2	311	2.231
108590	S2	355.6	0.33
108590	N2	254.9	0.532
108590	K1	242.4	0.857
108590	M4	26.7	0.05
108590	O1	209.6	0.723
108590	M6	124.8	0.175
108590	MK3	312.7	0.192
108590	S4	139	0.033
108590	MN4	333	0.094
108590	S6	103.5	0.003
108590	2N2	188.5	0.194
108590	OO1	147.2	0.107
108590	M1	296.7	0.042
108590	J1	185	0.123
108590	Q1	226.9	0.098
108590	2Q1	6.4	0.101
108590	P1	206.2	0.14
108590	2SM2	347.6	0.023
108590	M3	173.7	0.107
108590	L2	16.6	0.33
108590	2MK3	259.4	0.261
108590	K2	333.6	0.234
108590	M8	133.4	0.012
108590	MS4	175.5	0.139
108591	M2	283.4	0.882
108591	S2	358.9	0.171
108591	N2	240.1	0.154
108591	K1	255.4	0.128
108591	M4	240.3	0.12
108591	O1	212.2	0.125
108591	M6	144.7	0.039
108591	MK3	313.1	0.056
108591	S4	226.6	0.018
108591	MN4	221	0.025
108591	S6	163.6	0.002
108591	2N2	180.5	0.091
108591	OO1	72.3	0.044
108591	M1	54.2	0.008
108591	J1	228.1	0.028
108591	Q1	226.9	0.031
108591	2Q1	98.5	0.014
108591	2SM2	282	0.021
108591	M3	200.6	0.008
108591	L2	327.1	0.05
108591	2MK3	242.8	0.077
108591	M8	308.8	0.012
108591	MS4	236.8	0.059
108592	M2	278.1	1.001
108592	S2	0.2	0.198
108592	N2	234.3	0.159
108592	K1	263	0.16
108592	M4	217.7	0.163
108592	O1	214	0.126
108592	M6	137.7	0.076
108592	MK3	316.2	0.071
108592	S4	236.8	0.026
108592	MN4	161.5	0.039
108592	S6	229	0.005
108592	2N2	166.8	0.101
108592	OO1	71.6	0.052
108592	M1	24.1	0.011
108592	J1	214.4	0.029
108592	Q1	240	0.047
108592	2Q1	97.7	0.019
108592	2SM2	291.8	0.026
108592	M3	210.9	0.013
108592	L2	319.2	0.024
108592	2MK3	250.3	0.088
108592	M8	66.5	0.019
108592	MS4	234.1	0.095
108593	M2	274.1	0.925
108593	S2	359.7	0.204
108593	N2	225.4	0.147
108593	K1	263.2	0.172
108593	M4	198.8	0.142
108593	O1	222.1	0.116
108593	M6	120.5	0.079
108593	MK3	300.3	0.074
108593	S4	255.4	0.023
108593	MN4	150.7	0.053
108593	S6	204.6	0.011
108593	2N2	152.4	0.093
108593	OO1	64.2	0.055
108593	M1	17.8	0.014
108593	J1	200.6	0.027
108593	Q1	231.5	0.053
108593	2Q1	101.8	0.022
108593	2SM2	289.8	0.019
108593	M3	237.5	0.015
108593	L2	74.3	0.007
108593	2MK3	246.8	0.07
108593	M8	51.8	0.029
108593	MS4	234	0.1
108594	M2	350.5	0.128
108594	S2	206.7	0.012
108594	N2	293.5	0.031
108594	K1	234.3	0.104
108594	M4	22.8	0.004
108594	O1	215.4	0.044
108594	M6	22.7	0.001
108594	MK3	197.4	0.007
108594	S4	53.2	0.002
108594	MN4	246.1	0.005
108594	S6	179.6	0.004
108594	2N2	319.4	0.019
108594	OO1	353.5	0.011
108594	M1	140.8	0.006
108594	J1	141.5	0.027
108594	Q1	61.6	0.004
108594	2Q1	269.5	0.019
108594	2SM2	182	0.002
108594	M3	348.9	0.003
108594	L2	314.7	0.004
108594	2MK3	27.1	0.006
108594	M8	108.7	0.001
108594	MS4	192.7	0.001
108595	M2	357.1	0.133
108595	S2	245.4	0.012
108595	N2	310	0.032
108595	K1	240.7	0.105
108595	M4	275.8	0.003
108595	O1	216.9	0.045
108595	M6	334.5	0.002
108595	MK3	161.9	0.004
108595	S4	71	0.004
108595	MN4	287.8	0.01
108595	S6	140.7	0.002
108595	2N2	288.6	0.012
108595	OO1	297.2	0.018
108595	M1	163.1	0.002
108595	J1	142.2	0.02
108595	Q1	165.4	0.023
108595	2Q1	263.9	0.021
108595	2SM2	40.6	0.006
108595	M3	122.3	0.005
108595	L2	232.5	0.017
108595	2MK3	57.3	0.005
108595	M8	90.5	0.002
108595	MS4	63.5	0.003
108596	M2	358	0.069
108596	S2	292	0.005
108596	N2	323.1	0.031
108596	K1	238.9	0.038
108596	M4	192.8	0.003
108596	O1	229.3	0.038
108596	M6	132.8	0.002
108596	MK3	110.4	0.006
108596	S4	323.3	0.005
108596	MN4	140.2	0.004
108596	S6	141.3	0.003
108596	2N2	297.3	0.012
108596	OO1	205.6	0.016
108596	M1	271.8	0.012
108596	J1	352	0.014
108596	Q1	259.7	0.01
108596	2Q1	75.8	0.018
108596	2SM2	228.1	0.012
108596	M3	341.2	0.003
108596	L2	346.4	0.008
108596	2MK3	229	0.005
108596	M8	42.5	0.003
108596	MS4	290.9	0.001
108597	M2	162.4	0.216
108597	S2	152.4	0.059
108597	N2	102.4	0.034
108597	K1	340.5	0.518
108597	M4	261.7	0.008
108597	O1	308.8	0.234
108597	M6	195.4	0.002
108597	MK3	92	0.008
108597	S4	280.5	0.01
108597	MN4	168.5	0.009
108597	S6	354.9	0.009
108597	2N2	127.6	0.007
108597	OO1	143.7	0.01
108597	M1	288.4	0.034
108597	J1	242.2	0.03
108597	Q1	289.1	0.014
108597	2Q1	225	0.016
108597	P1	11.6	0.113
108597	2SM2	293.9	0.031
108597	M3	236.3	0.002
108597	L2	216.3	0.043
108597	2MK3	120.6	0.01
108597	M8	91.4	0.002
108597	MS4	231.2	0.019
108598	M2	164.6	0.256
108598	S2	143.2	0.079
108598	N2	131.7	0.027
108598	K1	337.7	0.678
108598	M4	174.6	0.025
108598	O1	303.2	0.333
108598	M6	353.5	0.007
108598	MK3	25.4	0.021
108598	S4	282	0.002
108598	MN4	95	0.013
108598	S6	225.8	0.004
108598	2N2	223.2	0.03
108598	OO1	188.5	0.075
108598	M1	301	0.038
108598	J1	241.3	0.047
108598	Q1	339	0.025
108598	2Q1	48.1	0.022
108598	P1	342.3	0.201
108598	2SM2	248.6	0.023
108598	M3	149.9	0.023
108598	L2	206	0.044
108598	2MK3	323.2	0.03
108598	M8	293.9	0.003
108598	MS4	159.5	0.014
108599	M2	169.8	0.222
108599	S2	135.6	0.099
108599	N2	170.1	0.039
108599	K1	335.7	0.616
108599	M4	159.6	0.012
108599	O1	306.8	0.28
108599	M6	347.6	0.003
108599	MK3	236.5	0.007
108599	S4	225.7	0.009
108599	MN4	190.2	0.004
108599	S6	224.2	0.004
108599	2N2	221.7	0.04
108599	OO1	185.2	0.061
108599	M1	285.5	0.029
108599	J1	257.3	0.046
108599	Q1	321.9	0.021
108599	2Q1	346.6	0.023
108599	P1	334.2	0.219
108599	2SM2	280.1	0.019
108599	M3	137.7	0.027
108599	L2	232.4	0.068
108599	2MK3	325.2	0.039
108599	M8	275.4	0.004
108599	MS4	150.9	0.012
108600	M2	11.1	0.878
108600	S2	65.6	0.186
108600	N2	338.4	0.187
108600	K1	287	0.362
108600	M4	125.8	0.086
108600	O1	275.7	0.271
108600	M6	234.7	0.025
108600	MK3	39	0.039
108600	S4	342.7	0.02
108600	MN4	125.7	0.066
108600	S6	260.7	0.005
108600	2N2	239	0.058
108600	OO1	284.4	0.039
108600	M1	341.9	0.018
108600	J1	347.8	0.064
108600	Q1	347.6	0.056
108600	2Q1	73.4	0.048
108600	P1	261.2	0.148
108600	2SM2	218.4	0.051
108600	M3	302.4	0.022
108600	L2	5	0.029
108600	2MK3	288.9	0.032
108600	K2	329.1	0.03
108600	M8	352.7	0.02
108600	MS4	30.4	0.007
108601	M2	17	1.031
108601	S2	78.8	0.181
108601	N2	337.3	0.262
108601	K1	292	0.469
108601	M4	151.4	0.108
108601	O1	282.7	0.319
108601	M6	235.4	0.045
108601	MK3	59.2	0.09
108601	S4	333	0.02
108601	MN4	117.3	0.048
108601	S6	269.6	0.007
108601	2N2	254.5	0.032
108601	OO1	247.7	0.04
108601	M1	47.8	0.025
108601	J1	327.3	0.057
108601	Q1	326.9	0.05
108601	2Q1	79.7	0.043
108601	P1	275.6	0.215
108601	2SM2	219.1	0.037
108601	M3	303.5	0.025
108601	L2	30.5	0.055
108601	2MK3	23.6	0.05
108601	K2	49.5	0.055
108601	M8	34.9	0.006
108601	MS4	238.6	0.045
108602	M2	23.4	1.12
108602	S2	58.7	0.202
108602	N2	338.3	0.261
108602	K1	291.4	0.633
108602	M4	179.1	0.096
108602	O1	274.5	0.42
108602	M6	234.2	0.039
108602	MK3	72.5	0.107
108602	S4	352.3	0.028
108602	MN4	91.1	0.037
108602	S6	181.5	0.005
108602	2N2	334.1	0.07
108602	OO1	241.5	0.041
108602	M1	39.4	0.014
108602	J1	291.7	0.051
108602	Q1	326.8	0.038
108602	2Q1	57.3	0.07
108602	P1	279	0.276
108602	2SM2	19.5	0.004
108602	M3	274.4	0.019
108602	L2	58.7	0.068
108602	2MK3	42.6	0.067
108602	K2	105.8	0.179
108602	M8	111.2	0.006
108602	MS4	240.2	0.05
108603	M2	10.2	2.165
108603	S2	65	0.468
108603	N2	319.8	0.563
108603	K1	278.1	1.052
108603	M4	107.2	0.196
108603	O1	258.6	0.774
108603	M6	173.4	0.078
108603	MK3	30.6	0.191
108603	S4	116.3	0.015
108603	MN4	46.5	0.086
108603	S6	56.9	0.005
108603	2N2	276.2	0.168
108603	OO1	217.4	0.093
108603	M1	318.3	0.025
108603	J1	250.2	0.098
108603	Q1	258.2	0.131
108603	2Q1	21.4	0.058
108603	P1	268.9	0.325
108603	2SM2	91.1	0.029
108603	M3	308.2	0.045
108603	L2	83	0.106
108603	2MK3	355.1	0.178
108603	K2	67.2	0.184
108603	M8	217.9	0.01
108603	MS4	181	0.131
108604	M2	12.2	2.689
108604	S2	66	0.601
108604	N2	319	0.703
108604	K1	280.1	1.299
108604	M4	98.9	0.257
108604	O1	258.7	0.964
108604	M6	131.7	0.052
108604	MK3	25.2	0.218
108604	S4	161.2	0.018
108604	MN4	38.6	0.093
108604	S6	68.4	0.008
108604	2N2	278.7	0.197
108604	OO1	218.1	0.108
108604	M1	318.5	0.029
108604	J1	246.8	0.129
108604	Q1	262.4	0.147
108604	2Q1	15.1	0.073
108604	P1	269.3	0.408
108604	2SM2	76	0.035
108604	M3	310.1	0.076
108604	L2	88.9	0.135
108604	2MK3	354.1	0.243
108604	K2	71	0.218
108604	M8	70.2	0.005
108604	MS4	160	0.156
108605	M2	13.8	2.811
108605	S2	67.3	0.626
108605	N2	319.4	0.725
108605	K1	280.6	1.305
108605	M4	91.6	0.292
108605	O1	259.4	0.967
108605	M6	85.6	0.084
108605	MK3	10	0.225
108605	S4	170.3	0.023
108605	MN4	26.9	0.089
108605	S6	38	0.023
108605	2N2	278.7	0.191
108605	OO1	221.4	0.103
108605	M1	324.2	0.028
108605	J1	241.9	0.12
108605	Q1	263	0.125
108605	2Q1	4	0.056
108605	P1	268.6	0.445
108605	2SM2	59	0.028
108605	M3	301.6	0.075
108605	L2	86.4	0.165
108605	2MK3	346.1	0.273
108605	K2	72.1	0.219
108605	M8	53.2	0.016
108605	MS4	147.9	0.168
108606	M2	9.2	2.267
108606	S2	56.5	0.501
108606	N2	316.6	0.543
108606	K1	281.1	1.095
108606	M4	252.4	0.019
108606	O1	259	0.923
108606	M6	321.3	0.042
108606	MK3	35.3	0.02
108606	S4	17.6	0.018
108606	MN4	176.8	0.035
108606	S6	110.5	0.007
108606	2N2	277.8	0.152
108606	OO1	242.3	0.067
108606	M1	319.8	0.047
108606	J1	240	0.101
108606	Q1	250	0.141
108606	2Q1	32.7	0.04
108606	P1	265.2	0.274
108606	2SM2	110.5	0.012
108606	M3	321.5	0.028
108606	L2	98.7	0.131
108606	2MK3	338.1	0.061
108606	K2	69.5	0.157
108606	M8	130.7	0.011
108606	MS4	19.5	0.07
108607	M2	9.6	3.002
108607	S2	55.7	0.637
108607	N2	316.4	0.709
108607	K1	281.1	1.411
108607	M4	332.7	0.046
108607	O1	259.7	1.179
108607	M6	322.4	0.092
108607	MK3	340.6	0.022
108607	S4	20.5	0.017
108607	MN4	198.6	0.034
108607	S6	111.2	0.004
108607	2N2	274.3	0.192
108607	OO1	236.6	0.083
108607	M1	323.7	0.058
108607	J1	243	0.133
108607	Q1	251	0.181
108607	2Q1	34.2	0.061
108607	P1	265	0.358
108607	2SM2	130.2	0.013
108607	M3	312.5	0.035
108607	L2	97.7	0.184
108607	2MK3	319.1	0.092
108607	K2	72.1	0.225
108607	M8	172.2	0.009
108607	MS4	25.8	0.113
108608	M2	10	3.199
108608	S2	56.5	0.665
108608	N2	317.5	0.747
108608	K1	281.8	1.482
108608	M4	313.3	0.054
108608	O1	259.9	1.245
108608	M6	314.7	0.095
108608	S4	5.9	0.019
108608	MN4	176.2	0.026
108608	2N2	271.5	0.181
108608	OO1	233.4	0.082
108608	M1	325.4	0.066
108608	J1	245.7	0.147
108608	Q1	252.1	0.201
108608	2Q1	38.1	0.066
108608	P1	264.5	0.361
108608	2SM2	137.5	0.018
108608	M3	322.6	0.033
108608	L2	97	0.216
108608	2MK3	324.6	0.081
108608	K2	73.4	0.222
108608	M8	220.7	0.009
108608	MS4	19.3	0.114
108609	M2	333.9	1.139
108609	S2	9.5	0.172
108609	N2	283.6	0.242
108609	K1	229.2	0.304
108609	M4	317	0.229
108609	O1	209.1	0.211
108609	M6	198.9	0.058
108609	MK3	225.2	0.082
108609	S4	139.4	0.025
108609	MN4	271.1	0.096
108609	S6	110.8	0.009
108609	2N2	186.5	0.117
108609	OO1	68	0.012
108609	M1	36.5	0.014
108609	J1	307.2	0.033
108609	Q1	214.5	0.067
108609	2Q1	283	0.03
108609	P1	250.1	0.074
108609	2SM2	203	0.025
108609	M3	30.6	0.005
108609	L2	28.2	0.108
108609	2MK3	206.1	0.071
108609	K2	5.2	0.132
108609	M8	164.3	0.028
108609	MS4	13.4	0.1
108610	M2	334.5	1.316
108610	S2	10.3	0.191
108610	N2	285.3	0.281
108610	K1	230.8	0.346
108610	M4	312.7	0.245
108610	O1	211.8	0.248
108610	M6	202.1	0.068
108610	MK3	221.8	0.093
108610	S4	135.1	0.028
108610	MN4	268.3	0.106
108610	S6	18.5	0.007
108610	2N2	184.2	0.13
108610	OO1	181.5	0.003
108610	M1	43.5	0.02
108610	J1	315.9	0.023
108610	Q1	219.4	0.073
108610	2Q1	304.2	0.033
108610	P1	249.9	0.088
108610	2SM2	192.3	0.032
108610	M3	29.8	0.003
108610	L2	25.7	0.115
108610	2MK3	205.8	0.075
108610	K2	5.7	0.149
108610	M8	169.1	0.031
108610	MS4	6.2	0.118
108611	M2	333.1	1.28
108611	S2	13.1	0.217
108611	N2	282.2	0.269
108611	K1	225.4	0.312
108611	M4	313.4	0.272
108611	O1	212	0.214
108611	M6	197.2	0.044
108611	MK3	234.6	0.109
108611	S4	120.6	0.039
108611	MN4	273.6	0.127
108611	S6	340.4	0.012
108611	2N2	181.6	0.138
108611	OO1	113.1	0.01
108611	M1	30.9	0.024
108611	Q1	241.2	0.062
108611	2Q1	311.1	0.027
108611	P1	233.2	0.099
108611	2SM2	188.1	0.041
108611	M3	220.7	0.007
108611	L2	13.9	0.111
108611	2MK3	202.7	0.098
108611	K2	10.2	0.112
108611	M8	164.5	0.016
108611	MS4	0.6	0.126
108612	M2	345.1	2.99
108612	S2	45.1	0.429
108612	N2	300.7	0.549
108612	K1	240.6	0.971
108612	M4	239	0.106
108612	O1	228	0.653
108612	M6	165	0.139
108612	MK3	12.9	0.25
108612	S4	7.6	0.031
108612	MN4	194.7	0.038
108612	2N2	252.4	0.232
108612	OO1	36.1	0.027
108612	M1	323	0.024
108612	J1	170	0.072
108612	Q1	248.1	0.069
108612	2Q1	95.8	0.043
108612	P1	224	0.3
108612	2SM2	139.6	0.019
108612	M3	234.7	0.041
108612	L2	11.8	0.18
108612	2MK3	318.8	0.204
108612	K2	1	0.22
108612	M8	154.4	0.036
108612	MS4	288.9	0.104
108613	M2	345.9	4.148
108613	S2	45	0.594
108613	N2	301.8	0.741
108613	K1	238.4	1.37
108613	M4	294.3	0.138
108613	O1	220.8	0.878
108613	M6	181.4	0.192
108613	MK3	9.3	0.289
108613	S4	352.9	0.032
108613	MN4	267.3	0.042
108613	S6	60.8	0.01
108613	2N2	251.8	0.314
108613	OO1	25.3	0.052
108613	M1	315.4	0.03
108613	J1	166.6	0.107
108613	Q1	235.8	0.096
108613	2Q1	88.6	0.038
108613	P1	223.5	0.407
108613	2SM2	136	0.02
108613	M3	221.4	0.077
108613	L2	19.1	0.243
108613	2MK3	313.2	0.304
108613	K2	359	0.279
108613	M8	152.6	0.046
108613	MS4	306	0.118
108614	M2	346	3.983
108614	S2	51.7	0.527
108614	N2	300.5	0.694
108614	K1	232.2	1.261
108614	M4	318.6	0.328
108614	O1	205.6	0.75
108614	M6	191.2	0.197
108614	MK3	350.7	0.243
108614	S4	256.9	0.015
108614	MN4	301.2	0.114
108614	S6	75.9	0.019
108614	2N2	249	0.274
108614	OO1	41.5	0.046
108614	M1	349.7	0.027
108614	J1	159.4	0.092
108614	Q1	208	0.079
108614	2Q1	58.9	0.04
108614	P1	216.1	0.419
108614	2SM2	158.7	0.025
108614	M3	213.9	0.081
108614	L2	24.3	0.251
108614	2MK3	299.9	0.413
108614	K2	346.2	0.189
108614	M8	149.7	0.064
108614	MS4	346.5	0.101
108615	M2	5.1	0.261
108615	S2	301.2	0.061
108615	N2	317.4	0.088
108615	K1	62.3	0.43
108615	M4	334.9	0.009
108615	O1	339.3	0.172
108615	M6	311.9	0.008
108615	MK3	37.9	0.074
108615	S4	87.1	0.015
108615	MN4	318.5	0.016
108615	S6	32.4	0.011
108615	2N2	292.9	0.05
108615	OO1	234	0.061
108615	M1	18.8	0.022
108615	J1	322.7	0.075
108615	Q1	291.1	0.038
108615	2Q1	266.9	0.027
108615	2SM2	133.7	0.023
108615	M3	250.8	0.046
108615	L2	44.3	0.061
108615	2MK3	167.8	0.008
108615	M8	176.1	0.005
108615	MS4	244.3	0.024
108616	M2	7	0.273
108616	S2	307.2	0.089
108616	N2	320.7	0.104
108616	K1	64.1	0.461
108616	M4	130.7	0.005
108616	O1	335.6	0.187
108616	M6	279.5	0.002
108616	MK3	40.3	0.062
108616	S4	116.7	0.016
108616	MN4	352.7	0.023
108616	S6	52.5	0.009
108616	2N2	289.6	0.05
108616	OO1	253.9	0.061
108616	M1	27.5	0.019
108616	J1	315.2	0.088
108616	Q1	304.9	0.041
108616	2Q1	246.3	0.022
108616	2SM2	140.5	0.032
108616	M3	255.9	0.049
108616	L2	56.7	0.076
108616	2MK3	110.7	0.017
108616	MS4	186	0.01
108617	M2	8.6	0.292
108617	S2	314.7	0.084
108617	N2	323.6	0.097
108617	K1	61.6	0.436
108617	M4	86.2	0.011
108617	O1	325.6	0.166
108617	M6	341.4	0.009
108617	MK3	62.1	0.074
108617	S4	145	0.016
108617	MN4	28.9	0.01
108617	S6	126.1	0.009
108617	2N2	274.5	0.043
108617	OO1	247.5	0.082
108617	M1	345.3	0.021
108617	J1	308.7	0.107
108617	Q1	326.3	0.022
108617	2Q1	279.8	0.028
108617	2SM2	155.8	0.062
108617	M3	244.7	0.036
108617	L2	55.5	0.096
108617	2MK3	79.7	0.021
108617	M8	154.2	0.003
108617	MS4	52.4	0.009
108618	M2	294.9	0.249
108618	S2	310.7	0.073
108618	N2	218.5	0.071
108618	K1	324.4	0.377
108618	M4	27.9	0.017
108618	O1	243.3	0.227
108618	M6	124.1	0.005
108618	MK3	52.6	0.056
108618	S4	184	0.012
108618	MN4	308.8	0.008
108618	S6	234.5	0.008
108618	2N2	328.4	0.027
108618	OO1	157.7	0.079
108618	M1	285.6	0.041
108618	J1	250.4	0.058
108618	Q1	189.7	0.065
108618	2Q1	202.5	0.036
108618	2SM2	107.7	0.028
108618	M3	257.8	0.021
108618	L2	4.7	0.037
108618	2MK3	288.9	0.021
108618	M8	356.5	0.002
108618	MS4	22	0.013
108619	M2	300.5	0.243
108619	S2	307.9	0.084
108619	N2	219.7	0.068
108619	K1	329.8	0.365
108619	M4	77.9	0.017
108619	O1	247	0.233
108619	M6	145	0.002
108619	MK3	58.8	0.049
108619	S4	324.4	0.007
108619	MN4	350.3	0.013
108619	S6	89.2	0.004
108619	2N2	317.8	0.012
108619	OO1	174.1	0.087
108619	M1	304.3	0.051
108619	J1	245.2	0.095
108619	Q1	206.7	0.089
108619	2Q1	231.6	0.028
108619	2SM2	195.3	0.004
108619	M3	270.8	0.031
108619	L2	24.4	0.064
108619	2MK3	332.2	0.013
108619	M8	245.2	0.002
108619	MS4	353.6	0.014
108620	M2	299	0.208
108620	S2	329.4	0.055
108620	N2	238	0.086
108620	K1	334.9	0.359
108620	M4	336.2	0.011
108620	O1	255.8	0.199
108620	M6	133.9	0.004
108620	MK3	48	0.027
108620	S4	37.4	0.006
108620	MN4	346.4	0.01
108620	S6	337.3	0.004
108620	2N2	274.4	0.008
108620	OO1	165.4	0.072
108620	M1	295.9	0.062
108620	J1	227.4	0.079
108620	Q1	192.3	0.079
108620	2Q1	215.1	0.033
108620	2SM2	166.9	0.015
108620	M3	263.4	0.041
108620	L2	27	0.065
108620	2MK3	226.1	0.008
108620	M8	139.9	0.003
108620	MS4	309.1	0.012
108621	M2	343.3	3.352
108621	S2	0.1	0.502
108621	N2	304.2	0.767
108621	K1	231.9	0.782
108621	M4	207.4	0.139
108621	O1	221.2	0.37
108621	M6	144	0.294
108621	MK3	288.8	0.101
108621	MN4	191.5	0.017
108621	NU2	320.7	0.177
108621	MU2	145.2	0.139
108621	2N2	313.8	0.035
108621	OO1	359.6	0.009
108621	LDA2	347.6	0.083
108621	M1	241.3	0.029
108621	J1	120.2	0.043
108621	MM	125.8	0.014
108621	SSA	281.9	0.005
108621	MSF	290	0.021
108621	MF	110.6	0.02
108621	RHO1	285.9	0.008
108621	Q1	221.7	0.037
108621	T2	1.4	0.031
108621	R2	203.6	0.006
108621	2Q1	13.3	0.007
108621	P1	222	0.241
108621	2SM2	171.9	0.011
108621	M3	197.1	0.131
108621	L2	29.7	0.2
108621	2MK3	272.4	0.219
108621	K2	353.2	0.17
108621	M8	4	0.054
108621	MS4	274.3	0.018
108622	M2	328.2	3.461
108622	S2	5.6	0.526
108622	N2	304.3	0.667
108622	K1	64.9	0.175
108622	M4	61.7	0.198
108622	O1	19.4	0.118
108622	M6	129.7	0.272
108622	MK3	99.4	0.034
108622	S4	43.1	0.02
108622	MN4	21.3	0.087
108622	NU2	304	0.165
108622	S6	356	0.009
108622	MU2	123.1	0.056
108622	2N2	267	0.06
108622	OO1	158.7	0.005
108622	LDA2	348.2	0.093
108622	S1	229.7	0.043
108622	M1	122.1	0.015
108622	J1	224.4	0.004
108622	RHO1	15.5	0.007
108622	Q1	344.5	0.015
108622	T2	1.2	0.033
108622	R2	260	0.018
108622	2Q1	106.4	0.01
108622	P1	75.7	0.045
108622	2SM2	230	0.022
108622	M3	28.1	0.035
108622	L2	356.9	0.288
108622	2MK3	49.2	0.071
108622	K2	4.7	0.145
108622	M8	254.8	0.025
108622	MS4	141.9	0.081
108623	M2	327.6	3.724
108623	S2	7.4	0.515
108623	N2	303.3	0.682
108623	K1	57.8	0.179
108623	M4	103.7	0.283
108623	O1	16.4	0.133
108623	M6	126.9	0.358
108623	MK3	141.5	0.029
108623	S4	79.8	0.024
108623	MN4	67.6	0.092
108623	NU2	303.6	0.191
108623	S6	10	0.006
108623	MU2	122.5	0.098
108623	2N2	259.4	0.06
108623	OO1	144.6	0.009
108623	LDA2	337.8	0.102
108623	S1	130.2	0.045
108623	M1	121.2	0.019
108623	J1	300.1	0.008
108623	RHO1	104.7	0.005
108623	Q1	341.3	0.02
108623	T2	359.1	0.023
108623	R2	281.4	0.026
108623	2Q1	104.5	0.01
108623	P1	72.7	0.047
108623	2SM2	227.5	0.022
108623	M3	28.7	0.036
108623	L2	358.7	0.353
108623	2MK3	57.6	0.074
108623	K2	3.4	0.147
108623	M8	266.3	0.053
108623	MS4	153.6	0.116
108624	M2	328.8	3.719
108624	S2	9.3	0.514
108624	N2	305	0.716
108624	K1	65.2	0.187
108624	M4	82	0.431
108624	O1	25.6	0.116
108624	M6	126.2	0.308
108624	MK3	148.9	0.053
108624	S4	71.5	0.03
108624	MN4	40.4	0.153
108624	NU2	306.2	0.186
108624	MU2	116	0.102
108624	2N2	256.8	0.067
108624	OO1	149.6	0.003
108624	LDA2	345.5	0.105
108624	S1	119.2	0.064
108624	M1	132	0.018
108624	J1	345.4	0.015
108624	RHO1	303.6	0.006
108624	Q1	49.2	0.012
108624	T2	14	0.036
108624	R2	267.2	0.009
108624	2Q1	66.7	0.01
108624	P1	92.6	0.043
108624	2SM2	222.9	0.014
108624	M3	26.8	0.034
108624	L2	359.5	0.333
108624	2MK3	83.9	0.081
108624	K2	0.5	0.146
108624	M8	245.4	0.085
108624	MS4	130.3	0.127
108625	M2	39	1.148
108625	S2	60.5	0.229
108625	N2	13.7	0.305
108625	K1	199.2	0.282
108625	M4	217	0.008
108625	O1	217	0.243
108625	M6	55.9	0.022
108625	MK3	211.3	0.014
108625	S4	308.6	0.012
108625	MN4	137.5	0.014
108625	NU2	7.1	0.049
108625	S6	93.3	0.004
108625	MU2	6.9	0.036
108625	2N2	351.9	0.051
108625	OO1	314.1	0.023
108625	LDA2	110.6	0.024
108625	M1	254.1	0.04
108625	J1	233.2	0.03
108625	RHO1	257.2	0.015
108625	Q1	166.7	0.086
108625	2Q1	352.6	0.035
108625	P1	237.7	0.098
108625	2SM2	14.8	0.034
108625	M3	75.5	0.023
108625	L2	109.6	0.034
108625	2MK3	153.1	0.008
108625	K2	56.5	0.046
108625	M8	35.8	0.012
108625	MS4	184.3	0.024
108626	M2	30.8	1.164
108626	S2	55.8	0.244
108626	N2	9	0.316
108626	K1	189.4	0.23
108626	M4	6	0.015
108626	O1	205.3	0.213
108626	M6	301.9	0.02
108626	MK3	130.5	0.013
108626	S4	9.7	0.007
108626	MN4	79.3	0.006
108626	NU2	344.7	0.048
108626	S6	163.3	0.012
108626	MU2	5.1	0.042
108626	2N2	6.9	0.053
108626	OO1	271.9	0.019
108626	LDA2	77.9	0.029
108626	M1	235.9	0.053
108626	J1	199.9	0.031
108626	RHO1	227.3	0.002
108626	Q1	156.9	0.088
108626	2Q1	278.8	0.023
108626	P1	237.1	0.098
108626	2SM2	30.2	0.017
108626	M3	46.4	0.033
108626	L2	31.7	0.037
108626	2MK3	135.4	0.008
108626	K2	65.8	0.05
108626	M8	262.6	0.009
108626	MS4	127	0.026
108627	M2	20.4	0.932
108627	S2	50.4	0.211
108627	N2	1.7	0.242
108627	K1	167.2	0.173
108627	M4	7.4	0.047
108627	O1	186.3	0.174
108627	M6	277.5	0.03
108627	MK3	0.3	0.017
108627	S4	355.1	0.008
108627	MN4	314	0.02
108627	NU2	318.1	0.027
108627	S6	150.2	0.001
108627	MU2	16.9	0.03
108627	2N2	353.1	0.044
108627	OO1	294.9	0.022
108627	LDA2	47.9	0.029
108627	M1	229.1	0.038
108627	J1	205.2	0.026
108627	RHO1	230.3	0.011
108627	Q1	158.9	0.056
108627	2Q1	228.8	0.024
108627	P1	217	0.077
108627	2SM2	86.2	0.011
108627	M3	346.1	0.017
108627	L2	345.4	0.037
108627	2MK3	46.9	0.024
108627	K2	38	0.047
108627	M8	251.3	0.007
108627	MS4	51.9	0.029
108628	M2	61.9	1.03
108628	S2	81.3	0.185
108628	N2	32.7	0.223
108628	K1	211.7	0.183
108628	M4	272.7	0.031
108628	O1	227	0.156
108628	M6	231.4	0.004
108628	MK3	18.1	0.017
108628	S4	348.5	0.012
108628	MN4	239.4	0.019
108628	NU2	42.4	0.059
108628	S6	220.3	0.002
108628	MU2	0.3	0.065
108628	2N2	19.9	0.013
108628	OO1	146.7	0.029
108628	LDA2	161.6	0.046
108628	M1	189.2	0.014
108628	J1	191.8	0.012
108628	RHO1	183.2	0.012
108628	Q1	182	0.04
108628	2Q1	112.1	0.029
108628	P1	222.2	0.101
108628	2SM2	43.8	0.017
108628	M3	134.1	0.011
108628	L2	133.8	0.037
108628	2MK3	149	0.007
108628	K2	101.9	0.062
108628	MS4	224.7	0.009
108629	M2	50.6	0.64
108629	S2	86.2	0.102
108629	N2	22.3	0.141
108629	K1	228.2	0.12
108629	M4	290.9	0.024
108629	O1	244.4	0.106
108629	M6	346.3	0.013
108629	MK3	178.9	0.014
108629	S4	335.8	0.008
108629	MN4	237.9	0.013
108629	NU2	16.5	0.03
108629	S6	30	0.003
108629	MU2	353.5	0.012
108629	2N2	354.3	0.023
108629	OO1	261.2	0.011
108629	LDA2	225.9	0.01
108629	M1	264.2	0.009
108629	J1	87.3	0.001
108629	RHO1	85.9	0.017
108629	Q1	215.9	0.034
108629	2Q1	144.1	0.025
108629	P1	248	0.055
108629	2SM2	11.9	0.004
108629	M3	63.8	0.014
108629	L2	55.7	0.033
108629	2MK3	114.3	0.008
108629	K2	97.1	0.038
108629	M8	203.2	0.004
108629	MS4	261.4	0.003
108630	M2	46.9	0.551
108630	S2	85.6	0.103
108630	N2	28.5	0.126
108630	K1	204.6	0.09
108630	M4	300.4	0.036
108630	O1	227.4	0.077
108630	M6	321.4	0.007
108630	MK3	106.7	0.012
108630	S4	2.3	0.005
108630	MN4	268.5	0.012
108630	NU2	11.6	0.037
108630	S6	30.1	0.002
108630	MU2	27.7	0.013
108630	2N2	6.1	0.025
108630	OO1	351	0.006
108630	LDA2	227.7	0.01
108630	M1	234	0.021
108630	J1	307.4	0.006
108630	RHO1	165.3	0.009
108630	Q1	204	0.042
108630	2Q1	129.7	0.016
108630	P1	233.9	0.041
108630	2SM2	285.2	0.004
108630	M3	322.8	0.009
108630	L2	40.8	0.026
108630	2MK3	135.4	0.008
108630	K2	97.6	0.033
108630	M8	203.9	0.007
108630	MS4	36.2	0.007
108631	M2	21.8	0.977
108631	S2	40.8	0.186
108631	N2	354.3	0.283
108631	K1	150	0.111
108631	M4	260.9	0.044
108631	O1	174.6	0.116
108631	M6	27.3	0.014
108631	MK3	350.2	0.009
108631	S4	259.1	0.011
108631	MN4	222	0.027
108631	NU2	331.6	0.032
108631	S6	354.7	0.004
108631	MU2	346.7	0.07
108631	2N2	325.9	0.04
108631	OO1	154.5	0.007
108631	LDA2	124.7	0.016
108631	S1	141	0.054
108631	M1	161	0.017
108631	J1	148.1	0.022
108631	RHO1	195.8	0.005
108631	Q1	165.9	0.026
108631	T2	331.3	0.02
108631	R2	22.6	0.056
108631	2Q1	87.5	0.014
108631	2SM2	41.3	0.017
108631	M3	54	0.019
108631	L2	206.4	0.006
108631	2MK3	213	0.006
108631	K2	54	0.073
108631	M8	84.4	0.005
108631	MS4	230.6	0.023
108632	M2	21.2	0.857
108632	S2	61.6	0.194
108632	N2	353.9	0.258
108632	K1	155.1	0.1
108632	M4	280.1	0.05
108632	O1	183.4	0.103
108632	M6	130.6	0.007
108632	MK3	7.1	0.02
108632	S4	260.3	0.011
108632	MN4	230.4	0.035
108632	NU2	353.9	0.033
108632	S6	320.1	0.008
108632	MU2	347.4	0.077
108632	2N2	323.1	0.032
108632	OO1	166	0.007
108632	LDA2	225.3	0.02
108632	S1	154.6	0.025
108632	M1	163.2	0.022
108632	J1	157	0.028
108632	RHO1	199.2	0.008
108632	Q1	139.1	0.016
108632	T2	89.4	0.035
108632	R2	343.8	0.071
108632	2Q1	79.7	0.006
108632	2SM2	41.3	0.014
108632	M3	5.8	0.011
108632	L2	237.6	0.016
108632	2MK3	257.8	0.005
108632	K2	45.6	0.083
108632	M8	40	0.008
108632	MS4	238.2	0.029
108633	M2	22.8	0.683
108633	S2	57.5	0.181
108633	N2	359.3	0.196
108633	K1	162.5	0.076
108633	M4	240.7	0.099
108633	O1	203.9	0.066
108633	M6	50.5	0.015
108633	MK3	340.7	0.031
108633	S4	273.5	0.005
108633	MN4	210.6	0.057
108633	NU2	10.2	0.035
108633	S6	305.3	0.007
108633	MU2	2.3	0.078
108633	2N2	338.3	0.022
108633	OO1	196.7	0.007
108633	LDA2	242.4	0.036
108633	S1	294	0.035
108633	M1	185.7	0.027
108633	J1	163.3	0.041
108633	RHO1	170.2	0.011
108633	Q1	59.5	0.012
108633	T2	72.4	0.029
108633	2Q1	274.9	0.006
108633	2SM2	152	0.003
108633	M3	226.6	0.007
108633	L2	264.9	0.019
108633	2MK3	356.9	0.02
108633	K2	60.6	0.045
108633	M8	312.8	0.001
108633	MS4	259.4	0.034
108634	M2	17.3	0.473
108634	S2	40.6	0.16
108634	N2	8.1	0.079
108634	K1	176	0.058
108634	M4	199.4	0.157
108634	O1	240.1	0.061
108634	M6	353.2	0.063
108634	MK3	240.1	0.01
108634	S4	20.6	0.005
108634	MN4	170.4	0.037
108634	NU2	32.3	0.041
108634	S6	138.6	0.002
108634	MU2	66	0.042
108634	2N2	313.9	0.022
108634	OO1	163.4	0.01
108634	LDA2	316.2	0.01
108634	S1	306.2	0.016
108634	M1	208.6	0.022
108634	J1	215.1	0.012
108634	RHO1	160	0.009
108634	Q1	37.3	0.009
108634	T2	59.8	0.053
108634	R2	215.9	0.116
108634	2Q1	325.6	0.007
108634	2SM2	161.9	0.017
108634	M3	345.5	0.002
108634	L2	34.5	0.043
108634	2MK3	16.5	0.014
108634	K2	296.7	0.039
108634	M8	105.3	0.006
108634	MS4	190.6	0.031
108635	M2	345	0.772
108635	S2	21	0.091
108635	N2	325.5	0.156
108635	K1	73.3	0.085
108635	M4	283.2	0.205
108635	O1	105.3	0.085
108635	M6	244.8	0.059
108635	MK3	46.6	0.071
108635	S4	269.7	0.013
108635	MN4	254.6	0.103
108635	NU2	320.4	0.03
108635	S6	336.1	0.008
108635	MU2	59.8	0.011
108635	2N2	328.9	0.017
108635	OO1	230.5	0.01
108635	LDA2	49.3	0.021
108635	S1	127.9	0.034
108635	M1	108.3	0.01
108635	J1	180.2	0.003
108635	RHO1	178.9	0.005
108635	Q1	73.5	0.011
108635	T2	82	0.019
108635	R2	18.7	0.035
108635	2Q1	230.5	0.013
108635	P1	266.6	0.017
108635	2SM2	255.6	0.009
108635	M3	3.3	0.024
108635	L2	18.7	0.082
108635	2MK3	76.5	0.056
108635	K2	12.1	0.037
108635	M8	252.1	0.019
108635	MS4	312	0.057
108636	M2	346.2	0.761
108636	S2	30	0.132
108636	N2	334.4	0.171
108636	K1	91.2	0.083
108636	M4	282.1	0.184
108636	O1	102.3	0.086
108636	M6	236.6	0.046
108636	MK3	49.2	0.057
108636	S4	289.9	0.006
108636	MN4	268.3	0.078
108636	NU2	281.5	0.036
108636	S6	347.1	0.007
108636	MU2	358.7	0.021
108636	2N2	346.3	0.028
108636	OO1	277.2	0.004
108636	LDA2	45.8	0.034
108636	S1	96.5	0.013
108636	M1	78.4	0.008
108636	J1	135.2	0.006
108636	RHO1	325.3	0.01
108636	Q1	86.5	0.018
108636	T2	39	0.031
108636	R2	333	0.019
108636	2Q1	240.5	0.005
108636	P1	102.7	0.013
108636	2SM2	15.7	0.004
108636	M3	345.2	0.018
108636	L2	348.7	0.047
108636	2MK3	71.5	0.045
108636	K2	12	0.045
108636	M8	230.8	0.013
108636	MS4	320.6	0.036
108637	M2	347.2	0.764
108637	S2	22.3	0.128
108637	N2	333	0.167
108637	K1	84.8	0.093
108637	M4	292.3	0.124
108637	O1	103.4	0.088
108637	M6	209.6	0.032
108637	MK3	55.8	0.048
108637	S4	342.3	0.007
108637	MN4	266.1	0.058
108637	NU2	285.1	0.031
108637	S6	15.3	0.005
108637	MU2	350.1	0.019
108637	2N2	354.8	0.029
108637	OO1	255.4	0.002
108637	LDA2	41	0.039
108637	S1	114.8	0.02
108637	M1	96.2	0.004
108637	J1	163.3	0.008
108637	RHO1	319.7	0.006
108637	Q1	77.6	0.017
108637	T2	36.2	0.026
108637	2Q1	191.5	0.003
108637	P1	42.5	0.007
108637	2SM2	315.9	0.003
108637	M3	9.1	0.015
108637	L2	342.3	0.052
108637	2MK3	81.7	0.039
108637	K2	3.6	0.031
108637	M8	178.4	0.012
108637	MS4	319.7	0.028
108638	M2	17.5	1.279
108638	S2	47.5	0.259
108638	N2	4.2	0.266
108638	K1	167.3	0.188
108638	M4	331	0.187
108638	O1	163.4	0.141
108638	M6	298	0.038
108638	MK3	68.4	0.031
108638	S4	354.7	0.024
108638	MN4	311.7	0.065
108638	NU2	6	0.072
108638	S6	213.3	0.008
108638	MU2	79.1	0.049
108638	2N2	20.1	0.039
108638	OO1	34.6	0.002
108638	LDA2	51.5	0.029
108638	M1	92.8	0.017
108638	J1	352	0.012
108638	RHO1	140.2	0.019
108638	Q1	145.5	0.022
108638	2Q1	51.2	0.019
108638	P1	156.5	0.05
108638	2SM2	11.7	0.022
108638	M3	359.6	0.019
108638	L2	52.6	0.105
108638	2MK3	73.3	0.036
108638	K2	38.3	0.06
108638	M8	62.9	0.007
108638	MS4	45.3	0.049
108639	M2	15.3	1.232
108639	S2	47.6	0.26
108639	N2	359.9	0.231
108639	K1	170.8	0.175
108639	M4	335.1	0.137
108639	O1	168.8	0.137
108639	M6	264.3	0.036
108639	MK3	43.7	0.032
108639	S4	355.1	0.021
108639	MN4	322	0.047
108639	NU2	334.4	0.049
108639	S6	220	0.004
108639	MU2	52.7	0.046
108639	2N2	12	0.049
108639	OO1	147.9	0.004
108639	LDA2	16	0.03
108639	M1	95.1	0.015
108639	J1	304	0.011
108639	RHO1	119.8	0.014
108639	Q1	139.5	0.02
108639	2Q1	60.3	0.019
108639	P1	166.5	0.053
108639	2SM2	357.8	0.016
108639	M3	352.8	0.011
108639	L2	47.2	0.101
108639	2MK3	60.1	0.036
108639	K2	39.6	0.062
108639	M8	185.3	0.007
108639	MS4	53.4	0.055
108640	M2	11.8	1.176
108640	S2	48.8	0.247
108640	N2	353	0.193
108640	K1	170.4	0.157
108640	M4	12.3	0.069
108640	O1	173.6	0.123
108640	M6	239	0.064
108640	MK3	12.6	0.029
108640	S4	320.6	0.015
108640	MN4	353.7	0.03
108640	NU2	278.1	0.067
108640	S6	305.1	0.009
108640	MU2	41.6	0.046
108640	2N2	10.2	0.056
108640	OO1	132.9	0.002
108640	LDA2	6.3	0.056
108640	M1	116	0.012
108640	J1	297	0.012
108640	RHO1	112.5	0.024
108640	Q1	131.9	0.029
108640	2Q1	75.5	0.018
108640	P1	171.2	0.049
108640	2SM2	335.8	0.015
108640	M3	354.5	0.01
108640	L2	36.2	0.111
108640	2MK3	27.5	0.035
108640	K2	41.8	0.061
108640	M8	255.5	0.019
108640	MS4	39	0.046
108641	M2	358.2	0.608
108641	S2	39.9	0.173
108641	N2	295.7	0.111
108641	K1	193.8	0.082
108641	M4	259.9	0.148
108641	O1	127.1	0.059
108641	M6	240.8	0.07
108641	MK3	26.5	0.049
108641	S4	305.4	0.035
108641	MN4	168.6	0.057
108641	S6	32.2	0.013
108641	2N2	0.4	0.064
108641	OO1	118	0.074
108641	M1	341.8	0.04
108641	J1	322.7	0.023
108641	Q1	225.1	0.035
108641	2Q1	62.2	0.04
108641	P1	239.5	0.027
108641	2SM2	342.4	0.009
108641	M3	57	0.02
108641	L2	65.4	0.062
108641	2MK3	344.6	0.069
108641	K2	285.5	0.1
108641	M8	159.5	0.027
108641	MS4	204.9	0.049
108642	M2	113.3	0.502
108642	S2	140	0.085
108642	N2	95.9	0.1
108642	K1	254.5	0.078
108642	M4	123.7	0.015
108642	O1	268.1	0.081
108642	M6	128.5	0.004
108642	MK3	96.3	0.008
108642	S4	121.5	0.001
108642	MN4	97	0.009
108642	NU2	125.6	0.031
108642	S6	308.2	0.002
108642	MU2	93.9	0.015
108642	2N2	101.3	0.018
108642	OO1	291.8	0.003
108642	LDA2	174.3	0.005
108642	M1	161.7	0.001
108642	J1	128.7	0.013
108642	RHO1	239.7	0.003
108642	Q1	261.2	0.023
108642	2Q1	312.3	0.009
108642	P1	239.4	0.03
108642	2SM2	142.9	0.016
108642	M3	259.8	0.001
108642	L2	157.3	0.034
108642	2MK3	178.3	0.004
108642	K2	149.5	0.011
108642	M8	2	0.002
108642	MS4	207.5	0.002
108643	M2	106.6	0.431
108643	S2	132.1	0.076
108643	N2	92	0.094
108643	K1	289.8	0.092
108643	M4	110.1	0.026
108643	O1	281.1	0.081
108643	M6	46.1	0.002
108643	MK3	279.8	0.003
108643	S4	133.9	0.008
108643	MN4	82.5	0.012
108643	NU2	105.4	0.018
108643	S6	39	0.004
108643	MU2	81.7	0.016
108643	2N2	67.5	0.023
108643	OO1	94.1	0.007
108643	LDA2	150.9	0.006
108643	M1	43.2	0.006
108643	J1	73.4	0.008
108643	RHO1	39.4	0.018
108643	Q1	236	0.02
108643	2Q1	271.6	0.011
108643	P1	246.4	0.063
108643	2SM2	158.6	0.011
108643	M3	228.9	0.007
108643	L2	160.4	0.027
108643	2MK3	324.7	0.006
108643	K2	156.9	0.012
108643	M8	15.5	0.002
108643	MS4	199	0.005
108644	M2	94	0.316
108644	S2	120.4	0.052
108644	N2	77.5	0.084
108644	K1	276.1	0.058
108644	M4	94	0.027
108644	O1	279.3	0.051
108644	M6	87.9	0.006
108644	MK3	235	0.012
108644	S4	91.9	0.001
108644	MN4	63.6	0.013
108644	NU2	69.7	0.037
108644	S6	92.7	0.003
108644	MU2	50.3	0.011
108644	2N2	42.6	0.032
108644	OO1	42.1	0.003
108644	LDA2	357.6	0.018
108644	M1	332.1	0.005
108644	J1	119.5	0.006
108644	RHO1	78.9	0.006
108644	Q1	243.4	0.012
108644	2Q1	204	0.011
108644	P1	236.9	0.035
108644	2SM2	165.5	0.008
108644	M3	182.1	0.007
108644	L2	110.8	0.008
108644	2MK3	264.7	0.004
108644	K2	133.2	0.016
108644	M8	300.4	0.001
108644	MS4	238.5	0.001
108645	M2	152.9	0.414
108645	S2	192.8	0.072
108645	N2	132.9	0.093
108645	K1	248.1	0.045
108645	M4	272.5	0.015
108645	O1	250.2	0.046
108645	M6	3.8	0.002
108645	MK3	309.9	0.007
108645	S4	16.3	0.004
108645	MN4	249.5	0.008
108645	NU2	141	0.024
108645	S6	335.8	0.002
108645	MU2	171.3	0.008
108645	2N2	103.9	0.01
108645	OO1	191.5	0.004
108645	LDA2	149.9	0.009
108645	M1	197.9	0.003
108645	J1	207.3	0.013
108645	RHO1	111.3	0.007
108645	Q1	235	0.01
108645	2Q1	255	0.003
108645	P1	235.2	0.032
108645	2SM2	27.6	0.003
108645	M3	205.1	0.003
108645	L2	182.9	0.019
108645	2MK3	310.3	0.004
108645	K2	179.4	0.027
108645	M8	84.5	0.004
108645	MS4	42.3	0.005
108646	M2	153.9	0.435
108646	S2	187.5	0.076
108646	N2	130.4	0.086
108646	K1	240.1	0.053
108646	M4	294.4	0.016
108646	O1	245.6	0.054
108646	M6	263.5	0.005
108646	MK3	37.9	0.005
108646	S4	57.5	0.004
108646	MN4	328	0.006
108646	NU2	124.6	0.035
108646	S6	355.9	0.009
108646	MU2	128.4	0.011
108646	2N2	111.5	0.012
108646	OO1	291.8	0.006
108646	LDA2	92.1	0.013
108646	M1	195.8	0.006
108646	J1	235	0.01
108646	RHO1	163.1	0.005
108646	Q1	285.7	0.012
108646	2Q1	300.4	0.004
108646	P1	194.7	0.017
108646	2SM2	168	0.008
108646	M3	41.4	0.004
108646	L2	182.3	0.031
108646	2MK3	337.8	0.007
108646	K2	160.8	0.021
108646	M8	338.1	0.001
108646	MS4	0.8	0.005
108647	M2	142.3	0.329
108647	S2	168.1	0.054
108647	N2	117.1	0.073
108647	K1	223.7	0.032
108647	M4	238.8	0.021
108647	O1	246	0.039
108647	M6	317.8	0.006
108647	MK3	358.3	0.01
108647	S4	179.2	0.002
108647	MN4	255.4	0.01
108647	NU2	28.7	0.021
108647	S6	247.3	0.003
108647	MU2	54	0.012
108647	2N2	90.7	0.017
108647	OO1	301.9	0.003
108647	LDA2	173.2	0.02
108647	M1	89.8	0.004
108647	J1	314.7	0.004
108647	RHO1	342.9	0.006
108647	Q1	295.3	0.015
108647	2Q1	303	0.01
108647	P1	145.8	0.021
108647	2SM2	59.1	0.006
108647	M3	47.6	0.002
108647	L2	140.6	0.022
108647	2MK3	312.2	0.005
108647	K2	145.7	0.014
108647	M8	94.6	0.002
108647	MS4	204.8	0.003
108648	M2	202.4	0.631
108648	S2	232.5	0.06
108648	N2	177.1	0.144
108648	K1	251.2	0.198
108648	M4	9.5	0.024
108648	O1	271.5	0.138
108648	M6	319.2	0.012
108648	MK3	39.8	0.016
108648	S4	281.2	0.008
108648	MN4	328.1	0.008
108648	NU2	182.9	0.029
108648	S6	0	0.004
108648	MU2	316.5	0.003
108648	2N2	149.2	0.008
108648	OO1	288	0.013
108648	LDA2	256.5	0.024
108648	S1	198.8	0.07
108648	M1	8.2	0.013
108648	J1	244.3	0.014
108648	RHO1	179.5	0.012
108648	Q1	246.8	0.039
108648	T2	199.1	0.023
108648	R2	27.6	0.033
108648	2Q1	154.1	0.007
108648	P1	227.6	0.079
108648	2SM2	53.8	0.004
108648	M3	292.8	0.007
108648	L2	203.3	0.05
108648	2MK3	46.6	0.017
108648	K2	217.2	0.046
108648	M8	104.9	0.004
108648	MS4	20.4	0.01
108649	M2	291.4	0.778
108649	S2	304.7	0.127
108649	N2	257.7	0.154
108649	K1	298.9	0.172
108649	M4	137.3	0.107
108649	O1	307.8	0.161
108649	M6	226.4	0.017
108649	MK3	119.5	0.021
108649	S4	310.7	0.005
108649	MN4	108.7	0.036
108649	S6	172	0.008
108649	2N2	243.7	0.032
108649	OO1	157.3	0.029
108649	M1	325.1	0.016
108649	J1	318.9	0.011
108649	Q1	269.4	0.056
108649	2Q1	34.2	0.07
108649	2SM2	62.3	0.016
108649	M3	259.4	0.022
108649	L2	290.3	0.068
108649	2MK3	142.1	0.032
108649	M8	125.8	0.005
108649	MS4	121.6	0.032
108650	M2	287.5	0.748
108650	S2	304.2	0.101
108650	N2	265.5	0.211
108650	K1	296	0.176
108650	M4	95.2	0.067
108650	O1	297.9	0.16
108650	M6	171.6	0.026
108650	MK3	43.6	0.028
108650	S4	256.1	0.011
108650	MN4	50.5	0.042
108650	S6	117.9	0.011
108650	2N2	275.4	0.058
108650	OO1	144.9	0.015
108650	M1	344.8	0.01
108650	J1	316	0.022
108650	Q1	270.5	0.06
108650	2Q1	40.2	0.055
108650	2SM2	27.8	0.012
108650	M3	182.5	0.028
108650	L2	145.3	0.026
108650	2MK3	109.5	0.03
108650	M8	48.8	0.004
108650	MS4	72.8	0.022
108651	M2	279.9	0.754
108651	S2	299.8	0.09
108651	N2	260.3	0.202
108651	K1	283	0.174
108651	M4	17.1	0.021
108651	O1	288.5	0.159
108651	M6	14.9	0.03
108651	MK3	199.5	0.015
108651	S4	323.1	0.023
108651	MN4	13.5	0.047
108651	S6	44.5	0.014
108651	2N2	205.8	0.072
108651	OO1	64.7	0.016
108651	M1	335.1	0.028
108651	J1	295.5	0.015
108651	Q1	235.2	0.033
108651	2Q1	42.2	0.026
108651	2SM2	206.4	0.013
108651	M3	118.8	0.03
108651	L2	341.4	0.17
108651	2MK3	235	0.012
108651	M8	106.6	0.026
108651	MS4	351.9	0.03
108652	M2	303.5	0.453
108652	S2	352.5	0.064
108652	N2	277.4	0.102
108652	K1	271.8	0.072
108652	M4	114.7	0.027
108652	O1	287.4	0.044
108652	M6	45.4	0.004
108652	MK3	117	0.018
108652	S4	345	0.003
108652	MN4	94.4	0.018
108652	S6	66.9	0.001
108652	2N2	258.5	0.007
108652	OO1	312.3	0.019
108652	M1	359.1	0.015
108652	J1	38.9	0.01
108652	Q1	159.1	0.032
108652	2Q1	306.8	0.002
108652	2SM2	268.9	0.005
108652	M3	259.5	0.014
108652	L2	330.2	0.049
108652	2MK3	152.5	0.021
108652	K2	316	0.005
108652	M8	284.8	0.002
108652	MS4	186.6	0.013
108653	M2	311.9	0.504
108653	S2	1	0.091
108653	N2	286.2	0.107
108653	K1	297.1	0.121
108653	M4	112	0.05
108653	O1	311.6	0.076
108653	M6	146.6	0.001
108653	MK3	139.1	0.011
108653	S4	98.8	0.005
108653	MN4	94.2	0.021
108653	S6	358.7	0.004
108653	2N2	300.6	0.019
108653	OO1	1.3	0.015
108653	M1	290.3	0.011
108653	J1	7.1	0.002
108653	Q1	191	0.03
108653	2Q1	324.6	0.003
108653	2SM2	217.8	0.016
108653	M3	228.8	0.009
108653	L2	349.9	0.048
108653	2MK3	189.4	0.016
108653	K2	13.6	0.047
108653	M8	213.2	0.004
108653	MS4	176.3	0.014
108654	M2	315.5	0.645
108654	S2	9.5	0.07
108654	N2	300.7	0.148
108654	K1	291	0.118
108654	M4	217.8	0.026
108654	O1	311	0.109
108654	M6	249	0.008
108654	MK3	205.3	0.018
108654	S4	98.2	0.009
108654	MN4	199.9	0.019
108654	S6	291.5	0.002
108654	2N2	270	0.013
108654	OO1	337.1	0.037
108654	M1	78.2	0.015
108654	J1	170.8	0.015
108654	Q1	250.3	0.017
108654	2Q1	197.1	0.026
108654	2SM2	132.1	0.01
108654	M3	24	0.01
108654	L2	348.2	0.041
108654	2MK3	242.7	0.017
108654	K2	41.4	0.044
108654	M8	240.8	0.012
108654	MS4	104.1	0.007
108655	M2	343.6	1.356
108655	S2	14.7	0.155
108655	N2	322.7	0.23
108655	K1	59.8	0.284
108655	M4	339.9	0.103
108655	O1	55.2	0.276
108655	M6	231.1	0.068
108655	MK3	94.7	0.068
108655	S4	277.8	0.004
108655	MN4	326.6	0.041
108655	NU2	325.3	0.067
108655	MU2	104.2	0.04
108655	2N2	269.6	0.019
108655	OO1	242	0.013
108655	LDA2	1.2	0.039
108655	S1	40.4	0.048
108655	M1	248.2	0.024
108655	J1	100.7	0.01
108655	RHO1	5.6	0.008
108655	Q1	34.6	0.053
108655	T2	274.9	0.013
108655	2Q1	347.4	0.021
108655	P1	51.7	0.067
108655	2SM2	71.2	0.005
108655	M3	48.6	0.004
108655	L2	354.6	0.115
108655	2MK3	72.1	0.087
108655	K2	21.1	0.056
108655	M8	211.2	0.014
108655	MS4	36.7	0.038
108656	M2	346.6	1.733
108656	S2	21.5	0.19
108656	N2	325.9	0.287
108656	K1	67.4	0.384
108656	M4	342.4	0.078
108656	O1	61	0.329
108656	M6	242.9	0.102
108656	MK3	130.7	0.072
108656	S4	291.1	0.006
108656	MN4	334	0.028
108656	NU2	326.7	0.093
108656	S6	238.8	0.002
108656	MU2	102.6	0.053
108656	2N2	269.9	0.032
108656	OO1	249.6	0.015
108656	LDA2	7	0.058
108656	S1	62.1	0.065
108656	M1	265.8	0.032
108656	J1	121.1	0.013
108656	RHO1	355.2	0.014
108656	Q1	41.7	0.064
108656	T2	31.3	0.005
108656	2Q1	355.3	0.023
108656	P1	61	0.098
108656	2SM2	79.5	0.006
108656	M3	70.2	0.01
108656	L2	358.6	0.14
108656	2MK3	91.2	0.076
108656	K2	26.6	0.069
108656	M8	224.3	0.017
108656	MS4	49.1	0.028
108657	M2	349.5	1.721
108657	S2	33.1	0.217
108657	N2	328.6	0.285
108657	K1	69.5	0.382
108657	M4	349.6	0.058
108657	O1	62.6	0.343
108657	M6	247.7	0.086
108657	MK3	145.3	0.057
108657	S4	295.6	0.008
108657	MN4	347.2	0.02
108657	NU2	331.4	0.094
108657	S6	213.7	0.003
108657	MU2	97.3	0.045
108657	2N2	270.9	0.035
108657	OO1	270	0.013
108657	LDA2	19.1	0.052
108657	S1	62.8	0.074
108657	M1	269.3	0.033
108657	J1	114.1	0.011
108657	RHO1	0.7	0.012
108657	Q1	44.2	0.065
108657	T2	77.9	0.027
108657	R2	267.9	0.04
108657	2Q1	353	0.024
108657	P1	63.8	0.101
108657	2SM2	87.2	0.008
108657	M3	84	0.013
108657	L2	1.9	0.136
108657	2MK3	92.5	0.07
108657	K2	2.3	0.063
108657	M8	246.3	0.013
108657	MS4	65.7	0.02
108658	M2	25.9	0.884
108658	S2	47.8	0.166
108658	K1	118.1	0.109
108658	M4	320.1	0.041
108658	O1	174.3	0.111
108658	M6	353.8	0.03
108658	MK3	55.9	0.042
108658	S4	258.3	0.029
108658	S6	187.4	0.015
108658	2N2	42.2	0.028
108658	OO1	344.3	0.017
108658	2Q1	172.7	0.028
108658	2SM2	319.1	0.036
108658	2MK3	127.3	0.037
108658	M8	90.4	0.01
108658	MS4	266.7	0.032
108659	M2	282.9	0.657
108659	S2	315.2	0.22
108659	N2	249.9	0.109
108659	K1	22.2	1.63
108659	M4	173.2	0.074
108659	O1	13.5	1.573
108659	M6	101.9	0.01
108659	S4	24.1	0.029
108659	NU2	254.3	0.021
108659	S6	15.9	0.007
108659	2N2	216.8	0.015
108659	OO1	30.8	0.068
108659	LDA2	297.9	0.005
108659	M1	17.8	0.112
108659	J1	26.5	0.124
108659	RHO1	9.8	0.06
108659	Q1	9.2	0.305
108659	T2	313.9	0.013
108659	R2	316.5	0.002
108659	2Q1	4.9	0.041
108659	P1	21.5	0.54
108659	L2	249.9	0.016
108659	K2	317.7	0.06
108659	M8	147.7	0.002
108660	M2	317.2	0.155
108660	S2	307.1	0.035
108660	N2	296.6	0.031
108660	K1	31.5	0.404
108660	M4	241.5	0.019
108660	O1	20.7	0.365
108660	M6	203.3	0.004
108660	MK3	344.5	0.041
108660	S4	23.9	0.008
108660	MN4	200.8	0.01
108660	S6	256.5	0.005
108660	2N2	7	0.031
108660	OO1	41.1	0.051
108660	M1	63.5	0.016
108660	J1	324.8	0.018
108660	Q1	20	0.047
108660	2Q1	55.9	0.015
108660	P1	40.9	0.108
108660	2SM2	120.2	0.012
108660	M3	176.4	0.01
108660	L2	353.3	0.015
108660	2MK3	327.8	0.033
108660	K2	324.2	0.026
108660	M8	205.5	0.004
108660	MS4	234.3	0.011
108661	M2	317.5	0.291
108661	S2	292.9	0.171
108661	K1	24.4	0.543
108661	M4	219.9	0.062
108661	O1	4.1	0.737
108661	M6	108.6	0.012
108661	MK3	279	0.057
108661	S4	283.1	0.023
108661	S6	121.3	0.004
108661	2N2	57.7	0.128
108661	OO1	6.9	0.15
108661	2Q1	182.6	0.162
108661	2SM2	57.7	0.04
108661	2MK3	313.3	0.133
108661	M8	233.3	0.005
108661	MS4	217.3	0.032
108662	M2	293.2	0.198
108662	S2	299.1	0.121
108662	K1	27.6	0.407
108662	M4	198.2	0.047
108662	O1	1.5	0.558
108662	M6	128.6	0.01
108662	MK3	277.4	0.045
108662	S4	323.7	0.008
108662	S6	78.3	0.008
108662	2N2	55.2	0.061
108662	OO1	7.9	0.11
108662	2Q1	193.3	0.102
108662	2SM2	32.1	0.031
108662	2MK3	308.3	0.064
108662	M8	96.7	0.006
108662	MS4	181.4	0.038
108663	M2	280.8	0.446
108663	S2	279.9	0.138
108663	N2	267.5	0.11
108663	K1	22	0.978
108663	M4	145.5	0.047
108663	O1	14.6	0.978
108663	M6	273.1	0.015
108663	MK3	194.3	0.006
108663	S4	305	0.026
108663	MN4	134.2	0.012
108663	NU2	286.2	0.031
108663	S6	245	0.005
108663	MU2	88.8	0.026
108663	2N2	81	0.059
108663	OO1	29.9	0.093
108663	LDA2	5.1	0.01
108663	M1	73.5	0.053
108663	J1	39.1	0.026
108663	RHO1	37.2	0.027
108663	Q1	353.1	0.171
108663	2Q1	122.2	0.029
108663	P1	11.7	0.28
108663	2SM2	353	0.011
108663	M3	123.5	0.029
108663	L2	319.3	0.023
108663	2MK3	212	0.027
108663	K2	330.7	0.065
108663	M8	191.2	0.01
108663	MS4	179.8	0.027
108664	M2	324.1	0.328
108664	S2	353.9	0.085
108664	N2	293.6	0.058
108664	K1	207	0.228
108664	M4	274.4	0.005
108664	O1	178.9	0.148
108664	M6	284.6	0.007
108664	MK3	242.9	0.016
108664	S4	121.7	0.004
108664	MN4	75.9	0.006
108664	NU2	269	0.012
108664	S6	13.4	0.004
108664	MU2	144.9	0.004
108664	2N2	196.9	0.009
108664	OO1	216.8	0.015
108664	LDA2	345.4	0.014
108664	S1	267.7	0.025
108664	M1	9.2	0.016
108664	J1	175.9	0.014
108664	RHO1	138.8	0.015
108664	Q1	151.8	0.024
108664	T2	310.2	0.016
108664	R2	312.4	0.018
108664	2Q1	25.2	0.012
108664	P1	196	0.057
108664	2SM2	306.6	0.006
108664	M3	223.8	0.01
108664	L2	13.2	0.032
108664	2MK3	292.2	0.022
108664	K2	5.3	0.059
108664	M8	197.4	0.002
108664	MS4	256.1	0.006
108665	M2	76.4	1.422
108665	S2	117.1	0.165
108665	N2	60.5	0.238
108665	K1	202.8	0.166
108665	M4	63.1	0.18
108665	O1	196.3	0.112
108665	M6	23	0.107
108665	MK3	186	0.072
108665	S4	161.7	0.012
108665	MN4	45.6	0.072
108665	NU2	46	0.067
108665	S6	345	0.002
108665	MU2	212.5	0.067
108665	2N2	26	0.01
108665	OO1	264	0.005
108665	LDA2	78.8	0.043
108665	M1	255.8	0.007
108665	J1	105.4	0.009
108665	RHO1	174.6	0.014
108665	Q1	210	0.024
108665	2Q1	150.4	0.006
108665	P1	182.5	0.061
108665	2SM2	216.5	0.006
108665	M3	93.7	0.02
108665	L2	73.2	0.179
108665	2MK3	178	0.07
108665	K2	124.6	0.061
108665	M8	246.9	0.006
108665	MS4	116.8	0.053
108666	M2	74.3	1.924
108666	S2	113.3	0.219
108666	N2	57.9	0.328
108666	K1	201.3	0.213
108666	M4	71.8	0.242
108666	O1	193.4	0.153
108666	M6	27	0.151
108666	MK3	185.4	0.069
108666	S4	158.4	0.013
108666	MN4	53.8	0.083
108666	NU2	44	0.099
108666	S6	343.4	0.006
108666	MU2	205	0.089
108666	2N2	8.7	0.007
108666	OO1	274.9	0.01
108666	LDA2	74.5	0.063
108666	M1	248.9	0.009
108666	J1	107.8	0.008
108666	RHO1	169.7	0.022
108666	Q1	199.7	0.034
108666	2Q1	189.7	0.007
108666	P1	178.6	0.073
108666	2SM2	218.3	0.007
108666	M3	113.5	0.02
108666	L2	73	0.254
108666	2MK3	169.7	0.077
108666	K2	127.5	0.073
108666	M8	180.5	0.01
108666	MS4	125.2	0.065
108667	M2	72.6	1.994
108667	S2	110.9	0.227
108667	N2	55.3	0.342
108667	K1	199.3	0.214
108667	M4	78.2	0.289
108667	O1	191.4	0.167
108667	M6	24.6	0.133
108667	MK3	182.2	0.067
108667	S4	161.8	0.011
108667	MN4	65.6	0.094
108667	NU2	45.7	0.108
108667	S6	11.3	0.007
108667	MU2	201.8	0.086
108667	2N2	3.6	0.015
108667	OO1	281	0.014
108667	LDA2	67.9	0.07
108667	M1	236.8	0.012
108667	J1	87.4	0.005
108667	RHO1	151.5	0.03
108667	Q1	193.7	0.042
108667	2Q1	223.8	0.01
108667	P1	177	0.066
108667	2SM2	217.3	0.008
108667	M3	122.7	0.023
108667	L2	71.3	0.269
108667	2MK3	168	0.078
108667	K2	125.2	0.063
108667	M8	132.4	0.017
108667	MS4	133.1	0.069
108668	M2	127.5	1.695
108668	S2	170.2	0.194
108668	N2	108.4	0.283
108668	K1	206.3	0.112
108668	M4	258.4	0.208
108668	O1	189.2	0.087
108668	M6	251.6	0.116
108668	MK3	293	0.068
108668	S4	156.9	0.004
108668	MN4	236	0.081
108668	NU2	103.2	0.089
108668	MU2	245.1	0.098
108668	2N2	135.5	0.042
108668	OO1	236.1	0.012
108668	LDA2	140.3	0.047
108668	S1	115.1	0.016
108668	M1	188.4	0.01
108668	J1	201.6	0.006
108668	MM	236.9	0.034
108668	SSA	323.9	0.093
108668	SA	140.8	0.096
108668	MSF	232.3	0.01
108668	MF	230.9	0.014
108668	RHO1	182.2	0.009
108668	Q1	179.5	0.011
108668	T2	155.2	0.01
108668	R2	106.6	0.01
108668	2Q1	161.1	0.009
108668	P1	207.7	0.03
108668	2SM2	57.8	0.012
108668	M3	191.8	0.014
108668	L2	147.3	0.207
108668	2MK3	255.4	0.071
108668	K2	164	0.067
108668	M8	327.1	0.024
108668	MS4	310.5	0.054
108669	M2	343.9	1.777
108669	S2	10.4	0.272
108669	N2	318.5	0.355
108669	K1	135.9	0.143
108669	M4	192.8	0.052
108669	O1	127.8	0.109
108669	M6	283	0.01
108669	MK3	3	0.021
108669	S4	249.4	0.011
108669	MN4	172.6	0.037
108669	NU2	304.3	0.049
108669	S6	198.3	0.002
108669	MU2	136.5	0.039
108669	2N2	332.4	0.033
108669	OO1	220.2	0.013
108669	LDA2	19.1	0.065
108669	S1	99	0.04
108669	M1	69	0.011
108669	J1	171.8	0.008
108669	RHO1	148.7	0.014
108669	Q1	125	0.013
108669	T2	344.7	0.041
108669	2Q1	125.4	0.012
108669	P1	118	0.068
108669	2SM2	261.4	0.017
108669	M3	111.8	0.005
108669	L2	12.4	0.125
108669	2MK3	18.8	0.022
108669	K2	17.1	0.079
108669	M8	295.4	0.016
108669	MS4	198	0.019
108670	M2	124.2	1.854
108670	S2	167.1	0.221
108670	N2	107.3	0.396
108670	K1	205.6	0.116
108670	M4	242.5	0.218
108670	O1	187.2	0.095
108670	M6	247.4	0.181
108670	MK3	300.9	0.061
108670	MN4	229.7	0.102
108670	2N2	223.2	0.085
108670	OO1	236.1	0.023
108670	M1	250.8	0.006
108670	J1	214.5	0.011
108670	Q1	197.3	0.021
108670	2Q1	180.5	0.013
108670	P1	168.6	0.032
108670	2SM2	350.8	0.008
108670	M3	154.5	0.013
108670	L2	145.2	0.279
108670	2MK3	236.3	0.089
108670	K2	175.2	0.07
108670	M8	324.3	0.043
108670	MS4	299.8	0.06
108671	M2	123.9	1.83
108671	S2	162.2	0.217
108671	N2	107.3	0.384
108671	K1	206.5	0.123
108671	M4	244.3	0.22
108671	O1	191.5	0.09
108671	M6	246.3	0.181
108671	MK3	298.7	0.06
108671	S4	243.7	0.005
108671	MN4	232.5	0.098
108671	2N2	222.8	0.077
108671	OO1	243.2	0.017
108671	M1	214.9	0.006
108671	J1	169	0.01
108671	Q1	193.7	0.015
108671	2Q1	225	0.005
108671	P1	175.9	0.023
108671	2SM2	79.3	0.009
108671	M3	164.3	0.019
108671	L2	145.7	0.277
108671	2MK3	235	0.083
108671	K2	171.4	0.085
108671	M8	330.5	0.043
108671	MS4	299	0.06
108672	M2	122.9	1.638
108672	S2	161.9	0.195
108672	N2	106.3	0.34
108672	K1	207.2	0.11
108672	M4	247	0.197
108672	O1	192.3	0.082
108672	M6	241.6	0.155
108672	MK3	296.3	0.051
108672	S4	262.4	0.005
108672	MN4	234.2	0.089
108672	2N2	219.7	0.068
108672	OO1	237.1	0.014
108672	M1	212.3	0.005
108672	J1	174.7	0.008
108672	Q1	197.7	0.014
108672	2Q1	209.2	0.005
108672	P1	167.4	0.022
108672	2SM2	82.1	0.009
108672	M3	161.1	0.016
108672	L2	145.3	0.246
108672	2MK3	232.7	0.07
108672	K2	168.2	0.078
108672	M8	334.1	0.036
108672	MS4	298.9	0.053
108673	M2	265.2	0.43
108673	S2	275.3	0.095
108673	N2	240.8	0.074
108673	K1	1.2	0.75
108673	M4	139.4	0.07
108673	O1	354.4	0.631
108673	M6	12.3	0.015
108673	MK3	220.7	0.023
108673	S4	214	0.025
108673	MN4	85.9	0.028
108673	S6	50.2	0.005
108673	2N2	57.8	0.056
108673	OO1	6.7	0.045
108673	M1	287.5	0.059
108673	J1	9.6	0.069
108673	Q1	335.5	0.112
108673	2Q1	115.3	0.034
108673	P1	352.3	0.202
108673	2SM2	359.3	0.017
108673	M3	45.7	0.032
108673	L2	320.9	0.018
108673	2MK3	193.2	0.031
108673	K2	242.5	0.052
108673	M8	174.2	0.014
108673	MS4	155.3	0.035
108674	M2	264.2	0.519
108674	S2	269.9	0.127
108674	N2	241.6	0.109
108674	K1	4.6	0.874
108674	M4	133.5	0.097
108674	O1	357.1	0.745
108674	M6	25	0.022
108674	MK3	228.1	0.031
108674	S4	204.9	0.023
108674	MN4	76.6	0.04
108674	S6	66.8	0.003
108674	2N2	76.4	0.059
108674	OO1	15.3	0.061
108674	M1	288.5	0.063
108674	J1	12.6	0.086
108674	Q1	336.6	0.142
108674	2Q1	133.9	0.038
108674	P1	355.7	0.194
108674	2SM2	10.7	0.016
108674	M3	60.5	0.048
108674	L2	278.3	0.019
108674	2MK3	192	0.036
108674	K2	279.7	0.081
108674	M8	206.1	0.019
108674	MS4	158.3	0.038
108675	M2	264.6	0.437
108675	S2	291.1	0.136
108675	N2	226.3	0.113
108675	K1	358	0.674
108675	M4	137.1	0.076
108675	O1	357.9	0.537
108675	M6	352.3	0.023
108675	MK3	220.5	0.047
108675	S4	195.8	0.015
108675	MN4	82.1	0.037
108675	S6	38.9	0.013
108675	2N2	106.3	0.041
108675	OO1	15.8	0.074
108675	M1	269	0.04
108675	J1	19.5	0.075
108675	Q1	343.4	0.108
108675	2Q1	145.4	0.054
108675	P1	358.9	0.262
108675	2SM2	14.5	0.023
108675	M3	53.5	0.02
108675	L2	9.4	0.01
108675	2MK3	135.1	0.015
108675	K2	320.7	0.016
108675	M8	176.4	0.011
108675	MS4	130.7	0.015
108676	M2	345.5	0.183
108676	S2	335.9	0.043
108676	N2	324.7	0.037
108676	K1	29.7	0.18
108676	M4	339.7	0.009
108676	O1	16.8	0.157
108676	M6	126.6	0.003
108676	MK3	353.4	0.022
108676	S4	329.5	0.004
108676	MN4	343.1	0.003
108676	NU2	342.3	0.006
108676	S6	290.7	0.002
108676	MU2	119.1	0.005
108676	2N2	17.6	0.005
108676	OO1	41.3	0.011
108676	LDA2	251.3	0.004
108676	S1	34.3	0.03
108676	M1	122.5	0.008
108676	J1	177.1	0.006
108676	RHO1	1.5	0.008
108676	Q1	6.5	0.03
108676	T2	6	0.005
108676	R2	10.9	0.007
108676	2Q1	53.2	0.01
108676	P1	25.7	0.051
108676	2SM2	51	0.002
108676	M3	88.7	0.006
108676	L2	345.7	0.018
108676	2MK3	355.9	0.02
108676	K2	350.5	0.015
108676	M8	355.8	0.003
108676	MS4	341.5	0.005
108677	M2	348.4	0.244
108677	S2	337.8	0.058
108677	N2	324.2	0.052
108677	K1	32.8	0.253
108677	M4	309.3	0.007
108677	O1	19.6	0.225
108677	M6	114.1	0.01
108677	MK3	345.8	0.03
108677	S4	313.3	0.006
108677	MN4	284.3	0.004
108677	NU2	344.3	0.011
108677	S6	104.1	0.003
108677	MU2	83.4	0.004
108677	2N2	62.2	0.008
108677	OO1	40.1	0.015
108677	LDA2	196.6	0.002
108677	S1	39.1	0.03
108677	M1	122.7	0.013
108677	J1	199	0.012
108677	RHO1	13.7	0.013
108677	Q1	9.3	0.04
108677	T2	45.9	0.009
108677	R2	62.3	0.008
108677	2Q1	58.3	0.011
108677	P1	32	0.068
108677	2SM2	54.2	0.007
108677	M3	78	0.011
108677	L2	332.8	0.022
108677	2MK3	353.4	0.024
108677	K2	345.4	0.025
108677	M8	4.2	0.007
108677	MS4	346.9	0.004
108678	M2	285.4	0.438
108678	S2	292.6	0.086
108678	N2	262.3	0.111
108678	K1	27.2	0.494
108678	M4	182.6	0.011
108678	O1	17.1	0.469
108678	M6	17.9	0.005
108678	MK3	147.4	0.037
108678	S4	72.2	0.006
108678	MN4	103	0.01
108678	NU2	286.1	0.019
108678	S6	292.3	0.003
108678	MU2	206.5	0.02
108678	2N2	229.3	0.061
108678	OO1	52.4	0.034
108678	LDA2	319	0.027
108678	M1	10.3	0.012
108678	J1	77.1	0.027
108678	RHO1	56.5	0.034
108678	Q1	2.6	0.091
108678	2Q1	275.3	0.024
108678	P1	11.9	0.178
108678	2SM2	218.7	0.024
108678	M3	76.9	0.015
108678	L2	11.3	0.021
108678	2MK3	131.7	0.047
108678	K2	350.4	0.054
108678	M8	287.3	0.002
108678	MS4	173.7	0.007
108679	M2	307.1	0.603
108679	S2	299.5	0.185
108679	N2	273.5	0.114
108679	K1	16.3	0.844
108679	M4	210.9	0.043
108679	O1	5.9	0.828
108679	M6	68.7	0.007
108679	MK3	248	0.033
108679	S4	25	0.015
108679	MN4	196.7	0.035
108679	NU2	256.8	0.02
108679	S6	106.3	0.003
108679	MU2	187.1	0.032
108679	2N2	307.3	0.069
108679	OO1	42.4	0.093
108679	LDA2	50.3	0.022
108679	M1	6.6	0.061
108679	J1	350.8	0.013
108679	RHO1	296	0.022
108679	Q1	351	0.136
108679	2Q1	20.2	0.026
108679	P1	22.8	0.266
108679	2SM2	15.1	0.033
108679	M3	168.8	0.017
108679	L2	320.8	0.025
108679	2MK3	242	0.031
108679	K2	12.3	0.082
108679	M8	332.6	0.008
108679	MS4	188.9	0.019
108680	M2	358.3	0.314
108680	S2	338.8	0.088
108680	N2	331.2	0.084
108680	K1	43.4	0.293
108680	M4	9.6	0.021
108680	O1	16.4	0.291
108680	M6	105	0.002
108680	MK3	34.9	0.037
108680	S4	253.5	0.012
108680	MN4	349.4	0.011
108680	NU2	329.7	0.022
108680	S6	58.6	0.003
108680	MU2	255.5	0.013
108680	2N2	52.1	0.022
108680	OO1	50.6	0.049
108680	LDA2	68.6	0.003
108680	S1	157.8	0.071
108680	M1	116	0.008
108680	J1	95.1	0.02
108680	RHO1	116.2	0.012
108680	Q1	338.5	0.042
108680	T2	34	0.036
108680	2Q1	55.5	0.013
108680	P1	58	0.09
108680	2SM2	188.9	0.012
108680	M3	84.7	0.009
108680	L2	52	0.002
108680	2MK3	8	0.028
108680	K2	3.1	0.04
108680	MS4	10.1	0.017
108681	M2	300.6	0.345
108681	S2	275.6	0.211
108681	K1	358.7	0.594
108681	M4	240.8	0.032
108681	O1	9.5	0.518
108681	M6	147.5	0.008
108681	MK3	290.5	0.032
108681	S4	295.7	0.029
108681	S6	69.6	0.001
108681	2N2	141.5	0.06
108681	OO1	29.6	0.051
108681	2Q1	245.1	0.092
108681	2SM2	287.7	0.027
108681	2MK3	9.5	0.005
108681	M8	323.5	0.002
108681	MS4	176.2	0.017
108682	M2	273.6	0.289
108682	S2	286.5	0.102
108682	N2	259.2	0.048
108682	K1	5	0.43
108682	M4	128.7	0.023
108682	O1	349	0.361
108682	M6	59.3	0.031
108682	S4	22.4	0.009
108682	NU2	261.1	0.009
108682	S6	232.2	0.022
108682	2N2	244.8	0.006
108682	OO1	20.9	0.016
108682	LDA2	279.6	0.002
108682	M1	357	0.026
108682	J1	12.9	0.029
108682	RHO1	342.2	0.014
108682	Q1	341.1	0.07
108682	T2	285.9	0.006
108682	R2	287	0.001
108682	2Q1	333.2	0.009
108682	P1	3.7	0.142
108682	L2	259.2	0.007
108682	K2	287.5	0.028
108682	M8	80.9	0.012
108683	M2	132.4	0.134
108683	S2	146.6	0.076
108683	N2	137.1	0.034
108683	K1	330.9	0.294
108683	M4	104.6	0.025
108683	O1	319.8	0.252
108683	M6	40.2	0.002
108683	MK3	309.5	0.023
108683	S4	211.7	0.01
108683	MN4	104.4	0.008
108683	NU2	186.4	0.008
108683	S6	152.8	0.002
108683	MU2	50.2	0.011
108683	2N2	278	0.024
108683	OO1	26.7	0.046
108683	LDA2	309.5	0.011
108683	M1	292.9	0.01
108683	J1	17.8	0.017
108683	RHO1	353.3	0.025
108683	Q1	304.6	0.058
108683	2Q1	314.6	0.006
108683	P1	336.2	0.122
108683	2SM2	352.4	0.008
108683	M3	258.3	0.014
108683	L2	133.8	0.007
108683	2MK3	327.8	0.024
108683	K2	279.5	0.005
108683	M8	15.9	0.004
108683	MS4	134	0.023
108684	M2	116.9	0.083
108684	S2	132.1	0.058
108684	N2	146.5	0.014
108684	K1	334.1	0.194
108684	M4	112.4	0.018
108684	O1	323.5	0.167
108684	M6	34.2	0.007
108684	MK3	293.2	0.014
108684	S4	184.1	0.009
108684	MN4	17.8	0.006
108684	NU2	44.3	0.004
108684	S6	137.7	0.003
108684	MU2	128.5	0.01
108684	2N2	268.7	0.014
108684	OO1	16.2	0.032
108684	LDA2	148.7	0.005
108684	M1	298.6	0.005
108684	J1	0.6	0.005
108684	RHO1	311	0.014
108684	Q1	311.2	0.039
108684	2Q1	193.9	0.004
108684	P1	340.1	0.075
108684	2SM2	274.1	0.003
108684	M3	26.1	0.002
108684	L2	147.9	0.014
108684	2MK3	316.1	0.011
108684	K2	304.4	0.01
108684	M8	358.1	0.004
108684	MS4	143.5	0.015
108685	M2	96.1	0.065
108685	S2	118.8	0.052
108685	N2	160.7	0.009
108685	K1	331	0.142
108685	M4	85.4	0.017
108685	O1	316.7	0.135
108685	M6	21.4	0.005
108685	MK3	345.1	0.011
108685	S4	143.6	0.004
108685	MN4	40.5	0.008
108685	NU2	170.8	0.008
108685	S6	178.4	0.002
108685	MU2	42.5	0.005
108685	2N2	266.6	0.007
108685	OO1	47.8	0.009
108685	LDA2	61.5	0.003
108685	M1	333.9	0.005
108685	J1	150.5	0.009
108685	RHO1	303.9	0.023
108685	Q1	304.4	0.025
108685	2Q1	132.3	0.025
108685	P1	339.5	0.055
108685	2SM2	210.2	0.003
108685	M3	284.6	0.006
108685	L2	234.6	0.011
108685	2MK3	18.4	0.01
108685	K2	89.2	0.006
108685	M8	321	0.001
108685	MS4	133.2	0.018
108686	M2	154.2	0.07
108686	S2	160.7	0.043
108686	N2	183.5	0.032
108686	K1	352.6	0.285
108686	M4	71.6	0.017
108686	O1	348.4	0.273
108686	M6	50.9	0.007
108686	MK3	21.4	0.02
108686	S4	130.5	0.007
108686	MN4	33	0.006
108686	NU2	228.3	0.025
108686	S6	117.3	0.007
108686	MU2	303.2	0.004
108686	2N2	316.9	0.018
108686	OO1	5.4	0.032
108686	LDA2	357.5	0.007
108686	M1	345	0.014
108686	J1	327.4	0.029
108686	RHO1	11.5	0.026
108686	Q1	316.2	0.052
108686	2Q1	106.9	0.015
108686	P1	73	0.084
108686	2SM2	116.4	0.006
108686	M3	287.3	0.011
108686	L2	270.8	0.005
108686	2MK3	16	0.034
108686	K2	92.9	0.014
108686	MS4	78.5	0.007
108687	M2	154.3	0.097
108687	S2	163	0.063
108687	N2	172.3	0.049
108687	K1	352.3	0.356
108687	M4	72.4	0.023
108687	O1	342.6	0.313
108687	M6	73.1	0.004
108687	MK3	24.1	0.032
108687	S4	172.1	0.007
108687	MN4	9.6	0.01
108687	NU2	208.1	0.023
108687	S6	146.7	0.006
108687	MU2	47.7	0.006
108687	2N2	311.5	0.016
108687	OO1	331.8	0.037
108687	LDA2	65.6	0.008
108687	M1	343.1	0.017
108687	J1	329.9	0.026
108687	RHO1	334.8	0.027
108687	Q1	317.3	0.068
108687	2Q1	225.7	0.001
108687	P1	42.2	0.113
108687	2SM2	69.5	0.012
108687	M3	283.6	0.009
108687	L2	6.7	0.013
108687	2MK3	28.2	0.036
108687	K2	97.7	0.026
108687	M8	79.1	0.001
108687	MS4	90.8	0.014
108688	M2	141.7	0.102
108688	S2	157.6	0.071
108688	N2	170.7	0.052
108688	K1	348.6	0.349
108688	M4	84.5	0.022
108688	O1	337.8	0.299
108688	M6	39.4	0.004
108688	MK3	29.1	0.037
108688	S4	184.3	0.005
108688	MN4	32.2	0.006
108688	NU2	206.5	0.023
108688	S6	144.2	0.005
108688	MU2	305.7	0.003
108688	2N2	334.1	0.011
108688	OO1	311.8	0.032
108688	LDA2	66.7	0.009
108688	M1	336.2	0.018
108688	J1	318.2	0.029
108688	RHO1	331.5	0.03
108688	Q1	315.3	0.073
108688	2Q1	265	0.005
108688	P1	40.2	0.112
108688	2SM2	52.3	0.011
108688	M3	293.5	0.01
108688	L2	29.2	0.009
108688	2MK3	22.2	0.039
108688	K2	91.4	0.032
108688	MS4	99.7	0.012
108689	M2	157.6	0.065
108689	S2	195.1	0.068
108689	N2	165.5	0.02
108689	K1	19.9	0.319
108689	M4	102.5	0.022
108689	O1	2.5	0.319
108689	M6	97.2	0.004
108689	MK3	342.3	0.02
108689	S4	231.5	0.014
108689	MN4	94.8	0.005
108689	NU2	310.4	0.008
108689	S6	302.7	0.007
108689	MU2	151.2	0.005
108689	2N2	279.4	0.009
108689	OO1	51.1	0.035
108689	LDA2	5.8	0.012
108689	M1	36.9	0.013
108689	J1	8.9	0.024
108689	RHO1	325.9	0.021
108689	Q1	350.2	0.068
108689	2Q1	356.1	0.028
108689	P1	4.4	0.142
108689	M3	293.8	0.008
108689	L2	69	0.005
108689	2MK3	342.4	0.028
108689	K2	137.2	0.027
108689	M8	75.8	0.002
108689	MS4	132.9	0.014
108690	M2	155.6	0.047
108690	S2	185.1	0.038
108690	N2	136.5	0.017
108690	K1	17.2	0.22
108690	M4	92.6	0.019
108690	O1	9.1	0.222
108690	M6	76.3	0.006
108690	MK3	337.1	0.018
108690	S4	277.3	0.003
108690	MN4	81.5	0.007
108690	NU2	349.8	0.008
108690	S6	356.1	0.007
108690	MU2	143	0.004
108690	2N2	295.7	0.009
108690	OO1	85.3	0.034
108690	LDA2	299	0.001
108690	M1	18.2	0.007
108690	J1	303.1	0.005
108690	RHO1	303.7	0.02
108690	Q1	347.9	0.037
108690	2Q1	62.8	0.007
108690	P1	4.8	0.091
108690	2SM2	46.8	0.006
108690	M3	246.7	0.01
108690	L2	223.6	0.013
108690	2MK3	354	0.02
108690	K2	115.1	0.002
108690	M8	108.8	0.002
108690	MS4	124.6	0.007
108691	M2	157.1	0.057
108691	S2	165.1	0.047
108691	N2	155.5	0.013
108691	K1	12.2	0.217
108691	M4	94.9	0.018
108691	O1	5	0.198
108691	M6	63.4	0.003
108691	MK3	323.8	0.015
108691	S4	211.8	0.006
108691	MN4	104.9	0.007
108691	NU2	331.1	0.006
108691	S6	344.8	0.005
108691	MU2	96.3	0.008
108691	2N2	301.8	0.012
108691	OO1	87.7	0.027
108691	LDA2	328.4	0.006
108691	M1	16.4	0.006
108691	J1	268.7	0.007
108691	RHO1	308	0.02
108691	Q1	339	0.035
108691	2Q1	293.6	0.009
108691	P1	354.3	0.081
108691	2SM2	62	0.004
108691	M3	271	0.014
108691	L2	265.8	0.011
108691	2MK3	335.3	0.018
108691	K2	82.2	0.012
108691	M8	340.1	0.001
108691	MS4	138.3	0.007
108692	M2	132.6	1.104
108692	S2	151.6	0.322
108692	N2	124.7	0.24
108692	K1	155.8	0.268
108692	M4	80.6	0.176
108692	O1	154.9	0.157
108692	M6	196.8	0.082
108692	MK3	37.3	0.057
108692	S4	174.6	0.019
108692	MN4	70	0.064
108692	S6	145.5	0.007
108692	2N2	354.7	0.017
108692	OO1	296.1	0.019
108692	M1	245.4	0.023
108692	J1	346.9	0.01
108692	Q1	187.5	0.019
108692	2Q1	309.2	0.004
108692	P1	151.6	0.079
108692	2SM2	234.8	0.029
108692	M3	276.5	0.021
108692	L2	92.2	0.031
108692	2MK3	3.8	0.041
108692	M8	205.8	0.026
108692	MS4	98	0.068
108693	M2	132.3	1.155
108693	S2	150.8	0.334
108693	N2	125.1	0.262
108693	K1	156.6	0.308
108693	M4	75.8	0.207
108693	O1	156.2	0.178
108693	M6	192.9	0.072
108693	MK3	39.3	0.063
108693	S4	168.5	0.017
108693	MN4	68.2	0.081
108693	S6	176.4	0.005
108693	2N2	327.4	0.015
108693	OO1	303.8	0.022
108693	M1	210.2	0.026
108693	J1	217.1	0.012
108693	Q1	162.6	0.031
108693	2Q1	58.8	0.006
108693	P1	146.8	0.091
108693	2SM2	241	0.016
108693	M3	271.3	0.028
108693	L2	96.2	0.031
108693	2MK3	8	0.051
108693	M8	200	0.031
108693	MS4	89.9	0.089
108694	M2	132.5	1.112
108694	S2	151.1	0.328
108694	N2	126.3	0.254
108694	K1	158.1	0.299
108694	M4	72.9	0.194
108694	O1	157.1	0.158
108694	M6	186.5	0.073
108694	MK3	35.5	0.068
108694	S4	167.9	0.017
108694	MN4	60.9	0.073
108694	S6	184.4	0.005
108694	2N2	313	0.014
108694	OO1	298.1	0.021
108694	M1	214.3	0.026
108694	J1	217.7	0.015
108694	Q1	162.4	0.024
108694	2Q1	30.1	0.01
108694	P1	150.7	0.097
108694	2SM2	233.2	0.016
108694	M3	267.6	0.027
108694	L2	95.4	0.03
108694	2MK3	11.8	0.049
108694	M8	198.4	0.03
108694	MS4	85.8	0.084
108695	M2	128.1	0.897
108695	S2	139.4	0.237
108695	N2	93.1	0.168
108695	K1	149.2	0.28
108695	M4	60.7	0.086
108695	O1	139.9	0.178
108695	M6	59	0.033
108695	MK3	38.6	0.077
108695	S4	218.7	0.003
108695	MN4	21.7	0.031
108695	S6	16.9	0.002
108695	2N2	339.9	0.023
108695	OO1	150.4	0.018
108695	M1	116.3	0.008
108695	J1	190	0.012
108695	Q1	150.2	0.016
108695	2Q1	219.4	0.015
108695	P1	147.8	0.07
108695	2SM2	296.9	0.013
108695	M3	201.8	0.018
108695	L2	126.4	0.023
108695	2MK3	319.3	0.01
108695	K2	140	0.104
108695	M8	41.5	0.003
108695	MS4	55.2	0.055
108696	M2	126	0.983
108696	S2	136.7	0.256
108696	N2	91.8	0.178
108696	K1	151.4	0.278
108696	M4	75.9	0.088
108696	O1	138.8	0.188
108696	M6	59	0.03
108696	MK3	47.1	0.059
108696	S4	262.2	0.004
108696	MN4	24.4	0.035
108696	S6	39.5	0.001
108696	2N2	21.2	0.008
108696	OO1	179.6	0.018
108696	M1	164.6	0.005
108696	J1	175.1	0.011
108696	Q1	127.3	0.019
108696	2Q1	214.5	0.013
108696	P1	125.7	0.074
108696	2SM2	329.4	0.009
108696	M3	202.7	0.018
108696	L2	145.7	0.032
108696	2MK3	310.3	0.017
108696	K2	139.3	0.116
108696	M8	45.2	0.004
108696	MS4	70.1	0.042
108697	M2	126.1	0.866
108697	S2	128.4	0.233
108697	N2	87.7	0.159
108697	K1	155.9	0.265
108697	M4	89	0.113
108697	O1	143.8	0.202
108697	M6	58.5	0.032
108697	MK3	77.7	0.079
108697	S4	282.5	0.008
108697	MN4	50.5	0.037
108697	S6	82.2	0.001
108697	2N2	332.1	0.022
108697	OO1	182.7	0.015
108697	M1	170.2	0.009
108697	J1	168.8	0.012
108697	Q1	142.7	0.021
108697	2Q1	211.3	0.013
108697	P1	108.2	0.056
108697	2SM2	324.7	0.006
108697	M3	210.4	0.02
108697	L2	127.6	0.036
108697	2MK3	134.1	0.016
108697	K2	126.8	0.121
108697	M8	342.1	0.005
108697	MS4	76.4	0.033
108698	M2	139	1.276
108698	S2	159.2	0.286
108698	N2	118.8	0.291
108698	K1	152.1	0.356
108698	M4	69	0.177
108698	O1	147.4	0.21
108698	M6	214.3	0.035
108698	MK3	50.2	0.116
108698	S4	34.3	0.009
108698	MN4	47.8	0.063
108698	NU2	120.7	0.058
108698	S6	124	0.002
108698	MU2	158.6	0.032
108698	2N2	210	0.019
108698	OO1	220.3	0.016
108698	LDA2	150.9	0.037
108698	S1	338.2	0.074
108698	M1	213.4	0.011
108698	J1	186.9	0.033
108698	RHO1	245.1	0.01
108698	Q1	153.8	0.044
108698	T2	159.4	0.044
108698	R2	9.2	0.065
108698	2Q1	128.6	0.01
108698	P1	145.8	0.092
108698	2SM2	18.4	0.016
108698	M3	49.2	0.012
108698	L2	159	0.033
108698	2MK3	346.6	0.056
108698	K2	182.9	0.137
108698	M8	198.2	0.018
108698	MS4	88.5	0.081
108699	M2	11.8	1.136
108699	S2	20.3	0.186
108699	N2	5.9	0.198
108699	K1	174.9	0.105
108699	M4	219.8	0.192
108699	O1	133.6	0.016
108699	M6	166.7	0.126
108699	MK3	33.4	0.045
108699	S4	357.2	0.01
108699	MN4	225.2	0.052
108699	NU2	1	0.074
108699	S6	148	0.006
108699	MU2	83.5	0.033
108699	2N2	69	0.016
108699	OO1	255.1	0.014
108699	LDA2	341.3	0.033
108699	S1	82.6	0.057
108699	M1	41	0.01
108699	J1	132.5	0.007
108699	RHO1	231.9	0.011
108699	Q1	177.4	0.007
108699	T2	54.9	0.065
108699	R2	126.2	0.045
108699	2Q1	163.8	0.012
108699	P1	170.4	0.024
108699	2SM2	241.8	0.006
108699	M3	152	0.019
108699	L2	40	0.104
108699	2MK3	79.3	0.036
108699	K2	35	0.059
108699	M8	336.5	0.023
108699	MS4	226.4	0.047
108700	M2	0.7	0.741
108700	S2	18.4	0.124
108700	N2	354	0.197
108700	K1	152.4	0.064
108700	M4	154.9	0.14
108700	O1	127.9	0.05
108700	M6	139.7	0.056
108700	MK3	298.1	0.03
108700	S4	326.1	0.002
108700	MN4	183.9	0.051
108700	NU2	336.5	0.045
108700	S6	96.5	0.012
108700	MU2	359.1	0.042
108700	2N2	8.3	0.022
108700	OO1	213	0.011
108700	LDA2	296.2	0.029
108700	S1	90.7	0.032
108700	M1	116.1	0.003
108700	J1	199.2	0.008
108700	RHO1	219.5	0.022
108700	Q1	179.9	0.01
108700	T2	9.6	0.047
108700	R2	102.3	0.056
108700	2Q1	134.1	0.016
108700	P1	119.6	0.021
108700	2SM2	270.6	0.014
108700	M3	130.3	0.009
108700	L2	327.2	0.065
108700	2MK3	340.8	0.014
108700	K2	23.1	0.064
108700	M8	296.8	0.042
108700	MS4	167.1	0.032
108701	M2	353.9	0.583
108701	S2	20.2	0.117
108701	N2	350.6	0.155
108701	K1	145.4	0.048
108701	M4	120.2	0.121
108701	O1	140.6	0.049
108701	M6	148.7	0.028
108701	MK3	282.9	0.029
108701	S4	287.7	0.003
108701	MN4	147.8	0.029
108701	NU2	336.7	0.034
108701	S6	68	0.011
108701	MU2	345.3	0.035
108701	2N2	17.1	0.018
108701	OO1	162.4	0.011
108701	LDA2	287	0.033
108701	S1	87.9	0.014
108701	M1	192.3	0.004
108701	J1	244.4	0.003
108701	RHO1	221.9	0.017
108701	Q1	176	0.011
108701	T2	24.6	0.039
108701	R2	115.8	0.062
108701	2Q1	135.1	0.012
108701	P1	104.1	0.019
108701	2SM2	277.2	0.016
108701	M3	163.1	0.003
108701	L2	315.6	0.054
108701	2MK3	306	0.011
108701	K2	29.8	0.049
108701	M8	275.8	0.032
108701	MS4	148	0.033
108702	M2	1.3	1.984
108702	S2	22.6	0.312
108702	N2	339.7	0.416
108702	K1	173	0.234
108702	M4	44.7	0.191
108702	O1	178.5	0.152
108702	M6	290.8	0.055
108702	MK3	197.6	0.003
108702	S4	333.1	0.021
108702	MN4	9.6	0.061
108702	NU2	339.2	0.085
108702	S6	26.6	0.004
108702	MU2	319.1	0.037
108702	2N2	6	0.048
108702	OO1	304.6	0.007
108702	LDA2	8.5	0.024
108702	S1	96	0.054
108702	M1	27.7	0.004
108702	J1	186.5	0.025
108702	RHO1	181.5	0.009
108702	Q1	173.5	0.034
108702	T2	13.3	0.032
108702	2Q1	195.2	0.015
108702	P1	174	0.045
108702	2SM2	343.9	0.011
108702	M3	130.8	0.025
108702	L2	21.1	0.046
108702	2MK3	79.6	0.006
108702	K2	6.6	0.078
108702	M8	317.2	0.03
108702	MS4	98.7	0.065
108703	M2	359.8	1.788
108703	S2	22.4	0.227
108703	N2	341.4	0.313
108703	K1	162.1	0.172
108703	M4	18.8	0.153
108703	O1	168.1	0.12
108703	M6	198.3	0.147
108703	MK3	25.2	0.012
108703	S4	323.2	0.015
108703	MN4	4.1	0.041
108703	NU2	329.8	0.066
108703	S6	322.4	0.008
108703	MU2	129	0.034
108703	2N2	21.3	0.022
108703	OO1	279.8	0.023
108703	LDA2	8.3	0.061
108703	S1	78.9	0.032
108703	M1	60.6	0.01
108703	J1	266.6	0.006
108703	RHO1	252.4	0.007
108703	Q1	156.3	0.016
108703	T2	31.4	0.047
108703	2Q1	130.2	0.002
108703	P1	183.4	0.031
108703	2SM2	234.6	0.011
108703	M3	117.5	0.021
108703	L2	18.5	0.14
108703	2MK3	12.2	0.017
108703	K2	15.6	0.071
108703	M8	237.6	0.034
108703	MS4	93.1	0.036
108704	M2	358.1	1.51
108704	S2	12.9	0.215
108704	N2	346	0.278
108704	K1	164.4	0.158
108704	M4	32.4	0.091
108704	O1	168.6	0.103
108704	M6	190.5	0.169
108704	MK3	13.7	0.019
108704	S4	321.2	0.016
108704	MN4	23.5	0.029
108704	NU2	341.6	0.069
108704	S6	355.5	0.005
108704	MU2	56.6	0.04
108704	2N2	22.8	0.028
108704	OO1	297.9	0.009
108704	LDA2	36.1	0.024
108704	S1	49.8	0.042
108704	J1	160.5	0.009
108704	RHO1	165.9	0.005
108704	Q1	162.1	0.021
108704	T2	12	0.065
108704	2Q1	186.7	0.007
108704	P1	201.7	0.031
108704	2SM2	356.1	0.01
108704	M3	89.5	0.013
108704	L2	25.3	0.11
108704	2MK3	39.8	0.019
108704	K2	44.3	0.053
108704	M8	230	0.025
108704	MS4	84.7	0.021
108705	M2	8.8	1.991
108705	S2	43.1	0.388
108705	N2	327.1	0.392
108705	K1	197.4	0.14
108705	M4	214.2	0.062
108705	O1	183.7	0.171
108705	M6	205.6	0.146
108705	MK3	355.7	0.055
108705	S4	79.7	0.018
108705	MN4	307.2	0.048
108705	S6	297.1	0.008
108705	2N2	342.1	0.178
108705	OO1	246.8	0.044
108705	M1	146.1	0.05
108705	J1	246.4	0.043
108705	Q1	210.2	0.024
108705	2Q1	49	0.041
108705	P1	234.7	0.039
108705	2SM2	55.8	0.036
108705	M3	180.4	0.06
108705	L2	85.9	0.111
108705	2MK3	51.5	0.041
108705	M8	232.6	0.003
108705	MS4	148.9	0.068
108706	M2	6.4	1.697
108706	S2	42.8	0.349
108706	N2	326.6	0.447
108706	K1	219.1	0.084
108706	M4	188.4	0.042
108706	O1	184.7	0.157
108706	M6	219.2	0.136
108706	MK3	0.8	0.013
108706	S4	348.3	0.006
108706	MN4	53.2	0.047
108706	S6	317.9	0.02
108706	2N2	318.2	0.095
108706	OO1	324.8	0.007
108706	M1	184.4	0.052
108706	J1	255.7	0.061
108706	Q1	196.1	0.035
108706	2Q1	348.4	0.016
108706	P1	307.6	0.045
108706	2SM2	27.7	0.037
108706	M3	114.9	0.024
108706	L2	325.3	0.052
108706	2MK3	2.6	0.004
108706	M8	41.6	0.024
108706	MS4	153.7	0.043
108707	M2	0.4	1.342
108707	S2	40.1	0.247
108707	N2	323.5	0.371
108707	K1	272.5	0.062
108707	M4	99.4	0.095
108707	O1	174.4	0.165
108707	M6	210.3	0.107
108707	MK3	172.8	0.008
108707	S4	315.7	0.022
108707	MN4	52.3	0.082
108707	S6	11.4	0.005
108707	2N2	296	0.078
108707	OO1	313.8	0.052
108707	M1	174.7	0.062
108707	J1	226.4	0.051
108707	Q1	260.8	0.028
108707	2Q1	151.3	0.012
108707	P1	332.7	0.053
108707	2SM2	11.8	0.039
108707	M3	38.8	0.042
108707	L2	328.8	0.117
108707	2MK3	274.2	0.044
108707	M8	21	0.034
108707	MS4	86	0.015
108708	M2	6.7	2.513
108708	S2	10.3	0.322
108708	N2	349.8	0.624
108708	K1	183.3	0.269
108708	M4	42.8	0.185
108708	O1	179.8	0.18
108708	M6	225.9	0.162
108708	MK3	64.1	0.042
108708	S4	296.8	0.02
108708	MN4	34.3	0.095
108708	S6	271.4	0.011
108708	2N2	323.8	0.065
108708	OO1	318.3	0.005
108708	M1	272	0.008
108708	J1	128.4	0.042
108708	Q1	192.2	0.05
108708	2Q1	354.2	0.004
108708	P1	181.9	0.117
108708	2SM2	13.1	0.016
108708	M3	214.2	0.016
108708	L2	10.3	0.259
108708	2MK3	43.3	0.054
108708	K2	81.8	0.09
108708	M8	297	0.069
108708	MS4	84.1	0.027
108709	M2	4.4	2.023
108709	S2	5.3	0.405
108709	N2	348	0.585
108709	K1	184.8	0.277
108709	M4	67.1	0.09
108709	O1	181.6	0.184
108709	M6	308.7	0.117
108709	MK3	147	0.022
108709	S4	298.6	0.008
108709	MN4	67.5	0.103
108709	S6	265.3	0.024
108709	2N2	342.7	0.178
108709	OO1	223.2	0.024
108709	M1	80.9	0.006
108709	J1	125.7	0.025
108709	Q1	162.3	0.051
108709	2Q1	256.3	0.008
108709	P1	178.3	0.128
108709	2SM2	13.6	0.026
108709	M3	144.9	0.056
108709	L2	313.5	0.035
108709	2MK3	155.2	0.028
108709	K2	123.6	0.061
108709	M8	301.9	0.025
108709	MS4	114.6	0.092
108710	M2	2.4	1.922
108710	S2	11.1	0.251
108710	N2	350.4	0.547
108710	K1	186.1	0.244
108710	M4	75.1	0.11
108710	O1	187.8	0.161
108710	M6	237.9	0.061
108710	MK3	161.4	0.022
108710	S4	287.4	0.011
108710	MN4	73.6	0.063
108710	S6	232.9	0.018
108710	2N2	352.9	0.138
108710	OO1	274.2	0.014
108710	M1	351.2	0.004
108710	J1	111.1	0.045
108710	Q1	169.3	0.043
108710	2Q1	48.6	0.006
108710	P1	172	0.111
108710	2SM2	32.7	0.022
108710	M3	155.2	0.03
108710	L2	332.4	0.09
108710	2MK3	131.1	0.018
108710	K2	81	0.097
108710	M8	3.9	0.032
108710	MS4	116.2	0.062
108711	M2	21.3	1.664
108711	S2	55.9	0.243
108711	N2	3.4	0.351
108711	K1	181.2	0.227
108711	M4	79	0.183
108711	O1	190	0.189
108711	M6	256.9	0.127
108711	MK3	224.1	0.023
108711	S4	287.1	0.014
108711	MN4	47.6	0.075
108711	NU2	4.3	0.083
108711	S6	290.8	0.006
108711	MU2	354.9	0.033
108711	2N2	338.3	0.061
108711	OO1	196.1	0.014
108711	LDA2	17.4	0.03
108711	M1	247.1	0.018
108711	J1	189.8	0.02
108711	RHO1	315	0.004
108711	Q1	178.5	0.038
108711	T2	88.9	0.023
108711	R2	313.8	0.069
108711	2Q1	257.5	0.008
108711	P1	174.6	0.076
108711	2SM2	238.9	0.011
108711	M3	181.9	0.032
108711	L2	23.1	0.074
108711	2MK3	268.8	0.012
108711	K2	11.3	0.066
108711	M8	222.5	0.011
108711	MS4	120	0.049
108712	M2	18.7	1.627
108712	S2	46.7	0.282
108712	N2	0.5	0.338
108712	K1	181.6	0.206
108712	M4	34.6	0.112
108712	O1	185.5	0.162
108712	M6	244.5	0.074
108712	MK3	34.3	0.014
108712	S4	328.1	0.009
108712	MN4	35.8	0.031
108712	NU2	4	0.062
108712	S6	317.2	0.007
108712	MU2	8.4	0.015
108712	2N2	329	0.047
108712	OO1	178.4	0.011
108712	LDA2	31.4	0.03
108712	S1	92.3	0.013
108712	M1	295.5	0.02
108712	J1	163.5	0.024
108712	RHO1	130.3	0.012
108712	Q1	195.3	0.017
108712	T2	47.9	0.045
108712	R2	237.5	0.053
108712	2Q1	253.4	0.004
108712	P1	169.5	0.065
108712	2SM2	254.4	0.007
108712	M3	187.8	0.024
108712	L2	14.7	0.089
108712	2MK3	50.4	0.022
108712	K2	33.1	0.038
108712	M8	204.2	0.019
108712	MS4	133.6	0.014
108713	M2	15.4	1.192
108713	S2	31	0.196
108713	N2	1.1	0.284
108713	K1	179.2	0.182
108713	M4	46.5	0.106
108713	O1	182.1	0.146
108713	M6	210.7	0.08
108713	MK3	228.5	0.022
108713	S4	321.6	0.019
108713	MN4	31.3	0.052
108713	NU2	8.7	0.068
108713	S6	246.5	0.003
108713	MU2	357.4	0.038
108713	2N2	305.3	0.037
108713	OO1	154.8	0.007
108713	LDA2	113.4	0.009
108713	S1	127.2	0.008
108713	M1	328.9	0.017
108713	J1	146.8	0.031
108713	RHO1	183.3	0.015
108713	Q1	165	0.019
108713	T2	348.1	0.042
108713	R2	127	0.043
108713	2Q1	7.3	0.003
108713	P1	161.4	0.054
108713	2SM2	266.3	0.008
108713	M3	208.5	0.025
108713	L2	359.9	0.03
108713	2MK3	226.3	0.019
108713	K2	48.7	0.046
108713	M8	232.4	0.003
108713	MS4	114.3	0.03
108714	M2	45.6	1.515
108714	S2	52.5	0.18
108714	N2	20.7	0.264
108714	K1	196.3	0.162
108714	M4	112.7	0.087
108714	O1	201.1	0.131
108714	M6	309.8	0.06
108714	MK3	163.1	0.028
108714	S4	349.9	0.015
108714	MN4	59.6	0.031
108714	NU2	32.6	0.053
108714	S6	4.1	0.003
108714	MU2	207.9	0.028
108714	2N2	78.1	0.015
108714	OO1	154.9	0.003
108714	LDA2	74.8	0.065
108714	S1	124.6	0.019
108714	M1	163.7	0.003
108714	J1	151.1	0.016
108714	RHO1	20.3	0.003
108714	Q1	181	0.022
108714	T2	358.7	0.02
108714	R2	204.9	0.013
108714	2Q1	71.2	0.002
108714	P1	176.7	0.044
108714	2SM2	70.3	0.003
108714	M3	211.6	0.037
108714	L2	90.7	0.105
108714	2MK3	158.2	0.052
108714	K2	64.2	0.047
108714	M8	70.2	0.03
108714	MS4	103.8	0.018
108715	M2	49.4	1.461
108715	S2	52.2	0.195
108715	N2	22.7	0.266
108715	K1	203.2	0.179
108715	M4	72.9	0.056
108715	O1	205.6	0.134
108715	M6	292.7	0.063
108715	MK3	143.2	0.047
108715	S4	32.4	0.012
108715	MN4	23.6	0.028
108715	NU2	25.8	0.053
108715	S6	320.5	0.006
108715	MU2	182.6	0.018
108715	2N2	61.8	0.019
108715	OO1	195.7	0.005
108715	LDA2	85.8	0.059
108715	S1	134.4	0.022
108715	M1	107.6	0.008
108715	J1	142	0.015
108715	RHO1	334.9	0.005
108715	Q1	187.7	0.022
108715	T2	359.3	0.027
108715	R2	215.9	0.021
108715	2Q1	105.6	0.009
108715	P1	182	0.06
108715	2SM2	224.5	0.01
108715	M3	223.9	0.037
108715	L2	103.8	0.093
108715	2MK3	162.1	0.057
108715	K2	61.5	0.047
108715	M8	83.8	0.041
108715	MS4	69.1	0.012
108716	M2	50	1.481
108716	S2	57.6	0.199
108716	N2	25.5	0.265
108716	K1	204.5	0.187
108716	M4	30.7	0.018
108716	O1	208.3	0.141
108716	M6	289.2	0.045
108716	MK3	128.6	0.05
108716	S4	53.5	0.008
108716	MN4	10	0.024
108716	NU2	34.3	0.054
108716	S6	21	0.006
108716	MU2	110.9	0.015
108716	2N2	55.4	0.025
108716	OO1	141	0.005
108716	LDA2	88.8	0.061
108716	S1	148.2	0.031
108716	M1	142.4	0.009
108716	J1	140.7	0.017
108716	RHO1	49.1	0.003
108716	Q1	175.9	0.019
108716	T2	15.4	0.017
108716	R2	231.1	0.016
108716	2Q1	92.6	0.016
108716	P1	179	0.063
108716	2SM2	238.5	0.014
108716	M3	212.7	0.043
108716	L2	107.5	0.099
108716	2MK3	148.3	0.059
108716	K2	59.9	0.056
108716	M8	90.4	0.028
108716	MS4	45	0.01
108717	M2	63.4	1.677
108717	S2	83.7	0.285
108717	N2	43.2	0.332
108717	K1	209.1	0.21
108717	M4	177	0.097
108717	O1	214.5	0.163
108717	M6	334.2	0.063
108717	MK3	111.8	0.01
108717	S4	5.8	0.012
108717	MN4	129.3	0.036
108717	NU2	35.5	0.059
108717	S6	46.3	0.003
108717	MU2	197.6	0.006
108717	2N2	357.8	0.046
108717	OO1	209.1	0.007
108717	LDA2	78.1	0.053
108717	S1	177	0.02
108717	M1	308	0.015
108717	J1	191.1	0.018
108717	RHO1	200.6	0.008
108717	Q1	209.1	0.02
108717	T2	88.1	0.056
108717	R2	254.6	0.08
108717	2Q1	263.2	0.008
108717	P1	194.9	0.058
108717	2SM2	286.1	0.005
108717	M3	257.6	0.014
108717	L2	59.4	0.106
108717	2MK3	107.3	0.029
108717	K2	99.7	0.034
108717	M8	233.6	0.017
108717	MS4	213.7	0.022
108718	M2	62.7	1.655
108718	S2	87	0.269
108718	N2	42.2	0.316
108718	K1	210	0.201
108718	M4	170.7	0.118
108718	O1	214	0.16
108718	M6	353.4	0.07
108718	MK3	110.1	0.011
108718	S4	7.7	0.01
108718	MN4	134.9	0.042
108718	NU2	35.8	0.054
108718	S6	79.4	0.003
108718	MU2	210.9	0.019
108718	2N2	358.4	0.041
108718	OO1	200.5	0.008
108718	LDA2	66.6	0.057
108718	S1	183.5	0.024
108718	M1	306.7	0.016
108718	J1	195.9	0.014
108718	RHO1	2.1	0.002
108718	Q1	210.4	0.023
108718	T2	94.1	0.056
108718	R2	270	0.072
108718	2Q1	297.3	0.005
108718	P1	192.5	0.055
108718	2SM2	268.9	0.006
108718	M3	231.7	0.016
108718	L2	59.4	0.116
108718	2MK3	112.7	0.031
108718	K2	78.3	0.032
108718	M8	223.2	0.035
108718	MS4	218.6	0.023
108719	M2	61.8	1.532
108719	S2	86.2	0.256
108719	N2	41.9	0.299
108719	K1	208.6	0.183
108719	M4	160.3	0.11
108719	O1	212.5	0.15
108719	M6	349.5	0.063
108719	MK3	117.2	0.009
108719	S4	11.5	0.01
108719	MN4	134.8	0.042
108719	NU2	36.3	0.049
108719	S6	105.3	0.004
108719	MU2	202.4	0.015
108719	2N2	351.6	0.037
108719	OO1	188.7	0.009
108719	LDA2	65.7	0.054
108719	S1	210.3	0.021
108719	M1	295.7	0.014
108719	J1	203.2	0.017
108719	RHO1	7.8	0.011
108719	Q1	214.4	0.026
108719	T2	90.6	0.054
108719	R2	270.6	0.064
108719	2Q1	344.9	0.006
108719	P1	188.3	0.051
108719	2SM2	241.7	0.005
108719	M3	221.7	0.017
108719	L2	57.4	0.103
108719	2MK3	125.2	0.021
108719	K2	75	0.029
108719	M8	216.6	0.031
108719	MS4	215.9	0.024
108720	M2	61	1.425
108720	S2	84.1	0.233
108720	N2	42.3	0.282
108720	K1	208.2	0.171
108720	M4	149.6	0.108
108720	O1	213.3	0.143
108720	M6	353.9	0.061
108720	MK3	93.5	0.006
108720	S4	17.2	0.008
108720	MN4	129.1	0.047
108720	NU2	34.5	0.044
108720	S6	97.9	0.006
108720	MU2	175	0.008
108720	2N2	340.4	0.037
108720	OO1	185.4	0.008
108720	LDA2	71.2	0.047
108720	S1	233.8	0.022
108720	M1	297.5	0.011
108720	J1	203.5	0.019
108720	RHO1	4.8	0.012
108720	Q1	216.1	0.029
108720	T2	80.9	0.047
108720	R2	262.6	0.05
108720	2Q1	13	0.007
108720	P1	183.6	0.048
108720	2SM2	214.9	0.003
108720	M3	217.3	0.016
108720	L2	54.7	0.095
108720	2MK3	122.4	0.015
108720	K2	80.9	0.031
108720	M8	203.9	0.02
108720	MS4	209.4	0.025
108721	M2	61.5	1.375
108721	S2	84.1	0.215
108721	N2	42.7	0.268
108721	K1	209.1	0.162
108721	M4	138.6	0.095
108721	O1	215.3	0.141
108721	M6	1.1	0.07
108721	MK3	102.8	0.007
108721	S4	19.6	0.006
108721	MN4	122.1	0.054
108721	NU2	31.2	0.046
108721	S6	85.9	0.006
108721	MU2	170.8	0.006
108721	2N2	335.3	0.042
108721	OO1	190	0.006
108721	LDA2	78.9	0.045
108721	S1	243.7	0.024
108721	M1	308.1	0.01
108721	J1	201.9	0.018
108721	RHO1	356.6	0.009
108721	Q1	216.6	0.029
108721	T2	76.3	0.042
108721	R2	263.3	0.046
108721	2Q1	26.3	0.008
108721	P1	179.9	0.044
108721	2SM2	244.8	0.002
108721	M3	198.1	0.014
108721	L2	54.8	0.102
108721	2MK3	125.6	0.02
108721	K2	83	0.03
108721	M8	231.9	0.008
108721	MS4	198	0.027
108722	M2	62.3	1.366
108722	S2	85.9	0.214
108722	N2	43.1	0.265
108722	K1	209.5	0.157
108722	M4	130.8	0.064
108722	O1	216.1	0.138
108722	M6	3.1	0.077
108722	MK3	103.1	0.014
108722	S4	66.1	0.003
108722	MN4	119.6	0.048
108722	NU2	27.2	0.043
108722	S6	71.3	0.005
108722	MU2	184.3	0.006
108722	2N2	333.2	0.042
108722	OO1	183.6	0.006
108722	LDA2	82.6	0.049
108722	S1	247	0.022
108722	M1	310.3	0.009
108722	J1	199.7	0.018
108722	RHO1	343.1	0.006
108722	Q1	214.5	0.029
108722	T2	81.2	0.04
108722	R2	264.5	0.054
108722	2Q1	23.9	0.008
108722	P1	181.7	0.041
108722	2SM2	272.4	0.002
108722	M3	184.3	0.014
108722	L2	54.4	0.106
108722	2MK3	122.2	0.029
108722	K2	82.7	0.03
108722	M8	299.6	0.019
108722	MS4	196.3	0.023
108723	M2	61.9	1.3
108723	S2	83.5	0.212
108723	N2	43.5	0.254
108723	K1	208.6	0.147
108723	M4	141.1	0.045
108723	O1	215.8	0.131
108723	M6	5.2	0.072
108723	MK3	98.9	0.016
108723	S4	83.7	0.005
108723	MN4	125.2	0.042
108723	NU2	22	0.039
108723	S6	71.7	0.004
108723	MU2	185.8	0.006
108723	2N2	333.7	0.038
108723	OO1	178.6	0.005
108723	LDA2	81.9	0.048
108723	S1	258.2	0.024
108723	M1	303.7	0.009
108723	J1	200.6	0.018
108723	RHO1	0.9	0.005
108723	Q1	215	0.028
108723	T2	77.2	0.045
108723	R2	255.7	0.062
108723	2Q1	15.7	0.007
108723	P1	183.3	0.039
108723	M3	185.3	0.013
108723	L2	54.5	0.099
108723	2MK3	117.2	0.03
108723	K2	92.7	0.026
108723	M8	304.2	0.036
108723	MS4	203.1	0.022
108724	M2	60.4	1.149
108724	S2	79.4	0.204
108724	N2	43.2	0.225
108724	K1	207.4	0.127
108724	M4	163.9	0.027
108724	O1	214.8	0.111
108724	M6	1.2	0.063
108724	MK3	84.7	0.017
108724	S4	75.8	0.005
108724	MN4	130.3	0.033
108724	NU2	13	0.039
108724	S6	83.1	0.002
108724	MU2	157.3	0.007
108724	2N2	328.1	0.036
108724	OO1	175.6	0.006
108724	LDA2	77.8	0.041
108724	S1	267.4	0.022
108724	M1	299	0.007
108724	J1	195.7	0.016
108724	RHO1	16.2	0.002
108724	Q1	219.3	0.025
108724	T2	74.5	0.051
108724	R2	247.2	0.073
108724	2Q1	22.7	0.008
108724	P1	181.6	0.033
108724	2SM2	141.8	0.003
108724	M3	177.1	0.01
108724	L2	51.7	0.087
108724	2MK3	107.8	0.027
108724	K2	110.8	0.017
108724	M8	297.5	0.039
108724	MS4	210.8	0.019
108725	M2	78.3	2.17
108725	S2	111	0.202
108725	N2	60.4	0.346
108725	K1	214.7	0.251
108725	M4	146.3	0.1
108725	O1	220.8	0.179
108725	M6	73.6	0.118
108725	MK3	155.8	0.038
108725	S4	151.1	0.009
108725	MN4	109.5	0.029
108725	NU2	58.4	0.071
108725	MU2	221.5	0.03
108725	2N2	65.6	0.044
108725	OO1	271.6	0.008
108725	LDA2	112.5	0.055
108725	M1	33.4	0.011
108725	J1	329.5	0.007
108725	RHO1	213.6	0.014
108725	Q1	210.1	0.04
108725	2Q1	212.7	0.012
108725	P1	210	0.084
108725	2SM2	28.2	0.018
108725	M3	215.4	0.031
108725	L2	105.6	0.187
108725	2MK3	135.7	0.065
108725	K2	103.8	0.084
108725	M8	233	0.009
108725	MS4	142.2	0.014
108726	M2	327.8	0.635
108726	S2	344.7	0.049
108726	N2	321.3	0.161
108726	K1	149.5	0.081
108726	M4	164.2	0.135
108726	O1	73.7	0.109
108726	M6	38.4	0.039
108726	MK3	252.1	0.113
108726	S4	250.1	0.03
108726	MN4	154.1	0.067
108726	S6	204.8	0.015
108726	2N2	343.6	0.015
108726	OO1	182.8	0.016
108726	M1	36.9	0.021
108726	J1	244.2	0.017
108726	Q1	8.5	0.008
108726	2Q1	2.7	0.033
108726	P1	19.1	0.089
108726	2SM2	10.4	0.013
108726	M3	136.6	0.011
108726	L2	343.1	0.015
108726	2MK3	260.1	0.045
108726	K2	236	0.045
108726	M8	227.2	0.026
108726	MS4	211.9	0.041
108727	M2	324.5	0.61
108727	S2	25.4	0.059
108727	N2	316.2	0.155
108727	K1	147.5	0.057
108727	M4	169.8	0.11
108727	O1	82.6	0.096
108727	M6	51.2	0.035
108727	MK3	258.1	0.085
108727	S4	226.4	0.026
108727	MN4	156.5	0.054
108727	S6	185.9	0.01
108727	2N2	47	0.004
108727	OO1	149.6	0.012
108727	M1	66.8	0.012
108727	J1	195.7	0.014
108727	Q1	99	0.011
108727	2Q1	19.7	0.027
108727	P1	19	0.084
108727	2SM2	14.2	0.023
108727	M3	169	0.014
108727	L2	285.8	0.023
108727	2MK3	259.3	0.042
108727	K2	193.2	0.03
108727	M8	213.3	0.02
108727	MS4	221.7	0.046
108728	M2	323	0.56
108728	S2	27.3	0.088
108728	N2	311.8	0.152
108728	K1	184.1	0.07
108728	M4	165.1	0.109
108728	O1	90.3	0.085
108728	M6	26.3	0.02
108728	MK3	271.5	0.062
108728	S4	255.4	0.008
108728	MN4	152.2	0.056
108728	S6	159.9	0.003
108728	2N2	147.1	0.017
108728	OO1	283.9	0.009
108728	M1	118.2	0.011
108728	J1	186.7	0.017
108728	Q1	87.1	0.013
108728	2Q1	81.8	0.014
108728	P1	4.8	0.117
108728	2SM2	68.8	0.012
108728	M3	169	0.017
108728	L2	239.3	0.03
108728	2MK3	288	0.027
108728	K2	136.9	0.029
108728	M8	129.9	0.011
108728	MS4	204.3	0.046
108729	M2	320.7	1.871
108729	S2	357.4	0.242
108729	N2	314	0.475
108729	K1	111.4	0.141
108729	M4	85.8	0.347
108729	O1	118	0.071
108729	M6	110.2	0.109
108729	MK3	259.4	0.046
108729	S4	310.8	0.016
108729	MN4	65.1	0.143
108729	S6	326.6	0.015
108729	2N2	344.3	0.1
108729	OO1	154.1	0.005
108729	M1	158.7	0.02
108729	J1	212.2	0.009
108729	Q1	117.3	0.034
108729	2Q1	69.6	0.002
108729	P1	125	0.055
108729	2SM2	60.4	0.031
108729	M3	116.5	0.017
108729	L2	308.9	0.116
108729	2MK3	268.5	0.035
108729	K2	345.7	0.059
108729	M8	242.1	0.081
108729	MS4	130.1	0.104
108730	M2	317.2	1.816
108730	S2	348.7	0.265
108730	N2	313.7	0.447
108730	K1	108.9	0.177
108730	M4	82.5	0.301
108730	O1	106.9	0.089
108730	M6	126.1	0.115
108730	MK3	277.9	0.061
108730	S4	314.4	0.003
108730	MN4	70.3	0.113
108730	S6	332.8	0.014
108730	2N2	350.6	0.11
108730	OO1	173.6	0.009
108730	M1	113.9	0.005
108730	J1	177.1	0.007
108730	Q1	116.6	0.033
108730	2Q1	267.3	0.004
108730	P1	143.6	0.058
108730	2SM2	82.7	0.022
108730	M3	169.2	0.009
108730	L2	293	0.124
108730	2MK3	265.5	0.056
108730	K2	353.7	0.086
108730	M8	236.8	0.054
108730	MS4	135.2	0.081
108731	M2	315	1.794
108731	S2	340.1	0.27
108731	N2	311.8	0.432
108731	K1	111.3	0.178
108731	M4	74	0.266
108731	O1	103.5	0.103
108731	M6	134.3	0.125
108731	MK3	275.1	0.067
108731	S4	136.6	0.004
108731	MN4	70.8	0.09
108731	S6	343.4	0.014
108731	2N2	355.1	0.116
108731	OO1	167.7	0.01
108731	M1	56.2	0.006
108731	J1	76.1	0.003
108731	Q1	117	0.031
108731	2Q1	219.3	0.004
108731	P1	143.4	0.06
108731	2SM2	134.6	0.017
108731	M3	165.2	0.013
108731	L2	289.5	0.14
108731	2MK3	261.7	0.064
108731	K2	350.1	0.105
108731	M8	220.3	0.043
108731	MS4	136.6	0.066
108732	M2	323	2.358
108732	S2	49.3	0.148
108732	N2	309.4	0.398
108732	K1	134.7	0.218
108732	M4	29.8	0.235
108732	O1	140.8	0.167
108732	M6	117.9	0.146
108732	MK3	219.9	0.04
108732	S4	89.1	0.009
108732	MN4	12.1	0.056
108732	S6	80.7	0.018
108732	2N2	221.7	0.078
108732	OO1	82.9	0.022
108732	M1	255.7	0.005
108732	J1	145.8	0.02
108732	Q1	139.3	0.037
108732	2Q1	356.4	0.009
108732	2SM2	107.9	0.025
108732	M3	125.1	0.047
108732	L2	303.6	0.134
108732	2MK3	23.8	0.023
108732	K2	172.8	0.14
108732	M8	180.7	0.042
108732	MS4	59.3	0.047
108733	M2	321.4	2.219
108733	S2	51.5	0.245
108733	N2	312	0.322
108733	K1	122.1	0.167
108733	M4	36	0.206
108733	O1	141.2	0.104
108733	M6	94.9	0.222
108733	MK3	302.5	0.055
108733	S4	149.5	0.014
108733	MN4	23.6	0.033
108733	S6	80	0.012
108733	2N2	241.2	0.084
108733	OO1	102.8	0.011
108733	M1	263.9	0.007
108733	J1	339.4	0.016
108733	Q1	253.8	0.003
108733	2Q1	172.4	0.007
108733	2SM2	108.6	0.02
108733	M3	136.8	0.031
108733	L2	318.6	0.182
108733	2MK3	316	0.053
108733	K2	116.8	0.122
108733	M8	127	0.071
108733	MS4	93.3	0.076
108734	M2	318.6	1.416
108734	S2	4.6	0.217
108734	N2	311.5	0.199
108734	K1	128	0.112
108734	M4	46	0.139
108734	O1	120.8	0.109
108734	M6	79.7	0.22
108734	MK3	209.2	0.072
108734	S4	159.1	0.014
108734	MN4	75	0.093
108734	S6	6.2	0.011
108734	2N2	186.9	0.051
108734	OO1	86.7	0.014
108734	M1	108.4	0.01
108734	J1	160.9	0.073
108734	Q1	109	0.063
108734	2Q1	320.1	0.018
108734	2SM2	24	0.012
108734	M3	145.7	0.015
108734	L2	331.8	0.142
108734	2MK3	331.9	0.007
108734	K2	30.7	0.065
108734	M8	163.7	0.025
108734	MS4	126.5	0.02
108735	M2	326.8	1.818
108735	S2	354.9	0.21
108735	N2	309.6	0.326
108735	K1	91.6	0.159
108735	M4	61.1	0.178
108735	O1	127.9	0.137
108735	M6	157.5	0.065
108735	MK3	279	0.047
108735	S4	178.6	0.006
108735	MN4	79.8	0.026
108735	S6	122.8	0.011
108735	2N2	181.9	0.099
108735	OO1	75	0.015
108735	M1	257.9	0.011
108735	J1	263.3	0.003
108735	Q1	134.9	0.041
108735	2Q1	358.5	0.011
108735	P1	147.8	0.144
108735	2SM2	70.3	0.006
108735	M3	147.7	0.044
108735	L2	289.8	0.192
108735	2MK3	277.8	0.045
108735	M8	143.8	0.053
108735	MS4	133.3	0.057
108736	M2	324.7	1.639
108736	S2	21.4	0.136
108736	N2	318	0.253
108736	K1	96.9	0.122
108736	M4	22.8	0.1
108736	O1	156.6	0.094
108736	M6	99.8	0.19
108736	MK3	21	0.027
108736	S4	351.5	0.015
108736	MN4	300.3	0.036
108736	S6	133.6	0.008
108736	2N2	232.2	0.045
108736	OO1	92.8	0.025
108736	M1	235	0.017
108736	J1	264.3	0.013
108736	Q1	180.1	0.035
108736	2Q1	41.6	0.002
108736	P1	167.5	0.126
108736	2SM2	175.9	0.005
108736	M3	152.4	0.027
108736	L2	319.7	0.154
108736	2MK3	3.6	0.029
108736	M8	197.2	0.033
108736	MS4	334.1	0.034
108737	M2	322.9	1.418
108737	S2	15.2	0.125
108737	N2	314.1	0.227
108737	K1	161.7	0.068
108737	M4	342.6	0.022
108737	O1	133.4	0.08
108737	M6	81.1	0.213
108737	MK3	215	0.033
108737	S4	72.6	0.007
108737	MN4	340.4	0.015
108737	S6	36.7	0.004
108737	2N2	216.4	0.074
108737	OO1	213.1	0.011
108737	M1	60.2	0.008
108737	J1	145.1	0.02
108737	Q1	76.8	0.035
108737	2Q1	289.5	0.013
108737	P1	64.2	0.086
108737	2SM2	37.7	0.011
108737	M3	130.6	0.033
108737	L2	316.5	0.124
108737	2MK3	226.5	0.016
108737	M8	309.1	0.016
108737	MS4	26.5	0.042
108738	M2	330.9	1.096
108738	S2	10.9	0.107
108738	N2	318.8	0.359
108738	K1	136.6	0.072
108738	M4	138.5	0.041
108738	O1	146.8	0.054
108738	M6	127.1	0.065
108738	MK3	348.7	0.021
108738	S4	311.5	0.014
108738	MN4	104.8	0.019
108738	NU2	280.4	0.078
108738	S6	89.8	0.005
108738	MU2	206.8	0.032
108738	2N2	338.8	0.111
108738	OO1	222.8	0.007
108738	LDA2	275.7	0.158
108738	M1	106.7	0.009
108738	J1	163.9	0.021
108738	RHO1	97.3	0.018
108738	Q1	208.6	0.015
108738	2Q1	235.8	0.012
108738	P1	172.7	0.034
108738	2SM2	351.4	0.008
108738	M3	193.4	0.022
108738	L2	147.9	0.044
108738	2MK3	341.9	0.012
108738	K2	38.1	0.106
108738	M8	96.2	0.002
108738	MS4	174.1	0.019
108739	M2	336.1	1.007
108739	S2	2.7	0.143
108739	N2	330.5	0.245
108739	K1	129.2	0.077
108739	M4	102.1	0.13
108739	O1	143.1	0.054
108739	M6	133	0.089
108739	MK3	296.8	0.028
108739	S4	349.5	0.004
108739	MN4	95.3	0.071
108739	NU2	292	0.083
108739	S6	182.3	0.006
108739	MU2	335.6	0.095
108739	2N2	212.2	0.007
108739	OO1	161.2	0.005
108739	LDA2	42.7	0.093
108739	M1	97.3	0.004
108739	J1	156.3	0.008
108739	RHO1	207.9	0.007
108739	Q1	72.5	0.014
108739	2Q1	115.9	0.009
108739	P1	110.9	0.02
108739	2SM2	323.2	0.014
108739	M3	151.8	0.022
108739	L2	244	0.149
108739	2MK3	310.2	0.018
108739	K2	20.9	0.07
108739	M8	51.6	0.032
108739	MS4	130.1	0.049
108740	M2	334.1	1.026
108740	S2	29.3	0.168
108740	N2	334.8	0.248
108740	K1	147.3	0.099
108740	M4	109.9	0.161
108740	O1	149.7	0.055
108740	M6	151.2	0.112
108740	MK3	261.8	0.025
108740	S4	328.4	0.029
108740	MN4	111.3	0.058
108740	S6	300.4	0.004
108740	2N2	175	0.053
108740	OO1	49.2	0.005
108740	M1	29.6	0.002
108740	J1	113.9	0.002
108740	Q1	118.4	0.012
108740	2Q1	329.5	0.004
108740	P1	116.5	0.027
108740	2SM2	123.8	0.038
108740	M3	130.6	0.017
108740	L2	313.9	0.056
108740	2MK3	288.1	0.035
108740	K2	21.3	0.06
108740	M8	264	0.013
108740	MS4	143.9	0.036
108741	M2	331	1.075
108741	S2	10.9	0.146
108741	N2	320.7	0.198
108741	K1	131.6	0.085
108741	M4	68	0.187
108741	O1	135.3	0.06
108741	M6	175.4	0.05
108741	MK3	261.5	0.023
108741	S4	356	0.011
108741	MN4	36.5	0.051
108741	NU2	313	0.046
108741	S6	90.1	0.003
108741	MU2	32.2	0.04
108741	2N2	319.3	0.033
108741	LDA2	58	0.02
108741	S1	118.8	0.011
108741	M1	347.8	0.003
108741	J1	119.3	0.007
108741	RHO1	108.2	0.003
108741	Q1	131.8	0.013
108741	T2	348.6	0.026
108741	R2	217.5	0.015
108741	P1	132.7	0.017
108741	2SM2	273.8	0.013
108741	M3	126	0.02
108741	L2	289.9	0.038
108741	2MK3	267.3	0.023
108741	K2	352.8	0.033
108741	M8	277.7	0.037
108741	MS4	105.5	0.041
108742	M2	331	1.012
108742	S2	12.5	0.138
108742	N2	321.6	0.177
108742	K1	133.6	0.08
108742	M4	68.7	0.18
108742	O1	138.1	0.057
108742	M6	168.8	0.052
108742	MK3	259.2	0.022
108742	S4	352.7	0.01
108742	MN4	39.9	0.049
108742	NU2	302.5	0.039
108742	S6	94.8	0.003
108742	MU2	28.4	0.038
108742	2N2	318.9	0.03
108742	LDA2	34	0.02
108742	S1	116.4	0.007
108742	M1	330.8	0.002
108742	J1	98.5	0.007
108742	RHO1	75.8	0.003
108742	Q1	133.8	0.01
108742	T2	338.5	0.025
108742	R2	225.7	0.017
108742	P1	125.7	0.016
108742	2SM2	275.7	0.011
108742	M3	128.3	0.016
108742	L2	301.2	0.035
108742	2MK3	265.3	0.022
108742	K2	2	0.032
108742	M8	264.2	0.023
108742	MS4	103.5	0.039
108743	M2	331.1	0.756
108743	S2	12.8	0.099
108743	N2	321.3	0.127
108743	K1	135	0.063
108743	M4	71.1	0.155
108743	O1	142	0.046
108743	M6	149.3	0.056
108743	MK3	240.7	0.022
108743	S4	358.2	0.007
108743	MN4	52.9	0.045
108743	NU2	278.8	0.035
108743	S6	121	0.002
108743	MU2	16.7	0.025
108743	2N2	315.8	0.022
108743	LDA2	46.6	0.017
108743	S1	103.7	0.005
108743	M1	273.8	0.002
108743	J1	94.6	0.006
108743	RHO1	38.7	0.004
108743	Q1	151.9	0.007
108743	T2	3.6	0.019
108743	R2	204.6	0.002
108743	P1	122.3	0.011
108743	2SM2	228	0.007
108743	M3	120.6	0.006
108743	L2	296.8	0.023
108743	2MK3	268.5	0.019
108743	K2	13.7	0.017
108743	M8	305.4	0.007
108743	MS4	109	0.04
108744	M2	304.1	1.143
108744	S2	336	0.312
108744	N2	292.8	0.19
108744	K1	213.4	0.495
108744	M4	167.3	0.108
108744	O1	185.8	0.205
108744	M6	345.9	0.067
108744	MK3	14.9	0.096
108744	S4	194.7	0.013
108744	MN4	158.5	0.048
108744	S6	294.8	0.007
108744	2N2	217.8	0.068
108744	OO1	12.4	0.006
108744	M1	238.3	0.019
108744	J1	210.2	0.021
108744	Q1	173.9	0.043
108744	2Q1	213.4	0.003
108744	P1	208.6	0.223
108744	2SM2	233.6	0.032
108744	M3	331.3	0.013
108744	L2	342.6	0.053
108744	2MK3	332.8	0.079
108744	K2	332.6	0.104
108744	M8	142.2	0.021
108744	MS4	187.3	0.085
108745	M2	304	1.171
108745	S2	337.5	0.317
108745	N2	290.6	0.196
108745	K1	210.4	0.48
108745	M4	186.2	0.118
108745	O1	173.7	0.226
108745	M6	357.4	0.068
108745	MK3	38.3	0.063
108745	S4	265.7	0.009
108745	MN4	170.3	0.055
108745	S6	307.1	0.004
108745	2N2	216.5	0.096
108745	OO1	108.4	0.014
108745	M1	231.8	0.011
108745	J1	212.4	0.018
108745	Q1	155.3	0.044
108745	2Q1	158.5	0.009
108745	P1	206.6	0.219
108745	2SM2	222.5	0.043
108745	M3	323.9	0.03
108745	L2	323.1	0.051
108745	2MK3	319.9	0.072
108745	K2	319.2	0.12
108745	M8	177.8	0.019
108745	MS4	212.7	0.081
108746	M2	304.2	0.929
108746	S2	338.3	0.239
108746	N2	290.7	0.164
108746	K1	204.3	0.365
108746	M4	177.5	0.05
108746	O1	173.5	0.141
108746	M6	324.9	0.039
108746	MK3	21.7	0.033
108746	S4	193.7	0.032
108746	MN4	150.2	0.015
108746	S6	317.1	0.012
108746	2N2	233.8	0.039
108746	OO1	18.9	0.022
108746	M1	267.4	0.028
108746	J1	223.3	0.027
108746	Q1	198.5	0.029
108746	2Q1	349.3	0.017
108746	P1	210.9	0.108
108746	2SM2	198	0.013
108746	M3	3.2	0.009
108746	L2	339.3	0.038
108746	2MK3	309.2	0.044
108746	K2	328.8	0.077
108746	M8	254.3	0.017
108746	MS4	194.8	0.078
108747	M2	287.4	0.508
108747	S2	297	0.107
108747	N2	243.1	0.108
108747	K1	181.8	0.36
108747	M4	165.3	0.02
108747	O1	155.1	0.135
108747	M6	39.6	0.011
108747	MK3	7	0.057
108747	S4	130.6	0.007
108747	MN4	116.4	0.031
108747	S6	54.1	0.013
108747	2N2	159.7	0.052
108747	OO1	349.1	0.001
108747	M1	272.5	0.008
108747	J1	233.3	0.042
108747	Q1	88.4	0.038
108747	2Q1	75.3	0.022
108747	P1	8.6	0.017
108747	2SM2	187.8	0.013
108747	M3	288.6	0.012
108747	L2	260.8	0.026
108747	2MK3	346.5	0.044
108747	K2	239.1	0.018
108747	M8	187.5	0.004
108747	MS4	204.1	0.022
108748	M2	284.8	0.524
108748	S2	292.9	0.125
108748	N2	238.3	0.135
108748	K1	170.2	0.301
108748	M4	253.5	0.004
108748	O1	161.6	0.148
108748	M6	28.2	0.011
108748	MK3	20	0.062
108748	S4	21.2	0.001
108748	MN4	120.7	0.028
108748	S6	90	0.009
108748	2N2	156.9	0.048
108748	OO1	250.8	0.014
108748	M1	30.1	0.006
108748	J1	258.4	0.019
108748	Q1	98	0.037
108748	2Q1	317	0.006
108748	P1	197.2	0.117
108748	2SM2	150.8	0.012
108748	M3	149.5	0.017
108748	L2	261.1	0.017
108748	2MK3	338.1	0.042
108748	K2	250.4	0.04
108748	M8	188.3	0.009
108748	MS4	207.9	0.032
108749	M2	284	0.526
108749	S2	297.6	0.143
108749	N2	233.5	0.126
108749	K1	172	0.217
108749	M4	125.8	0.011
108749	O1	162.7	0.143
108749	M6	2.9	0.011
108749	MK3	25.5	0.046
108749	S4	180.9	0.005
108749	MN4	154.2	0.015
108749	S6	34	0.004
108749	2N2	157	0.044
108749	OO1	242.4	0.012
108749	M1	101	0.018
108749	J1	241.2	0.013
108749	Q1	96.1	0.031
108749	2Q1	330.9	0.019
108749	P1	181.8	0.175
108749	2SM2	91.9	0.012
108749	M3	142.5	0.026
108749	L2	286.3	0.023
108749	2MK3	330	0.035
108749	K2	277	0.033
108749	M8	218	0.001
108749	MS4	237.7	0.015
108750	M2	0.7	0.096
108750	S2	27.8	0.039
108750	N2	346.9	0.024
108750	K1	269.5	0.021
108750	M4	343.1	0.009
108750	O1	323.7	0.01
108750	M6	256.4	0.004
108750	MK3	46.1	0.006
108750	S4	90	0.003
108750	MN4	8.3	0.003
108750	NU2	19.5	0.011
108750	S6	162.1	0.002
108750	MU2	267.2	0.006
108750	2N2	231.6	0.004
108750	OO1	324.7	0.005
108750	LDA2	302	0.007
108750	M1	330.8	0.003
108750	J1	318.2	0.007
108750	RHO1	281.7	0.006
108750	Q1	354.9	0.001
108750	2Q1	197.5	0.006
108750	P1	2.4	0.019
108750	2SM2	207.5	0.005
108750	M3	82.4	0.003
108750	L2	204.9	0.006
108750	2MK3	8.2	0.007
108750	K2	25.6	0.018
108750	M8	92.9	0.003
108750	MS4	328.1	0.003
108751	M2	281.1	1.071
108751	S2	298.2	0.461
108751	N2	250.3	0.278
108751	K1	12.3	1.184
108751	M4	161.7	0.026
108751	O1	357.5	0.976
108751	M6	65.6	0.012
108751	MK3	351.9	0.077
108751	S4	124.7	0.034
108751	MN4	147.5	0.022
108751	NU2	248.6	0.076
108751	S6	326.2	0.011
108751	MU2	131.1	0.051
108751	OO1	48.8	0.036
108751	LDA2	154.2	0.039
108751	S1	227.1	0.027
108751	M1	89.6	0.037
108751	J1	48.3	0.037
108751	RHO1	275.3	0.05
108751	Q1	339.8	0.123
108751	T2	171	0.098
108751	R2	21.9	0.278
108751	2Q1	45.8	0.051
108751	P1	8.6	0.374
108751	2SM2	268	0.031
108751	M3	232.7	0.023
108751	L2	47.5	0.076
108751	2MK3	291.1	0.046
108751	K2	278.4	0.304
108751	MS4	165.2	0.012
108752	M2	357.1	0.176
108752	S2	350.3	0.066
108752	N2	333	0.047
108752	K1	63	0.159
108752	M4	331.8	0.014
108752	O1	25.2	0.138
108752	M6	188.2	0.001
108752	MK3	55.9	0.016
108752	S4	280.2	0.009
108752	MN4	298.5	0.003
108752	NU2	1.7	0.011
108752	S6	222	0.003
108752	MU2	256.4	0.008
108752	2N2	291.8	0.014
108752	OO1	266.7	0.023
108752	LDA2	135.2	0.015
108752	S1	68.8	0.017
108752	M1	192.8	0.01
108752	J1	122.7	0.022
108752	RHO1	37.1	0.014
108752	Q1	35.6	0.011
108752	T2	229.3	0.011
108752	R2	60.6	0.03
108752	2Q1	289.9	0.013
108752	P1	50.3	0.069
108752	2SM2	129.9	0.001
108752	M3	46	0.014
108752	L2	17	0.008
108752	2MK3	35.5	0.015
108752	K2	306	0.042
108752	M8	183.3	0.001
108752	MS4	347.6	0.01
108753	M2	306.5	0.396
108753	S2	312.3	0.068
108753	N2	287.6	0.073
108753	K1	9.6	0.754
108753	M4	189.2	0.052
108753	O1	359.6	0.747
108753	M6	98.6	0.012
108753	MK3	233.8	0.058
108753	S4	271.7	0.014
108753	MN4	194.6	0.02
108753	S6	228.6	0.006
108753	2N2	75	0.038
108753	OO1	2.9	0.066
108753	M1	155.3	0.065
108753	J1	329.2	0.038
108753	Q1	356.7	0.129
108753	2Q1	106.5	0.032
108753	P1	15.6	0.19
108753	2SM2	38	0.016
108753	M3	110.9	0.013
108753	L2	318.9	0.033
108753	2MK3	251.7	0.075
108753	K2	314.1	0.08
108753	M8	262.5	0.004
108753	MS4	236.5	0.029
108754	M2	279.2	1.004
108754	S2	278.8	0.268
108754	N2	260.6	0.238
108754	K1	9.6	2.086
108754	M4	141	0.127
108754	O1	356.6	1.941
108754	M6	336.3	0.02
108754	MK3	233	0.078
108754	S4	275.7	0.026
108754	MN4	114	0.067
108754	NU2	224.3	0.049
108754	S6	163.4	0.021
108754	MU2	216.3	0.024
108754	2N2	163	0.2
108754	OO1	8.3	0.26
108754	LDA2	279.4	0.034
108754	S1	256.5	0.07
108754	M1	322.6	0.176
108754	J1	51.5	0.082
108754	RHO1	13.7	0.065
108754	Q1	347.6	0.365
108754	T2	245.9	0.04
108754	R2	329.6	0.077
108754	2Q1	228.8	0.148
108754	P1	7.3	0.619
108754	2SM2	184.5	0.011
108754	M3	103.4	0.053
108754	L2	323	0.064
108754	2MK3	197.7	0.061
108754	K2	303.4	0.237
108754	M8	220.5	0.009
108754	MS4	144.7	0.06
108755	M2	290.8	0.654
108755	S2	321.8	0.111
108755	N2	278.6	0.133
108755	K1	78.4	0.037
108755	M4	224.7	0.117
108755	O1	84.3	0.02
108755	M6	114.9	0.099
108755	MK3	342.1	0.026
108755	S4	342.4	0.023
108755	MN4	215.2	0.051
108755	NU2	243.1	0.022
108755	S6	292.6	0.005
108755	MU2	339.9	0.026
108755	2N2	258.9	0.014
108755	OO1	92	0.002
108755	LDA2	281.4	0.017
108755	S1	113.8	0.004
108755	M1	160.6	0.001
108755	J1	351	0.003
108755	RHO1	17.4	0.004
108755	Q1	50.3	0.002
108755	T2	312.6	0.012
108755	R2	320.6	0.003
108755	2Q1	115.8	0.005
108755	P1	59.7	0.009
108755	2SM2	66	0.008
108755	M3	310.1	0.009
108755	L2	289.8	0.053
108755	2MK3	338.6	0.025
108755	K2	319.3	0.032
108755	M8	56.3	0.019
108755	MS4	238.5	0.047
108756	M2	292.3	0.878
108756	S2	317.5	0.132
108756	N2	278.4	0.155
108756	K1	90.8	0.056
108756	M4	231.2	0.239
108756	O1	101.7	0.025
108756	M6	111.8	0.165
108756	MK3	358.6	0.044
108756	S4	336	0.025
108756	MN4	208.9	0.084
108756	NU2	274.3	0.033
108756	S6	257.3	0.006
108756	MU2	21.9	0.035
108756	2N2	275.1	0.017
108756	OO1	94.4	0.004
108756	LDA2	270.8	0.042
108756	S1	80.4	0.01
108756	M1	158.8	0.007
108756	J1	225.1	0.004
108756	RHO1	187.1	0.003
108756	Q1	120.1	0.009
108756	T2	318	0.005
108756	R2	244.9	0.011
108756	2Q1	57.7	0.002
108756	P1	91.3	0.017
108756	2SM2	115.6	0.011
108756	M3	340.7	0.024
108756	L2	294.3	0.087
108756	2MK3	343.5	0.034
108756	K2	307.3	0.037
108756	M8	37.9	0.051
108756	MS4	220.9	0.072
108757	M2	289.7	1.533
108757	S2	328.1	0.291
108757	N2	276.5	0.276
108757	K1	81.7	0.099
108757	M4	193.4	0.159
108757	O1	74.8	0.044
108757	M6	76.9	0.129
108757	MK3	52.6	0.009
108757	S4	334.2	0.073
108757	MN4	194.4	0.063
108757	NU2	272.1	0.108
108757	S6	255.6	0.03
108757	MU2	13.8	0.069
108757	2N2	305.4	0.036
108757	OO1	241.5	0.015
108757	LDA2	269.7	0.059
108757	M1	259.2	0.008
108757	J1	99.5	0.011
108757	RHO1	104	0.004
108757	Q1	150.3	0.018
108757	2Q1	184.9	0.003
108757	P1	98	0.046
108757	2SM2	41.4	0.019
108757	M3	10.8	0.043
108757	L2	289.2	0.106
108757	2MK3	316.9	0.03
108757	K2	324.1	0.072
108757	M8	313.2	0.038
108757	MS4	194.7	0.087
108758	M2	336.3	1.095
108758	S2	18.4	0.132
108758	N2	341.2	0.185
108758	K1	149.2	0.131
108758	M4	38.2	0.046
108758	O1	153.5	0.059
108758	M6	92.8	0.093
108758	MK3	81.7	0.05
108758	S4	34	0.014
108758	MN4	342.8	0.043
108758	NU2	104.3	0.021
108758	S6	292	0.006
108758	MU2	79	0.037
108758	2N2	270.2	0.013
108758	OO1	281.8	0.003
108758	LDA2	20.4	0.084
108758	M1	351.7	0.006
108758	J1	87.2	0.012
108758	RHO1	287.2	0.002
108758	Q1	154	0.021
108758	2Q1	37.5	0.008
108758	P1	149.4	0.033
108758	2SM2	231.7	0.004
108758	M3	350.8	0.002
108758	L2	27	0.076
108758	2MK3	72.3	0.029
108758	K2	46.4	0.063
108758	M8	284.2	0.022
108758	MS4	53.7	0.027
108759	M2	344.6	1.554
108759	S2	355.9	0.175
108759	N2	326.9	0.166
108759	K1	156.8	0.156
108759	M4	19.1	0.089
108759	O1	167	0.076
108759	M6	138.7	0.138
108759	MK3	82.2	0.077
108759	S4	28.9	0.018
108759	MN4	352.7	0.094
108759	NU2	7	0.019
108759	S6	14.3	0.007
108759	MU2	142.3	0.164
108759	2N2	80.8	0.074
108759	OO1	354.5	0.004
108759	LDA2	7.3	0.155
108759	M1	18.4	0.012
108759	J1	12.9	0.02
108759	RHO1	59.6	0.018
108759	Q1	150.6	0.026
108759	2Q1	91.9	0.019
108759	P1	169.2	0.039
108759	2SM2	210.1	0.025
108759	M3	78.3	0.019
108759	L2	47	0.21
108759	2MK3	84.7	0.057
108759	K2	20.1	0.079
108759	M8	116.7	0.005
108759	MS4	63.1	0.062
108760	M2	345.3	1.609
108760	S2	353.8	0.173
108760	N2	326.6	0.152
108760	K1	154.1	0.156
108760	M4	18	0.167
108760	O1	169	0.085
108760	M6	150.1	0.133
108760	MK3	85.1	0.084
108760	S4	30.4	0.015
108760	MN4	351.4	0.112
108760	NU2	65	0.016
108760	S6	1.6	0.006
108760	MU2	144.7	0.177
108760	2N2	81.2	0.079
108760	OO1	337	0.004
108760	LDA2	6.8	0.152
108760	M1	37.6	0.009
108760	J1	1.4	0.024
108760	RHO1	82.2	0.017
108760	Q1	142.9	0.029
108760	2Q1	116.4	0.019
108760	P1	171.2	0.042
108760	2SM2	207.3	0.03
108760	M3	101.6	0.026
108760	L2	48.2	0.224
108760	2MK3	87.3	0.075
108760	K2	23.4	0.088
108760	M8	180	0.031
108760	MS4	60.4	0.074
108761	M2	12.4	1.385
108761	S2	44.3	0.299
108761	N2	359.1	0.295
108761	K1	159.7	0.197
108761	M4	105.7	0.079
108761	O1	160.1	0.068
108761	M6	268.4	0.063
108761	MK3	199.3	0.01
108761	S4	104.5	0.029
108761	MN4	89.8	0.029
108761	S6	317.6	0.006
108761	2N2	338.4	0.062
108761	OO1	55.4	0.024
108761	M1	319.8	0.043
108761	J1	14.6	0.017
108761	Q1	214.9	0.049
108761	2Q1	8.8	0.01
108761	P1	172.8	0.087
108761	2SM2	306.1	0.037
108761	M3	87.8	0.016
108761	L2	345.4	0.053
108761	2MK3	90.6	0.024
108761	K2	354.6	0.056
108761	M8	149.9	0.028
108761	MS4	131.4	0.056
108762	M2	7.9	1.221
108762	S2	17.1	0.183
108762	N2	337.9	0.16
108762	K1	135.7	0.114
108762	M4	54.3	0.033
108762	O1	142.6	0.061
108762	M6	339.6	0.038
108762	MK3	117.5	0.021
108762	S4	109.1	0.034
108762	MN4	6.6	0.039
108762	S6	304.6	0.005
108762	2N2	328.1	0.12
108762	OO1	23.5	0.024
108762	M1	292.2	0.019
108762	J1	15	0.034
108762	Q1	201.3	0.031
108762	2Q1	136.7	0.01
108762	P1	106.4	0.032
108762	2SM2	292.8	0.047
108762	M3	166.8	0.023
108762	L2	44.2	0.071
108762	2MK3	125	0.044
108762	K2	356	0.051
108762	M8	148.5	0.02
108762	MS4	89.4	0.033
108763	M2	348.2	0.826
108763	S2	31.2	0.147
108763	N2	348.8	0.134
108763	K1	138.4	0.087
108763	M4	239	0.102
108763	O1	171.4	0.024
108763	M6	128.9	0.046
108763	MK3	316.2	0.034
108763	S4	200.9	0.006
108763	MN4	218.3	0.049
108763	2N2	290.7	0.036
108763	OO1	75.7	0.004
108763	M1	213.1	0.023
108763	J1	151.2	0.01
108763	Q1	177.9	0.016
108763	2Q1	192	0.009
108763	P1	145.6	0.028
108763	2SM2	311.4	0.006
108763	M3	134.3	0.016
108763	L2	339.5	0.038
108763	2MK3	2.7	0.023
108763	K2	358	0.044
108763	M8	268.4	0.03
108763	MS4	249.1	0.062
108764	M2	289.9	1.089
108764	S2	317.1	0.19
108764	N2	278.3	0.246
108764	K1	95.7	0.08
108764	M4	216.2	0.118
108764	O1	120.9	0.032
108764	M6	79	0.132
108764	MK3	292.2	0.011
108764	S4	312	0.043
108764	MN4	194.8	0.042
108764	NU2	290.3	0.039
108764	S6	316.2	0.005
108764	MU2	357.1	0.03
108764	2N2	243.2	0.022
108764	OO1	198.3	0.004
108764	LDA2	263.6	0.028
108764	M1	194.3	0.003
108764	J1	150.9	0.006
108764	RHO1	280.9	0.01
108764	Q1	148.8	0.012
108764	2Q1	321.7	0.003
108764	P1	74.8	0.017
108764	2SM2	82.4	0.006
108764	M3	351.1	0.012
108764	L2	279.2	0.101
108764	2MK3	309.6	0.028
108764	K2	318.6	0.062
108764	M8	348.7	0.043
108764	MS4	199.8	0.054
108765	M2	289.5	1.134
108765	S2	315.5	0.191
108765	N2	278.3	0.253
108765	K1	87.4	0.078
108765	M4	212.2	0.086
108765	O1	108.4	0.032
108765	M6	81.1	0.141
108765	MK3	287.4	0.019
108765	S4	319.8	0.038
108765	MN4	177.8	0.036
108765	NU2	288.1	0.05
108765	S6	348	0.004
108765	MU2	8.5	0.036
108765	2N2	264	0.021
108765	OO1	181.9	0.006
108765	LDA2	260.1	0.034
108765	M1	151.9	0.003
108765	J1	136.6	0.009
108765	RHO1	312.1	0.007
108765	Q1	135.8	0.009
108765	2Q1	330.3	0.002
108765	P1	74.6	0.013
108765	2SM2	78.5	0.006
108765	M3	347	0.015
108765	L2	280.1	0.107
108765	2MK3	313	0.031
108765	K2	323.6	0.066
108765	M8	338.5	0.028
108765	MS4	193.4	0.055
108766	M2	286.1	0.994
108766	S2	315.1	0.181
108766	N2	275.5	0.237
108766	K1	79.9	0.077
108766	M4	194.9	0.058
108766	O1	83.9	0.038
108766	M6	83.9	0.101
108766	MK3	284.6	0.022
108766	S4	320.9	0.038
108766	MN4	166	0.036
108766	NU2	274.8	0.043
108766	S6	14.3	0.002
108766	MU2	338.3	0.051
108766	2N2	285.8	0.024
108766	OO1	202.5	0.005
108766	LDA2	229.1	0.027
108766	M1	115.5	0.005
108766	J1	126.1	0.011
108766	Q1	96.6	0.014
108766	2Q1	237.3	0.005
108766	P1	67	0.016
108766	2SM2	8.2	0.006
108766	M3	351.2	0.016
108766	L2	256.5	0.084
108766	2MK3	293.6	0.021
108766	K2	322	0.067
108766	M8	343.2	0.012
108766	MS4	188.7	0.053
108767	M2	296.6	0.466
108767	S2	336	0.079
108767	N2	268.6	0.081
108767	K1	53.9	0.031
108767	M4	261.4	0.199
108767	O1	167.7	0.012
108767	M6	156.6	0.063
108767	MK3	17.6	0.03
108767	S4	8.4	0.019
108767	MN4	219.5	0.046
108767	S6	176.4	0.009
108767	2N2	33.6	0.018
108767	OO1	306.1	0.008
108767	M1	115.3	0.011
108767	J1	151.8	0.019
108767	Q1	213.9	0.003
108767	2Q1	336.9	0.011
108767	2SM2	334.8	0.012
108767	M3	359.3	0.029
108767	L2	359.1	0.062
108767	2MK3	26.8	0.025
108767	K2	301.9	0.056
108767	M8	85.7	0.058
108767	MS4	213.9	0.027
108768	M2	296.6	0.458
108768	S2	0.9	0.043
108768	N2	275.3	0.085
108768	K1	50.5	0.026
108768	M4	261.3	0.191
108768	O1	132.5	0.01
108768	M6	162.3	0.075
108768	MK3	16.9	0.027
108768	S4	2.4	0.015
108768	MN4	213.4	0.043
108768	S6	160.9	0.01
108768	2N2	78	0.019
108768	OO1	345.7	0.007
108768	M1	108.2	0.01
108768	J1	126	0.024
108768	Q1	173.7	0.002
108768	2Q1	341.3	0.011
108768	2SM2	358.1	0.01
108768	M3	6.1	0.02
108768	L2	355.5	0.035
108768	2MK3	28.8	0.019
108768	K2	346.2	0.038
108768	M8	80.7	0.068
108768	MS4	210.4	0.024
108769	M2	296.1	0.373
108769	S2	292.5	0.02
108769	N2	267.3	0.069
108769	K1	50.2	0.015
108769	M4	253.9	0.184
108769	O1	116.7	0.018
108769	M6	153	0.088
108769	MK3	12.2	0.028
108769	S4	11.8	0.019
108769	MN4	203.2	0.039
108769	S6	190.2	0.015
108769	2N2	153.4	0.015
108769	OO1	48.1	0.005
108769	M1	101.1	0.009
108769	J1	115.4	0.024
108769	Q1	154.2	0.005
108769	2Q1	321.2	0.011
108769	2SM2	26.6	0.017
108769	M3	355.7	0.021
108769	L2	26.2	0.015
108769	2MK3	46.4	0.015
108769	K2	70.2	0.012
108769	M8	77.4	0.067
108769	MS4	220.5	0.035
108770	M2	226.7	0.067
108770	S2	215.2	0.022
108770	N2	211.6	0.016
108770	K1	67.4	0.002
108770	M4	282.1	0.044
108770	O1	97.6	0.004
108770	M6	252.9	0.01
108770	MK3	315.2	0.009
108770	S4	212.3	0.007
108770	MN4	231.9	0.022
108770	NU2	242.3	0.009
108770	S6	175.8	0.005
108770	MU2	227.2	0.009
108770	2N2	303.4	0.003
108770	OO1	334.7	0.003
108770	LDA2	52.2	0.005
108770	M1	39.3	0.002
108770	J1	287.2	0.003
108770	RHO1	242.2	0.001
108770	Q1	97.8	0.003
108770	2Q1	15.8	0.001
108770	2SM2	155.8	0.005
108770	M3	264.2	0.006
108770	L2	281.9	0.007
108770	2MK3	279.8	0.003
108770	M8	67.3	0.004
108770	MS4	300.3	0.001
108771	M2	296.6	0.178
108771	S2	327.1	0.048
108771	N2	273.3	0.04
108771	K1	43.8	0.005
108771	M4	42.2	0.07
108771	O1	78.2	0.006
108771	M6	212.2	0.041
108771	MK3	183.7	0.006
108771	S4	292.8	0.004
108771	MN4	2.9	0.021
108771	NU2	297.6	0.004
108771	S6	260.6	0.003
108771	MU2	292.3	0.007
108771	2N2	157.6	0.004
108771	OO1	184.7	0.005
108771	LDA2	220.6	0.005
108771	M1	200.4	0.003
108771	J1	148	0.003
108771	RHO1	18.6	0.006
108771	Q1	344.2	0.003
108771	2Q1	104.2	0.002
108771	2SM2	332.9	0.002
108771	M3	343.4	0.001
108771	L2	152.6	0.004
108771	2MK3	251.2	0.003
108771	M8	14.8	0.004
108771	MS4	85.8	0.031
108772	M2	259.2	0.283
108772	S2	258.2	0.072
108772	N2	254.5	0.059
108772	K1	69.8	0.011
108772	M4	345.5	0.128
108772	O1	94.7	0.01
108772	M6	226.9	0.031
108772	MK3	279.3	0.016
108772	S4	314	0.022
108772	MN4	302	0.06
108772	NU2	178.8	0.023
108772	S6	249.3	0.01
108772	MU2	270	0.013
108772	2N2	205.9	0.012
108772	OO1	249.7	0.007
108772	LDA2	183.2	0.013
108772	S1	318.8	0.011
108772	M1	283.9	0.005
108772	J1	14.5	0.008
108772	RHO1	50.8	0.006
108772	Q1	296.4	0.01
108772	T2	358.8	0.028
108772	R2	171.1	0.027
108772	2Q1	310.3	0.003
108772	2SM2	245.3	0.011
108772	M3	318.9	0.006
108772	L2	343.5	0.012
108772	2MK3	252.8	0.014
108772	M8	111.1	0.006
108772	MS4	57.5	0.052
108773	M2	274	0.34
108773	S2	264.3	0.088
108773	N2	260.1	0.074
108773	K1	66.9	0.016
108773	M4	350.4	0.126
108773	O1	97.3	0.012
108773	M6	232.6	0.033
108773	MK3	290.1	0.016
108773	S4	319.1	0.02
108773	MN4	310.3	0.06
108773	NU2	200.1	0.022
108773	S6	253.5	0.012
108773	MU2	236.7	0.015
108773	2N2	172.9	0.009
108773	OO1	259.9	0.006
108773	LDA2	219.5	0.007
108773	S1	333.3	0.014
108773	M1	292.8	0.004
108773	J1	0	0.012
108773	RHO1	69.4	0.009
108773	Q1	319.1	0.01
108773	T2	16.8	0.039
108773	R2	189.6	0.032
108773	2Q1	239.6	0.005
108773	2SM2	254.1	0.015
108773	M3	310.8	0.009
108773	L2	333.6	0.013
108773	2MK3	271.8	0.015
108773	M8	127.4	0.004
108773	MS4	62.4	0.053
108774	M2	292.5	0.404
108774	S2	285.4	0.118
108774	N2	273	0.101
108774	K1	39.6	0.03
108774	M4	2.6	0.129
108774	O1	149.2	0.019
108774	M6	259.7	0.046
108774	MK3	296.2	0.014
108774	S4	322.8	0.02
108774	MN4	330.9	0.056
108774	NU2	249.6	0.026
108774	S6	277.8	0.016
108774	MU2	263.5	0.02
108774	2N2	260.6	0.017
108774	OO1	343.8	0.004
108774	LDA2	185	0.008
108774	S1	357.4	0.034
108774	M1	53.8	0.001
108774	J1	31.4	0.012
108774	RHO1	112.7	0.015
108774	Q1	91.8	0.013
108774	T2	37	0.049
108774	R2	237.5	0.048
108774	2Q1	284.7	0.009
108774	2SM2	298.8	0.009
108774	M3	346.6	0.012
108774	L2	286.4	0.021
108774	2MK3	297.1	0.016
108774	M8	87.3	0.014
108774	MS4	88.1	0.062
108775	M2	284.7	0.369
108775	S2	291.7	0.073
108775	N2	268.5	0.087
108775	K1	146.6	0.013
108775	M4	342.6	0.086
108775	O1	97.3	0.025
108775	M6	236	0.02
108775	MK3	320.2	0.012
108775	S4	0.3	0.002
108775	MN4	290.8	0.031
108775	NU2	273.4	0.018
108775	S6	169.2	0.002
108775	MU2	275.2	0.015
108775	2N2	256.8	0.01
108775	OO1	18.3	0.007
108775	LDA2	275.8	0.008
108775	S1	127	0.01
108775	M1	259.6	0.008
108775	J1	7.9	0.007
108775	RHO1	62.3	0.003
108775	Q1	167.2	0.011
108775	T2	230.9	0.013
108775	R2	9.2	0.028
108775	2Q1	60.8	0.008
108775	P1	180.9	0.011
108775	2SM2	6	0.005
108775	M3	9.2	0.006
108775	L2	288.2	0.011
108775	2MK3	271.8	0.009
108775	K2	356.8	0.037
108775	M8	44.7	0.005
108775	MS4	77.5	0.023
108776	M2	326.1	0.238
108776	S2	344	0.059
108776	N2	294.9	0.055
108776	K1	65.4	0.015
108776	M4	307.5	0.046
108776	O1	79.9	0.009
108776	M6	146.3	0.05
108776	MK3	336.8	0.004
108776	S4	296.4	0.001
108776	MN4	264.7	0.025
108776	NU2	339.6	0.011
108776	S6	122.9	0.002
108776	MU2	285.4	0.007
108776	2N2	300.2	0.006
108776	OO1	126.7	0.002
108776	LDA2	287	0.002
108776	S1	344.8	0.009
108776	M1	103.8	0.003
108776	J1	268	0.002
108776	RHO1	61.5	0.003
108776	Q1	9.3	0.003
108776	T2	357.1	0.012
108776	R2	168.8	0.015
108776	2Q1	322	0.005
108776	P1	3.2	0.004
108776	2SM2	342.2	0.005
108776	M3	343.5	0.005
108776	L2	42.7	0.008
108776	2MK3	282.9	0.006
108776	K2	274.6	0.011
108776	M8	254.1	0.018
108776	MS4	339.5	0.012
108777	M2	71.1	2.452
108777	S2	101.2	0.225
108777	N2	38.7	0.6
108777	K1	133.6	0.229
108777	M4	281.8	0.148
108777	O1	125.8	0.151
108777	M6	83.5	0.152
108777	MK3	193.5	0.017
108777	S4	132.4	0.014
108777	MN4	264.6	0.072
108777	S6	49.2	0.003
108777	2N2	118.7	0.055
108777	OO1	170.5	0.013
108777	M1	118.4	0.017
108777	J1	252.2	0.007
108777	Q1	125.5	0.025
108777	2Q1	78.1	0.014
108777	P1	140.3	0.137
108777	2SM2	315.9	0.014
108777	M3	323.8	0.013
108777	L2	115.4	0.17
108777	2MK3	171.3	0.019
108777	K2	101.4	0.162
108777	M8	251.1	0.031
108777	MS4	343.6	0.044
108778	M2	70.9	2.501
108778	S2	97.8	0.219
108778	N2	37.4	0.619
108778	K1	135.9	0.243
108778	M4	286.6	0.139
108778	O1	125.9	0.153
108778	M6	80.4	0.161
108778	MK3	192	0.02
108778	S4	145.9	0.015
108778	MN4	272.9	0.072
108778	S6	5.1	0.009
108778	2N2	113.8	0.058
108778	OO1	161	0.014
108778	M1	118.8	0.018
108778	J1	254.8	0.007
108778	Q1	116	0.025
108778	2Q1	78.2	0.016
108778	P1	144.2	0.143
108778	2SM2	314.1	0.017
108778	M3	315.7	0.012
108778	L2	107.6	0.167
108778	2MK3	172.2	0.02
108778	K2	100.1	0.176
108778	M8	245.6	0.026
108778	MS4	347	0.038
108779	M2	70.6	2.578
108779	S2	99	0.244
108779	N2	37.2	0.634
108779	K1	137.1	0.25
108779	M4	283.7	0.126
108779	O1	128.5	0.155
108779	M6	80.1	0.162
108779	MK3	203.4	0.022
108779	S4	148.4	0.016
108779	MN4	275.9	0.057
108779	S6	343.1	0.009
108779	2N2	113.6	0.066
108779	OO1	162.6	0.013
108779	M1	120.9	0.017
108779	J1	257.1	0.005
108779	Q1	122.3	0.025
108779	2Q1	71	0.014
108779	P1	144.7	0.147
108779	2SM2	329.7	0.015
108779	M3	305.5	0.01
108779	L2	106.1	0.19
108779	2MK3	178.5	0.024
108779	K2	103.6	0.17
108779	M8	259.7	0.032
108779	MS4	350.5	0.032
108780	M2	84.9	0.341
108780	S2	103.9	0.13
108780	N2	112.2	0.093
108780	K1	317.1	0.761
108780	M4	1.8	0.069
108780	O1	306.7	0.661
108780	M6	206	0.007
108780	MK3	240	0.024
108780	S4	117	0.003
108780	MN4	333.4	0.038
108780	NU2	168.2	0.025
108780	S6	344.8	0.009
108780	MU2	184.3	0.009
108780	2N2	161.3	0.035
108780	OO1	337.7	0.079
108780	LDA2	56.6	0.008
108780	M1	307.3	0.033
108780	J1	333.5	0.055
108780	RHO1	302.1	0.03
108780	Q1	298.7	0.132
108780	2Q1	8.4	0.01
108780	P1	328.7	0.183
108780	2SM2	270.1	0.009
108780	M3	202	0.014
108780	L2	327.3	0.02
108780	2MK3	195.7	0.007
108780	K2	120.9	0.034
108780	M8	211.7	0.002
108780	MS4	35.1	0.036
108781	M2	81	0.206
108781	S2	115.7	0.112
108781	N2	119.8	0.063
108781	K1	316.4	0.589
108781	M4	9.3	0.065
108781	O1	308.7	0.538
108781	M6	112.6	0.012
108781	MK3	274.9	0.011
108781	S4	156.7	0.015
108781	MN4	326.8	0.037
108781	NU2	178.2	0.029
108781	S6	222.4	0.004
108781	MU2	231.4	0.008
108781	2N2	215.4	0.024
108781	OO1	54.9	0.019
108781	LDA2	30.9	0.009
108781	M1	280.8	0.045
108781	J1	35.2	0.03
108781	RHO1	309.4	0.05
108781	Q1	291.5	0.109
108781	2Q1	71.1	0.04
108781	P1	349.1	0.127
108781	2SM2	84.1	0.015
108781	M3	69.5	0.009
108781	L2	40.2	0.03
108781	2MK3	335	0.02
108781	K2	71.8	0.043
108781	M8	341.6	0.003
108781	MS4	47.9	0.031
108782	M2	241.7	1.558
108782	S2	253.4	0.312
108782	N2	213	0.279
108782	K1	217	0.641
108782	M4	118.5	0.105
108782	O1	202.2	0.328
108782	M6	204.1	0.041
108782	MK3	114.3	0.147
108782	S4	29.8	0.008
108782	MN4	92.6	0.031
108782	NU2	227.6	0.083
108782	MU2	68	0.07
108782	2N2	153	0.041
108782	OO1	284.7	0.023
108782	LDA2	235.8	0.041
108782	S1	209.6	0.058
108782	M1	298.7	0.002
108782	J1	53.5	0.011
108782	RHO1	157.9	0.019
108782	Q1	222.5	0.067
108782	T2	210.7	0.019
108782	2Q1	235.5	0.02
108782	P1	221.5	0.19
108782	2SM2	95.7	0.021
108782	M3	38.5	0.044
108782	L2	269.8	0.106
108782	2MK3	105.8	0.161
108782	K2	245	0.155
108782	M8	141.4	0.004
108782	MS4	129.9	0.044
108783	M2	177.8	1.312
108783	S2	180.6	0.291
108783	N2	145.4	0.233
108783	K1	175	0.472
108783	M4	112.2	0.019
108783	O1	158.9	0.275
108783	M6	104.8	0.045
108783	MK3	49.4	0.009
108783	S4	11.3	0.005
108783	MN4	324.6	0.012
108783	S6	11.5	0.005
108783	2N2	320.6	0.008
108783	OO1	291.7	0.02
108783	M1	152.8	0.007
108783	J1	236.3	0.011
108783	Q1	160.7	0.04
108783	2Q1	99	0.009
108783	P1	164.2	0.135
108783	2SM2	13.4	0.022
108783	M3	353.8	0.027
108783	L2	214.9	0.05
108783	2MK3	26.4	0.052
108783	K2	181.7	0.097
108783	M8	14.3	0.013
108783	MS4	230.3	0.007
108784	M2	174.6	1.217
108784	S2	179.6	0.266
108784	N2	145.2	0.201
108784	K1	173	0.438
108784	M4	192.6	0.032
108784	O1	156.4	0.258
108784	M6	84.7	0.047
108784	MK3	153.5	0.012
108784	S4	37.2	0.004
108784	MN4	185.3	0.006
108784	S6	348.2	0.003
108784	2N2	227.4	0.011
108784	OO1	278.6	0.025
108784	M1	199.9	0.007
108784	J1	246	0.019
108784	Q1	160	0.039
108784	2Q1	99.4	0.012
108784	P1	164.5	0.131
108784	2SM2	359.9	0.014
108784	M3	357.8	0.023
108784	L2	195.5	0.058
108784	2MK3	16	0.039
108784	K2	171.9	0.09
108784	M8	28	0.009
108784	MS4	195.3	0.032
108785	M2	169.8	0.854
108785	S2	176.5	0.163
108785	N2	145.7	0.107
108785	K1	171.7	0.293
108785	M4	218.5	0.073
108785	O1	155.9	0.17
108785	M6	359.7	0.068
108785	MK3	84.3	0.012
108785	S4	149.9	0.018
108785	MN4	179.7	0.026
108785	S6	253.8	0.004
108785	2N2	235.8	0.042
108785	OO1	293.6	0.024
108785	M1	227.5	0.008
108785	J1	261.2	0.02
108785	Q1	179.9	0.025
108785	2Q1	202.4	0.013
108785	P1	172.7	0.088
108785	2SM2	330.8	0.026
108785	M3	289.8	0.017
108785	L2	198.4	0.075
108785	2MK3	341.7	0.063
108785	K2	183.2	0.068
108785	M8	243.4	0.003
108785	MS4	187.8	0.074
108786	M2	120.5	0.725
108786	S2	117.2	0.078
108786	N2	103	0.128
108786	K1	129.4	0.141
108786	M4	33.5	0.103
108786	O1	93	0.077
108786	M6	291.9	0.047
108786	MK3	345	0.095
108786	S4	292.4	0.007
108786	MN4	21.4	0.023
108786	NU2	117.8	0.034
108786	S6	177.6	0.005
108786	MU2	289.2	0.033
108786	2N2	110.5	0.007
108786	OO1	220.6	0.004
108786	LDA2	125.8	0.019
108786	S1	106.4	0.031
108786	M1	198.5	0.039
108786	J1	240.1	0.02
108786	RHO1	110	0.016
108786	Q1	131	0.022
108786	T2	206.5	0.018
108786	R2	272.8	0.064
108786	2Q1	21.6	0.007
108786	P1	152.5	0.082
108786	2SM2	303.8	0.009
108786	M3	69.8	0.013
108786	L2	122.3	0.064
108786	2MK3	315.4	0.093
108786	K2	80.9	0.053
108786	M8	247.3	0.01
108786	MS4	35.3	0.034
108787	M2	119.3	0.622
108787	S2	112.6	0.108
108787	N2	101.3	0.098
108787	K1	133.8	0.119
108787	M4	28.4	0.117
108787	O1	94.9	0.081
108787	M6	288.8	0.041
108787	MK3	348.4	0.094
108787	S4	335.6	0.004
108787	MN4	4.5	0.039
108787	NU2	95.2	0.031
108787	S6	167	0.004
108787	MU2	269.4	0.037
108787	2N2	66.4	0.009
108787	OO1	213.9	0.005
108787	LDA2	106.8	0.017
108787	S1	90.2	0.025
108787	M1	193.9	0.029
108787	J1	221.5	0.017
108787	RHO1	99.6	0.011
108787	Q1	126.2	0.017
108787	T2	255.3	0.007
108787	R2	296.3	0.045
108787	2Q1	26.6	0.008
108787	P1	141.7	0.071
108787	2SM2	315.1	0.007
108787	M3	41.6	0.01
108787	L2	124.1	0.053
108787	2MK3	322.9	0.088
108787	K2	104.4	0.046
108787	M8	243.2	0.011
108787	MS4	37.1	0.047
108788	M2	116.6	0.427
108788	S2	120.1	0.079
108788	N2	104.7	0.073
108788	K1	141	0.066
108788	M4	16.6	0.135
108788	O1	105.1	0.062
108788	M6	269.6	0.029
108788	MK3	349.6	0.093
108788	S4	208.2	0.001
108788	MN4	11	0.058
108788	NU2	81.6	0.02
108788	S6	125	0.003
108788	MU2	249.2	0.032
108788	2N2	359.4	0.005
108788	OO1	238.1	0.011
108788	LDA2	111.3	0.014
108788	S1	24.1	0.02
108788	M1	188.4	0.023
108788	J1	204	0.01
108788	RHO1	277.9	0.006
108788	Q1	110.7	0.013
108788	T2	282.6	0.012
108788	R2	242.5	0.024
108788	2Q1	65.4	0.001
108788	P1	115.9	0.043
108788	2SM2	60.7	0.002
108788	M3	53.5	0.017
108788	L2	109.1	0.029
108788	2MK3	322.4	0.083
108788	K2	171.5	0.017
108788	M8	284.6	0.005
108788	MS4	27.8	0.062
108789	M2	138.1	1.209
108789	S2	152.1	0.273
108789	N2	115.1	0.224
108789	K1	145	0.273
108789	M4	16.1	0.106
108789	O1	130.3	0.134
108789	M6	283.9	0.05
108789	MK3	349.2	0.135
108789	S4	131.3	0.006
108789	MN4	350	0.049
108789	NU2	130.8	0.058
108789	S6	249.7	0.002
108789	MU2	266.8	0.057
108789	2N2	80.4	0.038
108789	LDA2	115.6	0.022
108789	M1	200.3	0.032
108789	J1	219.7	0.016
108789	RHO1	183.1	0.025
108789	Q1	120.4	0.022
108789	2Q1	248.6	0.014
108789	P1	130.3	0.088
108789	2SM2	320.8	0.007
108789	M3	27.5	0.026
108789	L2	137.2	0.071
108789	2MK3	332.4	0.117
108789	K2	122.7	0.073
108789	M8	251.1	0.007
108789	MS4	11.4	0.033
108790	M2	137.7	1.033
108790	S2	155.2	0.232
108790	N2	122.5	0.188
108790	K1	148.1	0.201
108790	M4	14.8	0.067
108790	O1	132.3	0.1
108790	M6	266.9	0.056
108790	MK3	346.3	0.092
108790	S4	88	0.009
108790	MN4	344.9	0.045
108790	NU2	105.3	0.057
108790	S6	19	0.002
108790	MU2	266.3	0.056
108790	2N2	97.5	0.034
108790	OO1	337.5	0.014
108790	LDA2	108.8	0.018
108790	M1	190.6	0.027
108790	J1	193.9	0.017
108790	RHO1	150.7	0.029
108790	Q1	113.9	0.01
108790	2Q1	248	0.015
108790	P1	155.6	0.054
108790	2SM2	322.6	0.007
108790	M3	50.3	0.018
108790	L2	138	0.065
108790	2MK3	325.3	0.09
108790	K2	135.8	0.081
108790	M8	27.5	0.002
108790	MS4	352.2	0.016
108791	M2	136.6	0.889
108791	S2	154	0.201
108791	N2	120.8	0.149
108791	K1	152.6	0.168
108791	M4	2	0.043
108791	O1	132.7	0.1
108791	M6	260.6	0.065
108791	MK3	344.3	0.065
108791	S4	87.2	0.009
108791	MN4	349.7	0.03
108791	NU2	108.8	0.056
108791	S6	123.4	0.001
108791	MU2	254.7	0.046
108791	2N2	69.6	0.018
108791	OO1	344.6	0.017
108791	LDA2	144.5	0.014
108791	M1	174.1	0.016
108791	J1	227.4	0.017
108791	RHO1	146.8	0.007
108791	Q1	136.8	0.023
108791	2Q1	255.6	0.003
108791	P1	161.1	0.056
108791	2SM2	17	0.007
108791	M3	109.7	0.013
108791	L2	124.5	0.076
108791	2MK3	317.4	0.077
108791	K2	135.3	0.075
108791	M8	79.9	0.003
108791	MS4	358.4	0.02
108792	M2	276.2	0.278
108792	S2	236.1	0.138
108792	N2	238.2	0.068
108792	K1	8.7	0.329
108792	M4	203	0.023
108792	O1	357.5	0.315
108792	M6	31.7	0.01
108792	MK3	95.5	0.002
108792	S4	70.4	0.014
108792	MN4	163	0.01
108792	NU2	259.8	0.045
108792	S6	225	0.005
108792	MU2	167.8	0.004
108792	2N2	276.6	0.029
108792	OO1	338.1	0.019
108792	LDA2	339.2	0.017
108792	S1	247.2	0.027
108792	M1	50.8	0.019
108792	J1	329.9	0.029
108792	RHO1	358.3	0.032
108792	Q1	345.3	0.055
108792	T2	244.6	0.009
108792	R2	48.6	0.081
108792	2Q1	246.8	0.017
108792	P1	27.6	0.133
108792	2SM2	133.5	0.016
108792	M3	235.2	0.02
108792	L2	220.8	0.008
108792	2MK3	291	0.009
108792	K2	145.1	0.033
108792	M8	37.1	0.003
108792	MS4	135	0.022
108793	M2	280.3	0.362
108793	S2	244.3	0.182
108793	N2	243.9	0.086
108793	K1	12.4	0.447
108793	M4	218.2	0.026
108793	O1	1.3	0.419
108793	M6	52.5	0.007
108793	MK3	58.1	0.015
108793	S4	78.8	0.015
108793	MN4	164.3	0.011
108793	NU2	264.1	0.054
108793	S6	233.4	0.004
108793	MU2	161.1	0.005
108793	2N2	287.4	0.046
108793	OO1	341.2	0.03
108793	LDA2	340.9	0.017
108793	S1	248.6	0.034
108793	M1	37	0.022
108793	J1	347.4	0.03
108793	RHO1	7.8	0.043
108793	Q1	345.1	0.078
108793	T2	246.3	0.021
108793	R2	57.6	0.098
108793	2Q1	268.1	0.023
108793	P1	32.5	0.164
108793	2SM2	135.6	0.012
108793	M3	259.9	0.024
108793	L2	227.1	0.009
108793	2MK3	315.6	0.005
108793	K2	156.5	0.026
108793	M8	350.6	0.002
108793	MS4	139.9	0.022
108794	M2	285.2	0.445
108794	S2	256.7	0.207
108794	N2	253.2	0.107
108794	K1	12.1	0.551
108794	M4	225.6	0.032
108794	O1	3.2	0.52
108794	M6	139	0.004
108794	MK3	43.8	0.014
108794	S4	77.6	0.014
108794	MN4	179.1	0.013
108794	NU2	262.4	0.056
108794	S6	263	0.008
108794	MU2	125.3	0.004
108794	2N2	285.1	0.061
108794	OO1	351.1	0.041
108794	LDA2	352.6	0.016
108794	S1	311	0.031
108794	M1	33.7	0.027
108794	J1	1	0.042
108794	RHO1	18	0.046
108794	Q1	344.5	0.102
108794	T2	252.8	0.032
108794	R2	72.9	0.099
108794	2Q1	279.8	0.034
108794	P1	37.1	0.191
108794	2SM2	145.1	0.007
108794	M3	259.7	0.03
108794	L2	218.3	0.009
108794	2MK3	318.7	0.004
108794	K2	188.5	0.023
108794	M8	344	0.005
108794	MS4	139.4	0.021
108795	M2	294.8	0.685
108795	S2	311.6	0.354
108795	N2	270.3	0.166
108795	K1	18.4	0.868
108795	M4	230.4	0.048
108795	O1	5.7	0.742
108795	M6	164.6	0.005
108795	MK3	3.6	0.04
108795	S4	46.4	0.012
108795	MN4	209.1	0.027
108795	NU2	278.6	0.04
108795	S6	336.8	0.007
108795	MU2	196.5	0.042
108795	2N2	317.2	0.07
108795	OO1	37.7	0.067
108795	LDA2	61.9	0.042
108795	S1	262	0.13
108795	M1	61.7	0.049
108795	J1	90.1	0.031
108795	RHO1	323.3	0.028
108795	Q1	342.4	0.109
108795	T2	13	0.114
108795	R2	114.8	0.2
108795	2Q1	43.1	0.048
108795	P1	36.9	0.13
108795	2SM2	167.3	0.02
108795	M3	257.8	0.017
108795	L2	1.6	0.067
108795	2MK3	353.8	0.029
108795	M8	222.4	0.002
108795	MS4	212.5	0.018
108796	M2	295.9	0.642
108796	S2	313.2	0.347
108796	N2	271.1	0.153
108796	K1	20.7	0.832
108796	M4	233.7	0.049
108796	O1	6.1	0.703
108796	M6	138.6	0.005
108796	MK3	4.7	0.039
108796	S4	43	0.01
108796	MN4	216.8	0.026
108796	NU2	276.7	0.035
108796	S6	351.6	0.007
108796	MU2	204.6	0.043
108796	2N2	317.9	0.069
108796	OO1	36.5	0.065
108796	LDA2	70.1	0.041
108796	S1	275.5	0.174
108796	M1	64	0.045
108796	J1	107.7	0.03
108796	RHO1	316.1	0.034
108796	Q1	348.2	0.099
108796	T2	15.2	0.114
108796	R2	111.5	0.199
108796	2Q1	33.1	0.05
108796	P1	51.9	0.104
108796	2SM2	159.3	0.017
108796	M3	259.9	0.019
108796	L2	0.9	0.07
108796	2MK3	349.9	0.03
108796	MS4	216.5	0.021
108797	M2	298.2	0.606
108797	S2	310.2	0.333
108797	N2	274.6	0.146
108797	K1	21.5	0.805
108797	M4	229.5	0.055
108797	O1	5.4	0.667
108797	M6	139.4	0.006
108797	MK3	351.1	0.05
108797	S4	39.6	0.009
108797	MN4	209	0.028
108797	NU2	273.2	0.038
108797	S6	13.3	0.004
108797	MU2	206.4	0.043
108797	2N2	315.3	0.068
108797	OO1	38.4	0.066
108797	LDA2	69.4	0.038
108797	S1	275	0.175
108797	M1	65.6	0.042
108797	J1	117.6	0.028
108797	RHO1	315	0.039
108797	Q1	348.3	0.093
108797	T2	3.9	0.101
108797	R2	106.6	0.202
108797	2Q1	28.3	0.047
108797	P1	53.1	0.092
108797	2SM2	160.4	0.018
108797	M3	253.1	0.02
108797	L2	356.8	0.07
108797	2MK3	336.8	0.033
108797	M8	54.5	0.001
108797	MS4	206.3	0.02
108798	M2	340.1	0.284
108798	S2	296.2	0.051
108798	N2	320.1	0.057
108798	K1	27.1	0.269
108798	M4	293.5	0.03
108798	O1	17.1	0.259
108798	M6	284.4	0.003
108798	MK3	21.2	0.03
108798	S4	241	0.004
108798	MN4	261.6	0.021
108798	NU2	290.7	0.017
108798	S6	220.1	0.003
108798	MU2	170.5	0.031
108798	2N2	286.3	0.051
108798	OO1	40.4	0.019
108798	LDA2	351.8	0.014
108798	S1	9.1	0.035
108798	M1	36.5	0.018
108798	J1	337.2	0.015
108798	RHO1	347.9	0.017
108798	Q1	7.3	0.032
108798	T2	139.6	0.031
108798	R2	36.5	0.039
108798	2Q1	301.7	0.017
108798	P1	38.5	0.075
108798	2SM2	242.2	0.006
108798	M3	308.4	0.008
108798	L2	20.1	0.024
108798	2MK3	342.8	0.019
108798	K2	348.2	0.048
108798	M8	237.5	0.004
108798	MS4	261	0.019
108799	M2	347.1	0.395
108799	S2	288.3	0.075
108799	N2	326.2	0.08
108799	K1	27.2	0.413
108799	M4	310.4	0.035
108799	O1	18.5	0.383
108799	M6	262.5	0.01
108799	MK3	31.1	0.041
108799	S4	260.1	0.01
108799	MN4	300.4	0.023
108799	NU2	292.3	0.022
108799	S6	190.9	0.004
108799	MU2	184.2	0.038
108799	2N2	290.4	0.06
108799	OO1	38.8	0.034
108799	LDA2	355.9	0.021
108799	S1	27.2	0.034
108799	M1	38.9	0.023
108799	J1	333.7	0.017
108799	RHO1	353.1	0.02
108799	Q1	2.8	0.044
108799	T2	158.4	0.054
108799	R2	36.8	0.075
108799	2Q1	299.7	0.035
108799	P1	48	0.084
108799	2SM2	270.7	0.008
108799	M3	287.4	0.017
108799	L2	36.8	0.037
108799	2MK3	9.2	0.032
108799	K2	4.1	0.055
108799	M8	284.2	0.001
108799	MS4	319.3	0.022
108800	M2	347.3	0.406
108800	S2	290.3	0.092
108800	N2	327.1	0.084
108800	K1	27.9	0.434
108800	M4	315.4	0.03
108800	O1	18	0.404
108800	M6	254.6	0.011
108800	MK3	34.8	0.045
108800	S4	238.7	0.018
108800	MN4	306.8	0.024
108800	NU2	292	0.026
108800	S6	212.6	0.005
108800	MU2	178	0.039
108800	2N2	291.9	0.059
108800	OO1	42.5	0.038
108800	LDA2	351	0.023
108800	S1	19.3	0.012
108800	M1	38.8	0.021
108800	J1	345.7	0.02
108800	RHO1	357.4	0.025
108800	Q1	0.7	0.044
108800	T2	165.8	0.049
108800	R2	44.6	0.064
108800	2Q1	300	0.039
108800	P1	44.3	0.093
108800	2SM2	305.6	0.01
108800	M3	302.9	0.018
108800	L2	46.4	0.035
108800	2MK3	13.2	0.034
108800	K2	1.6	0.055
108800	M8	318.3	0.004
108800	MS4	318.1	0.026
108801	M2	335.7	0.515
108801	S2	302.6	0.153
108801	N2	298.3	0.138
108801	K1	44.4	0.925
108801	M4	350.1	0.022
108801	O1	37.9	0.673
108801	M6	338.9	0.004
108801	MK3	31.1	0.021
108801	S4	58	0.003
108801	MN4	307.9	0.019
108801	NU2	299.5	0.025
108801	S6	333	0.011
108801	MU2	223.4	0.034
108801	2N2	323.4	0.031
108801	OO1	87.1	0.105
108801	LDA2	82.3	0.021
108801	S1	102.7	0.241
108801	M1	56.5	0.014
108801	J1	16.3	0.047
108801	RHO1	349.9	0.037
108801	Q1	7.8	0.174
108801	T2	151	0.03
108801	R2	113.9	0.053
108801	2Q1	330.9	0.04
108801	2SM2	69.8	0.008
108801	M3	195.5	0.013
108801	L2	54.8	0.011
108801	2MK3	359.6	0.004
108801	M8	184.6	0.002
108801	MS4	347.4	0.02
108802	M2	288.9	0.453
108802	S2	267	0.13
108802	N2	262.2	0.119
108802	K1	5.5	0.489
108802	M4	190.9	0.025
108802	O1	356	0.434
108802	M6	114.4	0.017
108802	MK3	325.4	0.024
108802	S4	65.3	0.02
108802	MN4	102.1	0.018
108802	NU2	176.5	0.034
108802	S6	127.1	0.008
108802	MU2	190.6	0.042
108802	2N2	75.3	0.032
108802	OO1	359.9	0.04
108802	LDA2	32.8	0.029
108802	S1	256.9	0.143
108802	M1	63	0.043
108802	J1	103	0.022
108802	RHO1	281.3	0.047
108802	Q1	334.8	0.08
108802	T2	211.1	0.029
108802	R2	34.1	0.097
108802	2Q1	55.4	0.022
108802	P1	336.7	0.131
108802	2SM2	322.6	0.009
108802	M3	349.2	0.007
108802	L2	328.7	0.031
108802	2MK3	253.6	0.021
108802	K2	324.9	0.08
108802	M8	278.8	0.004
108802	MS4	124.7	0.018
108803	M2	285	0.567
108803	S2	258	0.162
108803	N2	258.4	0.15
108803	K1	11.6	0.607
108803	M4	184.9	0.006
108803	O1	0.2	0.552
108803	M6	139	0.018
108803	MK3	46.1	0.018
108803	S4	66.4	0.025
108803	MN4	54.9	0.009
108803	NU2	185.9	0.031
108803	S6	138.4	0.006
108803	MU2	186.8	0.047
108803	2N2	75.8	0.059
108803	OO1	11.3	0.051
108803	LDA2	42.9	0.032
108803	S1	261.1	0.144
108803	M1	67.6	0.05
108803	J1	101	0.024
108803	RHO1	294.4	0.049
108803	Q1	336.4	0.1
108803	T2	185.7	0.027
108803	R2	38.6	0.114
108803	2Q1	61.7	0.026
108803	P1	347.2	0.179
108803	2SM2	356.4	0.018
108803	M3	325.3	0.02
108803	L2	312.9	0.036
108803	2MK3	74.1	0.012
108803	K2	336.2	0.082
108803	MS4	108.8	0.017
108804	M2	286	0.643
108804	S2	255.2	0.168
108804	N2	258.5	0.163
108804	K1	13.8	0.674
108804	M4	148.4	0.003
108804	O1	3.4	0.626
108804	M6	154.9	0.013
108804	MK3	97.8	0.021
108804	S4	75.3	0.021
108804	NU2	206.3	0.021
108804	S6	170.9	0.003
108804	MU2	186.2	0.039
108804	2N2	77.9	0.07
108804	OO1	14.7	0.05
108804	LDA2	48.9	0.042
108804	S1	279.1	0.114
108804	M1	66.1	0.047
108804	J1	83.7	0.025
108804	RHO1	312.3	0.045
108804	Q1	339.1	0.114
108804	T2	145.7	0.038
108804	R2	31	0.098
108804	2Q1	60.4	0.034
108804	P1	357	0.193
108804	2SM2	2.5	0.019
108804	M3	295.4	0.021
108804	L2	321.9	0.039
108804	2MK3	97.3	0.024
108804	K2	342.3	0.094
108804	M8	159.9	0.004
108804	MS4	92.7	0.014
108805	M2	122.3	0.767
108805	S2	140.9	0.26
108805	N2	114.3	0.13
108805	K1	329.2	0.454
108805	M4	240.7	0.019
108805	O1	312.9	0.378
108805	M6	209.6	0.003
108805	MK3	100.2	0.032
108805	S4	125.3	0.003
108805	NU2	119.1	0.044
108805	S6	135	0.001
108805	MU2	330	0.025
108805	2N2	11.1	0.03
108805	OO1	304.7	0.013
108805	LDA2	177	0.027
108805	M1	217.1	0.004
108805	J1	306.8	0.016
108805	RHO1	306.2	0.026
108805	Q1	313.6	0.059
108805	2Q1	280.2	0.014
108805	P1	345	0.105
108805	2SM2	73.6	0.01
108805	M3	3.3	0.011
108805	L2	129	0.034
108805	2MK3	96.8	0.03
108805	K2	131.4	0.111
108805	M8	76.9	0.002
108805	MS4	195	0.003
108806	M2	123.6	0.93
108806	S2	141.3	0.311
108806	N2	118.1	0.156
108806	K1	330.4	0.554
108806	M4	246	0.019
108806	O1	315.6	0.459
108806	M6	227.6	0.006
108806	MK3	108.2	0.035
108806	S4	150.4	0.002
108806	NU2	122.9	0.044
108806	S6	167.7	0.003
108806	MU2	336.2	0.035
108806	2N2	3	0.04
108806	OO1	312.8	0.016
108806	LDA2	182.3	0.04
108806	M1	213.3	0.005
108806	J1	315.4	0.015
108806	RHO1	309.2	0.029
108806	Q1	315	0.071
108806	2Q1	279.8	0.014
108806	P1	345.7	0.129
108806	2SM2	72.9	0.013
108806	M3	8.9	0.012
108806	L2	133	0.042
108806	2MK3	109.9	0.038
108806	K2	135.1	0.133
108806	MS4	263.9	0.003
108807	M2	124.3	0.954
108807	S2	141.7	0.315
108807	N2	120	0.159
108807	K1	330.9	0.565
108807	M4	251.5	0.019
108807	O1	316.8	0.469
108807	M6	250.3	0.006
108807	MK3	112.9	0.034
108807	S4	215.4	0.002
108807	NU2	123.3	0.043
108807	S6	181.8	0.002
108807	MU2	343.6	0.038
108807	2N2	2.3	0.045
108807	OO1	320.4	0.017
108807	LDA2	182.9	0.045
108807	M1	224.1	0.006
108807	J1	320.9	0.013
108807	RHO1	310.3	0.028
108807	Q1	317.1	0.073
108807	2Q1	279.1	0.015
108807	P1	345.3	0.133
108807	2SM2	68.1	0.014
108807	M3	3.2	0.012
108807	L2	136.3	0.044
108807	2MK3	111.6	0.042
108807	K2	136.7	0.135
108807	MS4	292.9	0.004
108808	M2	148.5	0.685
108808	S2	170.9	0.217
108808	N2	144.7	0.108
108808	K1	338.9	0.347
108808	M4	264.8	0.042
108808	O1	324.7	0.295
108808	M6	339.1	0.009
108808	MK3	128.4	0.088
108808	S4	83.9	0.002
108808	MN4	244.1	0.006
108808	NU2	135.4	0.034
108808	S6	355.9	0.005
108808	MU2	307.8	0.022
108808	2N2	353.2	0.04
108808	OO1	338.6	0.005
108808	LDA2	212.4	0.023
108808	M1	229.7	0.007
108808	J1	329.7	0.01
108808	RHO1	347	0.013
108808	Q1	327.3	0.041
108808	2Q1	287.1	0.012
108808	P1	355.6	0.072
108808	2SM2	149.6	0.005
108808	M3	6.1	0.013
108808	L2	145.1	0.053
108808	2MK3	110.3	0.101
108808	K2	157.5	0.12
108808	M8	100.3	0.002
108808	MS4	280.4	0.016
108809	M2	149.3	0.824
108809	S2	172.4	0.261
108809	N2	145.6	0.129
108809	K1	339.6	0.414
108809	M4	274.2	0.042
108809	O1	325.5	0.353
108809	M6	302.6	0.01
108809	MK3	133.4	0.092
108809	S4	86.4	0.002
108809	MN4	234.1	0.006
108809	NU2	136.7	0.042
108809	S6	353.5	0.005
108809	MU2	317.6	0.027
108809	2N2	351	0.043
108809	OO1	324.8	0.007
108809	LDA2	213.9	0.027
108809	M1	221.7	0.003
108809	J1	329.6	0.009
108809	RHO1	337.6	0.015
108809	Q1	329.2	0.049
108809	2Q1	295.8	0.015
108809	P1	357.6	0.078
108809	2SM2	139	0.005
108809	M3	6.6	0.014
108809	L2	147.6	0.059
108809	2MK3	112.8	0.115
108809	K2	158.4	0.14
108809	M8	120.5	0.002
108809	MS4	273.1	0.017
108810	M2	149	0.858
108810	S2	172.9	0.268
108810	N2	145.5	0.13
108810	K1	339.5	0.424
108810	M4	277.2	0.041
108810	O1	325.5	0.361
108810	M6	300.5	0.011
108810	MK3	134.2	0.09
108810	S4	133.4	0.001
108810	MN4	231.4	0.007
108810	NU2	140.7	0.041
108810	S6	351.5	0.004
108810	MU2	320.6	0.03
108810	2N2	347.4	0.04
108810	OO1	326.4	0.008
108810	LDA2	213.3	0.028
108810	M1	31.7	0.001
108810	J1	338.5	0.009
108810	RHO1	337	0.014
108810	Q1	329.3	0.051
108810	2Q1	300.4	0.014
108810	P1	358.7	0.081
108810	2SM2	128.4	0.007
108810	M3	14.8	0.013
108810	L2	147.8	0.06
108810	2MK3	112.8	0.12
108810	K2	157.5	0.144
108810	M8	142.7	0.003
108810	MS4	270.5	0.02
108811	M2	125	0.622
108811	S2	141.2	0.208
108811	N2	120.2	0.107
108811	K1	326.2	0.298
108811	M4	161.2	0.017
108811	O1	317.6	0.273
108811	M6	212.6	0.012
108811	MK3	70.9	0.021
108811	S4	222.4	0.005
108811	MN4	105.4	0.005
108811	NU2	109.1	0.028
108811	S6	270.5	0.004
108811	MU2	271.3	0.024
108811	2N2	224.8	0.004
108811	OO1	53.7	0.041
108811	LDA2	134.3	0.008
108811	S1	25	0.064
108811	M1	70.2	0.022
108811	J1	343	0.024
108811	RHO1	308.6	0.023
108811	Q1	305.7	0.04
108811	T2	110	0.015
108811	2Q1	149.3	0.023
108811	P1	331.1	0.069
108811	2SM2	36.7	0.008
108811	M3	13.1	0.006
108811	L2	150.2	0.036
108811	2MK3	37	0.02
108811	K2	137.6	0.087
108811	MS4	133.7	0.014
108812	M2	129.2	0.722
108812	S2	149.6	0.27
108812	N2	119.8	0.127
108812	K1	331.6	0.331
108812	M4	193.2	0.031
108812	O1	320.7	0.322
108812	M6	242.7	0.016
108812	MK3	76.7	0.033
108812	S4	232	0.008
108812	MN4	175.1	0.008
108812	NU2	127.9	0.027
108812	S6	254.5	0.005
108812	MU2	293.5	0.032
108812	2N2	269.5	0.011
108812	OO1	51.5	0.047
108812	LDA2	171	0.007
108812	S1	10.8	0.069
108812	M1	79.6	0.025
108812	J1	348.9	0.025
108812	RHO1	317.4	0.025
108812	Q1	306.6	0.047
108812	T2	173.3	0.032
108812	R2	338.1	0.043
108812	2Q1	156.9	0.027
108812	P1	336.4	0.064
108812	2SM2	25.1	0.006
108812	M3	17.8	0.008
108812	L2	148.6	0.049
108812	2MK3	49.5	0.028
108812	K2	137.3	0.087
108812	MS4	179.8	0.014
108813	M2	134.2	0.786
108813	S2	151.1	0.315
108813	N2	121.4	0.138
108813	K1	337.4	0.367
108813	M4	202.7	0.028
108813	O1	325.7	0.361
108813	M6	253.3	0.015
108813	MK3	80.5	0.032
108813	S4	242.8	0.008
108813	MN4	175.2	0.008
108813	NU2	158.6	0.029
108813	S6	236.1	0.004
108813	MU2	313.6	0.038
108813	2N2	266.9	0.017
108813	OO1	47.1	0.042
108813	LDA2	219.6	0.013
108813	S1	1.3	0.072
108813	M1	84	0.021
108813	J1	345.9	0.028
108813	RHO1	338.4	0.02
108813	Q1	311.3	0.056
108813	T2	175.8	0.053
108813	R2	319.1	0.072
108813	2Q1	166.1	0.024
108813	P1	341.2	0.068
108813	2SM2	8.5	0.01
108813	M3	20.5	0.014
108813	L2	145.8	0.057
108813	2MK3	80	0.032
108813	K2	153.1	0.084
108813	MS4	201.1	0.011
\.



COPY public.constituents (name, definition, speed) FROM stdin;
J1	Basic 1 1 1 -1 0 -90    0 -1 0 0 0 0     76	15.5854433
K1	Compound 0 1 0 0 0 0 0 0	15.0410686
K2	Compound 0 0 0 0 0 0 0 1	30.0821373
L2	Compound 0 0 0 0 0 0 1 0	29.5284789
M1	Basic 1 -1 1 0 0 -90    1 -1 0 0 1 0     206	14.4966939
M2	Compound 0 0 0 1 0 0 0 0	28.9841042
M3	Basic 3 -3 3 0 0 0      3 -3 0 0 0 0     149	43.4761563
M4	Compound 0 0 0 2 0 0 0 0	57.9682084
M6	Compound 0 0 0 3 0 0 0 0	86.9523126
M8	Compound 0 0 0 4 0 0 0 0	115.9364169
N2	Compound 0 0 0 0 0 1 0 0	28.4397295
2N2	Basic 2 -4 2 2 0 0      2 -2 0 0 0 0     78	27.8953548
O1	Compound 1 0 0 0 0 0 0 0	13.9430356
OO1	Basic 1 2 1 0 0 -90     -2 -1 0 0 0 0    77	16.1391017
P1	Compound 0 0 1 0 0 0 0 0	14.9589314
Q1	Compound 0 0 0 0 0 0 0 0 1	13.3986609
2Q1	Basic 1 -4 1 2 0 90     2 -1 0 0 0 0     75	12.8542862
R2	Basic 2 0 1 0 -1 180    0 0 0 0 0 0      1	30.0410667
S1	Basic 1 0 0 0 0 0       0 0 0 0 0 0      1	15
S2	Compound 0 0 0 0 1 0 0 0	30
S4	Compound 0 0 0 0 2 0 0 0	60
S6	Compound 0 0 0 0 3 0 0 0	90
T2	Basic 2 0 -1 0 1 0      0 0 0 0 0 0      1	29.9589333
LDA2	Basic 2 -1 0 1 0 180    2 -2 0 0 0 0     78	29.4556253
MU2	Basic 2 -4 4 0 0 0      2 -2 0 0 0 0     78	27.9682084
NU2	Basic 2 -3 4 -1 0 0     2 -2 0 0 0 0     78	28.5125831
RHO1	Basic 1 -3 3 -1 0 90    2 -1 0 0 0 0     75	13.4715145
MK3	Compound 0 1 0 1 0 0 0 0	44.0251729
2MK3	Compound 0 -1 0 2 0 0 0 0	42.9271398
MN4	Compound 0 0 0 1 0 1 0 0	57.4238337
MS4	Compound 0 0 0 1 1 0 0 0	58.9841042
2SM2	Compound 0 0 0 -1 2 0 0 0	31.0158958
MF	Basic 0 2 0 0 0 0       -2 0 0 0 0 0     74	1.0980331
MSF	Compound 0 0 0 -1 1 0 0 0	1.0158958
MM	Basic 0 1 0 -1 0 0      0 0 0 0 0 0      73	0.5443747
SA	Basic 0 0 1 0 0 0       0 0 0 0 0 0      1	0.0410686
SSA	Basic 0 0 2 0 0 0       0 0 0 0 0 0      1	0.0821373
SA-IOS	Doodson 0 0 1 0 -1 0    0	0.0410667
MF-IOS	Doodson 0 2 0 0  0 0    0	1.0980331
S1-IOS	Doodson 1 0 0 0 1 -90   2\n  0  0 -2 .0  0.3534     0  1  0 .50 0.0264	15.000002
OO1-IOS	Doodson 1  2  1  0  0 -90    8\n  -2 -1  0 .50 0.0037    -2  0  0 .0  0.1496    -2  1  0 .0  0.0296\n  -1  0  0 .25 0.0240R1  -1  1  0 .25 0.0099R1   0  1  0 .0  0.6398\n  0  2  0 .0  0.1342     0  3  0 .0  0.0086	16.1391017
R2-IOS	Doodson 2 0 1 0 -1 180    2\n  0  0  2 .50 0.2535     0  1  2 .0  0.0141	30.0410667
A7	Basic 0 3 0 -1 0 0      -2 0 0 0 0 0     74	1.6424078
2MK5	Compound 0  1  0  2  0  0  0  0	73.0092771
2MK6	Compound 0  0  0  2  0  0  0  1	88.0503457
2MN2	Compound 0  0  0  2  0 -1  0  0	29.5284789
2MN6	Compound 0  0  0  2  0  1  0  0	86.4079379
2MS6	Compound 0  0  0  2  1  0  0  0	87.9682084
2NM6	Compound 0  0  0  1  0  2  0  0	85.8635632
2SK5	Compound 0  1  0  0  2  0  0  0	75.0410686
2SM6	Compound 0  0  0  1  2  0  0  0	88.9841042
3MK7	Compound 0  1  0  3  0  0  0  0	101.9933813
3MN8	Compound 0  0  0  3  0  1  0  0	115.3920422
3MS2	Compound 0  0  0  3 -2  0  0  0	26.9523126
3MS4	Compound 0  0  0  3 -1  0  0  0	56.9523126
3MS8	Compound 0  0  0  3  1  0  0  0	116.9523126
ALP1	Doodson 1 -5 3 1 0 90     2\n  -1  0  0 .75 0.0360R1   0 -1  0 .00 0.1906	12.3827651
BET1	Doodson 1 -1 -1 1 0 -90   1\n  0 -1  0 .00 0.2266	14.4145567
CHI1	Basic 1 -1 3 -1 0 -90   0 -1 0 0 0 0     76	14.5695476
H1	Doodson 2 -2 1 0 1 180    2\n  0 -1  0 .50 0.0224     1  0 -1 .50 0.0447	28.9430375
H2	Doodson 2 -2 3 0 -1 0     1\n  0 -1  0 .50 0.0217	29.0251709
KJ2	Basic 2 1 2 -1 0 0      0 -2 0 0 0 0     79	30.626512
ETA2	Doodson 2 1 2 -1 0 0      7\n  0 -1  0 .50 0.0187     0  1  0 .0  0.4355     0  2  0 .0  0.0467\n  1  0  0 .75 0.0747R2   1  1  0 .75 0.0482R2   1  2  0 .75 0.0093R2\n  2  0  0 .50 0.0078	30.626512
KQ1	Basic 1 3 1 -1 0 -90    -2 -1 0 0 0 0    77	16.6834764
UPS1	Doodson 1 3 1 -1 0 -90    5\n  -2  0  0 .00 0.0611     0  1  0 .00 0.6399     0  2  0 .00 0.1318\n  1  0  0 .25 0.0289R1   1  1  0 .25 0.0257R1	16.6834764
M10	Compound 0 0 0 5 0 0 0 0	144.9205211
M12	Compound 0 0 0 6 0 0 0 0	173.9046253
MK4	Compound 0  0  0  1  0  0  0  1	59.0662415
MKS2	Compound 0  0  0  1 -1  0  0  1	29.0662415
MNS2	Compound 0  0  0  1 -1  1  0  0	27.4238337
EPS2	Doodson 2 -5 4 1 0 0   3\n  -1 -1  0 .25 0.0075R2  -1  0  0 .25 0.0402R2   0 -1  0 .50 0.0373	27.4238337
MO3	Compound 1 0 0 1 0 0 0 0	42.9271398
MP1	Basic 1 -2 3 0 0 -90    0 -1 0 0 0 0     76	14.0251729
TAU1	Doodson 1 -2 3 0 0 -90    5\n  -2  0  0 .0  0.0446    -1  0  0 .25 0.0426R1   0 -1  0 .50 0.0284\n  0  1  0 .50 0.2170     0  2  0 .50 0.0142	14.0251729
MPS2	Compound 0 0 1 1 0 0 0 0 0 0 -1	28.9430356
MSK6	Compound 0  0  0  1  1  0  0  1	89.0662415
MSM	Basic 0 1 -2 1 0 0      0 0 0 0 0 0      73	0.4715211
MSN2	Compound 0  0  0  1  1 -1  0  0	30.5443747
MSN6	Compound 0  0  0  1  1  1  0  0	87.4238337
NLK2	Compound 0 0 0 0 0 1 1 -1	27.8860711
NO1	Compound -1 0 0 0 0 1 0 0	14.4966939
OP2	Compound 1  0  1  0  0  0  0  0	28.9019669
OQ2	Doodson 2 -5 2 3 0 0   2\n  -1  0  0 .25 0.1042R2   0 -1  0 .50 0.0386	27.3509801
PHI1	Basic 1 0 3 0 0 -90     0 0 0 0 0 0      1	15.1232059
KP1	Compound 0 0 -1 0 0 0 0 1	15.1232059
PI1	Basic 1 0 -2 0 1 90     0 0 0 0 0 0      1	14.9178647
TK1	Basic 1 0 -2 0 1 90     0 0 1 0 0 0      227	14.9178647
PSI1	Basic 1 0 2 0 -1 -90    0 0 0 0 0 0      1	15.0821353
RP1	Basic 1 0 2 0 -1 90     0 0 0 0 0 0      1	15.0821353
S3	Basic 3 0 0 0 0 0       0 0 0 0 0 0      1	45
SIG1	Basic 1 -4 3 0 0 90     2 -1 0 0 0 0     75	12.9271398
SK3	Compound 0  1  0  0  1  0  0  0	45.0410686
SK4	Compound 0 0 0 0 1 0 0 1	60.0821373
SN4	Compound 0  0  0  0  1  1  0  0	58.4397295
SNK6	Compound 0 0 0 0 1 1 0 1	88.5218668
SO1	Basic 1 2 -1 0 0 -90    0 -1 0 0 0 0     76	16.0569644
SO3	Compound 1  0  0  0  1  0  0  0	43.9430356
THE1	Basic 1 1 -1 1 0 -90    0 -1 0 0 0 0     76	15.5125897
2PO1	Compound -1  0  2  0  0  0  0  0	15.9748271
2NS2	Compound 0  0  0  0 -1  2  0  0	26.879459
MLN2S2	Compound 0  0  0  1 -2  1  1  0	26.9523126
2ML2S2	Compound 0  0  0  2 -2  0  1  0	27.4966873
SKM2	Compound 0  0  0 -1  1  0  0  1	31.0980331
2MS2K2	Compound 0  0  0  2  1  0  0 -2	27.8039339
MKL2S2	Compound 0  0  0  1 -2  0  1  1	28.5947204
M2(KS)2	Compound 0  0  0  1 -2  0  0  2	29.1483788
2SN(MK)2	Compound 0  0  0 -1  2  1  0 -1	29.373488
2KM(SN)2	Compound 0  0  0  1 -1 -1  0  2	30.7086493
NO3	Compound 1  0  0  0  0  1  0  0	42.3827651
2MLS4	Compound 0  0  0  2 -1  0  1  0	57.4966873
ML4	Compound 0  0  0  1  0  0  1  0	58.5125831
N4	Compound 0  0  0  0  0  2  0  0	56.879459
SL4	Compound 0  0  0  0  1  0  1  0	59.5284789
MNO5	Compound 1  0  0  1  0  1  0  0	71.3668693
2MO5	Compound 1  0  0  2  0  0  0  0	71.911244
MSK5	Compound 0  1  0  1  1  0  0  0	74.0251729
2MP5	Compound 0  0  1  2  0  0  0  0	72.9271398
3MP5	Compound 0  0 -1  3  0  0  0  0	71.9933813
MNK5	Compound 0  1  0  1  0  1  0  0	72.4649024
2NMLS6	Compound 0  0  0  1 -1  2  1  0	85.3920422
MSL6	Compound 0  0  0  1  1  0  1  0	88.5125831
2ML6	Compound 0  0  0  2  0  0  1  0	87.4966873
2MNLS6	Compound 0  0  0  2 -1  1  1  0	85.9364169
3MLS6	Compound 0  0  0  3 -1  0  1  0	86.4807916
2MNO7	Compound 1  0  0  2  0  1  0  0	100.3509735
2NMK7	Compound 0  1  0  1  0  2  0  0	100.9046319
2MSO7	Compound 1  0  0  2  1  0  0  0	101.911244
MSKO7	Compound 1  0  0  1  1  0  0  1	103.0092771
2MSN8	Compound 0  0  0  2  1  1  0  0	116.4079379
2(MS)8	Compound 0  0  0  2  2  0  0  0	117.9682084
2(MN)8	Compound 0  0  0  2  0  2  0  0	114.8476675
2MSL8	Compound 0  0  0  2  1  0  1  0	117.4966873
4MLS8	Compound 0  0  0  4 -1  0  1  0	115.4648958
3ML8	Compound 0  0  0  3  0  0  1  0	116.4807916
3MK8	Compound 0  0  0  3  0  0  0  1	117.0344499
2MSK8	Compound 0  0  0  2  1  0  0  1	118.0503457
2M2NK9	Compound 0  1  0  2  0  2  0  0	129.8887361
3MNK9	Compound 0  1  0  3  0  1  0  0	130.4331108
4MK9	Compound 0  1  0  4  0  0  0  0	130.9774855
3MSK9	Compound 0  1  0  3  1  0  0  0	131.9933813
4MN10	Compound 0  0  0  4  0  1  0  0	144.3761464
3MNS10	Compound 0  0  0  3  1  1  0  0	145.3920422
4MS10	Compound 0  0  0  4  1  0  0  0	145.9364169
3MSL10	Compound 0  0  0  3  1  0  1  0	146.4807916
3M2S10	Compound 0  0  0  3  2  0  0  0	146.9523126
4MSK11	Compound 0  1  0  4  1  0  0  0	160.9774855
4MNS12	Compound 0  0  0  4  1  1  0  0	174.3761464
5MS12	Compound 0  0  0  5  1  0  0  0	174.9205211
4MSL12	Compound 0  0  0  4  1  0  1  0	175.4648958
4M2S12	Compound 0  0  0  4  2  0  0  0	175.9364169
M1C	Basic 1 -1 1 0 0 0   1 -1 0 0 0 0   144	14.4920521
3MKS2	Compound 0 0 0 3 -1 0 0 -1	26.8701754
OQ2-HORN	Compound 1 0 0 0 0 0 0 0 1	27.3416965
MSK2	Compound 0 0 0 1 1 0 0 -1	28.9019669
MSP2	Compound 0 0 -1 1 0 0 0 0 0 0 1	29.0251729
2MP3	Compound 0 0 -1 2 0 0 0 0	43.0092771
4MS4	Compound 0 0 0 4 -2 0 0 0	55.9364169
2MNS4	Compound 0 0 0 2 -1 1 0 0	56.4079379
2MSK4	Compound 0 0 0 2 1 0 0 -1	57.8860711
3MN4	Compound 0 0 0 3 0 -1 0 0	58.5125831
2MSN4	Compound 0 0 0 2 1 -1 0 0	59.5284789
3MK5	Compound 0 -1 0 3 0 0 0 0	71.911244
3MO5	Compound -1 0 0 3 0 0 0 0	73.0092771
3MNS6	Compound 0 0 0 3 -1 1 0 0	85.3920422
4MS6	Compound 0 0 0 4 -1 0 0 0	85.9364169
2MNU6	Compound 0 0 0 2 0 0 0 0 0 1	86.4807916
3MSK6	Compound 0 0 0 3 1 0 0 -1	86.8701754
MKNU6	Compound 0 0 0 1 0 0 0 1 0 1	87.5788246
3MSN6	Compound 0 0 0 3 1 -1 0 0	88.5125831
M7	Compound 0 0 0 3 0 0 0 0 0 0 0 1	101.4490066
2MNK8	Compound 0 0 0 2 0 1 0 1	116.4900752
2(MS)N10	Compound 0 0 0 2 2 1 0 0	146.4079379
MNUS2	Compound 0 0 0 1 -1 0 0 0 0 1	27.4966873
2MK2	Compound 0 0 0 2 0 0 0 -1	27.8860711
3KM5	Compound 0  1  0  1  0  0  0  1	74.1073101
KJ2-IHO	Basic  2 1 2 -1 0 180    0 -2 0 0 0 0   79	30.626512
\.



COPY public.currents_geogroups (sid, state, region, subregion) FROM stdin;
ACT8916	Puerto Rico	\N	\N
ACT8921	Puerto Rico	\N	\N
ACT8926	Puerto Rico	\N	\N
ACT8931	Puerto Rico	\N	\N
ACT8936	Puerto Rico	\N	\N
ACT8951	Puerto Rico	\N	\N
ACT8971	Puerto Rico	\N	\N
EPT0003	Maine	\N	\N
EPT0004	Maine	\N	\N
ACT0091	Maine	\N	\N
ACT0101	Maine	\N	\N
ACT0106	Maine	\N	\N
ACT0111	Maine	\N	\N
ACT0116	Maine	\N	\N
ACT0121	Maine	\N	\N
ACT0131	Maine	\N	\N
ACT0136	Maine	\N	\N
ACT0141	Maine	\N	\N
ACT0146	Maine	\N	\N
ACT0151	Maine	\N	\N
ACT0161	Maine	\N	\N
ACT0166	Maine	\N	East Penobscot Bay
ACT0171	Maine	\N	East Penobscot Bay
ACT0176	Maine	\N	East Penobscot Bay
ACT0181	Maine	\N	East Penobscot Bay
ACT0191	Maine	\N	East Penobscot Bay
ACT0196	Maine	\N	East Penobscot Bay
ACT0201	Maine	\N	East Penobscot Bay
ACT0206	Maine	\N	East Penobscot Bay
ACT0216	Maine	\N	East Penobscot Bay
ACT0221	Maine	\N	East Penobscot Bay
ACT0231	Maine	\N	East Penobscot Bay
ACT0236	Maine	\N	East Penobscot Bay
ACT0246	Maine	\N	East Penobscot Bay
ACT0251	Maine	\N	East Penobscot Bay
ACT0256	Maine	\N	East Penobscot Bay
ACT0261	Maine	\N	East Penobscot Bay
ACT0266	Maine	\N	East Penobscot Bay
ACT0271	Maine	\N	East Penobscot Bay
ACT0276	Maine	\N	East Penobscot Bay
ACT0281	Maine	\N	East Penobscot Bay
ACT0291	Maine	\N	\N
ACT0296	Maine	\N	\N
ACT0306	Maine	\N	\N
ACT0311	Maine	\N	\N
PEB0611	Maine	\N	\N
ACT0321	Maine	\N	\N
ACT0331	Maine	\N	\N
PEB0610	Maine	\N	\N
PEB0609	Maine	\N	\N
ACT0346	Maine	\N	\N
PEB0608	Maine	\N	\N
PEB0607	Maine	\N	\N
PEB0606	Maine	\N	\N
PEB0605	Maine	\N	\N
ACT0371	Maine	\N	\N
PEB0604	Maine	\N	\N
ACT0381	Maine	\N	West Penobscot Bay
ACT0386	Maine	\N	West Penobscot Bay
ACT0391	Maine	\N	West Penobscot Bay
ACT0396	Maine	\N	West Penobscot Bay
ACT0411	Maine	\N	West Penobscot Bay
ACT0416	Maine	\N	West Penobscot Bay
ACT0421	Maine	\N	West Penobscot Bay
ACT0426	Maine	\N	West Penobscot Bay
ACT0431	Maine	\N	West Penobscot Bay
ACT0436	Maine	\N	West Penobscot Bay
ACT0441	Maine	\N	West Penobscot Bay
ACT0446	Maine	\N	West Penobscot Bay
ACT0451	Maine	\N	West Penobscot Bay
ACT0456	Maine	\N	West Penobscot Bay
ACT0461	Maine	\N	West Penobscot Bay
ACT0466	Maine	\N	West Penobscot Bay
ACT0471	Maine	\N	West Penobscot Bay
ACT0476	Maine	\N	West Penobscot Bay
ACT0481	Maine	\N	West Penobscot Bay
ACT0486	Maine	\N	West Penobscot Bay
ACT0491	Maine	\N	West Penobscot Bay
ACT0501	Maine	\N	West Penobscot Bay
ACT0506	Maine	\N	West Penobscot Bay
ACT0516	Maine	\N	West Penobscot Bay
ACT0521	Maine	\N	West Penobscot Bay
ACT0526	Maine	\N	West Penobscot Bay
ACT0531	Maine	\N	West Penobscot Bay
ACT0536	Maine	\N	West Penobscot Bay
ACT0541	Maine	\N	West Penobscot Bay
ACT0401	Maine	\N	Isle au Haut Bay
ACT0406	Maine	\N	Isle au Haut Bay
ACT0546	Maine	\N	\N
ACT0551	Maine	\N	\N
ACT0556	Maine	\N	\N
ACT0561	Maine	\N	\N
ACT0566	Maine	\N	\N
ACT0571	Maine	\N	\N
ACT0576	Maine	\N	\N
ACT0581	Maine	\N	\N
ACT0586	Maine	\N	\N
ACT0591	Maine	\N	\N
ACT0596	Maine	\N	\N
CAB1423	Maine	\N	\N
CAB1425	Maine	\N	\N
ACT0601	Maine	Kennebec River	\N
ACT0606	Maine	Kennebec River	\N
ACT0611	Maine	Kennebec River	\N
ACT0616	Maine	Kennebec River	\N
ACT0621	Maine	Kennebec River	\N
ACT0626	Maine	Kennebec River	\N
CAB1420	Maine	Kennebec River	\N
CAB1419	Maine	Kennebec River	\N
CAB1421	Maine	Kennebec River	\N
CAB1418	Maine	Kennebec River	\N
CAB1416	Maine	Casco Bay	\N
CAB1417	Maine	Casco Bay	\N
CAB1414	Maine	Casco Bay	\N
CAB1415	Maine	Casco Bay	\N
CAB1409	Maine	Casco Bay	\N
CAB1411	Maine	Casco Bay	\N
CAB1412	Maine	Casco Bay	\N
CAB1413	Maine	Casco Bay	\N
CAB1410	Maine	Casco Bay	\N
CAB1401	Maine	Casco Bay	\N
CAB1402	Maine	Casco Bay	\N
CAB1403	Maine	Casco Bay	\N
CAB1404	Maine	Casco Bay	\N
CAB1405	Maine	Casco Bay	\N
CAB1406	Maine	Casco Bay	\N
CAB1407	Maine	Casco Bay	\N
ACT0686	Maine	Portsmouth Harbor	\N
ACT0691	Maine	Portsmouth Harbor	\N
PIR0703	Maine	Portsmouth Harbor	\N
ACT0706	Maine	Portsmouth Harbor	\N
PIR0701	Maine	Portsmouth Harbor	\N
ACT0716	Maine	Portsmouth Harbor	\N
PIR0702	Maine	Portsmouth Harbor	\N
ACT0726	Maine	Portsmouth Harbor	\N
ACT0731	Maine	Portsmouth Harbor	\N
ACT0736	Maine	Portsmouth Harbor	\N
ACT0741	Maine	Portsmouth Harbor	\N
PIR0704	Maine	Portsmouth Harbor	\N
ACT0751	Maine	Portsmouth Harbor	\N
ACT0756	Maine	Portsmouth Harbor	\N
pm0101	Maine	Portsmouth Harbor	\N
PIR0705	Maine	\N	\N
PIR0706	Maine	\N	\N
PIR0707	Maine	\N	\N
PIR0708	Maine	\N	\N
PIR0709	Maine	\N	\N
PIR0710	Maine	\N	\N
ACT0791	Maine	\N	\N
ACT0796	Maine	\N	\N
ACT0801	Maine	\N	\N
ACT0806	Maine	\N	\N
PIR0711	Maine	\N	\N
ACT0816	Massachusetts	\N	\N
ACT0821	Massachusetts	\N	\N
ACT0826	Massachusetts	\N	\N
ACT0831	Massachusetts	\N	\N
ACT0836	Massachusetts	\N	\N
ACT0841	Massachusetts	\N	\N
BOS1101	Massachusetts	\N	Salem Sound
BOS1102	Massachusetts	\N	Salem Sound
BOS1103	Massachusetts	\N	Salem Sound
BOS1104	Massachusetts	\N	Salem Sound
BOS1105	Massachusetts	\N	Salem Sound
ACT0906	Massachusetts	\N	\N
ACT0911	Massachusetts	\N	\N
ACT0916	Massachusetts	\N	\N
ACT0921	Massachusetts	\N	\N
ACT0926	Massachusetts	\N	\N
ACT0941	Massachusetts	\N	\N
ACT0946	Massachusetts	\N	\N
ACT0951	Massachusetts	\N	\N
ACT0956	Massachusetts	\N	\N
ACT0961	Massachusetts	\N	\N
ACT0966	Massachusetts	\N	\N
ACT0971	Massachusetts	\N	\N
BOS1108	Massachusetts	\N	\N
ACT1591	Massachusetts	\N	\N
ACT1596	Massachusetts	\N	\N
ACT1601	Massachusetts	\N	\N
BOS1132	Massachusetts	\N	\N
BOS1131	Massachusetts	\N	\N
BOS1135	Massachusetts	\N	\N
BOS1133	Massachusetts	\N	\N
BOS1134	Massachusetts	\N	\N
BOS1128	Massachusetts	\N	\N
BOS1129	Massachusetts	\N	\N
BOS1130	Massachusetts	\N	\N
BOS1106	Massachusetts	\N	\N
ACT1026	Massachusetts	\N	\N
ACT1031	Massachusetts	\N	\N
ACT1036	Massachusetts	\N	\N
ACT1041	Massachusetts	\N	\N
ACT1046	Massachusetts	\N	\N
ACT1051	Massachusetts	\N	\N
BOS1127	Massachusetts	\N	\N
ACT1061	Massachusetts	\N	\N
ACT1066	Massachusetts	\N	\N
BOS1109	Massachusetts	\N	\N
BOS1107	Massachusetts	\N	\N
ACT1081	Massachusetts	\N	\N
ACT1086	Massachusetts	\N	\N
ACT1091	Massachusetts	\N	\N
BOS1110	Massachusetts	\N	\N
ACT1101	Massachusetts	\N	\N
ACT1106	Massachusetts	\N	\N
ACT1111	Massachusetts	\N	\N
BOS1111	Massachusetts	\N	\N
ACT1121	Massachusetts	\N	\N
ACT1126	Massachusetts	\N	\N
ACT1131	Massachusetts	\N	\N
ACT1136	Massachusetts	\N	\N
ACT1141	Massachusetts	\N	\N
ACT1151	Massachusetts	\N	\N
ACT1156	Massachusetts	\N	\N
ACT1161	Massachusetts	\N	\N
ACT1166	Massachusetts	\N	\N
BOS1112	Massachusetts	\N	\N
ACT1176	Massachusetts	\N	\N
ACT1181	Massachusetts	\N	\N
BOS1113	Massachusetts	\N	\N
ACT1191	Massachusetts	\N	\N
BOS1114	Massachusetts	\N	\N
BOS1115	Massachusetts	\N	\N
ACT1206	Massachusetts	\N	\N
BOS1117	Massachusetts	\N	\N
ACT1216	Massachusetts	\N	\N
BOS1118	Massachusetts	\N	\N
ACT1226	Massachusetts	\N	\N
ACT1231	Massachusetts	\N	\N
ACT1236	Massachusetts	\N	\N
ACT1241	Massachusetts	\N	\N
ACT1246	Massachusetts	\N	\N
ACT1251	Massachusetts	\N	\N
ACT1256	Massachusetts	\N	\N
ACT1261	Massachusetts	\N	\N
BOS1119	Massachusetts	\N	\N
ACT1271	Massachusetts	\N	\N
ACT1276	Massachusetts	\N	\N
ACT1281	Massachusetts	\N	\N
ACT1286	Massachusetts	\N	\N
ACT1291	Massachusetts	\N	\N
ACT1296	Massachusetts	\N	\N
BOS1120	Massachusetts	\N	\N
ACT1306	Massachusetts	\N	\N
BOS1121	Massachusetts	\N	\N
ACT1316	Massachusetts	\N	\N
ACT1321	Massachusetts	\N	\N
BOS1122	Massachusetts	\N	\N
ACT1331	Massachusetts	\N	\N
ACT1336	Massachusetts	\N	\N
ACT1341	Massachusetts	\N	\N
BOS1123	Massachusetts	\N	\N
ACT1356	Massachusetts	\N	\N
ACT1361	Massachusetts	\N	\N
ACT1366	Massachusetts	\N	\N
ACT1371	Massachusetts	\N	\N
ACT1376	Massachusetts	\N	\N
ACT1381	Massachusetts	\N	\N
ACT1386	Massachusetts	\N	\N
ACT1391	Massachusetts	\N	\N
ACT1396	Massachusetts	\N	\N
ACT1401	Massachusetts	\N	\N
ACT1406	Massachusetts	\N	\N
ACT1411	Massachusetts	\N	\N
ACT1416	Massachusetts	\N	\N
ACT1421	Massachusetts	\N	\N
ACT1426	Massachusetts	\N	\N
ACT1431	Massachusetts	\N	\N
ACT1436	Massachusetts	\N	\N
ACT1441	Massachusetts	\N	\N
ACT1446	Massachusetts	\N	\N
ACT1451	Massachusetts	\N	\N
ACT1456	Massachusetts	\N	\N
ACT1461	Massachusetts	\N	\N
ACT1466	Massachusetts	\N	\N
ACT1476	Massachusetts	\N	\N
BOS1124	Massachusetts	\N	\N
ACT1486	Massachusetts	\N	\N
ACT1491	Massachusetts	\N	\N
ACT1496	Massachusetts	\N	\N
ACT1501	Massachusetts	\N	\N
ACT1506	Massachusetts	\N	\N
BOS1125	Massachusetts	\N	\N
ACT1516	Massachusetts	\N	\N
BOS1126	Massachusetts	\N	\N
ACT1526	Massachusetts	\N	\N
ACT1531	Massachusetts	\N	\N
ACT1536	Massachusetts	\N	\N
ACT1546	Massachusetts	Cape Cod Bay	\N
ACT1551	Massachusetts	Cape Cod Bay	\N
ACT1556	Massachusetts	Cape Cod Bay	\N
ACT1611	Massachusetts	Nantucket Sound entrance	\N
ACT1616	Massachusetts	Nantucket Sound entrance	\N
ACT1626	Massachusetts	Nantucket Sound	\N
ACT1631	Massachusetts	Nantucket Sound	\N
ACT1636	Massachusetts	Nantucket Sound	\N
ACT1641	Massachusetts	Nantucket Sound	\N
ACT1646	Massachusetts	Nantucket Sound	\N
ACT1651	Massachusetts	Nantucket Sound	\N
ACT1656	Massachusetts	Nantucket Sound	\N
ACT1661	Massachusetts	Nantucket Sound	\N
ACT1666	Massachusetts	Nantucket Sound	\N
ACT1671	Massachusetts	Nantucket Sound	\N
ACT1676	Massachusetts	Nantucket Sound	\N
ACT1686	Massachusetts	Nantucket Sound	\N
ACT1691	Massachusetts	Nantucket Sound	\N
ACT1696	Massachusetts	Nantucket Sound	\N
ACT1701	Massachusetts	Nantucket Sound	\N
ACT1706	Massachusetts	Nantucket Sound	\N
ACT1716	Massachusetts	Nantucket Sound	\N
ACT1721	Massachusetts	Nantucket Sound	\N
ACT1726	Massachusetts	Nantucket Sound	\N
ACT1731	Massachusetts	Nantucket Sound	\N
ACT1736	Massachusetts	Nantucket Sound	\N
ACT1741	Massachusetts	Nantucket Sound	\N
ACT1746	Massachusetts	Nantucket Sound	\N
ACT1751	Massachusetts	Nantucket Sound	\N
ACT1756	Massachusetts	Nantucket Sound	\N
ACT1761	Massachusetts	Nantucket Sound	\N
ACT1766	Massachusetts	Nantucket Sound	\N
ACT1771	Massachusetts	Nantucket Sound	\N
ACT1786	Massachusetts	Nantucket Sound	\N
ACT1791	Massachusetts	Nantucket Sound	\N
ACT1796	Massachusetts	Nantucket Sound	\N
ACT1801	Massachusetts	Nantucket Sound	\N
ACT1806	Massachusetts	Nantucket Sound	\N
ACT1811	Massachusetts	Nantucket Sound	\N
ACT1816	Massachusetts	Nantucket Sound	\N
ACT1821	Massachusetts	Nantucket Sound	\N
ACT1826	Massachusetts	Vineyard Sound	\N
ACT1831	Massachusetts	Vineyard Sound	\N
ACT1836	Massachusetts	Vineyard Sound	\N
ACT1841	Massachusetts	Vineyard Sound	\N
ACT1846	Massachusetts	Vineyard Sound	\N
ACT1851	Massachusetts	Vineyard Sound	\N
ACT1861	Massachusetts	Vineyard Sound	\N
ACT1866	Massachusetts	Vineyard Sound	\N
COD0912	Massachusetts	\N	Woods Hole
COD0911	Massachusetts	\N	Woods Hole
COD0910	Massachusetts	\N	Woods Hole
COD0913	Massachusetts	\N	\N
ACT1901	Massachusetts	\N	Quicks Hole
ACT1911	Massachusetts	\N	Quicks Hole
COD0914	Massachusetts	\N	Quicks Hole
COD0915	Massachusetts	\N	\N
ca0101	Massachusetts	Cape Cod Canal	\N
COD0904	Massachusetts	Cape Cod Canal	\N
ACT2046	Massachusetts	Cape Cod Canal	\N
COD0903	Massachusetts	Cape Cod Canal	\N
COD0902	Massachusetts	Cape Cod Canal	\N
COD0901	Massachusetts	Cape Cod Canal	\N
ACT1921	Massachusetts	Buzzards Bay	\N
ACT1931	Massachusetts	Buzzards Bay	\N
ACT1936	Massachusetts	Buzzards Bay	\N
ACT1941	Massachusetts	Buzzards Bay	\N
ACT1946	Massachusetts	Buzzards Bay	\N
ACT1951	Massachusetts	Buzzards Bay	\N
ACT1956	Massachusetts	Buzzards Bay	\N
ACT1961	Massachusetts	Buzzards Bay	\N
ACT1966	Massachusetts	Buzzards Bay	\N
ACT1971	Massachusetts	Buzzards Bay	\N
ACT1976	Massachusetts	Buzzards Bay	\N
COD0909	Massachusetts	Buzzards Bay	\N
ACT1986	Massachusetts	Buzzards Bay	\N
COD0908	Massachusetts	Buzzards Bay	\N
ACT1996	Massachusetts	Buzzards Bay	\N
ACT2001	Massachusetts	Buzzards Bay	\N
COD0907	Massachusetts	Buzzards Bay	\N
ACT2011	Massachusetts	Buzzards Bay	\N
COD0906	Massachusetts	Buzzards Bay	\N
ACT2021	Massachusetts	Buzzards Bay	\N
ACT2026	Massachusetts	Buzzards Bay	\N
ACT2031	Massachusetts	Buzzards Bay	\N
COD0905	Massachusetts	Buzzards Bay	\N
ACT2071	Massachusetts	Narragansett Bay	\N
ACT2076	Massachusetts	Narragansett Bay	\N
ACT2096	Massachusetts	Narragansett Bay	\N
ACT2101	Massachusetts	Narragansett Bay	\N
ACT2106	Massachusetts	Narragansett Bay	\N
ACT2111	Massachusetts	Narragansett Bay	\N
ACT2116	Massachusetts	Narragansett Bay	\N
ACT2121	Massachusetts	Narragansett Bay	\N
ACT2126	Massachusetts	Narragansett Bay	\N
ACT2131	Massachusetts	Narragansett Bay	\N
ACT2136	Massachusetts	Narragansett Bay	\N
ACT2141	Massachusetts	Narragansett Bay	\N
ACT2146	Massachusetts	Narragansett Bay	\N
ACT2151	Massachusetts	Narragansett Bay	\N
ACT2156	Massachusetts	Narragansett Bay	\N
nb0301	Massachusetts	Narragansett Bay	\N
ACT2166	Massachusetts	Narragansett Bay	\N
ACT2171	Massachusetts	Narragansett Bay	\N
ACT2176	Massachusetts	Narragansett Bay	\N
ACT2181	Massachusetts	Narragansett Bay	\N
nb0201	Massachusetts	Narragansett Bay	\N
ACT2191	Massachusetts	Narragansett Bay	\N
ACT2196	Massachusetts	Narragansett Bay	\N
ACT2201	Massachusetts	Narragansett Bay	\N
ACT2211	Massachusetts	Narragansett Bay	\N
ACT2216	Massachusetts	Narragansett Bay	\N
ACT2226	Massachusetts	Narragansett Bay	\N
ACT2231	Massachusetts	Narragansett Bay	\N
ACT2236	Massachusetts	Narragansett Bay	\N
ACT2241	Massachusetts	Narragansett Bay	\N
ACT2246	Massachusetts	Narragansett Bay	\N
nb0101	Massachusetts	Narragansett Bay	\N
ACT2266	Rhode Island	Block Island Sound	Point Judith
ACT2276	Rhode Island	Block Island Sound	Point Judith
ACT2281	Rhode Island	Block Island Sound	Point Judith
ACT2291	Rhode Island	Block Island Sound	Block Island
ACT2296	Rhode Island	Block Island Sound	Block Island
ACT2301	Rhode Island	Block Island Sound	Block Island
ACT2306	Rhode Island	Block Island Sound	Block Island
ACT2311	Rhode Island	Block Island Sound	Block Island
ACT2316	Rhode Island	Block Island Sound	Block Island
ACT2321	Rhode Island	Block Island Sound	Block Island
ACT2326	Rhode Island	Block Island Sound	Block Island
ACT2331	Rhode Island	Block Island Sound	Block Island
ACT2341	Rhode Island	Block Island Sound	\N
ACT2346	Rhode Island	Block Island Sound	\N
ACT2356	Rhode Island	Block Island Sound	\N
ACT2361	Rhode Island	Block Island Sound	\N
ACT2366	Rhode Island	Block Island Sound	\N
ACT2371	Rhode Island	Block Island Sound	\N
ACT2376	Rhode Island	Block Island Sound	\N
ACT2381	Rhode Island	Block Island Sound	\N
ACT2386	Rhode Island	Block Island Sound	\N
ACT2391	Rhode Island	Block Island Sound	\N
ACT2396	Rhode Island	Block Island Sound	\N
ACT2401	Rhode Island	Block Island Sound	\N
ACT2406	Rhode Island	Block Island Sound	\N
LIS1002	Rhode Island	Block Island Sound	\N
ACT2416	Rhode Island	Block Island Sound	\N
ACT2421	Rhode Island	Block Island Sound	\N
ACT2426	Rhode Island	Block Island Sound	\N
ACT2436	Rhode Island	Block Island Sound	\N
ACT2441	Rhode Island	Block Island Sound	\N
ACT2451	Rhode Island	Block Island Sound	\N
ACT2456	Rhode Island	Block Island Sound	\N
ACT2466	Rhode Island	Block Island Sound	\N
ACT2556	Connecticut	Fishers Island Sound	\N
ACT2561	Connecticut	Fishers Island Sound	\N
ACT2571	Connecticut	Fishers Island Sound	\N
ACT2586	Connecticut	Fishers Island Sound	\N
ACT2591	Connecticut	Fishers Island Sound	\N
LIS1001	Connecticut	Long Island Sound	The Race
ACT2596	Connecticut	Long Island Sound	The Race
ACT2606	Connecticut	Long Island Sound	The Race
ACT2611	Connecticut	Long Island Sound	The Race
ACT2616	Connecticut	Long Island Sound	The Race
LIS1010	Connecticut	Long Island Sound	\N
LIS1004	Connecticut	Long Island Sound	\N
LIS1003	Connecticut	Long Island Sound	Thames River
LIS1005	Connecticut	Long Island Sound	Thames River
LIS1006	Connecticut	Long Island Sound	Thames River
LIS1007	Connecticut	Long Island Sound	Thames River
nl0101	Connecticut	Long Island Sound	Thames River
LIS1008	Connecticut	Long Island Sound	Thames River
LIS1009	Connecticut	Long Island Sound	Thames River
ACT2661	Connecticut	Long Island Sound	Thames River
ACT2666	Connecticut	Long Island Sound	\N
ACT2671	Connecticut	Long Island Sound	\N
ACT2676	Connecticut	Long Island Sound	\N
ACT2681	Connecticut	Long Island Sound	\N
ACT2686	Connecticut	Long Island Sound	\N
ACT2691	Connecticut	Long Island Sound	\N
LIS1011	Connecticut	Long Island Sound	\N
ACT2701	Connecticut	Long Island Sound	\N
LIS1012	Connecticut	Long Island Sound	\N
ACT2711	Connecticut	Long Island Sound	\N
ACT2716	Connecticut	Long Island Sound	\N
ACT2721	Connecticut	Long Island Sound	\N
ACT2726	Connecticut	Long Island Sound	\N
LIS1013	Connecticut	Long Island Sound	Connecticut River
LIS1015	Connecticut	Long Island Sound	Connecticut River
LIS1014	Connecticut	Long Island Sound	Connecticut River
ACT2746	Connecticut	Long Island Sound	Connecticut River
ACT2751	Connecticut	Long Island Sound	Connecticut River
ACT2756	Connecticut	Long Island Sound	Connecticut River
ACT2761	Connecticut	Long Island Sound	Connecticut River
ACT2766	Connecticut	Long Island Sound	Connecticut River
ACT2771	Connecticut	Long Island Sound	Connecticut River
ACT2776	Connecticut	Long Island Sound	\N
ACT2781	Connecticut	Long Island Sound	\N
ACT2786	Connecticut	Long Island Sound	\N
LIS1016	Connecticut	Long Island Sound	\N
ACT2796	Connecticut	Long Island Sound	\N
ACT2801	Connecticut	Long Island Sound	\N
ACT2806	Connecticut	Long Island Sound	\N
ACT2811	Connecticut	Long Island Sound	\N
ACT2816	Connecticut	Long Island Sound	\N
ACT2821	Connecticut	Long Island Sound	\N
LIS1018	Connecticut	Long Island Sound	\N
LIS1017	Connecticut	Long Island Sound	\N
LIS1019	Connecticut	Long Island Sound	\N
ACT2841	Connecticut	Long Island Sound	\N
ACT2846	Connecticut	Long Island Sound	\N
ACT2851	Connecticut	Long Island Sound	\N
ACT2856	Connecticut	Long Island Sound	\N
ACT2861	Connecticut	Long Island Sound	\N
ACT2866	Connecticut	Long Island Sound	\N
ACT2871	Connecticut	Long Island Sound	\N
ACT2876	Connecticut	Long Island Sound	\N
LIS1020	Connecticut	Long Island Sound	\N
ACT2886	Connecticut	Long Island Sound	\N
ACT2891	Connecticut	Long Island Sound	\N
LIS1021	Connecticut	Long Island Sound	\N
ACT2901	Connecticut	Long Island Sound	\N
ACT2906	Connecticut	Long Island Sound	\N
ACT2911	Connecticut	Long Island Sound	\N
LIS1023	Connecticut	Long Island Sound	\N
LIS1024	Connecticut	Long Island Sound	\N
LIS1022	Connecticut	Long Island Sound	\N
ACT2936	Connecticut	Long Island Sound	\N
ACT2941	Connecticut	Long Island Sound	\N
ACT2946	Connecticut	Long Island Sound	\N
ACT2951	Connecticut	Long Island Sound	Housatonic River
ACT2956	Connecticut	Long Island Sound	Housatonic River
ACT2961	Connecticut	Long Island Sound	Housatonic River
ACT2966	Connecticut	Long Island Sound	Housatonic River
ACT2976	Connecticut	Long Island Sound	\N
LIS1026	Connecticut	Long Island Sound	\N
ACT2986	Connecticut	Long Island Sound	\N
ACT2991	Connecticut	Long Island Sound	\N
ACT2996	Connecticut	Long Island Sound	\N
LIS1027	Connecticut	Long Island Sound	\N
ACT3006	Connecticut	Long Island Sound	\N
ACT3011	Connecticut	Long Island Sound	\N
ACT3016	Connecticut	Long Island Sound	\N
LIS1025	Connecticut	Long Island Sound	\N
ACT3026	Connecticut	Long Island Sound	\N
LIS1029	Connecticut	Long Island Sound	\N
LIS1028	Connecticut	Long Island Sound	\N
ACT3041	Connecticut	Long Island Sound	\N
ACT3046	Connecticut	Long Island Sound	\N
ACT3051	Connecticut	Long Island Sound	\N
ACT3056	Connecticut	Long Island Sound	\N
ACT3061	Connecticut	Long Island Sound	\N
ACT3066	Connecticut	Long Island Sound	\N
LIS1031	Connecticut	Long Island Sound	\N
ACT3076	Connecticut	Long Island Sound	\N
ACT3081	Connecticut	Long Island Sound	\N
LIS1032	Connecticut	Long Island Sound	\N
ACT3091	Connecticut	Long Island Sound	\N
ACT3096	Connecticut	Long Island Sound	\N
LIS1030	Connecticut	Long Island Sound	\N
ACT3106	Connecticut	Long Island Sound	\N
ACT3111	Connecticut	Long Island Sound	\N
ACT3116	Connecticut	Long Island Sound	\N
ACT3121	Connecticut	Long Island Sound	\N
ACT3126	Connecticut	Long Island Sound	\N
ACT3131	Connecticut	Long Island Sound	\N
ACT3136	Connecticut	Long Island Sound	\N
LIS1033	Connecticut	Long Island Sound	\N
LIS1034	Connecticut	Long Island Sound	\N
ACT3151	Connecticut	Long Island Sound	Oyster Bay
ACT3156	Connecticut	Long Island Sound	Oyster Bay
ACT3161	Connecticut	Long Island Sound	Oyster Bay
ACT3166	Connecticut	Long Island Sound	Oyster Bay
ACT3171	Connecticut	Long Island Sound	\N
ACT3176	Connecticut	Long Island Sound	\N
ACT3181	Connecticut	Long Island Sound	\N
ACT3186	Connecticut	Long Island Sound	\N
ACT3191	Connecticut	Long Island Sound	\N
ACT3196	Connecticut	Long Island Sound	\N
ACT3201	Connecticut	Long Island Sound	\N
LIS1035	Connecticut	Long Island Sound	\N
ACT3211	Connecticut	Long Island Sound	\N
ACT3216	Connecticut	Long Island Sound	\N
ACT3226	Connecticut	Long Island Sound	\N
ACT3236	Connecticut	Long Island Sound	\N
ACT3241	Connecticut	Long Island Sound	\N
ACT3246	Connecticut	Long Island Sound	\N
ACT3251	Connecticut	Long Island Sound	\N
ACT3256	Connecticut	Long Island Sound	\N
ACT3261	Connecticut	Long Island Sound	\N
LIS1036	Connecticut	Long Island Sound	\N
ACT3271	Connecticut	Long Island Sound	\N
LIS1037	Connecticut	Long Island Sound	\N
ACT3286	Connecticut	Long Island Sound	\N
ACT3296	Connecticut	Long Island Sound	\N
ACT3301	Connecticut	Long Island Sound	\N
ACT3306	Connecticut	Long Island Sound	\N
ACT3321	Connecticut	Long Island Sound	\N
ACT3326	Connecticut	Long Island Sound	\N
ACT3331	Connecticut	Long Island Sound	\N
LIS1038	Connecticut	Long Island Sound	\N
ACT2471	New York	\N	\N
ACT2476	New York	\N	\N
ACT2481	New York	\N	\N
ACT2486	New York	\N	\N
ACT2491	New York	\N	\N
ACT2496	New York	\N	\N
ACT2501	New York	\N	\N
ACT2506	New York	\N	\N
ACT2511	New York	\N	\N
ACT2521	New York	\N	\N
ACT2526	New York	\N	\N
ACT2531	New York	\N	\N
ACT2536	New York	\N	\N
ACT2541	New York	\N	\N
ACT2546	New York	\N	\N
ACT3341	New York	East River	\N
ACT3346	New York	East River	\N
ACT3356	New York	East River	\N
ACT3361	New York	East River	\N
ACT3366	New York	East River	\N
ACT3371	New York	East River	\N
ACT3376	New York	East River	\N
ACT3381	New York	East River	\N
ACT3386	New York	East River	\N
NYH1924	New York	East River	\N
ACT3406	New York	East River	Roosevelt Island
ACT3411	New York	East River	Roosevelt Island
ACT3416	New York	East River	Roosevelt Island
ACT3421	New York	East River	Roosevelt Island
ACT3426	New York	East River	Roosevelt Island
ACT3431	New York	East River	\N
NYH1922	New York	East River	\N
NYH1921	New York	East River	\N
NYH1920	New York	East River	\N
NYH1926	New York	Harlem River	\N
ACT3481	New York	Harlem River	\N
ACT3486	New York	Harlem River	\N
ACT3491	New York	Harlem River	\N
ACT3496	New York	Harlem River	\N
ACT3501	New York	Harlem River	\N
ACT3506	New York	Harlem River	\N
ACT3511	New York	Harlem River	\N
ACT3531	New York	Long Island	\N
ACT3536	New York	Long Island	\N
ACT3541	New York	Long Island	\N
ACT3546	New York	Long Island	\N
ACT3551	New York	Long Island	\N
ACT3556	New York	Long Island	\N
ACT3571	New York	Jamaica Bay	\N
NYH1904	New York	Jamaica Bay	\N
NYH1905	New York	Jamaica Bay	\N
NYH1931	New York	Jamaica Bay	\N
NYH1934	New York	Jamaica Bay	\N
ACT3596	New York	Jamaica Bay	\N
ACT3601	New York	Jamaica Bay	\N
NYH1903	New York	New York Harbor entrance	\N
ACT3611	New York	New York Harbor entrance	\N
n03020	New York	New York Harbor entrance	\N
NYH1901	New York	New York Harbor	Lower Bay
ACT3826	New York	New York Harbor	Lower Bay
NYH1902	New York	New York Harbor	Lower Bay
ACT3841	New York	New York Harbor	Lower Bay
ACT3846	New York	New York Harbor	Lower Bay
ACT3866	New York	New York Harbor	Lower Bay
ACT3861	New York	New York Harbor	Lower Bay
ACT3876	New York	New York Harbor	Lower Bay
ACT3621	New York	New York Harbor	Upper Bay
NYH1917	New York	New York Harbor	Upper Bay
NYH1918	New York	New York Harbor	Upper Bay
NYH1915	New York	New York Harbor	Upper Bay
NYH1914	New York	New York Harbor	Upper Bay
n05010	New York	New York Harbor	Upper Bay
ACT3646	New York	New York Harbor	Upper Bay
NYH1919	New York	New York Harbor	Upper Bay
NYH1927	New York	Hudson River (midchannel)	\N
NYH1928	New York	Hudson River (midchannel)	\N
ACT3656	New York	Hudson River (midchannel)	\N
HUR0611	New York	Hudson River (midchannel)	\N
NYH1930	New York	Hudson River (midchannel)	\N
ACT3671	New York	Hudson River (midchannel)	\N
ACT3676	New York	Hudson River (midchannel)	\N
ACT3681	New York	Hudson River (midchannel)	\N
HUR0502	New York	Hudson River (midchannel)	\N
ACT3691	New York	Hudson River (midchannel)	\N
ACT3696	New York	Hudson River (midchannel)	\N
HUR0401	New York	Hudson River (midchannel)	\N
HUR0503	New York	Hudson River (midchannel)	\N
ACT3711	New York	Hudson River (midchannel)	\N
HUR0504	New York	Hudson River (midchannel)	\N
ACT3721	New York	Hudson River (midchannel)	\N
ACT3726	New York	Hudson River (midchannel)	\N
HUR0506	New York	Hudson River (midchannel)	\N
HUR0507	New York	Hudson River (midchannel)	\N
ACT3741	New York	Hudson River (midchannel)	\N
HUR0620	New York	Hudson River (midchannel)	\N
ACT3751	New York	Hudson River (midchannel)	\N
HUR0509	New York	Hudson River (midchannel)	\N
HUR0612	New York	Hudson River (midchannel)	\N
ACT3766	New York	Hudson River (midchannel)	\N
ACT3771	New York	Hudson River (midchannel)	\N
HUR0613	New York	Hudson River (midchannel)	\N
ACT3781	New York	Hudson River (midchannel)	\N
HUR0614	New York	Hudson River (midchannel)	\N
HUR0615	New York	Hudson River (midchannel)	\N
HUR0616	New York	Hudson River (midchannel)	\N
ACT3801	New York	Hudson River (midchannel)	\N
HUR0617	New York	Hudson River (midchannel)	\N
HUR0618	New York	Hudson River (midchannel)	\N
n01010	New York	Kill Van Kull	\N
n02010	New York	Kill Van Kull	\N
n06010	New York	Kill Van Kull	\N
ACT3956	New York	Kill Van Kull	\N
n07010	New York	Newark Bay	\N
ACT3966	New York	Newark Bay	\N
NYH1913	New York	Newark Bay	\N
ACT3971	New York	Newark Bay	\N
ACT3976	New York	Newark Bay	\N
ACT3931	New York	Arthur Kill	\N
ACT3936	New York	Arthur Kill	\N
NYH1908	New York	Arthur Kill	\N
NYH1909	New York	Arthur Kill	\N
ACT3946	New York	Arthur Kill	\N
ACT3891	New York	Raritan Bay	\N
ACT3896	New York	Raritan Bay	\N
ACT3901	New York	Raritan Bay	\N
ACT3906	New York	Raritan Bay	\N
ACT3911	New York	Raritan Bay	\N
NYH1906	New York	Raritan Bay	\N
NYH1932	New York	Raritan River	\N
ACT3921	New York	Raritan River	\N
ACT3926	New York	Raritan River	\N
NYH1933	New Jersey	\N	\N
ACT3886	New Jersey	\N	\N
SHR9901	New Jersey	\N	\N
ACT3986	New Jersey	\N	\N
ACT3991	New Jersey	\N	\N
ACT3996	New Jersey	\N	\N
ACT4001	New Jersey	\N	\N
ACT4006	New Jersey	\N	\N
ACT4011	New Jersey	\N	\N
COR0301	New Jersey	\N	\N
ACT4031	New Jersey	\N	\N
ACT4036	New Jersey	\N	\N
CAM0001	New Jersey	\N	\N
ACT4046	New Jersey	\N	\N
ACT4056	New Jersey	\N	\N
ACT4061	New Jersey	\N	\N
ACT4066	New Jersey	\N	\N
DEB2101	New Jersey	\N	\N
ACT4076	New Jersey	\N	\N
DEB2102	New Jersey	\N	\N
DEB0002	New Jersey	\N	\N
ACT4091	New Jersey	\N	\N
DEB2103	New Jersey	\N	\N
ACT4101	New Jersey	\N	\N
ACT4111	New Jersey	\N	\N
ACT4116	New Jersey	\N	\N
ACT4121	New Jersey	\N	\N
DEB2104	New Jersey	\N	\N
db0502	New Jersey	\N	\N
DEB2105	New Jersey	\N	\N
DEB2106	New Jersey	\N	\N
ACT4141	New Jersey	\N	\N
ACT4146	New Jersey	\N	\N
ACT4151	New Jersey	\N	\N
ACT4156	New Jersey	\N	\N
ACT4161	New Jersey	\N	\N
ACT4166	New Jersey	\N	\N
DEB2107	New Jersey	\N	\N
ACT4176	New Jersey	\N	\N
ACT4181	New Jersey	\N	\N
ACT4191	New Jersey	\N	\N
ACT4196	New Jersey	\N	\N
DEB2114	New Jersey	\N	\N
DEB2108	New Jersey	\N	\N
ACT4206	New Jersey	\N	\N
ACT4211	New Jersey	\N	\N
DEB2109	New Jersey	\N	\N
ACT4221	New Jersey	\N	\N
ACT4226	New Jersey	\N	\N
ACT4241	New Jersey	\N	\N
ACT4246	New Jersey	\N	\N
ACT4251	New Jersey	\N	\N
DEB2111	New Jersey	\N	\N
DEB2110	New Jersey	\N	\N
ACT4261	New Jersey	\N	\N
ACT4266	New Jersey	\N	\N
ACT4271	New Jersey	\N	\N
db0201	New Jersey	\N	\N
DEB2112	New Jersey	\N	\N
DEB2113	New Jersey	\N	\N
ACT4296	New Jersey	\N	\N
ACT4301	New Jersey	\N	\N
ACT4306	New Jersey	\N	\N
DEB2115	New Jersey	\N	\N
ACT4316	New Jersey	\N	\N
ACT4321	New Jersey	\N	\N
ACT4326	New Jersey	\N	\N
DEB2116	New Jersey	\N	\N
DEB2117	New Jersey	\N	\N
ACT4351	New Jersey	\N	\N
DEB2118	New Jersey	\N	\N
DEB2119	New Jersey	\N	\N
DEB2121	New Jersey	\N	\N
DEB2122	New Jersey	\N	\N
DEB2124	New Jersey	\N	\N
DEB2123	New Jersey	\N	\N
ACT4391	New Jersey	\N	\N
DEB2126	New Jersey	\N	\N
ACT4406	New Jersey	\N	\N
DEB2128	New Jersey	\N	\N
DEB2129	New Jersey	\N	\N
db0301	New Jersey	\N	\N
db1935	New Jersey	\N	\N
DEB2130	New Jersey	\N	\N
DEB2131	New Jersey	\N	\N
DEB2132	New Jersey	\N	\N
DEB2133	New Jersey	\N	\N
DEB2134	New Jersey	\N	\N
ACT4496	Delaware	\N	\N
ACT4501	Delaware	\N	\N
ACT6231	Delaware	Chesapeake and Delaware Canal	\N
cb1301	Delaware	Chesapeake and Delaware Canal	\N
ACT6241	Delaware	Chesapeake and Delaware Canal	\N
ACT6246	Delaware	Chesapeake and Delaware Canal	\N
ACT6251	Delaware	Chesapeake and Delaware Canal	\N
ACT6256	Delaware	Chesapeake and Delaware Canal	\N
ACT4506	Maryland	Chesapeake Bay	\N
ACT4511	Maryland	Chesapeake Bay	\N
ACT4516	Maryland	Chesapeake Bay	\N
ACT4521	Maryland	Chesapeake Bay	\N
cb0102	Maryland	Chesapeake Bay	\N
ACT4531	Maryland	Chesapeake Bay	\N
ACT4536	Maryland	Chesapeake Bay	\N
ACT4541	Maryland	Chesapeake Bay	\N
ACT4546	Maryland	Chesapeake Bay	\N
ACT4551	Maryland	Chesapeake Bay	\N
ACT4556	Maryland	Chesapeake Bay	\N
ACT4561	Maryland	Chesapeake Bay	Chesapeake Bay Bridge Tunnel
CHB9902	Maryland	Chesapeake Bay	Chesapeake Bay Bridge Tunnel
ACT4571	Maryland	Chesapeake Bay	Chesapeake Bay Bridge Tunnel
ACT4576	Maryland	Chesapeake Bay	Chesapeake Bay Bridge Tunnel
ACT4581	Maryland	Chesapeake Bay	Chesapeake Bay Bridge Tunnel
ACT4586	Maryland	Chesapeake Bay	Chesapeake Bay Bridge Tunnel
ACT4591	Maryland	Chesapeake Bay	Chesapeake Bay Bridge Tunnel
ACT4596	Maryland	Chesapeake Bay	Chesapeake Bay Bridge Tunnel
ACT4601	Maryland	Chesapeake Bay	Chesapeake Bay Bridge Tunnel
ACT4606	Maryland	Chesapeake Bay	Chesapeake Bay Bridge Tunnel
ACT4611	Maryland	Chesapeake Bay	Chesapeake Bay Bridge Tunnel
ACT4616	Maryland	Chesapeake Bay	Chesapeake Bay Bridge Tunnel
ACT4621	Maryland	Chesapeake Bay	Chesapeake Bay Bridge Tunnel
ACT4626	Maryland	Chesapeake Bay	Chesapeake Bay Bridge Tunnel
ACT4631	Maryland	Chesapeake Bay	\N
ACT4636	Maryland	Chesapeake Bay	\N
ACT4641	Maryland	Chesapeake Bay	\N
ACT4646	Maryland	Chesapeake Bay	\N
ACT4651	Maryland	Chesapeake Bay	\N
ACT4656	Maryland	Chesapeake Bay	\N
ACT4661	Maryland	Chesapeake Bay	\N
ACT4666	Maryland	Chesapeake Bay	\N
ACT4671	Maryland	Chesapeake Bay	\N
ACT4676	Maryland	Chesapeake Bay	\N
ACT4681	Maryland	Chesapeake Bay	\N
ACT4686	Maryland	Chesapeake Bay	\N
ACT4691	Maryland	Chesapeake Bay	\N
ACT4696	Maryland	Chesapeake Bay	\N
ACT4701	Maryland	Chesapeake Bay	\N
ACT4706	Maryland	Chesapeake Bay	\N
ACT4711	Maryland	Chesapeake Bay	\N
ACT4716	Maryland	Chesapeake Bay	\N
ACT4721	Maryland	Chesapeake Bay	\N
ACT4726	Maryland	Chesapeake Bay	\N
ACT4731	Maryland	Chesapeake Bay	\N
ACT4736	Maryland	Chesapeake Bay	\N
cb0801	Maryland	Chesapeake Bay	\N
ACT4741	Maryland	Chesapeake Bay	\N
ACT4746	Maryland	Chesapeake Bay	\N
ACT4751	Maryland	Chesapeake Bay	\N
ACT4756	Maryland	Chesapeake Bay	\N
ACT4761	Maryland	Chesapeake Bay	\N
ACT4766	Maryland	Chesapeake Bay	\N
ACT4771	Maryland	Chesapeake Bay	\N
ACT4776	Maryland	Chesapeake Bay	\N
CHB0303	Maryland	Chesapeake Bay	\N
ACT4786	Maryland	Chesapeake Bay	\N
ACT4791	Maryland	Chesapeake Bay	\N
ACT4796	Maryland	Chesapeake Bay	\N
ACT4806	Maryland	Chesapeake Bay	\N
ACT4811	Maryland	Chesapeake Bay	\N
ACT4816	Maryland	Chesapeake Bay	\N
ACT4821	Maryland	Chesapeake Bay	\N
ACT4826	Maryland	Chesapeake Bay	\N
ACT4831	Maryland	Chesapeake Bay	\N
ACT4836	Maryland	Chesapeake Bay	\N
CHB0301	Maryland	Chesapeake Bay	\N
ACT4846	Maryland	Chesapeake Bay	\N
ACT4851	Maryland	Chesapeake Bay	\N
ACT4861	Maryland	Chesapeake Bay	\N
ACT4866	Maryland	Chesapeake Bay	\N
ACT4871	Maryland	Chesapeake Bay	\N
cb1001	Maryland	Chesapeake Bay	\N
ACT4876	Maryland	Chesapeake Bay	\N
ACT4881	Maryland	Chesapeake Bay	\N
CHB0304	Maryland	Chesapeake Bay	\N
ACT4891	Maryland	Chesapeake Bay	\N
ACT4896	Maryland	Chesapeake Bay	\N
ACT4901	Maryland	Chesapeake Bay	\N
ACT4906	Maryland	Chesapeake Bay	\N
ACT4911	Maryland	Chesapeake Bay	\N
ACT4916	Maryland	Chesapeake Bay	\N
ACT4921	Maryland	Chesapeake Bay	\N
ACT4926	Maryland	Chesapeake Bay	\N
ACT4931	Maryland	Chesapeake Bay	\N
ACT4936	Maryland	Chesapeake Bay	\N
ACT4941	Maryland	Chesapeake Bay	\N
ACT4946	Maryland	Chesapeake Bay	\N
ACT4951	Maryland	Chesapeake Bay	\N
ACT4956	Maryland	Chesapeake Bay	\N
ACT4961	Maryland	Chesapeake Bay	\N
ACT4966	Maryland	Chesapeake Bay	\N
ACT4971	Maryland	Chesapeake Bay	\N
ACT4976	Maryland	Chesapeake Bay	\N
cb1102	Maryland	Chesapeake Bay	\N
ACT4981	Maryland	Chesapeake Bay	\N
ACT4986	Maryland	Chesapeake Bay	\N
ACT4991	Maryland	Chesapeake Bay	\N
ACT4996	Maryland	Chesapeake Bay	\N
ACT5001	Maryland	Chesapeake Bay	\N
ACT5006	Maryland	Chesapeake Bay	\N
ACT5011	Maryland	Chesapeake Bay	\N
CHB0302	Maryland	Chesapeake Bay	\N
ACT5021	Maryland	Chesapeake Bay	\N
ACT5026	Maryland	Chesapeake Bay	\N
ACT5031	Maryland	Chesapeake Bay	\N
ACT5036	Maryland	Chesapeake Bay	\N
cb1201	Maryland	Chesapeake Bay	\N
ACT5046	Maryland	Chesapeake Bay	\N
ACT5051	Maryland	Chesapeake Bay	\N
ACT5056	Maryland	Chesapeake Bay	\N
ACT5061	Maryland	Chesapeake Bay	\N
ACT5066	Maryland	Chesapeake Bay	\N
ACT5071	Maryland	Chesapeake Bay	\N
ACT5076	Maryland	Chesapeake Bay	\N
ACT5081	Maryland	Chesapeake Bay	\N
ACT5086	Maryland	Chesapeake Bay	\N
ACT5091	Maryland	Chesapeake Bay	\N
ACT5096	Maryland	Chesapeake Bay	\N
ACT5101	Maryland	Chesapeake Bay	\N
ACT5106	Maryland	Chesapeake Bay	\N
ACT5111	Maryland	Chesapeake Bay	\N
ACT5116	Maryland	Chesapeake Bay	\N
ACT5121	Maryland	Chesapeake Bay	\N
ACT5126	Maryland	Chesapeake Bay	\N
ACT5131	Maryland	Chesapeake Bay	\N
ACT5136	Maryland	Chesapeake Bay	\N
ACT5141	Maryland	Chesapeake Bay	\N
ACT5146	Maryland	Chesapeake Bay	\N
ACT5151	Maryland	Chesapeake Bay	\N
ACT5156	Maryland	Chesapeake Bay	\N
ACT5751	Maryland	Potomac River	\N
ACT5756	Maryland	Potomac River	\N
ACT5761	Maryland	Potomac River	\N
ACT5766	Maryland	Potomac River	\N
ACT5776	Maryland	Potomac River	Cornfield Point
ACT5781	Maryland	Potomac River	Cornfield Point
ACT5786	Maryland	Potomac River	\N
ACT5791	Maryland	Potomac River	\N
ACT5796	Maryland	Potomac River	Piney Point
cb0901	Maryland	Potomac River	Piney Point
ACT5806	Maryland	Potomac River	Piney Point
ACT5811	Maryland	Potomac River	\N
ACT5816	Maryland	Potomac River	\N
ACT5821	Maryland	Potomac River	\N
ACT5826	Maryland	Potomac River	\N
ACT5831	Maryland	Potomac River	\N
ACT5836	Maryland	Potomac River	\N
ACT5841	Maryland	Potomac River	\N
ACT5846	Maryland	Potomac River	\N
ACT5851	Maryland	Potomac River	\N
ACT5861	Maryland	Potomac River	\N
ACT5866	Maryland	Potomac River	\N
ACT5871	Maryland	Potomac River	\N
ACT5876	Maryland	Potomac River	\N
ACT5881	Maryland	Potomac River	\N
ACT5886	Maryland	Potomac River	\N
ACT5891	Maryland	Potomac River	\N
ACT5896	Maryland	Potomac River	\N
ACT5901	Maryland	Potomac River	\N
ACT5906	Maryland	Potomac River	\N
ACT5911	Maryland	Potomac River	\N
ACT5916	Maryland	Potomac River	\N
ACT5921	Maryland	Potomac River	\N
ACT5931	Maryland	Patuxent River	\N
ACT5936	Maryland	Patuxent River	\N
ACT5941	Maryland	Patuxent River	\N
ACT5946	Maryland	Patuxent River	\N
ACT5951	Maryland	Patuxent River	\N
ACT5956	Maryland	Patuxent River	\N
ACT5961	Maryland	Patuxent River	\N
ACT5966	Maryland	Patuxent River	\N
ACT5971	Maryland	Little Choptank River	\N
ACT5976	Maryland	Little Choptank River	\N
ACT5981	Maryland	Choptank River	\N
ACT5986	Maryland	Choptank River	\N
ACT5991	Maryland	Choptank River	\N
ACT5996	Maryland	Choptank River	\N
ACT6001	Maryland	Choptank River	\N
ACT6006	Maryland	Choptank River	\N
ACT6011	Maryland	Choptank River	\N
ACT6016	Maryland	Choptank River	\N
ACT6021	Maryland	Choptank River	\N
ACT6031	Maryland	Choptank River	\N
ACT6041	Maryland	Choptank River	\N
ACT6046	Maryland	Eastern Bay	\N
ACT6051	Maryland	Eastern Bay	\N
ACT6056	Maryland	Eastern Bay	\N
ACT6061	Maryland	Eastern Bay	\N
ACT6066	Maryland	Eastern Bay	\N
ACT6081	Maryland	Eastern Bay	\N
ACT6086	Maryland	Eastern Bay	\N
ACT6096	Maryland	\N	\N
ACT6101	Maryland	\N	\N
ACT6106	Maryland	\N	\N
ACT6121	Maryland	\N	\N
ACT6126	Maryland	Chester River	\N
ACT6131	Maryland	Chester River	\N
ACT6136	Maryland	Chester River	\N
ACT6141	Maryland	Chester River	\N
ACT6146	Maryland	Chester River	\N
ACT6151	Maryland	Patapsco River	\N
ACT6156	Maryland	Patapsco River	\N
ACT6161	Maryland	Patapsco River	\N
ACT6166	Maryland	Patapsco River	\N
ACT6171	Maryland	Patapsco River	\N
ACT6176	Maryland	Patapsco River	\N
ACT6181	Maryland	Patapsco River	\N
ACT6186	Maryland	\N	\N
ACT6191	Maryland	\N	\N
ACT6196	Maryland	\N	\N
ACT6201	Maryland	Sassafrass River	\N
ACT6206	Maryland	Sassafrass River	\N
ACT6211	Maryland	Sassafrass River	\N
ACT6216	Maryland	Elk River	\N
ACT6221	Maryland	Elk River	\N
ACT6226	Maryland	Elk River	\N
ACT5161	Virginia	Hampton Roads	\N
cb0301	Virginia	Hampton Roads	\N
CHB9903	Virginia	Hampton Roads	\N
ACT5171	Virginia	Hampton Roads	Old Point Comfort
ACT5176	Virginia	Hampton Roads	Old Point Comfort
ACT5181	Virginia	Hampton Roads	Old Point Comfort
ACT5186	Virginia	Hampton Roads	\N
ACT5191	Virginia	Hampton Roads	\N
cb0402	Virginia	Hampton Roads	\N
ACT5201	Virginia	Hampton Roads	\N
ACT5206	Virginia	Hampton Roads	\N
ACT5211	Virginia	Hampton Roads	Newport News
cb0601	Virginia	Hampton Roads	Newport News
ACT5221	Virginia	Hampton Roads	Newport News
cb1401	Virginia	Hampton Roads	Newport News
CHB9904	Virginia	Hampton Roads	Newport News
ACT5301	Virginia	Hampton Roads	Newport News
ACT5306	Virginia	Hampton Roads	Newport News
ACT5226	Virginia	Elizabeth River	\N
CHB9905	Virginia	Elizabeth River	\N
ACT5236	Virginia	Elizabeth River	\N
ACT5241	Virginia	Elizabeth River	\N
ACT5246	Virginia	Elizabeth River	\N
ACT5251	Virginia	Elizabeth River	\N
ACT5256	Virginia	Elizabeth River	\N
ACT5261	Virginia	Elizabeth River	\N
ACT5266	Virginia	Elizabeth River	\N
ACT5271	Virginia	Elizabeth River	\N
ACT5276	Virginia	Elizabeth River	\N
ACT5281	Virginia	Nansemond River	\N
ACT5286	Virginia	Nansemond River	\N
ACT5291	Virginia	Nansemond River	\N
cb0701	Virginia	James River	\N
ACT5311	Virginia	James River	Rocklanding Shoal Channel
ACT5316	Virginia	James River	Rocklanding Shoal Channel
ACT5321	Virginia	James River	Rocklanding Shoal Channel
ACT5326	Virginia	James River	\N
ACT5331	Virginia	James River	\N
ACT5336	Virginia	James River	\N
ACT5341	Virginia	James River	\N
ACT5346	Virginia	James River	\N
ACT5351	Virginia	James River	\N
ACT5356	Virginia	James River	\N
ACT5361	Virginia	James River	\N
ACT5366	Virginia	James River	\N
ACT5371	Virginia	James River	\N
ACT5376	Virginia	James River	\N
ACT5381	Virginia	James River	\N
ACT5386	Virginia	James River	\N
cb0201	Virginia	York River	\N
ACT5401	Virginia	York River	\N
ACT5406	Virginia	York River	\N
ACT5411	Virginia	York River	\N
ACT5416	Virginia	York River	\N
ACT5421	Virginia	York River	Tue Marshes Light, 2.7 miles west of
ACT5426	Virginia	York River	Tue Marshes Light, 2.7 miles west of
ACT5431	Virginia	York River	Tue Marshes Light, 2.7 miles west of
ACT5436	Virginia	York River	\N
ACT5441	Virginia	York River	\N
ACT5446	Virginia	York River	\N
ACT5451	Virginia	York River	\N
ACT5456	Virginia	York River	\N
ACT5461	Virginia	York River	\N
ACT5466	Virginia	York River	\N
ACT5471	Virginia	York River	\N
ACT5476	Virginia	York River	\N
ACT5481	Virginia	York River	\N
ACT5486	Virginia	York River	\N
ACT5491	Virginia	York River	\N
ACT5496	Virginia	York River	\N
ACT5501	Virginia	York River	\N
ACT5506	Virginia	York River	\N
ACT5511	Virginia	York River	\N
ACT5516	Virginia	\N	\N
ACT5521	Virginia	\N	\N
ACT5526	Virginia	\N	\N
ACT5531	Virginia	Rappahannock River	\N
ACT5536	Virginia	Rappahannock River	\N
ACT5541	Virginia	Rappahannock River	\N
ACT5551	Virginia	Rappahannock River	\N
ACT5556	Virginia	Rappahannock River	\N
ACT5566	Virginia	Rappahannock River	\N
ACT5571	Virginia	Rappahannock River	\N
ACT5576	Virginia	Rappahannock River	\N
ACT5581	Virginia	Rappahannock River	\N
ACT5586	Virginia	Rappahannock River	\N
ACT5591	Virginia	Rappahannock River	\N
ACT5596	Virginia	Rappahannock River	\N
ACT5606	Virginia	Rappahannock River	\N
ACT5611	Virginia	Pocomoke Sound	\N
ACT5621	Virginia	Pocomoke Sound	\N
ACT5626	Virginia	Pocomoke Sound	\N
ACT5631	Virginia	Pocomoke Sound	\N
ACT5636	Virginia	Pocomoke Sound	\N
ACT5641	Virginia	Tangier Sound	\N
ACT5646	Virginia	Tangier Sound	\N
ACT5651	Virginia	Tangier Sound	\N
ACT5656	Virginia	Tangier Sound	\N
ACT5661	Virginia	Tangier Sound	\N
ACT5666	Virginia	Tangier Sound	\N
ACT5671	Virginia	Tangier Sound	\N
ACT5676	Virginia	Tangier Sound	\N
ACT5681	Virginia	Tangier Sound	\N
ACT5686	Virginia	Tangier Sound	Wicomico River
ACT5691	Virginia	Tangier Sound	Wicomico River
ACT5696	Virginia	Tangier Sound	Wicomico River
ACT5701	Virginia	Tangier Sound	Wicomico River
ACT5706	Virginia	Tangier Sound	Wicomico River
ACT5711	Virginia	Tangier Sound	\N
ACT5716	Virginia	Tangier Sound	\N
ACT5721	Virginia	Tangier Sound	\N
ACT5726	Virginia	Tangier Sound	\N
ACT5731	Virginia	Tangier Sound	\N
ACT5741	Virginia	Tangier Sound	\N
ACT5746	Virginia	Great Wicomico River	\N
ACT6261	Virginia	\N	\N
ACT6266	Virginia	\N	\N
ACT6271	North Carolina	Pamlico Sound	Oregon Inlet
ACT6276	North Carolina	Pamlico Sound	Oregon Inlet
ACT6281	North Carolina	Pamlico Sound	Oregon Inlet
ACT6286	North Carolina	Pamlico Sound	\N
ACT6296	North Carolina	Pamlico Sound	Ocracoke Inlet
ACT6301	North Carolina	Pamlico Sound	Ocracoke Inlet
ACT6306	North Carolina	Pamlico Sound	Ocracoke Inlet
ACT6311	North Carolina	Pamlico Sound	Ocracoke Inlet
ACT6316	North Carolina	Pamlico Sound	\N
ACT6326	North Carolina	\N	Beaufort Inlet
ACT6331	North Carolina	\N	Beaufort Inlet
ACT6336	North Carolina	\N	Beaufort Inlet
ACT6341	North Carolina	\N	Beaufort Inlet
ACT6346	North Carolina	\N	Beaufort Inlet
ACT6351	North Carolina	\N	Beaufort Inlet
ACT6356	North Carolina	\N	Beaufort Inlet
ACT6361	North Carolina	\N	Beaufort Inlet
ACT6366	North Carolina	\N	Beaufort Inlet
ACT6371	North Carolina	\N	Beaufort Inlet
ACT6376	North Carolina	\N	Beaufort Inlet
ACT6381	North Carolina	\N	Beaufort Inlet
ACT6391	North Carolina	\N	Beaufort Inlet
ACT6396	North Carolina	\N	Beaufort Inlet
ACT6401	North Carolina	\N	Beaufort Inlet
ACT6406	North Carolina	\N	Beaufort Inlet
CFR1626	North Carolina	Cape Fear River	\N
CFR1625	North Carolina	Cape Fear River	\N
CFR1624	North Carolina	Cape Fear River	\N
CFR1622	North Carolina	Cape Fear River	\N
CFR1623	North Carolina	Cape Fear River	\N
CFR1621	North Carolina	Cape Fear River	\N
CFR1620	North Carolina	Cape Fear River	\N
ACT6446	North Carolina	Cape Fear River	\N
ACT6451	North Carolina	Cape Fear River	\N
CFR1619	North Carolina	Cape Fear River	\N
ACT6461	North Carolina	Cape Fear River	\N
CFR1617	North Carolina	Cape Fear River	\N
CFR1616	North Carolina	Cape Fear River	\N
CFR1615	North Carolina	Cape Fear River	\N
CFR1618	North Carolina	Cape Fear River	\N
CFR1614	North Carolina	Cape Fear River	\N
CFR1613	North Carolina	Cape Fear River	\N
CFR1612	North Carolina	Cape Fear River	\N
CFR1611	North Carolina	Cape Fear River	\N
CFR1610	North Carolina	Cape Fear River	\N
CFR1609	North Carolina	Cape Fear River	\N
ACT6496	North Carolina	Cape Fear River	Brunswick River
ACT6501	North Carolina	Cape Fear River	Brunswick River
CFR1608	North Carolina	Cape Fear River	\N
CFR1607	North Carolina	Cape Fear River	\N
CFR1605	North Carolina	Cape Fear River	\N
CFR1603	North Carolina	Cape Fear River	\N
CFR1604	North Carolina	Cape Fear River	\N
CFR1602	North Carolina	Cape Fear River	\N
CFR1601	North Carolina	Cape Fear River	\N
ACT6531	South Carolina	Winyah Bay	\N
ACT6536	South Carolina	Winyah Bay	\N
ACT6541	South Carolina	Winyah Bay	\N
ACT6546	South Carolina	Winyah Bay	\N
ACT6551	South Carolina	Winyah Bay	\N
ACT6556	South Carolina	Winyah Bay	\N
ACT6561	South Carolina	Winyah Bay	\N
ACT6566	South Carolina	Winyah Bay	\N
ACT6571	South Carolina	Winyah Bay	\N
ACT6576	South Carolina	Winyah Bay	\N
ACT6581	South Carolina	Santee Rivers	\N
ACT6586	South Carolina	Santee Rivers	\N
ACT6611	South Carolina	Charleston Harbor	\N
ACT6616	South Carolina	Charleston Harbor	\N
ACT6621	South Carolina	Charleston Harbor	\N
ACT6631	South Carolina	Charleston Harbor	\N
ACT6626	South Carolina	Charleston Harbor	\N
ACT6636	South Carolina	Charleston Harbor	\N
ACT6641	South Carolina	Charleston Harbor	\N
ACT6646	South Carolina	Charleston Harbor	\N
ACT6651	South Carolina	Charleston Harbor	\N
ACT6656	South Carolina	Charleston Harbor	\N
ACT6716	South Carolina	Charleston Harbor	\N
ACT6721	South Carolina	Charleston Harbor	\N
ACT6726	South Carolina	Charleston Harbor	\N
ACT6661	South Carolina	Charleston Harbor	\N
ACT6666	South Carolina	Charleston Harbor	\N
ACT6681	South Carolina	Charleston Harbor	\N
ACT6676	South Carolina	Charleston Harbor	\N
ACT6686	South Carolina	Charleston Harbor	\N
ACT6731	South Carolina	Charleston Harbor	\N
ACT6736	South Carolina	Charleston Harbor	\N
ACT6741	South Carolina	Charleston Harbor	\N
ACT6691	South Carolina	Charleston Harbor	\N
ACT6696	South Carolina	Charleston Harbor	\N
ACT6701	South Carolina	Charleston Harbor	\N
ACT6746	South Carolina	Charleston Harbor	\N
ACT6751	South Carolina	Charleston Harbor	Cooper River
ACT6756	South Carolina	Charleston Harbor	Cooper River
ACT6706	South Carolina	Charleston Harbor	Cooper River
ACT6711	South Carolina	Charleston Harbor	Cooper River
ACT6761	South Carolina	Charleston Harbor	Cooper River
ACT6766	South Carolina	Charleston Harbor	Cooper River
ACT6771	South Carolina	Charleston Harbor	Cooper River
ACT6776	South Carolina	Charleston Harbor	Cooper River
ACT6781	South Carolina	Charleston Harbor	Cooper River
ACT6786	South Carolina	Charleston Harbor	Cooper River
ACT6791	South Carolina	Charleston Harbor	Cooper River
ACT6796	South Carolina	Charleston Harbor	Cooper River
ACT6806	South Carolina	Charleston Harbor	Cooper River
ACT6811	South Carolina	Charleston Harbor	Cooper River
ACT6816	South Carolina	Charleston Harbor	Cooper River
ACT6821	South Carolina	Charleston Harbor	Cooper River
ACT6826	South Carolina	Charleston Harbor	Cooper River
ACT6831	South Carolina	Charleston Harbor	Cooper River
ACT6836	South Carolina	Charleston Harbor	Cooper River
ACT6841	South Carolina	Charleston Harbor	Cooper River
ACT6846	South Carolina	Charleston Harbor	Cooper River
ACT6851	South Carolina	Charleston Harbor	Cooper River
ACT6861	South Carolina	Charleston Harbor	Cooper River
ACT6856	South Carolina	Charleston Harbor	Cooper River
ACT6866	South Carolina	Charleston Harbor	Cooper River
ACT6871	South Carolina	Charleston Harbor	Cooper River
ACT6881	South Carolina	Charleston Harbor	Cooper River
ACT6876	South Carolina	Charleston Harbor	Cooper River
ACT6886	South Carolina	Charleston Harbor	Cooper River
ACT6891	South Carolina	Charleston Harbor	Cooper River
ACT6896	South Carolina	Charleston Harbor	Cooper River
ACT6901	South Carolina	Charleston Harbor	Wando River
ACT6906	South Carolina	Charleston Harbor	Wando River
ACT6911	South Carolina	Charleston Harbor	Wando River
ACT6921	South Carolina	Charleston Harbor	Wando River
ACT6926	South Carolina	Charleston Harbor	Wando River
ACT6916	South Carolina	Charleston Harbor	Wando River
ACT6931	South Carolina	Charleston Harbor	Wando River
ACT6936	South Carolina	Charleston Harbor	Ashley River
ACT6941	South Carolina	Charleston Harbor	Ashley River
ACT6946	South Carolina	Charleston Harbor	Ashley River
ACT6951	South Carolina	Charleston Harbor	Ashley River
ACT6956	South Carolina	Charleston Harbor	Ashley River
ACT6961	South Carolina	Charleston Harbor	Ashley River
ACT6966	South Carolina	Charleston Harbor	Ashley River
ACT6971	South Carolina	Charleston Harbor	Ashley River
ACT6976	South Carolina	Stono River	\N
ACT6981	South Carolina	Stono River	\N
ACT6986	South Carolina	Stono River	\N
ACT6991	South Carolina	Stono River	\N
ACT6996	South Carolina	Stono River	\N
ACT7001	South Carolina	Stono River	\N
ACT7006	South Carolina	Stono River	\N
ACT7021	South Carolina	North Edisto River	\N
ACT7026	South Carolina	North Edisto River	\N
ACT7031	South Carolina	North Edisto River	\N
ACT7036	South Carolina	North Edisto River	\N
ACT7041	South Carolina	North Edisto River	\N
ACT7046	South Carolina	North Edisto River	\N
ACT7051	South Carolina	North Edisto River	\N
ACT7056	South Carolina	South Edisto River	\N
ACT7061	South Carolina	South Edisto River	\N
ACT7066	South Carolina	South Edisto River	\N
ACT7071	South Carolina	South Edisto River	\N
ACT7076	South Carolina	South Edisto River	\N
ACT7081	South Carolina	South Edisto River	\N
ACT7086	South Carolina	South Edisto River	\N
ACT7111	South Carolina	St. Helena Sound	\N
ACT7101	South Carolina	St. Helena Sound	\N
ACT7106	South Carolina	St. Helena Sound	\N
ACT7091	South Carolina	St. Helena Sound	\N
ACT7096	South Carolina	St. Helena Sound	\N
ACT7126	South Carolina	St. Helena Sound	\N
ACT7121	South Carolina	St. Helena Sound	\N
ACT7116	South Carolina	St. Helena Sound	\N
ACT7131	South Carolina	St. Helena Sound	\N
ACT7136	South Carolina	St. Helena Sound	\N
ACT7146	South Carolina	St. Helena Sound	\N
ACT7151	South Carolina	St. Helena Sound	\N
ACT7161	South Carolina	St. Helena Sound	\N
ACT7166	South Carolina	St. Helena Sound	\N
ACT7141	South Carolina	St. Helena Sound	\N
ACT7156	South Carolina	St. Helena Sound	\N
ACT7171	South Carolina	St. Helena Sound	\N
ACT7181	South Carolina	Port Royal Sound	\N
ACT7186	South Carolina	Port Royal Sound	\N
ACT7191	South Carolina	Port Royal Sound	\N
ACT7196	South Carolina	Port Royal Sound	\N
ACT7201	South Carolina	Port Royal Sound	\N
ACT7206	South Carolina	Port Royal Sound	\N
ACT7211	South Carolina	Port Royal Sound	\N
ACT7216	South Carolina	Port Royal Sound	\N
ACT7221	South Carolina	Port Royal Sound	\N
ACT7226	South Carolina	Port Royal Sound	\N
ACT7231	South Carolina	Port Royal Sound	\N
ACT7236	South Carolina	Port Royal Sound	\N
ACT7241	South Carolina	Port Royal Sound	\N
ACT7246	South Carolina	Port Royal Sound	\N
ACT7261	South Carolina	Port Royal Sound	\N
ACT7251	South Carolina	Port Royal Sound	\N
ACT7256	South Carolina	Port Royal Sound	\N
ACT7266	South Carolina	Port Royal Sound	\N
ACT7271	South Carolina	Port Royal Sound	\N
ACT7276	South Carolina	Port Royal Sound	\N
ACT7281	South Carolina	Port Royal Sound	\N
ACT7286	South Carolina	Calibogue Sound	\N
ACT7291	South Carolina	Calibogue Sound	\N
ACT7296	South Carolina	Calibogue Sound	\N
ACT7301	South Carolina	Calibogue Sound	\N
ACT7306	South Carolina	Calibogue Sound	\N
ACT7311	South Carolina	Calibogue Sound	\N
ACT7316	South Carolina	\N	\N
ACT7321	South Carolina	\N	\N
ACT7326	South Carolina	\N	\N
ACT7336	South Carolina	\N	\N
ACT7341	South Carolina	\N	\N
ACT7351	South Carolina	Savannah River	\N
ACT7356	South Carolina	Savannah River	\N
ACT7361	South Carolina	Savannah River	\N
ACT7366	South Carolina	Savannah River	\N
ACT7371	South Carolina	Savannah River	\N
ACT7376	South Carolina	Savannah River	\N
ACT7381	South Carolina	Savannah River	\N
ACT7386	South Carolina	Savannah River	\N
ACT7391	South Carolina	Savannah River	\N
ACT7396	South Carolina	Savannah River	\N
ACT7401	South Carolina	Savannah River	\N
ACT7406	South Carolina	Savannah River	\N
ACT7411	South Carolina	Savannah River	\N
ACT7416	South Carolina	Savannah River	\N
ACT7421	South Carolina	Savannah River	\N
ACT7426	South Carolina	Savannah River	\N
ACT7431	South Carolina	Savannah River	\N
ACT7441	South Carolina	Savannah River	\N
ACT7446	Georgia	Wassaw Sound	\N
ACT7451	Georgia	Wassaw Sound	\N
ACT7456	Georgia	Wassaw Sound	\N
ACT7461	Georgia	Wassaw Sound	\N
ACT7466	Georgia	Wassaw Sound	\N
ACT7471	Georgia	Wassaw Sound	\N
ACT7476	Georgia	Wassaw Sound	\N
ACT7481	Georgia	Wassaw Sound	\N
ACT7486	Georgia	Wassaw Sound	\N
ACT7491	Georgia	Wassaw Sound	\N
ACT7496	Georgia	Wassaw Sound	\N
ACT7501	Georgia	Wassaw Sound	\N
ACT7506	Georgia	Wassaw Sound	\N
ACT7511	Georgia	Wassaw Sound	\N
ACT7516	Georgia	Wassaw Sound	\N
ACT7521	Georgia	Wassaw Sound	\N
ACT7526	Georgia	Wassaw Sound	\N
ACT7531	Georgia	Wassaw Sound	\N
ACT7536	Georgia	Wassaw Sound	\N
ACT7541	Georgia	Wassaw Sound	\N
ACT7546	Georgia	Wassaw Sound	\N
ACT7551	Georgia	Wassaw Sound	\N
ACT7556	Georgia	Wassaw Sound	\N
ACT7561	Georgia	Wassaw Sound	\N
ACT7566	Georgia	Wassaw Sound	\N
ACT7571	Georgia	Ossabaw Sound	\N
ACT7576	Georgia	Ossabaw Sound	\N
ACT7581	Georgia	Ossabaw Sound	\N
ACT7586	Georgia	Ossabaw Sound	\N
ACT7591	Georgia	Ossabaw Sound	\N
ACT7596	Georgia	Ossabaw Sound	\N
ACT7601	Georgia	Ossabaw Sound	\N
ACT7606	Georgia	Ossabaw Sound	\N
ACT7611	Georgia	Ossabaw Sound	\N
ACT7616	Georgia	St. Catherines Sound	Bear River
ACT7621	Georgia	St. Catherines Sound	Bear River
ACT7626	Georgia	St. Catherines Sound	Bear River
ACT7631	Georgia	St. Catherines Sound	Bear River
ACT7636	Georgia	St. Catherines Sound	\N
ACT7641	Georgia	St. Catherines Sound	\N
ACT7646	Georgia	St. Catherines Sound	\N
ACT7651	Georgia	St. Catherines Sound	\N
ACT7656	Georgia	St. Catherines Sound	\N
ACT7661	Georgia	St. Catherines Sound	\N
ACT7666	Georgia	St. Catherines Sound	\N
ACT7671	Georgia	St. Catherines Sound	\N
ACT7676	Georgia	St. Catherines Sound	\N
ACT7681	Georgia	Sapelo Sound	\N
ACT7686	Georgia	Sapelo Sound	\N
ACT7691	Georgia	Sapelo Sound	\N
ACT7696	Georgia	Sapelo Sound	\N
ACT7701	Georgia	Sapelo Sound	\N
ACT7706	Georgia	Sapelo Sound	\N
ACT7711	Georgia	Sapelo Sound	Mud River
ACT7716	Georgia	Sapelo Sound	\N
ACT7721	Georgia	Sapelo Sound	\N
ACT7726	Georgia	Doboy Sound	\N
ACT7731	Georgia	Doboy Sound	\N
ACT7736	Georgia	Doboy Sound	\N
ACT7741	Georgia	Doboy Sound	\N
ACT7746	Georgia	Doboy Sound	\N
ACT7751	Georgia	Doboy Sound	\N
ACT7756	Georgia	Doboy Sound	\N
ACT7761	Georgia	Doboy Sound	\N
ACT7766	Georgia	Doboy Sound	\N
ACT7771	Georgia	Altamaha Sound	\N
ACT7776	Georgia	Altamaha Sound	\N
ACT7781	Georgia	Altamaha Sound	\N
ACT7786	Georgia	Altamaha Sound	\N
ACT7791	Georgia	Altamaha Sound	Buttermilk Sound
ACT7796	Georgia	St. Simons Sound	\N
ACT7801	Georgia	St. Simons Sound	\N
ACT7806	Georgia	St. Simons Sound	\N
ACT7811	Georgia	St. Simons Sound	\N
ACT7816	Georgia	St. Simons Sound	\N
ACT7821	Georgia	St. Simons Sound	\N
ACT7826	Georgia	St. Simons Sound	\N
ACT7831	Georgia	St. Simons Sound	\N
ACT7836	Georgia	St. Simons Sound	\N
ACT7841	Georgia	St. Simons Sound	\N
ACT7846	Georgia	St. Andrews Sound	\N
ACT7851	Georgia	St. Andrews Sound	\N
ACT7856	Georgia	St. Andrews Sound	\N
ACT7861	Georgia	St. Andrews Sound	\N
kb0101	Georgia	Cumberland Sound	St. Mary's River
FEB1108	Georgia	Cumberland Sound	St. Mary's River
kb0102	Georgia	Cumberland Sound	St. Mary's River
FEB1102	Georgia	Cumberland Sound	St. Mary's River
FEB1103	Georgia	Cumberland Sound	St. Mary's River
ACT7886	Georgia	Cumberland Sound	St. Mary's River
kb0301	Georgia	Cumberland Sound	\N
ACT7896	Georgia	Cumberland Sound	\N
kb0501	Georgia	Cumberland Sound	\N
kb0601	Georgia	Cumberland Sound	\N
ACT7906	Georgia	Cumberland Sound	\N
FEB1104	Georgia	Cumberland Sound	\N
FEB1107	Georgia	Cumberland Sound	\N
ACT7921	Georgia	Cumberland Sound	\N
ACT7926	Florida	Nassau Sound	\N
ACT7931	Florida	Nassau Sound	\N
ACT7936	Florida	Nassau Sound	\N
ACT7941	Florida	Nassau Sound	\N
SJR0304	Florida	St. Johns River	\N
jx0101	Florida	St. Johns River	\N
SJR9801	Florida	St. Johns River	\N
jx0201	Florida	St. Johns River	\N
ACT7971	Florida	St. Johns River	\N
jx0302	Florida	St. Johns River	\N
jx0301	Florida	St. Johns River	\N
ACT7986	Florida	St. Johns River	\N
ACT7991	Florida	St. Johns River	\N
jx0401	Florida	St. Johns River	\N
SJR9807	Florida	St. Johns River	\N
SJR0301	Florida	St. Johns River	\N
jx0501	Florida	St. Johns River	\N
ACT8016	Florida	St. Johns River	\N
jx0601	Florida	St. Johns River	\N
SJR9806	Florida	St. Johns River	\N
SJR0302	Florida	St. Johns River	\N
ACT8031	Florida	St. Johns River	\N
ACT8036	Florida	St. Johns River	\N
ACT8041	Florida	St. Johns River	\N
jx0701	Florida	St. Johns River	\N
ACT8051	Florida	St. Johns River	\N
ACT8056	Florida	St. Johns River	\N
ACT8061	Florida	St. Johns River	\N
FPI0901	Florida	Fort Pierce Inlet	\N
FPI0902	Florida	Fort Pierce Inlet	\N
FPI0903	Florida	Fort Pierce Inlet	\N
FPI0904	Florida	Fort Pierce Inlet	\N
LWI0901	Florida	Lake Worth Inlet	\N
LWI0904	Florida	Lake Worth Inlet	\N
ACT8106	Florida	Port Everglades	\N
PEV0901	Florida	Port Everglades	\N
PEV0902	Florida	Port Everglades	\N
PEV0903	Florida	Port Everglades	\N
ACT8126	Florida	Port Everglades	\N
PEV0904	Florida	Port Everglades	\N
PEV0905	Florida	Port Everglades	\N
ACT8141	Florida	Miami Harbor	\N
MIH0802	Florida	Miami Harbor	Government Cut
MIH0901	Florida	Miami Harbor	Government Cut
MIH0804	Florida	Miami Harbor	Government Cut
MIH0805	Florida	Miami Harbor	Main Channel
MIH0808	Florida	Miami Harbor	Main Channel
MIH0812	Florida	Miami Harbor	Main Channel
MIH0813	Florida	Miami Harbor	Main Channel
MIH0806	Florida	Miami Harbor	Fishermans Channel
MIH0807	Florida	Miami Harbor	Fishermans Channel
MIH0809	Florida	Miami Harbor	Fishermans Channel
MIH0810	Florida	Miami Harbor	Fishermans Channel
MIH0811	Florida	Miami Harbor	Fishermans Channel
MIH0814	Florida	Miami Harbor	\N
ACT8211	Florida	Miami Harbor	\N
ACT8216	Florida	\N	\N
ACT8221	Florida	\N	\N
ACT8226	Florida	\N	\N
FLK1324	Florida	\N	\N
FLK1327	Florida	\N	\N
FLK1325	Florida	\N	\N
FLK1311	Florida	\N	\N
ACT8241	Florida	\N	\N
FLK1302	Florida	\N	Key West
FLK1303	Florida	\N	Key West
FLK1304	Florida	\N	Key West
FLK1301	Florida	\N	Key West
ACT8261	Florida	\N	Key West
FLK1306	Florida	\N	Key West
FLK1307	Florida	\N	Key West
FLK1315	Florida	\N	Key West
FLK1313	Florida	\N	Key West
FLK1310	Florida	\N	\N
FLK1308	Florida	\N	\N
FLK1309	Florida	\N	\N
FLK1316	Florida	\N	\N
FLK1317	Florida	\N	\N
ACT8291	Florida	\N	\N
ACT8296	Florida	\N	\N
ACT8301	Florida	\N	\N
ACT8306	Florida	\N	\N
ACT8311	Florida	\N	\N
ACT8316	Florida	\N	\N
ACT8331	Florida	\N	\N
ACT8346	Florida	\N	\N
ACT8351	Florida	\N	\N
ACT8356	Florida	\N	\N
ACT8361	Florida	\N	\N
ACT8371	Florida	Sarasota Bay	\N
ACT8376	Florida	Sarasota Bay	\N
ACT8381	Florida	Sarasota Bay	\N
ACT8386	Florida	Sarasota Bay	\N
ACT8391	Florida	Sarasota Bay	\N
ACT8396	Florida	Sarasota Bay	\N
ACT8401	Florida	Tampa Bay	\N
ACT8406	Florida	Tampa Bay	\N
ACT8411	Florida	Tampa Bay	\N
ACT8416	Florida	Tampa Bay	\N
ACT8421	Florida	Tampa Bay	\N
ACT8426	Florida	Tampa Bay	\N
ACT8431	Florida	Tampa Bay	\N
ACT8436	Florida	Tampa Bay	\N
ACT8441	Florida	Tampa Bay	\N
ACT8446	Florida	Tampa Bay	\N
ACT8451	Florida	Tampa Bay	\N
ACT8456	Florida	Tampa Bay	\N
t01010	Florida	Tampa Bay	\N
ACT8466	Florida	Tampa Bay	\N
ACT8471	Florida	Tampa Bay	\N
ACT8476	Florida	Tampa Bay	\N
ACT8481	Florida	Tampa Bay	Pinellas Point
ACT8486	Florida	Tampa Bay	Pinellas Point
ACT8491	Florida	Tampa Bay	Pinellas Point
ACT8496	Florida	Tampa Bay	Pinellas Point
t03010	Florida	Tampa Bay	\N
ACT8511	Florida	Tampa Bay	\N
ACT8516	Florida	Tampa Bay	\N
ACT8521	Florida	Tampa Bay	\N
ACT8526	Florida	Tampa Bay	\N
ACT8531	Florida	Tampa Bay	\N
ACT8536	Florida	Tampa Bay	\N
ACT8541	Florida	Tampa Bay	\N
ACT8546	Florida	Tampa Bay	\N
ACT8551	Florida	Tampa Bay	\N
t02010	Florida	Tampa Bay	\N
ACT8561	Florida	Tampa Bay	\N
ACT8566	Florida	Tampa Bay	\N
ACT8571	Florida	Tampa Bay	\N
ACT8576	Florida	Tampa Bay	\N
ACT8581	Florida	Tampa Bay	\N
ACT8586	Florida	Tampa Bay	\N
ACT8591	Florida	Tampa Bay	\N
ACT8596	Florida	Tampa Bay	\N
ACT8601	Florida	Tampa Bay	\N
ACT8606	Florida	\N	\N
ACT8611	Florida	\N	\N
ACT8616	Florida	\N	\N
ACT8621	Florida	\N	\N
ACT8626	Florida	\N	\N
JOP1101	Florida	\N	\N
JOP1103	Florida	\N	\N
JOP1104	Florida	\N	\N
ACT8646	Florida	\N	\N
ACT8651	Florida	\N	\N
ACT8656	Florida	\N	\N
ACT8666	Florida	Apalachee Bay	\N
ACT8671	Florida	Apalachee Bay	\N
ACT8676	Florida	Apalachee Bay	\N
SAB0803	Florida	St. Andrew Bay	\N
SAB0807	Florida	St. Andrew Bay	\N
SAB0808	Florida	St. Andrew Bay	\N
SAB0806	Florida	St. Andrew Bay	\N
SAB0805	Florida	St. Andrew Bay	\N
SAB0809	Florida	St. Andrew Bay	\N
SAB0812	Florida	St. Andrew Bay	\N
ACT8716	Florida	Pensacola Bay	\N
MOB1101	Alabama	Mobile Bay	\N
ACT8731	Alabama	Mobile Bay	\N
ACT8736	Alabama	Mobile Bay	\N
ACT8741	Alabama	Mobile Bay	\N
ACT8746	Alabama	Mobile Bay	\N
MOB1106	Alabama	Mobile Bay	\N
MOB1104	Alabama	Mississippi Sound	\N
ps0201	Alabama	Mississippi Sound	\N
MOB1105	Alabama	Mississippi Sound	\N
gp0101	Alabama	Mississippi Sound	\N
gp0201	Alabama	Mississippi Sound	\N
gp0301	Alabama	Mississippi Sound	\N
ACT8771	Louisiana	\N	\N
ACT8776	Louisiana	\N	\N
ACT8781	Louisiana	\N	\N
ACT8786	Louisiana	\N	\N
ACT8791	Louisiana	\N	\N
ACT8801	Louisiana	\N	\N
ACT8806	Louisiana	\N	\N
ACT8811	Louisiana	\N	\N
lc0201	Louisiana	\N	\N
lc0301	Louisiana	\N	\N
ACT8821	Louisiana	\N	\N
ACT8826	Louisiana	\N	\N
sn0101	Texas	Sabine Pass	\N
ACT8831	Texas	Sabine Pass	\N
sn0201	Texas	Sabine Pass	\N
sn0801	Texas	Sabine Pass	\N
sn0301	Texas	Sabine Pass	\N
sn0701	Texas	Sabine Pass	\N
sn0501	Texas	Sabine Pass	\N
ACT8851	Texas	Galveston Bay	\N
g06010	Texas	Galveston Bay	\N
ACT8856	Texas	Galveston Bay	\N
g11010	Texas	Galveston Bay	\N
g09010	Texas	Galveston Bay	\N
g05010	Texas	Galveston Bay	\N
ACT8876	Texas	Galveston Bay	\N
ACT8881	Texas	Galveston Bay	\N
g02010	Texas	Galveston Bay	\N
g08010	Texas	Galveston Bay	\N
g10010	Texas	Galveston Bay	\N
fr0201	Texas	Freeport	\N
mg0201	Texas	Matagorda Bay	\N
mg0101	Texas	Matagorda Bay	\N
cc0601	Texas	\N	\N
cc0302	Texas	\N	\N
cc0501	Texas	\N	\N
STX1801	Texas	\N	\N
STX1802	Texas	\N	\N
cc0401	Texas	\N	\N
STX1812	Texas	Laguna Madre	\N
STX1813	Texas	Laguna Madre	\N
STX1814	Texas	Laguna Madre	\N
STX1820	Texas	\N	\N
STX1821	Texas	\N	\N
STX1819	Texas	\N	\N
STX1815	Texas	\N	\N
STX1822	Texas	\N	\N
STX1818	Texas	\N	\N
STX1817	Texas	\N	\N
HAI1125	Hawaii	\N	Hawaii Island
HAI1126	Hawaii	\N	Hawaii Island
HAI1127	Hawaii	\N	Hawaii Island
HAI1128	Hawaii	\N	Hawaii Island
HAI1130	Hawaii	\N	Hawaii Island
HAI1129	Hawaii	\N	Hawaii Island
HAI1124	Hawaii	\N	Maui Island
HAI1123	Hawaii	\N	Maui Island
HAI1118	Hawaii	\N	Maui Island
HAI1119	Hawaii	\N	Maui Island
HAI1120	Hawaii	\N	Maui Island
HAI1122	Hawaii	\N	Maui Island
HAI1121	Hawaii	\N	Maui Island
HAI1117	Hawaii	\N	\N
HAI1116	Hawaii	\N	\N
HAI1115	Hawaii	\N	Molokai Island
HAI1114	Hawaii	\N	Molokai Island
HAI1113	Hawaii	\N	Molokai Island
HAI1111	Hawaii	\N	Oahu Island
HAI1112	Hawaii	\N	Oahu Island
HAI1106	Hawaii	\N	Oahu Island
HAI1107	Hawaii	\N	Oahu Island
HAI1108	Hawaii	\N	Oahu Island
HAI1109	Hawaii	\N	Oahu Island
HAI1110	Hawaii	\N	Oahu Island
HAI1105	Hawaii	\N	Oahu Island
HAI1104	Hawaii	\N	Oahu Island
HAI1103	Hawaii	\N	Oahu Island
HAI1101	Hawaii	\N	Kauai Island
HAI1102	Hawaii	\N	Kauai Island
PCT0016	California	\N	\N
PCT0026	California	San Diego Bay	\N
PCT0031	California	San Diego Bay	\N
PCT0036	California	San Diego Bay	\N
PCT0041	California	San Diego Bay	\N
PCT0046	California	San Diego Bay	\N
PCT0051	California	San Diego Bay	\N
PCT0056	California	San Diego Bay	\N
PCT0061	California	San Diego Bay	\N
PCT0066	California	San Diego Bay	\N
PCT0071	California	San Diego Bay	\N
PCT0076	California	San Diego Bay	\N
PCT0081	California	San Diego Bay	\N
PCT0091	California	San Diego Bay	\N
PCT0096	California	San Diego Bay	\N
PCT0101	California	San Diego Bay	\N
PCT0106	California	San Diego Bay	\N
PCT0111	California	San Diego Bay	\N
PCT0116	California	San Diego Bay	\N
lb0101	California	\N	\N
PCT0166	California	\N	\N
PCT0171	California	\N	\N
PCT0156	California	Monterey Bay	\N
PCT0161	California	Monterey Bay	\N
SFB1223	California	\N	\N
SFB1224	California	\N	\N
SFB1222	California	\N	\N
SFB1225	California	\N	\N
PCT0181	California	\N	\N
SFB1221	California	\N	\N
PCT0191	California	\N	\N
PCT0201	California	\N	\N
PCT0206	California	\N	\N
PCT0211	California	\N	\N
PCT0231	California	\N	\N
PCT0236	California	\N	\N
SFB1220	California	\N	\N
PCT0246	California	\N	\N
PCT0251	California	\N	\N
PCT0256	California	\N	\N
PCT0261	California	\N	\N
SFB1201	California	\N	\N
SFB1202	California	\N	\N
SFB1203	California	\N	\N
PCT0281	California	\N	\N
PCT0286	California	\N	\N
PCT0291	California	San Francisco Bay	\N
SFB1204	California	San Francisco Bay	\N
PCT0301	California	San Francisco Bay	\N
SFB1211	California	San Francisco Bay	\N
SFB1205	California	San Francisco Bay	\N
SFB1218	California	San Francisco Bay	\N
SFB1210	California	San Francisco Bay	\N
PCT0321	California	San Francisco Bay	\N
PCT0326	California	San Francisco Bay	\N
SFB1206	California	San Francisco Bay	\N
SFB1209	California	San Francisco Bay	\N
PCT0336	California	San Francisco Bay	\N
SFB1208	California	San Francisco Bay	\N
SFB1207	California	San Francisco Bay	\N
PCT0346	California	San Francisco Bay	\N
PCT0351	California	San Francisco Bay	\N
PCT0356	California	San Francisco Bay	\N
PCT0361	California	San Francisco Bay	\N
s09010	California	San Francisco Bay	\N
s10010	California	San Francisco Bay	\N
PCT0371	California	San Francisco Bay	\N
SFB1213	California	San Francisco Bay	\N
SFB1214	California	San Francisco Bay	\N
PCT0386	California	San Francisco Bay	\N
SFB1216	California	San Francisco Bay	\N
PCT0396	California	San Francisco Bay	\N
SFB1215	California	San Francisco Bay	\N
SFB1217	California	San Francisco Bay	\N
PCT0406	California	San Francisco Bay	\N
PCT0411	California	San Francisco Bay	\N
PCT0416	California	San Francisco Bay	\N
PCT0421	California	San Francisco Bay	\N
PCT0426	California	San Francisco Bay	\N
PCT0431	California	San Francisco Bay	\N
PCT0436	California	San Francisco Bay	\N
PCT0441	California	San Francisco Bay	\N
PCT0446	California	San Francisco Bay	\N
PCT0451	California	San Francisco Bay	\N
PCT0456	California	San Francisco Bay	\N
PCT0461	California	San Francisco Bay	\N
SFB1308	California	San Francisco Bay	\N
PCT0466	California	San Francisco Bay	\N
PCT0471	California	San Francisco Bay	\N
PCT0476	California	San Francisco Bay	\N
PCT0481	California	San Francisco Bay	\N
PCT0486	California	San Francisco Bay	\N
PCT0491	California	San Francisco Bay	\N
SFB1307	California	San Francisco Bay	\N
SFB1306	California	San Francisco Bay	\N
PCT0501	California	San Francisco Bay	\N
PCT0506	California	San Francisco Bay	\N
PCT0511	California	San Francisco Bay	\N
SFB1305	California	San Francisco Bay	\N
PCT0521	California	San Francisco Bay	\N
SFB1302	California	San Francisco Bay	\N
SFB1304	California	San Francisco Bay	\N
SFB1301	California	San Francisco Bay	\N
PCT0531	California	San Francisco Bay	\N
PCT0536	California	San Francisco Bay	\N
PCT0541	California	San Francisco Bay	\N
PCT0546	California	San Francisco Bay	\N
PCT0551	California	San Francisco Bay	\N
PCT0556	California	San Francisco Bay	\N
PCT0561	California	San Francisco Bay	\N
PCT0566	California	San Francisco Bay	\N
PCT0571	California	San Francisco Bay	\N
PCT0576	California	San Francisco Bay	\N
PCT0581	California	San Francisco Bay	\N
PCT0586	California	San Francisco Bay	\N
PCT0591	California	San Francisco Bay	\N
PCT0596	California	San Francisco Bay	\N
PCT0606	California	San Francisco Bay	\N
SFB1212	California	San Francisco Bay	\N
PCT0621	California	San Francisco Bay	\N
PCT0626	California	San Francisco Bay	\N
PCT0631	California	San Francisco Bay	\N
SFB1309	California	San Francisco Bay	\N
PCT0641	California	San Francisco Bay	\N
SFB1310	California	San Francisco Bay	\N
PCT0651	California	San Francisco Bay	\N
PCT0656	California	San Francisco Bay	\N
PCT0661	California	San Francisco Bay	\N
s08010	California	San Francisco Bay	\N
PCT0666	California	San Francisco Bay	\N
PCT0671	California	San Francisco Bay	\N
PCT0676	California	San Francisco Bay	\N
PCT0681	California	San Francisco Bay	\N
PCT0686	California	San Francisco Bay	\N
PCT0691	California	San Francisco Bay	\N
SFB1312	California	San Pablo Bay	\N
PCT0701	California	San Pablo Bay	\N
PCT0706	California	San Pablo Bay	\N
PCT0711	California	San Pablo Bay	\N
SFB1314	California	San Pablo Bay	\N
PCT0721	California	San Pablo Bay	\N
SFB1315	California	San Pablo Bay	\N
SFB1313	California	San Pablo Bay	\N
PCT0731	California	San Pablo Bay	\N
PCT0736	California	San Pablo Bay	\N
PCT0741	California	San Pablo Bay	\N
PCT0746	California	San Pablo Bay	\N
SFB1316	California	San Pablo Bay	\N
PCT0756	California	San Pablo Bay	\N
SFB1317	California	Carquinez Strait	\N
PCT0766	California	Carquinez Strait	\N
SFB1318	California	Carquinez Strait	\N
SFB1319	California	Carquinez Strait	\N
SFB1320	California	Carquinez Strait	\N
PCT0781	California	Carquinez Strait	\N
PCT0786	California	Carquinez Strait	\N
PCT0791	California	Carquinez Strait	\N
PCT0796	California	Carquinez Strait	\N
SFB1322	California	Suisun Bay	\N
PCT0801	California	Suisun Bay	Montezuma Slough
PCT0806	California	Suisun Bay	Montezuma Slough
PCT0811	California	Suisun Bay	Suisun Slough
PCT0816	California	Suisun Bay	Suisun Slough
PCT0821	California	Suisun Bay	Suisun Slough
s06010	California	Suisun Bay	\N
PCT0831	California	Suisun Bay	\N
PCT0836	California	Suisun Bay	\N
PCT0841	California	Suisun Bay	\N
SFB1323	California	Suisun Bay	\N
PCT0851	California	Suisun Bay	\N
PCT0856	California	Suisun Bay	\N
SFB1324	California	Suisun Bay	\N
PCT0866	California	Suisun Bay	\N
SFB1325	California	Suisun Bay	\N
PCT0876	California	Suisun Bay	\N
PCT0881	California	Suisun Bay	\N
SFB1326	California	Suisun Bay	\N
PCT0891	California	Suisun Bay	\N
SFB1330	California	Sacramento River	\N
SFB1331	California	Sacramento River	\N
PCT0906	California	Sacramento River	\N
SFB1332	California	Sacramento River	\N
PCT0911	California	San Joaquin River	\N
PCT0916	California	San Joaquin River	\N
PCT0921	California	San Joaquin River	\N
SFB1327	California	San Joaquin River	\N
SFB1328	California	San Joaquin River	\N
SFB1329	California	San Joaquin River	\N
PCT0936	California	San Joaquin River	\N
HUB0401	California	Humboldt Bay	\N
HUB0402	California	Humboldt Bay	\N
HUB0202	California	Humboldt Bay	\N
hb0201	California	Humboldt Bay	\N
HUB0207	California	Humboldt Bay	\N
hb0302	California	Humboldt Bay	\N
hb0401	California	Humboldt Bay	\N
HUB0203	California	Humboldt Bay	\N
PCT1021	California	Humboldt Bay	\N
PCT1026	California	Humboldt Bay	\N
PCT1056	Oregon	\N	\N
PCT1061	Oregon	\N	\N
PCT1066	Oregon	\N	\N
PCT1071	Oregon	\N	\N
PCT1076	Oregon	Yaquina Bay	\N
PCT1081	Oregon	Yaquina Bay	\N
PCT1086	Oregon	Yaquina Bay	\N
PCT1091	Oregon	Yaquina Bay	\N
PCT1096	Oregon	Tillamook Bay	\N
PCT1106	Oregon	\N	\N
PCT1111	Oregon	\N	\N
PCT1116	Oregon	\N	\N
PCT1121	Oregon	\N	\N
PCT1126	Oregon	\N	\N
PCT1146	Oregon	\N	\N
PCT1151	Oregon	\N	\N
PCT1156	Oregon	\N	\N
PCT1161	Oregon	\N	\N
PCT1166	Oregon	\N	\N
PCT1171	Oregon	\N	\N
PCT1176	Oregon	\N	\N
PCT1186	Oregon	\N	\N
PCT1191	Oregon	\N	\N
PCT1201	Oregon	\N	\N
PCT1206	Oregon	\N	\N
PCT1216	Oregon	\N	\N
PCT1231	Oregon	\N	\N
PCT1251	Oregon	\N	\N
PCT1271	Washington	\N	\N
PCT1276	Washington	Grays Harbor	\N
PCT1281	Washington	Grays Harbor	\N
PCT1286	Washington	Grays Harbor	\N
PCT1291	Washington	Grays Harbor	\N
PCT1296	Washington	Grays Harbor	\N
PCT1301	Washington	Grays Harbor	\N
PCT1306	Washington	Grays Harbor	\N
PCT1316	Washington	Grays Harbor	\N
PCT1321	Washington	\N	\N
PUG1642	Washington	Strait of Juan de Fuca	\N
PUG1641	Washington	Strait of Juan de Fuca	\N
PUG1639	Washington	Strait of Juan de Fuca	\N
PUG1640	Washington	Strait of Juan de Fuca	\N
PCT1371	Washington	Strait of Juan de Fuca	\N
PCT1376	Washington	Strait of Juan de Fuca	\N
PUG1638	Washington	Strait of Juan de Fuca	\N
PUG1637	Washington	Strait of Juan de Fuca	\N
PCT1391	Washington	Strait of Juan de Fuca	\N
PUG1635	Washington	Strait of Juan de Fuca	\N
PCT1401	Washington	Strait of Juan de Fuca	\N
PUG1636	Washington	Strait of Juan de Fuca	\N
PCT1411	Washington	Strait of Juan de Fuca	\N
PUG1631	Washington	Strait of Juan de Fuca	\N
PUG1630	Washington	Strait of Juan de Fuca	\N
PUG1632	Washington	Strait of Juan de Fuca	\N
PCT1451	Washington	Strait of Juan de Fuca	\N
PUG1634	Washington	Strait of Juan de Fuca	\N
PCT1466	Washington	Strait of Juan de Fuca	\N
PUG1623	Washington	Admiralty Inlet	\N
PUG1624	Washington	Admiralty Inlet	\N
PUG1625	Washington	Admiralty Inlet	\N
PCT1496	Washington	Admiralty Inlet	\N
PCT1501	Washington	Admiralty Inlet	\N
PCT1511	Washington	Admiralty Inlet	Marrowstone Point
PUG1619	Washington	Admiralty Inlet	Marrowstone Point
PUG1620	Washington	Admiralty Inlet	Marrowstone Point
PUG1615	Washington	Admiralty Inlet	\N
PUG1616	Washington	Admiralty Inlet	\N
PUG1617	Washington	Admiralty Inlet	\N
PUG1611	Washington	Admiralty Inlet	\N
PUG1614	Washington	Admiralty Inlet	\N
PUG1608	Washington	Hood Canal	\N
PCT1571	Washington	Hood Canal	\N
PUG1604	Washington	Hood Canal	\N
PUG1603	Washington	Hood Canal	\N
PUG1602	Washington	Hood Canal	\N
ks0201	Washington	Hood Canal	\N
PUG1601	Washington	Hood Canal	\N
PCT1596	Washington	Hood Canal	\N
PCT1606	Washington	Puget Sound	\N
PUG1610	Washington	Puget Sound	\N
PUG1606	Washington	Puget Sound	\N
PUG1607	Washington	Puget Sound	\N
PUG1503	Washington	Puget Sound	\N
PUG1511	Washington	Puget Sound	\N
PUG1509	Washington	Puget Sound	\N
PCT1636	Washington	Puget Sound	\N
PUG1501	Washington	Puget Sound	\N
PCT1646	Washington	Puget Sound	\N
PCT1651	Washington	Puget Sound	\N
PUG1508	Washington	Puget Sound	\N
PCT1661	Washington	Puget Sound	\N
PUG1515	Washington	Puget Sound	\N
PCT1671	Washington	Puget Sound	\N
PUG1504	Washington	Puget Sound	\N
PCT1676	Washington	Puget Sound	\N
PUG1516	Washington	Puget Sound	\N
PUG1502	Washington	Puget Sound	\N
PUG1507	Washington	Puget Sound	\N
PUG1506	Washington	Puget Sound	\N
PUG1512	Washington	Puget Sound	\N
PUG1513	Washington	Puget Sound	Rich Passage
PCT1701	Washington	Puget Sound	Rich Passage
ks0101	Washington	Puget Sound	Rich Passage
PUG1514	Washington	Puget Sound	Rich Passage
PUG1505	Washington	Puget Sound	\N
PCT1711	Washington	Puget Sound	\N
PUG1510	Washington	Puget Sound	\N
PUG1517	Washington	Puget Sound	\N
PUG1520	Washington	Puget Sound	\N
PUG1518	Washington	Puget Sound	\N
PUG1519	Washington	Puget Sound	\N
PUG1521	Washington	Puget Sound	\N
PUG1522	Washington	Puget Sound	\N
PUG1523	Washington	Puget Sound	\N
PUG1524	Washington	Puget Sound	The Narrows
PUG1526	Washington	Puget Sound	The Narrows
PUG1527	Washington	Puget Sound	The Narrows
PUG1528	Washington	Puget Sound	The Narrows
PUG1529	Washington	Puget Sound	\N
PUG1530	Washington	Puget Sound	\N
PUG1531	Washington	Puget Sound	\N
PUG1532	Washington	Puget Sound	\N
PUG1533	Washington	Puget Sound	\N
PUG1534	Washington	Puget Sound	\N
PUG1535	Washington	Puget Sound	\N
PUG1536	Washington	Puget Sound	\N
PUG1537	Washington	Puget Sound	\N
PUG1538	Washington	Puget Sound	\N
PUG1539	Washington	Puget Sound	\N
PUG1540	Washington	Puget Sound	\N
PCT1861	Washington	Puget Sound	\N
PUG1541	Washington	Puget Sound	\N
PUG1542	Washington	Puget Sound	\N
PUG1543	Washington	Puget Sound	\N
PUG1544	Washington	Puget Sound	\N
PUG1545	Washington	Puget Sound	\N
PCT1896	Washington	Puget Sound	\N
PUG1546	Washington	Puget Sound	\N
PUG1547	Washington	Puget Sound	\N
PUG1548	Washington	Puget Sound	\N
PCT1916	Washington	Puget Sound	\N
PUG1605	Washington	\N	\N
PUG1609	Washington	\N	\N
PUG1612	Washington	\N	\N
PUG1618	Washington	\N	\N
PUG1613	Washington	\N	\N
PUG1627	Washington	\N	\N
PCT1926	Washington	\N	\N
PUG1622	Washington	\N	\N
PUG1626	Washington	\N	\N
PUG1628	Washington	\N	\N
PUG1629	Washington	Rosario Strait	\N
PUG1701	Washington	Rosario Strait	\N
PCT1966	Washington	Rosario Strait	\N
PCT1971	Washington	Rosario Strait	\N
PUG1728	Washington	Rosario Strait	\N
PUG1727	Washington	Rosario Strait	\N
PUG1702	Washington	Rosario Strait	\N
PUG1730	Washington	Rosario Strait	\N
PCT2006	Washington	Rosario Strait	\N
PUG1729	Washington	Rosario Strait	\N
PCT2026	Washington	Rosario Strait	\N
PUG1731	Washington	Rosario Strait	\N
PUG1733	Washington	Rosario Strait	\N
PCT2046	Washington	Rosario Strait	\N
PUG1739	Washington	Rosario Strait	\N
PUG1732	Washington	Rosario Strait	\N
PUG1704	Washington	Rosario Strait	\N
PUG1705	Washington	Rosario Strait	\N
PUG1706	Washington	Rosario Strait	\N
PCT2071	Washington	Rosario Strait	\N
PCT2076	Washington	Rosario Strait	\N
PCT2086	Washington	Rosario Strait	\N
PUG1734	Washington	Rosario Strait	\N
PUG1735	Washington	Rosario Strait	\N
PUG1736	Washington	Rosario Strait	\N
PCT2106	Washington	Rosario Strait	\N
PCT2116	Washington	Rosario Strait	\N
PUG1740	Washington	Rosario Strait	\N
PUG1741	Washington	Rosario Strait	\N
PCT2126	Washington	Rosario Strait	\N
PUG1707	Washington	Rosario Strait	\N
PUG1708	Washington	Rosario Strait	\N
PUG1710	Washington	Rosario Strait	\N
PUG1709	Washington	Rosario Strait	\N
PUG1711	Washington	Rosario Strait	\N
PUG1712	Washington	Rosario Strait	\N
PUG1713	Washington	Rosario Strait	\N
PUG1714	Washington	Rosario Strait	\N
PCT2286	Washington	Rosario Strait	\N
PCT2166	Washington	Rosario Strait	\N
PUG1725	Washington	Rosario Strait	\N
cp0101	Washington	Rosario Strait	\N
PCT1416	Washington	San Juan Channel	\N
PUG1743	Washington	San Juan Channel	\N
PUG1742	Washington	San Juan Channel	\N
PUG1703	Washington	San Juan Channel	\N
PCT2191	Washington	San Juan Channel	\N
PUG1746	Washington	San Juan Channel	\N
PUG1745	Washington	San Juan Channel	\N
PUG1723	Washington	San Juan Channel	\N
PUG1721	Washington	San Juan Channel	\N
PUG1720	Washington	San Juan Channel	\N
PUG1719	Washington	San Juan Channel	\N
PUG1715	Washington	San Juan Channel	\N
PUG1722	Washington	San Juan Channel	\N
PCT2236	Washington	San Juan Channel	\N
PCT2241	Washington	San Juan Channel	\N
PUG1744	Washington	\N	\N
PUG1724	Washington	\N	\N
PUG1718	Washington	\N	\N
PUG1717	Washington	\N	\N
PCT2266	Washington	\N	\N
PUG1716	Washington	\N	\N
PCT2276	Washington	\N	\N
PCT2281	Washington	\N	\N
PCT2301	Washington	Georgia Strait	\N
PUG1726	Washington	Georgia Strait	\N
PCT2311	Washington	Georgia Strait	\N
PCT2576	Alaska	\N	\N
PCT2586	Alaska	\N	\N
PCT2591	Alaska	\N	\N
PCT2601	Alaska	\N	\N
PCT2606	Alaska	\N	\N
PCT2611	Alaska	Dixon Entrance	\N
PCT2616	Alaska	Dixon Entrance	\N
PCT2621	Alaska	Dixon Entrance	\N
PCT2626	Alaska	Dixon Entrance	\N
SEA0708	Alaska	Dixon Entrance	\N
PCT2636	Alaska	Dixon Entrance	\N
PCT2641	Alaska	Dixon Entrance	\N
PCT2646	Alaska	Dixon Entrance	\N
PCT2651	Alaska	Dixon Entrance	\N
PCT2656	Alaska	Dixon Entrance	\N
PCT2661	Alaska	Dixon Entrance	\N
PCT2666	Alaska	Dixon Entrance	\N
PCT2671	Alaska	Pearse Canal	\N
PCT2676	Alaska	Pearse Canal	\N
PCT2681	Alaska	Pearse Canal	\N
PCT2686	Alaska	Pearse Canal	\N
PCT2691	Alaska	Portland Canal	\N
PCT2696	Alaska	Portland Canal	\N
PCT2701	Alaska	Portland Canal	\N
PCT2706	Alaska	Portland Canal	\N
PCT2711	Alaska	Portland Canal	\N
PCT2716	Alaska	Portland Canal	\N
PCT2721	Alaska	Portland Canal	\N
PCT2726	Alaska	Portland Canal	\N
PCT2731	Alaska	Portland Canal	\N
PCT2736	Alaska	Revillagigedo Channel	\N
PCT2741	Alaska	Revillagigedo Channel	\N
PCT2746	Alaska	Revillagigedo Channel	\N
PCT2756	Alaska	Revillagigedo Channel	\N
PCT2761	Alaska	Revillagigedo Channel	\N
PCT2766	Alaska	Carroll Inlet	\N
SEA0712	Alaska	Tongass Narrows	\N
SEA0714	Alaska	Tongass Narrows	\N
PCT2781	Alaska	Tongass Narrows	\N
PCT2786	Alaska	Tongass Narrows	\N
SEA0711	Alaska	Tongass Narrows	\N
PCT2796	Alaska	Tongass Narrows	\N
PCT2806	Alaska	Felice Strait	\N
PCT2811	Alaska	Felice Strait	\N
PCT2816	Alaska	Felice Strait	\N
PCT2821	Alaska	Felice Strait	\N
PCT2831	Alaska	Felice Strait	\N
PCT2836	Alaska	Felice Strait	\N
PCT2841	Alaska	Felice Strait	\N
PCT2856	Alaska	Felice Strait	\N
PCT2861	Alaska	Felice Strait	\N
PCT2866	Alaska	Felice Strait	\N
PCT2871	Alaska	Nichols Passage	\N
PCT2876	Alaska	Nichols Passage	\N
PCT2881	Alaska	Nichols Passage	\N
PCT2886	Alaska	Nichols Passage	\N
PCT2891	Alaska	Nichols Passage	\N
PCT2896	Alaska	Nichols Passage	\N
PCT2901	Alaska	Nichols Passage	\N
PCT2906	Alaska	Nichols Passage	\N
PCT2911	Alaska	Nichols Passage	\N
SEA0713	Alaska	Nichols Passage	\N
PCT2921	Alaska	Behm Canal	\N
PCT2926	Alaska	Behm Canal	\N
PCT2931	Alaska	Behm Canal	\N
PCT2936	Alaska	Behm Canal	\N
PCT2941	Alaska	Behm Canal	\N
PCT2946	Alaska	Behm Canal	\N
PCT2961	Alaska	Clarence Strait	\N
PCT2966	Alaska	Clarence Strait	\N
PCT2971	Alaska	Clarence Strait	\N
PCT2976	Alaska	Clarence Strait	\N
PCT2986	Alaska	Clarence Strait	\N
PCT2991	Alaska	Clarence Strait	\N
SEA0710	Alaska	Clarence Strait	\N
PCT3001	Alaska	Clarence Strait	\N
SEA0709	Alaska	Clarence Strait	\N
PCT3011	Alaska	Clarence Strait	\N
PCT3016	Alaska	Clarence Strait	\N
PCT3021	Alaska	Clarence Strait	\N
PCT3026	Alaska	Clarence Strait	\N
PCT3031	Alaska	Clarence Strait	\N
PCT3036	Alaska	Clarence Strait	\N
PCT3141	Alaska	Clarence Strait	\N
SEA0404	Alaska	Clarence Strait	\N
PCT3151	Alaska	Clarence Strait	\N
SEA0403	Alaska	Clarence Strait	\N
PCT3161	Alaska	Clarence Strait	\N
SEA0402	Alaska	Clarence Strait	\N
SEA0401	Alaska	Clarence Strait	\N
PCT3041	Alaska	Ernest Sound	\N
PCT3046	Alaska	Ernest Sound	\N
PCT3051	Alaska	Ernest Sound	\N
PCT3056	Alaska	Ernest Sound	\N
PCT3061	Alaska	Ernest Sound	\N
PCT3066	Alaska	Ernest Sound	\N
PCT3071	Alaska	\N	\N
PCT3076	Alaska	\N	\N
PCT3081	Alaska	\N	\N
PCT3086	Alaska	\N	\N
PCT3091	Alaska	\N	\N
PCT3096	Alaska	\N	\N
PCT3101	Alaska	Zimovia Strait	\N
PCT3106	Alaska	Zimovia Strait	\N
PCT3111	Alaska	Zimovia Strait	\N
PCT3116	Alaska	Zimovia Strait	\N
PCT3121	Alaska	Zimovia Strait	\N
PCT3126	Alaska	Zimovia Strait	\N
PCT3131	Alaska	Zimovia Strait	\N
PCT3136	Alaska	Zimovia Strait	\N
PCT3176	Alaska	Stikine Strait	\N
PCT3181	Alaska	Stikine Strait	\N
PCT3186	Alaska	Stikine Strait	\N
PCT3191	Alaska	Stikine Strait	\N
PCT3196	Alaska	Cordova Bay	\N
PCT3201	Alaska	Cordova Bay	\N
PCT3211	Alaska	Cordova Bay	\N
PCT3221	Alaska	Cordova Bay	\N
PCT3226	Alaska	Cordova Bay	\N
PCT3231	Alaska	Tlevak Strait	\N
PCT3236	Alaska	Tlevak Strait	\N
PCT3241	Alaska	Tlevak Strait	\N
PCT3246	Alaska	Tlevak Strait	\N
PCT3251	Alaska	Tlevak Strait	\N
PCT3256	Alaska	Tlevak Strait	\N
PCT3261	Alaska	Tlevak Strait	\N
PCT3266	Alaska	Tlevak Strait	\N
PCT3271	Alaska	Tlevak Strait	\N
SEA0706	Alaska	Tlevak Strait	\N
PCT3281	Alaska	Meares Passage	\N
SEA0705	Alaska	Meares Passage	\N
PCT3291	Alaska	Meares Passage	\N
PCT3296	Alaska	Meares Passage	\N
PCT3301	Alaska	Ulloa Channel	\N
SEA0704	Alaska	Ulloa Channel	\N
PCT3311	Alaska	Ulloa Channel	\N
PCT3316	Alaska	\N	\N
SEA0703	Alaska	\N	\N
PCT3326	Alaska	\N	\N
PCT3331	Alaska	\N	\N
PCT3336	Alaska	\N	\N
PCT3346	Alaska	\N	\N
PCT3351	Alaska	\N	\N
PCT3356	Alaska	\N	\N
SEA0901	Alaska	\N	\N
SEA0636	Alaska	\N	\N
SEA0637	Alaska	\N	\N
SEA0642	Alaska	\N	\N
SEA0635	Alaska	\N	\N
SEA0639	Alaska	\N	\N
SEA0641	Alaska	\N	\N
SEA0638	Alaska	\N	\N
SEA0634	Alaska	\N	\N
SEA0632	Alaska	\N	\N
SEA0633	Alaska	\N	\N
SEA0631	Alaska	\N	\N
SEA0623	Alaska	\N	\N
SEA0624	Alaska	\N	\N
SEA0628	Alaska	\N	\N
SEA0630	Alaska	\N	\N
SEA0629	Alaska	\N	\N
PCT3456	Alaska	\N	\N
SEA0627	Alaska	\N	\N
SEA0625	Alaska	\N	\N
SEA0702	Alaska	\N	\N
SEA0626	Alaska	El Capitan Passage	\N
PCT3476	Alaska	El Capitan Passage	\N
PCT3481	Alaska	El Capitan Passage	\N
PCT3486	Alaska	El Capitan Passage	\N
PCT3491	Alaska	El Capitan Passage	\N
PCT3496	Alaska	El Capitan Passage	Aneskett Point
PCT3501	Alaska	El Capitan Passage	Aneskett Point
PCT3506	Alaska	El Capitan Passage	Aneskett Point
SEA0614	Alaska	El Capitan Passage	\N
SEA0622	Alaska	Sumner Strait	\N
PCT3521	Alaska	Sumner Strait	\N
SEA0621	Alaska	Sumner Strait	\N
SEA0617	Alaska	Sumner Strait	\N
SEA0619	Alaska	Sumner Strait	\N
SEA0618	Alaska	Sumner Strait	\N
PCT3551	Alaska	Sumner Strait	\N
PCT3556	Alaska	Sumner Strait	\N
PCT3561	Alaska	Sumner Strait	\N
SEA0611	Alaska	Sumner Strait	\N
SEA0610	Alaska	Sumner Strait	\N
PCT3576	Alaska	Sumner Strait	\N
PCT3581	Alaska	Sumner Strait	\N
SEA0615	Alaska	Sumner Strait	\N
SEA0612	Alaska	Sumner Strait	\N
SEA0613	Alaska	Sumner Strait	\N
SEA0616	Alaska	Sumner Strait	\N
SEA0609	Alaska	Sumner Strait	\N
SEA0608	Alaska	Sumner Strait	\N
PCT3616	Alaska	Sumner Strait	\N
SEA0607	Alaska	Sumner Strait	\N
SEA0605	Alaska	Sumner Strait	\N
PCT3636	Alaska	Sumner Strait	\N
SEA0604	Alaska	Sumner Strait	\N
SEA0603	Alaska	Sumner Strait	\N
SEA0606	Alaska	Sumner Strait	\N
SEA0602	Alaska	Sumner Strait	\N
SEA0601	Alaska	Sumner Strait	\N
SEA0405	Alaska	Sumner Strait	\N
PCT3681	Alaska	Sumner Strait	\N
PCT3686	Alaska	Keku Strait	\N
PCT3691	Alaska	Keku Strait	\N
PCT3696	Alaska	Keku Strait	\N
PCT3701	Alaska	Keku Strait	\N
PCT3706	Alaska	Keku Strait	\N
PCT3711	Alaska	Keku Strait	\N
PCT3716	Alaska	Keku Strait	\N
PCT3721	Alaska	Keku Strait	\N
PCT3726	Alaska	Keku Strait	\N
PCT3731	Alaska	Keku Strait	\N
SEA0505	Alaska	Keku Strait	\N
PCT3741	Alaska	Wrangell Narrows	\N
PCT3746	Alaska	Wrangell Narrows	\N
PCT3751	Alaska	Wrangell Narrows	\N
PCT3756	Alaska	Wrangell Narrows	\N
SEA0104	Alaska	Wrangell Narrows	\N
PCT3766	Alaska	Wrangell Narrows	\N
PCT3771	Alaska	Wrangell Narrows	\N
PCT3781	Alaska	Wrangell Narrows	\N
PCT3786	Alaska	Wrangell Narrows	\N
PCT3791	Alaska	Wrangell Narrows	\N
PCT3796	Alaska	Wrangell Narrows	\N
SEA0103	Alaska	Wrangell Narrows	\N
PCT3806	Alaska	Wrangell Narrows	\N
PCT3811	Alaska	Frederick Sound	\N
SEA0504	Alaska	Frederick Sound	\N
SEA0503	Alaska	Stephens Passage	\N
PCT3826	Alaska	Stephens Passage	\N
SEA0502	Alaska	Stephens Passage	\N
PCT3841	Alaska	Stephens Passage	\N
PCT3846	Alaska	Stephens Passage	\N
SEA0811	Alaska	Stephens Passage	\N
SEA0307	Alaska	Stephens Passage	\N
SEA0810	Alaska	Stephens Passage	\N
PCT3866	Alaska	Stephens Passage	\N
SEA0809	Alaska	Stephens Passage	\N
PCT3876	Alaska	Stephens Passage	\N
SEA0806	Alaska	Stephens Passage	Taku Inlet
PCT3886	Alaska	Stephens Passage	Taku Inlet
SEA0807	Alaska	Stephens Passage	Taku Inlet
PCT3896	Alaska	Stephens Passage	Taku Inlet
PCT3901	Alaska	Stephens Passage	Taku Inlet
PCT3916	Alaska	Stephens Passage	Gastineau Channel
PCT3921	Alaska	Stephens Passage	Gastineau Channel
PCT3926	Alaska	Stephens Passage	Gastineau Channel
PCT3936	Alaska	Stephens Passage	Gastineau Channel
PCT3946	Alaska	Stephens Passage	Gastineau Channel
SEA0801	Alaska	Stephens Passage	Gastineau Channel
SEA0802	Alaska	Stephens Passage	Gastineau Channel
SEA0803	Alaska	Stephens Passage	Gastineau Channel
SEA0804	Alaska	Stephens Passage	Gastineau Channel
SEA0805	Alaska	Stephens Passage	Gastineau Channel
SEA0812	Alaska	Stephens Passage	\N
SEA0813	Alaska	Stephens Passage	\N
SEA0815	Alaska	Stephens Passage	\N
PCT3966	Alaska	Stephens Passage	\N
SEA0814	Alaska	Stephens Passage	\N
SEA0816	Alaska	Stephens Passage	\N
SEA0818	Alaska	Stephens Passage	\N
PCT3986	Alaska	Stephens Passage	\N
SEA0817	Alaska	Lynn Canal	\N
SEA0820	Alaska	Lynn Canal	\N
SEA0819	Alaska	Lynn Canal	\N
SEA0822	Alaska	Lynn Canal	\N
PCT4006	Alaska	Lynn Canal	\N
SEA0823	Alaska	Lynn Canal	\N
PCT4011	Alaska	Lynn Canal	\N
SEA0828	Alaska	Lynn Canal	\N
SEA0827	Alaska	Lynn Canal	\N
PCT4026	Alaska	Lynn Canal	\N
PCT4041	Alaska	Lynn Canal	\N
SEA0826	Alaska	Lynn Canal	\N
SEA0825	Alaska	Lynn Canal	\N
SEA0824	Alaska	Lynn Canal	\N
PCT4056	Alaska	Chatham Strait	\N
PCT4061	Alaska	Chatham Strait	\N
PCT4066	Alaska	Chatham Strait	\N
PCT4071	Alaska	Chatham Strait	\N
PCT4076	Alaska	Chatham Strait	\N
PCT4081	Alaska	Chatham Strait	\N
PCT4086	Alaska	Chatham Strait	\N
PCT4091	Alaska	Chatham Strait	\N
SEA0406	Alaska	Chatham Strait	\N
PCT4101	Alaska	Chatham Strait	\N
PCT4106	Alaska	Chatham Strait	\N
PCT4111	Alaska	Chatham Strait	\N
PCT4116	Alaska	Chatham Strait	\N
SEA0507	Alaska	Chatham Strait	\N
PCT4131	Alaska	Sitka Sound	\N
PCT4136	Alaska	Sitka Sound	\N
SEA0407	Alaska	Sitka Sound	\N
SEA0408	Alaska	Sitka Sound	\N
PCT4151	Alaska	Sitka Sound	\N
PCT4156	Alaska	Sitka Sound	\N
SEA0409	Alaska	Sitka Sound	\N
PCT4166	Alaska	Sitka Sound	\N
PCT4171	Alaska	Krestof Sound	\N
PCT4176	Alaska	Krestof Sound	\N
PCT4186	Alaska	\N	\N
PCT4191	Alaska	\N	\N
SEA0205	Alaska	Olga Strait	\N
SEA0204	Alaska	Neva Strait	\N
PCT4211	Alaska	Neva Strait	\N
PCT4216	Alaska	Neva Strait	\N
SEA0306	Alaska	Neva Strait	\N
SEA0305	Alaska	Neva Strait	\N
PCT4231	Alaska	Neva Strait	\N
PCT4236	Alaska	Salisbury Sound	\N
PCT4241	Alaska	Salisbury Sound	\N
PCT4246	Alaska	Salisbury Sound	\N
SEA0203	Alaska	Peril Strait	\N
SEA0304	Alaska	Peril Strait	\N
SEA0202	Alaska	Peril Strait	\N
PCT4266	Alaska	Peril Strait	\N
PCT4271	Alaska	Peril Strait	\N
SEA0303	Alaska	Peril Strait	\N
SEA0302	Alaska	Peril Strait	\N
PCT4286	Alaska	Peril Strait	\N
PCT4291	Alaska	Peril Strait	\N
PCT4296	Alaska	Peril Strait	\N
PCT4301	Alaska	Peril Strait	\N
PCT4306	Alaska	Peril Strait	\N
PCT4311	Alaska	Peril Strait	\N
PCT4316	Alaska	Peril Strait	\N
PCT4321	Alaska	Peril Strait	\N
PCT4326	Alaska	Peril Strait	\N
PCT4331	Alaska	Peril Strait	\N
SEA0837	Alaska	\N	\N
SEA0836	Alaska	\N	\N
SEA0835	Alaska	\N	\N
SEA0834	Alaska	\N	\N
SEA0833	Alaska	Cross Sound	\N
SEA1008	Alaska	Cross Sound	\N
SEA1009	Alaska	Cross Sound	\N
SEA1010	Alaska	Cross Sound	\N
SEA0832	Alaska	Cross Sound	\N
SEA0851	Alaska	Cross Sound	\N
SEA0831	Alaska	Cross Sound	\N
SEA1006	Alaska	Cross Sound	\N
PCT4361	Alaska	Cross Sound	\N
SEA1007	Alaska	Cross Sound	\N
SEA0830	Alaska	Cross Sound	\N
SEA1005	Alaska	Cross Sound	\N
SEA0845	Alaska	\N	\N
SEA0843	Alaska	\N	\N
SEA1004	Alaska	\N	\N
SEA1003	Alaska	\N	\N
SEA1002	Alaska	\N	\N
SEA0847	Alaska	\N	\N
SEA0849	Alaska	\N	\N
SEA0848	Alaska	\N	\N
SEA0850	Alaska	\N	\N
SEA1001	Alaska	\N	\N
SEA0840	Alaska	\N	\N
SEA0839	Alaska	\N	\N
SEA0838	Alaska	Lituya Bay	\N
PCT4406	Alaska	Icy Bay	\N
PCT4411	Alaska	Icy Bay	\N
PCT4416	Alaska	Icy Bay	\N
PCT4421	Alaska	Icy Bay	\N
PCT4426	Alaska	Icy Bay	\N
PCT4436	Alaska	Controller Bay	\N
PCT4441	Alaska	Controller Bay	\N
PWS0729	Alaska	Prince William Sound	Hinchinbrook Entrance
PWS0721	Alaska	Prince William Sound	Hinchinbrook Entrance
PCT4466	Alaska	Prince William Sound	Hinchinbrook Entrance
PCT4471	Alaska	Prince William Sound	Hinchinbrook Entrance
PWS0726	Alaska	Prince William Sound	Hinchinbrook Entrance
PWS0725	Alaska	Prince William Sound	Hinchinbrook Entrance
PCT4501	Alaska	Prince William Sound	\N
PCT4506	Alaska	Prince William Sound	\N
PWS0719	Alaska	Prince William Sound	\N
PWS0717	Alaska	Prince William Sound	\N
PWS0715	Alaska	Prince William Sound	\N
PWS0716	Alaska	Prince William Sound	\N
PWS0714	Alaska	Prince William Sound	\N
PWS0712	Alaska	Prince William Sound	\N
PWS0713	Alaska	Prince William Sound	\N
PCT4546	Alaska	Prince William Sound	\N
PWS0711	Alaska	Prince William Sound	\N
PWS0709	Alaska	Prince William Sound	\N
PWS0710	Alaska	Prince William Sound	\N
PWS0708	Alaska	Prince William Sound	\N
PWS0723	Alaska	Prince William Sound	\N
PWS0724	Alaska	Prince William Sound	\N
PCT4596	Alaska	Prince William Sound	Central Sound
PWS0739	Alaska	Prince William Sound	Central Sound
PWS0740	Alaska	Prince William Sound	Central Sound
PWS0741	Alaska	Prince William Sound	Central Sound
PWS0742	Alaska	Prince William Sound	Central Sound
PWS0743	Alaska	Prince William Sound	Central Sound
PWS0744	Alaska	Prince William Sound	Central Sound
PCT4671	Alaska	Prince William Sound	\N
PWS0727	Alaska	Prince William Sound	\N
PWS0731	Alaska	Prince William Sound	\N
PWS0736	Alaska	Prince William Sound	\N
PWS0732	Alaska	Prince William Sound	\N
PWS0735	Alaska	Prince William Sound	\N
PWS0733	Alaska	Prince William Sound	\N
PWS0734	Alaska	Prince William Sound	\N
PWS0738	Alaska	Prince William Sound	Valdez Arm
PWS0745	Alaska	Prince William Sound	Valdez Arm
PWS0747	Alaska	Prince William Sound	Valdez Arm
PWS0746	Alaska	Prince William Sound	Valdez Arm
PCT4711	Alaska	Prince William Sound	Port Wells
PWS0702	Alaska	Prince William Sound	Port Wells
PWS0706	Alaska	Prince William Sound	Port Wells
PWS0704	Alaska	Prince William Sound	Port Wells
PWS0707	Alaska	Prince William Sound	Port Wells
PWS0703	Alaska	Prince William Sound	Port Wells
PWS0705	Alaska	Prince William Sound	Port Wells
PWS0701	Alaska	Prince William Sound	Port Wells
PCT4751	Alaska	Orca Bay	\N
PCT4756	Alaska	Orca Bay	\N
PCT4761	Alaska	Orca Bay	\N
PCT4766	Alaska	Orca Bay	\N
PCT4771	Alaska	Orca Bay	\N
PCT4776	Alaska	Orca Bay	\N
PCT4781	Alaska	Orca Bay	\N
PCT4786	Alaska	Orca Bay	\N
PCT4791	Alaska	Orca Bay	\N
PCT4796	Alaska	Orca Bay	\N
PCT4801	Alaska	Orca Bay	\N
PCT4806	Alaska	Orca Bay	\N
PCT4811	Alaska	Orca Bay	\N
PCT4816	Alaska	Orca Bay	\N
COI0519	Alaska	Cook Inlet	\N
COI0517	Alaska	Cook Inlet	\N
PCT4831	Alaska	Cook Inlet	\N
COI0520	Alaska	Cook Inlet	\N
PCT4841	Alaska	Cook Inlet	\N
PCT4846	Alaska	Cook Inlet	\N
COI0418	Alaska	Cook Inlet	\N
COI0521	Alaska	Cook Inlet	\N
COI0524	Alaska	Cook Inlet	\N
COI0523	Alaska	Cook Inlet	\N
COI0522	Alaska	Cook Inlet	\N
COI0514	Alaska	Cook Inlet	\N
COI0516	Alaska	Cook Inlet	\N
PCT4886	Alaska	Cook Inlet	\N
COI1202	Alaska	Cook Inlet	\N
COI0513	Alaska	Cook Inlet	\N
PCT4896	Alaska	Cook Inlet	\N
COI0421	Alaska	Cook Inlet	\N
COI1201	Alaska	Cook Inlet	\N
COI0422	Alaska	Cook Inlet	\N
PCT4916	Alaska	Cook Inlet	\N
COI0515	Alaska	Cook Inlet	\N
PCT4926	Alaska	Cook Inlet	\N
PCT4931	Alaska	Cook Inlet	\N
COI1203	Alaska	Cook Inlet	\N
COI0420	Alaska	Cook Inlet	\N
PCT4941	Alaska	Cook Inlet	\N
PCT4946	Alaska	Cook Inlet	\N
COI0419	Alaska	Cook Inlet	\N
PCT4956	Alaska	Cook Inlet	\N
COI0511	Alaska	Cook Inlet	\N
PCT4966	Alaska	Cook Inlet	\N
PCT4971	Alaska	Cook Inlet	\N
PCT4976	Alaska	Cook Inlet	\N
PCT4981	Alaska	Cook Inlet	\N
COI0510	Alaska	Cook Inlet	\N
COI1205	Alaska	Cook Inlet	\N
COI0508	Alaska	Cook Inlet	\N
COI0509	Alaska	Cook Inlet	\N
COI0507	Alaska	Cook Inlet	\N
PCT5006	Alaska	Cook Inlet	\N
PCT5011	Alaska	Cook Inlet	\N
PCT5016	Alaska	Cook Inlet	\N
COI0506	Alaska	Cook Inlet	\N
COI0505	Alaska	Cook Inlet	\N
COI0802	Alaska	Cook Inlet	\N
COI0504	Alaska	Cook Inlet	\N
COI0801	Alaska	Cook Inlet	\N
PCT5046	Alaska	Cook Inlet	\N
COI0502	Alaska	Cook Inlet	\N
PCT5056	Alaska	Cook Inlet	\N
COI0503	Alaska	Cook Inlet	\N
PCT5066	Alaska	Cook Inlet	\N
COI1210	Alaska	Cook Inlet	\N
PCT5071	Alaska	Cook Inlet	\N
COI1204	Alaska	Cook Inlet	\N
PCT5076	Alaska	Cook Inlet	\N
PCT5081	Alaska	Cook Inlet	\N
COI1207	Alaska	Cook Inlet	\N
PCT5091	Alaska	Cook Inlet	\N
PCT5096	Alaska	Cook Inlet	\N
COI0307	Alaska	Cook Inlet	\N
COI1208	Alaska	Cook Inlet	\N
COI0306	Alaska	Cook Inlet	\N
PCT5111	Alaska	Cook Inlet	\N
COI0207	Alaska	Cook Inlet	\N
COI1209	Alaska	Cook Inlet	\N
COI0213	Alaska	Cook Inlet	\N
PCT5126	Alaska	Cook Inlet	\N
PCT5131	Alaska	Cook Inlet	\N
COI0206	Alaska	Cook Inlet	\N
PCT5141	Alaska	Cook Inlet	\N
PCT5146	Alaska	Cook Inlet	\N
PCT5151	Alaska	Cook Inlet	\N
COI0303	Alaska	Cook Inlet	\N
PCT5161	Alaska	Cook Inlet	\N
PCT5166	Alaska	Cook Inlet	\N
COI0211	Alaska	Cook Inlet	\N
COI0301	Alaska	Cook Inlet	\N
COI0302	Alaska	Cook Inlet	\N
PCT5186	Alaska	Cook Inlet	\N
KOD0944	Alaska	\N	\N
KOD0938	Alaska	\N	\N
KOD0939	Alaska	\N	\N
KOD0940	Alaska	\N	\N
KOD0937	Alaska	\N	\N
KOD0936	Alaska	\N	\N
PCT5221	Alaska	\N	\N
KOD0926	Alaska	\N	\N
KOD0925	Alaska	\N	\N
KOD0923	Alaska	\N	\N
KOD0924	Alaska	\N	\N
KOD0922	Alaska	\N	\N
KOD0921	Alaska	\N	\N
KOD0935	Alaska	\N	\N
KOD0927	Alaska	\N	Kupreanof Strait
KOD0928	Alaska	\N	Kupreanof Strait
KOD0929	Alaska	\N	Kupreanof Strait
KOD0930	Alaska	\N	Whale Passage
KOD0931	Alaska	\N	Whale Passage
KOD0932	Alaska	\N	Whale Passage
KOD0934	Alaska	\N	\N
KOD0941	Alaska	\N	Marmot Strait
KOD0942	Alaska	\N	Marmot Strait
KOD0943	Alaska	\N	Marmot Strait
KOD0933	Alaska	\N	\N
KOD0904	Alaska	\N	Chiniak Bay
KOD0905	Alaska	\N	Chiniak Bay
KOD0903	Alaska	\N	Chiniak Bay
KOD0902	Alaska	\N	Chiniak Bay
KOD0901	Alaska	\N	Chiniak Bay
KOD0906	Alaska	\N	Chiniak Bay
KOD0907	Alaska	\N	\N
KOD0910	Alaska	\N	Sitkalidak Strait
KOD0911	Alaska	\N	Sitkalidak Strait
KOD0912	Alaska	\N	Sitkalidak Strait
KOD0913	Alaska	\N	Sitkalidak Strait
KOD0915	Alaska	\N	Sitkinak Strait
KOD0914	Alaska	\N	Sitkinak Strait
KOD0916	Alaska	\N	Sitkinak Strait
KOD0919	Alaska	\N	Sitkinak Strait
KOD0918	Alaska	\N	Sitkinak Strait
KOD0917	Alaska	\N	Sitkinak Strait
KOD0920	Alaska	\N	\N
PCT5406	Alaska	Shumagin Islands	\N
PCT5411	Alaska	Shumagin Islands	\N
PCT5416	Alaska	\N	\N
PCT5421	Alaska	\N	\N
PCT5426	Alaska	\N	\N
PCT5431	Alaska	\N	\N
PCT5441	Alaska	Unimak Island	\N
UNI1901	Alaska	Isanotski Strait	\N
PCT5451	Alaska	Isanotski Strait	\N
UNI1001	Alaska	Aleutian Islands	\N
UNI1002	Alaska	Aleutian Islands	\N
UNI1004	Alaska	Aleutian Islands	\N
UNI1005	Alaska	Aleutian Islands	\N
PCT5481	Alaska	Aleutian Islands	\N
UNI1008	Alaska	Aleutian Islands	\N
UNI1007	Alaska	Aleutian Islands	\N
UNI1006	Alaska	Aleutian Islands	\N
UNI1022	Alaska	Aleutian Islands	\N
UNI1003	Alaska	Aleutian Islands	\N
PCT5511	Alaska	Aleutian Islands	\N
UNI1010	Alaska	Aleutian Islands	\N
UNI1009	Alaska	Aleutian Islands	\N
UNI1011	Alaska	Aleutian Islands	\N
UNI1021	Alaska	Aleutian Islands	\N
UNI1012	Alaska	Aleutian Islands	\N
UNI1018	Alaska	Aleutian Islands	\N
PCT5546	Alaska	Aleutian Islands	\N
UNI1020	Alaska	Aleutian Islands	\N
UNI1019	Alaska	Aleutian Islands	\N
PCT5561	Alaska	Aleutian Islands	\N
UNI1017	Alaska	Aleutian Islands	\N
UNI1023	Alaska	Aleutian Islands	\N
UNI1024	Alaska	Aleutian Islands	\N
UNI1013	Alaska	Aleutian Islands	\N
UNI1014	Alaska	Aleutian Islands	\N
UNI1015	Alaska	Aleutian Islands	\N
UNI1016	Alaska	Aleutian Islands	\N
PCT5611	Alaska	Aleutian Islands	\N
PCT5616	Alaska	Aleutian Islands	\N
PCT5621	Alaska	Aleutian Islands	\N
PCT5626	Alaska	Aleutian Islands	\N
PCT5631	Alaska	Aleutian Islands	\N
PCT5636	Alaska	Aleutian Islands	\N
PCT5641	Alaska	Aleutian Islands	\N
PCT5646	Alaska	Aleutian Islands	\N
PCT5656	Alaska	Aleutian Islands	\N
PCT5661	Alaska	Aleutian Islands	\N
PCT5666	Alaska	Aleutian Islands	\N
PCT5671	Alaska	Aleutian Islands	\N
PCT5681	Alaska	Aleutian Islands	\N
PCT5691	Alaska	Aleutian Islands	\N
PCT5721	Alaska	Aleutian Islands	\N
PCT5726	Alaska	Aleutian Islands	\N
PCT5741	Alaska	Aleutian Islands	\N
PCT5746	Alaska	Port Moller	\N
PCT5751	Alaska	Port Moller	\N
PCT5756	Alaska	Port Moller	\N
PCT5761	Alaska	\N	\N
PCT5766	Alaska	\N	\N
PCT5771	Alaska	\N	\N
PCT5776	Alaska	Kvichak Bay	\N
PCT5781	Alaska	Kvichak Bay	\N
PCT5791	Alaska	\N	\N
PCT5796	Alaska	\N	\N
PCT5801	Alaska	\N	\N
PCT5806	Alaska	\N	\N
PCT5811	Alaska	\N	\N
PCT5821	Alaska	Kuskokwim Bay	\N
PCT5826	Alaska	Kuskokwim Bay	\N
PCT5831	Alaska	Kuskokwim Bay	\N
PCT5836	Alaska	Kuskokwim Bay	\N
PCT5841	Alaska	\N	Pribilof Islands
PCT5861	Alaska	\N	Pribilof Islands
PCT5866	Alaska	\N	\N
PCT5871	Alaska	\N	\N
PCT5881	Alaska	\N	St. Lawrence Island
PCT5886	Alaska	\N	St. Lawrence Island
\.



COPY public.data_sets (index, name, station_id_context, station_id, lat, lng, timezone, country, units, min_dir, max_dir, legalese, notes, comments, source, restriction, date_imported, xfields, meridian, datumkind, datum, months_on_station, last_date_on_station, ref_index, min_time_add, min_level_add, min_level_multiply, max_time_add, max_level_add, max_level_multiply, flood_begins, ebb_begins, original_name, state) FROM stdin;
102693	Port Allen, Hanapepe Bay, Kauai Island, Hawaii	NOS	1611347	21.9033	-159.592	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT ALLEN, HANAPEPE BAY, KAUAI ISLAND	HI
102694	Nawiliwili, Nawiliwili Harbor, Kauai Island, Hawaii	NOS	1611400	21.9544	-159.3561	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nawiliwili	HI
102695	Honolulu, Honolulu Harbor, Oahu Island, Hawaii	NOS	1612340	21.30333333333334	-157.8645277777778	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Honolulu	HI
102696	Fort Kamehameha, Bishop Point, Pearl Harbor, Oahu Island, Hawaii	NOS	1612366	21.33	-157.967	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORT KAMEHAMEHA, BISHOP POINT, PEARL HBR	HI
102697	Ford Island, Pearl Harbor, Oahu Island, Hawaii	NOS	1612401	21.36750030517578	-157.96389770507812	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pearl Harbor	HI
102698	Pearl Harbor, Ford Island Ferry Dock, Oahu Island, Hawaii	NOS	1612404	21.3683	-157.94	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORD ISLAND, FERRY DOCK, PEARL HARBOR	HI
102699	Moku o Loe, Kaneohe Bay, Oahu Island, Hawaii	NOS	1612480	21.43305555555556	-157.79	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0500000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mokuoloe	HI
102700	Kaunakakai Harbor, Molokai Island, Hawaii	NOS	1613198	21.085	-157.032	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kaunakakai Harbor	HI
102701	Kahului, Kahului Harbor, Hawaii	NOS	1615680	20.89494444444445	-156.469	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1199999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kahului, Kahului Harbor	HI
102702	Kawaihae, Hawaii Island, Hawaii	NOS	1617433	20.0366	-155.8294	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9100000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kawaihae	HI
102703	Hilo, Hilo Bay, Kuhio Bay, Hawaii Island, Hawaii	NOS	1617760	19.73027777777778	-155.0555555555555	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1500000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hilo, Hilo Bay, Kuhio Bay	HI
102704	Johnston Atoll, Pacific Ocean	NOS	1619000	16.7383	-169.53	:Pacific/Johnston	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johnston Atoll	\N
102705	Sand Island, Midway Islands	NOS	1619910	28.2116667	-177.36	:Pacific/Midway	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6499999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sand Island, Midway Islands	\N
102706	Apra Harbor, Guam	NOS	1630000	13.44338888888889	144.6563611111111	:Pacific/Guam	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Apra Harbor, Guam	GU
102707	Pago Bay, Guam	NOS	1631428	13.4283333	144.7988888888889	:Pacific/Guam	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0100000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pago Bay, Guam	GU
102708	Tanapag Harbor, Saipan Island, Marianas	NOS	1633227	15.2267	145.737	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saipan	MP
102709	Pago Pago, American Samoa	NOS	1770000	-14.279999732971191	-170.69000244140625	:Pacific/Pago_Pago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3599999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pago Pago, American Samoa	AS
102710	Kwajalein, Marshall Islands	NOS	1820000	8.731666564941406	167.7361145019531	:Pacific/Kwajalein	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kwajalein, Marshall Islands	MH
102711	Chuuk, Moen Island, E. Caroline Islands, FSM	NOS	1840000	7.44667	151.847	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHUUK, MOEN ISLAND, E. CAROLINE ISLANDS	FM
102712	Malakal Harbor, Palau	NOS	1841367	7.3333001136779785	134.46670532226562	:Pacific/Palau	Palau	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.64	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Malakal Harbor, Palau Island	PW
102713	Wake Island, Pacific Ocean	NOS	1890000	19.2905556	166.6175	:Pacific/Wake	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1400000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wake Island, Pacific Ocean	MH
102714	Eastport, Passamaquoddy Bay, Maine	NOS	8410140	44.904598236083984	-66.98290252685547	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.7	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eastport	ME
102715	Coffin Point, Coffin Neck, Maine	NOS	8410714	44.87	-67.1083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COFFIN POINT, COFFIN NECK	ME
102716	Garnet Point, Hersey Neck, Pennamquan River, Cobscook Bay, Maine	NOS	8410715	44.9233	-67.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARNET POINT, HERSEY NECK	ME
102717	Pettegrove Point, Dochet Island, Maine	NOS	8410834	45.12844444444445	-67.14466666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pettegrove Point, Dochet Island	ME
102718	Gravelly Point, Whiting Bay, Maine	NOS	8410864	44.823299407958984	-67.15170288085938	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gravelly Point, Whiting Bay	ME
102719	Cutler (Farris Wharf), Little River, Maine	NOS	8411060	44.656700134277344	-67.20999908447266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cutler Farris Wharf	ME
102720	Cutler Naval Base, Machias Bay, Maine	NOS	8411250	44.6417	-67.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cutler Naval Base	ME
102721	Milbridge, Narraguagus River, Maine	NOS	8412581	44.54	-67.875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Milbridge	ME
102722	Bar Harbor, Frenchman Bay, Maine	NOS	8413320	44.39219444444444	-68.20427777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bar Harbor	ME
102723	Ellsworth, Union River, Blue Hill Bay, Maine	NOS	8413801	44.535	-68.4217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ellsworth	ME
102724	Mackerel Cove, Swans Island, Blue Hill Bay, Maine	NOS	8413825	44.16999816894531	-68.43499755859375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.46	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MACKEREL COVE, SWANS ISLAND	ME
102725	Oceanville, Deer Isle, Penobscot Bay, Maine	NOS	8414249	44.19230555555556	-68.62093055555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.289999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oceanville, Deer Isle	ME
102726	Bangor, Penobscot River, Maine	NOS	8414612	44.785	-68.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor	ME
102727	Fort Point, Penobscot River, Maine	NOS	8414721	44.4717	-68.8133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.609999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	ME
102728	Winterport, Penobscot River, Maine	NOS	8414781	44.63669967651367	-68.8416976928711	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.200000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WINTERPORT, PENOBSCOT RIVER	ME
102729	Pulpit Harbor, North Haven Island, Penobscot Bay, Maine	NOS	8414888	44.1567	-68.8867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.36	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PULPIT HARBOR, PENOBSCOT BAY	ME
102730	Rockland, Penobscot River, Maine	NOS	8415490	44.105	-69.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.329999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockland	ME
102731	Thomaston, St. George River, Maine	NOS	8415709	44.0717	-69.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.949999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thomaston	ME
102732	Walpole, Damariscotta River, Maine	NOS	8416731	43.9333	-69.58	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.050000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WALPOLE, DAMARISCOTTA RIVER	ME
102733	Wiscasset, Sheepscot River, Maine	NOS	8416921	44	-69.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.059999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wiscasset	ME
102734	Gardiner, Kennebec River, Maine	NOS	8417134	44.2333	-69.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gardiner	ME
106032	Pollock Rip Channel (Butler Hole) (depth 7 ft), Massachusetts Current	NOS	ACT1616_1	41.54999923706055	-69.9832992553711	:America/New_York	USA	knots	226	37	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pollock Rip Channel (Butler Hole)	MA
102736	Fort Popham, Hunniwell Point, Kennebec River, Maine	NOS	8417177	43.755	-69.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.59	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hunniwell Point	ME
102737	Richmond, Kennebec River, Maine	NOS	8417208	44.0883	-69.7983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9700000000000024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond	ME
102738	Bath, Kennebec River, Maine	NOS	8417227	43.925	-69.815	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bath	ME
102739	Portland, Casco Bay, Maine	NOS	8418150	43.65805555555556	-70.24416666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland	ME
102740	Pine Point, Maine	NOS	8418445	43.545	-70.3333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.759999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pine Point	ME
102741	Camp Ellis, Saco River entrance, Maine	NOS	8418606	43.4617	-70.3817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.820000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAMP ELLIS, SACO RIVER	ME
102742	Biddeford, Saco River, Maine	NOS	8418828	43.4917	-70.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.98	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIDDEFORD, SACO RIVER	ME
102743	Kennebunkport, Kennebunk River, Maine	NOS	8418911	43.3583	-70.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KENNEBUNKPORT, KENNEBUNK RIVER	ME
102744	Wells, Webhannet River, Maine	NOS	8419317	43.31999969482422	-70.56330108642578	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.77	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wells	ME
102745	Seavey Island, Portsmouth Harbor, Maine	NOS	8419870	43.0797222	-70.74111111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.460000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seavey Island	ME
102746	Dover, Cocheco River, Piscataqua River, New Hampshire	NOS	8420411	43.1983	-70.8683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9099999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOVER, COCHECO RIVER	NH
102747	Atlantic Terminals T14A, New Hampshire	NOS	8423005	43.1167	-70.8117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ATLANTIC TERMINALS  T14A	NH
102748	Fort Point, Portsmouth Harbor, New Hampshire	NOS	8423898	43.071388244628906	-70.71055603027344	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	NH
102749	Salisbury Point, Merrimack River, Massachusetts	NOS	8440273	42.8383	-70.9083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALISBURY POINT, MERRIMACK RIVER	MA
102750	Merrimacport, Merrimack River, Massachusetts	NOS	8440369	42.825	-70.9883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MERRIMACPORT, MERRIMACK RIVER	MA
102751	Plum Island, Merrimack River entrance, Merrimack River, Massachusetts	NOS	8440452	42.8167	-70.82	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLUM ISLAND, MERRIMACK  RIVER ENTRANCE	MA
102752	Newburyport, Merrimack River, Massachusetts	NOS	8440466	42.815	-70.8733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWBURYPORT, MERRIMACK RIVER	MA
102753	Riverside, Merrimack River, Massachusetts	NOS	8440889	42.7633	-71.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7800000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIVERSIDE, MERRIMACK RIVER	MA
102754	Plum Island Sound (south end), Massachusetts	NOS	8441241	42.71013888888889	-70.78861111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Island South	MA
102755	Rockport Harbor, Massachusetts	NOS	8441551	42.6583	-70.615	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.709999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ROCKPORT HARBOR	MA
102756	Annisquam, Lobster Cove, Massachusetts	NOS	8441571	42.654998779296875	-70.67669677734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.760000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LOBSTER COVE,  ANNISQUAM RIVER	MA
102757	Essex, Essex River, Massachusetts	NOS	8441771	42.6317	-70.7767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.080000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESSEX, ESSEX RIVER	MA
102758	Gloucester Harbor, Massachusetts	NOS	8441841	42.61000061035156	-70.66000366210938	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.7700000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GLOUCESTER HARBOR	MA
102759	Beverly Harbor, Beverly, Massachusetts	NOS	8442417	42.540000915527344	-70.88670349121094	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BEVERLY, BEVERLY HARBOR	MA
102760	Salem, Salem Harbor, Massachusetts	NOS	8442645	42.5233	-70.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.85	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALEM, SALEM HARBOR	MA
102761	Lynn, Lynn Harbor, Massachusetts	NOS	8443187	42.4583	-70.9433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LYNN, LYNN HARBOR	MA
102762	Amelia Earhart Dam, Mystic River, Boston Harbor, Massachusetts	NOS	8443662	42.395	-71.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.239999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AMELIA EARHART DAM, MYSTIC RIVER	MA
102763	Chelsea St. Bridge, Chelsea River, Boston Harbor, Massachusetts	NOS	8443725	42.3867	-71.0233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chelsea	MA
102764	Boston, Boston Harbor, Massachusetts	NOS	8443970	42.35388888888889	-71.05027777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.210000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston	MA
102765	Boston Light, Boston Harbor, Massachusetts	NOS	8444162	42.3283	-70.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.910000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Light	MA
102766	Nut Island, Quincy Bay, Massachusetts	NOS	8444525	42.28	-70.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.170000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nut Island	MA
102767	Shipyard Point, Weymouth Fore River, Massachusetts	NOS	8444788	42.2483	-70.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weymouth Fore River	MA
102768	Scituate, Scituate Harbor, Massachusetts	NOS	8445138	42.2017	-70.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.89	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SCITUATE, SCITUATE HARBOR	MA
102769	Brant Rock, Green Harbor River, Massachusetts	NOS	8446009	42.0833	-70.6467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.949999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BRANT ROCK, GREEN HARBOR RIVER	MA
102770	Provincetown, Cape Cod, Massachusetts	NOS	8446121	42.04959166666666	-70.18215833333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.030000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Provincetown	MA
102771	Duxbury, Duxbury Harbor, Cape Cod Bay, Massachusetts	NOS	8446166	42.0383	-70.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.489999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DUXBURY, DUXBURY HARBOR	MA
102772	Plymouth Harbor, Plymouth, Cape Cod Bay, Massachusetts	NOS	8446493	41.96	-70.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLYMOUTH, PLYMOUTH HARBOR	MA
102773	Cape Cod Canal (Sta. 115), Sagamore, Cape Cod Bay, Massachusetts	NOS	8447173	41.775	-70.535	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.41	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sagamore, Cape Cod Canal (Sta. 115)	MA
102774	Cape Cod Canal, Sandwich, Cape Cod Bay, Massachusetts	NOS	8447180	41.7717	-70.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.7	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandwich	MA
102775	Cape Cod Canal (Sta. 200), Bournedale, Cape Cod Bay, Massachusetts	NOS	8447191	41.77	-70.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bournedale, Cape Cod Canal (Sta. 200)	MA
102776	Sesuit Harbor, East Dennis, Cape Cod Bay, Massachusetts	NOS	8447241	41.7517	-70.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.220000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SESUIT HARBOR, EAST DENNIS	MA
102777	Cape Cod Canal (Sta. 320), Bourne Bridge, Cape Cod Bay, Massachusetts	NOS	8447259	41.745	-70.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bourne Bridge, Cape Cod Canal (Sta. 320)	MA
102778	Cape Cod Canal, RR. bridge, Buzzards Bay, Massachusetts	NOS	8447270	41.7417	-70.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buzzards Bay	MA
102779	Gray Gables, Buzzards Bay, Massachusetts	NOS	8447295	41.735	-70.6233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7700000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gray Gables	MA
102780	Great Hill, Buzzards Bay, Massachusetts	NOS	8447368	41.7117	-70.715	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Hill	MA
102781	Fall River, Narragansett Bay, Massachusetts	NOS	8447386	41.70429992675781	-71.16410064697266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fall River	MA
102782	Piney Point, Buzzards Bay, Massachusetts	NOS	8447416	41.695	-70.72	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piney Point	MA
102783	Chatham, Cape Cod, Massachusetts	NOS	8447435	41.688499450683594	-69.95110321044922	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.55	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chatham	MA
102784	Saquatucket Harbor, Nantucket Sound, Massachusetts	NOS	8447495	41.6683	-70.0567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAQUATUCKET HARBOR	MA
102785	Chatham, Stage Harbor, Cape Cod, Massachusetts	NOS	8447505	41.6667	-69.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHATHAM, STAGE HARBOR	MA
102786	Hyannis Port, Nantucket Sound, Massachusetts	NOS	8447605	41.6317	-70.3	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.92	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HYANNISPORT	MA
102787	New Bedford Harbor, marine terminal, Buzzards Bay, Massachusetts	NOS	8447636	41.62120056152344	-70.9136962890625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Bedford Harbor	MA
102788	Chapoquoit Point, West Falmouth Harbor, Buzzards Bay, Massachusetts	NOS	8447685	41.605	-70.6517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.85	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chappaquoit Point	MA
102789	Clarks Point, New Bedford, Buzzards Bay, Massachusetts	NOS	8447712	41.5933	-70.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW BEDFORD, CLARKS POINT	MA
102790	Round Hill Point, Buzzards Bay, Massachusetts	NOS	8447842	41.5383	-70.9283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6700000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ROUND HILL POINT	MA
102791	Woods Hole, Buzzards Bay, Massachusetts	NOS	8447930	41.52361297607422	-70.67111206054688	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.98	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woods Hole	MA
102792	Vineyard Haven Harbor, Vineyard Haven, Massachusetts	NOS	8448157	41.4583	-70.6	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VINEYARD HAVEN, VINEYARD HVN HBR	MA
102793	Penikese Island, Buzzards Bay, Massachusetts	NOS	8448248	41.45	-70.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6899999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PENIKESE ISLAND	MA
102794	Edgartown, Martha's Vineyard, Massachusetts	NOS	8448558	41.3883	-70.5117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgartown	MA
102795	Menemsha Harbor, Massachusetts	NOS	8448725	41.35444444444445	-70.76783333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Menemsha Harbor, MA	MA
102796	Martha's Vineyard GPS buoy, Martha's Vineyard, Massachusetts	NOS	8448875	41.32622222222222	-70.59033333333333	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4399999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Martha's Vineyard GPS Buoy	MA
102797	Nantucket, Nantucket Island, Massachusetts	NOS	8449130	41.28499984741211	-70.0967025756836	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nantucket Island	MA
102798	Sakonnet, Sakonnet River, Rhode Island	NOS	8450768	41.465	-71.1933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6100000000000012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAKONNET	RI
102799	Bristol Ferry, Narragansett Bay, Rhode Island	NOS	8451552	41.6367	-71.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BRISTOL FERRY	RI
102800	Bristol Highlands, Narragansett Bay, Rhode Island	NOS	8452154	41.69670104980469	-71.29329681396484	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bristol Highlands	RI
102801	Newport, Narragansett Bay, Rhode Island	NOS	8452660	41.5043333	-71.3261389	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newport	RI
102802	Conimicut Light, Narragansett Bay, Rhode Island	NOS	8452944	41.71670150756836	-71.34329986572266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Conimicut Light	RI
102803	Bay Spring, Bullock Cove, Narragansett Bay, Rhode Island	NOS	8453033	41.75170135498047	-71.35169982910156	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAY SPRING, BULLOCK COVE	RI
102804	Rumford, Seekonk River, Narragansett Bay, Rhode Island	NOS	8453433	41.84000015258789	-71.37329864501953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RUMFORD, SEEKONK RIVER	RI
102805	West Jamestown, Dutch Island Harbor, Conanicut Island, Rhode Island	NOS	8453742	41.4967	-71.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEST JAMESTOWN	RI
102806	Pawtuxet, Pawtuxet Cove, Narragansett Bay, Rhode Island	NOS	8453767	41.76169967651367	-71.38829803466797	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAWTUXET COVE, PROVIDENCE RIVER	RI
102807	Providence, State Pier No. 1, Narragansett Bay, Rhode Island	NOS	8454000	41.80716666666667	-71.40066666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Providence	RI
102808	Quonset Point, Rhode Island	NOS	8454049	41.58679962158203	-71.41100311279297	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8699999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quonset Point	RI
102809	Wickford, Narragansett Bay, Rhode Island	NOS	8454538	41.5717	-71.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8499999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WICKFORD, NARRAGANSETT BAY	RI
102810	East Greenwich, Narragansett Bay, Rhode Island	NOS	8454578	41.665000915527344	-71.44499969482422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0600000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Greenwich	RI
106033	Baltimore Harbor approach (off Sandy Point) (depth 43 ft), Maryland Current	NOS	ACT4996_1	39.01300048828125	-76.36830139160156	:America/New_York	USA	knots	189	25	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baltimore Harbor Approach (off Sandy Point)	MD
102812	Point Judith, Harbor of Refuge, Rhode Island	NOS	8455083	41.3633	-71.49	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POINT JUDITH, HARBOR OF REFUGE	RI
102813	Kickamuit River, Narragansett Bay, Rhode Island	NOS	8455137	41.707801818847656	-71.24169921875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1900000000000013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kickamuit River	RI
102814	Westerly, Pawcatuck River, Rhode Island	NOS	8455189	41.3817	-71.8317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Westerly Pawcatuck	RI
102815	Weekapaug Point, Block Island Sound, Rhode Island	NOS	8458022	41.3283	-71.7617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEEKAPAUG POINT, BLOCK ISLAND SOUND	RI
102816	Block Island (Old Harbor), Rhode Island	NOS	8459338	41.1733	-71.5567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.46	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Block Island	RI
102819	Block Island (SW end), Block Island Sound, Rhode Island	NOS	8459681	41.1633	-71.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Block Island	RI
102820	West Mystic, Mystic River, Long Island Sound, Connecticut	NOS	8460751	41.343299865722656	-71.9749984741211	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Mystic River	CT
102821	New London, Thames River, Connecticut	NOS	8461490	41.36140060424805	-72.08999633789062	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5399999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London	CT
102822	Clinton Harbor, Connecticut	NOS	8463701	41.2683	-72.5317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.469999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Harbor	CT
102823	New Haven Harbor, New Haven Reach, Connecticut	NOS	8465705	41.28329849243164	-72.9083023071289	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3299999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven	CT
102824	Bridgeport Harbor, Bridgeport, Connecticut	NOS	8467150	41.17581944444444	-73.18396944444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6199999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport	CT
102825	Black Rock Harbor, Cedar Creek, Connecticut	NOS	8467373	41.1567	-73.2133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.630000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Black Rock Harbor	CT
102826	Southport, Southport Harbor, Connecticut	NOS	8467726	41.1333	-73.2833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.669999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport, Southport Harbor	CT
102827	Saugatuck, Saugatuck River, Long Island Sound, Connecticut	NOS	8468191	41.119998931884766	-73.36830139160156	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7600000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saugatuck River	CT
102828	South Norwalk, Norwalk River, Connecticut	NOS	8468448	41.0967	-73.415	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8099999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Norwalk	CT
102829	Long Neck Point, Long Island Sound, Connecticut	NOS	8468799	41.0383	-73.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.82	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG NECK POINT, LONG ISLAND SOUND	CT
102830	Mianus, Connecticut	NOS	8469057	41.039194	-73.592028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mianus	CT
102817	Vails Beach, Block Is. Sound, Rhode Island	NOS	8459449	41.1483	-71.575	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VAILS BEACH, BLOCK IS. SOUND	RI
102831	Stamford Harbor, Stamford, Connecticut	NOS	8469198	41.0383	-73.5467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8499999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stamford Harbor	CT
102833	Lake Montauk, Long Island, New York	NOS	8510448	41.0733	-71.935	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1800000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Montauk	NY
102834	Montauk, Fort Pond Bay, Long Island Sound, New York	NOS	8510560	41.0483333	-71.9594444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2399999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montauk	NY
102835	Silver Eel Pond, Fishers Island, New York	NOS	8510719	41.2567	-72.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4200000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Silver Eel Pond	NY
102837	Plum Gut Harbor, Plum Island, Long Island, New York	NOS	8511236	41.1717	-72.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5200000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLUM ISLAND  PLUM GUT HARBOR	NY
102838	Sag Harbor, Shelter Island Sound, New York	NOS	8511629	41.0033	-72.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sag Harbor	NY
102839	Orient Harbor, Orient, Shelter Island Sound, New York	NOS	8511671	41.1367	-72.3067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orient Harbor	NY
102840	Greenport, Shelter Island Sound, New York	NOS	8511907	41.101	-72.36116666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4499999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Greenport	NY
102841	Shinnecock Inlet (ocean), Long Island, New York	NOS	8512354	40.8367	-72.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.610000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHINNECOCK INLET OPEN COAST	NY
102842	Ponquoque Point, Shinnecock Bay, New York	NOS	8512451	40.85	-72.5033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5200000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PONQUOGUE POINT	NY
102843	Mattituck Inlet, Long Island Sound, New York	NOS	8512668	41.01499938964844	-72.56169891357422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.710000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mattituck Inlet, Long Island	NY
102844	South Jamesport, Great Peconic Bay, New York	NOS	8512735	40.935	-72.5817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6400000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Jamesport	NY
102845	Shinnecock Yacht Club, Penniman Creek, Shinnecock Bay, New York	NOS	8512769	40.81855555555556	-72.58661111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHINNECOCK YACHT CLUB, PENNIMAN CREEK	NY
102846	Northville, Long Island, New York	NOS	8512987	40.9817	-72.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northville	NY
102847	Moriches USCG station, Long Island, New York	NOS	8513388	40.7867	-72.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moriches CGS, Moriches Bay	NY
102848	Moriches Inlet, Long Island, New York	NOS	8513398	40.76441666666667	-72.75597222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.620000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moriches Inlet	NY
102849	Smith Point Bridge, Narrow Bay, Long Island, New York	NOS	8513825	40.7383	-72.8683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SMITH POINT BRIDGE, NARROW BAY	NY
102850	Patchogue, Patchogue River, Great South Bay, New York	NOS	8514322	40.75	-73	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PATCHOGUE, PATCHOGUE RIVER	NY
102851	Cedar Beach, Long Island, New York	NOS	8514422	40.965	-73.0433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CEDAR BEACH	NY
102852	Port Jefferson, Long Island, New York	NOS	8514560	40.95000076293945	-73.07669830322266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT JEFFERSON	NY
102853	Seaview Ferry Dock, Great South Bay, New York	NOS	8514779	40.64925	-73.15061111111112	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seaview Ferry Dock	NY
102836	Threemile Harbor entrance, Gardiners Bay, Long Island, New York	NOS	8511171	41.035	-72.19	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.34	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THREEMILE HARBOR ENTRANCE	NY
102854	Fire Island USCG station, Great South Bay, New York	NOS	8515186	40.6267	-73.26	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island	NY
102855	Northport, Northport Bay, Long Island, New York	NOS	8515586	40.9	-73.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8699999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTHPORT, NORTHPORT BAY	NY
102856	Eatons Neck Point, Long Island, New York	NOS	8515786	40.9533	-73.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck	NY
102857	Huntington Harbor Lighthouse, Huntington Bay, Long Island, New York	NOS	8515921	40.91	-73.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LLOYD HARBOR LIGHTHOUSE	NY
102858	Cold Spring Harbor, Oyster Bay, New York	NOS	8516061	40.87329864501953	-73.47000122070312	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COLD SPRING HARBOR	NY
102859	Green Island, Hempstead Bay, New York	NOS	8516155	40.6233	-73.5017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.759999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GREEN ISLAND	NY
102860	Bayville Bridge, Oyster Bay, New York	NOS	8516299	40.9033	-73.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYVILLE BRIDGE, OYSTER BAY	NY
102861	Point Lookout, Long Island, New York	NOS	8516402	40.59388888888889	-73.58397222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.240000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Lookout	NY
102862	Parsonnage Cove, Long Island, New York	NOS	8516501	40.6333	-73.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.419999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parsonnage Cove	NY
102863	Harry Tappen Marina, Hempstead Harbor, Long Island, New York	NOS	8516607	40.83461111111111	-73.65241666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harry Tappen Marina	NY
102864	Glen Cove Yacht Club, Hempstead Harbor, Long Island, New York	NOS	8516614	40.8633	-73.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GLEN COVE YACHT CLUB, LONG ISLAND	NY
102865	Bay Park, East Rockaway, Hewlett Bay, New York	NOS	8516661	40.63	-73.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5600000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Park, NY	NY
102866	Long Beach (Bridgeview Yacht Club), New York	NOS	8516663	40.59633333333333	-73.65508333333334	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4400000000000013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG BEACH, NEW YORK	NY
102867	Port Washington, Manhasset Bay, Long Island, New York	NOS	8516761	40.8317	-73.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT WASHINGTON, MANHASSSET BAY	NY
102868	Atlantic Beach, East Rockaway Inlet, Long Island, New York	NOS	8516881	40.595	-73.7433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic Beach	NY
102869	Norton Point, Head of Bay, Jamaica Bay, New York	NOS	8516891	40.635	-73.7467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTON POINT, HOOK CREEK, NEW YORK	NY
102870	Kings Point, Long Island Sound, New York	NOS	8516945	40.810298919677734	-73.76490020751953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.889999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kings Point	NY
102871	Willets Point, Little Bay, East River, New York	NOS	8516990	40.7933	-73.7817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Willets Point	NY
102872	Beach Channel (bridge), Jamaica Bay, New York	NOS	8517137	40.5883	-73.82	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beach Channel	NY
102873	North Channel Bridge, Grassy Bay, Jamaica Bay, New York	NOS	8517201	40.645	-73.8367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0299999999999976	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Channel	NY
106034	Charleston Harbor (off Fort Sumter) (depth 5 ft), South Carolina Current	NOS	ACT6651_1	32.75600051879883	-79.87030029296875	:America/New_York	USA	knots	127	313	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston Harbor (off Fort Sumter)	SC
102876	Kingsborough Community College, Sheepshead Bay, Long Island, New York	NOS	8517756	40.581199645996094	-73.93379974365234	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6499999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingsborough CC	NY
102877	Brooklyn Bridge, East River, New York	NOS	8517847	40.7033	-73.995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Bridge	NY
102878	Rye Beach (Amusement Park), New York	NOS	8518091	40.9617	-73.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RYE BEACH, AMUSEMENT PARK	NY
102879	Throgs Neck, New York	NOS	8518526	40.805	-73.795	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Throgs Neck	NY
102880	Port Morris (Stony Point), East River, New York	NOS	8518639	40.8017	-73.9067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Morris	NY
102881	Harlem River, Randalls Island, East River, New York	NOS	8518643	40.8	-73.9283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Randalls Island	NY
102882	Horns Hook, East 90th Street, East River, New York, New York	NOS	8518668	40.7767	-73.9417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5299999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horns Hook	NY
102883	Queensboro Bridge, East River, New York	NOS	8518687	40.7583	-73.9583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Queensboro Bridge	NY
102884	Williamsburg Bridge, East River, New York	NOS	8518699	40.7117	-73.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Williamsburg Bridge	NY
102885	The Battery, New York Harbor, New York	NOS	8518750	40.7005556	-74.0141667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Battery	NY
102886	Ferry Slip, Dyckman Street, Hudson River, New York	NOS	8518902	40.8683	-73.9333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dyckman Street	NY
106035	Savannah River entrance (between jetties) (depth 11 ft), South Carolina Current	NOS	ACT7351_1	32.035701751708984	-80.89029693603516	:America/New_York	USA	knots	110	286	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Savannah River Entrance (between jetties)	SC
102889	Haverstraw Bay, Hudson River, New York	NOS	8518924	41.2183	-73.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HAVERSTRAW BAY	NY
102890	Beacon, Flushkill, Hudson River, New York	NOS	8518934	41.5	-73.9833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beacon, Hudson River	NY
102891	Hyde Park, Hudson River, New York	NOS	8518951	41.7833	-73.95	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.009999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hyde Park	NY
102892	Turkey Point Hudson River NERRS, Hudson River, New York	NOS	8518962	42.01390075683594	-73.93920135498047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turkey Point, Hudson River NERRS	NY
102893	Albany, Hudson River, New York	NOS	8518995	42.65	-73.7467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ALBANY, HUDSON RIVER	NY
106287	Hog Neck (depth 15 ft), Buzzards Bay, Massachusetts Current	NOS	COD0905_5	41.72389	-70.63938	:America/New_York	USA	knots	209	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.105	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hog Neck	MA
102895	USCG station, The Narrows, New York	NOS	8519050	40.612	-74.0598611111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG Station NY	NY
102896	Great Kills Harbor, New York	NOS	8519436	40.5433	-74.14	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.729999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Kills Harbor	NY
102897	Bayonne Bridge, Bergen Point West Reach, New York	NOS	8519483	40.63911111111111	-74.14630555555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bergen Point West Reach	NY
102898	Port Elizabeth, New Jersey	NOS	8530882	40.6733	-74.14	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT ELIZABETH, NEWARK BAY	NJ
102899	Port Reading, Arthur Kill, New Jersey	NOS	8531142	40.55500030517578	-74.24500274658203	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Reading	NJ
102888	Riverdale, Hudson River, New York	NOS	8518905	40.9033	-73.9167	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIVERDALE, HUDSON RIVER	NY
102900	Cheesequake Creek, Garden State Parkway, New Jersey	NOS	8531223	40.4533	-74.2733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHEESEQUAKE CREEK	NJ
106036	Tampa Bay entrance (Egmont Channel) (depth 15 ft), Florida Current	NOS	ACT8411_1	27.604299545288086	-82.76029968261719	:America/New_York	USA	knots	298	120	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tampa Bay Entrance (Egmont Channel)	FL
102902	Keasbey, Raritan River, New Jersey	NOS	8531262	40.50830078125	-74.31169891357422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.86	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEASBEY, RARITAN RIVER	NJ
102903	Old Bridge, South River, Raritan River, New Jersey	NOS	8531369	40.41669845581055	-74.36329650878906	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH OLD BRIDGE, SOUTH RIVER	NJ
102904	Sayreville, Raritan River, New Jersey	NOS	8531390	40.47829818725586	-74.35669708251953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAYREVILLE, RARITAN RIVER	NJ
102905	New Brunswick, Raritan River, New Jersey	NOS	8531463	40.48830032348633	-74.43499755859375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW BRUNSWICK  RARITAN RIVER	NJ
102906	Sandy Hook, Fort Hancock, New Jersey	NOS	8531680	40.46689987182617	-74.0093994140625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandy Hook	NJ
102907	Sea Bright, Shrewsbury River, New Jersey	NOS	8531804	40.365	-73.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Bright	NJ
102908	Toms River (town), Toms River, Barnegat Bay, New Jersey	NOS	8533051	39.95000076293945	-74.19830322265625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Toms River	NJ
102909	Stouts Creek, Barnegat Bay, New Jersey	NOS	8533365	39.845001220703125	-74.15170288085938	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.44000000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stouts Creek	NJ
102910	Barnegat Inlet, USCG station, Barnegat Bay, New Jersey	NOS	8533615	39.7617	-74.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BARNEGAT INLET (INSIDE)	NJ
102911	Shooting Thorofare, Little Egg Inlet, Great Bay, New Jersey	NOS	8534319	39.50830078125	-74.32499694824219	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01409335.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.55	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GREAT BAY, SHOOTING THOROFARE	NJ
102912	Mays Landing, Great Egg Harbor River, New Jersey	NOS	8534468	39.4483	-74.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MAYS LANDING, GREAT EGG HARBOR RIVER	NJ
102913	Atlantic City, New Jersey	NOS	8534720	39.356666564941406	-74.41805267333984	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic City	NJ
102914	Ventnor City, ocean pier, New Jersey	NOS	8534770	39.335	-74.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENTNOR CITY, FISHING PIER	NJ
102915	Steelmanville, Patcong Ck., 2.5 nmi above ent., Great Egg Harbor Bay, New Jersey	NOS	8534778	39.334999084472656	-74.5967025756836	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	STEELMANVILLE, PATCONG RIVER	NJ
102916	Longport, Risely Channel, New Jersey	NOS	8534836	39.3083	-74.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0300000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONGPORT, RISELY CHANNEL	NJ
102917	Tuckahoe, Tuckahoe River, Great Egg Harbor Bay, New Jersey	NOS	8534883	39.295	-74.7483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TUCKAHOE,TUCKAHOE RIVER	NJ
102918	Bivalve, Maurice River, Delaware Bay, New Jersey	NOS	8535055	39.23249816894531	-75.03279876708984	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01412150.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1300000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bivalve, Maurice River	NJ
102919	Ocean Drive bridge, Townsends Inlet, New Jersey	NOS	8535375	39.1217	-74.7167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1999999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Townsend Inlet	NJ
102920	Ingram Thorofare, Townsends Inlet, New Jersey	NOS	8535419	39.11	-74.7383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ingram Thorofare	NJ
102921	Stone Harbor, Great Channel, Hereford Inlet, New Jersey	NOS	8535581	39.05670166015625	-74.76499938964844	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01411360.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	STONE HARBOR, GREAT CHANNEL	NJ
102922	Wildwood Crest, ocean pier, New Jersey	NOS	8535835	38.975	-74.8233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WILDWOOD CREST	NJ
102923	Cape May Canal, Cape May, Delaware Bay, New Jersey	NOS	8536110	38.968299865722656	-74.95999908447266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May	NJ
102924	Bidwell Creek entrance, Delaware Bay, New Jersey	NOS	8536581	39.1283	-74.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIDWELL CREEK ENTRANCE, DELAWARE BAY	NJ
102925	Fortescue Creek, New Jersey	NOS	8536931	39.2383	-75.175	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORTESCUE CREEK	NJ
102926	Ship John Shoal, Delaware River, New Jersey	NOS	8537121	39.30538888888889	-75.37667777777777	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0400000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship John Shoal	NJ
102927	Paulsboro, Mantua Creek, New Jersey	NOS	8538512	39.835	-75.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.2600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAULSBORO, MANTUA CREEK	NJ
102928	Tacony-Palmyra Bridge, New Jersey	NOS	8538886	40.01194	-75.04299999978807	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6400000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tacony-Palmyra Bridge	NJ
102929	Burlington, Delaware River, New Jersey	NOS	8539094	40.08169937133789	-74.86969757080078	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9899999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burlington, Delaware River	NJ
102930	Fieldsboro, Delaware River, New Jersey	NOS	8539487	40.1367	-74.7367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FIELDSBORO, DELAWARE RIVER	NJ
102931	Trenton Marine Terminal, Trenton, New Jersey	NOS	8539993	40.1883	-74.755	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.470000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TRENTON MARINE TERMINAL	NJ
102932	Marcus Hook, Pennsylvania	NOS	8540433	39.81180555555556	-75.4095	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1400000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marcus Hook	PA
102933	Philadelphia (USCG station), Delaware River, Pennsylvania	NOS	8545240	39.93305555555556	-75.14198055555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4899999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Philadelphia	PA
102934	Philadelphia, Municipal Pier 11, Pennsylvania	NOS	8545530	39.9533	-75.1383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PHILADELPHIA (PIER 11 NORTH), DEL. RIVER	PA
102935	Bridesburg, Philadelphia, Pennsylvania	NOS	8546252	39.97968333333333	-75.07931666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.59	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridesburg	PA
102936	Newbold, Delaware River, Pennsylvania	NOS	8548989	40.13733333333333	-74.75183333333334	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newbold	PA
102937	Delaware City, Delaware River, Delaware	NOS	8551762	39.58219444444445	-75.58897222222222	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.950000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware City	DE
102938	Reedy Point, C&D Canal, Delaware	NOS	8551910	39.5583333	-75.5719444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9199999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Point	DE
102939	Mahon River entrance, Delaware Bay, Delaware	NOS	8554399	39.185	-75.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mahon River Entrance	DE
102940	Brandywine Shoal Light, Delaware Bay, New Jersey	NOS	8555889	38.98666666666667	-75.11333333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.610000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Shoal Light	NJ
102941	Lewes, Fort Miles, Delaware	NOS	8557380	38.78283333333334	-75.11927777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lewes	DE
102942	Inlet (USCG station), Indian River, Delaware	NOS	8558690	38.61	-75.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	INDIAN RIVER INLET	DE
102943	Rosedale Beach, Indian River, Delaware	NOS	8558814	38.59149932861328	-75.21160125732422	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01484540.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.64	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosedale Beach, Indian River	DE
102944	Little Assawoman Bay, Delaware	NOS	8559957	38.45500183105469	-75.05829620361328	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01484701.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Little Assawoman Bay	DE
102945	Ocean City (fishing pier), Maryland	NOS	8570280	38.3267	-75.0833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN CITY, FISHING PIER	MD
102946	Ocean City Inlet, Maryland	NOS	8570283	38.32833	-75.09166666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocean City Inlet	MD
102947	South Point, Sinepuxent Neck, Chincoteague Bay, Maryland	NOS	8570536	38.215	-75.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH POINT, SINEPUXENT NECK, CHINC. BAY	MD
102948	Public Landing, Chincoteague Bay, Maryland	NOS	8570649	38.1483	-75.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUBLIC LANDING, CHINCOTEAGUE BAY	MD
102949	Buntings Bridge, Chincoteague Bay, Maryland	NOS	8570691	38.13894444444445	-75.18352777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buntings Bridge	MD
102950	Crisfield, Little Annemessex River, Chesapeake Bay, Maryland	NOS	8571091	37.9767	-75.8633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRISFIELD	MD
102951	Ewell, Smith Island, Chesapeake Bay, Maryland	NOS	8571117	37.995	-76.0317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9400000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ewell, Smith Island	MD
102952	Snow Hill, city park, Pocomoke River, Maryland	NOS	8571359	38.17833	-75.39666666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Hill	MD
102953	Bishops Head, Hooper Strait, Maryland	NOS	8571421	38.22	-76.0383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bishops Head	MD
102954	McCready's Creek, Fishing Bay, Chesapeake Bay, Maryland	NOS	8571559	38.3	-76.005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	McCready's Creek	MD
102955	Barren Island, Chesapeake Bay, Maryland	NOS	8571579	38.3417	-76.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barren Island	MD
102956	Salisbury, Wicomico River, Maryland	NOS	8571616	38.3650016784668	-75.60669708251953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALISBURY, WICOMICO RIVER	MD
102957	Smithville Road Bridge, Beaverdam Creek, Little Choptank River, Maryland	NOS	8571702	38.42833	-76.23666666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beaverdam Creek	MD
102958	Vienna, Nanticoke River, Maryland	NOS	8571773	38.48333	-75.81833333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vienna	MD
102959	Sharptown, Nanticoke River, Maryland	NOS	8571858	38.54499816894531	-75.72329711914062	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01488110.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHARPSTOWN, NANTICOKE RIVER	MD
102960	Cambridge, Choptank River, Maryland	NOS	8571892	38.5725	-76.0616667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cambridge	MD
102961	Poplar Island, Chesapeake Bay, Maryland	NOS	8572271	38.75833333333333	-76.375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.78	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Poplar Island	MD
102963	Kent Point Marina, Chesapeake Bay, Maryland	NOS	8572467	38.8367	-76.3733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kent Point	MD
102964	Hillsboro, Tuckahoe Creek, Maryland	NOS	8572669	38.9167	-75.945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4600000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hillsboro	MD
102965	Matapeake, Kent Island, Chesapeake Bay, Maryland	NOS	8572770	38.9567	-76.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matapeake	MD
102966	Love Point, Chester River, Maryland	NOS	8572955	39.0317	-76.3017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Love Point Pier	MD
102967	Crumpton, Chester River, Maryland	NOS	8573349	39.245	-75.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crumpton	MD
102968	Tolchester Beach, Chesapeake Bay, Maryland	NOS	8573364	39.21344444444444	-76.24455555555555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tolchester Beach	MD
102969	Sassafras River, Betterton, Chesapeake Bay, Maryland	NOS	8573704	39.3717	-76.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Betterton	MD
102970	Town Point Wharf, Elk River, Maryland	NOS	8573903	39.5033	-75.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TOWN POINT WHARF	MD
102971	Chesapeake City, Chesapeake and Delaware Canal, Maryland	NOS	8573927	39.5266667	-75.81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake City	MD
102972	Havre de Grace, Susquehanna River, Maryland	NOS	8574070	39.5367	-76.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Havre De Grace	MD
102973	Pond Point (Aberdeen P.G.), Bush River, Chesapeake Bay, Maryland	NOS	8574459	39.3883	-76.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POND POINT (ABERDEEN P.G.), BUSH RIVER	MD
102974	Baltimore (Fort McHenry), Maryland	NOS	8574680	39.266700744628906	-76.57830047607422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baltimore	MD
102975	Fort McHenry Marsh, Patapsco River, Maryland	NOS	8574683	39.2617	-76.585	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort McHenry Marsh	MD
102976	Annapolis (US Naval Academy), Severn River, Maryland	NOS	8575512	38.983299255371094	-76.48159790039062	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Annapolis	MD
102977	Long Beach, Chesapeake Bay, Maryland	NOS	8577004	38.465	-76.4733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Long Beach	MD
102978	Cove Point, Chesapeake Bay, Maryland	NOS	8577188	38.3917	-76.3983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COVE POINT	MD
102979	Solomons Island, Patuxent River, Maryland	NOS	8577330	38.31669998168945	-76.45169830322266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Solomons Island	MD
102980	Lower Marlboro, Patuxent River, Maryland	NOS	8579542	38.655	-76.68333333333334	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1099999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Marlboro	MD
102981	Bladensburg, Anacostia River, Maryland	NOS	8579997	38.9333	-76.9383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.63	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLADENSBURG, ANACOSTIA RIVER	MD
102982	Washington, Potomac River, DC	NOS	8594900	38.87333333333334	-77.02166666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Washington	DC
102983	Jesters Island, Virginia	NOS	8630111	37.9817008972168	-75.30169677734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	JESTERS ISLAND, CHINCOTEAGUE BAY	VA
102984	Chincoteague Island, USCG station, Virginia	NOS	8630249	37.93170166015625	-75.38330078125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINCOTEAGUE, USCG STATION	VA
102985	Chincoteague Channel (south end), Chincoteague Bay, Virginia	NOS	8630308	37.9067	-75.405	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1700000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINCOTEAGUE CHANNEL, SOUTH END	VA
102986	Southern Chincoteague Island, Chincoteague Bay, Virginia	NOS	8630315	37.902400970458984	-75.40789794921875	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01484746.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.63	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southern Chincoteague Island	VA
102987	Wachapreague, Wachapreague Channel, Virginia	NOS	8631044	37.60777777777778	-75.68583333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wachapreague	VA
102988	Kiptopeke Beach, Chesapeake Bay, Virginia	NOS	8632200	37.165199279785156	-75.9884033203125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kiptopeke	VA
106037	Galveston Bay ent. (between jetties) (depth 15 ft), Texas Current	NOS	ACT8851_2	29.34869956970215	-94.71420288085938	:America/Chicago	USA	knots	88	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Bay Ent. (between jetties)	TX
102990	Rappahannock Light, Virginia	NOS	8632837	37.5383	-76.015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9399999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rappahannock Light	VA
102991	Gaskins Point, Occohannock Creek, Chesapeake Bay, Virginia	NOS	8632869	37.5567	-75.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GASKINS PT., OCCOHANNOCK CREEK	VA
102992	Tangier Island, Chesapeake Bay, Virginia	NOS	8633532	37.8283	-75.9933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8499999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tangier Island	VA
102993	Saxis, Starling Creek, Pocomoke Sound, Chesapeake Bay, Virginia	NOS	8633777	37.92169952392578	-75.72830200195312	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAXIS, STARLING CREEK	VA
102994	Dahlgren, Upper Machodoc Creek, Potomac River, Virginia	NOS	8635027	38.31975277777778	-77.03659722222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9399999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dahlgren	VA
102995	Colonial Beach, Potomac River, Virginia	NOS	8635150	38.2517	-76.96	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Colonial Beach, Potomac River	VA
102996	Rappahannock Bend, Virginia	NOS	8635257	38.2133	-77.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rappahannock Bend	VA
102997	Lewisetta, Potomac River, Virginia	NOS	8635750	37.99610137939453	-76.46440124511719	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lewisetta	VA
102998	Wares Wharf, Rappahannock River, Virginia	NOS	8635985	37.8733	-76.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wares Wharf	VA
102999	Windmill Point, Rappahannock River, Virginia	NOS	8636580	37.6155	-76.28977777777777	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Windmill Point	VA
103000	Lester Manor, Pamunkey River, Virginia	NOS	8636653	37.5833	-76.99	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lester Manor	VA
103001	Richmond Deepwater Terminal, James River, Virginia	NOS	8636941	37.45955555555555	-77.42077777777777	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond Deepwater Terminal, James River	VA
103004	Gloucester Point, York River, Virginia	NOS	8637624	37.2467	-76.5	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2900000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gloucester Point	VA
103005	Yorktown USCG Training Center, York River, Virginia	NOS	8637689	37.2265	-76.47880555555555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yorktown USCG Training Center	VA
103028	Roanoke Marshes Light, Pamlico Sound, North Carolina	NOS	8652547	35.8117	-75.7	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roanoke Marshes Light	NC
103003	New Point (Comfort Shoal), Virginia	NOS	8637590	37.2567	-76.2217	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW POINT, COMFORT SHOAL	VA
103006	Jamestown Wharf, Jamestown, Virginia	NOS	8637712	37.22010040283203	-76.79139709472656	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=02042770.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jamestown	VA
103007	Fort Eustis (MARAD), James River, Virginia	NOS	8638017	37.13822222222223	-76.62275	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2799999999999976	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORT EUSTIS (MARAD), JAMES RIVER	VA
103008	Western Branch, Elizabeth River, Virginia	NOS	8638339	36.82322222222222	-76.39911111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5400000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Western Branch	VA
106038	Bolivar Roads (depth 14 ft), Galveston Bay, Texas Current	NOS	ACT8856_2	29.343299865722656	-94.78130340576172	:America/Chicago	USA	knots	123	296	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bolivar Roads	TX
103010	Kingsmill, James River, Virginia	NOS	8638424	37.22	-76.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2799999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingsmill	VA
103011	Scotland, James River, Virginia	NOS	8638433	37.185	-76.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1500000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scotland	VA
103012	Lanexa, Chickahominy River, Virginia	NOS	8638445	37.4033	-76.9117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lanexa, Chickahominy River	VA
103013	Tettington, James River, Virginia	NOS	8638450	37.24	-76.9433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.129999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tettington, James River	VA
103014	Willcox Wharf, Charles City, James River, Virginia	NOS	8638464	37.315	-77.0983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3099999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilcox Wharf	VA
103015	Hopewell, City Point, James River, Virginia	NOS	8638481	37.3133	-77.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hopewell	VA
103016	Puddledock Sand & Gravel, Appomattox River, Virginia	NOS	8638489	37.2667	-77.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puddledock	VA
103017	Richmond River Locks, James River, Virginia	NOS	8638495	37.525	-77.42	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond River Locks, James River	VA
103018	Sewells Point, Hampton Roads, Virginia	NOS	8638610	36.9427778	-76.3286111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sewells Point	VA
103019	Portsmouth, Naval Shipyard, Elizabeth River, Virginia	NOS	8638660	36.8217	-76.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5299999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORTSMOUTH, NORFOLK NAVAL SHIPYARD	VA
103020	Lafayette River, Virginia	NOS	8638671	36.88422222222222	-76.27585833333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lafayette River	VA
103021	Chesapeake Bay Bridge-Tunnel, Virginia	NOS	8638863	36.96670150756836	-76.11329650878906	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4200000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Bridge Tunnel	VA
103022	Chesapeake Bay Bridge-Tunnel, Chesapeake Bay, Virginia	NOS	8638901	37.032901763916016	-76.08329772949219	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CBBT, Chesapeake Channel	VA
103023	Inside channel, Rudee Inlet, Virginia	NOS	8639207	36.8317	-75.9733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8000000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rudee Inlet	VA
103024	Money Point, South Bridge, Elizabeth River, Virginia	NOS	8639348	36.77819444444445	-76.30186111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Money Point	VA
103025	FRF Pier, Duck, North Carolina	NOS	8651370	36.18330001831055	-75.74669647216797	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7700000000000031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Duck	NC
103026	Manns Harbor, Croatan Sound, North Carolina	NOS	8652247	35.9033	-75.77	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.21999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Manns Harbor	NC
103027	Oyster Creek, Croatan Sound, North Carolina	NOS	8652437	35.845	-75.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.31000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oyster Creek	NC
103029	Oregon Inlet Marina, Pamlico Sound, North Carolina	NOS	8652587	35.79569444444444	-75.54819444444445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5800000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oregon Inlet Marina	NC
103030	Old House Channel, Pamlico Sound, North Carolina	NOS	8652648	35.77669906616211	-75.58499908447266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.45999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old House Channel	NC
103031	Oregon Inlet (USCG station), North Carolina	NOS	8652678	35.7683	-75.5267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG LIFEBOAT STATION, OREGON INLET	NC
103032	Rodanthe, Pamlico Sound, North Carolina	NOS	8653215	35.595001220703125	-75.4717025756836	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.42000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RODANTHE, PAMLICO SOUND	NC
106039	Vieques Passage (depth 5 ft), Puerto Rico Current	NOS	ACT8926_1	18.18829917907715	-65.61830139160156	:America/Puerto_Rico	USA	knots	57	250	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vieques Passage	PR
103034	Engelhard, Pamlico Sound, North Carolina	NOS	8653471	35.5093994140625	-75.98889923095703	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Engelhard	NC
103035	Avon Seafood dock, Peter's Ditch, Avon, North Carolina	NOS	8653951	35.35013888888889	-75.51202777777777	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.28999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peter's Ditch	NC
103036	Cape Hatteras (fishing pier), North Carolina	NOS	8654400	35.2233	-75.635	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6199999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Hatteras Fishing Pier	NC
103037	Hatteras (USCG station), North Carolina	NOS	8654467	35.20861111111111	-75.70419444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG Station Hatteras	NC
103038	Ocracoke, Pamlico Sound, North Carolina	NOS	8654769	35.115501403808594	-75.98690032958984	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.45999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocracoke, Pamlico Sound	NC
103039	Ocracoke, Ocracoke Island, North Carolina	NOS	8654792	35.115	-75.9883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCRACOKE ISLAND	NC
103040	Oriental, Neuse River, North Carolina	NOS	8655133	35.024600982666016	-76.69180297851562	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ORIENTAL, NEUSE RIVER	NC
103041	Cedar Island, Pamlico Sound, North Carolina	NOS	8655151	35.01890182495117	-76.31430053710938	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CEDAR ISLAND	NC
103042	Sea Level, Core Sound, North Carolina	NOS	8655875	34.875	-76.3433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Level	NC
103043	Core Creek Bridge, North Carolina	NOS	8656084	34.82500076293945	-76.69000244140625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1199999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CORE CREEK BRIDGE	NC
103044	Davis, Core Sound, North Carolina	NOS	8656201	34.79679870605469	-76.45549774169922	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6300000000000026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Davis, Core Sound	NC
103045	Spooner Creek, Bogue Sound, North Carolina	NOS	8656467	34.725	-76.8033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spooners Creek	NC
103046	Duke Marine Lab, Beaufort, North Carolina	NOS	8656483	34.71733055555556	-76.67065833333334	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beaufort, Duke Marine Lab	NC
103047	Morehead City Harbor, North Carolina	NOS	8656502	34.720001220703125	-76.71080017089844	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MOREHEAD CITY HARBOR, HARBOR CHANNEL	NC
103048	Triple S Pier, Atlantic Beach, North Carolina	NOS	8656590	34.6933	-76.7117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic Beach Triple S Pier	NC
103049	Swansboro, East Corbett Ave. Bridge, North Carolina	NOS	8656613	34.68659973144531	-77.11810302734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Swansboro, East Corbett Ave Bridge	NC
103050	Cape Lookout Bight, North Carolina	NOS	8656841	34.6133	-76.5383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE LOOKOUT, LOOKOUT BIGHT	NC
103051	Sneads Ferry, New River, North Carolina	NOS	8657002	34.57630157470703	-77.39540100097656	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sneads Ferry, New River	NC
103052	Hampstead, ICWW, North Carolina	NOS	8657813	34.33940124511719	-77.70600128173828	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.860000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hampstead	NC
103053	Wilmington, North Carolina	NOS	8658120	34.2275	-77.9536111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilmington	NC
103054	Shinn Point, ICWW, North Carolina	NOS	8658145	34.217899322509766	-77.81230163574219	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1400000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shinn Point	NC
103055	Wrightsville Beach, North Carolina	NOS	8658163	34.21330555555556	-77.78669444444445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.150000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrightsville Beach	NC
103056	Wharf 3, MOTSU, Cape Fear River, North Carolina	NOS	8658579	34.0233	-77.9467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SUNNY POINT, MOTSU NORTH WHARF	NC
103057	Zekes Island, Cape Fear River, North Carolina	NOS	8658741	33.95	-77.9517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZEKES ISLAND, CAPE FEAR RIVER	NC
103058	Southport, Cape Fear River, North Carolina	NOS	8659084	33.915	-78.0183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport	NC
103059	Oak Island, Yaupon Beach, North Carolina	NOS	8659182	33.9017	-78.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5400000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oak Island, Atlantic Ocean	NC
103060	Varnamtown, Lockwoods Folly River, North Carolina	NOS	8659414	33.933101654052734	-78.21890258789062	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.150000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Varnamtown, Lockwoods Folly River	NC
103061	Shallotte Inlet (Bowen Point), North Carolina	NOS	8659665	33.915000915527344	-78.37329864501953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2600000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOWEN POINT, SHALLOTTE INLET	NC
103062	Sunset Beach Pier, North Carolina	NOS	8659897	33.865	-78.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunset Beach	NC
103063	Carolina Forest, ICWW, South Carolina	NOS	8660754	33.734901428222656	-78.88269805908203	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carolina Forest	SC
103064	Springmaid Pier, Springmaid Beach, South Carolina	NOS	8661070	33.654998779296875	-78.91829681396484	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.710000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Springmaid Pier	SC
103065	Bucksport, Waccamaw River, South Carolina	NOS	8661139	33.6467	-79.095	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUCKSPORT, WACCAMAW RIVER	SC
103066	Garden City Bridge, Main Creek, Murrells Inlet, South Carolina	NOS	8661419	33.5783	-79.0033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARDEN CITY BRIDGE, MURRELLS INLET	SC
103067	Garden City Pier (ocean), South Carolina	NOS	8661437	33.575	-78.9967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7100000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARDEN CITY PIER, MURRELLS INLET	SC
103068	Wachesaw Landing, Waccamaw River, South Carolina	NOS	8661493	33.560001373291016	-79.08499908447266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WACHESAW LANDING, WACCAMAW R.	SC
103069	Oaks Creek, upper end, Murrells Inlet, South Carolina	NOS	8661684	33.5117	-79.0683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OAKS CREEK, UPPER END, MURRELLS INLET	SC
103070	Thoroughfare Creek entrance, Waccamaw River, South Carolina	NOS	8661703	33.5067	-79.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY ISLAND, THOROUGHFARE CREEK	SC
103071	Bennet's Dock, Pawleys Island Creek, South Carolina	NOS	8661989	33.435	-79.1267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BENNETT'S DOCK	SC
103072	Pawleys Island Pier (ocean), South Carolina	NOS	8662006	33.4317	-79.1167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAWLEYS ISLAND PIER, ATLANTIC OCEAN	SC
103073	Ward's Dock, Pawleys Inlet, South Carolina	NOS	8662071	33.4117	-79.135	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.92	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAWLEYS INLET, WARDS DOCK	SC
103074	Crab Haul Creek north inlet estuary, Oyster Landing, South Carolina	NOS	8662245	33.35169982910156	-79.18669891357422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oyster Landing (N Inlet Estuary)	SC
103075	Clambank Creek Dock, Goat Island, North Inlet, South Carolina	NOS	8662299	33.3333	-79.1933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7100000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLAMBANK CREEK DOCK, GOAT ISLAND	SC
103076	South Island Plantation (USCG station), Winyah Bay, South Carolina	NOS	8662746	33.235	-79.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0500000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WINYAH BAY, SOUTH ISLAND PLANTATION	SC
103077	Georgetown, Sampit River, South Carolina	NOS	8662926	33.361698150634766	-79.27999877929688	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1900000000000013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GEORGETOWN, SAMPIT RIVER ENT.	SC
103078	Waccamaw River entrance, Winyah Bay, South Carolina	NOS	8662931	33.36669921875	-79.25499725341797	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.990000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WACCAMAW RIVER ENTRANCE	SC
103079	Windsor Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8662953	33.415	-79.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9599999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WINDSOR PLANTATION, BLACK RIVER	SC
103080	South Santee River, ICWW (Fourmile Creek Canal), South Carolina	NOS	8663219	33.15420150756836	-79.35440063476562	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1499999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	S. SANTEE R.,IWW(4 MI. CANAL CR)	SC
103081	Buck Hall, Awendaw Creek, Bulls Bay, South Carolina	NOS	8663858	33.040000915527344	-79.55999755859375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6399999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUCK HALL, AWENDAW CREEK	SC
103082	General Dynamics Pier, Cooper River, South Carolina	NOS	8664022	33.0083	-79.9233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GEN. DYNAMICS PIER, COOPER R.	SC
103083	Cainhoy, Wando River, South Carolina	NOS	8664545	32.9267	-79.83	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5400000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cainhoy, Wando River	SC
103084	Army Depot, Cooper River, South Carolina	NOS	8664662	32.91	-79.9517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Army Depot	SC
103085	North Charleston, Ashley River, South Carolina	NOS	8664699	32.900299072265625	-80.11750030517578	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.669999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Charleston, Ashley River	SC
103086	Capers Creek, South Capers Island, South Carolina	NOS	8664941	32.8567	-79.7067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5799999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Capers Island	SC
103087	I-526 bridge, Ashley River, South Carolina	NOS	8665099	32.8367	-80.0217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.289999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-526 BRIDGE, ASHLEY RIVER	SC
103088	Charleston, Cooper River entrance, South Carolina	NOS	8665530	32.7808333	-79.9236111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9200000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston	SC
103089	Church Flats, Stono River, South Carolina	NOS	8665763	32.746700286865234	-80.16500091552734	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5100000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hollywood, Wadmalaw River	SC
103090	White House Woods, Mosquito Creek, Ashepoo River, St. Helena Sound, South Carolina	NOS	8667295	32.55870056152344	-80.45439910888672	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.450000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	White House Woods, Mosquito Creek	SC
103091	Air Station Beaufort, McCalleys Creek, South Carolina	NOS	8667612	32.50189971923828	-80.68489837646484	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Air Station Beaufort, McCalleys Creek	SC
103092	Clarendon Plantation, South Carolina	NOS	8667633	32.5025	-80.7841	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.800000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clarendon Plantation	SC
103093	Beaufort, Beaufort River, South Carolina	NOS	8667999	32.43	-80.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BEAUFORT	SC
103094	Fripp Inlet, Hunting Island Bridge, St. Helena Sound, South Carolina	NOS	8668498	32.34	-80.465	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fripps Inlet	SC
103095	Skull Creek, Ribaut Island, South Carolina	NOS	8668918	32.2667	-80.7367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.89	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIBAUT ISLAND, SKULL CREEK	SC
103096	Brighton Beach, May River, South Carolina	NOS	8669246	32.2140998840332	-80.84649658203125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.260000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brighton Beach	SC
103097	Port Wentworth, Savannah River, Georgia	NOS	8670424	32.14330555555556	-81.14169444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Wentworth	GA
106040	Little Misery Island (depth 50 ft), Salem Sound, Massachusetts Current	NOS	BOS1101_1	42.54217	-70.80013	:America/New_York	USA	knots	90	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Little Misery Island	MA
103099	Fort Pulaski, Savannah River, Georgia	NOS	8670870	32.03469444444445	-80.90302777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pulaski	GA
106041	Little Misery Island (depth 18 ft), Salem Sound, Massachusetts Current	NOS	BOS1101_11	42.54217	-70.80013	:America/New_York	USA	knots	102	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Little Misery Island	MA
103101	Skidaway Institute, Skidaway River, Georgia	NOS	8671086	31.99	-81.0233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.2700000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SKIDAWAY INSTITUTE, SKIDAWAY RIVER	GA
103102	Halfmoon Reef, Halfmoon River, Georgia	NOS	8671314	31.963300704956055	-80.94329833984375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HALFMOON REEF, HALFMOON RIVER	GA
103103	Priest Landing, Wilmington River, Georgia	NOS	8671315	31.963300704956055	-81.01170349121094	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PRIEST LANDING, WILMINGTON RIVER	GA
103104	Richmond Hill, Ogeechee River, Georgia	NOS	8671489	31.94300079345703	-81.28980255126953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond Hill, Ogeechee River	GA
103105	Little Wassaw Island, Green Island Sound, Georgia	NOS	8671946	31.889699935913086	-81.06169891357422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8400000000000034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Little Wassaw Island, Green Island Sound	GA
103106	Bear River, Range A Light, Georgia	NOS	8672667	31.7933	-81.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A Light, Bear River	GA
103107	Sunbury, Sunbury Channel, Georgia	NOS	8672875	31.7667	-81.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunbury, Sunbury Channel	GA
103108	South Ossabaw Island, Bear River, Georgia	NOS	8673171	31.72302777777778	-81.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Ossabaw Island, Bear River	GA
103109	South Newport River (Daymark 135), Georgia	NOS	8674301	31.575	-81.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7900000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #135, South Newport River	GA
103110	Mud River, head of (Daymark 156), Georgia	NOS	8674975	31.4867	-81.32	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.199999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #156, Head of Mud River	GA
103111	Rockdedundy River (Daymark 185), Georgia	NOS	8675761	31.37386111111111	-81.33394444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #185, Rockdedundy River Entrance	GA
103112	Crispen Island, Turtle River, Georgia	NOS	8676808	31.213300704956055	-81.55000305175781	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRISPEN ISLAND,TURTLE RIVER	GA
103113	St. Simons Lighthouse, St. Simons Island, Georgia	NOS	8677344	31.1317	-81.3967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5699999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St.Simons Island	GA
103114	Howe Street Pier, Brunswick, Georgia	NOS	8677406	31.14455555555556	-81.49680555555555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.009999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Howe Street Pier, Brunswick	GA
103115	Raccoon Key Spit, St. Andrew Sound, Georgia	NOS	8678124	31.01480555555555	-81.45597222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5599999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raccoon Key Spit	GA
103116	Bailey Cut, 0.8 mi west of, Satilla River, Georgia	NOS	8678322	30.985	-81.5917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bailey Cut, Satilla River	GA
103117	Kings Bay, Navy Base, Georgia	NOS	8679511	30.7967	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5599999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KINGS BAY	GA
103118	Kings Bay, MSF Pier, Cumberland Sound, Georgia	NOS	8679598	30.778099060058594	-81.49140167236328	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kings Bay MSF Pier	GA
103119	Dungeness, Seacamp Dock, Georgia	NOS	8679758	30.7633	-81.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DUNGENESS, SEACAMP DOCK	GA
103120	St. Marys, St. Marys River, Georgia	NOS	8679964	30.72	-81.5483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MARYS, ST. MARYS RIVER	GA
103121	Crandall, St. Marys River, Florida	NOS	8720004	30.7217	-81.6217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8199999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRANDALL, ST. MARYS RIVER	FL
103122	Cut 1N front range, St. Marys River, Florida	NOS	8720011	30.7083	-81.465	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1999999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUT 1N FRONT RANGE, ST MARYS RIVER ENTR	FL
106042	Little Misery Island (depth 5 ft), Salem Sound, Massachusetts Current	NOS	BOS1101_15	42.54217	-70.80013	:America/New_York	USA	knots	105	249	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Little Misery Island	MA
103124	Chester, Bells River, Florida	NOS	8720023	30.6833	-81.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHESTER, BELLS RIVER	FL
103125	Fernandina Beach, Amelia River, Florida	NOS	8720030	30.67135555555556	-81.46584166666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fernandina Beach	FL
103126	Lofton, Lanceford Creek, Florida	NOS	8720051	30.6433	-81.5233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LANCEFORD CREEK, LOFTON	FL
103127	Vaughns Landing, Florida	NOS	8720059	30.63	-81.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8299999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vaughns Landing	FL
103128	Nassauville, Nassau River East, Florida	NOS	8720098	30.5683	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NASSAUVILLE, NASSAU RIVER EAST	FL
103129	Edwards Creek, Nassau River, Florida	NOS	8720145	30.5017	-81.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edwards Creek	FL
103130	Cedar Heights, Broward River, Florida	NOS	8720189	30.4367	-81.6417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CEDAR HEIGHTS	FL
103131	Sisters Creek, Florida	NOS	8720196	30.4167	-81.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3800000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SISTERS CREEK	FL
103132	Clapboard Creek, Pelotes Island, Florida	NOS	8720198	30.4067	-81.51	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLAPBOARD CREEK	FL
103133	Water Treatment Dock, Mayport Naval Station, St. Johns River, Florida	NOS	8720211	30.4	-81.4133	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport Naval Sta., St Johns River	FL
103134	Sherwood Forest, Trout River, Florida	NOS	8720213	30.42	-81.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TROUT R., SHERWOOD FOREST	FL
103135	Degaussing structure, Mayport Naval Station, Florida	NOS	8720214	30.3967	-81.395	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5599999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Degaussing Structure	FL
103136	Bar Pilot Dock, St. Johns River, Florida	NOS	8720218	30.39816666666667	-81.42788888888889	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4700000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport (Bar Pilots Dock)	FL
103137	Dame Point, St. Johns River, Florida	NOS	8720219	30.386699676513672	-81.55829620361328	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8599999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point	FL
103138	Mayport (Ferry Depot), Florida	NOS	8720220	30.3933	-81.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport (Ferry Depot)	FL
103139	Mayport, St. Johns River, Florida	NOS	8720224	30.395	-81.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MAYPORT, ST JOHNS RIVER	FL
103140	Phoenix Park, Florida	NOS	8720225	30.3833	-81.6367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3199999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PHOENIX PARK	FL
103141	Main Street Bridge, St. Johns River, Florida	NOS	8720226	30.32	-81.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southbank Riverwalk, St Johns River	FL
103142	Jacksonville, Long Branch, Florida	NOS	8720242	30.360000610351562	-81.62000274658203	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3699999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Long Branch	FL
103143	Jacksonville Beach, Florida	NOS	8720291	30.2833	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.55	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jacksonville Beach	FL
103144	I-295 Bridge (west end), St. Johns River, Florida	NOS	8720357	30.19241666666667	-81.68888888888888	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-295 Buckman Bridge	FL
103145	Peoria Point, Doctors Lake, Florida	NOS	8720406	30.12	-81.7583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOCTORS LAKE, PEORIA POINT	FL
103146	Black Creek, S.C.L. RR. bridge, Florida	NOS	8720434	30.079999923706055	-81.76170349121094	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACK CREEK	FL
103147	Tolomato River, ICWW, Florida	NOS	8720494	29.994400024414062	-81.32949829101562	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TOLOMATO RIVER, ICWW	FL
103148	Red Bay Point, St. Johns River, Florida	NOS	8720503	29.98166666666667	-81.63416666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bay Point, St Johns River	FL
103149	Vilano Beach ICWW, Tolomato River, Florida	NOS	8720554	29.9167	-81.3	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vilano Beach ICWW	FL
103150	State Road 312, Matanzas River, ICWW, Florida	NOS	8720582	29.8667	-81.3067	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Road 312, Matanzas River	FL
103151	St. Augustine Beach, Florida	NOS	8720587	29.8567	-81.2633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4300000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Augustine Beach	FL
103152	Racy Point, St. Johns River, Florida	NOS	8720625	29.8017	-81.5483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.64	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Racy Point, St Johns River	FL
103153	Crescent Beach, Matanzas River, ICWW, Florida	NOS	8720651	29.7683	-81.2583	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crescent Beach, Matanzas River	FL
103154	State Road A1A Bridge, Florida	NOS	8720692	29.70453055555556	-81.22785555555555	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9399999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Road A1A Bridge	FL
103155	Bings Landing, Matanzas River, ICWW, Florida	NOS	8720757	29.615	-81.205	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9400000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bings Landing, Matanzas River	FL
103156	Buffalo Bluff, St. Johns River, Florida	NOS	8720767	29.595	-81.6817	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5800000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buffalo Bluff, St Johns River	FL
103157	Palatka, St. Johns River, Florida	NOS	8720774	29.6433	-81.6317	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.72	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Palatka, St Johns River	FL
103158	Welaka, St. Johns River, Florida	NOS	8720832	29.4767	-81.675	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Welaka	FL
106043	Haste Shoal (depth 15 ft), Salem Sound, Massachusetts Current	NOS	BOS1102_2	42.53935	-70.84496	:America/New_York	USA	knots	67	268	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haste Shoal	MA
103160	Daytona Beach Shores, Sunglow Pier, Florida	NOS	8721120	29.1467	-80.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DAYTONA BEACH SHORES	FL
103161	Ponce De Leon Inlet South, Florida	NOS	8721147	29.06333333333333	-80.91583333333334	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.64	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ponce De Leon Inlet South	FL
103162	Mosquito Lagoon, New Smyrna Beach, Florida	NOS	8721164	29.0233	-80.9183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Smyrna Beach	FL
103163	Packwood Place, Florida	NOS	8721222	28.94	-80.87	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PACKWOOD PLACE	FL
103164	Turtle Mound, Florida	NOS	8721223	28.9267	-80.825	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.18000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURTLE MOUND	FL
103165	Trident Pier, Port Canaveral, Florida	NOS	8721604	28.415800094604492	-80.59310150146484	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trident Pier, Port Canaveral	FL
103167	Cocoa Beach, Florida	NOS	8721649	28.3683	-80.6	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COCOA BEACH, ATLANTIC OCEAN	FL
103168	Melbourne Causeway, Indian River, Florida	NOS	8721843	28.08329963684082	-80.5916976928711	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.16000000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MELBOURNE CAUSEWAY	FL
103169	Vero Beach, Indian River, Florida	NOS	8722125	27.6317	-80.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.43000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vero Beach	FL
103170	North Beach Causeway, Indian River, Florida	NOS	8722208	27.4717	-80.325	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9500000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Beach Causeway	FL
103171	Fort Pierce Inlet, Binney Dock, Florida	NOS	8722213	27.46830555555556	-80.3	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2300000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Binney Dock	FL
103172	South Beach Causeway, Indian River, Florida	NOS	8722219	27.4567	-80.3233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Beach Causeway	FL
103173	Ankona, Indian River, Florida	NOS	8722274	27.355	-80.2733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7799999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ANKONA, INDIAN RIVER	FL
103166	Canaveral Harbor entrance, Florida	NOS	8721608	28.4083	-80.6017	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CANAVERAL HARBOR ENTRANCE	FL
103174	Jensen Beach Causeway Park, ICWW, Florida	NOS	8722329	27.251699447631836	-80.21829986572266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jensen Beach Causeway Park	FL
103175	Sewall Point, St. Lucie River, Florida	NOS	8722371	27.174999237060547	-80.18830108642578	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SEWALL POINT. ST. LUCIE RIVER	FL
103176	South Point, St. Lucie Inlet, St. Lucie River, Florida	NOS	8722375	27.1583	-80.1567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH POINT, ST LUCIE INLET	FL
103177	PGA Boulevard Bridge, Palm Beach, Florida	NOS	8722548	26.8433	-80.0667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PGA Boulevard Bridge, Palm Beach	FL
103178	Port of West Palm Beach, Florida	NOS	8722588	26.77	-80.0517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of West Palm Beach	FL
103179	Lake Worth ICW, Florida	NOS	8722669	26.6133	-80.0467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4499999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth ICW	FL
103180	Lake Worth Pier, Florida	NOS	8722670	26.6127778	-80.0341667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5400000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth Pier, Atlantic Ocean	FL
103182	Ocean Ridge, ICWW, Florida	NOS	8722718	26.52669906616211	-80.05329895019531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN RIDGE	FL
103183	South Delray Beach, ICWW, Florida	NOS	8722761	26.4467	-80.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH DELRAY BEACH	FL
103184	Lake Wyman, ICWW, Florida	NOS	8722802	26.37	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAKE WYMAN	FL
103185	Boca Raton, Lake Boca Raton, Florida	NOS	8722816	26.343299865722656	-80.07669830322266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOCA RATON	FL
103186	Deerfield Beach, Hillsboro River, Florida	NOS	8722832	26.31330555555556	-80.08169444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DEERFIELD BEACH	FL
103187	Hillsboro Inlet Marina, Florida	NOS	8722859	26.260000228881836	-80.08499908447266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HILLSBORO	FL
103188	Lauderdale-by-the-Sea, Anglin Fishing Pier, Florida	NOS	8722899	26.18829917907715	-80.09329986572266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4599999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAUDERDALE-BY-THE-SEA	FL
103189	Andrews Avenue bridge, New River, Fort Lauderdale, Florida	NOS	8722937	26.1183	-80.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1400000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FT. LAUDERDALE, ANDREWS AVENUE BRIDGE	FL
103190	South Port Everglades, ICWW, Florida	NOS	8722956	26.0816667	-80.1166667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4100000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Port Everglades	FL
103191	Haulover Pier, N. Miami Beach, Florida	NOS	8723080	25.9033	-80.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HAULOVER PIER, N. MIAMI BEACH	FL
103192	Miami, Miamarina, Biscayne Bay, Florida	NOS	8723165	25.7783	-80.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MIAMI, BISCAYNE BAY	FL
103193	Miami Beach (city pier), Florida	NOS	8723170	25.7683	-80.1317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami Beach	FL
103194	Government Cut, Miami Harbor entrance, Florida	NOS	8723178	25.7633	-80.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MIAMI BEACH, GOVERNMENT CUT	FL
103195	Virginia Key, Bear Cut, Biscayne Bay, Florida	NOS	8723214	25.731399536132812	-80.16179656982422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.129999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Virginia Key	FL
103196	Cutler, Biscayne Bay, Florida	NOS	8723289	25.615	-80.305	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUTLER, BISCAYNE BAY	FL
103197	Ragged Key No. 5, Biscayne Bay, Florida	NOS	8723355	25.5233	-80.175	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RAGGED KEY NO. 5, BISCAYNE BAY	FL
103198	Elliott Key Harbor, Elliott Key, Biscayne Bay, Florida	NOS	8723409	25.4533	-80.1967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ELLIOTT KEY HARBOR, ELLIOTT KEY	FL
103199	Turkey Point, Biscayne Bay, Florida	NOS	8723423	25.4367	-80.33	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURKEY POINT, BISCAYNE BAY	FL
103200	East Arsenicker, Card Sound, Florida	NOS	8723465	25.3733	-80.29	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST ARSENICKER, CARD SOUND	FL
103201	Pumpkin Key, south end, Card Sound, Florida	NOS	8723506	25.325	-80.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUMPKIN KEY, CARD SOUND	FL
103202	Little Card Sound bridge, Florida	NOS	8723534	25.2883	-80.37	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CARD SOUND BRIDGE	FL
103203	Key Colony Beach, Florida	NOS	8723962	24.7183	-81.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key Colony Beach	FL
103204	Vaca Key, Florida Bay, Florida	NOS	8723970	24.711	-81.1065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5099999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vaca Key, Florida Bay	FL
103205	Boca Chica Marina, Florida	NOS	8724493	24.575	-81.7083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6499999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOCA CHICA MARINA	FL
103206	Fleming Key, north end, Florida	NOS	8724571	24.5917	-81.795	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7100000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fleming Key	FL
103207	Key West, Florida	NOS	8724580	24.555700302124023	-81.80789947509766	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West	FL
103208	Sand Key Lighthouse, Sand Key Channel, Florida	NOS	8724635	24.4533	-81.8783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAND KEY LIGHTHOUSE	FL
103209	Smith Shoal Light, Florida	NOS	8724671	24.71827777777778	-81.92152777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Shoal Light	FL
103210	Loggerhead Key, Dry Tortugas, Florida	NOS	8724698	24.6317	-82.92	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Loggerhead Key	FL
103211	Dismal Key, Pumpkin Bay, Florida	NOS	8724963	25.895	-81.5583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DISMAL KEY, PUMPKIN BAY	FL
103212	Coon Key Pass, Gullivan Bay, Florida	NOS	8724964	25.8967	-81.6367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COON KEY PASS, GULLIVAN BAY	FL
103213	Marco Island, Caxambas Pass, Florida	NOS	8724967	25.9083	-81.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.68	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARCO ISLAND, CAXAMBAS PASS	FL
103214	Marco, Big Marco River, Florida	NOS	8724991	25.9717	-81.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARCO, BIG MARCO RIVER	FL
103215	McIlvaine Bay, Florida	NOS	8724996	25.985	-81.7017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.44	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MCILVAINE BAY	FL
103216	Keewaydin Island (inside), Florida	NOS	8725019	26.025	-81.7683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4500000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEEWAYDIN ISLAND, INSIDE	FL
103217	Naples, Florida	NOS	8725110	26.1316667	-81.8075	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naples, Gulf of Mexico	FL
103218	Naples, Naples Bay, north end, Florida	NOS	8725114	26.136699676513672	-81.78829956054688	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naples Bay, North	FL
103219	Little Hickory Island, Estero Bay, Florida	NOS	8725283	26.353300094604492	-81.8550033569336	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LITTLE HICKORY IS., ESTERO B.	FL
103220	Coconut Point, Estero Bay, Florida	NOS	8725319	26.4	-81.8433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COCONUT POINT, ESTERO BAY	FL
103221	Carlos Point, Estero Bay, Florida	NOS	8725325	26.405000686645508	-81.88500213623047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CARLOS POINT, ESTERO BAY	FL
103222	Estero Island, Estero Bay, Florida	NOS	8725351	26.4383	-81.9183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESTERO ISLAND, ESTERO BAY	FL
103223	Tarpon Bay, Sanibel Island, Florida	NOS	8725362	26.4433	-82.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TARPON BAY	FL
103224	Hendry Creek, Estero Bay, Florida	NOS	8725377	26.47	-81.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HENDRY CREEK, ESTERO BAY	FL
103225	Punta Rassa, San Carlos Bay, Florida	NOS	8725391	26.488300323486328	-82.01329803466797	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUNTA RASSA, SAN CARLOS BAY	FL
103226	St. James City, Pine Island, Florida	NOS	8725393	26.49169921875	-82.08170318603516	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. JAMES CITY,PINE ISLAND	FL
103227	Cape Coral Bridge, Caloosahatchee River, Florida	NOS	8725451	26.56329917907715	-81.93329620361328	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE CORAL BR.,CALOOSAHATCHEE R.	FL
103228	North Captiva Island, Florida	NOS	8725488	26.605	-82.2183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH CAPTIVA ISLAND	FL
103229	Matlacha Pass (bascule bridge), Florida	NOS	8725506	26.63170051574707	-82.06829833984375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.98	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MATLACHA PASS (SWING BR.)	FL
103230	Fort Myers, Caloosahatchee River, Florida	NOS	8725520	26.64777777777778	-81.8711111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Myers	FL
103231	Bokellia, Charlotte Harbor, Florida	NOS	8725541	26.70669937133789	-82.16329956054688	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9200000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOKEELIA, CHARLOTTE HARBOR	FL
103232	Port Boca Grande, Charlotte Harbor, Florida	NOS	8725577	26.719999313354492	-82.25830078125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT BOCA GRANDE, CHARLOTTE HBR.	FL
103233	Turtle Bay, Charlotte Harbor, Florida	NOS	8725649	26.7967	-82.1833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURTLE BAY	FL
103234	Don Pedro Island State Park, cutoff (south), Florida	NOS	8725685	26.855	-82.3033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUTOFF SOUTH	FL
103235	Locust Point, Hog Island, Charlotte Harbor, Florida	NOS	8725745	26.93	-82.1367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LOCUST POINT, HOG ISLAND	FL
103236	Harbour Heights, Peace River, Charlotte Harbor, Florida	NOS	8725791	26.9883	-81.9933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HARBOUR HEIGHTS, PEACE RIVER	FL
103237	Manasota, Lemon Bay, Florida	NOS	8725809	27.0117	-82.41	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MANASOTA	FL
103238	Myakka River, US 41 bridge, Charlotte Harbor, Florida	NOS	8725837	27.045	-82.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MYAKKA RIVER, US 41	FL
103239	Venice Fishing Pier, Venice, Florida	NOS	8725858	27.0717	-82.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENICE, GULF OF MEXICO	FL
103240	Siesta Key, Big Sarasota Pass, Florida	NOS	8726034	27.283899307250977	-82.56500244140625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Siesta Key, Big Sarasota Pass	FL
103241	Ellenton, Manatee River, Tampa Bay, Florida	NOS	8726265	27.51490020751953	-82.53379821777344	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ellenton, Manatee River	FL
103242	Egmont Key, Egmont Channel, Tampa Bay, Florida	NOS	8726347	27.6017	-82.76	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EGMONT KEY, TAMPA BAY	FL
103243	Mullet Key Channel (Skyway), Tampa Bay, Florida	NOS	8726364	27.615	-82.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1099999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MULLET KEY, TAMPA BAY	FL
103244	Port Manatee, Tampa Bay, Florida	NOS	8726384	27.638700485229492	-82.56210327148438	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Manatee	FL
103245	Little Manatee River, Florida	NOS	8726436	27.705	-82.4483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LITTLE MANATEE RIVER	FL
103246	St. Petersburg, Tampa Bay, Florida	NOS	8726520	27.76059913635254	-82.62689971923828	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Petersburg	FL
103247	Newman Branch, Tampa Bay, Florida	NOS	8726539	27.7833	-82.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWMAN BRANCH	FL
103248	Port Tampa, Old Tampa Bay, Florida	NOS	8726607	27.857799530029297	-82.55280303955078	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Port Tampa	FL
103249	Ballast Point, Tampa, Florida	NOS	8726639	27.89	-82.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TAMPA, BALLAST POINT	FL
103250	CSX Rockport, Mckay Bay entrance, Florida	NOS	8726667	27.913299560546875	-82.42500305175781	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.46	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mckay Bay Entrance	FL
103251	East Bay, Tampa Bay, Florida	NOS	8726674	27.923099517822266	-82.42140197753906	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Bay	FL
103252	Clearwater Beach, Florida	NOS	8726724	27.9783333	-82.8316667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clearwater Beach	FL
103253	Safety Harbor, Old Tampa Bay, Florida	NOS	8726738	27.9883	-82.685	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAFETY HARBOR, OLD TAMPA BAY	FL
103254	Anclote Lighthouse, Anclote Key, Florida	NOS	8726917	28.165	-82.8433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6999999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ANCLOTE LIGHTHOUSE, ANCLOTE KEY	FL
103255	Bayport, Florida	NOS	8727151	28.5333	-82.65	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYPORT	FL
103256	Johns Island, Chassahowitzka Bay, Florida	NOS	8727235	28.6917	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	JOHNS ISLAND, CHASSAHOWITZKA BAY	FL
103257	Chassahowitzka, Chassahowitzka River, Florida	NOS	8727246	28.715	-82.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHASSAHOWITZKA RIVER	FL
103258	Mason Creek, Homosassa Bay, Florida	NOS	8727274	28.7617	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MASON CREEK, HOMOSASSA BAY	FL
103259	Tuckers Island, Homosassa River, Florida	NOS	8727277	28.7717	-82.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TUCKERS ISLAND, HOMOSASSA RIVER	FL
103260	Halls River bridge, Homosassa River, Florida	NOS	8727293	28.8	-82.6033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.32999999999999985	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HALLS RIVER BRIDGE, HALLS RIVER	FL
103261	Ozello, St. Martins River, Florida	NOS	8727306	28.825	-82.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.34999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OZELLO	FL
103262	Ozello North, Crystal Bay, Florida	NOS	8727328	28.8633	-82.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OZELLO NORTH	FL
103263	Mangrove Pt., Crystal Bay, Florida	NOS	8727333	28.87	-82.7233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mangrove Point	FL
103264	Dixie Bay, Salt River, Crystal Bay, Florida	NOS	8727336	28.8817	-82.635	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DIXIE BAY	FL
103265	Crystal River, Kings Bay, Florida	NOS	8727343	28.8983	-82.5983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRYSTAL RIVER, KINGS BAY	FL
103266	Twin Rivers Marina, Crystal River, Florida	NOS	8727348	28.905	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2399999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Twin Rivers Marina	FL
103267	Shell Island, north end, Crystal River, Florida	NOS	8727359	28.9233	-82.6917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5099999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELL ISLAND, CRYSTAL RIVER	FL
103268	Cedar Key, Florida	NOS	8727520	29.135000228881836	-83.03170013427734	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cedar Key	FL
103269	Shell Mound, Cedar Keys NWR, Florida	NOS	8727535	29.20639991760254	-83.0697021484375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shell Mound	FL
103270	Horseshoe Point, Florida	NOS	8727648	29.4367	-83.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HORSESHOE POINT	FL
103271	Hagens Cove, Florida	NOS	8727792	29.79669952392578	-83.58380126953125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hagens Cove	FL
103272	Spring Warrior Creek, Florida	NOS	8727843	29.92	-83.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPRING WARRIOR CREEK	FL
103273	Snipe Island, Econfina River State Park, Apalachee Bay, Florida	NOS	8727976	30.061899185180664	-83.95269775390625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.759999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snipe Island	FL
103274	Port Leon, Apalachee Bay, Florida	NOS	8728104	30.124399185180664	-84.14900207519531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9600000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Leon	FL
103275	St. Marks lighthouse, Apalachee Bay, Florida	NOS	8728130	30.0783	-84.1783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9200000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MARKS LHTSE., APALACHEE BAY	FL
103276	St. Marks, Wakulla River, Apalachee Bay, Florida	NOS	8728152	30.158899307250977	-84.21859741210938	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.030000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Marks, Wakulla River	FL
103277	Shell Point, Walker Creek, Apalachee Bay, Florida	NOS	8728229	30.05833333333333	-84.29055555555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELL POINT, WALKER CREEK	FL
103278	Wakulla Airport, Ochlockonee Bay, Florida	NOS	8728262	29.980199813842773	-84.3958969116211	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7500000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ochlockonee Bay	FL
103279	Panacea, Dickerson Bay, Apalachee Bay, Florida	NOS	8728269	30.02829933166504	-84.38670349121094	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9899999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PANACEA, DICKERSON BAY	FL
103280	Turkey Point, Apalachee Bay, St. James Island, Florida	NOS	8728360	29.915	-84.5117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURKEY POINT	FL
103281	Dog Island, east end, St. George Sound, Florida	NOS	8728408	29.81	-84.585	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOG ISLAND, EAST END	FL
103282	Lanark, St. George Sound, Florida	NOS	8728412	29.878299713134766	-84.59500122070312	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LANARK, ST. GEORGES SOUND	FL
103283	Carrabelle, Carrabelle River, St. George Sound, Florida	NOS	8728464	29.85	-84.665	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CARRABELLE RIVER, ST. GEORGE SOUND	FL
103284	St. George Island, NE end, St. George Sound, Florida	NOS	8728486	29.766700744628906	-84.69999694824219	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NE END, ST. GEORGE ISLAND	FL
103285	South Carrabelle Beach, Florida	NOS	8728488	29.801700592041016	-84.73670196533203	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4000000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH CARRABELLE BEACH	FL
103286	East Bayou, Florida	NOS	8728593	29.818899154663086	-84.85030364990234	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Bayou	FL
103287	Cat Point, Apalachicola Bay, Florida	NOS	8728619	29.72330093383789	-84.88670349121094	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAT POINT, APALACHICOLA BAY	FL
103288	St. George Island, 12th St. W (bayside), St. George Sound, Florida	NOS	8728626	29.6533	-84.8967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. GEORGE ISLAND, BAYSIDE	FL
103289	St. George Island, Sikes Cut, St. George Sound, Florida	NOS	8728669	29.613300323486328	-84.95829772949219	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SIKES CUT, ST. GEORGE ISLAND	FL
103290	Apalachicola, Apalachicola Bay, Florida	NOS	8728690	29.7244444	-84.9805556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9100000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Apalachicola	FL
103291	White Beach, East Bay, Florida	NOS	8728694	29.785	-84.8983	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WHITE BEACH, EAST BAY	FL
103292	Apalachicola River (A&N RR bridge), Apalachicola Bay, Florida	NOS	8728711	29.7633	-85.0333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	APALACHICOLA RIVER	FL
103293	Little St. George Island, Apalachicola Bay, Florida	NOS	8728728	29.603599548339844	-85.04280090332031	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.860000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Little St George Island	FL
103294	Huckleberry Landing, Jackson River, Florida	NOS	8728757	29.770000457763672	-85.08499908447266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7000000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HUCKLEBERRY LANDING, JACKSON RIVER	FL
103295	Eleven Mile, St. Vincent Sound, Florida	NOS	8728786	29.70669937133789	-85.1532974243164	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ELEVEN MILE, ST. VINCENT SOUND	FL
103296	Lake Wimico, Florida	NOS	8728819	29.821399688720703	-85.17330169677734	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4399999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Wimico	FL
103297	Indian Pass, St. Vincent Sound, Florida	NOS	8728852	29.685100555419922	-85.22129821777344	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Indian Pass	FL
103298	White City, ICWW, Florida	NOS	8728853	29.88069444444444	-85.22144444444444	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	White City, ICWW	FL
103299	White City, Gulf County Canal, St. Joseph Bay, Florida	NOS	8728886	29.86680030822754	-85.27059936523438	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5399999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	White City, Gulf County Canal	FL
103300	Port Saint Joe, St. Joseph Bay, Florida	NOS	8728912	29.815	-85.3133	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port St. Joe	FL
106044	Haste Shoal (depth 4 ft), Salem Sound, Massachusetts Current	NOS	BOS1102_9	42.53935	-70.84496	:America/New_York	USA	knots	93	273	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haste Shoal	MA
103302	Overstreet, St. Andrew Bay, Florida	NOS	8728957	29.996700286865234	-85.37000274658203	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OVERSTREET	FL
103303	St. Joseph Point, St. Joseph Bay, Florida	NOS	8728958	29.873300552368164	-85.38999938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.76	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. JOSEPH POINT, ST. JOSEPH BAY	FL
103304	Cape San Blas (western cape), St. Joseph Bay, Florida	NOS	8728978	29.764400482177734	-85.40249633789062	:America/Chicago	USA	feet	\N	\N	\N	NOS uses UTC-5 for LST	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape San Blas, Western Cape	FL
103305	Goose Point, East Bay, St. Andrew Bay, Florida	NOS	8729026	30.061199188232422	-85.48860168457031	:America/Chicago	USA	feet	\N	\N	\N	NOS uses UTC-5 for LST	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Bay, Goose Point	FL
103306	Deer Point Lake, St. Andrew Bay, Florida	NOS	8729082	30.26959991455078	-85.60790252685547	:America/Chicago	USA	feet	\N	\N	\N	NOS uses UTC-5 for LST	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deer Point Lake	FL
103307	Panama City, St. Andrew Bay, Florida	NOS	8729108	30.1497222	-85.6644444	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Panama City	FL
103308	Courtney Point, St. Andrew Bay, Florida	NOS	8729132	30.15169906616211	-85.66670227050781	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Courtney Point, St Andrew Bay	FL
103309	Sulphur Point, Port of Panama City, St. Andrew Bay, Florida	NOS	8729142	30.183000564575195	-85.73280334472656	:America/Chicago	USA	feet	\N	\N	\N	NOS uses UTC-5 for LST	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sulphur Point, Port of Panama City	FL
103310	West Bay Creek, West Bay, St. Andrew Bay, Florida	NOS	8729197	30.29330062866211	-85.8582992553711	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEST BAY CREEK  WEST BAY	FL
103311	Panama City Beach (outside), St. Andrew Bay, Florida	NOS	8729210	30.21375	-85.87858333333334	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Panama City Beach	FL
103312	Santa Rosa, Hogtown Bayou, Choctawhatchee Bay, Florida	NOS	8729376	30.399999618530273	-86.22830200195312	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANTA ROSA HOGTOWN BAYOU	FL
103313	Driftwood Point, Choctawhatchee Bay, Florida	NOS	8729425	30.389400482177734	-86.32879638671875	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Driftwood Point, Choctawhatcheee Bay	FL
103314	Rocky Bayou, Choctawhatchee Bay, Florida	NOS	8729479	30.50670051574707	-86.44670104980469	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.27000000000000135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ROCKY BAYOU	FL
103315	Valparaiso, Choctawhatchee Bay, Florida	NOS	8729501	30.503299713134766	-86.49330139160156	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.27999999999999936	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valparaiso	FL
103316	Okaloosa Island, Florida	NOS	8729547	30.391399383544922	-86.59320068359375	:America/Chicago	USA	feet	\N	\N	\N	NOS uses UTC-5 for LST	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Okaloosa Island	FL
103317	Mary Esther, Santa Rosa Sound, Florida	NOS	8729572	30.4064998626709	-86.65049743652344	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.43000000000000327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mary Esther	FL
103318	Navarre Beach, Florida	NOS	8729678	30.3767	-86.865	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAVARRE BEACH	FL
103319	East Bay, Pensacola Bay, Florida	NOS	8729702	30.450000762939453	-86.91829681396484	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST BAY, HOLLEY	FL
103320	Navarre (north side), East Bay, Pensacola Bay, Florida	NOS	8729717	30.443099975585938	-86.95140075683594	:America/Chicago	USA	feet	\N	\N	\N	NOS uses UTC-5 for LST	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7399999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Navarre, North Side	FL
103321	Woodlawn Beach, Florida	NOS	8729736	30.386699676513672	-86.99169921875	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6599999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WOODLAWN BEACH	FL
106055	Commissioners Ledge (depth 6 ft), Massachusetts Current	NOS	BOS1107_4	42.33584	-70.91296	:America/New_York	USA	knots	37	222	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Commissioners Ledge	MA
103323	Shield Point, Blackwater River, Florida	NOS	8729747	30.58169937133789	-87.01499938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHIELD POINT, BLACKWATER RIVER	FL
103324	Hawkins Recreational Park, Blackwater River, Florida	NOS	8729753	30.636699676513672	-87.0282974243164	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACKWATER RIVER	FL
103325	Hernandez Point North, Escambia Bay, Florida	NOS	8729791	30.454999923706055	-87.0999984741211	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6500000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HERNANDEZ POINT NORTH	FL
103326	Fishing Bend, Santa Rosa Sound, Florida	NOS	8729806	30.336700439453125	-87.13999938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6300000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FISHING BEND, SANTA ROSA SOUND	FL
103327	Pensacola Beach Pier, Florida	NOS	8729807	30.3275	-87.141944	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pensacola Beach Pier	FL
103328	Lora Point, Escambia Bay, Pensacola Bay, Florida	NOS	8729816	30.514999389648438	-87.16169738769531	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LORA POINT, ESCAMBIA BAY	FL
103329	Floridatown, Escambia Bay, Florida	NOS	8729824	30.58169937133789	-87.18000030517578	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FLORIDATOWN, ESCAMBIA BAY	FL
103330	Pensacola, Florida	NOS	8729840	30.404399871826172	-87.21119689941406	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.620000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pensacola	FL
103331	Millview, Perdido Bay, Florida	NOS	8729905	30.4183	-87.3567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Millview, Perdido Bay	FL
103332	Big Lagoon, Florida	NOS	8729909	30.32670021057129	-87.35669708251953	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIG LAGOON	FL
103333	Blue Angels Park, Perdido Bay, Florida	NOS	8729941	30.38694444444445	-87.42880555555556	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blue Angels Park	FL
103334	Mill Point, Arnica Bay, Alabama	NOS	8730561	30.310199737548828	-87.51930236816406	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.379999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arnica Bay, Mill Point	AL
103335	Alabama Point, Perdido Pass, Alabama	NOS	8730667	30.27861111111111	-87.55500030517578	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alabama Point	AL
103336	Wolf Bay, Alabama	NOS	8730849	30.354999542236328	-87.5999984741211	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4200000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wolf Bay	AL
103337	Gulf State Park Pier, Alabama	NOS	8731269	30.248300552368164	-87.66829681396484	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulf State Park Pier	AL
103338	Gulf Shores, ICWW, Alabama	NOS	8731439	30.27988888888889	-87.68427777777778	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulf Shores, ICWW	AL
103339	Weeks Bay, Alabama	NOS	8732828	30.416900634765625	-87.82540130615234	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weeks Bay, Mobile Bay	AL
103340	Fly Creek, Mobile Bay, Alabama	NOS	8733502	30.542800903320312	-87.9010009765625	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fly Creek, Mobile Bay	AL
103341	Point Clear, Mobile Bay, Alabama	NOS	8733821	30.48663888888889	-87.93452777777777	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7800000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Clear, Mobile Bay	AL
103342	Meaher State Park, Mobile Bay, Alabama	NOS	8733839	30.66716666666667	-87.93644444444445	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Meaher State Park, Mobile Bay	AL
103343	Dauphin Island, Mobile Bay, Alabama	NOS	8735180	30.25	-88.07499694824219	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dauphin Island	AL
103344	Dauphin Island Hydro, Alabama	NOS	8735181	30.25131944444444	-88.07948611111111	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dauphin Island Hydro	AL
103345	Dog River Bridge, Alabama	NOS	8735391	30.565200805664062	-88.08799743652344	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dog River Bridge	AL
103346	East Fowl River Bridge, Alabama	NOS	8735523	30.443700790405273	-88.11389923095703	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Fowl River Bridge	AL
103347	Coast Guard sector, Mobile, Alabama	NOS	8736897	30.6495	-88.05811111111112	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coast Guard Sector Mobile	AL
103348	Mobile (Mobile State Docks), Alabama	NOS	8737048	30.70461111111111	-88.03961111111111	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mobile State Docks	AL
103349	Chickasaw Creek, Alabama	NOS	8737138	30.78190040588379	-88.07360076904297	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.860000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chickasaw Creek	AL
103350	Lower Bryant Landing, Tensay River, Alabama	NOS	8737373	30.9783	-87.8733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9300000000000033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Bryant Landing	AL
103351	West Fowl River Bridge, Alabama	NOS	8738043	30.37660026550293	-88.15859985351562	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Fowl River Bridge	AL
103352	Bayou La Batre Bridge, Alabama	NOS	8739803	30.40570068359375	-88.2477035522461	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bayou La Batre Bridge	AL
103353	Grand Bay NERR, Mississippi Sound, Mississippi	NOS	8740166	30.41319444444444	-88.4028888888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grand Bay NERR, Mississippi Sound	MS
103354	Petit Bois Island, Mississippi Sound, Mississippi	NOS	8740405	30.2033	-88.4417	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PETIT BOIS ISLAND, MISS. SOUND	MS
103355	Pascagoula, south side, Mississippi	NOS	8740993	30.322200775146484	-88.50800323486328	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8099999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pascagoula, South Side	MS
103356	Dock E, Port of Pascagoula, Mississippi	NOS	8741041	30.3477778	-88.5058333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dock E, Port of Pascagoula	MS
103357	Pascagoula Point, Mississippi Sound, Mississippi	NOS	8741196	30.34	-88.5333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pascagoula Point	MS
103358	Pascagoula NOAA Lab, Pascagoula River, Mississippi	NOS	8741533	30.36777777777778	-88.56305555555555	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pascagoula NOAA Lab	MS
103359	Gautier, Mississippi	NOS	8741798	30.3833	-88.61	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gautier	MS
103360	Graveline Bayou entrance, Mississippi	NOS	8742205	30.3617	-88.6633	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAVELINE BAYOU ENTRANCE	MS
103361	Horn Island, Mississippi Sound, Mississippi	NOS	8742221	30.2383	-88.6667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horn Island	MS
103362	North Shore, Mississippi	NOS	8742523	30.3733	-88.705	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8699999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Shore	MS
103363	Hollingsworth Point, Davis Bayou, Mississippi	NOS	8743081	30.3867	-88.7733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HOLLINGSWORTH POINT, DAVIS BAYOU	MS
103364	Ocean Springs Marina, Old Fort Bayou, Mississippi	NOS	8743181	30.4217	-88.7883	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Fort Bayou, Ocean Springs Marina	MS
103365	Ocean Springs, Mississippi	NOS	8743281	30.3917	-88.7983	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.870000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocean Springs	MS
103366	Bayou Talla, Back Bay, Biloxi, Mississippi	NOS	8743301	30.43	-88.8	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8599999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYOU TALLA, BACK BAY OF BILOXI	MS
103367	Ocean Springs, Old Fort Bayou, Mississippi	NOS	8743495	30.42	-88.8283	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9300000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN SPRINGS, OLD FORT BAYOU	MS
103368	Bayou Poito, Back Bay, Biloxi, Mississippi	NOS	8743639	30.4383	-88.845	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYOU POITO, BACK BAY OF BILOXI	MS
103369	Biloxi (Cadet Point), Biloxi Bay, Mississippi	NOS	8743735	30.39	-88.8567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biloxi (Cadet Point)	MS
103370	Deer Island, Mississippi	NOS	8743812	30.3833	-88.8667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deer Island	MS
103371	Langley Point, Mississippi	NOS	8743838	30.425	-88.87	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Langley Point	MS
103372	Biloxi, Biloxi Bay, Mississippi	NOS	8744117	30.4117	-88.9033	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biloxi	MS
106288	Hog Neck (depth 2 ft), Buzzards Bay, Massachusetts Current	NOS	COD0905_9	41.72389	-70.63938	:America/New_York	USA	knots	210	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.163	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hog Neck	MA
103375	Popps Ferry, Back Bay, Biloxi, Mississippi	NOS	8744671	30.4133	-88.975	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POPPS FERRY, BACK BAY OF BILOXI	MS
103376	Ship Island, Mississippi Sound, Mississippi	NOS	8744756	30.2133	-88.9717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, Mississippi Sound	MS
103377	Biloxi River, lower end, Mississippi	NOS	8744934	30.435	-89.0083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BILOXI RIVER, LOWER END	MS
103378	Handsboro Bridge, Bernard Bayou, Mississippi	NOS	8745101	30.4067	-89.0267	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HANDSBORO BRIDGE, BERNARD BAYOU	MS
103379	Landon, Mississippi	NOS	8745555	30.4317	-89.0817	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Landon	MS
103380	Gulfport, Gulfport Harbor, Mississippi	NOS	8745557	30.36	-89.0817	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulfport Harbor	MS
103381	Pass Christian Yacht Club, Mississippi Sound, Mississippi	NOS	8746819	30.31	-89.245	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PASS CHRISTIAN YACHT CLUB, MISS. SOUND	MS
103382	Bay Waveland Yacht Club, Bay St. Louis, Mississippi	NOS	8747437	30.32634166666667	-89.3258	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Waveland Yacht Club	MS
103374	Tchoutacabouffa River entrance, Mississippi	NOS	8744663	30.4417	-88.9733	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tchoutacabouffa River Entrance	MS
103383	Waveland, Mississipi Sound, Mississippi	NOS	8747766	30.2817	-89.3667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waveland	MS
103384	Devon Energy Facility, Louisiana	NOS	8760417	29.20075	-89.04446666666666	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devon Energy Facility	LA
103385	South Pass, Louisiana	NOS	8760551	28.99	-89.14	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Pass	LA
103386	Grand Pass, Louisiana	NOS	8760668	30.126699447631836	-89.2217025756836	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAND PASS	LA
103387	Pilottown, Louisiana	NOS	8760721	29.17930555555556	-89.25883333333333	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilottown	LA
103389	Olga Compressor Station, Grand Bay, Louisiana	NOS	8760889	29.38655555555556	-89.3801388888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olga Compressor Station, Grand Bay	LA
103390	Pilots Station (east), Southwest Pass, Louisiana	NOS	8760922	28.9322	-89.4075	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilots Station East, S.W. Pass	LA
103391	Pilot Station, Southwest Pass, Louisiana	NOS	8760943	28.925	-89.4183	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6300000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SW Pass	LA
106045	Fort Pickering, 0.2 nmi south of (depth 29 ft), Salem Sound, Massachusetts Current	NOS	BOS1104_1	42.52238	-70.86795	:America/New_York	USA	knots	\N	261.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pickering, 0.2nm south of	MA
103393	Shell Beach, Lake Borgne, Louisiana	NOS	8761305	29.86811111111111	-89.67325	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shell Beach	LA
103394	University of New Orleans vicinity, Chef Menteur Pass, Louisiana	NOS	8761385	30.06875	-89.802083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5799999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VICINITY OF UNO CHEF MENTEUR	LA
103395	The Rigolets, US Highway 90, Louisiana	NOS	8761402	30.1667	-89.7367	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Rigolets	LA
103396	Rat Bayou, Louisiana	NOS	8761431	29.566694	-89.763361	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.240000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rat Bayou	LA
103397	Bayou Chene, Louisiana	NOS	8761432	29.512694	-89.764528	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bayou Chene	LA
103398	Martello Castle, Lake Borgne, Louisiana	NOS	8761529	29.945	-89.835	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARTELLO CASTLE, LAKE BORGNE	LA
103400	Grand Isle, Mississippi River Delta, Louisiana (2)	NOS	8761724	29.26333333333333	-89.95666666666666	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grand Isle	LA
103401	Mendicant Island, Barataria Bay, Louisiana	NOS	8761742	29.318300247192383	-89.9800033569336	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MENDICANT ISLAND, BARATARIA BAY	LA
103402	Texaco Dock, Hackberry Bay, Louisiana	NOS	8761819	29.4017	-90.0383	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.45999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TEXACO DOCK, HACKBERRY BAY	LA
103388	Venice, Grand Pass, Louisiana	NOS	8760849	29.2733	-89.3517	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENICE, GRAND PASS	LA
103403	Caminada Pass (bridge), Louisiana	NOS	8761826	29.209999084472656	-90.04000091552734	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.48999999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHENIERE CAMINADA, CAMINADA PASS	LA
103404	Lafitte, Barataria Waterway, Louisiana	NOS	8761899	29.6667	-90.1117	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.17000000000000037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAFITTE, BARATARIA WATERWAY	LA
103405	New Canal USCG station, Lake Pontchartrain, Louisiana	NOS	8761927	30.02722222222222	-90.11333333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.27000000000000046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Canal Station	LA
103406	Port Fourchon, Belle Pass, Louisiana	NOS	8762075	29.114200592041016	-90.19930267333984	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.629999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Fourchon, Belle Pass	LA
103407	Leeville, Bayou Lafourche, Louisiana	NOS	8762084	29.2483	-90.2117	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LEEVILLE, BAYOU LAFOURCHE	LA
103408	Golden Meadow, Plaisance Canal, Louisiana	NOS	8762184	29.373300552368164	-90.26499938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GOLDEN MEADOW, PLAISANCE CANAL	LA
103409	East Timbalier Island, Timbalier Bay, Louisiana	NOS	8762223	29.0767	-90.285	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST TIMBALIER ISLAND, TIMBALIER BAY	LA
103410	Bayou Faleau, Louisiana	NOS	8762329	29.470389	-90.342222	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bayou Faleau	LA
103411	East Bank 1, Norco, Bayou LaBranche, Louisiana	NOS	8762372	30.05033333333333	-90.368	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Bank 1, Norco, B. LaBranche	LA
103412	I-10 Bonnet Carre Floodway, Louisiana	NOS	8762483	30.067899703979492	-90.38999938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.29000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-10 Bonnet Carre Floodway	LA
103413	Pointe au Chien, Cutoff Canal, Louisiana	NOS	8762525	29.41670036315918	-90.44670104980469	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pointe Au Chien, Cut Off Canal	LA
103414	East Isle Dernire, Lake Pelto, Louisiana	NOS	8762888	29.0717	-90.64	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	E. ISLE DERNIERES, LAKE PELTO	LA
103415	Cocodrie, Terrebonne Bay, Louisiana	NOS	8762928	29.245	-90.6617	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5599999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cocodrie	LA
103416	Texas Gas Platform, Caillou Bay, Louisiana	NOS	8763535	29.17477777777778	-90.97644444444444	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Texas Gas Platform, Caillou Bay	LA
103417	Fourleague Bay, Atchafalaya Bay, Louisiana	NOS	8763843	29.341800689697266	-91.135498046875	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fourleague Bay	LA
103418	Stouts Pass at Six Mile Lake, Louisiana	NOS	8764025	29.7433	-91.23	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4200000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stouts Pass at Six Mile Lake	LA
103419	Tesoro Marine Term., Atchafalaya River, Louisiana	NOS	8764044	29.6675	-91.23761111111111	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.28999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Berwick, Atchafalaya River	LA
103420	Lawma, Amerada Pass, Atchafalaya Bay, Louisiana	NOS	8764227	29.449600219726562	-91.33809661865234	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAWMA, Amerada Pass	LA
106046	Fort Pickering, 0.2 nmi south of (depth 16 ft), Salem Sound, Massachusetts Current	NOS	BOS1104_5	42.52238	-70.86795	:America/New_York	USA	knots	81	268	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pickering, 0.2nm south of	MA
103422	Eugene Island, north of, Louisiana	NOS	8764314	29.36750030517578	-91.38390350341797	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0200000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eugene Island, North of, Atchafalaya Bay	LA
103423	Weeks Bay, Louisiana	NOS	8765148	29.83722222222222	-91.8375	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.89	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weeks Bay	LA
103424	Cypremort Point, Louisiana	NOS	8765251	29.71336111111111	-91.88	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cypremort Point	LA
103425	Bayou Fearman, Vermillion Bay, Louisiana	NOS	8765746	29.674400329589844	-92.13520050048828	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bayou Fearman, Vermillion Bay	LA
103426	Intracoastal City, Louisiana	NOS	8765785	29.783000946044922	-92.15560150146484	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Intracoastal City	LA
103427	Freshwater Bayou, Louisiana	NOS	8765969	29.655399322509766	-92.25070190429688	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4499999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freshwater Bayou	LA
103428	Schooner Bayou, Vermillion Bay, Louisiana	NOS	8765994	29.758100509643555	-92.26380157470703	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.620000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Schooner Bayou	LA
103429	Freshwater Canal Locks, Louisiana	NOS	8766072	29.55169444444444	-92.30519444444444	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freshwater Canal Locks	LA
103430	Joseph Harbor, Louisiana	NOS	8766941	29.637500762939453	-92.76719665527344	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2399999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Joseph Harbor	LA
103431	Catfish Point, Louisiana	NOS	8767095	29.862899780273438	-92.8488998413086	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.740000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Catfish Point	LA
103432	Mermentau River, Grand Chenier, Louisiana	NOS	8767403	29.774999618530273	-93.00830078125	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0399999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MERMENTAU RIVER, GRAND CHENIER	LA
103433	Lake Charles, Calcasieu River, Louisiana	NOS	8767816	30.2236111	-93.2216667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7800000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Charles	LA
103434	East Calcasieu Lake, Louisiana	NOS	8767911	29.993900299072266	-93.27050018310547	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Calcasieu Lake	LA
103435	Bulk terminal, Calcasieu Ship Channel, Louisiana	NOS	8767961	30.19029998779297	-93.30069732666016	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bulk Terminal	LA
103436	Calcasieu Pass, east jetty, Louisiana	NOS	8768094	29.76816666666667	-93.3428888888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.120000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Calcasieu Pass	LA
103437	Gum Cove, ICWW, Louisiana	NOS	8768772	30.058700561523438	-93.52259826660156	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.509999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gum Cove, ICWW	LA
103438	East Sabine Lake, Louisiana	NOS	8769858	29.812700271606445	-93.86209869384766	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Sabine Lake	LA
103439	Sabine Naches Canal, Port Arthur, Texas	NOS	8770475	29.86669921875	-93.93000030517578	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Arthur	TX
103440	Rainbow Bridge, Neches River, Texas	NOS	8770520	29.979999542236328	-93.88169860839844	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rainbow Bridge	TX
103441	Mesquite Point, Sabine Pass, Texas	NOS	8770539	29.7667	-93.895	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mesquite Point	TX
103442	Buffalo Bayou, Houston Ship Channel, Galveston Bay, Texas	NOS	8770542	29.761899948120117	-95.34429931640625	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buffalo Bayou	TX
103443	Round Point, Trinity Bay, Galveston Bay, Texas	NOS	8770559	29.7133	-94.69	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.76	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Round Point	TX
103444	Sabine Pass (north), Texas	NOS	8770570	29.7284	-93.8701	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass North	TX
103445	Orange (Old Navy Base), Texas	NOS	8770597	30.0983	-93.7217	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orange	TX
103446	Barbours Cut, Morgans Point, Galveston Bay, Texas	NOS	8770613	29.6816667	-94.985	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Morgans Point, Barbours Cut	TX
103447	Umbrella Point, Trinity Bay, Texas	NOS	8770625	29.68	-94.8683	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UMBRELLA POINT, TRINITY BAY	TX
103448	Cypress, San Jacinto River, Galveston Bay, Texas	NOS	8770653	29.84670066833496	-95.08830261230469	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CYPRESS, SAN JACINTO RIVER	TX
103449	Lynchburg Landing, San Jacinto River, Galveston Bay, Texas	NOS	8770733	29.76486111111111	-95.07886111111111	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lynchburg Landing	TX
103450	San Jacinto Battleground State Historic Site, Texas	NOS	8770743	29.75670051574707	-95.08999633789062	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Battleship Texas State Park	TX
103451	COX WC-53 Platform, Louisiana	NOS	8770752	29.62400054931641	-93.75	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3299999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COX WC-53 Platform	LA
103452	Houston Ship Channel, Galveston Bay, Manchester, Texas	NOS	8770777	29.726299285888672	-95.26580047607422	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Manchester	TX
103453	High Island (TCOON), Texas	NOS	8770808	29.59469985961914	-94.39029693603516	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	High Island	TX
103468	Galveston Pier 21, Galveston Channel, Texas	NOS	8771450	29.31	-94.79330555555556	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Pier 21	TX
103530	Tidal Creek, Elkhorn Slough, Monterey Bay, Port San Luis, California	NOS	9413643	36.83330154418945	-121.74500274658203	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8699999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tidal Creek, Elkhorn Slough	CA
103454	Texas Point, Sabine Pass, Texas	NOS	8770822	29.689300537109375	-93.841796875	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Texas Point, Sabine Pass	TX
103455	Smith Point, Galveston Bay, Texas	NOS	8770931	29.535	-94.7817	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SMITH POINT, GALVESTON BAY	TX
103456	Clear Lake, Galveston Bay, Texas	NOS	8770933	29.5633	-95.0667	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6399999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clear Lake	TX
103457	Rollover Pass, Texas	NOS	8770971	29.514999389648438	-94.51329803466797	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7399999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rollover Pass	TX
103458	Eagle Point, Galveston Bay, Texas	NOS	8771013	29.48130555555555	-94.91725277777778	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6100000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Point, Galveston Bay	TX
103459	Renaissance SA-13 Platform, Louisiana	NOS	8771050	29.47900009155273	-93.63999938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Renaissance SA-13 Platform	LA
103460	Fieldwood WC-289 Platform, Louisiana	NOS	8771074	29.34700012207031	-93.63500213623047	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2199999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fieldwood WC-289 Platform	LA
106047	Fort Pickering, 0.2 nmi south of (depth 6 ft), Salem Sound, Massachusetts Current	NOS	BOS1104_8	42.52238	-70.86795	:America/New_York	USA	knots	80	264	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pickering, 0.2nm south of	MA
103462	Goat Island, Galveston Bay, Texas	NOS	8771165	29.431100845336914	-94.71040344238281	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6599999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goat Island	TX
103463	Texas City, Galveston Bay, Texas	NOS	8771262	29.390600204467773	-94.88490295410156	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Texas City	TX
103464	Port Bolivar, Galveston Bay, Texas	NOS	8771328	29.365	-94.78	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8400000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Bolivar	TX
103465	Galveston Bay entrance, north jetty, Texas	NOS	8771341	29.35746111111111	-94.724725	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9700000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Bay Entrance, North Jetty	TX
103466	Sabine Offshore Light (USCG S-1 Platform), Louisiana	NOS	8771367	29.4689998626709	-93.72000122070312	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\nThese data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Offshore Light	LA
103467	Galveston Bay entrance, south jetty, Texas	NOS	8771416	29.32670021057129	-94.69329833984375	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.169999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Bay Entrance, South Jetty	TX
103469	Galveston Railroad Bridge, Texas	NOS	8771486	29.302600860595703	-94.89710235595703	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Railroad Bridge	TX
103470	Galveston Pleasure Pier, Galveston, Texas	NOS	8771510	29.2853	-94.7894	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1100000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Pleasure Pier	TX
103471	Jamaica Beach, Texas	NOS	8771722	29.19860076904297	-94.98829650878906	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.48999999999999844	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jamaica Beach	TX
103472	San Luis Pass (TCOON), Texas	NOS	8771972	29.094999313354492	-95.11329650878906	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6900000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Luis Pass	TX
103473	Old Brazos River, Freeport, Texas	NOS	8772391	28.96109962463379	-95.36740112304688	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Brazos River Freeport	TX
103474	Freeport, DOW Barge Canal, Texas	NOS	8772440	28.9483	-95.3083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9500000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport	TX
103475	USCG Freeport, Texas	NOS	8772447	28.94330555555555	-95.3025	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport	TX
103476	Freeport SPIP, Freeport Harbor, Texas	NOS	8772471	28.935699462890625	-95.29419708251953	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9100000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport Harbor	TX
103477	Quintana Jetty (Freeport entrance jetty), Texas	NOS	8772479	28.930299758911133	-95.30590057373047	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9200000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport Entrance Jetty	TX
103478	Sargent (TCOON), Texas	NOS	8772985	28.77163888888889	-95.61683333333333	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sargent	TX
103479	Seadrift, San Antonio Bay, Texas	NOS	8773037	28.40690040588379	-96.71240234375	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.18999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seadrift	TX
103480	Matagorda City (TCOON), Texas	NOS	8773146	28.709999084472656	-95.91390228271484	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matagorda City	TX
103481	Port Lavaca, Lavaca Causeway, Matagorda Bay, Texas	NOS	8773259	28.640600204467773	-96.60980224609375	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Lavaca	TX
103529	Elkhorn Slough at Elkhorn, Monterey Bay, California	NOS	9413631	36.81829833984375	-121.74700164794922	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elkhorn Slough at Elkhorn	CA
103553	Chevron Oil Company Pier, Richmond, San Francisco Bay, California	NOS	9414863	37.92829895019531	-122.4000015258789	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond	CA
103482	Port O'Connor, Matagorda Bay, Texas	NOS	8773701	28.45170021057129	-96.38829803466797	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.40000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port O'Connor	TX
103483	Matagorda Bay entrance channel, Texas	NOS	8773767	28.42690086364746	-96.3301010131836	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.740000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matagorda Bay Entrance Channel	TX
103484	Barroom Bay, Espiritu Santo Bay, Texas	NOS	8773808	28.402999877929688	-96.48079681396484	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.21999999999999886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barroom Bay	TX
103485	Shoalwater Flats, Espiritu Santo Bay, Texas	NOS	8773896	28.364500045776367	-96.5802993774414	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.1700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shoalwater Flats	TX
103486	Aransas Wildlife Refuge (TCOON), Texas	NOS	8774230	28.228300094604492	-96.79499816894531	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.1700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aransas Wildlife Refuge	TX
103487	Copano Bay State Fishing Pier, Texas	NOS	8774513	28.11440086364746	-97.02439880371094	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.20999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Copano Bay	TX
103488	Bayside, Copano Bay, Texas	NOS	8774652	28.068300247192383	-97.19560241699219	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.23000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYSIDE, COPANO BAY	TX
103489	Rockport, Aransas Bay, Texas	NOS	8774770	28.0216667	-97.0466667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.1899999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockport	TX
103490	Conn Brown Harbor, Aransas Pass, Texas	NOS	8775083	27.908100128173828	-97.13529968261719	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ARANSAS PASS, REDFISH BAY	TX
103491	Portland, Nueces Bay, Corpus Christi Bay, Texas	NOS	8775131	27.88279914855957	-97.34310150146484	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland	TX
103492	La Quinta Channel North, Corpus Christi Bay, Texas	NOS	8775132	27.880399703979492	-97.27349853515625	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	La Quinta Channel North	TX
103493	White Point Bay, Texas	NOS	8775188	27.858299255371094	-97.4749984741211	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	White Point	TX
103494	Viola Turning Basin, Corpus Christi Bay, Texas	NOS	8775222	27.846099853515625	-97.52069854736328	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.40000000000000213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Viola Turning Basin	TX
103495	Port Aransas, Texas	NOS	8775237	27.83970069885254	-97.07250213623047	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6499999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Aransas	TX
103554	Corte Madera Creek, San Francisco Bay, California	NOS	9414874	37.94329833984375	-122.51300048828125	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CORTE MADERA CREEK	CA
103496	Aransas, Aransas Pass, Texas	NOS	8775241	27.836599349975586	-97.03910064697266	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aransas, Aransas Pass	TX
103497	Nueces Bay (TCOON), Texas	NOS	8775244	27.832799911499023	-97.48590087890625	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.38000000000000256	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nueces Bay	TX
103498	Port Aransas (H. Caldwell Pier), Texas	NOS	8775270	27.82670021057129	-97.05000305175781	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9199999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT ARANSAS, H. CALDWELL PIER	TX
103499	Enbridge Energy dock, Ingleside, Corpus Christi Channel, Texas	NOS	8775283	27.81861111111111	-97.20894444444444	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Enbridge, Ingleside	TX
103500	Texas State Aquarium, Corpus Christi, Texas	NOS	8775296	27.814899444580078	-97.38919830322266	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USS Lexington, Corpus Christi Bay	TX
103501	Corpus Christi Naval Air Station, Corpus Christi Bay, Texas	NOS	8775421	27.704999923706055	-97.27999877929688	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naval Air Station	TX
103502	Packery Channel, Texas	NOS	8775792	27.63330078125	-97.23670196533203	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Packery Channel	TX
103503	Bob Hall Pier, Corpus Christi, Texas	NOS	8775870	27.579999923706055	-97.2166976928711	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bob Hall Pier, Corpus Christi	TX
103504	Padre Island, Port Mansfield Channel ent., Texas	NOS	8778485	26.564199447631836	-97.27649688720703	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Padre Island, Port Mansfield Channel Ent	TX
103505	Realitos Peninsula, Texas	NOS	8779280	26.262399673461914	-97.2853012084961	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Realitos Peninsula	TX
103506	USCG station, South Padre Island, Texas	NOS	8779748	26.07309913635254	-97.1675033569336	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Padre Island CG Station	TX
103507	South Padre Island, Brazos Santiago Pass, Texas	NOS	8779749	26.0674991607666	-97.15480041503906	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.870000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPI Brazos Santiago	TX
103508	Padre Island, Brazos Santiago Pass, Texas	NOS	8779750	26.0683	-97.1567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8799999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Padre Island, Brazos Santiago Pass	TX
103509	Port Isabel, Laguna Madre, Texas	NOS	8779770	26.06116666666667	-97.21552777777778	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Isabel	TX
103510	San Martin Lake Channel, Texas	NOS	8779911	26.001800537109375	-97.29859924316406	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Martin Lake Channel	TX
103511	Wilson Cove, San Clemente Island, California	NOS	9410032	33.005001068115234	-118.55699920654297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WILSON COVE, SAN CLEMENTE IS.	CA
103512	Avalon, Santa Catalina Island, California	NOS	9410079	33.345001220703125	-118.32499694824219	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.719999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AVALON, SANTA CATALINA ISLAND	CA
103513	South San Diego Bay, California	NOS	9410135	32.62910079956055	-117.10780334472656	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South San Diego Bay	CA
103514	Ballast Point, California	NOS	9410155	32.6867	-117.233	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.799999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballast Point	CA
103515	San Diego, San Diego Bay, California	NOS	9410170	32.71555555555555	-117.1766666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Diego	CA
103516	Mission Bay, California	NOS	9410196	32.793701171875	-117.22380065917969	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8100000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mission Bay	CA
103517	La Jolla (Scripps Institution Wharf), California	NOS	9410230	32.86688888888889	-117.2571388888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	La Jolla	CA
103518	Newport Beach, Newport Bay entrance, Corona del Mar, California	NOS	9410580	33.6033	-117.883	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7800000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWPORT BEACH, NEWPORT BAY ENTRANCE	CA
103519	Los Angeles (outer harbor), California	NOS	9410660	33.72	-118.272	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Los Angeles	CA
103520	Long Beach, Terminal Island, California	NOS	9410680	33.7517	-118.227	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG BEACH, TERMINAL ISLAND	CA
103521	Santa Monica, Municipal Pier, San Pedro Channel, California	NOS	9410840	34.0083	-118.5	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7900000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Monica	CA
103522	Rincon Island, Mussel Shoals, Santa Barbara Channel, California	NOS	9411270	34.3483	-119.443	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RINCON ISLAND, PACIFIC OCEAN	CA
103523	Santa Barbara, California	NOS	9411340	34.40458888888889	-119.6924944444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.78	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Barbara	CA
103524	Gaviota State Park, California	NOS	9411399	34.46938888888889	-120.2283055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gaviota State Park, Pacific Ocean	CA
103525	Oil Platform Harvest (Topex Project), California	NOS	9411406	34.46916666666667	-120.6819444444444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.719999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oil Platform Harvest	CA
103526	Port San Luis, California	NOS	9412110	35.16888888888889	-120.7541666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port San Luis	CA
103527	Mansfield Cone, California	NOS	9412802	35.94952777777777	-121.4819444444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7399999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mansfield Cone	CA
103528	Monterey, Monterey Harbor, California	NOS	9413450	36.6088889	-121.8913889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Monterey	CA
103531	Kirby Park, Elkhorn Slough, Monterey Bay, Port San Luis, California	NOS	9413651	36.84130096435547	-121.74530029296875	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.950000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kirby Park, Elkhorn Slough	CA
103532	Elkhorn Slough railroad bridge, Monterey Bay, California	NOS	9413663	36.85667	-121.755	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9300000000000033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elkhorn Slough Railroad Bridge	CA
103533	Pillar Point Harbor, Half Moon Bay, California	NOS	9414131	37.5025	-122.4821666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9899999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point Harbor	CA
103534	San Francisco, San Francisco Bay, California	NOS	9414290	37.80630555555555	-122.4658888888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.119999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco	CA
106056	Lovell Island, 1.3 nmi north of (depth 30 ft), Massachusetts Current	NOS	BOS1108_1	42.35498	-70.9319	:America/New_York	USA	knots	27	187	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovell Island, 1.3nm north of	MA
103536	Rincon Point, Pier 22, San Francisco Bay, California	NOS	9414317	37.79	-122.387	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PIER 22 1/2, SAN FRANCISCO	CA
103537	Hunters Point, San Francisco Bay, California	NOS	9414358	37.73	-122.357	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5600000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HUNTERS POINT, S.F. BAY	CA
103538	Oyster Point Marina, San Francisco Bay, California	NOS	9414392	37.665	-122.377	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7700000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OYSTER POINT MARINA, SAN FRANCISCO BAY	CA
103539	San Mateo Bridge (west end), San Francisco Bay, California	NOS	9414458	37.58	-122.253	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.109999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Mateo Bridge	CA
103541	Dumbarton Highway Bridge, San Francisco Bay, California	NOS	9414509	37.5067	-122.115	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.68	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dumbarton Bridge	CA
103542	Redwood City, Wharf 5, San Francisco Bay, California	NOS	9414523	37.50681388888889	-122.2119055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redwood City	CA
103543	Coyote Creek, Alviso Slough, San Francisco Bay, California	NOS	9414575	37.465	-122.023	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.869999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coyote Creek	CA
103544	San Leandro Marina, San Francisco Bay, California	NOS	9414688	37.695	-122.192	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.920000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Leandro Marina	CA
103545	Oakland Harbor, Park Street Bridge, San Francisco Bay, California	NOS	9414746	37.7717	-122.235	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3800000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PARK STREET BRIDGE	CA
103546	Alameda, San Francisco Bay, California	NOS	9414750	37.77195277777778	-122.3002611111111	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.45	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alameda	CA
103547	Oakland Inner Harbor, San Francisco Bay, California	NOS	9414764	37.795	-122.282	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor	CA
103548	Alameda Naval Air Station fuel pier, San Francisco Bay, California	NOS	9414767	37.7933	-122.315	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ALAMEDA NAS, NAVY FUEL PIER	CA
103549	Sausalito, San Francisco Bay, California	NOS	9414806	37.8467	-122.477	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAUSALITO, SAN FRANCISCO BAY	CA
103550	Nurse Slough, Bradmoor Island, Suisun Bay, California	NOS	9414811	38.1833	-121.923	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bradmoor Island	CA
103551	Berkeley, San Francisco Bay, California	NOS	9414816	37.8650016784668	-122.30699920654297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.2800000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BERKELEY,S.F.BAY	CA
103552	Sausalito, Corps of Engineers Dock, San Francisco Bay, California	NOS	9414819	37.865	-122.493	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAUSALITO, COE DOCK, S.F. BAY	CA
103540	Redwood Creek Marker 8, San Francisco Bay, California	NOS	9414501	37.5333	-122.193	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REDWOOD CREEK,C.M. NO. 8,S.F.BAY	CA
103555	Bolinas, Bolinas Lagoon, California	NOS	9414958	37.90800094604492	-122.67849731445312	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bolinas, Bolinas Lagoon	CA
103556	Drakes Bay, Point Reyes, California	NOS	9415020	37.9941667	-122.9736111	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Reyes	CA
103557	Blackslough Landing, San Joaquin River, California	NOS	9415021	37.994998931884766	-121.41999816894531	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8400000000000318	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACKSLOUGH LANDING, SAN JOAQUIN RIVER	CA
103558	Pinole Point, San Pablo Bay, California	NOS	9415056	38.015	-122.363	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Point, San Pablo Bay	CA
103559	Antioch, San Joaquin River, California	NOS	9415064	38.02	-121.815	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ANTIOCH, SAN JOAQUIN RIVER	CA
103560	Martinez-Amorco Pier, California	NOS	9415102	38.03463888888889	-122.1251944444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Martinez-Amorco Pier	CA
103561	Wards Island, Little Connection Slough, San Joaquin River, California	NOS	9415105	38.04999923706055	-121.49700164794922	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WARDS ISLAND, SAN JOAQUIN RIVER	CA
103562	Mallard Island Ferry Wharf, Suisun Bay, California	NOS	9415112	38.0433	-121.918	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MALLARD ISLAND, SUISUN BAY	CA
103563	Crockett, Carquinez Strait, California	NOS	9415143	38.0583	-122.223	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.210000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CROCKETT, CARQUINEZ STRAIT	CA
103564	Port Chicago, Suisun Bay, California	NOS	9415144	38.056	-122.0395	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5599999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Chicago	CA
103565	Threemile Slough entrance, San Joaquin River, California	NOS	9415193	38.086700439453125	-121.68499755859375	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THREE MILE SLOUGH,SAN JOAQUIN R.	CA
103566	Mare Island Naval Shipyard, Carquinez Strait, California	NOS	9415218	38.07	-122.25	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mare Island	CA
103567	Korths Harbor, San Joaquin River, California	NOS	9415229	38.097599029541016	-121.56839752197266	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KORTHS HBR, SAN JOAQUIN RIVER	CA
103568	Petaluma River entrance, San Pablo Bay, California	NOS	9415252	38.11530555555556	-122.5056666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.2300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PETALUMA RIVER ENTRANCE	CA
103569	Suisun Slough entrance, Suisun Bay, California	NOS	9415265	38.1283	-122.073	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.61	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SUISUN SLOUGH ENTRANCE	CA
103570	Rio Vista, Sacramento River, California	NOS	9415316	38.145	-121.692	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.129999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rio Vista	CA
103571	Sonoma Creek, San Pablo Bay, California	NOS	9415338	38.1567	-122.407	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sonoma Creek Entrance	CA
103572	Lakeville, Petaluma River, California	NOS	9415423	38.1983	-122.547	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.45	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAKEVILLE, PETALUMA RIVER	CA
103573	Upper drawbridge, Petaluma River, San Pablo Bay, California	NOS	9415584	38.2283	-122.613	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Petaluma River, Upper Drawbridge	CA
103574	Green Cove, California	NOS	9416409	38.70433333333333	-123.4493888888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Cove	CA
103575	Arena Cove, California	NOS	9416841	38.91455555555556	-123.7110833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1400000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arena Cove	CA
103576	Noyo Harbor, Fort Bragg, California	NOS	9417426	39.42577777777778	-123.8051111111111	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NOYO HARBOR	CA
103577	Shelter Cove, California	NOS	9418024	40.025001525878906	-124.05799865722656	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELTER COVE	CA
103578	Cockrobin Island Bridge, Eel River, San Francisco, California	NOS	9418637	40.63719940185547	-124.2822036743164	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3699999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cockrobin Island Bridge	CA
103579	Fields Landing, Humboldt Bay, California	NOS	9418723	40.7233	-124.222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.72	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FIELDS LANDING, HUMBOLDT BAY	CA
103580	North Spit, Humboldt Bay, California	NOS	9418767	40.76690555555555	-124.2173444444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Spit	CA
103581	Samoa, Humboldt Bay, California	NOS	9418817	40.8267	-124.18	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Samoa, Humboldt Bay	CA
106048	Marblehead Channel (depth 30 ft), Salem Sound, Massachusetts Current	NOS	BOS1105_1	42.5007	-70.82023	:America/New_York	USA	knots	\N	319.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marblehead Channel	MA
103583	Crescent City, California	NOS	9419750	41.74561111111111	-124.1843888888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6999999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crescent City	CA
103584	Pyramid Point, Smith River, California	NOS	9419945	41.94525	-124.2009166666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.419999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pyramid Point	CA
103585	Gold Beach, Rogue River, Oregon	NOS	9431011	42.42163888888889	-124.4187222222222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9099999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gold Beach	OR
103586	Port Orford, Oregon	NOS	9431647	42.73899841308594	-124.49829864501953	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Orford	OR
103587	Rink Creek entrance, Coquille River, Oregon	NOS	9432436	43.157901763916016	-124.18180084228516	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.490000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coquille River	OR
103588	Charleston, Coos Bay, Oregon	NOS	9432780	43.345001220703125	-124.3219985961914	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston	OR
103589	Halfmoon Bay, Umpqua River, Oregon	NOS	9433445	43.675	-124.192	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Half Moon Bay	OR
103590	Reedsport, Umpqua River, Oregon	NOS	9433501	43.70830154418945	-124.0979995727539	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.950000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REEDSPORT	OR
103591	Cushman, Siuslaw River, Oregon	NOS	9434068	43.98500061035156	-124.04499816894531	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9399999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cushman	OR
103592	Florence USCG Pier, Siuslaw River, Oregon	NOS	9434098	44.00210189819336	-124.12300109863281	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Florence USCG Pier, Siuslaw River	OR
103593	Waldport, Alsea Bay, Oregon	NOS	9434939	44.43436111111111	-124.0580833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldport	OR
103594	Weiser Point, Yaquina River, Oregon	NOS	9435308	44.5933	-124.008	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEISER POINT, YAQUINA RIVER	OR
103595	South Beach, Yaquina Bay and River, Oregon	NOS	9435380	44.62544444444445	-124.0449444444444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.449999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Beach	OR
103596	Depoe Bay, Oregon	NOS	9435827	44.81	-124.058	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DEPOE BAY	OR
103597	Chinook Bend, Siletz River, Oregon	NOS	9435992	44.880001068115234	-123.9636001586914	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chinook Bend	OR
103598	Cascade Head, Salmon River, Oregon	NOS	9436381	45.04794444444445	-124.0073055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cascade Head, Salmon River	OR
103599	Dick Point, Tillamook Bay, Oregon	NOS	9437381	45.4817	-123.902	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3099999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dick Point	OR
103600	Garibaldi, Tillamook Bay, Oregon	NOS	9437540	45.55453	-123.9189444443915	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Garibaldi	OR
103601	North jetty, Tillamook Bay, Oregon	NOS	9437585	45.56999969482422	-123.96499633789062	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.270000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH JETTY, TILLAMOOK BAY	OR
103602	North Fork, Nehalem River, Oregon	NOS	9437954	45.73379898071289	-123.87640380859375	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Fork	OR
103603	Cathcart Landing, Youngs River, Oregon	NOS	9438772	46.12425	-123.8043333333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.659999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cathcart Landing	OR
103604	Hammond, Oregon	NOS	9439011	46.2017	-123.945	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hammond	OR
103605	Tongue Point, Astoria, Columbia River, Oregon	NOS	9439040	46.20731	-123.76830555558205	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Astoria	OR
103606	Wauna, Columbia River, Oregon	NOS	9439099	46.15999984741211	-123.40499877929688	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wauna	OR
103607	Rocky Point, Multnomah Channel, Oregon	NOS	9439189	45.6967	-122.868	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4199999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rocky Point	OR
103608	Saint Helens, Columbia River, Oregon	NOS	9439201	45.8650016784668	-122.7969970703125	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Helens	OR
103609	Portland, Morrison Street Bridge, Oregon	NOS	9439221	45.51	-122.673	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Morrison Street Bridge	OR
103610	Washougal, Columbia River, Washington	NOS	9440047	45.57830047607422	-122.38200378417969	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WASHOUGAL, COLUMBIA RIVER	WA
103611	Beacon Rock State Park, Columbia River, Washington	NOS	9440079	45.62030029296875	-122.02030181884766	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7800000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beacon Rock State Park	WA
103612	Vancouver, Columbia River, Washington	NOS	9440083	45.63117222222222	-122.6957722222222	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vancouver	WA
103613	Knapp Landing, Columbia River, Washington	NOS	9440171	45.74169921875	-122.75499725341797	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KNAPP(THORNES)LNDG, WILLOW BAR	WA
103614	Temco Kalama Terminal, Columbia River, Washington	NOS	9440357	45.98366666666666	-122.8346111111111	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TEMCO Kalama Terminal	WA
103634	Foulweather Bluff, Washington	NOS	9445016	47.9267	-122.617	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.869999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff	WA
103615	Longview, Columbia River, Washington	NOS	9440422	46.10609817504883	-122.9542007446289	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Longview	WA
103616	Cape Horn, Columbia River, Washington	NOS	9440482	46.15169906616211	-123.29000091552734	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9899999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE HORN, COLUMBIA RIVER	WA
103617	Barlow Point, Columbia River, Washington	NOS	9440483	46.152198791503906	-123.03919982910156	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barlow Point	WA
103618	Skamokawa, Steamboat Slough, Columbia River, Washington	NOS	9440569	46.27030555555555	-123.4565	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skamokawa	WA
103619	Cape Disappointment, Washington	NOS	9440581	46.28102777777778	-124.0462777777778	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Disappointment	WA
103620	Greenhead Slough, Washington	NOS	9440650	46.37220001220703	-123.95030212402344	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.890000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Greenhead Slough	WA
103621	Nahcotta, Willapa Bay, Washington	NOS	9440747	46.5017	-124.023	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAHCOTTA, WILLAPA BAY	WA
103622	South Bend, Willapa River, Willapa Bay, Washington	NOS	9440875	46.6633	-123.798	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH BEND	WA
103623	Toke Point, Willapa Bay, Washington	NOS	9440910	46.7075	-123.9669444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.780000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Toke Point	WA
103624	Westport, Point Chehalis, Grays Harbor, Washington	NOS	9441102	46.90431	-124.1050833331214	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Westport	WA
103625	Aberdeen, Grays Harbor, Washington	NOS	9441187	46.9683	-123.853	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.6000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aberdeen	WA
106057	Lovell Island, 1.3 nmi north of (depth 20 ft), Massachusetts Current	NOS	BOS1108_4	42.35498	-70.9319	:America/New_York	USA	knots	27	192	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovell Island, 1.3nm north of	MA
103627	La Push, Quillayute River, Washington	NOS	9442396	47.91283611111111	-124.6357388888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	La Push, Quillayute River	WA
103628	Tskawahyah Island, Cape Alava, Washington	NOS	9442705	48.17110061645508	-124.73690032958984	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.669999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tskawahyah Island, Cape Alava	WA
103629	Neah Bay, Strait Of Juan De Fuca, Washington	NOS	9443090	48.37072222222222	-124.6015888888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Neah Bay	WA
103630	Sekiu, Clallam Bay, Strait of Juan de Fuca, Washington	NOS	9443361	48.2633	-124.297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SEKIU, CLALLAM BAY	WA
103631	Jim Creek, Washington	NOS	9443551	48.187198638916016	-124.0625	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.059999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jim Creek	WA
103632	Port Angeles, Strait Of Juan De Fuca, Washington	NOS	9444090	48.125	-123.44000244140625	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.240000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Angeles	WA
103633	Port Townsend (Point Hudson), Admiralty Inlet, Washington	NOS	9444900	48.11122222222222	-122.7596777777778	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Townsend	WA
103635	Bangor Wharf, Washington	NOS	9445133	47.7483	-122.727	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor	WA
103636	Union, Hood Canal, Washington	NOS	9445478	47.3583	-123.098	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UNION, HOOD CANAL	WA
103637	Bremerton, Sinclair Inlet, Port Orchard, Puget Sound, Washington	NOS	9445958	47.56169891357422	-122.62300109863281	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.8199999999999985	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bremerton	WA
103638	Wauna, Carr Inlet, Puget Sound, Washington	NOS	9446291	47.378299713134766	-122.63400268554688	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.640000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wauna	WA
103639	Tacoma, Commencement Bay, Sitcum Waterway, Puget Sound, Washington	NOS	9446484	47.266700744628906	-122.41329956054688	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tacoma	WA
103640	Yoman Point, Anderson Island, Balch Passage, Puget Sound, Washington	NOS	9446705	47.18	-122.675	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	YOMAN POINT, ANDERSON ISLAND	WA
103641	Sandy Point, Anderson Island, Puget Sound, Washington	NOS	9446804	47.15299987792969	-122.67510223388672	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.619999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY POINT ANDERSON ISLAND, PUGET SOUND	WA
103642	Budd Inlet, south of Gull Harbor, Washington	NOS	9446807	47.0983	-122.895	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.329999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUDD INLET, SOUTH OF GULL HARBOR	WA
103643	Seattle, Puget Sound, Washington	NOS	9447130	47.60263888888889	-122.3393055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.64	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seattle	WA
103644	Everett, Washington	NOS	9447659	47.98	-122.223	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EVERETT	WA
103645	Priest Point, Washington	NOS	9447717	48.03494444444444	-122.2271944444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Priest Point	WA
103646	Tulalip, Tulalip Bay, Washington	NOS	9447773	48.065	-122.288	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tulalip, Tulalip Bay	WA
103647	Greenbank, Whidbey Island, Washington	NOS	9447883	48.105	-122.57	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.609999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Bank	WA
103648	Naval Air Station Whidbey Island, Washington	NOS	9447973	48.34280014038086	-122.68579864501953	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.439999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAS Whidbey Island	WA
103649	Spee-Bi-Dah, Washington	NOS	9448009	48.08825	-122.3223333333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spee-Bi-Dah	WA
103650	Tulare Beach, Port Susan, Washington	NOS	9448043	48.10680555555555	-122.3472777777778	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.459999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tulare Beach, Port Susan	WA
103651	Sneeoosh Point, Washington	NOS	9448576	48.4	-122.548	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.390000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sneeoosh Point	WA
106396	Port Graham (depth 114 ft), Cook Inlet, Alaska Current	NOS	COI0516_1	59.40002	-151.9659	:America/Anchorage	USA	knots	202	32	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Graham	AK
103653	Deception Pass St. Park, Bowman Bay, Fidalgo I., Washington	NOS	9448614	48.415000915527344	-122.6520004272461	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.630000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOWMAN BAY, FIDALGO ISLAND	WA
103654	Turner Bay, Similk Bay, Washington	NOS	9448657	48.445	-122.555	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turner Bay	WA
103655	Swinomish Channel entrance, Padilla Bay, Washington	NOS	9448682	48.45830154418945	-122.51300048828125	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.040000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Swinomish	WA
103656	Village Point, Lummi Island, Washington	NOS	9449161	48.7167	-122.708	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.010000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VILLAGE POINT, LUMMI ISLAND	WA
103657	Cherry Point, Strait of Georgia, Washington	NOS	9449424	48.86271666666666	-122.7585833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.279999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point	WA
103658	Point Roberts, Strait of Georgia, Washington	NOS	9449639	48.974998474121094	-123.08300018310547	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.640000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Roberts	WA
103659	Drayton Harbor, Blaine, Strait of Georgia, Washington	NOS	9449679	48.9917	-122.765	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blaine, Drayton Harbor	WA
103660	Waldron Island, Haro Strait, Washington	NOS	9449746	48.686798095703125	-123.03759765625	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldron Island	WA
103661	Rosario, East Sound, Orcas Island, Washington	NOS	9449771	48.64670181274414	-122.87000274658203	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario, Orcas Island	WA
103662	Hanbury Point, Mosquito Pass, San Juan I., Haro Strait, Washington	NOS	9449828	48.5817	-123.17	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HANBURY POINT, SAN JUAN ISLAND	WA
103663	Kanaka Bay, San Juan Island, Haro Strait, Washington	NOS	9449856	48.48500061035156	-123.08300018310547	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.390000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanaka Bay, San Juan Island	WA
103664	Friday Harbor, San Juan Island, San Juan Channel, Washington	NOS	9449880	48.54527777777778	-123.0125	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.550000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Friday Harbor	WA
103665	Upright Head, Lopez Island, Washington	NOS	9449911	48.57170104980469	-122.88500213623047	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.620000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Head	WA
103666	Armitage Island, Thatcher Pass, Washington	NOS	9449932	48.535	-122.797	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.660000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Armitage Island	WA
103667	Richardson, Lopez Island, San Juan Channel, Washington	NOS	9449982	48.4467	-122.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richardson	WA
103668	Telegraph Bay, Washington	NOS	9449988	48.44329833984375	-122.80500030517578	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Telegraph Bay	WA
103669	Windy Cove entrance, Alaska	NOS	9450251	55.0354	-133.0238	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.85	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance to Windy Cove	AK
103670	Dunbar Inlet GPS Tide Buoy, Alaska	NOS	9450286	55.0879	-132.81583	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.859999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dunbar Inlet GPS Tide Buoy	AK
103671	Custom House Cove, Mary Island, Alaska	NOS	9450296	55.1	-131.217	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Custom House Cove, Mary Island	AK
103672	Metlakatla, Port Chester, Alaska	NOS	9450314	55.1283	-131.567	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Metlakatla, Port Chester, AK	AK
103673	Hydaburg, Sukkwan Strait, Alaska	NOS	9450364	55.201698303222656	-132.822998046875	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hydaburg, Sukkwan Strait	AK
103674	Ketchikan, Tongass Narrows, Alaska	NOS	9450460	55.3319444	-131.6261111	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketchikan	AK
103675	Trocadero Bay, Alaska	NOS	9450463	55.35166666666667	-132.9380555555556	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trocadero Bay	AK
103676	Craig, Klawock Inlet, Bucareli Bay, Alaska	NOS	9450551	55.4883	-133.142	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.34	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRAIG	AK
103677	Lindeman Cove, Kasaan Bay, Alaska	NOS	9450625	55.6017	-132.512	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.209999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lindeman Cove	AK
103700	Golf Island, Necker Islands, Alaska	NOS	9451421	56.7867	-135.393	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golf Island	AK
103678	Northern Carroll Inlet GPS Tide Buoy, Alaska	NOS	9450642	55.629	-131.362694	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.149999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northern Carroll Inlet GPS Tide Buoy	AK
103679	Nossuk Bay, Tonowek Bay, Gulf of Esquibel, Alaska	NOS	9450711	55.72166666666666	-133.35	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.46	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nossuk Bay	AK
103680	Magnetic Point, Union Bay, Earnest Sound, Alaska	NOS	9450753	55.78828333333333	-132.1908833333334	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Magnetic Point, Union Bay, Earnest Sound	AK
103681	Hyder, Portland Canal, Alaska	NOS	9450831	55.90449905395508	-130.01080322265625	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.550000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hyder	AK
103682	Burrough Bay, Behm Canal, Alaska	NOS	9450914	56.0383	-131.095	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrough Bay, Behm Canal	AK
103683	Thoms Point, Zimovia Strait, Alaska	NOS	9450970	56.1183	-132.078	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thoms Point	AK
103684	El Capitan Passage, Alaska	NOS	9450997	56.1633	-133.33	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.86	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EL Capitan Passage	AK
103685	Dry Pass, El Capitan Passage, Alaska	NOS	9450998	56.1633	-133.413	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dry Pass, EL Capitan Passage	AK
103686	Point Harrington, Clarence Strait, Alaska	NOS	9451005	56.1783	-132.697	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POINT HARRINGTON, CLARENCE STRAIT	AK
103687	Bradfield Canal, Alaska	NOS	9451012	56.1833	-131.572	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bradfield Canal	AK
103688	Village Rock, Zimovia Strait, Alaska	NOS	9451037	56.22	-132.297	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.36	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Village Rock	AK
103689	Port Alexander, Baranof Island, Alaska	NOS	9451054	56.2467	-134.647	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Alexander	AK
103690	Bushy Island, Snow Passage, Alaska	NOS	9451074	56.2767	-132.985	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUSHY ISLAND, SNOW PASSAGE	AK
103691	Reef Point, Stikine Strait, Alaska	NOS	9451124	56.3533	-132.553	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REEF POINT, STIKINE STRAIT	AK
103692	Madan Bay, Clarence Strait, Alaska	NOS	9451152	56.3922	-132.169	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Madan Bay	AK
103693	Wrangell, Wrangell Island, Alaska	NOS	9451204	56.47	-132.387	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrangell	AK
103694	Monte Carlo Island, Keku Strait, Alaska	NOS	9451247	56.535	-133.767	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.6	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Monte Carlo Island	AK
103695	Point Lockwood, Woewodski Island, Wrangell Narrows, Alaska	NOS	9451263	56.5583	-132.963	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.729999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Lockwood	AK
103696	Beecher Pass, Wrangell Narrows, Alaska	NOS	9451287	56.595	-132.987	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beecher Pass	AK
103697	Anchor Point, Wrangell Narrows, Alaska	NOS	9451317	56.6383	-132.927	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point	AK
103698	Papke's Landing, Wrangell Narrows, Alaska	NOS	9451346	56.6767	-132.933	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.540000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Papke's Landing	AK
103699	The Summit, Keku Strait, Alaska	NOS	9451349	56.68242222222222	-133.7369083333333	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Summit	AK
103701	Leconte Bay, Frederick Sound, Alaska	NOS	9451422	56.7883	-132.502	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LECONTE BAY	AK
103702	Turn Point, Alaska	NOS	9451434	56.8	-132.98	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.34	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point	AK
103703	Entrance Island, Keku Strait, Alaska	NOS	9451438	56.8117	-133.787	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance Island	AK
103704	Red Bluff Bay, Baranof Island, Alaska	NOS	9451467	56.8567	-134.723	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.789999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bluff Bay, Baranof Island	AK
103705	Saginaw Bay, Kuiu Island, Frederick Sound, Alaska	NOS	9451497	56.90333333333334	-134.3030555555556	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saginaw Bay, Kuiu Island	AK
103706	Kake Harbor, Keku Strait, Alaska	NOS	9451528	56.94830555555556	-133.8947222222222	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.509999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kake Harbor, Keku Strait	AK
103707	Sitka, Baronof Island, Sitka Sound, Alaska	NOS	9451600	57.05169444444444	-135.342	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.290000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitka	AK
103708	Baranof, Warm Spring Bay, Alaska	NOS	9451625	57.08833333333333	-134.825	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baranof,  Warm Spring Bay	AK
103709	Whitestone Narrows, Neva Strait, Alaska	NOS	9451741	57.25	-135.567	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.319999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WHITESTONE NARROWS, Neva Strait	AK
103710	The Brothers, Stephens Passage, Alaska	NOS	9451785	57.295	-133.797	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THE BROTHERS, STEPHENS PASSAGE	AK
103711	Scraggy Island, Alaska	NOS	9451805	57.34	-135.707	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scraggy Island	AK
103712	Sergius Narrows, Alaska	NOS	9451853	57.41	-135.627	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.97	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sergius Narrows	AK
103713	Provorotni Island, Alaska	NOS	9451936	57.515	-135.555	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.930000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Provorotni Island	AK
103714	Target Island, Mitchell Bay, Kootznahoo Inlet, Alaska	NOS	9451953	57.5333	-134.417	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.710000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Target Island, Mitchell Bay	AK
103715	Juneau, Gastineau Channel, Stephens Pass, Alaska	NOS	9452210	58.2988	-134.4106	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau	AK
103716	Hawk Inlet entrance, Alaska	NOS	9452294	58.085	-134.777	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawk Inlet	AK
103717	False Bay, Chatham Strait, Alaska	NOS	9452328	57.9667	-134.935	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	False Bay, Chatham Strait	AK
103718	Tenakee Springs, Tenakee Inlet, Alaska	NOS	9452386	57.77930555555555	-135.2194722222222	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.95	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tenakee Springs	AK
103719	Skagway, Taiya Inlet, Lynn Canal, Alaska	NOS	9452400	59.4508	-135.328	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagway, Taiya Inlet	AK
103720	Chilkat Inlet, Lynn Canal, Alaska	NOS	9452421	59.17	-135.4	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHILKAT INLET	AK
103721	Hoonah, Port Fredrick, Alaska	NOS	9452438	58.10755555555556	-135.4441944444444	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.910000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hoonah, Port Fredrick	AK
103722	Bartlett Cove, Glacier Bay, Alaska	NOS	9452534	58.45669937133789	-135.88299560546875	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.719999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BARTLETT COVE, GLACIER BAY	AK
106058	Lovell Island, 1.3 nmi north of (depth 4 ft), Massachusetts Current	NOS	BOS1108_9	42.35498	-70.9319	:America/New_York	USA	knots	29	198	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovell Island, 1.3nm north of	MA
103724	Pelican Harbor, Lisianski Inlet, Alaska	NOS	9452611	57.95777777777778	-136.2267777777778	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pelican Harbor, Lisianski Inlet, AK	AK
103725	Elfin Cove, Port Althorp, Cross Sound, Alaska	NOS	9452634	58.19472222222223	-136.3469444444444	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elfin Cove	AK
103726	Tarr Inlet, Glacier Bay, Alaska	NOS	9452749	58.96477777777778	-136.8775833333333	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.780000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tarr Inlet, Glacier Bay	AK
103727	Yakutat, Yakutat Bay, Alaska	NOS	9453220	59.5483333	-139.7330556	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yakutat, Yakutat Bay	AK
103728	Tyndall Glacier, Icy Bay, Alaska	NOS	9453431	60.07830047607422	-141.27499389648438	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.170000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TYNDALL GLACIER, ICY BAY	AK
103729	Moraine Bay, Icy Bay, Alaska	NOS	9453443	59.93000030517578	-141.36300659179688	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.130000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moraine Bay	AK
103730	Cordova, Orca Inlet, Prince William Sd, Alaska	NOS	9454050	60.5575	-145.7554083333333	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.739999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cordova	AK
103731	Gravina River, Prince William Sound, Alaska	NOS	9454153	60.766700744628906	-146.0845947265625	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAVINA RIVER	AK
103732	Valdez, Prince William Sound, Alaska	NOS	9454240	61.125	-146.36199951171875	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valdez	AK
103733	Cape Hinchinbrook, Hinchinbrook Island, Alaska	NOS	9454329	60.23830032348633	-146.6479949951172	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.949999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Hichinbrook	AK
103734	Perch Point, Montague Island, Alaska	NOS	9454561	60.1267	-147.395	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Perch Point	AK
103735	Wooded Islands, Montague Island, Alaska	NOS	9454562	59.875	-147.403	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.390000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wooded Island	AK
103736	Seal Island, Alaska	NOS	9454564	60.425	-147.41	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SEAL ISLAND	AK
106059	South Channel Aldridge Ledge (depth 30 ft), Massachusetts Current	NOS	BOS1109_1	42.34958	-70.91286	:America/New_York	USA	knots	39	219	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Channel Aldridge Ledge	MA
103738	Montague Island, Alaska	NOS	9454616	60.025	-147.592	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Island	AK
103739	South Arm, Knight Island, Bay of Isles, Alaska	NOS	9454652	60.3667	-147.7	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH ARM, KNIGHT ISLAND, BAY OF ISLES	AK
103740	Snug Harbor, Knight Island, Alaska	NOS	9454662	60.25	-147.717	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snug Harbor	AK
103741	College Fiord, Prince William Sound, Alaska	NOS	9454672	61.2057991027832	-147.7613983154297	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COLLEGE FIORD	AK
103742	Herring Point, Knight Island, Prince William Sound, Alaska	NOS	9454691	60.475	-147.792	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HERRING POINT, KNIGHT ISLAND, PR WIL SND	AK
103743	South Bay, Perry Island, Alaska	NOS	9454721	60.6717	-147.932	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.36	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PERRY ISLAND (SOUTH BAY)	AK
103744	Guguak, Alaska	NOS	9454751	60.1	-148.038	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guguak	AK
103745	Bainbridge Point, Bainbridge Island, Prince William Sound, Alaska	NOS	9454755	60.19670104980469	-148.04200744628906	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bainbridge Point	AK
103746	Point Elrington, Elrington Island, Prince William Sound, Alaska	NOS	9454814	59.9383	-148.227	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.680000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Erlington, Erlington Island	AK
103747	Whittier, Prince William Sound, Alaska	NOS	9454949	60.7783	-148.665	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whittier	AK
103748	Seward, Resurrection Bay, Alaska	NOS	9455090	60.1193	-149.4281083333333	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seward	AK
103749	Agnes Cove, Aialik Peninsula, Alaska	NOS	9455120	59.7733	-149.588	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.59	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AGNES COVE	AK
103750	Aialik Bay, north end, Alaska	NOS	9455145	59.9533	-149.715	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.530000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AIALIK BAY, NORTH END	AK
103751	Aialik Sill, Aialik Bay, Alaska	NOS	9455146	59.885	-149.718	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.559999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AIALIK SILL, AIALIK BAY	AK
103752	Camp Cove, Harris Peninsula, Alaska	NOS	9455151	59.6933	-149.748	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAMP COVE, HARRIS PENNINSULA	AK
103753	Crater Bay, Harris Bay, Alaska	NOS	9455159	59.7133	-149.787	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRATER BAY, HARRIS BAY	AK
103754	Upper Northwestern Fiord, Harris Bay, Alaska	NOS	9455204	59.79	-150.032	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UPPER NORTHWESTERN FIORD	AK
103755	McCarty Fiord, Kenai Peninsula, Alaska	NOS	9455258	59.511600494384766	-150.35519409179688	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.93	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	McCarty Fiord	AK
103756	Seldovia, Cook Inlet, Alaska	NOS	9455500	59.44049835205078	-151.7198944091797	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.559999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seldovia	AK
103757	Kasitsna Bay, Kachemak Bay, Alaska	NOS	9455517	59.46830555555555	-151.565	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kasitsna Bay, Kachemak Bay	AK
103758	Homer, Coal Point, Kachemak Bay, Cook Inlet, Alaska	NOS	9455558	59.60139846801758	-151.4105987548828	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COAL POINT	AK
103759	Bear Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455595	59.725	-151.023	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Cove, Kachemak Bay	AK
103760	Anchor Point, Cook Inlet, Alaska	NOS	9455606	59.77197222222223	-151.8670277777778	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.709999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, Cook Inlet	AK
103761	Ninilchik, Cook Inlet, Alaska	NOS	9455653	60.055	-151.682	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ninilchik, Cook Inlet	AK
103762	Cape Kasilof, Cook Inlet, Alaska	NOS	9455711	60.3367	-151.38	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kasilof	AK
103763	Kaligan Island (north end), Cook Inlet, Alaska	NOS	9455732	60.51169967651367	-151.95199584960938	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KALIGAN ISLAND (NORTH END),  COOK INLET	AK
103764	Chinulna Point, Cook Inlet, Alaska	NOS	9455735	60.5033	-151.283	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINULNA POINT, COOK INLET	AK
103765	Nikiski, Cook Inlet, Alaska	NOS	9455760	60.6833333	-151.3980556	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.290000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikiski	AK
103766	Point Possession, Alaska	NOS	9455866	61.0367	-150.413	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	14.260000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Possession	AK
103767	North Foreland, Alaska	NOS	9455869	61.04330555555556	-151.163	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.500000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Foreland	AK
103768	Fire Island, Cook Inlet, Alaska	NOS	9455912	61.1733	-150.213	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	14.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, Cook Inlet	AK
103769	Anchorage, Knik Arm, Cook Inlet, Alaska	NOS	9455920	61.2375	-149.8903888888889	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	16.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchorage	AK
103770	Port Mackenzie, Cook Inlet, Alaska	NOS	9455934	61.2682991027832	-149.91700744628906	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	16.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Mackenzie	AK
103771	Goose Creek, Knik Arm, Cook Inlet, Alaska	NOS	9455963	61.3933	-149.847	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	17.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goose Creek, Cook Inlet	AK
103772	Southwest Iniskin Bay, Cook Inlet, Alaska	NOS	9456525	59.65169906616211	-153.4680938720703	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.729999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SW Iniskin Bay	AK
103773	Nukshak Island, Shelikof Strait, Alaska	NOS	9456717	58.3917	-153.958	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NUKSHAK ISLAND, SHELIKOF STRAIT	AK
103774	Aguchik Island, Kukak Bay, Alaska	NOS	9456901	58.29	-154.27	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.22	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AGUCHIK ISLAND, KUKAK BAY	AK
103775	Ouzinkie, Spruce Island, Alaska	NOS	9457287	57.9217	-152.498	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ouzinkie, Spruce Island	AK
103776	Kodiak, Women's Bay, Alaska	NOS	9457292	57.7302778	-152.5138889	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kodiak Island	AK
103777	Uzkosti Point, Kupreanof Strait, Alaska	NOS	9457376	57.9283	-152.812	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uzkosti Point	AK
103778	Port Lions, Kodiak Island, Alaska	NOS	9457391	57.87347222222222	-152.8671111111111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.789999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Lions, AK	AK
106049	Marblehead Channel (depth 17 ft), Salem Sound, Massachusetts Current	NOS	BOS1105_5	42.5007	-70.82023	:America/New_York	USA	knots	\N	338.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marblehead Channel	MA
103780	Nachalni Island, Kupreanof Strait, Alaska	NOS	9457407	57.9783	-152.925	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nachalni Island	AK
103781	Terror Bay (southwest), Kodiak Island, Alaska	NOS	9457493	57.74402777777778	-153.1954722222222	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.39	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SW Terror Bay	AK
103782	Sitkalidak Island GPS Tide Buoy, Alaska	NOS	9457512	56.96572	-153.252194	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.340000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitkalidak Island GPS Tide Buoy	AK
103783	Old Harbor, Kodiak Island, Alaska	NOS	9457527	57.20277777777778	-153.3038888888889	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.430000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OLD HARBOR, KODIAK ISLAND	AK
103784	West Raspberry Island, Alaska	NOS	9457535	58.10716666666666	-153.3401111111111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.3500000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Raspberry Island	AK
103785	Japanese Bay, Kodiak Island, Alaska	NOS	9457634	56.96	-153.687	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Japanese Bay, Kodiak Island	AK
103786	Larsen Bay, Kodiak Island, Alaska	NOS	9457724	57.5333	-153.99	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.140000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Larsen Bay, Kodiak Island, AK	AK
103787	Geese Island GPS Tide Buoy, Alaska	NOS	9457726	56.594694	-153.996028	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.609999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Geese Island GPS Tide Buoy	AK
103789	Alitak, Lazy Bay, Alaska	NOS	9457804	56.89738888888889	-154.248	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.170000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alitak	AK
103790	Puale Bay, Alaska	NOS	9458209	57.7067	-155.393	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puale Bay	AK
103791	Chirikof Island, Alaska	NOS	9458293	55.8083	-155.74	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.609999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chirikof Island	AK
103792	Chowiet Island, Semidi Island, Alaska	NOS	9458519	56.0517	-156.698	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chowiet island	AK
103794	Castle Bay, Northwest Arm, Alaska	NOS	9458907	56.2317	-158.347	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.640000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Castle Bay	AK
103795	Hump Island, Kuiukta Bay, Alaska	NOS	9458964	56.1133	-158.598	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hump Island, Kuiukta Bay	AK
103796	Mitrofania Island, Alaska	NOS	9459016	55.89	-158.82	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mitrofania Island	AK
103797	Herendeen Island, Shumagin Islands, Alaska	NOS	9459163	55.06555555555556	-159.4186666666667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Herendeen Island, Shumagin Islands	AK
103798	Bird Island, Shumagin Bank, Shumagin Islands, Alaska	NOS	9459251	54.83522222222222	-159.7595555555556	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bird Island, Shumagin Bank	AK
103799	Sand Point, Popof Island, Alaska	NOS	9459450	55.33172222222223	-160.5043333333333	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sand Point	AK
103800	Zachary Bay, Unga Island, Shumagin Islands, Alaska	NOS	9459465	55.334999084472656	-160.61700439453125	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.969999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZACHARY BAY, UNGA IS (N. SIDE)	AK
103801	Dolgoi Harbor, Dolgoi Island, Alaska	NOS	9459758	55.121700286865234	-161.79200744628906	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolgoi Harbor, Dolgoi Island	AK
103802	King Cove, Deer Passage, Alaska	NOS	9459881	55.05988888888889	-162.3261111111111	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	King Cove	AK
103803	Cold Bay, Alaska	NOS	9459949	55.2083	-162.698	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cold Bay	AK
103804	Attu, Massacre Bay, Alaska	NOS	9460150	52.84000015258789	173.19500732421875	:America/Adak	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	A set of tidal harmonic constants based on data collected prior to 1960 have\nbeen calculated for use in generating tide predictions at this location. Due\nto the limitations of these historical observations, MSL is held fixed as the\nstation datum and MLLW is referenced to MSL in order to remove any reference\nto the terrestrial system. The removal of the terrestrial reference enables\nthe relationship between MSL and MLLW to remain consistent over time and not\nrequire periodic National Tidal Datum Epoch (NTDE) updates. Due to the remote\nnature of this location, there are no immediate plans to collect updated water\nlevels data in the area. If you require additional assistance, please contact\nCO-PS Customer Service via email at Tide.Predictions@noaa.gov.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.94	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ATTU, MASSACRE BAY	AK
103805	Sweeper Cove, Adak Island, Alaska	NOS	9461380	51.86063888888889	-176.6375833333333	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Adak Island	AK
103806	Atka, Nazan Bay, Atka Island, Alaska	NOS	9461710	52.23194444444444	-174.1725	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9699999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atka	AK
103807	Nikolski, Umnak Island, Alaska	NOS	9462450	52.94061	-168.8713055557675	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikolski	AK
103808	Unalaska, Dutch Harbor, Alaska	NOS	9462620	53.87919444444444	-166.5403055555556	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0799999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalaska	AK
103809	Biorka Village, Biverly Inlet, Alaska	NOS	9462645	53.82891666666667	-166.21625	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biorka Village, Biverly Inlet	AK
103810	Reef Bight, Alaska	NOS	9462662	54.13072222222223	-166.0993333333333	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.009999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reef Bight	AK
103811	Broad Bight, Akutan Island, Aleutian Islands, Alaska	NOS	9462676	54.06458333333333	-165.9370555555556	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Broad Bight	AK
103812	Akutan, Aleutian Islands, Alaska	NOS	9462694	54.13327777777778	-165.7773055555556	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1599999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan, Alaska	AK
103813	Green Bight, Akutan Island, Aleutian Islands, Alaska	NOS	9462705	54.11027777777778	-165.6613888888889	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8700000000000045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Bight	AK
103814	Surf Bay, Akutan Bay, Alaska	NOS	9462711	54.15083333333333	-165.615	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Surf Bay, Akutan Bay	AK
103815	Akun Cove, Akun Island, Aleutian Islands, Alaska	NOS	9462719	54.2333	-165.533	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akun Cove, Akun Island	AK
103816	Trident Bay, Akun Island, Aleutian Islands, Alaska	NOS	9462721	54.14	-165.527	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.210000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trident Bay, Akun Island	AK
103817	Rootok Island, Rootok Strait, Alaska	NOS	9462723	54.05222222222222	-165.5141666666667	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.830000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rootok Island	AK
103818	Tigalda Bay, Tigalda Island, Alaska	NOS	9462782	54.12	-164.977	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6199999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tigalda Bay, Tigalda Island	AK
103819	SE Tigalda Island, Aleutian Islands, Alaska	NOS	9462786	54.10180555555556	-164.9415833333333	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.960000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SE Tigalda Island, Pacific Ocean	AK
103820	Cape Sarichef, Unimak Island, Alaska	NOS	9462787	54.6	-164.928	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Sarichef, Unimak Island	AK
103821	Scotch Cap, Unimak Island, Alaska	NOS	9462808	54.39363888888889	-164.7457222222222	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scotch Cap, Unimak Island, AK	AK
103822	Cape Chunak, Unimak Island, Alaska	NOS	9462941	55.06427777777778	-163.5341666666667	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.289999999999992	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chunak, AK	AK
103823	Neumans Cove, Bechevin Bay, Aleutian Islands, Alaska	NOS	9462948	54.9667	-163.44	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEUMANS COVE	AK
103824	False Pass, Isanotski Strait, Unimak Island, Alaska	NOS	9462955	54.8583	-163.407	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	False Pass, Unimak Island	AK
103825	Isanotski Strait entrance, Aleutian Islands, Alaska	NOS	9462961	54.77844444444445	-163.3642777777778	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ISANOTSKI STRAIT ENTRANCE	AK
103826	Port Moller, Bristol Bay, Alaska	NOS	9463502	55.9858333	-160.5736111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.849999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Moller	AK
103827	Zapadni Bay, St. George Island, Alaska	NOS	9463885	56.56669998168945	-169.6667022705078	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZAPADNI BAY, ST. GEORGE ISLAND	AK
103828	Meshik, Port Heiden, Bristol Bay, Alaska	NOS	9464075	56.90829849243164	-158.68490600585938	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.420000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Meshik, Port Heiden	AK
103829	Village Cove, St. Paul Island, Pribilof Islands, Alaska	NOS	9464212	57.125301361083984	-170.2852020263672	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Village Cove, St Paul Island	AK
103830	Dago Creek Mouth, Ugashik Bay, Bristol Bay, Alaska	NOS	9464512	57.61479949951172	-157.60069274902344	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.880000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dago Creek Mouth, Ugashik Bay	AK
103831	Egegik, Egegik River, Alaska	NOS	9464874	58.21670150756836	-157.375	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.390000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EGEGIK, EGEGIK R, BRISTOL BAY	AK
103849	Kwigillingok, Alaska	NOS	9465911	59.87975	-163.166361	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kwigillingok	AK
103850	Kipnuk, Yukon Delta, Alaska	NOS	9465951	59.943199157714844	-164.04339599609375	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kipnuk, Kuguklik River	AK
103832	Cape Constantine, Nushagak Peninsula, Bristol Bay, Alaska	NOS	9464961	58.52170181274414	-159.15199279785156	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.050000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE CONSTANTINE, NUSHAGAK PENINSULA	AK
103833	Protection Point, Nushagak Bay, Alaska	NOS	9465056	58.5	-158.712	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PROTECTION POINT, NUSHAGAK BAY	AK
106050	Marblehead Channel (depth 4 ft), Salem Sound, Massachusetts Current	NOS	BOS1105_9	42.5007	-70.82023	:America/New_York	USA	knots	171	280	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marblehead Channel	MA
103835	Cape Peirce, west side, Bristol Bay, Alaska	NOS	9465137	58.62670135498047	-161.83700561523438	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8100000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE PEIRCE, WEST SIDE	AK
103837	Naknek, Naknek River, Kvichak Bay, Alaska	NOS	9465203	58.73210144042969	-156.98330688476562	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naknek	AK
103840	Clarks Point, Nushagak Bay, Alaska	NOS	9465261	58.8483	-158.552	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.97	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLARKS POINT, NUSHAGAK BAY	AK
103841	Kulukak Point, Kulukak Bay, Alaska	NOS	9465265	58.84000015258789	-159.64700317382812	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.060000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KULUKAK POINT	AK
103842	Summit Island, NE side, Togiak Bay, Alaska	NOS	9465283	58.8467	-160.21	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.\nNOS uses UTC-11 for LST; AKST (since 1983) is UTC-9	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.6899999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NE SIDE SUMMIT ISLAND, TOGIAK BAY A	AK
103843	Snag Point, Dillingham, Alaska	NOS	9465374	59.04	-158.447	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.839999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snag Point, Dillingham	AK
103844	Platinum, Alaska	NOS	9465396	59.0467	-161.818	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8399999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Platinum	AK
103845	Levelock, Kvichak River, Alaska	NOS	9465419	59.11330032348633	-156.83200073242188	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.219999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LEVELOCK, KVICHAK RIVER	AK
103846	Goodnews Bay, Alaska	NOS	9465438	59.11439895629883	-161.5843963623047	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.869999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goodnews Bay	AK
103847	Carter Bay, Kuskokwim Bay, Alaska	NOS	9465601	59.37801666666667	-162.0293333333333	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carter Bay, Kuskokwim Bay	AK
103848	Quinhagak (Kwinak), Kuskokwim River, Alaska	NOS	9465831	59.75055277777778	-161.9154361111111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.449999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quinhagak (Kwinak), Kushkokwin River	AK
103836	High Island, Bristol Bay, Alaska	NOS	9465173	58.721699	-160.427	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.61	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HIGH ISLAND, BRISTOL BAY	AK
103839	Estus Point, Hagemeister Strait, Alaska	NOS	9465249	58.8083	-161.1	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.94	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESTUS POINT, HAGEMEISTER STRAIT	AK
103851	Kinak Bay, Yukon Delta, Alaska	NOS	9465953	59.947528	-164.2107	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.760000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kinak Bay	AK
103852	Cape Corwin GPS Tide Buoy, Nunivak Island, Alaska	NOS	9465988	60.004639	-165.590972	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.729999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Corwin GPS Tide Buoy	AK
103853	Eastern Nunivak Island, Alaska	NOS	9466012	60.04294	-165.680583	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7700000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eastern Nunivak Island	AK
103854	Popokamute (Kokokamute), Kuskokwim River, Alaska	NOS	9466057	60.12327777777778	-162.5003611111111	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.050000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Popokamute (Kokokamute), Kuskokwim River	AK
103855	Chefornak, Kinia River, Yukon Delta, Alaska	NOS	9466084	60.159400939941406	-164.27259826660156	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chefornak	AK
103856	Helmick Point (SE of), Kuskokwim River, Alaska	NOS	9466153	60.270301818847656	-162.4102020263672	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.760000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Helmick Point	AK
103857	Tuntutuliak, Tagayarak River, Alaska	NOS	9466197	60.34149932861328	-162.68600463867188	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tuntutuliak	AK
103858	Mekoryuk, Mekoryuk River entrance, Nunivak Island, Alaska	NOS	9466217	60.4167	-166.167	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8699999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mekoryuk, Mekoryuk River Entrance	AK
103859	Tooksook Bay, Nelson Island, Yukon Delta, Alaska	NOS	9466298	60.5167	-165.133	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.169999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nelson Island, Tooksook Bay	AK
103860	Lomavik, Kuskokwim River, Alaska	NOS	9466328	60.554298400878906	-162.29710388183594	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lomavik	AK
103861	Bethel, Kuskokwim River, Alaska	NOS	9466477	60.8	-161.75	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bethel, Kuskokwim River, AK	AK
103862	Newtok, Ningliq River, Yukon Delta, Alaska	NOS	9466563	60.93450164794922	-164.63870239257812	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newtok	AK
103863	Dall Point, Hooper Bay, Yukon Delta, Alaska	NOS	9466931	61.5317	-166.148	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8399999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dall Point	AK
103864	Kun River, Scammon Bay, Yukon Delta, Alaska	NOS	9467124	61.84170150756836	-165.56700134277344	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kun River	AK
103865	Nunam Iqua (Sheldon Point), Yukon Delta, Alaska	NOS	9467551	62.53294444444445	-164.8452777777778	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nunam Iqua (Sheldon Point)	AK
103866	Alakanuk, Yukon River, Alaska	NOS	9467645	62.687198638916016	-164.66690063476562	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9100000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alakanuk, Yukon River	AK
103867	Emmonak, Kwiguk Pass, Yukon Delta, Alaska	NOS	9467701	62.77750015258789	-164.54690551757812	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Emmonak	AK
103868	Kotlik, Kotlik River, Norton Sound, Alaska	NOS	9467861	63.037899017333984	-163.52650451660156	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kotlik, AK	AK
103869	Northeast Cape, St. Lawrence Island, Alaska	NOS	9468039	63.3167	-168.967	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northeast Cape, St. Lawrence Island	AK
103871	Stebbins, Norton Sound, Alaska	NOS	9468151	63.525001525878906	-162.29299926757812	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.\nNOS uses UTC-11 for LST; AKST (since 1983) is UTC-9	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2100000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	STEBBINS, NORTON SOUND, EAST	AK
103872	Savoonga, St. Lawrence Island, Alaska	NOS	9468258	63.67908333333333	-170.5371111111111	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2800000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Savoonga	AK
103873	Kavalghak Bay, St. Lawrence Island, Alaska	NOS	9468261	63.682861	-171.750194	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2199999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kavalghak Bay, AK	AK
106051	Northeast Grave (depth 45 ft), Massachusetts Current	NOS	BOS1106_1	42.37176	-70.8618	:America/New_York	USA	knots	114	301	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northeast Grave	MA
103875	Unalakleet, Alaska	NOS	9468333	63.875	-160.78799438476562	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.55	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalakleet	AK
103876	Shaktoolik, Alaska	NOS	9468691	64.38022222222222	-161.2351388888889	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6699999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shaktoolik	AK
103877	Nome, Norton Sound, Alaska	NOS	9468756	64.49461111111111	-165.4396388888889	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nome, Norton Sound	AK
103878	Golovin, Golovnin Lagoon entrance, Norton Sound, Alaska	NOS	9468793	64.54630279541016	-163.0316925048828	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5799999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golovin, Golovnin Lagoon Entrance	AK
103879	Upper Golovnin Lagoon, Norton Sound, Alaska	NOS	9468841	64.62079620361328	-163.1490020751953	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4699999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upper Golovnin Lagoon	AK
103880	Elim, Norton Bay, Alaska	NOS	9468863	64.6167	-162.248	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.\nNOS uses UTC-11 for LST; AKST (since 1983) is UTC-9	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ELIM, NORTON BAY	AK
103881	Koyuk, Norton Bay, Alaska	NOS	9469031	64.93119812011719	-161.1508026123047	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Koyuk	AK
103882	Imuruk Basin, Alaska	NOS	9469146	65.11840057373047	-165.47210693359375	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.21999999999999886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Imuruk Basin	AK
103883	Point Spencer, Port Clarence, Norton Sound, Alaska	NOS	9469237	65.2567	-166.847	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Spencer, Port Clarence	AK
103884	Teller, Port Clarence, Alaska	NOS	9469239	65.2667	-166.353	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TELLER, PORT CLARENCE	AK
103885	Lost River, Seward Peninsula, Alaska	NOS	9469338	65.39	-167.145	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5200000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LOST RIVER, SEWARD PENINSULA	AK
103886	Tin City, Bering Sea, Alaska	NOS	9469439	65.55833333333334	-167.975	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.46999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tin City, Bering Sea	AK
103887	Outside Lopp Lagoon, Alaska	NOS	9469515	65.728806	-168.032139	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.480000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Outside Lopp Lagoon	AK
103888	Buckland, Buckland River, Alaska	NOS	9469677	65.97550201416016	-161.125	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1400000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buckland	AK
103889	Deering, Kotzebue Sound, Alaska	NOS	9469751	66.09716666666667	-162.7404722222222	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9499999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deering	AK
103890	Goodhope Bay, Kotzebue Sound, Alaska	NOS	9469833	66.23030090332031	-163.9040985107422	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8800000000000026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goodhope Bay	AK
103891	Shishmaref Inlet 2, Alaska	NOS	9469854	66.2633	-166.02	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shishmaref Inlet 2	AK
103892	Cape Espenberg, Kotzebue Sound, Alaska	NOS	9490096	66.58569444444444	-164.2508333333333	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5300000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Espenberg, Kotzebue Sound	AK
103893	Kotzebue, Kotzebue Sound, Alaska	NOS	9490424	66.9017	-162.582	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kotzebue	AK
103894	Cape Krusenstern, Kotzebue Sound, Alaska	NOS	9490571	67.05419444444445	-163.3212777777778	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.23000000000000398	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Krusenstern	AK
103895	Red Dog Dock, Alaska	NOS	9491094	67.57580555555556	-164.0643888888889	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Dog Dock	AK
103896	Kivalina, Alaska	NOS	9491253	67.7267	-164.592	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kivalina	AK
103897	Point Hope, Chukchi Sea, Alaska	NOS	9491873	68.3417	-166.808	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3299999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Hope	AK
103898	Wainwright, Chukchi Sea, Alaska	NOS	9494212	70.643798828125	-160.06509399414062	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.29000000000000625	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wainwright	AK
103899	Barrow (offshore), Alaska	NOS	9494935	71.36011111111111	-156.7298611111111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3100000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barrow Offshore	AK
103900	Prudhoe Bay, Alaska	NOS	9497645	70.4113889	-148.5316667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3399999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Prudhoe Bay	AK
106052	Northeast Grave (depth 25 ft), Massachusetts Current	NOS	BOS1106_7	42.37176	-70.8618	:America/New_York	USA	knots	90	266	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northeast Grave	MA
103903	Barter Island, Alaska	NOS	9499176	70.12855555555555	-143.6110277777778	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.28000000000000025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barter Island	AK
103904	Grapetree Bay, St. Croix, Virgin Islands	NOS	9751082	17.740699768066406	-64.60579681396484	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grapetree Bay	VI
103905	Teague Bay, St. Croix, Virgin Islands	NOS	9751084	17.7549991607666	-64.60240173339844	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Teague Bay	VI
103902	Cross Island (Dinkum Sands), Alaska	NOS	9497778	70.4917	-147.95	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CROSS ISLAND, (DINKUM SANDS)	AK
103906	Fareham Bay, St. Croix, Virgin Islands	NOS	9751219	17.709999084472656	-64.68280029296875	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fareham Bay	VI
103907	Johns Folly Bay, St. John, Virgin Islands	NOS	9751274	18.316999435424805	-64.70210266113281	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johns Folly Bay	VI
103908	Leinster Point, Leinster Bay, St. John, Virgin Islands	NOS	9751309	18.36761111111111	-64.72072222222222	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5299999999999976	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Leinster Point, Leinster Bay, St. John's	VI
103909	Christiansted Harbor, St. Croix, Virgin Islands	NOS	9751364	17.74769444444445	-64.69838888888889	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.379999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Christiansted Harbor, St Croix	VI
103910	Coral Harbor, St. John, Virgin Islands	NOS	9751373	18.34830093383789	-64.7166976928711	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST JOHN'S ISLAND, CORAL HARBOR	VI
103911	Lameshur Bay, St. John, Virgin Islands	NOS	9751381	18.31825	-64.72422222222222	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lameshur Bay, St John	VI
103912	Fish Bay, St. John, Virgin Islands	NOS	9751388	18.31920051574707	-64.76180267333984	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fish Bay	VI
103913	Salt River Bay, St. Croix, Virgin Islands	NOS	9751389	17.775299072265625	-64.76229858398438	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Salt River Bay	VI
103914	Lime Tree Bay, St. Croix, Virgin Islands	NOS	9751401	17.694700241088867	-64.75379943847656	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.37000000000000455	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Limetree Bay	VI
103915	Hawksnest Beach, St. John, Virgin Islands	NOS	9751417	18.348899841308594	-64.77739715576172	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawksnest Beach	VI
103916	Haulover Bay, St. John, Virgin Islands	NOS	9751419	18.349700927734375	-64.67960357666016	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.46000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HAULOVER BAY, ST. JOHNS	VI
103917	Lovango Cay, St. John, Virgin Islands	NOS	9751467	18.36066666666667	-64.80352777777777	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.48999999999999844	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovango Cay, St. John	VI
103918	Cruz Bay, St. John, Virgin Islands	NOS	9751472	18.33289909362793	-64.79409790039062	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.45999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cruz Bay	VI
103919	Dog Island, St. Thomas, Virgin Islands	NOS	9751494	18.29713888888889	-64.81775	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dog Island, St. Thomas	VI
103920	Pavilion Point, St. Thomas, Virgin Islands	NOS	9751561	18.33989906311035	-64.85240173339844	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5300000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pavillion Point	VI
103922	Jersey Bay, St. Thomas, Virgin Islands	NOS	9751574	18.318099975585938	-64.8594970703125	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jersey Bay	VI
103923	Water Bay, St. Thomas, Virgin Islands	NOS	9751583	18.34894444444445	-64.86416666666666	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5599999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Water Bay	VI
103924	Fredericksted, St. Croix, Virgin Islands	NOS	9751584	17.7133	-64.8833	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fredericksted, St. Croix	VI
103925	Charlotte Amalie, St. Thomas, Virgin Islands	NOS	9751639	18.3305833	-64.9258056	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3799999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charlotte Amalie	VI
103926	Magens Bay, St. Thomas, Virgin Islands	NOS	9751693	18.366300582885742	-64.9220962524414	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Magens Bay	VI
103927	Crown Bay, St. Thomas, Virgin Islands	NOS	9751749	18.33289909362793	-64.95169830322266	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.379999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crown Bay	VI
103928	Dorothea Bay, St. Thomas, Virgin Islands	NOS	9751768	18.37125	-64.96347222222222	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5799999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dorothea Bay, Saint Thomas	VI
103929	Botany Bay, St. Thomas, Virgin Islands	NOS	9751774	18.3633	-65.035	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Botany Bay, St. Thomas	VI
103930	Culebrita, Puerto Rico	NOS	9752062	18.319400787353516	-65.23809814453125	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5799999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Culebrita	PR
103931	Culebra, Puerto Rico	NOS	9752235	18.30086111111111	-65.30247222222222	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5399999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Culebra	PR
103932	Punta la Plata, Vieques, Puerto Rico	NOS	9752426	18.116600036621094	-65.3729019165039	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.379999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Playa la Plata	PR
103933	Isabel Segunda, Vieques, Puerto Rico	NOS	9752619	18.15252777777778	-65.44380555555556	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isabel Segunda, Vieques Island	PR
103934	Esperanza, Vieques, Puerto Rico	NOS	9752695	18.09386111111111	-65.47136111111111	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Esperanza, Vieques Island	PR
103935	Mosquito Pier, Vieques, Puerto Rico	NOS	9752813	18.14889907836914	-65.51490020751953	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mosquito Pier	PR
103936	Isla Palominos, Puerto Rico	NOS	9752962	18.34497222222222	-65.5695	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7099999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isla Palominos	PR
103937	Punta Arenas, Vieques, Puerto Rico	NOS	9752998	18.11240005493164	-65.57589721679688	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUNTA ARENAS, VIEQUES ISLAND	PR
103938	Ceiba, Roosevelt Roads, Puerto Rico	NOS	9753182	18.228099822998047	-65.61969757080078	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.48999999999999844	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ceiba, Roosevelt Road	PR
103939	Fajardo, Puerto Rico	NOS	9753216	18.3352778	-65.6311111	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fajardo	PR
103940	Naguabo, Puerto Rico	NOS	9753641	18.18705555555556	-65.71138888888889	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naguabo	PR
103941	Luquillo, Puerto Rico	NOS	9753766	18.38170051574707	-65.73650360107422	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7399999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Luquillo, PR	PR
103942	Palmas del Mar, Puerto Rico	NOS	9754057	18.078100204467773	-65.79560089111328	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Palmas del Mar	PR
103943	Yabucoa Harbor, Puerto Rico	NOS	9754228	18.05508333333333	-65.833	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.34999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yabucoa Harbor	PR
103944	Puerto Maunabo, Puerto Rico	NOS	9754487	17.99139976501465	-65.88880157470703	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puerto Maunabo	PR
103945	Boca de Cangrejos, Puerto Rico	NOS	9754986	18.456600189208984	-65.99150085449219	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOCA DE CANGREJOS	PR
103946	San Juan, La Puntilla, San Juan Bay, Puerto Rico	NOS	9755371	18.45894444444445	-66.11641666666667	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan, La Puntilla, San Juan Bay	PR
103947	Las Mareas, Puerto Rico	NOS	9755679	17.9283	-66.1583	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Las Mareas	PR
103948	Central Aguirre, Puerto Rico	NOS	9755971	17.950000762939453	-66.22640228271484	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3299999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Central Aguirre	PR
103949	Boca del Cibuco, Puerto Rico	NOS	9756567	18.485200881958008	-66.3843994140625	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boca del Cibuco	PR
103950	Santa Isabel, Puerto Rico	NOS	9756639	17.955	-66.4067	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Isabel	PR
103951	Ponce, Puerto Rico	NOS	9757487	17.969600677490234	-66.61990356445312	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ponce	PR
103952	Arecibo, Puerto Rico	NOS	9757809	18.48052777777778	-66.70236111111112	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arecibo	PR
103953	Peuelas (Punta Guayanilla), Puerto Rico	NOS	9758053	17.97252777777778	-66.76177777777778	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Penuelas (Punta Guayanilla)	PR
103954	Gunica, Puerto Rico	NOS	9758627	17.95800018310547	-66.90679931640625	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guanica	PR
103955	Magueyes Island, Caribbean Sea, Puerto Rico	NOS	9759110	17.97011111111111	-67.04638888888888	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Magueyes Island	PR
103956	Boquern, Puerto Rico	NOS	9759173	18.02400016784668	-67.17310333251953	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boqueron	PR
103957	Joyuda, Puerto Rico	NOS	9759183	18.115800857543945	-67.18319702148438	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Joyuda	PR
103958	Puerto Real, Puerto Rico	NOS	9759189	18.07480555555556	-67.18877777777777	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4200000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puerto Real	PR
103959	Baha Salinas, Puerto Rico	NOS	9759197	17.95144444444444	-67.19658333333334	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bahia Salinas	PR
103960	Mayagez, Puerto Rico	NOS	9759394	18.21883333333333	-67.16244444444445	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayaguez	PR
103961	Aguadilla, Crashboat Beach, Puerto Rico	NOS	9759412	18.45663888888889	-67.16458333333334	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.629999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aguadilla, Crashboat Beach	PR
103962	Punta Guanajibo, Mayagez, Puerto Rico	NOS	9759421	18.165000915527344	-67.18170166015625	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUNTA GUANAJIBO, MAYAGUES	PR
103963	Southeast Mona Island, Puerto Rico	NOS	9759866	18.06529998779297	-67.86609649658203	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southeast Mona Island	PR
103964	Mona Island, Puerto Rico	NOS	9759938	18.08928888888889	-67.93820833333334	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mona Island	PR
103033	Pungo River, Route 45, North Carolina	NOS	8653244	35.585201263427734	-76.48560333251953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.43999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pungo River NC 45	NC
103392	Bay Pomme d'Or, Louisiana	NOS	8761115	29.350608	-89.539944	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Pomme D'or	LA
102735	Augusta, MCRR Bridge, Kennebec River, Maine	NOS	8417144	44.32	-69.77028	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.91	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Augusta, MCRR Bridge, Kennebec River	ME
102811	Narragansett Pier, Narragansett Bay, Rhode Island	NOS	8454658	41.4217	-71.455	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NARRAGANSETT PIER	RI
102818	Sandy Point, Block Island Sound, Rhode Island	NOS	8459479	41.2283	-71.58	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY POINT, BLOCK IS, SOUND	RI
102832	Montauk Point Light, Long Island Sound, New York	NOS	8510321	41.0717	-71.8567	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MONTAUK POINT LIGHT	NY
102874	Worlds Fair Marina, Flushing Bay, New York	NOS	8517251	40.761	-73.85036111111111	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.7	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Worlds Fair Marina	NY
102875	College Pt, Ft. of 110th Street, Long Island, New York	NOS	8517276	40.7833	-73.8567	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COLLEGE PT, FT. OF 110TH ST, LI	NY
102887	Spuyten Duyvil Creek entrance, Hudson River, New York	NOS	8518903	40.8783	-73.925	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPUYTEN DUYVIL CK, ENT., HUDSON R,	NY
102894	Fort Wadsworth, The Narrows, Staten Island, New York	NOS	8519024	40.6067008972168	-74.05500030517578	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.46	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORT WADSWORTH, STATEN ISLAND	NY
102901	South Amboy, Raritan River, New Jersey	NOS	8531232	40.4917	-74.2817	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH AMBOY  RARITAN RIVER	NJ
102962	St. Michaels, Miles River, Chesapeake Bay, Maryland	NOS	8572342	38.7867	-76.2217	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MICHAELS, MILES RIVER	MD
102989	Cape Charles Harbor (USCG wharf), Chesapeake Bay, Virginia	NOS	8632366	37.2633	-76.02	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE CHARLES HBR (U.S. G. WHARF)	VA
103002	New Point, Virginia	NOS	8637289	37.3467	-76.2733	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.85	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW POINT	VA
103009	Burwell Bay, James River, Virginia	NOS	8638421	37.0567	-76.6683	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BURWELL BAY, JAMES RIVER	VA
103098	Savannah (Bull Street), Georgia	NOS	8670681	32.0817	-81.0917	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BULL STREET, SAVANNAH RIVER	GA
103973	Kamalo Harbor, Molokai Island, Hawaii	NOS	1613077	21.0483	-156.877	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102695	-00:16:00	0	\N	-00:37:00	0.1	\N	\N	\N	Kamalo Harbor	HI
103100	Palmer Johnson Shipyard, Wilmington River, Georgia	NOS	8670893	32.0233	-81.0467	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.98	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PALMER JOHNSON SHIPYARD, WILMINGTON R.	GA
103123	Cut 2N front range, St. Marys River, Georgia	NOS	8720012	30.7167	-81.3017	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.99	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUT 2N FRONT RANGE, ST MARYS RIVER ENTR	GA
103159	Daytona Beach (ocean), Florida	NOS	8721020	29.2283	-81.005	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DAYTONA BEACH (OCEAN)	FL
103181	Boynton Beach, Lake Worth, Florida	NOS	8722706	26.54829978942871	-80.05329895019531	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOYNTON BEACH	FL
103301	Richardson Hammock, St. Joseph Bay, Florida	NOS	8728949	29.69	-85.3633	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.7	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RICHARDSON HAMMOCK, ST. JOSEPH BAY	FL
103322	Upper Blackwater River, Florida	NOS	8729738	30.6583	-86.9883	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UPPER BLACKWATER RIVER	FL
103373	Keesler AFB, Back Bay, Biloxi, Mississippi	NOS	8744284	30.4183	-88.925	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEESLER AFB, BACK BAY OF BILOXI	MS
103399	Grand Isle, Mississippi River Delta, Louisiana	NOS	8761720	29.255	-89.9683	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAND ISLE	LA
103421	Eugene Island, Atchafalaya Bay, Louisiana	NOS	8764311	29.3717	-91.385	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eugene Island	LA
103461	Sabine (offshore), Louisiana	NOS	8771081	29.4983	-93.64	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Offshore	LA
103535	North Point, Pier 41, San Francisco, San Francisco Bay, California	NOS	9414305	37.81	-122.413	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH POINT, PIER 41, S.F.BAY	CA
103582	Requa Dock, California	NOS	9419551	41.545	-124.07	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Requa Dock	CA
103626	Taholah, Washington	NOS	9441644	47.34817	-124.28475	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Taholah	WA
103652	Yokeko Point, Deception Pass, Washington	NOS	9448601	48.4133	-122.615	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	5.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	YOKEKO POINT	WA
103723	Muir Inlet, Glacier Bay, Alaska	NOS	9452584	58.9133	-136.108	:America/Juneau	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	8.63	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Muir Inlet, Glacier Bay	AK
103737	Storey Island (north side), Alaska	NOS	9454571	60.7317	-147.437	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	6.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	STOREY ISLAND NORTH SIDE	AK
103779	Dovolno Point, Kizhuyak Bay, Alaska	NOS	9457393	57.7394	-152.87472	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dovolno Point, Kizhuyak Bay	AK
103788	Uyak, Uyak Bay, Alaska	NOS	9457728	57.635	-154.007	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	7.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uyak	AK
103793	Sutwik Island, west end, Alaska	NOS	9458665	56.54	-157.327	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.91	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEST END, SUTWIK ISLAND	AK
103834	Pyrite Point, Bristol Bay, Alaska	NOS	9465123	58.62	-161.542	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PYRITE POINT, BRISTOL BAY	AK
103838	Hagemeister Island (north end), Alaska	NOS	9465234	58.7767	-160.777	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.6	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH END, HAGEMEISTER ISLAND	AK
103870	St. Michael, Norton Sound, Alaska	NOS	9468132	63.475	-162.027	:America/Nome	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.63	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MICHAEL, NORTON SOUND	AK
103874	Akeftapak, St. Lawrence Island, Alaska	NOS	9468283	63.7185	-171.6447	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM HST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akeftapak, St. Lawrence Island	AK
103901	Prudhoe Bay #2, Alaska	NOS	9497649	70.3883	-148.51	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PRUDHOE BAY #2	AK
103921	Benner Bay, St. Thomas, Virgin Islands	NOS	9751567	18.32	-64.87	:America/St_Thomas	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AST to 2002-01-01 12:00 AM AST\n	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BENNER BAY	VI
103965	Nonopapa, Niihau Island, Hawaii	NOS	1610367	21.87	-160.235	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102695	-00:11:00	\N	0.77	-00:16:00	\N	0.77	\N	\N	Nonopapa, Niihau Island	HI
103966	Waimea Bay, Kauai Island, Hawaii	NOS	1611401	21.9567	-159.673	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102694	00:18:00	\N	0.91	00:07:00	\N	0.86	\N	\N	Waimea Bay	HI
103967	Hanamaulu Bay, Kauai Island, Hawaii	NOS	1611443	21.995	-159.335	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102694	00:04:00	\N	0.91	00:10:00	\N	1	\N	\N	Hanamaulu Bay	HI
103968	Hanalei Bay, Kauai Island, Hawaii	NOS	1611683	22.215	-159.502	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102694	-01:22:00	\N	0.91	-01:01:00	\N	1.07	\N	\N	Hanalei Bay	HI
103969	Hanauma Bay, Oahu Island, Hawaii	NOS	1612301	21.275	-157.697	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102695	-00:45:00	\N	1	-00:59:00	\N	1	\N	\N	Hanauma Bay	HI
103970	Waimanalo, Oahu Island, Hawaii	NOS	1612376	21.335	-157.693	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102699	00:05:00	\N	0.75	00:11:00	\N	0.88	\N	\N	Waimanalo	HI
103971	Waianae, Oahu Island, Hawaii	NOS	1612482	21.445	-158.192	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102695	00:18:00	\N	1	00:20:00	\N	0.93	\N	\N	Waianae	HI
103972	Haleiwa, Waialua Bay, Oahu Island, Hawaii	NOS	1612668	21.5983	-158.108	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102695	-02:05:00	\N	0.8	-01:02:00	\N	0.8	\N	\N	Haleiwa, Waialua Bay	HI
103974	Pukoo Harbor, Molokai Island, Hawaii	NOS	1613155	21.0717	-156.8	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102695	-00:48:00	0	\N	-01:03:00	0.1	\N	\N	\N	Pukoo Harbor	HI
103975	Kolo, Molokai Island, Hawaii	NOS	1613226	21.0933	-157.197	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102695	00:01:00	0	\N	00:05:00	0	\N	\N	\N	Kolo	HI
103976	Kaumalapau, Lanai Island, Hawaii	NOS	1614465	20.79	-156.995	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102695	00:03:00	0	\N	00:02:00	0.2	\N	\N	\N	Kaumalapau, Lanai Island	HI
103977	Makena, Maui Island, Hawaii	NOS	1615202	20.6567	-156.445	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102701	01:09:00	\N	0.54	01:21:00	\N	0.73	\N	\N	Makena	HI
103978	Hana, Maui Island, Hawaii	NOS	1615395	20.7617	-155.987	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102701	00:18:00	\N	0.54	00:40:00	\N	1.05	\N	\N	Hana	HI
103979	Kuheia Bay, Kahoolawe Island, Hawaii	NOS	1616696	20.595	-156.607	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102695	-00:09:00	0	\N	-00:09:00	0.2	\N	\N	\N	Kuheia Bay	HI
103980	Mahukona, Hawaii Island, Hawaii	NOS	1617277	20.1867	-155.903	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102703	00:42:00	\N	0.67	00:38:00	\N	0.8	\N	\N	Mahukona	HI
103981	Kailua Kona, Hawaii Island, Hawaii	NOS	1617846	19.6433	-156	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102703	00:37:00	\N	0.67	00:38:00	\N	0.8	\N	\N	Kailua Kona	HI
103982	Napoopoo, Kealakekua Bay, Hawaii Island, Hawaii	NOS	1618021	19.4767	-155.922	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102703	00:47:00	\N	0.67	00:48:00	\N	0.8	\N	\N	Napoopoo, Kealakekua Bay	HI
103983	Honuapo, Hawaii Island, Hawaii	NOS	1618578	19.0883	-155.553	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102703	00:33:00	\N	1	00:38:00	\N	1.01	\N	\N	Honuapo	HI
103984	East Island, French Frigate Shoals, Hawaii	NOS	1619222	23.783300399780273	-166.20799255371094	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102695	00:11:00	\N	0.73	00:05:00	\N	0.73	\N	\N	East Island, French Frigate Shoals	HI
103985	Laysan Island, Hawaii	NOS	1619645	25.766700744628906	-171.75	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102695	01:15:00	\N	0.5	01:04:00	\N	0.53	\N	\N	Laysan Island	HI
103986	Koror, Palau	NOS	1841281	7.349999904632568	134.48300170898438	:Pacific/Palau	Palau	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102712	-00:04:00	0	\N	-00:07:00	-0.1	\N	\N	\N	Koror	PW
103987	Birch Islands, Cobscook Bay, Maine	NOS	8410875	44.875	-67.1583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102714	01:13:00	\N	0.75	00:59:00	\N	0.94	\N	\N	Birch Islands	ME
103988	Stone Island, Machias Bay, Maine	NOS	8411411	44.6033	-67.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102714	-00:28:00	\N	0.68	-00:11:00	\N	0.68	\N	\N	Stone Island, Machias Bay	ME
103989	Machiasport, Machias River, Maine	NOS	8411467	44.6983	-67.3933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102714	-00:09:00	\N	0.69	00:01:00	\N	0.69	\N	\N	Machiasport, Machias River	ME
103990	Shoppee Point, Englishman Bay, Maine	NOS	8411696	44.615	-67.4967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102714	-00:13:00	\N	0.66	-00:05:00	\N	0.66	\N	\N	Shoppee Point, Englishman Bay	ME
103991	Steele Harbor Island, Maine	NOS	8411801	44.4933	-67.5433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:20:00	\N	1.27	-00:28:00	\N	1.27	\N	\N	Steele Harbor Island	ME
103992	Green Island, Petit Manan Bar, Maine	NOS	8412568	44.3717	-67.87	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:24:00	\N	1.16	-00:28:00	\N	1.16	\N	\N	Green Island, Petit Manan Bar	ME
103993	Prospect Harbor, Maine	NOS	8412932	44.4	-68.0217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:15:00	\N	1.15	-00:24:00	\N	1.15	\N	\N	Prospect Harbor	ME
103994	Winter Harbor, Frenchman Bay, Maine	NOS	8413079	44.3883	-68.0867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	00:10:00	\N	0.95	-00:01:00	\N	0.95	\N	\N	Winter Harbor, Frenchman Bay	ME
103995	Southwest Harbor, Mount Desert Island, Maine	NOS	8413564	44.275	-68.3133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	-00:27:00	\N	0.95	00:00:00	\N	0.96	\N	\N	Southwest Harbor	ME
103996	Bass Harbor, Mount Desert Island, Maine	NOS	8413651	44.2417	-68.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	-00:27:00	\N	0.93	00:04:00	\N	0.93	\N	\N	Bass Harbor	ME
103997	Burnt Coat Harbor, Swans Island, Maine	NOS	8413857	44.145	-68.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	00:06:00	\N	0.88	-00:01:00	\N	0.89	\N	\N	Burnt Coat Harbor, Swans Island	ME
103998	Blue Hill Harbor, Blue Hill Bay, Maine	NOS	8414112	44.4083	-68.5633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	00:11:00	\N	0.95	00:09:00	\N	0.95	\N	\N	Blue Hill Harbor	ME
103999	Center Harbor, Eggemoggin Reach, Maine	NOS	8414168	44.2633	-68.5867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	00:12:00	\N	0.95	00:09:00	\N	0.95	\N	\N	Center Harbor	ME
104000	Isle Au Haut, Penobscot Bay, Maine	NOS	8414288	44.0733	-68.6367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	-00:27:00	\N	0.88	-00:01:00	\N	0.87	\N	\N	Isle Au Haut	ME
104001	Stonington, Deer Isle, Penobscot Bay, Maine	NOS	8414348	44.1533	-68.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	00:06:00	\N	0.9	00:08:00	\N	0.91	\N	\N	Stonington, Deer Isle	ME
104002	Little Deer Isle, Eggemoggin Reach, Maine	NOS	8414424	44.2917	-68.6933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	00:14:00	\N	0.93	00:16:00	\N	0.94	\N	\N	Little Deer Isle	ME
104003	Gross Point, Eastern Channel, Penobscot River, Maine	NOS	8414581	44.5367	-68.7583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	00:10:00	\N	0.98	-00:06:00	\N	0.99	\N	\N	Gross Point, Eastern Channel	ME
104004	Castine, Penobscot Bay, Maine	NOS	8414672	44.3867	-68.7967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	00:11:00	\N	1	00:15:00	\N	0.95	\N	\N	Castine	ME
104005	Bucksport, Penobscot River, Maine	NOS	8414684	44.5717	-68.8017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	00:11:00	\N	1	-00:04:00	\N	1.01	\N	\N	Bucksport	ME
104006	Sandy Point, Penobscot River, Maine	NOS	8414692	44.505	-68.805	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	00:08:00	\N	0.98	00:06:00	\N	0.99	\N	\N	Sandy Point	ME
104007	Vinalhaven, Vinalhaven Island, Penobscot Bay, Maine	NOS	8414776	44.0433	-68.84	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	00:10:00	\N	0.88	00:09:00	\N	0.87	\N	\N	Vinalhaven, Vinalhaven Island	ME
104008	North Haven, Penobscot Bay, Maine	NOS	8414856	44.1267	-68.8733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	00:10:00	\N	0.9	00:13:00	\N	0.91	\N	\N	North Haven	ME
104009	Matinicus Harbor, Wheaton Island, Penobscot Bay, Maine	NOS	8414876	43.8617	-68.8817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	-00:27:00	\N	0.85	00:05:00	\N	0.85	\N	\N	Matinicus Harbor, Wheaton Island	ME
104010	Belfast, Penobscot Bay, Maine	NOS	8415191	44.4267	-69.005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102722	00:04:00	\N	1.03	00:09:00	\N	0.97	\N	\N	Belfast	ME
104011	Tenants Harbor, Maine	NOS	8415809	43.965	-69.2167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:11:00	\N	1.02	-00:11:00	\N	1.02	\N	\N	Tenants Harbor	ME
104012	Otis Cove, St. George River, Maine	NOS	8415867	43.9867	-69.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:14:00	\N	1	-00:15:00	\N	1	\N	\N	Otis Cove	ME
104013	Port Clyde, St. George River, Maine	NOS	8415933	43.925	-69.26	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:07:00	\N	0.98	-00:11:00	\N	0.98	\N	\N	Port Clyde	ME
104014	Burnt Island, Georges Islands, Maine	NOS	8416028	43.8717	-69.295	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:12:00	\N	0.98	-00:13:00	\N	0.98	\N	\N	Burnt Island, Georges Islands	ME
104015	Monhegan Island, Maine	NOS	8416092	43.765	-69.3217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:09:00	\N	0.97	-00:13:00	\N	0.97	\N	\N	Monhegan Island	ME
104016	Friendship Harbor, Maine	NOS	8416141	43.97	-69.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:11:00	\N	0.99	-00:18:00	\N	0.99	\N	\N	Friendship Harbor	ME
104017	Waldoboro, Medomak River, Maine	NOS	8416224	44.0933	-69.3767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:04:00	\N	1.04	-00:16:00	\N	1.04	\N	\N	Waldoboro	ME
104018	Jones Neck, Medomak River, Maine	NOS	8416232	44.015	-69.38	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:05:00	\N	1	-00:10:00	\N	1	\N	\N	Jones Neck	ME
104019	Muscongus Harbor, Muscongus Sound, Maine	NOS	8416381	43.9667	-69.4417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:03:00	\N	0.99	-00:09:00	\N	0.99	\N	\N	Muscongus Harbor, Muscongus Sound	ME
104020	New Harbor, Muscongus Bay, Maine	NOS	8416501	43.875	-69.4917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:08:00	\N	0.97	-00:10:00	\N	0.97	\N	\N	New Harbor, Muscongus Bay	ME
105916	Erikub Atoll, Marshall Islands	NOS	TPT2717	9.2	169.91666666667007	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Erikub Atoll	MH
104021	Pemaquid Harbor, Johns Bay, Maine	NOS	8416581	43.8767	-69.525	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:04:00	\N	0.97	-00:05:00	\N	0.97	\N	\N	Pemaquid Harbor, Johns Bay	ME
104022	Newcastle, Damariscotta River, Maine	NOS	8416608	44.0333	-69.5367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:25:00	\N	1.02	00:16:00	\N	1.02	\N	\N	Newcastle	ME
104023	East Boothbay, Damariscotta River, Maine	NOS	8416721	43.865	-69.5833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:01:00	\N	0.98	-00:02:00	\N	0.98	\N	\N	East Boothbay	ME
104024	Damariscove Harbor, Damariscove Island, Maine	NOS	8416796	43.7583	-69.615	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:10:00	\N	0.97	-00:09:00	\N	0.97	\N	\N	Damariscove Harbor, Damariscove Island	ME
104025	Sheepscot (below rapids), Sheepscot River, Maine	NOS	8416804	44.05	-69.6183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:20:00	\N	1.05	00:20:00	\N	1.05	\N	\N	Sheepscot (below rapids)	ME
104026	Boothbay Harbor, Maine	NOS	8416828	43.85	-69.6283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:08:00	\N	0.97	-00:06:00	\N	0.97	\N	\N	Boothbay Harbor	ME
104027	Southport, Townsend Gut, Maine	NOS	8416908	43.8467	-69.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:01:00	\N	0.98	00:01:00	\N	0.98	\N	\N	Southport, Townsend Gut	ME
104028	Wiscasset, Sheepscot River, Maine (sub)	NOS	8416921	44	-69.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:04:00	\N	1.03	00:16:00	\N	1.03	\N	\N	Wiscasset	ME
104029	Cross River entrance, Sheepscot River, Maine	NOS	8416928	43.925	-69.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:04:00	\N	1	00:07:00	\N	1	\N	\N	Cross River entrance	ME
104030	Back River, Sheepscot River, Maine	NOS	8416961	43.9583	-69.6833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:31:00	\N	1	00:34:00	\N	1	\N	\N	Back River	ME
104031	Isle of Springs, Sheepscot River, Maine	NOS	8416968	43.86	-69.6867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:04:00	\N	0.98	-00:02:00	\N	0.98	\N	\N	Isle of Springs	ME
104032	Robinhood, Sasanoa River, Sheepscot River, Maine	NOS	8417067	43.8533	-69.7333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:14:00	\N	0.97	00:14:00	\N	0.97	\N	\N	Robinhood, Sasanoa River	ME
104033	Mill Point, Sasanoa River, Sheepscot River, Maine	NOS	8417127	43.8867	-69.7633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:43:00	\N	0.97	00:35:00	\N	0.97	\N	\N	Mill Point, Sasanoa River	ME
104034	Phippsburg, Kennebec River, Maine	NOS	8417221	43.8183	-69.81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:28:00	\N	0.88	00:26:00	\N	0.88	\N	\N	Phippsburg	ME
104035	Sturgeon Island, Merrymeeting Bay, Kennebec River, Maine	NOS	8417271	43.9817	-69.835	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	02:04:00	\N	0.58	02:00:00	\N	0.58	\N	\N	Sturgeon Island, Merrymeeting Bay	ME
104036	Howard Point, New Meadows River, Casco Bay, Maine	NOS	8417367	43.89	-69.8833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:01:00	\N	0.99	-00:05:00	\N	0.99	\N	\N	Howard Point, New Meadows River	ME
104037	Androscoggin River entrance, Kennebec River, Maine	NOS	8417377	43.95	-69.8883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	03:26:00	\N	0.52	02:24:00	\N	0.52	\N	\N	Androscoggin River entrance	ME
104038	Cundy Harbor, New Meadows River, Casco Bay, Maine	NOS	8417387	43.7883	-69.8933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:02:00	\N	0.98	-00:01:00	\N	0.98	\N	\N	Cundy Harbor, New Meadows River	ME
104039	Bowdoinham, Cathance River, Kennebec River, Maine	NOS	8417391	44.0083	-69.895	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	02:42:00	\N	0.63	02:34:00	\N	0.63	\N	\N	Bowdoinham, Cathance River	ME
104040	Brunswick, Androscoggin River, Kennebec River, Maine	NOS	8417527	43.9217	-69.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	04:36:00	\N	0.42	02:35:00	\N	0.42	\N	\N	Brunswick, Androscoggin River	ME
104041	Wilson Cove, Middle Bay, Casco Bay, Maine	NOS	8417553	43.825	-69.9767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:02:00	\N	1	00:02:00	\N	1	\N	\N	Wilson Cove, Middle Bay	ME
104042	South Harpswell, Potts Harbor, Casco Bay, Maine	NOS	8417647	43.7383	-70.0233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:01:00	\N	0.98	00:02:00	\N	0.98	\N	\N	South Harpswell, Potts Harbor	ME
104043	South Freeport, Casco Bay, Maine	NOS	8417801	43.82	-70.1033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:10:00	\N	0.99	00:12:00	\N	0.99	\N	\N	South Freeport	ME
104044	Cliff Island, Luckse Sound, Casco Bay, Maine	NOS	8417821	43.695	-70.11	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:02:00	\N	1	-00:02:00	\N	1	\N	\N	Cliff Island, Luckse Sound	ME
104045	Doyle Point, Casco Bay, Maine	NOS	8417874	43.7517	-70.14	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:03:00	\N	0.88	-00:02:00	\N	1	\N	\N	Doyle Point	ME
104046	Great Chebeague Island, Casco Bay, Maine	NOS	8417881	43.7217	-70.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:02:00	\N	1.03	00:02:00	\N	1	\N	\N	Great Chebeague Island	ME
104047	Vaill Island, Casco Bay, Maine	NOS	8417911	43.6767	-70.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:01:00	\N	1.03	00:05:00	\N	0.98	\N	\N	Vaill Island	ME
104048	Long Island, Casco Bay, Maine	NOS	8417941	43.69	-70.17	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:01:00	\N	1	-00:01:00	\N	1	\N	\N	Long Island	ME
104049	Prince Point, Casco Bay, Maine	NOS	8417948	43.7617	-70.1733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:01:00	\N	0.99	00:00:00	\N	1	\N	\N	Prince Point	ME
104050	Great Diamond Island, Casco Bay, Maine	NOS	8417988	43.67	-70.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:00:00	\N	1.03	00:00:00	\N	1	\N	\N	Great Diamond Island	ME
104051	Cushing Island, Casco Bay, Maine	NOS	8417997	43.645	-70.1983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:01:00	\N	1.03	00:01:00	\N	0.99	\N	\N	Cushing Island	ME
104052	Peak Island, Casco Bay, Maine	NOS	8418001	43.655	-70.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:08:00	\N	0.99	-00:04:00	\N	0.99	\N	\N	Peak Island	ME
104053	Cow Island, Casco Bay, Maine	NOS	8418009	43.69	-70.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:00:00	\N	1	-00:01:00	\N	1	\N	\N	Cow Island	ME
104054	Falmouth Foreside, Casco Bay, Maine	NOS	8418015	43.7317	-70.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:01:00	\N	0.97	00:01:00	\N	1	\N	\N	Falmouth Foreside	ME
104055	Portland Head Light, Casco Bay, Maine	NOS	8418031	43.6233	-70.2067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:01:00	\N	1	-00:02:00	\N	0.97	\N	\N	Portland Head Light	ME
104056	Presumpscot River Bridge, Casco Bay, Maine	NOS	8418137	43.6867	-70.2467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:04:00	\N	1.06	00:01:00	\N	1.01	\N	\N	Presumpscot River Bridge	ME
104057	Back Cove, Casco Bay, Maine	NOS	8418175	43.6767	-70.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:06:00	\N	0.97	00:02:00	\N	0.97	\N	\N	Back Cove	ME
104058	Fore River, Casco Bay, Maine	NOS	8418268	43.6417	-70.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:02:00	\N	1.03	00:02:00	\N	1	\N	\N	Fore River	ME
104059	Old Orchard Beach, Maine	NOS	8418557	43.5167	-70.3667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:06:00	\N	0.97	00:00:00	\N	0.97	\N	\N	Old Orchard Beach	ME
104060	Cape Porpoise, Maine	NOS	8418772	43.3667	-70.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:14:00	\N	0.95	00:12:00	\N	0.95	\N	\N	Cape Porpoise	ME
104061	Cape Neddick, Maine	NOS	8419399	43.1667	-70.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:08:00	\N	1	00:02:00	\N	0.95	\N	\N	Cape Neddick	ME
104062	York Harbor, Maine	NOS	8419518	43.1317	-70.6417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:13:00	\N	0.95	00:03:00	\N	0.95	\N	\N	York Harbor	ME
104063	Fort Point, York Harbor, Maine	NOS	8419528	43.13	-70.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:10:00	\N	0.94	-00:04:00	\N	0.95	\N	\N	Fort Point, York Harbor	ME
104064	Seapoint, Cutts Island, Maine	NOS	8419590	43.085	-70.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:04:00	\N	0.96	00:01:00	\N	0.96	\N	\N	Seapoint, Cutts Island	ME
104065	Gerrish Island, Portsmouth Harbor, Maine	NOS	8419688	43.0667	-70.6967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:03:00	\N	0.95	-00:02:00	\N	0.95	\N	\N	Gerrish Island	ME
104066	Kittery Point, Portsmouth Harbor, Maine	NOS	8419807	43.0817	-70.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:01:00	\N	0.96	-00:07:00	\N	0.96	\N	\N	Kittery Point	ME
104067	Salmon Falls River, Piscataqua River, New Hampshire	NOS	8419997	43.1917	-70.825	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	01:52:00	\N	0.75	01:35:00	\N	0.75	\N	\N	Salmon Falls River	NH
104068	Dover Point, Piscataqua River, New Hampshire	NOS	8421897	43.1217	-70.8333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	01:27:00	\N	0.7	01:33:00	\N	0.7	\N	\N	Dover Point	NH
104069	Squamscott River RR. Bridge, Piscataqua River, New Hampshire	NOS	8422687	43.0533	-70.9133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	02:41:00	\N	0.75	02:19:00	\N	0.75	\N	\N	Squamscott River RR. Bridge	NH
104070	Atlantic Heights, E of, Piscataqua River, Maine	NOS	8423635	43.09	-70.7633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:28:00	\N	0.82	00:37:00	\N	0.82	\N	\N	Atlantic Heights	ME
104071	Portsmouth, Portsmouth Harbor, New Hampshire	NOS	8423745	43.0783	-70.7517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:17:00	\N	0.86	00:22:00	\N	0.86	\N	\N	Portsmouth	NH
104072	Jaffrey Point, Portsmouth Harbor, New Hampshire	NOS	8424601	43.0567	-70.7133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:05:00	\N	0.95	-00:03:00	\N	0.95	\N	\N	Jaffrey Point	NH
104073	Gosport Harbor, Isles of Shoals, New Hampshire	NOS	8427031	42.9783	-70.615	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	-00:02:00	\N	0.93	00:02:00	\N	0.93	\N	\N	Gosport Harbor, Isles of Shoals	NH
104074	Hampton Harbor, New Hampshire	NOS	8429489	42.895	-70.8167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102739	00:32:00	\N	0.91	00:14:00	\N	0.91	\N	\N	Hampton Harbor	NH
104075	Charlestown, Charles River entrance, Boston Harbor, Massachusetts	NOS	8443838	42.3717	-71.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:01:00	\N	1	00:00:00	\N	1	\N	\N	Charlestown, Charles River entrance	MA
104076	Deer Island (south end), Boston Harbor, Massachusetts	NOS	8444012	42.3483	-70.96	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:00:00	\N	0.97	00:01:00	\N	0.97	\N	\N	Deer Island (south end)	MA
104077	Moon Head, Boston Harbor, Massachusetts	NOS	8444312	42.3083	-70.9917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:04:00	\N	0.99	00:01:00	\N	0.99	\N	\N	Moon Head	MA
104078	Hull, Massachusetts	NOS	8444351	42.3033	-70.92	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:07:00	\N	0.97	00:05:00	\N	0.97	\N	\N	Hull	MA
104079	Neponset, Neponset River, Boston Harbor, Massachusetts	NOS	8444488	42.285	-71.04	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:03:00	\N	1	-00:02:00	\N	1	\N	\N	Neponset, Neponset River	MA
104080	Nantasket Beach, Weir River, Massachusetts	NOS	8444601	42.27	-70.86	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:07:00	\N	0.99	00:06:00	\N	0.99	\N	\N	Nantasket Beach, Weir River	MA
104081	Crow Point, Hingham Harbor entrance, Massachusetts	NOS	8444662	42.2617	-70.8933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:05:00	\N	0.99	00:02:00	\N	0.99	\N	\N	Crow Point, Hingham Harbor entrance	MA
104082	Cohasset Harbor (White Head), Massachusetts	NOS	8444762	42.2483	-70.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	-00:02:00	\N	0.92	00:04:00	\N	0.92	\N	\N	Cohasset Harbor (White Head)	MA
104083	Hingham, Massachusetts	NOS	8444775	42.2467	-70.885	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:08:00	\N	1	00:09:00	\N	1	\N	\N	Hingham	MA
104084	Damons Point, North River, Massachusetts	NOS	8445425	42.16	-70.7333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:36:00	\N	0.89	00:20:00	\N	0.89	\N	\N	Damons Point, North River	MA
104085	Wellfleet, Cape Cod Bay, Massachusetts	NOS	8446613	41.93	-70.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:30:00	\N	1.05	00:14:00	\N	1.05	\N	\N	Wellfleet	MA
104086	Onset Beach, Onset Bay, Buzzards Bay, Massachusetts	NOS	8447277	41.7417	-70.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	01:25:00	\N	1.03	00:41:00	\N	1.03	\N	\N	Onset Beach, Onset Bay	MA
104087	Steep Brook, Taunton River, Massachusetts	NOS	8447281	41.74	-71.1317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	00:05:00	\N	1.29	00:26:00	\N	1.3	\N	\N	Steep Brook, Taunton River	MA
104088	Pleasant Bay, Cape Cod, Massachusetts	NOS	8447291	41.7367	-69.9817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	03:27:00	\N	0.34	02:28:00	\N	0.34	\N	\N	Pleasant Bay	MA
104089	Barnstable Harbor, Beach Point, Cape Cod Bay, Massachusetts	NOS	8447335	41.7217	-70.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:30:00	\N	1	00:11:00	\N	1	\N	\N	Barnstable Harbor, Beach Point	MA
104090	Monument Beach, Buzzards Bay, Massachusetts	NOS	8447355	41.715	-70.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	00:30:00	\N	1.15	00:16:00	\N	1.15	\N	\N	Monument Beach	MA
104091	Marion, Sippican Harbor, Buzzards Bay, Massachusetts	NOS	8447385	41.705	-70.7617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	00:12:00	\N	1.29	00:10:00	\N	1.13	\N	\N	Marion, Sippican Harbor	MA
104092	Texas Tower, Georges Shoal	NOS	8447436	41.6883	-67.76	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	-00:43:00	\N	0.44	-00:47:00	\N	0.44	\N	\N	Georges Shoal, Texas Tower	\N
104093	South Yarmouth, Bass River, Nantucket Sound, Massachusetts	NOS	8447504	41.665	-70.1833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	01:46:00	\N	0.29	01:48:00	\N	0.29	\N	\N	South Yarmouth, Bass River	MA
104094	Wychmere Harbor, Nantucket Sound, Massachusetts	NOS	8447506	41.665000915527344	-70.06500244140625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:25:00	\N	0.39	00:52:00	\N	0.39	\N	\N	Wychmere Harbor	MA
104095	Dennisport, Nantucket Sound, Massachusetts	NOS	8447525	41.6583	-70.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:38:00	\N	0.36	01:03:00	\N	0.36	\N	\N	Dennisport	MA
104096	Mattapoisett, Mattapoisett Harbor, Buzzards Bay, Massachusetts	NOS	8447531	41.6567	-70.8133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	00:20:00	\N	1	00:11:00	\N	1.09	\N	\N	Mattapoisett, Mattapoisett Harbor	MA
104097	Cotuit Highlands, Nantucket Sound, Massachusetts	NOS	8447675	41.6083	-70.4367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:47:00	\N	0.26	01:17:00	\N	0.26	\N	\N	Cotuit Highlands	MA
104098	Poponesset Island, Poponesset Bay, Nantucket Sound, Massachusetts	NOS	8447742	41.5867	-70.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	01:52:00	\N	0.24	02:03:00	\N	0.24	\N	\N	Poponesset Island, Poponesset Bay	MA
104099	Hix Bridge, East Branch, Westport River, Massachusetts	NOS	8447791	41.57	-71.0733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	02:30:00	\N	0.77	01:40:00	\N	0.77	\N	\N	Hix Bridge, East Branch	MA
104100	Falmouth Heights, Nantucket Sound, Massachusetts	NOS	8447865	41.545	-70.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	-00:09:00	\N	0.14	-00:16:00	\N	0.14	\N	\N	Falmouth Heights	MA
104101	Little Harbor, Woods Hole, Massachusetts	NOS	8447939	41.52	-70.665	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	02:21:00	\N	0.4	00:32:00	\N	0.4	\N	\N	Little Harbor	MA
104102	Uncatena Island (south side), Woods Hole, Massachusetts	NOS	8447941	41.52	-70.7083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	00:22:00	\N	1.02	00:12:00	\N	1.02	\N	\N	Uncatena Island (south side)	MA
104103	Westport Harbor, Westport River, Massachusetts	NOS	8447975	41.5083	-71.0933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	00:33:00	\N	0.85	00:09:00	\N	0.85	\N	\N	Westport Harbor	MA
104104	Oak Bluffs, Martha's Vineyard, Massachusetts	NOS	8448208	41.4583	-70.555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	03:47:00	\N	0.71	03:59:00	\N	0.5	\N	\N	Oak Bluffs	MA
104105	Quicks Hole, north side, Massachusetts	NOS	8448251	41.4483	-70.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	-00:08:00	\N	0.99	-00:08:00	\N	0.99	\N	\N	Quicks Hole, North side	MA
104106	Cedar Tree Neck, Martha's Vineyard, Massachusetts	NOS	8448325	41.435	-70.6967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	01:32:00	\N	0.62	00:10:00	\N	0.62	\N	\N	Cedar Tree Neck	MA
104107	Cuttyhunk, Massachusetts	NOS	8448376	41.42499923706055	-70.91670227050781	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	01:15:00	\N	0.93	01:20:00	\N	0.97	\N	\N	Cuttyhunk	MA
104108	Great Point, Nantucket Island, Massachusetts	NOS	8448566	41.3867	-70.0467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:28:00	\N	0.32	00:43:00	\N	0.32	\N	\N	Great Point	MA
104109	Wasque Point, Chappaquiddick Island, Martha's Vineyard, Massachusetts	NOS	8448683	41.3633	-70.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	03:20:00	\N	0.31	02:02:00	\N	0.31	\N	\N	Wasque Point, Chappaquiddick Island	MA
104110	Gay Head, Martha's Vineyard, Massachusetts	NOS	8448733	41.3533	-70.83	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	00:45:00	\N	0.82	-00:06:00	\N	0.82	\N	\N	Gay Head	MA
104111	Muskeget Island, north side, Nantucket Island, Massachusetts	NOS	8448817	41.3367	-70.305	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:15:00	\N	0.21	00:25:00	\N	0.21	\N	\N	Muskeget Island, north side	MA
104112	Squibnocket Point, Martha's Vineyard, Massachusetts	NOS	8448942	41.3117	-70.7683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	-00:02:00	\N	0.82	-00:45:00	\N	0.82	\N	\N	Squibnocket Point	MA
104113	Eel Point, Nantucket Island, Massachusetts	NOS	8449062	41.2917	-70.2083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102764	00:07:00	\N	0.24	00:39:00	\N	0.24	\N	\N	Eel Point	MA
104114	Nomans Land, Martha's Vineyard, Massachusetts	NOS	8449287	41.2617	-70.8183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	00:18:00	\N	0.85	-00:19:00	\N	0.85	\N	\N	Nomans Land	MA
104115	North End, Bay Oil pier, Sakonnet River, Rhode Island	NOS	8450898	41.6517	-71.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	00:01:00	\N	1.07	00:20:00	\N	1.2	\N	\N	North End, Bay Oil pier	RI
104116	Anthony Point, Sakonnet River, Rhode Island	NOS	8450948	41.6383	-71.2117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	-00:01:00	\N	1.09	00:00:00	\N	1.09	\N	\N	Anthony Point	RI
104117	Nannaquaket Neck, Sakonnet River, Rhode Island	NOS	8450954	41.6183	-71.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	-00:13:00	\N	1.01	-00:12:00	\N	1.01	\N	\N	Nannaquaket Neck	RI
104118	The Glen, Sakonnet River, Rhode Island	NOS	8451301	41.5583	-71.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	-00:03:00	\N	1	-00:13:00	\N	0.98	\N	\N	The Glen	RI
104119	Sachuest, Flint Point, Sakonnet River, Rhode Island	NOS	8451351	41.4867	-71.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	00:15:00	\N	0.93	-00:05:00	\N	0.9	\N	\N	Sachuest, Flint Point	RI
104120	Bristol, Bristol Harbor, Narragansett Bay, Rhode Island	NOS	8451929	41.6683	-71.28	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	00:00:00	\N	1.14	00:13:00	\N	1.16	\N	\N	Bristol, Bristol Harbor	RI
104121	Prudence Island, south end, Narragansett Bay, Rhode Island	NOS	8452555	41.58	-71.3217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	-00:03:00	\N	1.14	00:08:00	\N	1.08	\N	\N	Prudence Island, (south end)	RI
104122	Castle Hill, Narragansett Bay, Rhode Island	NOS	8453201	41.4633	-71.3617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	00:13:00	\N	1	-00:05:00	\N	0.94	\N	\N	Castle Hill	RI
104123	Conanicut Point, Conanicut Island, Rhode Island	NOS	8453465	41.5733	-71.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	-00:06:00	\N	1.07	00:07:00	\N	1.07	\N	\N	Conanicut Point	RI
104124	Pawtucket, Seekonk River, Narragansett Bay, Rhode Island	NOS	8453611	41.8683	-71.38	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	00:09:00	\N	1.29	00:18:00	\N	1.31	\N	\N	Pawtucket, Seekonk River	RI
104125	Beavertail Point, Conanicut Island, Rhode Island	NOS	8453999	41.4517	-71.4017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	00:04:00	\N	0.98	-00:05:00	\N	0.98	\N	\N	Beavertail Point	RI
104126	Watson Pier, Boston Neck, Narragansett Bay, Rhode Island	NOS	8454341	41.46	-71.4283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	00:16:00	\N	0.93	-00:03:00	\N	0.96	\N	\N	Watson Pier, Boston Neck	RI
104127	Narragansett Pier, Narragansett Bay, Rhode Island (sub)	NOS	8454658	41.4217	-71.455	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	00:11:00	\N	0.93	-00:11:00	\N	0.91	\N	\N	Narragansett Pier	RI
104128	Westerly, Pawcatuck River, Rhode Island (sub)	NOS	8455189	41.3817	-71.8317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	00:03:00	\N	1	-00:21:00	\N	1.02	\N	\N	Westerly, Pawcatuck River	RI
104129	Watch Hill Point, Rhode Island	NOS	8458694	41.305	-71.86	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102801	01:16:00	\N	0.71	00:41:00	\N	0.74	\N	\N	Watch Hill Point	RI
104130	Norwich, Thames River, Connecticut	NOS	8461392	41.5233	-72.0783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	00:19:00	\N	1.21	00:24:00	\N	1.18	\N	\N	Norwich	CT
104131	Yale boathouse, Thames River, Connecticut	NOS	8461467	41.43	-72.0933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	00:10:00	\N	1.11	00:14:00	\N	1.07	\N	\N	Yale boathouse	CT
104132	Niantic, Niantic River, Connecticut	NOS	8461925	41.325	-72.1867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	00:57:00	\N	0.84	00:52:00	\N	0.99	\N	\N	Niantic, Niantic River	CT
104133	Saybrook Jetty, Connecticut River, Connecticut	NOS	8462723	41.2633	-72.3433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	00:45:00	\N	1.35	01:11:00	\N	1.36	\N	\N	Saybrook Jetty	CT
104134	Saybrook Point, Connecticut River, Connecticut	NOS	8462752	41.2833	-72.35	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	00:53:00	\N	1.25	01:11:00	\N	1.24	\N	\N	Saybrook Point	CT
104135	Lyme, highway bridge, Connecticut River, Connecticut	NOS	8462764	41.3217	-72.35	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	01:09:00	\N	0.95	01:36:00	\N	1.26	\N	\N	Lyme, highway bridge	CT
104136	Essex, Connecticut River, Connecticut	NOS	8462925	41.3483	-72.385	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	01:38:00	\N	1.15	01:39:00	\N	1.16	\N	\N	Essex	CT
104137	Hadlyme, Connecticut River, Connecticut	NOS	8463155	41.42	-72.4283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	02:23:00	\N	1.05	02:19:00	\N	1.05	\N	\N	Hadlyme	CT
104138	Tylerville, Connecticut River, Connecticut	NOS	8463348	41.4517	-72.465	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	02:51:00	\N	1.02	02:38:00	\N	1.02	\N	\N	Tylerville	CT
104139	Westbrook, Duck Island Roads, Connecticut	NOS	8463409	41.2733	-72.475	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	-00:32:00	\N	0.6	-00:24:00	\N	0.61	\N	\N	Westbrook, Duck Island Roads	CT
104140	Haddam, Connecticut River, Connecticut	NOS	8463582	41.4817	-72.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	03:08:00	\N	0.95	02:48:00	\N	0.97	\N	\N	Haddam	CT
104141	Maromas, Connecticut River, Connecticut	NOS	8463827	41.5417	-72.5517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	04:01:00	\N	0.91	03:25:00	\N	0.91	\N	\N	Maromas	CT
104142	Higganum Creek, Connecticut River, Connecticut	NOS	8463836	41.5033	-72.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	03:40:00	\N	0.91	03:08:00	\N	0.91	\N	\N	Higganum Creek	CT
104143	Madison, Connecticut	NOS	8464041	41.27	-72.59	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	-00:30:00	\N	0.72	-00:21:00	\N	0.73	\N	\N	Madison	CT
104144	Rocky Hill, Connecticut River, Connecticut	NOS	8464255	41.6633	-72.63	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	05:36:00	\N	0.63	04:30:00	\N	0.72	\N	\N	Rocky Hill	CT
104145	Middletown, Connecticut River, Connecticut	NOS	8464336	41.56	-72.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	04:39:00	\N	0.83	03:54:00	\N	0.83	\N	\N	Middletown	CT
104146	South Hartford, Connecticut River, Connecticut	NOS	8464418	41.755	-72.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	06:54:00	\N	0.58	05:24:00	\N	0.74	\N	\N	South Hartford	CT
104147	Guilford Harbor, Connecticut	NOS	8464445	41.2717	-72.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	-00:21:00	\N	0.96	-00:11:00	\N	0.77	\N	\N	Guilford Harbor	CT
104148	Hartford, Connecticut River, Connecticut	NOS	8464464	41.77	-72.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	06:52:00	\N	0.75	05:30:00	\N	0.74	\N	\N	Hartford	CT
104149	Sachem Head, Connecticut	NOS	8464687	41.245	-72.7083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	-00:15:00	\N	0.8	-00:11:00	\N	0.8	\N	\N	Sachem Head	CT
104150	Branford, Branford River, Connecticut	NOS	8465233	41.2617	-72.8183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	-00:13:00	\N	0.96	-00:05:00	\N	0.87	\N	\N	Branford, Branford River	CT
104151	Lighthouse Point, New Haven Harbor, Connecticut	NOS	8465692	41.2517	-72.905	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	-00:07:00	\N	0.96	-00:04:00	\N	0.91	\N	\N	Lighthouse Point, New Haven Harbor	CT
104152	Gulf Beach, Connecticut	NOS	8466375	41.205	-73.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	-00:08:00	\N	1.04	-00:05:00	\N	0.94	\N	\N	Gulf Beach	CT
104153	Milford Harbor, Connecticut	NOS	8466442	41.2183	-73.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	-00:03:00	\N	1.04	-00:02:00	\N	0.94	\N	\N	Milford Harbor	CT
104154	Shelton, Housatonic River, Connecticut	NOS	8466573	41.3017	-73.0717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	01:19:00	\N	0.96	00:46:00	\N	1.04	\N	\N	Shelton	CT
104155	Long Hill, Housatonic River, Connecticut	NOS	8466664	41.275	-73.0883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	01:13:00	\N	1.04	00:43:00	\N	1.02	\N	\N	Long Hill	CT
104156	Sniffens Point, Housatonic River, Connecticut	NOS	8466791	41.1867	-73.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	00:09:00	\N	1	00:10:00	\N	0.96	\N	\N	Sniffens Point	CT
104157	Stratford, I-95 bridge, Housatonic River, Connecticut	NOS	8466797	41.2033	-73.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	00:23:00	\N	1	00:23:00	\N	0.98	\N	\N	Stratford, I-95 bridge	CT
104158	Rowayton, Fivemile River, Connecticut	NOS	8468609	41.065	-73.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	00:05:00	\N	1.08	00:00:00	\N	1.05	\N	\N	Rowayton, Fivemile River	CT
104159	Cos Cob Harbor, Connecticut	NOS	8469549	41.0167	-73.5967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	00:11:00	\N	1.08	00:05:00	\N	1.07	\N	\N	Cos Cob Harbor	CT
104160	Montauk Harbor entrance, Long Island, New York	NOS	8510502	41.075	-71.9367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	-00:16:00	\N	0.75	-00:24:00	\N	0.74	\N	\N	Montauk Harbor entrance	NY
104161	Little Gull Island, Long Island, New York	NOS	8510884	41.2067	-72.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	-00:22:00	\N	0.85	00:13:00	\N	0.85	\N	\N	Little Gull Island	NY
104162	Threemile Harbor entrance, Gardiners Bay, Long Island, New York (sub)	NOS	8511171	41.035	-72.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	00:19:00	\N	1	00:39:00	\N	0.96	\N	\N	Threemile Harbor entrance, Gardiners Bay	NY
104163	Noyack Bay, Shelter Island Sound, New York	NOS	8511779	40.995	-72.3317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	01:44:00	\N	0.89	02:06:00	\N	0.89	\N	\N	Noyack Bay	NY
104164	Hashamomuck Beach, Long Island, New York	NOS	8512053	41.095	-72.3983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	-00:13:00	\N	0.64	00:03:00	\N	0.64	\N	\N	Hashamomuck Beach	NY
104165	Southold, Shelter Island Sound, New York	NOS	8512114	41.06	-72.4133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	01:33:00	\N	0.89	01:44:00	\N	0.89	\N	\N	Southold	NY
104166	New Suffolk, Peconic Bays, New York	NOS	8512328	40.9917	-72.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102821	02:11:00	\N	1	02:27:00	\N	1.01	\N	\N	New Suffolk	NY
104167	Shinnecock Bay entrance, Shinnecock Bay, New York	NOS	8512671	40.82	-72.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	01:51:00	\N	0.37	01:12:00	\N	0.51	\N	\N	Shinnecock Bay entrance	NY
104168	Mount Sinai Harbor, Long Island, New York	NOS	8514421	40.9633	-73.04	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	00:18:00	\N	0.88	00:04:00	\N	0.89	\N	\N	Mount Sinai Harbor	NY
104169	Port Jefferson Harbor entrance, Long Island, New York	NOS	8514594	40.9717	-73.0917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	00:01:00	\N	0.98	00:02:00	\N	0.98	\N	\N	Port Jefferson Harbor entrance	NY
104170	Great River, Connetquot River, Great South Bay, New York	NOS	8514783	40.7233	-73.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	03:32:00	\N	0.15	03:19:00	\N	0.15	\N	\N	Great River, Connetquot River	NY
104171	West Fire Island, Great South Bay, New York	NOS	8514961	40.6567	-73.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:18:00	\N	0.13	02:10:00	\N	0.13	\N	\N	West Fire Island	NY
104172	Fire Island Light, Great South Bay, New York	NOS	8515014	40.635	-73.22	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	01:22:00	\N	0.15	00:46:00	\N	0.15	\N	\N	Fire Island Light	NY
104173	Bay Shore, Watchogue Creek entrance, Great South Bay, New York	NOS	8515102	40.7167	-73.24	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:27:00	\N	0.37	02:15:00	\N	0.22	\N	\N	Bay Shore, Watchogue Creek Entrance	NY
104174	Democrat Point, Fire Island Inlet, Long Island, New York	NOS	8515228	40.6333	-73.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	-00:27:00	\N	0.55	-00:39:00	\N	0.56	\N	\N	Democrat Point, Fire Island Inlet	NY
104175	Oak Beach, Great South Bay, New York	NOS	8515336	40.64	-73.295	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:58:00	\N	0.15	02:23:00	\N	0.15	\N	\N	Oak Beach	NY
104176	Babylon, Great South Bay, New York	NOS	8515421	40.685	-73.315	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:41:00	\N	0.15	02:11:00	\N	0.13	\N	\N	Babylon	NY
104177	Gilgo Heading, Great South Bay, New York	NOS	8515764	40.62	-73.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:58:00	\N	0.25	02:22:00	\N	0.24	\N	\N	Gilgo Heading	NY
104178	Amityville, Great South Bay, New York	NOS	8515864	40.655	-73.4183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	03:05:00	\N	0.25	02:20:00	\N	0.26	\N	\N	Amityville	NY
104179	Biltmore Shores, South Oyster Bay, Long Island, New York	NOS	8516055	40.6667	-73.4683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:32:00	\N	0.3	02:04:00	\N	0.3	\N	\N	Biltmore Shores, South Oyster Bay	NY
104180	Oyster Bay Harbor, Oyster Bay, New York	NOS	8516201	40.8667	-73.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102824	00:13:00	\N	1.08	00:07:00	\N	1.08	\N	\N	Oyster Bay Harbor	NY
104181	Bellmore, Bellmore Creek, Hempstead Bay, New York	NOS	8516211	40.6633	-73.52	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	01:58:00	\N	0.45	01:28:00	\N	0.43	\N	\N	Bellmore, Bellmore Creek	NY
104182	Cuba Island, Hempstead Bay, New York	NOS	8516221	40.62	-73.5233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	01:22:00	\N	0.5	01:07:00	\N	0.49	\N	\N	Cuba Island	NY
104183	Deep Creek Meadow, Hempstead Bay, New York	NOS	8516225	40.6033	-73.525	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	01:11:00	\N	0.5	01:01:00	\N	0.51	\N	\N	Deep Creek Meadow	NY
104184	Neds Creek, Hempstead Bay, New York	NOS	8516315	40.6233	-73.555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:54:00	\N	0.6	00:49:00	\N	0.58	\N	\N	Neds Creek	NY
104185	Jones Inlet (Point Lookout), Long Island, New York	NOS	8516385	40.5867	-73.5783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	-00:25:00	\N	0.75	-00:20:00	\N	0.77	\N	\N	Jones Inlet (Point Lookout)	NY
104186	Freeport, Baldwin Bay, Hempstead Bay, New York	NOS	8516411	40.6333	-73.5867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:55:00	\N	0.65	00:37:00	\N	0.64	\N	\N	Freeport, Baldwin Bay	NY
104187	Long Beach (Inside), Hempstead Bay, New York	NOS	8516601	40.6	-73.65	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:02:00	\N	0.85	00:18:00	\N	0.84	\N	\N	Long Beach (Inside)	NY
104188	Woodmere, Brosewere Bay, Hempstead Bay, New York	NOS	8516745	40.62	-73.6983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:50:00	\N	0.85	00:34:00	\N	0.84	\N	\N	Woodmere, Brosewere Bay	NY
104189	Motts Basin, Jamaica Bay, New York	NOS	8516925	40.6167	-73.7583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:48:00	\N	1.15	00:39:00	\N	1.16	\N	\N	Motts Basin	NY
104190	J.F.K. International Airport, Jamaica Bay, New York	NOS	8516999	40.6233	-73.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:45:00	\N	1.15	00:25:00	\N	1.14	\N	\N	J.F.K. International Airport	NY
104191	Whitestone, East River, New York	NOS	8517125	40.7983	-73.8133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102870	00:09:00	\N	1.04	00:07:00	\N	1	\N	\N	Whitestone	NY
104192	Beach Channel (bridge), Jamaica Bay, New York (sub)	NOS	8517137	40.5883	-73.82	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:24:00	\N	1.1	00:37:00	\N	1.09	\N	\N	Beach Channel (bridge)	NY
104193	College Pt, Ft. of 110th Street, Long Island, New York (sub)	NOS	8517276	40.7833	-73.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102870	00:16:00	\N	1.04	00:17:00	\N	0.95	\N	\N	College Point, Flushing Bay	NY
104194	Canarsie, Jamaica Bay, New York	NOS	8517381	40.63	-73.885	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:08:00	\N	1.1	00:27:00	\N	1.12	\N	\N	Canarsie	NY
104195	Barren Island, Rockaway Inlet, Jamaica Bay, New York	NOS	8517394	40.5783	-73.8883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	-00:04:00	\N	1.05	-00:01:00	\N	1.07	\N	\N	Barren Island, Rockaway Inlet	NY
104196	Hell Gate, Wards Island, East River, New York	NOS	8517401	40.7867	-73.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	03:45:00	\N	1.59	02:58:00	\N	1.33	\N	\N	Hell Gate, Wards Island	NY
104197	Mill Basin, Jamaica Bay, New York	NOS	8517519	40.6083	-73.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:04:00	\N	1.1	00:28:00	\N	1.12	\N	\N	Mill Basin	NY
104198	Plumb Beach Channel, Jamaica Bay, New York	NOS	8517531	40.585	-73.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	-00:03:00	\N	1.05	00:02:00	\N	1.05	\N	\N	Plumb Beach Channel	NY
104199	Hunters Point, Newtown Creek, East River, New York	NOS	8517673	40.74	-73.9617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	00:56:00	\N	0.9	01:22:00	\N	0.89	\N	\N	Hunters Point, Newtown Creek	NY
104200	Wallabout Bay, Brooklyn Navy Yard, East River, New York	NOS	8517732	40.7067	-73.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	00:22:00	\N	1.05	00:32:00	\N	0.94	\N	\N	Wallabout Bay, Brooklyn Navy Yard	NY
104201	Coney Island, New York	NOS	8517741	40.57	-73.9833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	-00:17:00	\N	1	-00:04:00	\N	1.01	\N	\N	Coney Island	NY
104202	Norton Point, Gravesend Bay, New York	NOS	8517811	40.59	-73.9983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:03:00	\N	1.15	-00:01:00	\N	1.02	\N	\N	Norton Point, Gravesend Bay	NY
104203	Gowanus Bay, New York	NOS	8517921	40.665	-74.0133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	-00:12:00	\N	0.95	-00:18:00	\N	1.03	\N	\N	Gowanus Bay	NY
104204	Fort Hamilton, The Narrows, New York	NOS	8517942	40.6083	-74.035	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:07:00	\N	1	00:02:00	\N	1.01	\N	\N	Fort Hamilton, The Narrows	NY
104205	New Rochelle, New York	NOS	8518490	40.8933	-73.7817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102870	-00:18:00	\N	0.93	-00:16:00	\N	1.01	\N	\N	New Rochelle	NY
104206	Hunts Point, East River, New York	NOS	8518621	40.8	-73.8733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102870	00:10:00	\N	1.07	00:12:00	\N	0.97	\N	\N	Hunts Point	NY
104207	North Brother Island, East River, New York	NOS	8518635	40.7983	-73.8983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102870	00:18:00	\N	1.11	00:18:00	\N	0.93	\N	\N	North Brother Island	NY
104208	East 41st Street, New York City, East River, New York	NOS	8518695	40.7467	-73.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	00:46:00	\N	1.09	01:03:00	\N	0.95	\N	\N	East 41st Street, New York City	NY
104209	Spuyten Duyvil Creek entrance, Hudson River, New York (sub)	NOS	8518903	40.8783	-73.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	00:48:00	\N	0.84	00:52:00	\N	0.84	\N	\N	Spuyten Duyvil Creek ent., N.Y.	NY
104210	Riverdale, Hudson River, New York (sub)	NOS	8518905	40.9033	-73.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	00:49:00	\N	0.85	00:48:00	\N	0.85	\N	\N	Riverdale, N.Y.	NY
104211	Tarrytown, Hudson River, New York	NOS	8518919	41.0783	-73.87	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	01:57:00	\N	0.7	01:49:00	\N	0.7	\N	\N	Tarrytown	NY
104212	Newburgh, Hudson River, New York	NOS	8518935	41.5	-74.0067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	04:03:00	\N	0.64	03:46:00	\N	0.62	\N	\N	Newburgh	NY
104213	New Hamburg, Hudson River, New York	NOS	8518939	41.5833	-73.95	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	04:28:00	\N	0.64	04:04:00	\N	0.64	\N	\N	New Hamburg	NY
104214	Poughkeepsie, Hudson River, New York	NOS	8518945	41.7	-73.9333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	04:46:00	\N	0.68	04:34:00	\N	0.68	\N	\N	Poughkeepsie	NY
104215	Peekskill, Hudson River, New York	NOS	8518949	41.2883	-73.9317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	03:03:00	\N	0.64	02:28:00	\N	0.64	\N	\N	Peekskill	NY
104216	Tivoli, Hudson River, New York	NOS	8518964	42.0583	-73.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	06:04:00	\N	0.86	05:50:00	\N	0.86	\N	\N	Tivoli	NY
104217	Hudson, Hudson River, New York	NOS	8518974	42.25	-73.8	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	07:12:00	\N	0.86	06:58:00	\N	0.88	\N	\N	Hudson	NY
104218	Castleton, Hudson River, New York	NOS	8518989	42.5333	-73.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102893	-00:29:00	0.1	\N	-00:17:00	-0.2	\N	\N	\N	Castleton	NY
104219	Kingston, Hudson River, New York	NOS	8518993	41.9183	-73.9833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	05:34:00	\N	0.82	05:20:00	\N	0.81	\N	\N	Kingston	NY
104220	St. George, Staten Island, New York	NOS	8519112	40.6433	-74.0733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	-00:15:00	\N	0.99	-00:17:00	\N	0.99	\N	\N	St. George, Staten Island	NY
104221	Port Ivory, Howland Hook, Arthur Kill, New York	NOS	8519200	40.645	-74.18	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:39:00	\N	1.09	00:27:00	\N	1.09	\N	\N	Port Ivory, Howland Hook, N.Y.	NY
104222	Princes Bay, New York	NOS	8519726	40.5117	-74.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:06:00	\N	1.05	00:00:00	\N	1.05	\N	\N	Princes Bay	NY
104223	Rossville, Arthur Kill, New York	NOS	8519789	40.5567	-74.2233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:29:00	\N	1.12	00:20:00	\N	1.12	\N	\N	Rossville, N.Y.	NY
104224	Alpine, Hudson River, New Jersey	NOS	8530095	40.945	-73.9183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	01:02:00	\N	0.9	01:05:00	\N	0.83	\N	\N	Alpine, N.J.	NJ
104225	New Millford, Hackensack River, New Jersey	NOS	8530186	40.935	-74.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	02:49:00	\N	1.02	01:17:00	\N	1.02	\N	\N	New Millford	NJ
104226	Hackensack, Hackensack River, New Jersey	NOS	8530278	40.88	-74.04	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	01:00:00	\N	1.38	01:06:00	\N	1.33	\N	\N	Hackensack	NJ
104227	Ridgefield Park, Hackensack River, New Jersey	NOS	8530398	40.85	-74.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	01:00:00	\N	1.26	01:00:00	\N	1.26	\N	\N	Ridgefield Park	NJ
104228	East Rutherford, Passaic River, New Jersey	NOS	8530403	40.8467	-74.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	01:06:00	\N	1.29	00:09:00	\N	1.29	\N	\N	East Rutherford	NJ
104229	Edgewater, Hudson River, New Jersey	NOS	8530505	40.8133	-73.9783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	00:28:00	\N	0.93	00:31:00	\N	0.93	\N	\N	Edgewater, N.J.	NJ
104230	Carlstadt, Garretts Reach, Hackensack River, New Jersey	NOS	8530528	40.8067	-74.06	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	00:45:00	\N	1.29	00:59:00	\N	1.26	\N	\N	Carlstadt, Garretts Reach	NJ
104231	North Secaucus, Garretts Reach, Hackensack River, New Jersey	NOS	8530531	40.805	-74.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	00:57:00	\N	1.23	00:57:00	\N	1.23	\N	\N	North Secaucus, Garretts Reach	NJ
104232	Fish Creek, Berrys Creek, Hackensack River, New Jersey	NOS	8530586	40.7933	-74.0917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	01:00:00	\N	1	01:02:00	\N	1.16	\N	\N	Fish Creek, Berrys Creek	NJ
104233	Belleville, Passaic River, New Jersey	NOS	8530591	40.7867	-74.1467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	00:49:00	\N	1.19	00:09:00	\N	1.23	\N	\N	Belleville	NJ
104234	Weehawken, Union City, Hudson River, New Jersey	NOS	8530645	40.765	-74.0183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	00:15:00	\N	0.96	00:13:00	\N	0.96	\N	\N	Weehawken, Union City, N.J.	NJ
104235	Amtrak RR. swing bridge, Hackensack River, New Jersey	NOS	8530696	40.7517	-74.0967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	00:39:00	\N	1.1	00:33:00	\N	1.16	\N	\N	Amtrak RR. swing bridge	NJ
104236	Point No Point, Passaic River, New Jersey	NOS	8530743	40.7317	-74.1167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	00:22:00	\N	1.04	00:00:00	\N	1.15	\N	\N	Point No Point	NJ
104237	Kearny Point, Hackensack River, New Jersey	NOS	8530772	40.7283	-74.1033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	00:22:00	\N	1.14	00:11:00	\N	1.15	\N	\N	Kearny Point	NJ
104238	Port Elizabeth, New Jersey (sub)	NOS	8530882	40.6733	-74.14	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	00:13:00	\N	0.95	-00:02:00	\N	1.11	\N	\N	Port Elizabeth	NJ
104239	Port Newark Terminal, New Jersey	NOS	8530884	40.69	-74.1333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	00:21:00	\N	1.12	00:03:00	\N	1.12	\N	\N	Port Newark Terminal	NJ
104240	Constable Hook, New Jersey	NOS	8530985	40.655	-74.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102885	-00:08:00	\N	1.02	-00:18:00	\N	1.02	\N	\N	Constable Hook	NJ
104241	Rahway River, RR. Bridge, Arthur Kill, New Jersey	NOS	8531077	40.5983	-74.2317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:30:00	\N	1.16	00:17:00	\N	1.14	\N	\N	Rahway River, RR. Bridge	NJ
104242	Carteret, Arthur Kill, New Jersey	NOS	8531095	40.5867	-74.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:33:00	\N	1.09	00:22:00	\N	1.09	\N	\N	Carteret	NJ
104243	Woodbridge Creek, 0.8 nmi above entrance, Arthur Kill, New Jersey	NOS	8531156	40.545	-74.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:21:00	\N	1	00:09:00	\N	1.1	\N	\N	Woodbridge Creek, 0.8 n.mi. above entrance	NJ
104244	South Amboy, Raritan River, New Jersey (sub)	NOS	8531232	40.4917	-74.2817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:08:00	\N	1.09	-00:04:00	\N	1.09	\N	\N	South Amboy	NJ
104245	Matawan Creek, Route 35 bridge, New Jersey	NOS	8531526	40.4333	-74.2183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:07:00	\N	1.08	-00:01:00	\N	1.08	\N	\N	Matawan Creek, Route 35 bridge	NJ
104246	Keyport, New Jersey	NOS	8531545	40.44	-74.1983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:06:00	\N	1.1	-00:04:00	\N	1.08	\N	\N	Keyport	NJ
104247	Waackaack Creek, New Jersey	NOS	8531592	40.4483	-74.1433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:21:00	\N	0.99	-00:06:00	\N	0.99	\N	\N	Waackaack Creek	NJ
104248	Atlantic Highlands, Sandy Hook Bay, New Jersey	NOS	8531662	40.4183	-74.035	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	-00:10:00	\N	1.01	-00:10:00	\N	1.01	\N	\N	Atlantic Highlands	NJ
104249	Highlands, Route 36 bridge, Shrewsbury River, New Jersey	NOS	8531712	40.3967	-73.9817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:14:00	\N	0.9	00:17:00	\N	0.9	\N	\N	Highlands, Route 36 bridge	NJ
104250	Oceanic Bridge, Navesink River, Shrewsbury River, New Jersey	NOS	8531753	40.3767	-74.015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	01:45:00	\N	0.63	01:13:00	\N	0.72	\N	\N	Oceanic Bridge, Navesink River	NJ
104251	Sea Bright, Shrewsbury River, New Jersey (sub)	NOS	8531804	40.365	-73.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	01:07:00	\N	0.68	01:15:00	\N	0.68	\N	\N	Sea Bright	NJ
104252	Red Bank, Navesink River, Shrewsbury River, New Jersey	NOS	8531833	40.355	-74.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	01:57:00	\N	0.63	01:17:00	\N	0.74	\N	\N	Red Bank, Navesink River	NJ
104253	Gooseneck Point, bridge, Shrewsbury River, New Jersey	NOS	8531925	40.3267	-74.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:41:00	\N	0.55	02:18:00	\N	0.55	\N	\N	Gooseneck Point, bridge	NJ
104254	Long Branch Reach, Shrewsbury River, New Jersey	NOS	8531942	40.325	-73.9967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:41:00	\N	0.63	02:18:00	\N	0.56	\N	\N	Long Branch Reach	NJ
104255	Long Branch (fishing pier), New Jersey	NOS	8531991	40.3033	-73.9767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	-00:36:00	\N	1	-00:26:00	\N	0.94	\N	\N	Long Branch (fishing pier)	NJ
104256	Shark River Hills, Shark River, New Jersey	NOS	8532322	40.1917	-74.0383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	-00:09:00	\N	0.94	-00:13:00	\N	0.94	\N	\N	Shark River Hills	NJ
104257	Belmar (ocean), New Jersey	NOS	8532337	40.185	-74.0083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	-00:45:00	\N	0.95	-00:35:00	\N	0.95	\N	\N	Belmar, Atlantic Ocean	NJ
104258	Shark River Island, fixed RR. bridge, Shark River, New Jersey	NOS	8532339	40.1867	-74.0267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	-00:08:00	\N	0.93	-00:13:00	\N	0.93	\N	\N	Shark River Island, fixed RR. bridge	NJ
104259	New Bedford, Shark River, New Jersey	NOS	8532371	40.1783	-74.0467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	-00:07:00	\N	0.95	-00:13:00	\N	0.95	\N	\N	New Bedford	NJ
104260	Brielle, Route 35 bridge, Manasquan River, New Jersey	NOS	8532585	40.105	-74.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	-00:20:00	\N	0.83	-00:06:00	\N	0.83	\N	\N	Brielle, Route 35 bridge	NJ
104261	Manasquan Inlet, USCG station, New Jersey	NOS	8532591	40.1017	-74.035	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	-00:24:00	\N	0.95	-00:12:00	\N	0.86	\N	\N	Manasquan Inlet, USCG Station	NJ
104262	Riviera Beach, Manasquan River, New Jersey	NOS	8532611	40.0967	-74.0867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:38:00	\N	0.73	00:08:00	\N	0.73	\N	\N	Riviera Beach	NJ
104263	Forge Pond, Metedeconk River, New Jersey	NOS	8532703	40.065	-74.135	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:07:00	\N	0.07	02:17:00	\N	0.07	\N	\N	Forge Pond	NJ
104264	Beaverdam Creek entrance, Metedeconk River, New Jersey	NOS	8532715	40.0617	-74.0617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:40:00	\N	0.37	02:41:00	\N	0.07	\N	\N	Beaverdam Creek entrance	NJ
104265	Beaverdam Creek, inside, Metedeconk River, New Jersey	NOS	8532716	40.0617	-74.0733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:47:00	\N	0.06	02:49:00	\N	0.06	\N	\N	Beaverdam Creek, inside	NJ
104266	Tall Pines Camp, Metedeconk River, New Jersey	NOS	8532721	40.0583	-74.1167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:24:00	\N	0.06	02:23:00	\N	0.06	\N	\N	Tall Pines Camp	NJ
104267	Mantoloking, Barnegat Bay, New Jersey	NOS	8532786	40.0367	-74.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	04:39:00	\N	0.07	04:28:00	\N	0.07	\N	\N	Mantoloking	NJ
104268	Kettle Creek, Green Island, Barnegat Bay, New Jersey	NOS	8532835	40.0133	-74.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	04:41:00	\N	0.08	04:23:00	\N	0.08	\N	\N	Kettle Creek, Green Island	NJ
104269	Ocean Beach, Barnegat Bay, New Jersey	NOS	8532885	39.9883	-74.0683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	04:36:00	\N	0.08	04:17:00	\N	0.08	\N	\N	Ocean Beach	NJ
104270	Silver Bay, Silver Bay Marina, Barnegat Bay, New Jersey	NOS	8532921	39.9967	-74.1483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	04:39:00	\N	0.08	04:26:00	\N	0.08	\N	\N	Silver Bay, Silver Bay Marina	NJ
104271	Goose Creek entrance, Barnegat Bay, New Jersey	NOS	8533005	39.9633	-74.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	04:29:00	\N	0.08	04:06:00	\N	0.08	\N	\N	Goose Creek entrance	NJ
104272	Coates Point, Barnegat Bay, New Jersey	NOS	8533055	39.9483	-74.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	04:21:00	\N	0.08	04:00:00	\N	0.08	\N	\N	Coates Point	NJ
104273	Seaside Heights, ocean, New Jersey	NOS	8533071	39.9433	-74.035	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	-00:32:00	\N	0.92	-00:30:00	\N	0.92	\N	\N	Seaside Heights, ocean	NJ
104274	Seaside Park, Barnegat Bay, New Jersey	NOS	8533135	39.9217	-74.0833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	04:05:00	\N	0.08	03:40:00	\N	0.08	\N	\N	Seaside Park	NJ
104275	Barnegat Pier, Barnegat Bay, New Jersey	NOS	8533141	39.9183	-74.11	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	03:55:00	\N	0.08	03:35:00	\N	0.08	\N	\N	Barnegat Pier	NJ
104276	Sloop Creek, Barnegat Bay, New Jersey	NOS	8533185	39.905	-74.1333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	04:01:00	\N	0.08	03:38:00	\N	0.08	\N	\N	Sloop Creek	NJ
104277	Cedar Creek, Barnegat Bay, New Jersey	NOS	8533295	39.87	-74.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	03:45:00	\N	0.08	03:23:00	\N	0.08	\N	\N	Cedar Creek	NJ
104278	Island Beach, Barnegat Bay, New Jersey	NOS	8533345	39.8517	-74.0883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	03:28:00	\N	0.08	03:04:00	\N	0.08	\N	\N	Island Beach	NJ
104279	Forked River, Barnegat Bay, New Jersey	NOS	8533391	39.825	-74.1733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	03:20:00	\N	0.07	03:08:00	\N	0.07	\N	\N	Forked River	NJ
104280	Oyster Creek, Barnegat Bay, New Jersey	NOS	8533465	39.8083	-74.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	03:36:00	\N	0.06	03:30:00	\N	0.06	\N	\N	Oyster Creek	NJ
104281	Island Beach, Sedge Islands, Barnegat Bay, New Jersey	NOS	8533535	39.7883	-74.0983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	03:56:00	\N	0.07	03:00:00	\N	0.07	\N	\N	Island Beach, Sedge Islands	NJ
104282	Waretown, Barnegat Bay, New Jersey	NOS	8533541	39.7917	-74.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	03:00:00	\N	0.07	02:43:00	\N	0.07	\N	\N	Waretown	NJ
104283	High Bar, Barnegat Bay, New Jersey	NOS	8533631	39.7567	-74.1283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	01:55:00	\N	0.12	01:04:00	\N	0.12	\N	\N	High Bar	NJ
104284	Double Creek, Barnegat Bay, New Jersey	NOS	8533665	39.745	-74.2017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	03:33:00	\N	0.07	03:03:00	\N	0.07	\N	\N	Double Creek	NJ
104285	Loveladies Harbor, Barnegat Bay, New Jersey	NOS	8533738	39.725	-74.1367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	03:39:00	\N	0.1	03:02:00	\N	0.1	\N	\N	Loveladies Harbor	NJ
104286	Flat Creek, Manahawkin Bay, New Jersey	NOS	8533780	39.7067	-74.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	04:35:00	\N	0.18	03:33:00	\N	0.18	\N	\N	Flat Creek	NJ
104287	North Beach, Manahawkin Bay, New Jersey	NOS	8533862	39.675	-74.16	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	04:07:00	\N	0.22	03:02:00	\N	0.22	\N	\N	North Beach	NJ
104288	Mill Creek, 1 nmi above entrance, Little Egg Harbor, New Jersey	NOS	8533905	39.665	-74.2317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	03:33:00	\N	0.35	02:32:00	\N	0.35	\N	\N	Mill Creek, 1 n.mi. above entrance	NJ
104289	Manahawkin Creek, Manahawkin Bay, New Jersey	NOS	8533909	39.6667	-74.215	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	03:51:00	\N	0.27	02:50:00	\N	0.27	\N	\N	Manahawkin Creek	NJ
104290	Manahawkin Drawbridge, Manahawkin Bay, New Jersey	NOS	8533935	39.6533	-74.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	03:39:00	\N	0.27	02:47:00	\N	0.27	\N	\N	Manahawkin Drawbridge	NJ
104291	Cedar Run, Little Egg Harbor, New Jersey	NOS	8533941	39.6533	-74.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:56:00	\N	0.4	02:10:00	\N	0.4	\N	\N	Cedar Run	NJ
104292	Dinner Point Creek, upper end, Little Egg Harbor, New Jersey	NOS	8533982	39.6567	-74.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	03:17:00	\N	0.4	02:41:00	\N	0.4	\N	\N	Dinner Point Creek, upper end	NJ
104293	West Creek, Westecunk Creek, Little Egg Harbor, New Jersey	NOS	8533987	39.6317	-74.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:40:00	\N	0.47	02:10:00	\N	0.44	\N	\N	West Creek, Westecunk Creek	NJ
104294	Sweetwater, Mullica River Marina, Mullica River, New Jersey	NOS	8534002	39.625	-74.6417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	04:21:00	\N	0.56	03:23:00	\N	0.56	\N	\N	Sweetwater, Mullica River Marina	NJ
104295	Wading River (town), Wading River, Mullica River, New Jersey	NOS	8534043	39.6183	-74.4967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:44:00	\N	0.79	02:48:00	\N	0.64	\N	\N	Wading River (town), Wading River	NJ
104296	Westecunk Creek entrance, Little Egg Harbor, New Jersey	NOS	8534044	39.6133	-74.2633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:40:00	\N	0.47	02:00:00	\N	0.42	\N	\N	Westecunk Creek entrance	NJ
104297	Beach Haven Crest, Little Egg Harbor, New Jersey	NOS	8534048	39.6133	-74.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:59:00	\N	0.32	02:13:00	\N	0.38	\N	\N	Beach Haven Crest	NJ
104298	Parker Run, upper end, Little Egg Harbor, New Jersey	NOS	8534049	39.6167	-74.31	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:39:00	\N	0.47	02:05:00	\N	0.45	\N	\N	Parker Run, upper end	NJ
104299	Tuckerton, Tuckerton Creek, Little Egg Harbor, New Jersey	NOS	8534080	39.6017	-74.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:15:00	\N	0.47	01:45:00	\N	0.45	\N	\N	Tuckerton, Tuckerton Creek	NJ
104300	New Gretna, Bass River, Mullica River, New Jersey	NOS	8534104	39.5917	-74.4417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:06:00	\N	0.74	01:52:00	\N	0.66	\N	\N	New Gretna, Bass River	NJ
104301	Green Bank, Mullica River, New Jersey	NOS	8534117	39.6117	-74.59	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	03:16:00	\N	0.66	02:59:00	\N	0.66	\N	\N	Green Bank	NJ
104302	Tuckerton Creek entrance, Little Egg Harbor, New Jersey	NOS	8534139	39.5767	-74.3317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	01:59:00	\N	0.45	01:32:00	\N	0.45	\N	\N	Tuckerton Creek entrance	NJ
104303	Beach Haven USCG station, Little Egg Harbor, New Jersey	NOS	8534208	39.5483	-74.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	01:23:00	\N	0.58	01:18:00	\N	0.46	\N	\N	Beach Haven Coast Guard Station	NJ
104304	Cramers Boatyard, Mullica River, New Jersey	NOS	8534212	39.5483	-74.4617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	02:01:00	\N	0.79	01:27:00	\N	0.63	\N	\N	Chestnut Neck Boat Yard	NJ
104305	Graveling Point, Great Bay, New Jersey	NOS	8534244	39.540000915527344	-74.38670349121094	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	01:14:00	\N	0.68	00:44:00	\N	0.68	\N	\N	Graveling Point	NJ
104306	Nacote Creek, US Highway 9 bridge, Mullica River, New Jersey	NOS	8534256	39.535	-74.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	01:55:00	\N	0.68	01:34:00	\N	0.66	\N	\N	Nacote Creek, U.S. Highway 9 bridge	NJ
104307	Little Sheepshead Creek, Great Bay, New Jersey	NOS	8534287	39.5217	-74.32	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:44:00	\N	0.68	00:35:00	\N	0.66	\N	\N	Little Sheepshead Creek	NJ
104308	Seven Island, Newmans Thorofare, Great Bay, New Jersey	NOS	8534296	39.5167	-74.3367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:28:00	\N	0.73	00:32:00	\N	0.73	\N	\N	Seven Island, Newmans Thorofare	NJ
104309	Main Marsh Thorofare, New Jersey	NOS	8534393	39.4783	-74.3833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	01:52:00	\N	0.76	01:10:00	\N	0.8	\N	\N	Main Marsh Thorofare	NJ
104310	Brigantine Channel @ Hoffman Thorofare, New Jersey	NOS	8534496	39.435	-74.3633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	00:58:00	\N	0.88	00:59:00	\N	0.9	\N	\N	Brigantine Channel @ Hoffman Thorofare	NJ
104311	Absecon, Absecon Creek, US Hwy. 30 bridge, New Jersey	NOS	8534540	39.4233	-74.5	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	01:37:00	\N	0.94	01:28:00	\N	0.96	\N	\N	Absecon, Absecon Creek, U.S. Hwy. 30 bridge	NJ
104312	Absecon Channel, State Route 87 bridge, New Jersey	NOS	8534638	39.385	-74.425	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	00:26:00	\N	1.13	00:38:00	\N	0.96	\N	\N	Absecon Channel, State Route 87 bridge	NJ
104313	Pleasantville, Lakes Bay, Great Egg Harbor Inlet, New Jersey	NOS	8534657	39.3817	-74.5183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	01:37:00	\N	0.82	01:00:00	\N	0.98	\N	\N	Pleasantville, Lakes Bay, Great Egg Harbor Inlet	NJ
104314	River Bend Marina, Great Egg Harbor River, New Jersey	NOS	8534691	39.3683	-74.7167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	02:25:00	\N	1	02:12:00	\N	0.87	\N	\N	River Bend Marina, Great Egg Harbor River	NJ
104315	Dock Thorofare, Risley Channel, New Jersey	NOS	8534739	39.3517	-74.54	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	01:00:00	\N	0.94	00:55:00	\N	0.98	\N	\N	Dock Thorofare, Risley Channel	NJ
104316	Beesleys Point, Great Egg Harbor Bay, New Jersey	NOS	8534975	39.2883	-74.6283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	01:32:00	\N	1	00:55:00	\N	0.87	\N	\N	Beesleys Point	NJ
104317	Cedar Swamp Creek, Tuckahoe River, Great Egg Harbor Bay, New Jersey	NOS	8535001	39.2467	-74.7183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	03:03:00	\N	1.53	03:14:00	\N	0.78	\N	\N	Cedar Swamp Creek, Tuckahoe River	NJ
104318	Middle Thorofare, Ocean Drive bridge, Corson Inlet, New Jersey	NOS	8535101	39.215	-74.6483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	00:30:00	\N	0.94	00:31:00	\N	0.95	\N	\N	Middle Thorofare, Ocean Drive bridge	NJ
104319	Strathmere, Strathmere Bay, Corson Inlet, New Jersey	NOS	8535163	39.2	-74.6567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	00:38:00	\N	1	00:31:00	\N	0.95	\N	\N	Strathmere, Strathmere Bay	NJ
104320	Ludlam Bay, west side, Corson Inlet, New Jersey	NOS	8535221	39.1767	-74.71	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	01:12:00	\N	0.94	00:56:00	\N	0.98	\N	\N	Ludlam Bay, west side	NJ
104321	Townsend Sound, Townsends Inlet, New Jersey	NOS	8535309	39.1467	-74.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	01:39:00	\N	0.59	01:08:00	\N	0.9	\N	\N	Townsend Sound	NJ
104322	Stites Sound, Townsends Inlet, New Jersey	NOS	8535357	39.12	-74.755	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	01:04:00	\N	1	00:49:00	\N	0.97	\N	\N	Stites Sound	NJ
104323	Ingram Thorofare, Townsends Inlet, New Jersey (sub)	NOS	8535419	39.11	-74.7383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	00:50:00	\N	1	00:44:00	\N	0.96	\N	\N	Ingram Thorofare	NJ
104324	Long Reach, Ingram Thorofare, Townsends Inlet, New Jersey	NOS	8535451	39.1017	-74.755	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	01:11:00	\N	1.06	01:06:00	\N	0.98	\N	\N	Long Reach, Ingram Thorofare	NJ
104325	Nummy Island, Grassy Sound Channel, Hereford Inlet, New Jersey	NOS	8535661	39.0283	-74.8017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	00:45:00	\N	1	00:32:00	\N	1	\N	\N	Nummy Island, Grassy Sound Channel	NJ
104326	Old Turtle Thorofare, RR. bridge, Hereford Inlet, New Jersey	NOS	8535695	39.0183	-74.8417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	01:10:00	\N	1	00:56:00	\N	1.06	\N	\N	Old Turtle Thorofare, RR. bridge	NJ
104327	West Wildwood, Grassy Sound, Hereford Inlet, New Jersey	NOS	8535726	39.005	-74.8267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	01:11:00	\N	1	00:57:00	\N	1.04	\N	\N	West Wildwood, Grassy Sound	NJ
104328	Swain Channel, Taylor Sound, Cape May Inlet, New Jersey	NOS	8535805	38.98	-74.8633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	00:40:00	\N	1.06	00:55:00	\N	1.09	\N	\N	Swain Channel, Taylor Sound	NJ
104329	Wildwood Crest, Sunset Lake, Cape May Inlet, New Jersey	NOS	8535838	38.9783	-74.8367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	00:47:00	\N	1.06	00:52:00	\N	1.1	\N	\N	Wildwood Crest, Sunset Lake	NJ
104330	Cape May Harbor, Cape May Inlet, New Jersey	NOS	8535901	38.9483	-74.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	00:19:00	\N	1.06	00:33:00	\N	1.1	\N	\N	Cape May Harbor	NJ
104331	Cape Island Creek, Cape May, New Jersey	NOS	8535902	38.9467	-74.9133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	00:20:00	\N	1.19	00:40:00	\N	1.11	\N	\N	Cape Island Creek, Cape May	NJ
104332	Cape May (ocean), New Jersey	NOS	8535962	38.93	-74.935	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102913	00:21:00	\N	1.06	00:34:00	\N	1.12	\N	\N	Cape May, Atlantic Ocean	NJ
104333	Cape May Point, Sunset Beach, Delaware Bay, New Jersey	NOS	8536021	38.9467	-74.9717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	-00:08:00	\N	1.16	-00:05:00	\N	1.16	\N	\N	Cape May Point, Sunset Beach	NJ
104334	North Highlands Beach, Delaware Bay, New Jersey	NOS	8536271	39.0183	-74.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	00:14:00	\N	1.26	00:04:00	\N	1.26	\N	\N	North Highlands Beach	NJ
104335	Dias Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536449	39.0833	-74.8867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	03:18:00	\N	0.46	01:09:00	\N	0.46	\N	\N	Dias Creek, Route 47 bridge	NJ
104336	Bidwell Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536551	39.1183	-74.8683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	00:48:00	\N	1.36	00:36:00	\N	1.36	\N	\N	Bidwell Creek, Route 47 bridge	NJ
104337	Sluice Creek, Route 47 bridge, Dennis Creek, Delaware Bay, New Jersey	NOS	8536687	39.1617	-74.8317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	01:36:00	\N	1.22	01:49:00	\N	1.22	\N	\N	Sluice Creek, Route 47 bridge, Dennis Creek	NJ
104338	Dennis Creek, 2.5 nmi above entrance, Delaware Bay, New Jersey	NOS	8536736	39.1783	-74.8517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	01:17:00	\N	1.26	00:55:00	\N	1.26	\N	\N	Dennis Creek, 2.5 n.mi. above entrance	NJ
104339	Dennis Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536752	39.1833	-74.8217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	01:30:00	\N	1.2	02:01:00	\N	1.2	\N	\N	Dennis Creek, Route 47 bridge	NJ
104340	West Creek, 0.7 nmi above entrance, Delaware Bay, New Jersey	NOS	8536764	39.1883	-74.915	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	01:31:00	\N	1.15	00:20:00	\N	1.15	\N	\N	West Creek, 0.7 n.mi. above entrance	NJ
104341	East Point, Maurice River Cove, Delaware Bay, New Jersey	NOS	8536780	39.2	-75.02	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	01:08:00	\N	1.39	00:40:00	\N	1.39	\N	\N	East Point, Maurice River Cove	NJ
104342	Riggins Ditch, 0.5 nmi above entrance, Delaware Bay, New Jersey	NOS	8536801	39.2	-74.97	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	01:29:00	\N	1.24	00:29:00	\N	1.24	\N	\N	Riggins Ditch, 0.5 n.mi. above entrance	NJ
104343	East Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536823	39.2083	-74.9017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	02:24:00	\N	0.94	01:46:00	\N	0.94	\N	\N	East Creek, Route 47 bridge	NJ
104344	Fishing Creek entrance, Delaware Bay, New Jersey	NOS	8536848	39.2167	-75.1583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	-02:10:00	\N	1.02	-01:51:00	\N	1.02	\N	\N	Fishing Creek entrance	NJ
104345	Dividing Creek entrance, Delaware Bay, New Jersey	NOS	8536849	39.2167	-75.1033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	01:05:00	\N	1.35	00:29:00	\N	1.35	\N	\N	Dividing Creek entrance	NJ
104346	West Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536851	39.2167	-74.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	03:17:00	\N	0.58	02:20:00	\N	0.58	\N	\N	West Creek, Route 47 bridge	NJ
104347	Riggins Ditch, Heislerville, Delaware Bay, New Jersey	NOS	8536855	39.2183	-74.98	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	01:40:00	\N	1.12	01:36:00	\N	1.12	\N	\N	Riggins Ditch, Heislerville	NJ
104348	Weir Creek bridge, Dividing Creek, Delaware Bay, New Jersey	NOS	8536935	39.25	-75.1283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	02:33:00	\N	0.71	01:38:00	\N	0.71	\N	\N	Weir Creek bridge, Dividing Creek	NJ
104349	Hollywood Beach, The Glades, Delaware Bay, New Jersey	NOS	8537026	39.275	-75.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	01:13:00	\N	0.21	01:45:00	\N	0.21	\N	\N	Hollywood Beach, The Glades	NJ
104350	Money Island, Nantuxent Creek entrance, Delaware Bay, New Jersey	NOS	8537052	39.285	-75.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	-01:58:00	\N	1.1	-01:43:00	\N	1.1	\N	\N	Money Island, Nantuxent Creek entrance	NJ
104351	Mauricetown, Maurice River, New Jersey	NOS	8537059	39.285	-74.9917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	02:30:00	\N	1.05	02:17:00	\N	1.05	\N	\N	Mauricetown	NJ
104352	Newport Landing, Nantuxent Creek, Delaware Bay, New Jersey	NOS	8537079	39.2917	-75.1983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	-00:28:00	\N	0.74	-00:03:00	\N	0.74	\N	\N	Newport Landing, Nantuxent Creek	NJ
104353	Cedar Creek entrance, Nantuxent Cove, Delaware Bay, New Jersey	NOS	8537101	39.2983	-75.2467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	-01:51:00	\N	1.08	-01:37:00	\N	1.08	\N	\N	Cedar Creek entrance, Nantuxent Cove	NJ
104354	Back Creek entrance, Nantuxent Cove, Delaware Bay, New Jersey	NOS	8537116	39.305	-75.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	-01:34:00	\N	1.07	-01:29:00	\N	1.07	\N	\N	Back Creek entrance, Nantuxent Cove	NJ
104355	Port Elizabeth, Manumuskin River, Maurice River, New Jersey	NOS	8537147	39.3133	-74.985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	02:58:00	\N	1.05	02:52:00	\N	1.05	\N	\N	Port Elizabeth, Manumuskin River	NJ
104356	Menantico Creek entrance, Maurice River, New Jersey	NOS	8537242	39.3433	-75.0083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	03:09:00	\N	1.1	03:06:00	\N	1.1	\N	\N	Menantico Creek entrance	NJ
104357	Tindalls Wharf, Cohansey River, Delaware Bay, New Jersey	NOS	8537353	39.3783	-75.235	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	-00:02:00	\N	1.09	01:01:00	\N	1.09	\N	\N	Tindalls Wharf, Cohansey River	NJ
104358	Millville, Maurice River, New Jersey	NOS	8537359	39.3917	-75.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	03:36:00	\N	1.21	03:33:00	\N	1.21	\N	\N	Millville	NJ
104359	Greenwich Pier, Cohansey River, Delaware Bay, New Jersey	NOS	8537374	39.3833	-75.35	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	-00:54:00	\N	0.99	-00:42:00	\N	0.99	\N	\N	Greenwich Pier, Cohansey River	NJ
104360	Stathems Neck, Stow Creek, Delaware River, New Jersey	NOS	8537416	39.4067	-75.405	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	-00:37:00	\N	0.88	-00:22:00	\N	0.88	\N	\N	Stathems Neck, Stow Creek, N.J.	NJ
104361	Pine Island, Malapartis Creek, Mad Horse Creek, New Jersey	NOS	8537488	39.4217	-75.4283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	-00:18:00	\N	0.92	00:21:00	\N	0.92	\N	\N	Pine Island, Malapartis Creek, N.J.	NJ
104362	Raccoon Ditch, Newport Meadows, Stow Creek, Delaware River, New Jersey	NOS	8537489	39.4217	-75.3817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	00:33:00	\N	0.76	01:08:00	\N	0.76	\N	\N	Raccoon Ditch, Newport Meadows, Stow Creek, N.J.	NJ
104363	1 nmi above entrance, Mad Horse Creek, New Jersey	NOS	8537535	39.4317	-75.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	-00:47:00	\N	1.07	-00:20:00	\N	1.07	\N	\N	1 n.mi. above entrance, N.J.	NJ
104364	Canton, Stow Creek, Delaware River, New Jersey	NOS	8537562	39.4617	-75.4033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	00:45:00	\N	0.8	01:36:00	\N	0.8	\N	\N	Canton, Stow Creek, N.J.	NJ
104365	Artificial Island, Salem Nuclear Plant, Delaware River, New Jersey	NOS	8537614	39.46	-75.5317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	-00:33:00	\N	1.08	-00:35:00	\N	1.08	\N	\N	Artificial Island, Salem Nuclear Plant, N.J.	NJ
104366	Hope Creek, 0.6 nmi above entrance, Delaware River, New Jersey	NOS	8537667	39.4583	-75.495	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	-00:36:00	\N	1.05	-00:25:00	\N	1.05	\N	\N	Hope Creek, 0.6 n.mi. above entrance, N.J.	NJ
104367	0.8 nmi above entrance, Alloway Creek, New Jersey	NOS	8537731	39.4967	-75.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	-00:10:00	\N	0.99	00:21:00	\N	0.99	\N	\N	0.8 n.mi. above entrance	NJ
104368	2.5 nmi above entrance, Alloway Creek, New Jersey	NOS	8537753	39.505	-75.4833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	00:15:00	\N	0.9	00:51:00	\N	0.9	\N	\N	2.5 n.mi. above entrance	NJ
104369	Abbots Meadow, Alloway Creek, New Jersey	NOS	8537774	39.5117	-75.4933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	00:12:00	\N	0.94	00:44:00	\N	0.94	\N	\N	Abbots Meadow	NJ
104370	Coopers Creek bridge, Alloway Creek, New Jersey	NOS	8537779	39.5133	-75.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	01:00:00	\N	0.78	01:51:00	\N	0.78	\N	\N	Coopers Creek bridge	NJ
104371	Quinton, Alloway Creek, New Jersey	NOS	8537889	39.5483	-75.415	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	01:30:00	\N	0.69	02:24:00	\N	0.69	\N	\N	Quinton	NJ
104372	Sinnickson Landing, Salem River, New Jersey	NOS	8537961	39.57	-75.4983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	00:19:00	\N	0.97	00:04:00	\N	0.97	\N	\N	Sinnickson Landing	NJ
104373	Salem, Salem River, New Jersey	NOS	8537979	39.5767	-75.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	00:41:00	\N	0.76	00:49:00	\N	0.76	\N	\N	Salem	NJ
104374	Salem Canal entrance, Delaware River, New Jersey	NOS	8538231	39.6833	-75.51	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	00:52:00	\N	1	00:36:00	\N	1	\N	\N	Salem Canal entrance, N.J.	NJ
104375	Auburn, Oldmans Creek, Delaware River, New Jersey	NOS	8538274	39.715	-75.36	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	03:30:00	\N	0.55	04:12:00	\N	0.55	\N	\N	Auburn, Oldmans Creek, N.J.	NJ
104376	Pedricktown, Oldmans Creek, Delaware River, New Jersey	NOS	8538369	39.7617	-75.4033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	02:07:00	\N	0.75	02:11:00	\N	0.75	\N	\N	Pedricktown, Oldmans Creek, N.J.	NJ
104377	Mantua, Mantua Creek, New Jersey	NOS	8538438	39.795	-75.1767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	00:56:00	\N	0.71	01:28:00	\N	0.71	\N	\N	Mantua, Mantua Creek, N.J.	NJ
104378	Bridgeport, Raccoon Creek, New Jersey	NOS	8538449	39.8067	-75.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	-00:50:00	\N	1	-01:11:00	\N	0.91	\N	\N	Bridgeport, Raccoon Creek, N.J.	NJ
104379	Woodbury Creek, New Jersey	NOS	8538548	39.86	-75.1867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	-00:14:00	\N	0.95	-00:13:00	\N	0.96	\N	\N	Woodbury Creek, N.J.	NJ
104380	Billingsport, New Jersey	NOS	8538552	39.85	-75.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	-00:28:00	\N	0.95	-00:35:00	\N	0.93	\N	\N	Billingsport, N.J.	NJ
104381	Westville, Rt. 47 bridge, Big Timber Creek, New Jersey	NOS	8538601	39.8733	-75.1233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	00:03:00	\N	1	00:02:00	\N	0.97	\N	\N	Westville, Rt. 47 bridge, Big Timber Creek, N.J.	NJ
104382	Pavonia, Cooper River, RR. bridge, New Jersey	NOS	8538752	39.9467	-75.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	00:23:00	\N	1	00:14:00	\N	1.04	\N	\N	Pavonia, Cooper River, RR. bridge, N.J.	NJ
104383	Hainesport, South Branch, Rancocas Creek, New Jersey	NOS	8538824	39.9783	-74.8233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	03:05:00	\N	0.62	02:58:00	\N	0.62	\N	\N	Hainesport, South Branch	NJ
104384	North Branch, Rancocas Creek, New Jersey	NOS	8538848	39.9983	-74.8183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	03:29:00	\N	0.6	02:58:00	\N	0.48	\N	\N	North Branch	NJ
104385	Palmyra, Pennsauken Creek, Route 73 bridge, New Jersey	NOS	8538853	39.9933	-75.0283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	01:03:00	\N	0.89	00:51:00	\N	0.89	\N	\N	Palmyra, Pennsauken Creek, Route 73 bridge, N.J.	NJ
104386	Pompeston Creek, New Jersey	NOS	8538875	40.0133	-75.0083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	00:43:00	\N	1.05	00:21:00	\N	1.05	\N	\N	Pompeston Creek, N.J.	NJ
104387	Bridgeboro, Rancocas Creek, New Jersey	NOS	8538921	40.0283	-74.9317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	01:18:00	\N	1	01:15:00	\N	1.06	\N	\N	Bridgeboro	NJ
104388	Assiscunk Creek, Route 130 bridge, New Jersey	NOS	8539058	40.0733	-74.8483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	01:31:00	\N	0.85	01:04:00	\N	1.12	\N	\N	Assiscunk Creek, Route 130 bridge, N.J.	NJ
104389	Wanamaker Bridge, Darby Creek, Pennsylvania	NOS	8542425	39.8767	-75.305	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	-00:34:00	\N	0.95	-00:46:00	\N	0.95	\N	\N	Wanamaker Bridge	PA
104390	Norwood City, Darby Creek, Pennsylvania	NOS	8542699	39.88	-75.29	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	-00:35:00	\N	1	-00:42:00	\N	0.97	\N	\N	Norwood City	PA
104391	Tinicum National Wildlife Refuge, Darby Creek, Pennsylvania	NOS	8542885	39.8783	-75.2767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	-00:08:00	\N	0.9	-00:22:00	\N	0.91	\N	\N	Tinicum National Wildlife Refuge	PA
104392	Tinicum National Wildlife Refuge, Darby Creek, Pennsylvania (2)	NOS	8543024	39.8867	-75.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	00:27:00	\N	0.74	-00:24:00	\N	0.74	\N	\N	Tinicum National Wildlife Refuge	PA
104393	Penrose Avenue Bridge, Schuylkill River, Pennsylvania	NOS	8543925	39.8983	-75.2117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	-00:11:00	\N	0.85	-00:22:00	\N	0.96	\N	\N	Penrose Avenue Bridge	PA
104394	Market Street Bridge, Schuylkill River, Pennsylvania	NOS	8545120	39.955	-75.18	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	00:00:00	\N	0.8	-00:20:00	\N	0.99	\N	\N	Market Street Bridge	PA
104395	Cornwells Heights, Pennsylvania	NOS	8547333	40.0683	-74.9383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	00:58:00	\N	1	00:46:00	\N	1.17	\N	\N	Cornwells Heights, Pa.	PA
104396	Edgely, Pennsylvania	NOS	8549424	40.1283	-74.8233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102933	01:28:00	\N	1.15	01:08:00	\N	1.27	\N	\N	Edgely, Pa.	PA
104397	Edgemoor, Delaware River, Delaware	NOS	8550438	39.75	-75.4933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	01:11:00	\N	1.17	00:52:00	\N	1.02	\N	\N	Edgemoor, Del.	DE
104398	Millside, RR. bridge, Christina River, Delaware	NOS	8550658	39.725	-75.56	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	01:19:00	\N	1.06	01:08:00	\N	0.99	\N	\N	Millside, RR. bridge	DE
104399	Wilmington Marine Terminal, Christina River, Delaware	NOS	8550714	39.7183	-75.52	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	01:06:00	\N	1.11	00:50:00	\N	0.99	\N	\N	Wilmington Marine Terminal	DE
104400	New Castle, Delaware River, Delaware	NOS	8551201	39.6567	-75.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	00:40:00	\N	1	00:29:00	\N	0.98	\N	\N	New Castle, Delaware	DE
104401	Pea Patch Island, Bulkhead Shoal Channel, Delaware River, Delaware	NOS	8551702	39.5833	-75.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	00:00:00	\N	1	00:03:00	\N	1.05	\N	\N	Pea Patch Island, Bulkhead Shoal Channel, Del.	DE
104402	Delaware City Branch Channel bridge, Delaware River, Delaware	NOS	8551851	39.57	-75.59	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	00:05:00	\N	0.89	00:00:00	\N	1.02	\N	\N	Delaware City Branch Channel bridge	DE
104403	St. Georges, Chesapeake and Delaware Canal, Delaware	NOS	8551973	39.555	-75.6483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	-00:17:00	\N	1	-00:16:00	\N	0.83	\N	\N	St. Georges, Delaware	DE
104404	Summit Bridge, Chesapeake and Delaware Canal, Delaware	NOS	8552125	39.5333	-75.7333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	-00:52:00	\N	0.56	-00:28:00	\N	0.65	\N	\N	Summit Bridge, Delaware	DE
104405	Taylors Bridge, Blackbird Creek, Delaware River, Delaware	NOS	8553069	39.405	-75.5983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	00:57:00	\N	0.56	01:53:00	\N	0.54	\N	\N	Taylors Bridge, Blackbird Creek, Del.	DE
104406	Woodland Beach, Delaware River, Delaware	NOS	8553501	39.3333	-75.4667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102938	-01:10:00	\N	1.11	-01:07:00	\N	1.11	\N	\N	Woodland Beach, Del.	DE
104407	Leipsic, Leipsic River, Delaware Bay, Delaware	NOS	8554038	39.245	-75.5183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	03:49:00	\N	0.63	03:35:00	\N	0.85	\N	\N	Leipsic, Leipsic River	DE
104408	Murderkill River entrance, Delaware Bay, Delaware	NOS	8555388	39.0583	-75.3967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	01:11:00	\N	0.94	00:39:00	\N	1.25	\N	\N	Murderkill River entrance	DE
104409	Mispillion River entrance, Delaware Bay, Delaware	NOS	8556198	38.945	-75.3133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102941	00:50:00	\N	1	00:22:00	\N	1.13	\N	\N	Mispillion River entrance	DE
104410	Rehoboth Beach, Delaware	NOS	8557863	38.72	-75.0833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	00:08:00	\N	1.33	00:15:00	\N	1.13	\N	\N	Rehoboth Beach	DE
104411	Keydash, Isle of Wight Bay, Maryland	NOS	8570255	38.3417	-75.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	00:54:00	\N	0.81	-00:57:00	\N	0.47	\N	\N	Keydash, Isle of Wight Bay	MD
104412	Ocean City (Isle of Wight Bay), Maryland	NOS	8570282	38.3317	-75.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	00:23:00	\N	0.94	00:25:00	\N	0.67	\N	\N	Ocean City (Isle of Wight Bay)	MD
104413	Ape Hole Creek, Pocomoke Sound, Chesapeake Bay, Maryland	NOS	8571072	37.961700439453125	-75.82170104980469	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	04:58:00	\N	0.83	04:27:00	\N	0.9	\N	\N	Ape Hole Creek, Pocomoke Sound	MD
104414	Shelltown, Pocomoke River, Maryland	NOS	8571097	37.98	-75.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	05:16:00	\N	1	04:32:00	\N	0.94	\N	\N	Shelltown	MD
104415	Colburn Creek, Big Annemessex River, Chesapeake Bay, Maryland	NOS	8571181	38.0483	-75.8033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	05:30:00	\N	1.17	04:59:00	\N	0.78	\N	\N	Colburn Creek, Big Annemessex River	MD
104416	Long Point, Big Annemessex River, Chesapeake Bay, Maryland	NOS	8571201	38.0567	-75.8033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	05:47:00	\N	0.83	05:19:00	\N	0.82	\N	\N	Long Point, Big Annemessex River	MD
104417	Holland Island Bar Light, Chesapeake Bay, Maryland	NOS	8571214	38.0683	-76.0967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	05:30:00	\N	0.58	05:16:00	\N	0.56	\N	\N	Holland Island Bar Light	MD
104418	Teague Creek, Manokin River, Chesapeake Bay, Maryland	NOS	8571269	38.1083	-75.8383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	06:05:00	\N	0.83	05:38:00	\N	0.82	\N	\N	Teague Creek, Manokin River	MD
104419	Chance, Chesapeake Bay, Maryland	NOS	8571351	38.1717	-75.945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	05:57:00	\N	1.17	05:29:00	\N	0.78	\N	\N	Chance	MD
104420	Sharkfin Shoal Light, Chesapeake Bay, Maryland	NOS	8571396	38.2017	-75.9867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	06:06:00	\N	0.92	05:46:00	\N	0.86	\N	\N	Sharkfin Shoal Light	MD
104421	Hooper Strait Light, Chesapeake Bay, Maryland	NOS	8571402	38.2267	-76.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	05:51:00	\N	1.17	05:26:00	\N	0.61	\N	\N	Hooper Strait Light	MD
104422	Great Shoals Light, Monie Bay, Chesapeake Bay, Maryland	NOS	8571416	38.2167	-75.8833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	06:22:00	\N	0.92	06:00:00	\N	0.9	\N	\N	Great Shoals Light, Monie Bay	MD
104423	Roaring Point, Nanticoke River, Maryland	NOS	8571476	38.2617	-75.92	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	06:35:00	\N	0.92	06:00:00	\N	0.9	\N	\N	Roaring Point	MD
104424	Whitehaven, Wicomico River, Maryland	NOS	8571485	38.2683	-75.7883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	06:46:00	\N	1	06:26:00	\N	0.94	\N	\N	Whitehaven	MD
104425	Middle Hooper Island, Chesapeake Bay, Maryland	NOS	8571519	38.2967	-76.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-04:39:00	\N	1.5	-04:40:00	\N	1.32	\N	\N	Middle Hooper Island	MD
104426	Taylors Island, Slaughter Creek, Little Choptank River, Maryland	NOS	8571752	38.4667	-76.295	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-03:00:00	\N	1.18	-03:15:00	\N	1.1	\N	\N	Taylors Island, Slaughter Creek	MD
104427	Woolford, Church Creek, Little Choptank River, Maryland	NOS	8571807	38.5067	-76.1733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-02:55:00	\N	1.41	-03:11:00	\N	1.25	\N	\N	Woolford, Church Creek	MD
104428	Cherry Island, Beckwiths Creek, Little Choptank River, Maryland	NOS	8571881	38.5617	-76.2083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-02:57:00	\N	1.27	-03:07:00	\N	1.18	\N	\N	Cherry Island, Beckwiths Creek	MD
104429	Avalon, Dogwood Harbor, Chesapeake Bay, Maryland	NOS	8571901	38.71	-76.335	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-02:48:00	\N	1.36	-02:54:00	\N	1.18	\N	\N	Avalon, Dogwood Harbor	MD
104430	Dover Bridge, Choptank River, Maryland	NOS	8571944	38.7567	-75.9983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-00:41:00	\N	1.68	-00:18:00	\N	1.54	\N	\N	Dover Bridge	MD
104431	Ferry Cove, Tilghman Island, Chesapeake Bay, Maryland	NOS	8571979	38.765	-76.3283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-02:42:00	\N	1	-02:33:00	\N	0.98	\N	\N	Tilghman Island, Ferry Cove, Eastern Bay	MD
104432	Oxford, Tred Avon River, Maryland	NOS	8572108	38.6933	-76.1733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-02:45:00	\N	1.41	-02:50:00	\N	1.25	\N	\N	Oxford	MD
104433	Deep Neck Point, Broad Creek, Chesapeake Bay, Maryland	NOS	8572204	38.7317	-76.235	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-02:47:00	\N	1.41	-02:57:00	\N	1.25	\N	\N	Deep Neck Point, Broad Creek	MD
104434	Easton Point, Tred Avon River, Maryland	NOS	8572296	38.7683	-76.095	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-02:35:00	\N	1.59	-02:45:00	\N	1.47	\N	\N	Easton Point	MD
104435	St. Michaels, San Domingo Creek, Chesapeake Bay, Maryland	NOS	8572313	38.775	-76.2333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-02:52:00	\N	1.41	-02:55:00	\N	1.25	\N	\N	St. Michaels, San Domingo Creek	MD
104436	St. Michaels, Miles River, Chesapeake Bay, Maryland (sub)	NOS	8572342	38.7867	-76.2217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-02:02:00	\N	1.18	-02:12:00	\N	1.22	\N	\N	St. Michaels, Miles River	MD
104437	Claiborne, Eastern Bay, Chesapeake Bay, Maryland	NOS	8572468	38.8367	-76.28	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-02:28:00	\N	1.09	-02:26:00	\N	0.96	\N	\N	Claiborne, Eastern Bay	MD
104438	Kent Island Narrows, Chesapeake Bay, Maryland	NOS	8572792	38.9667	-76.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-01:23:00	\N	1.18	-01:30:00	\N	1.1	\N	\N	Kent Island Narrows	MD
104439	Queenstown, Chester River, Maryland	NOS	8572867	38.9967	-76.1583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-00:08:00	\N	1.27	00:05:00	\N	1.18	\N	\N	Queenstown	MD
104440	Centreville Landing, Corsica River, Chester River, Maryland	NOS	8573006	39.0533	-76.075	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	00:14:00	\N	1.89	00:20:00	\N	1.47	\N	\N	Centreville Landing, Corsica River	MD
104441	Cliffs Point, Chester River, Maryland	NOS	8573125	39.1067	-76.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-00:02:00	\N	1.5	00:12:00	\N	1.32	\N	\N	Cliffs Point	MD
104442	Cliffs Wharf, Chester River, Maryland	NOS	8573137	39.11	-76.1383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-00:08:00	\N	1.27	00:09:00	\N	1.33	\N	\N	Cliffs Wharf	MD
104443	Deep Landing, Swan Creek, Chesapeake Bay, Maryland	NOS	8573211	39.145	-76.26	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-00:04:00	\N	1.09	00:02:00	\N	0.96	\N	\N	Deep Landing, Swan Creek	MD
104444	Chestertown, Chester River, Maryland	NOS	8573343	39.2067	-76.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	00:36:00	\N	1.77	01:03:00	\N	1.62	\N	\N	Chestertown	MD
104445	Worton Creek entrance, Chesapeake Bay, Maryland	NOS	8573442	39.2967	-76.1717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	01:19:00	\N	1.27	01:22:00	\N	1.18	\N	\N	Worton Creek entrance	MD
104446	Saxis, Starling Creek, Pocomoke Sound, Chesapeake Bay, Virginia (sub)	NOS	8573777	37.92166666666701	-75.728333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	04:36:00	\N	1.17	03:52:00	\N	0.89	\N	\N	Saxis, Starling Creek, Pocomoke Sound	VA
104447	Charlestown, Northeast River, Chesapeake Bay, Maryland	NOS	8573968	39.5733	-75.97	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	04:03:00	\N	1.86	03:52:00	\N	1.69	\N	\N	Charlestown, Northeast River	MD
104448	Old Frenchtown Wharf, Elk River, Maryland	NOS	8573969	39.575	-75.8433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	03:00:00	\N	2.27	03:13:00	\N	2.06	\N	\N	Old Frenchtown Wharf	MD
104449	Port Deposit, Susquehanna River, Maryland	NOS	8574008	39.6033	-76.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	03:49:00	\N	1.14	03:24:00	\N	1.51	\N	\N	Port Deposit	MD
104450	Hawkins Point, Patapsco River, Maryland	NOS	8574821	39.2083	-76.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	00:06:00	\N	0.95	00:00:00	\N	1.03	\N	\N	Hawkins Point	MD
104451	North Point, Patapsco River, Maryland	NOS	8574857	39.1967	-76.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	00:04:00	\N	1.09	00:12:00	\N	0.93	\N	\N	North Point	MD
104452	Stony Creek, Patapsco River, Maryland	NOS	8574931	39.1633	-76.5267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-00:05:00	\N	0.91	00:03:00	\N	0.95	\N	\N	Stony Creek	MD
104453	Cornfield Creek, Magothy River, Chesapeake Bay, Maryland	NOS	8575109	39.1	-76.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-00:38:00	\N	0.95	-00:29:00	\N	0.89	\N	\N	Cornfield Creek, Magothy River	MD
104454	Mountain Point, Magothy River, Chesapeake Bay, Maryland	NOS	8575229	39.0617	-76.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-00:04:00	\N	0.77	-00:04:00	\N	0.74	\N	\N	Mountain Point, Magothy River	MD
104455	Brewer Point, Severn River, Maryland	NOS	8575331	39.0267	-76.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-00:54:00	\N	0.91	-00:45:00	\N	0.74	\N	\N	Brewer Point	MD
104456	Gingerville Creek, South River, Chesapeake Bay, Maryland	NOS	8575550	38.9583	-76.555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-02:06:00	\N	1	-02:01:00	\N	0.92	\N	\N	Gingerville Creek, South River	MD
104457	Edgewater, South River, Chesapeake Bay, Maryland	NOS	8575579	38.95	-76.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-02:07:00	\N	0.91	-01:51:00	\N	0.81	\N	\N	Edgewater, South River	MD
104458	Thomas Point Shoal Light, Chesapeake Bay, Maryland	NOS	8575737	38.9	-76.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-02:11:00	\N	0.91	-01:56:00	\N	0.81	\N	\N	Thomas Point Shoal Light	MD
104459	Rhode River (County Wharf), Chesapeake Bay, Maryland	NOS	8575787	38.8867	-76.54	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-02:17:00	\N	1	-02:07:00	\N	0.88	\N	\N	Rhode River (County Wharf)	MD
104460	Galesville, West River, Chesapeake Bay, Maryland	NOS	8575923	38.8417	-76.54	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-01:34:00	\N	0.91	-01:39:00	\N	0.81	\N	\N	Galesville, West River	MD
104461	Rose Haven, Chesapeake Bay, Maryland	NOS	8576256	38.725	-76.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-02:44:00	\N	0.91	-02:37:00	\N	0.81	\N	\N	Rose Haven	MD
104462	Chesapeake Beach, Chesapeake Bay, Maryland	NOS	8576363	38.7	-76.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-03:05:00	\N	1	-02:47:00	\N	0.88	\N	\N	Chesapeake Beach	MD
104463	Broomes Island, Patuxent River, Maryland	NOS	8577123	38.415	-76.545	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-04:19:00	\N	1.36	-04:13:00	\N	1.18	\N	\N	Broomes Island	MD
104464	Cornfield Harbor, Potomac River, Maryland	NOS	8577940	38.06	-76.3617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-07:35:00	\N	0.53	-06:16:00	\N	0.48	\N	\N	Cornfield Harbor, Md.	MD
104465	Point Lookout, Chesapeake Bay, Maryland	NOS	8578002	38.04	-76.3233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-05:37:00	\N	0.77	-05:28:00	\N	1.02	\N	\N	Point Lookout	MD
104466	Piney Point, Potomac River, Maryland	NOS	8578240	38.1333333	-76.5333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-07:16:00	\N	0.6	-05:54:00	\N	0.51	\N	\N	Piney Point, Md.	MD
104467	Colton Point, Potomac River, Maryland	NOS	8578465	38.2233	-76.7483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-06:43:00	\N	0.73	-05:18:00	\N	0.65	\N	\N	Colton Point, Md.	MD
104468	Mills Point (south of), Wicomico River, Maryland	NOS	8578551	38.3267	-76.8333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-06:05:00	\N	0.73	-05:05:00	\N	0.65	\N	\N	Mills Point (south of), Wicomico Riv., Md.	MD
104469	Lower Cedar Point, Potomac River, Maryland	NOS	8578693	38.3417	-76.9767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-05:56:00	\N	0.6	-04:48:00	\N	0.54	\N	\N	Lower Cedar Point, Md.	MD
104470	Goose Creek, Port Tobacco River, Potomac River, Maryland	NOS	8578769	38.4533	-77.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-05:07:00	\N	0.6	-04:08:00	\N	0.54	\N	\N	Goose Creek, Port Tobacco River, Md.	MD
104471	Riverside, Potomac River, Maryland	NOS	8578853	38.3867	-77.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-04:24:00	\N	0.53	-03:23:00	\N	0.48	\N	\N	Riverside, Md.	MD
104472	Clifton Beach, Smith Point, Potomac River, Maryland	NOS	8578931	38.41333333333299	-77.266666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-02:46:00	\N	0.67	-01:42:00	\N	0.41	\N	\N	Clifton Beach, Smith Point, Md.	MD
104473	Liverpool Point, Potomac River, Maryland	NOS	8578984	38.46	-77.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-01:58:00	\N	0.67	-00:39:00	\N	0.44	\N	\N	Liverpool Point, Md.	MD
104474	Benedict, Patuxent River, Maryland	NOS	8579135	38.5133	-76.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102974	-03:54:00	\N	1.82	-03:54:00	\N	1.47	\N	\N	Benedict	MD
104475	Indian Head, Potomac River, Maryland	NOS	8579381	38.6017	-77.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-01:33:00	\N	0.73	-00:14:00	\N	0.65	\N	\N	Indian Head, Md.	MD
104476	Marshall Hall, Potomac River, Maryland	NOS	8579629	38.6867	-77.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-00:55:00	\N	0.93	00:10:00	\N	0.82	\N	\N	Marshall Hall, Md.	MD
104477	Bellevue, Potomac River, DC	NOS	8590111	38.8267	-77.0267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-00:11:00	\N	1.33	00:34:00	\N	1.02	\N	\N	Bellevue, D.C.	DC
104478	Washington Naval Yard, Anacostia River, DC	NOS	8593005	38.8717	-76.995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-00:06:00	\N	1.2	00:18:00	\N	1.01	\N	\N	Washington Naval Yard	DC
104479	Kingman Lake, Anacostia River, DC	NOS	8593545	38.895	-76.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	00:04:00	\N	1.2	00:22:00	\N	1.03	\N	\N	Kingman Lake	DC
104480	Kenilworth Aquatic Garden, Anacostia River, DC	NOS	8593909	38.91	-76.955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	00:10:00	\N	1.07	00:29:00	\N	1.05	\N	\N	Kenilworth Aquatic Garden	DC
104481	Franklin City, Virginia	NOS	8630055	38.0067	-75.3817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	03:00:00	\N	0.63	02:20:00	\N	0.22	\N	\N	Franklin City	VA
104482	Chincoteague Island, Blake Cove, Virginia	NOS	8630194	37.9517	-75.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	02:32:00	\N	0.56	01:51:00	\N	0.28	\N	\N	Chincoteague Island, Blake Cove	VA
104483	Chincoteague Island, Oyster Bay, Virginia	NOS	8630225	37.9417	-75.3467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	02:05:00	\N	0.56	01:44:00	\N	0.46	\N	\N	Chincoteague Island, Oyster Bay	VA
104484	Chincoteague Island, Lewis Creek, Virginia	NOS	8630229	37.9383	-75.3733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	01:38:00	\N	0.63	01:17:00	\N	0.4	\N	\N	Chincoteague Island, Lewis Creek	VA
104485	Wishart Point, Bogues Bay, Virginia	NOS	8630371	37.8817	-75.4917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	01:13:00	\N	0.63	00:52:00	\N	0.77	\N	\N	Wishart Point, Bogues Bay	VA
104486	Assateague Beach, Toms Cove, Virginia	NOS	8630413	37.865	-75.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	00:48:00	\N	1.25	00:35:00	\N	1.08	\N	\N	Assateague Beach, Toms Cove	VA
104487	Wallops Island, Virginia	NOS	8630440	37.8417	-75.4783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	-00:04:00	\N	0.31	00:04:00	\N	1.06	\N	\N	Wallops Island	VA
104488	Gargathy Neck, Virginia	NOS	8630637	37.7767	-75.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	01:27:00	\N	0.63	01:31:00	\N	0.88	\N	\N	Gargathy Neck	VA
104489	Folly Creek, Metompkin Inlet, Virginia	NOS	8630839	37.6967	-75.635	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	01:12:00	\N	0.63	01:24:00	\N	0.97	\N	\N	Folly Creek, Metompkin Inlet	VA
104490	Metompkin Inlet, Virginia	NOS	8630901	37.6717	-75.595	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	00:44:00	\N	1.25	01:01:00	\N	1.08	\N	\N	Metompkin Inlet	VA
104491	Revel Island, Revel Creek, Virginia	NOS	8631234	37.4967	-75.6833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	00:27:00	\N	1	00:35:00	\N	1.19	\N	\N	Revel Creek, Revel Island	VA
104492	Upshur Neck, south end, Virginia	NOS	8631287	37.4667	-75.8	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	01:14:00	\N	1.25	01:09:00	\N	1.31	\N	\N	Upshur Neck, south end	VA
104493	Great Machipongo Inlet (inside), Virginia	NOS	8631411	37.3933	-75.7133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	00:56:00	\N	1.25	01:05:00	\N	1.16	\N	\N	Great Machipongo Inlet (inside)	VA
104494	Sand Shoal Inlet (USCG station), Virginia	NOS	8631542	37.3017	-75.7783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	00:17:00	\N	1	00:32:00	\N	1.18	\N	\N	Sand Shoal Inlet (Coast Guard Station)	VA
104495	Oyster Harbor, Virginia	NOS	8631591	37.2883	-75.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	00:36:00	\N	1.13	01:00:00	\N	1.34	\N	\N	Oyster Harbor	VA
104496	Smith Island (USCG station), Virginia	NOS	8631874	37.1233	-75.9117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102945	01:29:00	\N	1.25	00:52:00	\N	1.05	\N	\N	Smith Island (Coast Guard Station)	VA
104497	Fishermans Island, Chesapeake Bay, Virginia	NOS	8632085	37.0967	-75.9833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	00:11:00	\N	1.25	00:02:00	\N	1.19	\N	\N	Fishermans Island	VA
104498	Old Plantation Light, Chesapeake Bay, Virginia	NOS	8632314	37.2333	-76.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	00:52:00	\N	0.83	00:33:00	\N	0.92	\N	\N	Old Plantation Light	VA
104499	Cape Charles Harbor (USCG wharf), Chesapeake Bay, Virginia (sub)	NOS	8632366	37.2633	-76.02	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	01:03:00	\N	0.92	00:45:00	\N	0.9	\N	\N	Cape Charles Harbor	VA
104500	Harborton, Pungoteague Creek, Chesapeake Bay, Virginia	NOS	8633091	37.6667	-75.8333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	03:33:00	\N	0.83	03:11:00	\N	0.7	\N	\N	Harborton, Pungoteague Creek	VA
104501	Onancock, Onancock Creek, Chesapeake Bay, Virginia	NOS	8633214	37.7117	-75.7567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	04:19:00	\N	0.83	03:55:00	\N	0.71	\N	\N	Onancock, Onancock Creek	VA
104502	Chesconessex Creek, Schooner Bay, Chesapeake Bay, Virginia	NOS	8633362	37.7633	-75.7733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	03:59:00	\N	1.25	03:41:00	\N	0.78	\N	\N	Chesconessex Creek, Schooner Bay	VA
104503	Watts Island, Chesapeake Bay, Virginia	NOS	8633451	37.7983	-75.8967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	04:12:00	\N	0.83	04:02:00	\N	0.64	\N	\N	Watts Island	VA
104504	Guard Shore, Chesapeake Bay, Virginia	NOS	8633596	37.85	-75.7	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	04:47:00	\N	0.83	04:06:00	\N	0.9	\N	\N	Guard Shore	VA
104505	Muddy Creek entrance, Chesapeake Bay, Virginia	NOS	8633604	37.855	-75.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	04:51:00	\N	0.83	04:14:00	\N	0.86	\N	\N	Muddy Creek Entrance	VA
104506	Alexandria, Potomac River, Virginia	NOS	8634214	38.805	-77.0383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-00:11:00	\N	1.33	00:18:00	\N	0.96	\N	\N	Alexandria, Va.	VA
104507	Quantico, Potomac River, Virginia	NOS	8634689	38.52	-77.2867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-02:04:00	\N	0.67	-00:52:00	\N	0.51	\N	\N	Quantico, Va.	VA
104508	Aquia Creek, Potomac River, Virginia	NOS	8634858	38.4183	-77.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-02:32:00	\N	0.67	-01:28:00	\N	0.48	\N	\N	Aquia Creek, Va.	VA
104509	Mathias Point, Potomac River, Virginia	NOS	8634892	38.3983	-77.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-04:56:00	\N	0.67	-04:00:00	\N	0.44	\N	\N	Mathias Point, Va.	VA
104510	Massaponax Sand & Gravel, Rappahannock River, Virginia	NOS	8635154	38.255	-77.41	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-00:41:00	\N	1.33	-00:39:00	\N	0.88	\N	\N	Massaponax	VA
104511	Hopyard Landing, Rappahannock River, Virginia	NOS	8635171	38.2433	-77.2267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-01:57:00	\N	0.67	-01:07:00	\N	0.75	\N	\N	Hopyard Landing	VA
104512	Port Royal, Rappahannock River, Virginia	NOS	8635299	38.1733	-77.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-03:02:00	\N	0.67	-02:19:00	\N	0.68	\N	\N	Port Royal	VA
104513	Mount Holly, Nomini Creek, Potomac River, Virginia	NOS	8635409	38.0983	-76.735	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-06:14:00	\N	0.67	-04:51:00	\N	0.54	\N	\N	Mount Holly, Nomini Creek, Va.	VA
104514	Ragged Point, Coles Neck, Potomac River, Virginia	NOS	8635485	38.1417	-76.6133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-07:03:00	\N	0.67	-05:35:00	\N	0.54	\N	\N	Ragged Point, Coles Neck, Va.	VA
104515	Saunders Wharf, Rappahannock River, Virginia	NOS	8635554	38.09	-77.0333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-04:41:00	\N	0.66	-03:53:00	\N	0.54	\N	\N	Saunders Wharf	VA
104516	Kinsale, Yeocomico River, Virginia	NOS	8635671	38.0317	-76.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-06:53:00	\N	0.67	-05:46:00	\N	0.44	\N	\N	Kinsale, Yeocomico River, Va.	VA
104517	Travis Point, Coan River, Potomac River, Virginia	NOS	8635762	37.9967	-76.4667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-07:05:00	\N	0.67	-06:00:00	\N	0.44	\N	\N	Travis Point, Coan River, Va.	VA
104518	Tappahannock, Rappahannock River, Virginia	NOS	8635881	37.93	-76.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	05:18:00	\N	0.83	04:40:00	\N	0.71	\N	\N	Tappahannock	VA
104519	Sunnybank, Little Wicomico River, Chesapeake Bay, Virginia	NOS	8635959	37.8867	-76.2667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	06:45:00	\N	0.3	06:41:00	\N	0.3	\N	\N	Sunnybank, Little Wicomico River	VA
104520	Glebe Point, Great Wicomico River, Chesapeake Bay, Virginia	NOS	8636046	37.8467	-76.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	04:37:00	\N	0.83	04:15:00	\N	0.49	\N	\N	Glebe Point, Great Wicomico River	VA
104521	Fleeton Point, Chesapeake Bay, Virginia	NOS	8636128	37.8133	-76.275	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	04:14:00	\N	0.41	03:58:00	\N	0.41	\N	\N	Fleeton Point	VA
104522	Great Wicomico River Light, Chesapeake Bay, Virginia	NOS	8636142	37.805	-76.2683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	04:11:00	\N	0.41	03:58:00	\N	0.41	\N	\N	Great Wicomico River Light	VA
104523	Bayport, Rappahannock River, Virginia	NOS	8636261	37.755	-76.6733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	03:51:00	\N	0.83	03:22:00	\N	0.67	\N	\N	Bayport	VA
104524	Millenbeck, Corrotoman River, Rappahannock River, Virginia	NOS	8636458	37.6683	-76.4867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	03:05:00	\N	0.83	02:37:00	\N	0.55	\N	\N	Millenbeck, Corrotoman River	VA
104525	Wakema (Fraziers Ferry), Mattaponi River, Virginia	NOS	8636499	37.65	-76.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	03:57:00	\N	1.67	03:34:00	\N	1.41	\N	\N	Wakema (Fraziers Ferry), Mattaponi River	VA
104526	Urbanna, Rappahannock River, Virginia	NOS	8636522	37.65	-76.575	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	03:09:00	\N	0.83	02:50:00	\N	0.59	\N	\N	Urbanna	VA
104527	Northbury, Pamunkey River, Virginia	NOS	8636558	37.625	-77.1217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	06:18:00	\N	1.67	06:03:00	\N	1.37	\N	\N	Northbury	VA
104528	Windmill Point Light, Chesapeake Bay, Virginia	NOS	8636623	37.5967	-76.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	03:12:00	\N	0.41	02:48:00	\N	0.41	\N	\N	Windmill Point Light	VA
104529	Mill Creek (Grey Point), Rappahannock River, Virginia	NOS	8636654	37.5833	-76.4183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	02:42:00	\N	0.83	02:28:00	\N	0.55	\N	\N	Mill Creek (Grey Point)	VA
104530	Jackson Creek, Deltaville, Piankatank River, Virginia	NOS	8636735	37.5483	-76.3317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	02:04:00	\N	0.83	01:36:00	\N	0.51	\N	\N	Jackson Creek, Deltaville	VA
104531	West Point, York River, Virginia	NOS	8636769	37.535	-76.7933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	02:38:00	\N	0.83	02:12:00	\N	1.14	\N	\N	West Point	VA
104532	Dixie, Piankatank River, Virginia	NOS	8636831	37.5067	-76.4167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	02:14:00	\N	0.83	01:34:00	\N	0.55	\N	\N	Dixie	VA
104533	Roane Point, York River, Virginia	NOS	8636969	37.4467	-76.7083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	01:50:00	\N	0.83	01:47:00	\N	1.14	\N	\N	Roane Point	VA
104534	Belleville, Mobjack Bay, Virginia	NOS	8637072	37.4117	-76.4383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	00:00:00	\N	0.83	-00:06:00	\N	1.02	\N	\N	Belleville	VA
104535	Wolf Trap Light, Chesapeake Bay, Virginia	NOS	8637144	37.39	-76.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	00:32:00	\N	0.83	-00:02:00	\N	0.67	\N	\N	Wolf Trap Light	VA
104536	Mobjack, East River, Mobjack Bay, Virginia	NOS	8637199	37.3733	-76.3467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	00:02:00	\N	0.83	-00:17:00	\N	0.98	\N	\N	Mobjack, East River	VA
104537	Browns Bay, Mobjack Bay, Virginia	NOS	8637444	37.3	-76.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	-00:03:00	\N	1.58	-00:11:00	\N	0.98	\N	\N	Browns Bay	VA
104538	Cheatham Annex, York River, Virginia	NOS	8637472	37.2917	-76.5867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	00:40:00	\N	0.83	00:48:00	\N	1.02	\N	\N	Cheatham Annex	VA
104539	Tue Marshes Light, York River, Virginia	NOS	8637663	37.235	-76.385	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	00:03:00	\N	0.83	00:03:00	\N	0.9	\N	\N	Tue Marshes Light	VA
104540	Goodwin Neck, Yorktown, York River, Virginia	NOS	8637686	37.23	-76.4367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	00:15:00	\N	0.83	00:18:00	\N	0.9	\N	\N	Yorktown, Goodwin Neck	VA
104541	Messick Point, Back River, Chesapeake Bay, Virginia	NOS	8638051	37.1083	-76.3183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	00:02:00	\N	0.97	-00:07:00	\N	0.97	\N	\N	Messick Point, Back River	VA
104542	Old Point Comfort, Hampton Roads, Virginia	NOS	8638288	37.0033	-76.315	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	00:09:00	\N	0.83	00:01:00	\N	1.02	\N	\N	Old Point Comfort	VA
104543	Newport News, James River, Virginia	NOS	8638379	36.9733	-76.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	00:28:00	\N	0.83	00:29:00	\N	1.08	\N	\N	Newport News	VA
104544	Huntington Park, James River, Virginia	NOS	8638401	37.0133	-76.4583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	00:39:00	\N	0.92	00:38:00	\N	1.07	\N	\N	Huntington Park	VA
104545	Town Point, Nansemond River, Virginia	NOS	8638406	36.8833	-76.5083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	00:44:00	\N	0.83	00:37:00	\N	1.22	\N	\N	Town Point	VA
104546	Menchville, James River, Virginia	NOS	8638407	37.0817	-76.525	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	01:19:00	\N	0.83	01:03:00	\N	1.06	\N	\N	Menchville	VA
104547	Hollidays Point (Kings Highway bridge), Nansemond River, Virginia	NOS	8638409	36.8383	-76.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	01:03:00	\N	1.67	00:56:00	\N	1.25	\N	\N	Hollidays Point (Kings Highway bridge)	VA
104548	Smithfield, Pagan River, James River, Virginia	NOS	8638418	36.9833	-76.63	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	01:38:00	\N	0.83	01:34:00	\N	1.14	\N	\N	Smithfield, Pagan River	VA
104549	Burwell Bay, James River, Virginia (sub)	NOS	8638421	37.0567	-76.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	01:39:00	\N	1.17	01:17:00	\N	1	\N	\N	Burwell Bay	VA
104550	Wright Island Landing, Chickahominy River, Virginia	NOS	8638441	37.345	-76.875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	05:03:00	\N	0.83	04:44:00	\N	0.9	\N	\N	Wright Island Landing	VA
104551	Ferry Point (bridge), Chickahominy River, Virginia	NOS	8638442	37.2633	-76.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	04:26:00	\N	0.83	04:01:00	\N	0.78	\N	\N	Ferry Point (bridge)	VA
104552	Claremont, James River, Virginia	NOS	8638449	37.2317	-76.9483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	04:25:00	\N	1.17	03:51:00	\N	0.76	\N	\N	Claremont	VA
104553	Sturgeon Point, James River, Virginia	NOS	8638455	37.3067	-77.0067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	05:09:00	\N	0.83	04:37:00	\N	0.86	\N	\N	Sturgeon Point	VA
104554	Jordan Point, James River, Virginia	NOS	8638476	37.3133	-77.2233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	06:39:00	\N	0.83	06:16:00	\N	1.02	\N	\N	Jordan Point	VA
104555	Haxall, James River, Virginia	NOS	8638478	37.3733	-77.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-04:53:00	\N	1.33	-04:10:00	\N	0.99	\N	\N	Haxall	VA
104556	Meadowville, James River, Virginia	NOS	8638486	37.3783	-77.3233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-04:17:00	\N	1.33	-03:46:00	\N	1.05	\N	\N	Meadowville	VA
104557	Chester, James River, Virginia	NOS	8638491	37.3833	-77.3783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102982	-03:59:00	\N	0.67	-03:39:00	\N	1.02	\N	\N	Chester	VA
104558	Pig Point, Nansemond River, Virginia	NOS	8638514	36.9167	-76.435	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	00:40:00	\N	0.83	00:42:00	\N	1.05	\N	\N	Pig Point	VA
104559	Craney Island Light, Elizabeth River, Virginia	NOS	8638596	36.8917	-76.3383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	00:04:00	\N	0.83	00:18:00	\N	1.06	\N	\N	Craney Island Light	VA
104560	Norfolk, Elizabeth River, Virginia	NOS	8638654	36.8517	-76.2983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	00:20:00	\N	0.83	00:23:00	\N	1.14	\N	\N	Norfolk	VA
104561	Little Creek NAB, Chesapeake Bay, Virginia	NOS	8638776	36.9117	-76.175	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	00:09:00	\N	1.17	00:08:00	\N	1.01	\N	\N	Little Creek, NAB	VA
104562	Buchanan Creek entrance, Lynnhaven Bay, Virginia	NOS	8638854	36.8617	-76.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	02:56:00	\N	0.83	02:02:00	\N	0.75	\N	\N	Buchanan Creek entrance	VA
104563	Bayville, Lynnhaven Bay, Virginia	NOS	8638867	36.8933	-76.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	02:48:00	\N	0.83	01:52:00	\N	0.67	\N	\N	Bayville	VA
104564	Virginia pilot's dock, Lynnhaven Inlet, Chesapeake Bay, Virginia	NOS	8638888	36.9067	-76.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	00:38:00	\N	1.08	00:40:00	\N	0.88	\N	\N	Lynnhaven Inlet, Virginia Pilots Dock	VA
104565	Long Creek, Lynnhaven Bay, Virginia	NOS	8638916	36.9033	-76.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	01:15:00	\N	1.08	01:15:00	\N	0.68	\N	\N	Long Creek	VA
104566	Brown Cove, Lynnhaven Bay, Virginia	NOS	8638922	36.875	-76.0617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	02:43:00	\N	0.83	02:05:00	\N	0.65	\N	\N	Brown Cove	VA
104567	Broad Bay Canal, Lynnhaven Bay, Virginia	NOS	8638923	36.9017	-76.0617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103021	02:00:00	\N	0.92	02:05:00	\N	0.56	\N	\N	Broad Bay Canal	VA
104568	Cape Henry, Virginia	NOS	8638999	36.93	-76.00669444444445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103025	00:36:00	\N	0.93	00:31:00	\N	0.96	\N	\N	Cape Henry	VA
104569	Virginia Beach, Virginia	NOS	8639168	36.8433	-75.9717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103025	00:16:00	\N	1.07	00:15:00	\N	1.07	\N	\N	Virginia Beach	VA
104570	Rudee Inlet entrance, Virginia	NOS	8639208	36.8317	-75.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103025	00:02:00	\N	0.86	00:02:00	\N	1.01	\N	\N	Rudee Inlet entrance	VA
104571	Rudee Heights, Lake Wesley, Virginia	NOS	8639214	36.825	-75.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103025	00:16:00	\N	1	00:18:00	\N	1.03	\N	\N	Rudee Heights, Lake Wesley	VA
104572	Lake Rudee, south end, Virginia	NOS	8639219	36.825	-75.9817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103025	00:19:00	\N	1.07	00:20:00	\N	1.05	\N	\N	Lake Rudee, south end	VA
104573	Deep Creek entrance, Elizabeth River, Virginia	NOS	8639414	36.755	-76.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103018	00:18:00	\N	1.25	00:22:00	\N	1.21	\N	\N	Deep Creek Entrance	VA
104574	Sandbridge, Virginia	NOS	8639428	36.6917	-75.92	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103025	00:07:00	\N	1.04	00:07:00	\N	1.04	\N	\N	Sandbridge	VA
104575	Kitty Hawk (ocean), North Carolina	NOS	8651605	36.1017	-75.71	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103025	00:02:00	\N	1.43	-00:01:00	\N	1.01	\N	\N	Kitty Hawk (ocean)	NC
104576	Jennettes Pier, Nags Head (ocean), North Carolina	NOS	8652226	35.91	-75.59169444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103025	00:01:00	\N	1.43	-00:05:00	\N	1.04	\N	\N	Jennettes Pier, Nags Head (ocean)	NC
104577	Roanoke Sound Channel, North Carolina	NOS	8652591	35.7983	-75.5833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103029	01:17:00	\N	0.14	01:37:00	\N	0.47	\N	\N	Roanoke Sound Channel	NC
104578	Oregon Inlet Channel, Pamlico Sound, North Carolina	NOS	8652657	35.7733	-75.5583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103029	-00:34:00	\N	0.43	-00:09:00	\N	1.23	\N	\N	Oregon Inlet Channel	NC
104579	Oregon Inlet Bridge, North Carolina	NOS	8652659	35.7733	-75.5383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103029	-00:55:00	\N	0.64	-00:17:00	\N	1.89	\N	\N	Oregon Inlet Bridge	NC
104580	Davis Slough, Pamlico Sound, North Carolina	NOS	8652737	35.7483	-75.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103029	-00:01:00	\N	0.29	00:09:00	\N	0.85	\N	\N	Davis Slough	NC
104581	North River Bridge, North Carolina	NOS	8656225	34.7917	-76.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	03:08:00	\N	0.67	02:25:00	\N	0.59	\N	\N	North River Bridge	NC
104582	Newport River (Yacht Club), North Carolina	NOS	8656306	34.7683	-76.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	01:13:00	\N	1	01:03:00	\N	1.03	\N	\N	Newport River (Yacht Club)	NC
104583	Gallants Channel, North Carolina	NOS	8656451	34.7283	-76.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	00:44:00	\N	1.25	00:49:00	\N	1.01	\N	\N	Gallant Channel	NC
104584	Morehead City, North Carolina	NOS	8656496	34.7183	-76.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	00:27:00	\N	1.25	00:26:00	\N	1.04	\N	\N	Morehead City	NC
104585	Atlantic Beach Bridge, North Carolina	NOS	8656499	34.7183	-76.7367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	01:02:00	\N	0.83	00:48:00	\N	0.79	\N	\N	Atlantic Beach Bridge	NC
104586	Harkers Island Bridge, North Carolina	NOS	8656503	34.715	-76.5783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	02:31:00	\N	0.67	02:08:00	\N	0.52	\N	\N	Harkers Island Bridge	NC
104587	Beaufort, Taylor Creek, North Carolina	NOS	8656518	34.7117	-76.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	00:48:00	\N	1.17	00:52:00	\N	0.95	\N	\N	Beaufort, Taylor Creek	NC
104588	Lenoxville Point, North Carolina	NOS	8656539	34.7083	-76.62	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	01:11:00	\N	1	01:18:00	\N	0.8	\N	\N	Lenoxville Point	NC
104589	Channel Marker Lt. 59, North Carolina	NOS	8656554	34.7033	-76.62	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	01:27:00	\N	0.83	01:25:00	\N	0.66	\N	\N	Channel Marker Lt. 59	NC
104590	Coral Bay, Atlantic Beach, North Carolina	NOS	8656566	34.7	-76.7683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	02:14:00	\N	0.83	01:47:00	\N	0.53	\N	\N	Coral Bay, Atlantic Beach	NC
104591	Beaufort Inlet Channel Range, North Carolina	NOS	8656569	34.6983	-76.665	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	00:11:00	\N	1.67	00:07:00	\N	1.07	\N	\N	Beaufort Inlet Channel Range	NC
104592	Fort Macon, USCG station, North Carolina	NOS	8656571	34.6983	-76.6817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	00:18:00	\N	1.25	00:17:00	\N	1.03	\N	\N	Fort Macon, USCG Station	NC
104593	Cape Lookout (ocean), North Carolina	NOS	8656937	34.6083	-76.5283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	-00:22:00	\N	1.25	-00:22:00	\N	1.15	\N	\N	Cape Lookout (ocean)	NC
104594	New River Inlet, North Carolina	NOS	8657167	34.5333	-77.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	00:17:00	\N	0.83	00:16:00	\N	0.98	\N	\N	New River Inlet	NC
104595	Ocean City Beach (fishing pier), North Carolina	NOS	8657419	34.4517	-77.495	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	-00:01:00	\N	1.33	00:03:00	\N	1.4	\N	\N	Ocean City Beach (fishing pier)	NC
104596	Orton Point, Cape Fear River, North Carolina	NOS	8658501	34.0567	-77.94	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103053	-00:58:00	\N	1	-00:36:00	\N	0.98	\N	\N	Orton Point	NC
104597	Wilmington Beach, North Carolina	NOS	8658559	34.0317	-77.8933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	00:10:00	\N	1.25	00:18:00	\N	1.4	\N	\N	Wilmington Beach	NC
104598	Reaves Point, Cape Fear River, North Carolina	NOS	8658622	34.0033	-77.955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103053	-01:18:00	\N	1.07	-00:54:00	\N	0.96	\N	\N	Reaves Point	NC
104599	Sunny Point Army Base, Wharf No. 1, Cape Fear River, North Carolina	NOS	8658654	33.99	-77.9567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103053	-01:45:00	\N	0.93	-01:03:00	\N	0.95	\N	\N	Sunny Point Army Base, Wharf no.1	NC
104600	Federal Point, Cape Fear River, North Carolina	NOS	8658715	33.9617	-77.94	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103053	-01:52:00	\N	0.93	-01:17:00	\N	0.94	\N	\N	Federal Point	NC
104601	Bald Head, Cape Fear River, North Carolina	NOS	8658901	33.88	-78.0017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103053	-02:43:00	\N	1.13	-02:06:00	\N	1.05	\N	\N	Bald Head	NC
104602	Fort Caswell, Cape Fear River, North Carolina	NOS	8659086	33.8967	-78.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103053	-02:45:00	\N	1.25	-02:02:00	\N	1.03	\N	\N	Fort Caswell	NC
104603	Sunset Beach Bridge, North Carolina	NOS	8659899	33.88166666666701	-78.51	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103064	00:56:00	\N	0.84	00:34:00	\N	0.94	\N	\N	Sunset Beach Bridge	NC
104604	Little River Neck, north end, South Carolina	NOS	8660098	33.87	-78.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103064	00:46:00	\N	0.84	00:32:00	\N	0.92	\N	\N	Little River Neck, north end	SC
104605	Little River (town), South Carolina	NOS	8660121	33.87	-78.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:39:00	\N	0.79	00:13:00	\N	0.84	\N	\N	Little River (town)	SC
104606	Dunn Sound, north end, South Carolina	NOS	8660147	33.86	-78.58	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103064	00:40:00	\N	0.84	00:25:00	\N	0.93	\N	\N	Dunn Sound, north end	SC
104607	Dunn Sound, Little River Inlet, South Carolina	NOS	8660148	33.8583	-78.57	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103064	00:41:00	\N	0.8	00:15:00	\N	0.91	\N	\N	Dunn Sound, Little River Inlet	SC
104608	Nixon Crossroads, South Carolina	NOS	8660166	33.855	-78.6483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:51:00	\N	0.68	00:27:00	\N	0.78	\N	\N	Nixon Crossroads	SC
104609	Dunn Sound, west end, South Carolina	NOS	8660195	33.8517	-78.5883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103064	00:36:00	\N	1	00:29:00	\N	0.96	\N	\N	Dunn Sound, west end	SC
104610	Cherry Grove (inside), South Carolina	NOS	8660265	33.835	-78.6333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103064	00:44:00	\N	0.74	00:40:00	\N	0.92	\N	\N	Cherry Grove (inside)	SC
104611	Hog Inlet Pier, South Carolina	NOS	8660266	33.8367	-78.6067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103064	-00:07:00	\N	0.9	-00:06:00	\N	0.99	\N	\N	Hog Inlet Pier	SC
104612	Conway, RR. bridge, Waccamaw River, South Carolina	NOS	8660275	33.835	-79.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	07:28:00	\N	0.74	07:19:00	\N	0.25	\N	\N	Conway, RR. bridge	SC
104613	Grahamville, Waccamaw River, South Carolina	NOS	8660315	33.83	-78.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	08:32:00	\N	0.58	08:17:00	\N	0.2	\N	\N	Grahamville	SC
104614	Myrtle Beach Airport, South Carolina	NOS	8660401	33.82	-78.7183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	01:47:00	\N	0.84	01:09:00	\N	0.56	\N	\N	Myrtle Beach Airport	SC
104615	Pitch Landing, Waccamaw River, South Carolina	NOS	8660475	33.8	-79.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	07:30:00	\N	0.74	07:25:00	\N	0.2	\N	\N	Pitch Landing	SC
104616	North Myrtle Beach, South Carolina	NOS	8660642	33.766700744628906	-78.81500244140625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	03:12:00	\N	0.84	02:15:00	\N	0.36	\N	\N	North Myrtle Beach, ICWW	SC
104617	Keysfield, Waccamaw River, South Carolina	NOS	8660831	33.745	-79.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	06:20:00	\N	0.89	06:09:00	\N	0.28	\N	\N	Keysfield	SC
104618	Myrtle Beach, Combination Bridge, South Carolina	NOS	8660854	33.7133	-78.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	04:18:00	\N	0.89	02:56:00	\N	0.35	\N	\N	Myrtle Beach, Combination Bridge	SC
104619	Socastee Bridge, South Carolina	NOS	8660983	33.6867	-79.005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	04:41:00	\N	0.74	03:27:00	\N	0.41	\N	\N	Socastee Bridge	SC
104620	Enterprise Landing, Waccamaw River, South Carolina	NOS	8661067	33.6667	-79.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	05:35:00	\N	0.37	05:01:00	\N	0.38	\N	\N	Enterprise Landing	SC
104621	Yauhannah Bridge, Great Pee Dee River, South Carolina	NOS	8661093	33.66	-79.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	05:24:00	\N	0.68	04:33:00	\N	0.33	\N	\N	Yauhannah Bridge	SC
104622	Little Bull Creek entrance, Bull Creek, Waccamaw River, South Carolina	NOS	8661119	33.6017	-79.1183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	04:43:00	\N	0.84	03:59:00	\N	0.46	\N	\N	Little Bull Creek entrance, Bull Creek	SC
104623	Lower Topsaw Landing, Great Pee Dee River, South Carolina	NOS	8661299	33.6083	-79.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	05:20:00	\N	0.53	04:48:00	\N	0.2	\N	\N	Lower Topsaw Landing	SC
104624	Bull Creek entrance, Waccamaw River, South Carolina	NOS	8661347	33.5967	-79.0983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	04:22:00	\N	0.79	03:36:00	\N	0.48	\N	\N	Bull Creek entrance	SC
104625	Rhems, Black Mingo Creek, Black River, Great Pee Dee River, South Carolina	NOS	8661367	33.6033	-79.4267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	06:13:00	\N	1.05	06:00:00	\N	0.36	\N	\N	Rhems, Black Mingo Creek, Black River	SC
104626	Captain Alex's Marina, Parsonage Creek, Murrells Inlet, South Carolina	NOS	8661529	33.5517	-79.0367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103064	01:28:00	\N	0.68	00:57:00	\N	0.85	\N	\N	Captain Alex's Marina, Parsonage Creek	SC
104627	Holly Grove Plantation, Great Pee Dee River, South Carolina	NOS	8661558	33.5517	-79.1767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	04:12:00	\N	0.68	03:20:00	\N	0.5	\N	\N	Holly Grove Plantation	SC
104628	Smith's Dock, Murrells Inlet, South Carolina	NOS	8661559	33.545	-79.045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103064	01:36:00	\N	0.95	01:01:00	\N	0.86	\N	\N	Smith's Dock	SC
104629	Divine's Dock, Murrells Inlet, South Carolina	NOS	8661582	33.5417	-79.0283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103064	01:18:00	\N	0.84	00:40:00	\N	0.84	\N	\N	Divine's Dock	SC
104630	Winea Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8661593	33.535	-79.3883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	04:39:00	\N	0.84	04:23:00	\N	0.47	\N	\N	Winea Plantation, Black River	SC
104631	Allston Creek, Murrells Inlet, South Carolina	NOS	8661608	33.5317	-79.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103064	01:32:00	\N	0.95	00:52:00	\N	0.84	\N	\N	Allston Creek	SC
104632	Oaks Creek, 0.5 mi above entrance, Murrells Inlet, South Carolina	NOS	8661609	33.53	-79.0433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103064	01:03:00	\N	0.95	00:38:00	\N	0.85	\N	\N	Oaks Creek, 0.5 mi. above entrance	SC
104633	Black River (south of Dunbar), Great Pee Dee River, South Carolina	NOS	8661686	33.5117	-79.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	04:09:00	\N	0.89	03:29:00	\N	0.47	\N	\N	Black River (south of Dunbar)	SC
104634	Mt. Pleasant Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8661734	33.495	-79.4617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	06:04:00	\N	1.05	05:38:00	\N	0.37	\N	\N	Mt. Pleasant Plantation, Black River	SC
104635	Arundel Plantation, Great Pee Dee River, South Carolina	NOS	8661741	33.4833	-79.1783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	03:39:00	\N	0.79	02:38:00	\N	0.53	\N	\N	Arundel Plantation	SC
104636	South of Sam Worth Game Management Area, Great Pee Dee River, South Carolina	NOS	8661866	33.4683	-79.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	03:06:00	\N	0.68	02:21:00	\N	0.69	\N	\N	South of Sam Worth Game Management Area	SC
104637	Litchfield Beach bridge, South Carolina	NOS	8661867	33.4717	-79.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103064	03:02:00	\N	0.75	01:10:00	\N	0.58	\N	\N	Litchfield Beach bridge	SC
104638	Carr Creek, 1 mi above entrance, Great Pee Dee River, South Carolina	NOS	8661873	33.465	-79.1867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	03:00:00	\N	0.84	02:13:00	\N	0.69	\N	\N	Carr Creek, 1 mile above entrance	SC
104639	Weymouth Plantation, Great Pee Dee River, South Carolina	NOS	8661913	33.455	-79.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	03:02:00	\N	0.89	02:16:00	\N	0.68	\N	\N	Weymouth Plantation	SC
104640	Midway Inlet North, Pawleys Island, South Carolina	NOS	8661947	33.4483	-79.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103064	00:42:00	\N	1	00:16:00	\N	0.87	\N	\N	Midway Inlet North, Pawleys Island	SC
104641	Hagley Landing, Waccamaw River, South Carolina	NOS	8661991	33.435	-79.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	02:53:00	\N	0.79	01:58:00	\N	0.67	\N	\N	Hagley Landing	SC
104642	Cumberland, Sampit River, South Carolina	NOS	8662216	33.37	-79.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	02:29:00	\N	0.74	02:42:00	\N	0.77	\N	\N	Cumberland	SC
104643	Jacobs Wharf, Sampit River, South Carolina	NOS	8662237	33.3633	-79.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	02:22:00	\N	0.74	02:15:00	\N	0.73	\N	\N	Jacobs Wharf	SC
104644	Jamestown Bridge, Santee River, South Carolina	NOS	8662405	33.305	-79.6783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	06:30:00	\N	0.37	04:15:00	\N	0.22	\N	\N	Jamestown Bridge, Santee River	SC
104645	South Island Ferry, ICWW, South Carolina	NOS	8662549	33.2517	-79.2683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	01:25:00	\N	0.74	00:54:00	\N	0.71	\N	\N	South Island Ferry, Intracoastal Waterway	SC
104646	Pleasant Hill Landing, Santee River, South Carolina	NOS	8662670	33.245	-79.5217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	03:47:00	\N	0.74	02:28:00	\N	0.45	\N	\N	Pleasant Hill Landing, Santee River	SC
104647	South Island Plantation (USCG station), Winyah Bay, South Carolina (sub)	NOS	8662746	33.235	-79.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:36:00	\N	0.84	00:35:00	\N	0.74	\N	\N	South Island Plantation (C.G. Station)	SC
104648	Georgetown Lighthouse, South Carolina	NOS	8662747	33.2233	-79.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:25:00	\N	1.05	00:26:00	\N	0.75	\N	\N	Georgetown Lighthouse	SC
104649	North Santee Bridge, South Carolina	NOS	8662793	33.21	-79.385	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	01:54:00	\N	0.74	01:09:00	\N	0.72	\N	\N	North Santee Bridge	SC
104650	Minim Creek ent., ICWW, North Santee Bay, South Carolina	NOS	8662796	33.195	-79.275	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	01:00:00	\N	0.95	00:16:00	\N	0.77	\N	\N	Minim Creek ent., ICWW, North Santee Bay	SC
104651	US Highway 17 bridge, South Santee River, South Carolina	NOS	8662799	33.185	-79.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	01:43:00	\N	0.95	00:43:00	\N	0.78	\N	\N	U.S. Highway 17 bridge, South Santee River	SC
104652	Cape Romain, South Carolina	NOS	8663101	33.025	-79.3483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:17:00	\N	0.89	-00:22:00	\N	0.89	\N	\N	Cape Romain	SC
104653	Cedar Island, North Santee Bay, South Carolina	NOS	8663261	33.14	-79.245	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:17:00	\N	0.95	-00:03:00	\N	0.8	\N	\N	Cedar Island, North Santee Bay	SC
104654	Cedar Island Point, South Santee River, South Carolina	NOS	8663381	33.12	-79.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:08:00	\N	0.79	-00:16:00	\N	0.78	\N	\N	Cedar Island Point, South Santee River	SC
104655	Casino Creek, ICWW, South Carolina	NOS	8663461	33.1083	-79.3933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:53:00	\N	0.79	00:40:00	\N	0.87	\N	\N	Casino Creek, ICWW	SC
104656	Quinby Creek bridge, East Branch, Cooper River, South Carolina	NOS	8663535	33.095	-79.8083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	04:12:00	\N	1.42	04:37:00	\N	0.56	\N	\N	Quinby Creek bridge, East Branch	SC
104657	Pimlico, West Branch, Cooper River, South Carolina	NOS	8663539	33.095	-79.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	03:53:00	\N	0.89	03:19:00	\N	0.34	\N	\N	Pimlico, West Branch	SC
104658	McClellanville, Jeremy Creek, Bulls Bay, South Carolina	NOS	8663618	33.0783	-79.46	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:24:00	\N	0.89	00:31:00	\N	0.93	\N	\N	McClellanville, Jeremy Creek	SC
104659	Old Rice Mill, West Branch, Cooper River, South Carolina	NOS	8663631	33.0783	-79.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	02:51:00	\N	1.63	02:56:00	\N	0.53	\N	\N	Old Rice Mill, West Branch	SC
104660	Richmond Plantation, East Branch, Cooper River, South Carolina	NOS	8663665	33.0767	-79.855	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	03:43:00	\N	1.37	03:43:00	\N	0.54	\N	\N	Richmond Plantation, East Branch	SC
104661	Bonneau Ferry, East Branch, Cooper River, South Carolina	NOS	8663731	33.0717	-79.8833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	02:49:00	\N	1.79	03:14:00	\N	0.63	\N	\N	Bonneau Ferry, East Branch	SC
104662	Dupont, Dean Hall, Cooper River, South Carolina	NOS	8663757	33.0583	-79.9367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	02:07:00	\N	1.58	02:21:00	\N	0.68	\N	\N	Dupont, Dean Hall	SC
104663	Blessing Plantation, East Branch, Cooper River, South Carolina	NOS	8663781	33.055	-79.88	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	03:20:00	\N	1.32	03:24:00	\N	0.56	\N	\N	Blessing Plantation, East Branch	SC
104664	Harbor River entrance, Bulls Bay, South Carolina	NOS	8663899	33.0333	-79.535	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:36:00	\N	0.95	00:03:00	\N	0.93	\N	\N	Harbor River entrance	SC
104665	Five Fathom Creek entrance, Bulls Bay, South Carolina	NOS	8664099	33	-79.4967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:07:00	\N	0.95	-00:06:00	\N	0.93	\N	\N	Five Fathom Creek entrance	SC
104666	Back River Reservoir, West Branch, Cooper River, South Carolina	NOS	8664131	32.995	-79.9367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	05:57:00	\N	0.79	05:44:00	\N	0.17	\N	\N	Back River Reservoir, West Branch	SC
104667	Moores Landing, ICWW, Sewee Bay, South Carolina	NOS	8664442	32.9367	-79.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:08:00	\N	1	00:11:00	\N	0.96	\N	\N	Moores Landing, ICWW, Sewee Bay	SC
104668	Snow Point, 0.4 mi north of, Cooper River, South Carolina	NOS	8664515	32.9483	-79.9317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:45:00	\N	1.05	00:59:00	\N	1.02	\N	\N	Snow Point, 0.4 mi. North of	SC
104669	Bacon Bridge, Ashley River, South Carolina	NOS	8664531	32.9583	-80.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	03:41:00	\N	0.16	02:45:00	\N	0.39	\N	\N	Bacon Bridge	SC
104670	Greggs Landing, Matceba Gardens, Ashley River, South Carolina	NOS	8664532	32.9317	-80.1567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	01:42:00	\N	1.16	02:06:00	\N	1.15	\N	\N	Greggs Landing, Mateeba Gardens	SC
104671	Yeamans Hall, Goose Creek, Cooper River, South Carolina	NOS	8664541	32.925	-79.9867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	01:31:00	\N	1.37	02:06:00	\N	1	\N	\N	Yeamans Hall, Goose Creek	SC
104672	Woodville, Wando River, South Carolina	NOS	8664582	32.92	-79.7333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	01:22:00	\N	1.19	02:07:00	\N	1.19	\N	\N	Woodville	SC
104673	Hanahan, Turkey Creek, Goose Creek, Cooper River, South Carolina	NOS	8664589	32.9183	-80.0117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	02:13:00	\N	0.79	02:51:00	\N	0.9	\N	\N	Hanahan, Turkey Creek, Goose Creek	SC
104674	Big Paradise Island, Wando River, South Carolina	NOS	8664611	32.915	-79.7467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:52:00	\N	1.11	01:24:00	\N	1.24	\N	\N	Big Paradise Island	SC
104675	Wharf Creek entrance, Bulls Bay, South Carolina	NOS	8664621	32.9133	-79.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:08:00	\N	0.95	00:12:00	\N	0.97	\N	\N	Wharf Creek entrance	SC
104676	Clouter Creek, north entrance, Cooper River, South Carolina	NOS	8664688	32.9067	-79.935	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:33:00	\N	1	00:45:00	\N	1.04	\N	\N	Clouter Creek, north entrance	SC
104677	Nowell Creek, Wando River, South Carolina	NOS	8664701	32.9	-79.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:23:00	\N	1.05	00:47:00	\N	1.13	\N	\N	Nowell Creek	SC
104678	Parker Island, Horlbeck Creek, Wando River, South Carolina	NOS	8664782	32.885	-79.845	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:27:00	\N	1.11	00:43:00	\N	1.09	\N	\N	Parker Island, Horlbeck Creek	SC
104679	Price Creek, North Capers Island, South Carolina	NOS	8664801	32.8817	-79.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:21:00	\N	0.89	-00:01:00	\N	0.92	\N	\N	Price Creek, North Capers Island	SC
104680	Magnolia Gardens, Ashley River, South Carolina	NOS	8664841	32.8767	-80.0833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:54:00	\N	1.05	01:02:00	\N	1.1	\N	\N	Magnolia Gardens	SC
104681	Old Capers Landing, Santee Pass, Capers Island, South Carolina	NOS	8664878	32.87	-79.6867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:09:00	\N	0.84	00:21:00	\N	0.94	\N	\N	Old Capers Landing, Santee Pass, Capers Island	SC
104682	Clouter Creek, south entrance, Cooper River, South Carolina	NOS	8664945	32.86	-79.9383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:19:00	\N	1	00:25:00	\N	1.02	\N	\N	Clouter Creek, south entrance	SC
104683	North Dewees Island, Capers Inlet, South Carolina	NOS	8664992	32.85	-79.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:11:00	\N	0.95	-00:02:00	\N	0.91	\N	\N	North Dewees Island, Capers Inlet	SC
104684	Drayton, Bee's Ferry, Ashley River, South Carolina	NOS	8665002	32.8483	-80.0517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:39:00	\N	1.05	00:41:00	\N	1.09	\N	\N	Drayton, Bee's Ferry	SC
104685	Cosgrove Bridge, Ashley River, South Carolina	NOS	8665101	32.835	-79.9867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:17:00	\N	1.05	00:25:00	\N	1.07	\N	\N	Cosgrove Bridge	SC
104686	South Dewees Island, Dewees Inlet, South Carolina	NOS	8665111	32.8333	-79.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:17:00	\N	0.89	-00:01:00	\N	0.94	\N	\N	South Dewees Island, Dewees Inlet	SC
104687	Duck Island, Ashley River, South Carolina	NOS	8665145	32.83	-79.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:17:00	\N	1.06	00:23:00	\N	1.06	\N	\N	Duck Island	SC
104688	Hamlin Sound, South Carolina	NOS	8665167	32.8267	-79.7867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:13:00	\N	1	00:13:00	\N	0.99	\N	\N	Hamlin Sound	SC
104689	Hobcaw Point, Wando River, South Carolina	NOS	8665192	32.8217	-79.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:13:00	\N	0.95	00:19:00	\N	1.03	\N	\N	Hobcaw Point	SC
104690	Canaday Landing, south of, Edisto River, South Edisto River, South Carolina	NOS	8665257	32.8133	-80.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	05:34:00	\N	0.32	04:20:00	\N	0.13	\N	\N	Canaday Landing, south of, Edisto River	SC
104691	Hamlin Creek, Isle of Palms, South Carolina	NOS	8665387	32.7867	-79.7917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:12:00	\N	1	00:06:00	\N	0.97	\N	\N	Hamlin Creek, Isle of Palms	SC
104692	Folly Creek, Hwy. 171 bridge, South Carolina	NOS	8665424	32.675	-79.9517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:06:00	\N	1	00:25:00	\N	1.04	\N	\N	Folly Creek, Hwy. 171 bridge	SC
104693	Shem Creek, South Carolina	NOS	8665426	32.7933	-79.8817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:03:00	\N	1	-00:02:00	\N	0.99	\N	\N	Shem Creek	SC
104694	Limehouse Bridge, Stono River, South Carolina	NOS	8665475	32.7867	-80.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	01:34:00	\N	1.08	01:43:00	\N	1.08	\N	\N	Limehouse Bridge	SC
104695	Isle of Palms Pier, South Carolina	NOS	8665494	32.7833	-79.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:28:00	\N	0.89	-00:25:00	\N	0.95	\N	\N	Isle of Palms Pier	SC
104696	South Ashley Bridge, Ashley River, South Carolina	NOS	8665495	32.7833	-79.9567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:07:00	\N	1.05	00:04:00	\N	1.01	\N	\N	South Ashley Bridge	SC
104697	Breach Inlet, Isle of Palms, South Carolina	NOS	8665552	32.7767	-79.8117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:14:00	\N	1.05	-00:05:00	\N	0.95	\N	\N	Breach Inlet, Isle of Palms	SC
104698	Ben Sawyer Bridge, ICWW, South Carolina	NOS	8665567	32.7733	-79.8417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:12:00	\N	1	00:06:00	\N	0.97	\N	\N	Ben Sawyer Bridge, ICWW	SC
104699	Sandblasters, Pennys Creek, Stono River, South Carolina	NOS	8665589	32.77	-80.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	01:18:00	\N	1.02	01:30:00	\N	1.02	\N	\N	Sandblasters, Pennys Creek	SC
104700	Pennys Creek, west entrance, Stono River, South Carolina	NOS	8665599	32.7683	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	01:20:00	\N	1.32	01:23:00	\N	1.03	\N	\N	Pennys Creek, west entrance	SC
104701	Wappoo Creek, highway bridge, Ashley River, South Carolina	NOS	8665613	32.7667	-79.9733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:22:00	\N	0.99	00:22:00	\N	0.99	\N	\N	Wappoo Creek, highway bridge	SC
104702	The Cove, Fort Moultrie, South Carolina	NOS	8665637	32.7633	-79.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:10:00	\N	0.95	-00:01:00	\N	0.97	\N	\N	The Cove, Fort Moultrie	SC
104703	Elliott Cut entrance, Stono River, South Carolina	NOS	8665641	32.7633	-80.0017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:52:00	\N	1.16	00:48:00	\N	0.99	\N	\N	Elliott Cut entrance	SC
104704	Fort Johnson, South Carolina	NOS	8665726	32.7517	-79.8983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:02:00	\N	1	-00:05:00	\N	0.97	\N	\N	Fort Johnson	SC
104705	Fort Sumter, South Carolina	NOS	8665728	32.7533	-79.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:01:00	\N	0.95	00:02:00	\N	0.97	\N	\N	Fort Sumter	SC
104706	Jacksonboro Camp, South Edisto River, South Carolina	NOS	8665737	32.7533	-80.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	03:34:00	\N	0.86	02:46:00	\N	0.59	\N	\N	Jacksonboro Camp	SC
104707	James Island Creek, 1 mi above ent., Ashley River, South Carolina	NOS	8665775	32.745	-79.9483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:07:00	\N	1.05	00:17:00	\N	1.02	\N	\N	James Island Creek, 1 mi. above ent.	SC
104708	Ashepoo, Ashepoo River, South Carolina	NOS	8665814	32.7433	-80.5567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	04:00:00	\N	1.05	04:18:00	\N	0.34	\N	\N	Ashepoo	SC
104709	Penny Creek, south of, Edisto River, South Edisto River, South Carolina	NOS	8666017	32.715	-80.4367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	02:43:00	\N	1.18	02:10:00	\N	0.73	\N	\N	Penny Creek, south of, Edisto River	SC
104710	Church Creek bridge, Wadmalaw River, South Carolina	NOS	8666029	32.715	-80.0917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:58:00	\N	1	01:58:00	\N	1.3	\N	\N	Church Creek bridge	SC
104711	Johns Island, Church Creek, Wadmalaw River, South Carolina	NOS	8666101	32.7067	-80.1567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	01:00:00	\N	1.16	01:43:00	\N	1.3	\N	\N	Johns Island, Church Creek	SC
104712	Lower Toogoodoo Creek, 2 mi above entrance, North Edisto River, South Carolina	NOS	8666131	32.7033	-80.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:47:00	\N	1.26	01:26:00	\N	1.29	\N	\N	Lower Toogoodoo Creek, 2 mi. above entrance	SC
104713	Cuckolds Creek, Combahee River, South Carolina	NOS	8666166	32.7133	-80.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	04:12:00	\N	1.73	04:45:00	\N	0.51	\N	\N	Cuckolds Creek	SC
104714	Hope Creek, Edisto River, South Edisto River, South Carolina	NOS	8666167	32.7	-80.4267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	02:13:00	\N	1.05	01:46:00	\N	0.82	\N	\N	Hope Creek, Edisto River	SC
104715	Yonges Island, Wadmalaw River, South Carolina	NOS	8666217	32.695	-80.2233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:45:00	\N	1.16	01:22:00	\N	1.24	\N	\N	Yonges Island	SC
104716	Oak Branch, Bohicket Creek, North Edisto River, South Carolina	NOS	8666282	32.6833	-80.0967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:57:00	\N	1.16	01:39:00	\N	1.26	\N	\N	Oak Branch, Bohicket Creek	SC
104717	Abbapoola Creek entrance, Stono River, South Carolina	NOS	8666283	32.6767	-80.0067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:02:00	\N	0.95	00:17:00	\N	1.01	\N	\N	Abbapoola Creek entrance	SC
104718	Bluff Plantation, Combahee River, South Carolina	NOS	8666359	32.6833	-80.7383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	03:51:00	\N	1.59	04:17:00	\N	0.5	\N	\N	Bluff Plantation	SC
104719	Willtown Bluff, Edisto River, South Edisto River, South Carolina	NOS	8666367	32.6817	-80.4167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	02:03:00	\N	1	01:34:00	\N	0.83	\N	\N	Willtown Bluff, Edisto River	SC
104720	Toogoodoo Creek, 2 mi above entrance, North Edisto River, South Carolina	NOS	8666433	32.6683	-80.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:38:00	\N	1.05	01:06:00	\N	1.21	\N	\N	Toogoodoo Creek, 2 mi. above entrance	SC
104721	Folly River, north, Folly Island, South Carolina	NOS	8666467	32.67	-79.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:05:00	\N	0.95	00:24:00	\N	1.03	\N	\N	Folly River, north, Folly Island	SC
104722	Park Island, Tom Point Creek, North Edisto River, South Carolina	NOS	8666552	32.665	-80.3167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:34:00	\N	1.21	01:19:00	\N	1.21	\N	\N	Park Island, Tom Point Creek	SC
104723	Dawho River, South Edisto River, South Carolina	NOS	8666616	32.6567	-80.3917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:31:00	\N	0.95	01:07:00	\N	0.89	\N	\N	Dawho River	SC
104724	Folly River Bridge, Folly Island, South Carolina	NOS	8666652	32.6617	-79.945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:03:00	\N	0.95	00:21:00	\N	1.01	\N	\N	Folly River Bridge, Folly Island	SC
104725	US 17 Bridge, Combahee River, South Carolina	NOS	8666659	32.6517	-80.6833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	02:29:00	\N	1.14	03:00:00	\N	0.71	\N	\N	U.S. 17 Bridge	SC
104726	Bluff Point, Wadmalaw River, South Carolina	NOS	8666699	32.6467	-80.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:31:00	\N	1.11	00:58:00	\N	1.17	\N	\N	Bluff Point	SC
104727	Airy Hall Plantation, Ashepoo River, South Carolina	NOS	8666749	32.6317	-80.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:59:00	\N	1	01:57:00	\N	0.6	\N	\N	Airy Hall Plantation	SC
104728	Snake Island, Stono River, South Carolina	NOS	8666767	32.64	-80.015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:12:00	\N	1	00:01:00	\N	1.01	\N	\N	Snake Island	SC
104729	Leadenwah Creek, 3 mi above entrance, North Edisto River, South Carolina	NOS	8666775	32.6367	-80.2017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:23:00	\N	1.11	00:54:00	\N	1.15	\N	\N	Leadenwah Creek, 3 mi. above entrance	SC
104730	Dawho Bridge, Dawho River, North Edisto River, South Carolina	NOS	8666799	32.6367	-80.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:47:00	\N	1.11	00:56:00	\N	1.18	\N	\N	Dawho Bridge, Dawho River	SC
104731	Ho-Non-Wah Boy Scout Camp, Bohicket Creek, North Edisto River, South Carolina	NOS	8666918	32.625	-80.1667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:30:00	\N	1.11	00:49:00	\N	1.13	\N	\N	Ho-Non-Wah Boy Scout Camp, Bohicket Creek	SC
104732	Brickyard Ferry, swing bridge, Ashepoo River, South Carolina	NOS	8667017	32.6133	-80.4817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:34:00	\N	0.86	01:27:00	\N	0.71	\N	\N	Brickyard Ferry, swing bridge	SC
104733	Kiawah River Bridge, South Carolina	NOS	8667062	32.6033	-80.1317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:06:00	\N	0.89	00:14:00	\N	1.07	\N	\N	Kiawah River Bridge	SC
104734	Pine Landing, South Edisto River, South Carolina	NOS	8667067	32.6033	-80.3883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:45:00	\N	0.95	00:29:00	\N	0.92	\N	\N	Pine Landing	SC
104735	Wiggins, Chehaw River, Combahee River, South Carolina	NOS	8667074	32.6017	-80.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:20:00	\N	1.18	01:45:00	\N	0.88	\N	\N	Wiggins, Chehaw River	SC
104736	Steamboat Landing, Steamboat Creek, North Edisto River, South Carolina	NOS	8667075	32.6033	-80.2867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:25:00	\N	1.11	00:45:00	\N	1.15	\N	\N	Steamboat Landing, Steamboat Creek	SC
104737	Tulifiny River, I-95 bridge, Broad River, South Carolina	NOS	8667076	32.6017	-80.9033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	03:31:00	\N	0.73	03:24:00	\N	0.73	\N	\N	Tulifiny River, I-95 bridge	SC
104738	Rockville, Bohicket Creek, North Edisto River, South Carolina	NOS	8667089	32.5983	-80.195	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:07:00	\N	1.11	00:19:00	\N	1.09	\N	\N	Rockville, Bohicket Creek	SC
104739	Windsor Plantation, Russel Creek, North Edisto River, South Carolina	NOS	8667101	32.5983	-80.345	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:35:00	\N	1.11	01:16:00	\N	1.21	\N	\N	Windsor Plantation, Russel Creek	SC
104740	North Dawson Landing, Coosawhatchie River, Broad River, South Carolina	NOS	8667146	32.5617	-80.91	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	02:10:00	\N	1.14	02:34:00	\N	1.12	\N	\N	North Dawson Landing, Coosawhatchie River	SC
104741	Sheldon, Huspa Creek, Whale Branch, Coosaw River, South Carolina	NOS	8667172	32.5833	-80.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:52:00	\N	0.77	02:11:00	\N	1.16	\N	\N	Sheldon, Huspa Creek, Whale Branch	SC
104742	Point of Pines, North Edisto River, South Carolina	NOS	8667178	32.585	-80.2283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:11:00	\N	1.05	00:15:00	\N	1.08	\N	\N	Point of Pines	SC
104743	Briars Creek ent., Wimbee Creek, Bull River, Coosaw River, South Carolina	NOS	8667199	32.5783	-80.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:24:00	\N	0.95	02:06:00	\N	0.93	\N	\N	Briars Creek ent., Wimbee Creek, Bull River	SC
104744	Bluff Islands, Ashepoo River, South Carolina	NOS	8667201	32.5783	-80.4933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:04:00	\N	0.91	00:46:00	\N	0.84	\N	\N	Bluff Islands	SC
104745	Musselboro Island, Mosquito Creek, Ashepoo River, South Carolina	NOS	8667209	32.5783	-80.4483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:57:00	\N	0.91	01:21:00	\N	0.9	\N	\N	Musselboro Island, Mosquito Creek	SC
104746	Fields Point, Combahee River, South Carolina	NOS	8667259	32.5683	-80.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:52:00	\N	0.91	00:42:00	\N	0.91	\N	\N	Fields Point	SC
104747	Bowles Island, New Chehaw River, Combahee River, South Carolina	NOS	8667272	32.565	-80.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:42:00	\N	1	01:02:00	\N	0.96	\N	\N	Bowles Island, New Chehaw River	SC
104748	Ocella Creek, 2 mi above entrance, North Edisto River, South Carolina	NOS	8667281	32.5617	-80.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:09:00	\N	1.08	00:32:00	\N	1.08	\N	\N	Ocella Creek, 2 mi. above entrance	SC
104749	Fenwick Island, South Edisto River, South Carolina	NOS	8667309	32.56	-80.4183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:25:00	\N	1.09	00:15:00	\N	0.9	\N	\N	Fenwick Island	SC
104750	Hutchinson Island, Ashepoo River, South Carolina	NOS	8667351	32.5517	-80.4817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:44:00	\N	0.91	00:31:00	\N	0.87	\N	\N	Hutchinson Island	SC
104751	Lobeco, Whale Branch, Coosaw River, South Carolina	NOS	8667411	32.5733	-80.745	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:28:00	\N	0.95	01:40:00	\N	1.11	\N	\N	Lobeco, Whale Branch	SC
104752	Peters Point, St. Pierre Creek, South Edisto River, South Carolina	NOS	8667425	32.54	-80.34	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:09:00	\N	0.95	00:22:00	\N	0.88	\N	\N	Peters Point, St. Pierre Creek	SC
104753	Ashepoo-Coosaw Cutoff, ICWW, Ashepoo River, South Carolina	NOS	8667482	32.525	-80.4517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:23:00	\N	0.91	00:15:00	\N	0.9	\N	\N	Ashepoo-Coosaw Cutoff, ICWW	SC
104754	Whale Branch entrance, Coosaw River, South Carolina	NOS	8667491	32.525	-80.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:20:00	\N	0.95	01:27:00	\N	1.06	\N	\N	Whale Branch entrance	SC
104755	Summerhouse Point, Bull River, Coosaw River, South Carolina	NOS	8667493	32.5267	-80.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:37:00	\N	0.95	00:55:00	\N	0.96	\N	\N	Summerhouse Point, Bull River	SC
104756	RR. Bridge, Hall Island, Broad River, South Carolina	NOS	8667508	32.5217	-80.8383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:24:00	\N	1.05	01:39:00	\N	1.17	\N	\N	RR. Bridge, Hall Island	SC
104757	Seabrook, Ashepoo River, South Carolina	NOS	8667524	32.5233	-80.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:18:00	\N	0.91	00:11:00	\N	0.9	\N	\N	Seabrook	SC
104758	Pilot Island, West Branch Boyds Creek, Broad River, South Carolina	NOS	8667591	32.505	-80.8633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:24:00	\N	0.91	01:50:00	\N	1.15	\N	\N	Pilot Island, West Branch Boyds Creek	SC
104759	Brickyard Point, Brickyard Creek, Coosaw River, South Carolina	NOS	8667624	32.4933	-80.685	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:19:00	\N	0.95	01:27:00	\N	1.08	\N	\N	Brickyard Point, Brickyard Creek	SC
104760	Edisto Beach, Edisto Island, South Carolina	NOS	8667630	32.5017	-80.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	-00:29:00	\N	0.95	-00:21:00	\N	0.84	\N	\N	Edisto Beach, Edisto Island	SC
104761	Edisto Marina, Big Bay Creek entrance, South Edisto River, South Carolina	NOS	8667676	32.4933	-80.34	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	-00:13:00	\N	0.91	-00:06:00	\N	0.86	\N	\N	Edisto Marina, Big Bay Creek entrance	SC
104762	Carters Dock, Big Bay Creek, South Edisto River, South Carolina	NOS	8667679	32.4933	-80.3267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	-00:07:00	\N	0.91	00:08:00	\N	0.87	\N	\N	Carters Dock, Big Bay Creek	SC
104763	Sams Point, Lucy Point Creek, Coosaw River, South Carolina	NOS	8667733	32.4833	-80.6	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:45:00	\N	0.91	00:55:00	\N	0.97	\N	\N	Sams Point, Lucy Point Creek	SC
104764	Otter Island, St. Helena Sound, South Carolina	NOS	8667783	32.4767	-80.42	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:07:00	\N	0.95	00:04:00	\N	0.87	\N	\N	Otter Island	SC
104765	Marine Corps Air Station, Brickyard Creek, Beaufort River, South Carolina	NOS	8667864	32.465	-80.6917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:11:00	\N	0.95	01:27:00	\N	1.1	\N	\N	Marine Corps Air Station, Brickyard Creek	SC
104766	Lucy Point Creek entrance, Morgan River, South Carolina	NOS	8667901	32.4517	-80.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:33:00	\N	0.88	00:53:00	\N	0.9	\N	\N	Lucy Point Creek entrance	SC
104767	Albergottie Creek, Rt. 21 bridge, Beaufort River, South Carolina	NOS	8667909	32.45	-80.7317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	02:02:00	\N	0.45	01:48:00	\N	0.98	\N	\N	Albergottie Creek, Rt. 21 bridge	SC
104856	Dover Bluff, Dover Creek, Georgia	NOS	8678111	31.0167	-81.5283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:31:00	\N	1.15	00:06:00	\N	1.15	\N	\N	Dover Bluff, Dover Creek	GA
104768	Village Creek entrance, Morgan River, South Carolina	NOS	8667927	32.445	-80.5033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:07:00	\N	1	00:17:00	\N	0.93	\N	\N	Village Creek Entrance	SC
104769	Edding Point, Edding Creek, Morgan River, South Carolina	NOS	8667972	32.4467	-80.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:14:00	\N	0.95	00:31:00	\N	0.93	\N	\N	Edding Point, Edding Creek	SC
104770	Jenkins Creek, 1 mi above entrance, Morgan River, South Carolina	NOS	8667982	32.44	-80.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:17:00	\N	0.95	00:41:00	\N	0.98	\N	\N	Jenkins Creek, 1 mi. above entrance	SC
104771	Village Creek Cemetery, Morgan River, South Carolina	NOS	8668077	32.4167	-80.52	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:15:00	\N	0.95	00:36:00	\N	0.94	\N	\N	Village Creek Cemetery	SC
104772	Jenkins Creek, Polawana Island, Morgan River, South Carolina	NOS	8668091	32.42	-80.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:27:00	\N	1.05	00:55:00	\N	1.01	\N	\N	Jenkins Creek, Polawana Island	SC
104773	Battery Creek, 4 mi above entrance, Beaufort River, South Carolina	NOS	8668092	32.4133	-80.7	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:37:00	\N	0.91	01:14:00	\N	1.1	\N	\N	Battery Creek, 4 mi. above entrance	SC
104774	Broughton Point, Hazzard Creek, Broad River, South Carolina	NOS	8668109	32.41	-80.885	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:30:00	\N	0.82	01:34:00	\N	1.1	\N	\N	Broughton Point, Hazzard Creek	SC
104775	Harbor River Bridge, St. Helena Sound, South Carolina	NOS	8668146	32.4033	-80.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	-00:06:00	\N	0.95	00:03:00	\N	0.88	\N	\N	Harbor River Bridge	SC
104776	Distant Island Creek, upper end, Cowen Creek, Beaufort River, South Carolina	NOS	8668155	32.4017	-80.6533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:08:00	\N	0.36	01:00:00	\N	0.98	\N	\N	Distant Island Creek, upper end, Cowen Creek	SC
104777	Cowen Creek, Rt. 21 bridge, Beaufort River, South Carolina	NOS	8668173	32.3983	-80.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:58:00	\N	0.55	00:55:00	\N	1	\N	\N	Cowen Creek, Rt. 21 bridge	SC
104778	Hwy. 170 bridge, Broad River, South Carolina	NOS	8668223	32.3867	-80.7767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:45:00	\N	0.91	00:51:00	\N	1.06	\N	\N	Hwy. 170 bridge	SC
104779	Johnson Creek Bridge, Hunting Island, St. Helena Sound, South Carolina	NOS	8668227	32.3917	-80.4383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:03:00	\N	0.86	00:03:00	\N	0.85	\N	\N	Johnson Creek Bridge, Hunting Island	SC
104780	Capers Creek, Cowen Creek, St. Helena Island, Beaufort River, South Carolina	NOS	8668255	32.3717	-80.605	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:34:00	\N	0.95	00:58:00	\N	1.08	\N	\N	Capers Creek, Cowen Creek, St. Helena Island	SC
104781	Distant Island, Cowen Creek, Beaufort River, South Carolina	NOS	8668282	32.3783	-80.6333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:27:00	\N	1.05	00:43:00	\N	1.06	\N	\N	Distant Island, Cowen Creek	SC
104782	Chechessee Bluff, Chechessee River, South Carolina	NOS	8668301	32.3733	-80.8367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:48:00	\N	1	01:06:00	\N	1.1	\N	\N	Chechessee Bluff, Chechessee River	SC
104783	Parris Island, Marine Corps Recruit Depot, Beaufort River, South Carolina	NOS	8668445	32.35	-80.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:26:00	\N	0.91	00:37:00	\N	1.02	\N	\N	Parris Island, Marine Corps Recruit Depot	SC
104784	Baileys Landing, Okatee River, Colleton River, South Carolina	NOS	8668482	32.3467	-80.89	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:57:00	\N	1.05	01:25:00	\N	1.17	\N	\N	Baileys Landing, Okatee River, Colleton River	SC
104785	Callawassie Island Bridge, Colleton River, South Carolina	NOS	8668511	32.3417	-80.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:49:00	\N	1.14	01:12:00	\N	1.13	\N	\N	Callawassie Island Bridge, Colleton River	SC
104786	Club Bridge Creek ent., Trenchards Inlet, South Carolina	NOS	8668529	32.335	-80.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	-00:24:00	\N	1	00:15:00	\N	0.99	\N	\N	Club Bridge Creek ent., Trenchards Inlet	SC
104787	Station Creek, County Landing, South Carolina	NOS	8668601	32.325	-80.6017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	-00:16:00	\N	1	00:27:00	\N	0.99	\N	\N	Station Creek, County Landing	SC
104788	Colleton River entrance, South Carolina	NOS	8668619	32.3217	-80.7917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:37:00	\N	1.05	00:49:00	\N	1.05	\N	\N	Colleton River Entrance	SC
104789	Callawassie Creek, Colleton River, South Carolina	NOS	8668636	32.3167	-80.8417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:53:00	\N	1.14	01:15:00	\N	1.13	\N	\N	Callawassie Creek, Colleton River	SC
104790	Callawassie Island, south, Colleton River, South Carolina	NOS	8668655	32.3133	-80.86	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:40:00	\N	1.11	01:09:00	\N	1.19	\N	\N	Callawassie Island, south, Colleton River	SC
104791	Fort Fremont, Beaufort River, South Carolina	NOS	8668686	32.3067	-80.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:17:00	\N	0.64	00:19:00	\N	0.95	\N	\N	Fort Fremont	SC
104792	Purrysburg Landing, Savannah River, South Carolina	NOS	8668701	32.3033	-81.1217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	03:38:00	\N	0.41	02:14:00	\N	0.44	\N	\N	Purrysburg Landing, S.C.	SC
104793	Station Creek, west end, South Carolina	NOS	8668836	32.28	-80.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:13:00	\N	0.91	00:16:00	\N	0.96	\N	\N	Station Creek, west end	SC
104794	Capers Island, Trenchards Inlet, South Carolina	NOS	8668837	32.2733	-80.585	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	-00:18:00	\N	0.95	-00:01:00	\N	0.93	\N	\N	Capers Island, Trenchards Inlet	SC
104795	Pinckney Island, Mackay Creek, Chechessee River, South Carolina	NOS	8668944	32.26	-80.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:25:00	\N	0.91	00:36:00	\N	1.04	\N	\N	Pinckney Island, Mackay Creek, Chechessee River	SC
104796	Rt. 170 bridge, New River, South Carolina	NOS	8669072	32.2367	-81.0117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	03:53:00	\N	0.51	04:12:00	\N	0.51	\N	\N	Rt. 170 bridge	SC
104797	Bluffton, May River, South Carolina	NOS	8669103	32.23	-80.8617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:37:00	\N	1.05	01:00:00	\N	1.16	\N	\N	Bluffton	SC
104798	Skull Creek, south entrance, Hilton Head Island, South Carolina	NOS	8669133	32.2233	-80.7717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:23:00	\N	1.05	00:34:00	\N	1.05	\N	\N	Skull Creek, south entrance, Hilton Head Island	SC
104799	Port Royal Plantation, Hilton Head Island, South Carolina	NOS	8669167	32.22	-80.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	-00:11:00	\N	1	00:01:00	\N	0.88	\N	\N	Port Royal Plantation, Hilton Head Island	SC
104800	Bull Island North, May River, South Carolina	NOS	8669262	32.2	-80.815	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:25:00	\N	1.05	00:40:00	\N	1.09	\N	\N	Bull Island North	SC
104801	Cook Landing Cemetery, New River, South Carolina	NOS	8669277	32.195	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	03:00:00	\N	1.41	03:09:00	\N	0.69	\N	\N	Cook Landing Cemetery	SC
104802	Savage I., Savage Creek, Bull Creek, South Carolina	NOS	8669323	32.185	-80.86	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:19:00	\N	1	00:46:00	\N	1.1	\N	\N	Savage I., Savage Creek, Bull Creek	SC
104803	Broad Creek, Hilton Head Island, South Carolina	NOS	8669338	32.185	-80.7533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:17:00	\N	1.05	00:33:00	\N	1.08	\N	\N	Broad Creek, Hilton Head Island	SC
104804	Good Hope Landing, south of, New River, South Carolina	NOS	8669346	32.1767	-80.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	02:06:00	\N	1.55	02:19:00	\N	0.85	\N	\N	Good Hope Landing, south of	SC
104805	Moreland Cemetery, May River, South Carolina	NOS	8669369	32.175	-80.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:23:00	\N	0.77	00:49:00	\N	1.11	\N	\N	Moreland Cemetery	SC
104806	Bull Creek, Bull Island South, Cooper River, South Carolina	NOS	8669414	32.165	-80.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:12:00	\N	1.05	00:28:00	\N	1.05	\N	\N	Bull Creek, Bull Island South, Cooper River	SC
104807	Little Back River, Hwy. 17, Back River, Savannah River, Georgia	NOS	8669415	32.165	-81.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:41:00	\N	1.14	01:28:00	\N	1.1	\N	\N	Little Back River, Hwy. 17, Back River, S.C.	GA
104808	Calibogue Cay, Broad Creek, Hilton Head Island, South Carolina	NOS	8669464	32.1533	-80.795	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:09:00	\N	1	00:20:00	\N	1.04	\N	\N	Calibogue Cay, Broad Creek, Hilton Head Island	SC
104809	Haig Point, Daufuskie Island, Cooper River, South Carolina	NOS	8669493	32.1467	-80.8367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:10:00	\N	1	00:20:00	\N	1.02	\N	\N	Haig Point, Daufuskie Island, Cooper River	SC
104810	Doughboy Island, New River, South Carolina	NOS	8669531	32.1383	-80.9317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:06:00	\N	1.05	01:04:00	\N	1.01	\N	\N	Doughboy Island	SC
104811	Turnbridge Landing, Salt Water Creek, South Carolina	NOS	8669575	32.1283	-81.0117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:59:00	\N	1.09	01:41:00	\N	1.06	\N	\N	Turnbridge Landing, Salt Water Creek	SC
104812	Pine Island, Ramshorn Creek, Cooper River, South Carolina	NOS	8669601	32.1217	-80.8983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:28:00	\N	0.91	00:34:00	\N	1.03	\N	\N	Pine Island, Ramshorn Creek, Cooper River	SC
104813	Braddock Point, Hilton Head Island, South Carolina	NOS	8669625	32.1133	-80.83	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	-00:02:00	\N	1	00:05:00	\N	0.98	\N	\N	Braddock Point, Hilton Head Island	SC
104814	Daufuskie Landing, Daufuskie Island, New River, South Carolina	NOS	8669691	32.1033	-80.895	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:33:00	\N	0.95	00:30:00	\N	1.01	\N	\N	Daufuskie Landing, Daufuskie Island	SC
104815	Hargray Pier, Daufuskie Island, New River, South Carolina	NOS	8669722	32.0983	-80.8983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:27:00	\N	1.05	00:19:00	\N	1.01	\N	\N	Hargray Pier, Daufuskie Island	SC
104816	Bloody Point, Daufuskie Island, New River, South Carolina	NOS	8669801	32.0817	-80.8783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:19:00	\N	0.91	00:01:00	\N	0.98	\N	\N	Bloody Point, Daufuskie Island	SC
104817	Fields Cut, Wright River, South Carolina	NOS	8669815	32.0867	-80.9333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:29:00	\N	1.05	00:16:00	\N	1.02	\N	\N	Fields Cut, Wright River	SC
104818	S.C.L. RR. bridge, Savannah River, South Carolina	NOS	8670073	32.2317	-81.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	03:08:00	\N	0.91	01:51:00	\N	0.9	\N	\N	S.C.L. RR. bridge	SC
104819	Fort Jackson, Savannah River, Georgia	NOS	8670678	32.0817	-81.0367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:42:00	\N	1.09	00:29:00	\N	1.09	\N	\N	Fort Jackson	GA
104820	Savannah (Bull Street), Georgia (sub)	NOS	8670681	32.0817	-81.0917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:33:00	\N	1.14	00:44:00	\N	1.14	\N	\N	SAVANNAH	GA
104821	Tybee Light, Savannah River, Georgia	NOS	8670892	32.0283	-80.855	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	-00:12:00	\N	0.99	-00:10:00	\N	0.99	\N	\N	Tybee Light	GA
104822	Vernon View, Burnside River, Georgia	NOS	8671642	31.9267	-81.0983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:31:00	\N	1.09	00:40:00	\N	1.09	\N	\N	Vernon View, Burnside River	GA
104823	Florida Passage, Ogeechee River, Georgia	NOS	8672219	31.8533	-81.1467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:46:00	\N	0.91	00:34:00	\N	1.05	\N	\N	Florida Passage, Ogeechee River	GA
104824	Bradley Point, Bradley River, Georgia	NOS	8672455	31.8217	-81.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:13:00	\N	0.95	00:04:00	\N	1.02	\N	\N	Bradley Point, Bradley River	GA
104825	Belfast, Belfast River, Georgia	NOS	8672462	31.8217	-81.2983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:10:00	\N	1.14	01:23:00	\N	1.13	\N	\N	Belfast, Belfast River	GA
104826	Kilkenny Club, Kilkenny Creek, Georgia	NOS	8672696	31.7883	-81.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:37:00	\N	0.91	00:48:00	\N	1.09	\N	\N	Kilkenny Club, Kilkenny Creek	GA
104827	Halfmoon, Timmons River, Georgia	NOS	8673381	31.695	-81.2717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:09:00	\N	1.05	01:21:00	\N	1.06	\N	\N	Halfmoon, Timmons River	GA
104828	Walburg Creek entrance, Georgia	NOS	8673437	31.69	-81.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:21:00	\N	1	00:16:00	\N	1.03	\N	\N	Walburg Creek entrance	GA
104829	North Newport River (Daymark 119), Georgia	NOS	8673499	31.6817	-81.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:31:00	\N	1	00:35:00	\N	1.05	\N	\N	North Newport River (Daymark 119)	GA
104830	Thomas Landing, S. Newport River, Georgia	NOS	8673812	31.6433	-81.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:46:00	\N	0.95	00:57:00	\N	1.06	\N	\N	Thomas Landing, S. Newport River	GA
104831	Eagle Neck, South Newport River, Georgia	NOS	8673875	31.65	-81.305	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:06:00	\N	1	01:16:00	\N	1.09	\N	\N	Eagle Neck, South Newport River	GA
104832	Harris Neck, Barbour Island River, Georgia	NOS	8673962	31.6233	-81.2633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:32:00	\N	1	00:54:00	\N	1.08	\N	\N	Harris Neck, Barbour Island River	GA
104833	Barbour Island, Barbour Island River, Georgia	NOS	8674251	31.5783	-81.24	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:24:00	\N	1	00:36:00	\N	1.06	\N	\N	Barbour Island, Barbour Island River	GA
104834	Pine Harbor, Sapelo River, Georgia	NOS	8674512	31.5483	-81.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:04:00	\N	1.05	01:03:00	\N	1.05	\N	\N	Pine Harbor, Sapelo River	GA
104835	Dog Hammock, Sapelo River, Georgia	NOS	8674623	31.5317	-81.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:22:00	\N	0.91	00:33:00	\N	1.04	\N	\N	Dog Hammock, Sapelo River	GA
104836	Bellville Point, Sapelo River, Georgia	NOS	8674638	31.5317	-81.36	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:02:00	\N	0.86	01:12:00	\N	1.08	\N	\N	Bellville Point, Sapelo River	GA
104837	Eagle Creek, Mud River, Georgia	NOS	8674801	31.51	-81.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:19:00	\N	1.05	00:21:00	\N	1.05	\N	\N	Eagle Creek, Mud River	GA
104838	Creighton Narrows entrance, Crescent River, Georgia	NOS	8674875	31.4983	-81.325	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:37:00	\N	1.09	00:49:00	\N	1.08	\N	\N	Creighton Narrows Entrance, Crescent River	GA
104839	Blackbeard Creek, Blackbeard Island, Georgia	NOS	8674962	31.4883	-81.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:47:00	\N	0.95	00:19:00	\N	0.94	\N	\N	Blackbeard Creek, Blackbeard Island	GA
104840	Hudson Creek entrance, Georgia	NOS	8675245	31.4467	-81.3433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:31:00	\N	1.05	00:37:00	\N	1.05	\N	\N	Hudson Creek entrance	GA
104841	Old Tea Kettle Creek (Daymark 173), Georgia	NOS	8675365	31.4317	-81.3067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:39:00	\N	0.82	00:39:00	\N	0.96	\N	\N	Old Tea Kettle Creek (Daymark 173)	GA
104842	Old Tower, Sapelo Island, Georgia	NOS	8675622	31.39	-81.2883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:14:00	\N	0.95	00:15:00	\N	0.99	\N	\N	Old Tower, Sapelo Island	GA
104843	Darien, Darien River, Georgia	NOS	8675779	31.3683	-81.435	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:15:00	\N	1.05	01:08:00	\N	1.06	\N	\N	Darien, Darien River	GA
104844	Threemile Cut entrance, Darien River, Georgia	NOS	8675843	31.3567	-81.3767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:55:00	\N	1.05	00:44:00	\N	1.03	\N	\N	Threemile Cut entrance, Darien River	GA
104845	Champney Island, South Altamaha River, Georgia	NOS	8676012	31.3317	-81.46	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	02:33:00	\N	0.77	01:10:00	\N	0.76	\N	\N	Champney Island, South Altamaha River	GA
104846	Mackay River (ICWW), Buttermilk Sound, Georgia	NOS	8676329	31.285	-81.385	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:23:00	\N	1.09	00:58:00	\N	1	\N	\N	Mackay River (ICWW), Buttermilk Sound	GA
104847	Dillard Creek, Turtle River, Georgia	NOS	8676722	31.225	-81.5717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:02:00	\N	1.18	01:32:00	\N	1.16	\N	\N	Dillard Creek	GA
104848	Frederica River, Georgia	NOS	8676743	31.2217	-81.3933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:56:00	\N	1.05	00:48:00	\N	1.05	\N	\N	Frederica River	GA
104849	Mackay River (Daymark 239), Georgia	NOS	8676766	31.21	-81.425	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:56:00	\N	1.09	00:58:00	\N	1.03	\N	\N	Mackay River (Daymark 239)	GA
104850	Buffalo River entrance, Turtle River, Georgia	NOS	8676787	31.215	-81.5833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:58:00	\N	1.18	01:37:00	\N	1.16	\N	\N	Buffalo River entrance	GA
104851	Frederick River Bridge, Georgia	NOS	8677045	31.1683	-81.4133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:45:00	\N	1.09	00:43:00	\N	1	\N	\N	Frederick River Bridge	GA
104852	8 mi above mouth, Little Satilla River, Georgia	NOS	8677566	31.0983	-81.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	01:02:00	\N	1.2	00:24:00	\N	1.2	\N	\N	8 miles above mouth	GA
104853	Jointer Island, Jointer Creek, Georgia	NOS	8677576	31.095	-81.505	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:31:00	\N	1.18	00:11:00	\N	1.18	\N	\N	Jointer Island, Jointer Creek	GA
104854	Jekyll Island Marina, Jekyll Creek, Georgia	NOS	8677832	31.0567	-81.4233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:36:00	\N	1.16	00:03:00	\N	1.13	\N	\N	Jekyll Island Marina, Jekyll Creek	GA
104855	2.5 mi above mouth, Little Satilla River, Georgia	NOS	8677833	31.0583	-81.4933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:31:00	\N	1.12	-00:04:00	\N	1.12	\N	\N	2.5 miles above mouth	GA
104857	Todd Creek entrance, Satilla River, Georgia	NOS	8678412	30.9717	-81.52	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:41:00	\N	1.1	-00:08:00	\N	1.1	\N	\N	Todd Creek entrance	GA
104858	Ceylon, Satilla River, Georgia	NOS	8678466	30.9633	-81.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	01:35:00	\N	1.09	00:34:00	\N	1.09	\N	\N	Ceylon	GA
104859	Floyd Creek, 2.8 mi above entrance, Georgia	NOS	8678642	30.9367	-81.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:21:00	\N	1.17	00:08:00	\N	1.17	\N	\N	Floyd Creek, 2.8 miles above entrance	GA
104860	Cumberland Wharf, Cumberland River, Georgia	NOS	8678688	30.93	-81.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:26:00	\N	1.12	00:00:00	\N	1.12	\N	\N	Cumberland Wharf, Cumberland River	GA
104861	Harrietts Bluff, Crooked River, Georgia	NOS	8679083	30.87	-81.585	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	01:56:00	\N	1.05	01:29:00	\N	1.05	\N	\N	Harrietts Bluff, Crooked River	GA
104862	Crooked River, Cumberland Dividings, Georgia	NOS	8679242	30.8433	-81.4867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:56:00	\N	1.12	00:44:00	\N	1.12	\N	\N	Crooked River, Cumberland Dividings	GA
104863	Beach Creek ent., Cumberland Island, Georgia	NOS	8679945	30.7267	-81.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	-00:04:00	\N	0.95	00:00:00	\N	0.98	\N	\N	Beach Creek ent., Cumberland Island	GA
104864	St. Marys entrance, north jetty, Georgia	NOS	8679997	30.72	-81.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	-00:03:00	\N	0.96	-00:36:00	\N	0.96	\N	\N	St. Marys Entrance, North Jetty	GA
104865	Kings Ferry, St. Marys River, Florida	NOS	8720001	30.7867	-81.84	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	04:09:00	\N	1.16	04:05:00	\N	0.49	\N	\N	Kings Ferry	FL
104866	Little St. Marys River, St. Marys River, Florida	NOS	8720006	30.7317	-81.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	02:36:00	\N	0.79	02:49:00	\N	0.71	\N	\N	Little St. Marys River	FL
104867	Roses Bluff, Bells River, Florida	NOS	8720007	30.7033	-81.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:35:00	\N	0.95	00:35:00	\N	1.03	\N	\N	Roses Bluff, Bells River	FL
104868	Kingsley Creek, RR. bridge, Florida	NOS	8720058	30.6317	-81.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:25:00	\N	1	00:27:00	\N	0.99	\N	\N	Kingsley Creek, RR. bridge	FL
104869	Boggy Creek, 2 mi above entrance, Nassau River, Florida	NOS	8720084	30.5883	-81.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	03:50:00	\N	0.89	03:29:00	\N	0.49	\N	\N	Boggy Creek, 2 mi. above entrance	FL
104870	Amelia City, South Amelia River, Florida	NOS	8720086	30.5867	-81.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:42:00	\N	0.89	00:21:00	\N	0.89	\N	\N	Amelia City, South Amelia River	FL
104871	Halfmoon Island, highway bridge, Nassau River, Florida	NOS	8720093	30.5767	-81.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	02:39:00	\N	1.05	02:00:00	\N	0.7	\N	\N	Halfmoon Island, highway bridge	FL
104872	Cuno, Lofton Creek, Nassau River, Florida	NOS	8720097	30.5767	-81.5717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	02:48:00	\N	1.05	02:14:00	\N	0.6	\N	\N	Cuno, Lofton Creek	FL
104873	Mink Creek entrance, Nassau River, Florida	NOS	8720119	30.5367	-81.5817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	02:05:00	\N	1.05	01:13:00	\N	0.72	\N	\N	Mink Creek entrance	FL
104874	Nassau River entrance, Florida	NOS	8720135	30.5183	-81.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:41:00	\N	1	-00:18:00	\N	0.86	\N	\N	entrance	FL
104875	Sawpit Creek entrance, bridge, Florida	NOS	8720137	30.5133	-81.4567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:21:00	\N	1	-00:14:00	\N	0.84	\N	\N	Sawpit Creek entrance, bridge	FL
104876	Sawpit Creek, 1 mi above entrance, Florida	NOS	8720143	30.5033	-81.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:31:00	\N	0.74	00:05:00	\N	0.84	\N	\N	Sawpit Creek, 1 mi. above entrance	FL
104877	Tiger Point, Pumpkin Hill Creek, Nassau River, Florida	NOS	8720148	30.5017	-81.495	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	01:46:00	\N	0.95	01:22:00	\N	0.82	\N	\N	Tiger Point, Pumpkin Hill Creek	FL
104878	Simpson Creek, A1A highway bridge, Florida	NOS	8720168	30.465	-81.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:17:00	\N	0.63	00:04:00	\N	0.84	\N	\N	Simpson Creek, A1A highway bridge	FL
105265	Christmas Bay, Texas	NOS	8772132	29.0417	-95.175	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103468	02:37:00	\N	0.23	04:47:00	\N	0.58	\N	\N	Christmas Bay	TX
104879	Fort George Island, Fort George River, Florida	NOS	8720186	30.44	-81.4383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:33:00	\N	0.74	00:10:00	\N	0.79	\N	\N	Fort George Island, Fort George River	FL
104880	Little Talbot Island, ocean, Florida	NOS	8720194	30.43	-81.405	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	-00:13:00	\N	1	-00:36:00	\N	0.91	\N	\N	Little Talbot Island, ocean	FL
104881	Blount Island Bridge, Florida	NOS	8720203	30.4133	-81.545	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103136	01:05:00	\N	0.73	00:42:00	\N	0.77	\N	\N	Blount Island Bridge	FL
104882	Jacksonville, Navy Fuel Depot, Florida	NOS	8720215	30.4	-81.6267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103136	01:48:00	\N	0.53	01:14:00	\N	0.56	\N	\N	Jacksonville, Navy Fuel Depot	FL
104883	Lake Forest, Ribault River, Trout River, Florida	NOS	8720216	30.3983	-81.6983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103136	02:10:00	\N	0.6	01:13:00	\N	0.58	\N	\N	Lake Forest, Ribault River	FL
104884	Moncrief Creek entrance, Trout River, Florida	NOS	8720217	30.3917	-81.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103136	01:53:00	\N	0.53	01:11:00	\N	0.55	\N	\N	Moncrief Creek entrance	FL
104885	Fulton, Florida	NOS	8720221	30.39	-81.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103136	00:40:00	\N	0.73	00:24:00	\N	0.8	\N	\N	Fulton	FL
104886	Pablo Creek entrance, Florida	NOS	8720232	30.3767	-81.4483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103136	00:33:00	\N	0.73	00:29:00	\N	0.85	\N	\N	Pablo Creek entrance	FL
104887	Atlantic Beach, Florida	NOS	8720259	30.335	-81.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	-00:23:00	\N	0.86	-00:41:00	\N	0.86	\N	\N	Atlantic Beach	FL
104888	Pablo Creek, ICWW bridge, Florida	NOS	8720267	30.3233	-81.4383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103136	01:20:00	\N	1	01:14:00	\N	0.84	\N	\N	Pablo Creek, ICWW bridge	FL
104889	Little Pottsburg Creek, Florida	NOS	8720274	30.31	-81.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103136	02:09:00	\N	0.53	01:31:00	\N	0.44	\N	\N	Little Pottsburg Creek	FL
104890	Ortega River entrance, Florida	NOS	8720296	30.2783	-81.705	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103136	02:47:00	\N	0.47	02:09:00	\N	0.25	\N	\N	Ortega River entrance	FL
104891	Oak Landing, ICWW, Florida	NOS	8720305	30.2533	-81.43	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	02:03:00	\N	0.8	02:15:00	\N	0.68	\N	\N	Oak Landing, ICWW	FL
104892	Piney Point, Florida	NOS	8720333	30.2283	-81.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103136	03:36:00	\N	0.4	02:39:00	\N	0.2	\N	\N	Piney Point	FL
104893	Orange Park Landing, Orange Park, Florida	NOS	8720374	30.16830062866211	-81.69499969482422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103136	04:44:00	\N	0.2	03:24:00	\N	0.2	\N	\N	Orange Park Landing, Orange Park	FL
104894	Palm Valley, ICWW, Florida	NOS	8720398	30.1333	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	01:49:00	\N	0.75	02:00:00	\N	0.79	\N	\N	Palm Valley, ICWW	FL
104895	Julington Creek, Florida	NOS	8720409	30.135000228881836	-81.62999725341797	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103136	05:13:00	\N	0.2	03:58:00	\N	0.2	\N	\N	Julington Creek	FL
104896	Green Cove Springs, Florida	NOS	8720496	29.99	-81.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103136	05:55:00	\N	0.27	04:57:00	\N	0.17	\N	\N	Green Cove Springs	FL
104897	St. Augustine, city dock, Florida	NOS	8720576	29.8917	-81.31	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:01:00	\N	0.89	-00:20:00	\N	0.75	\N	\N	St. Augustine, city dock	FL
104898	Tocoi, Florida	NOS	8720596	29.8583	-81.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103136	07:03:00	\N	0.27	06:02:00	\N	0.21	\N	\N	Tocoi	FL
104899	Palmetto Bluff, Florida	NOS	8720653	29.7633	-81.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103136	07:36:00	\N	0.47	06:35:00	\N	0.23	\N	\N	Palmetto Bluff	FL
104900	Fort Matanzas, Matanzas River, ICWW, Florida	NOS	8720686	29.715	-81.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	00:49:00	\N	0.95	00:03:00	\N	0.65	\N	\N	Fort Matanzas, Matanzas River, ICWW	FL
104901	Sutherlands Still, Dunns Creek, Florida	NOS	8720782	29.5717	-81.6067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103136	09:05:00	\N	0.2	07:35:00	\N	0.18	\N	\N	Sutherlands Still, Dunns Creek	FL
105818	Troy, Hudson River, New York	NOS	TEC1603	42.71666666666667	-73.7	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102893	00:10:00	\N	1	00:08:00	\N	1	\N	\N	Troy	NY
104902	Smith Creek, Flagler Beach, Florida	NOS	8720833	29.4783	-81.1367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	05:00:00	\N	0.3	04:33:00	\N	0.15	\N	\N	Smith Creek, Flagler Beach	FL
104903	Ormond Beach, Halifax River, Florida	NOS	8720954	29.28499984741211	-81.05329895019531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	04:31:00	\N	0.45	03:17:00	\N	0.11	\N	\N	Ormond Beach, Halifax River	FL
104904	Daytona Beach Shores, Sunglow Pier, Florida (sub)	NOS	8721120	29.1467	-80.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	-00:42:00	\N	0.84	-00:56:00	\N	0.65	\N	\N	Daytona Beach Shores, Sunglow Pier	FL
104905	Ponce Inlet, Halifax River, Florida	NOS	8721138	29.0817	-80.9367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:33:00	\N	1	00:05:00	\N	1.18	\N	\N	Ponce Inlet, Halifax River	FL
104906	Patrick Air Force Base, Florida	NOS	8721727	28.245	-80.6	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	-00:38:00	\N	1.43	-01:04:00	\N	1.5	\N	\N	Patrick Air Force Base	FL
104907	Canova Beach, Florida	NOS	8721804	28.1383	-80.5783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	-00:26:00	\N	1.5	-00:53:00	\N	1.49	\N	\N	Canova Beach	FL
104908	Micco, Indian River, Florida	NOS	8721994	27.8733	-80.4967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	02:19:00	\N	0.57	01:14:00	\N	0.14	\N	\N	Micco	FL
104909	Sebastian Inlet bridge, Florida	NOS	8722004	27.86	-80.4483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	-00:24:00	\N	1	-00:48:00	\N	0.93	\N	\N	Sebastian Inlet bridge	FL
104910	Sebastian, Indian River, Florida	NOS	8722029	27.8117	-80.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	02:36:00	\N	0.5	01:32:00	\N	0.15	\N	\N	Sebastian	FL
104911	Wabasso, Indian River, Florida	NOS	8722059	27.755	-80.425	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	03:24:00	\N	0.42	02:20:00	\N	0.17	\N	\N	Wabasso	FL
104912	Vero Beach (ocean), Florida	NOS	8722105	27.67	-80.36	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	-00:35:00	\N	1.36	-00:55:00	\N	1.45	\N	\N	Vero Beach (ocean)	FL
104913	Oslo, Indian River, Florida	NOS	8722146	27.5933	-80.3567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	03:59:00	\N	0.5	03:00:00	\N	0.34	\N	\N	Oslo	FL
104914	St. Lucie, Indian River, Florida	NOS	8722207	27.48	-80.3333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:46:00	\N	1	00:41:00	\N	0.48	\N	\N	St. Lucie	FL
104915	Fort Pierce Inlet, south jetty, Florida	NOS	8722212	27.47	-80.2883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	-00:18:00	\N	1.5	-00:31:00	\N	1.14	\N	\N	Fort Pierce Inlet, south jetty	FL
104916	Eden, Nettles Island, Indian River, Florida	NOS	8722312	27.2867	-80.2267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	03:31:00	\N	0.92	02:35:00	\N	0.45	\N	\N	Eden, Nettles Island	FL
104917	North Fork, St. Lucie River, Florida	NOS	8722334	27.2433	-80.3133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	03:28:00	\N	0.92	02:28:00	\N	0.46	\N	\N	North Fork	FL
104918	Stuart, St. Lucie River, Florida	NOS	8722357	27.2	-80.2583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	03:30:00	\N	0.86	02:13:00	\N	0.4	\N	\N	Stuart	FL
104919	Seminole Shores, Florida	NOS	8722366	27.1833	-80.1583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	-00:35:00	\N	1.28	-00:59:00	\N	1.29	\N	\N	Seminole Shores	FL
104920	South Fork, St. Lucie River, Florida	NOS	8722376	27.165	-80.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	03:32:00	\N	0.92	02:35:00	\N	0.43	\N	\N	South Fork	FL
104921	Great Pocket, St. Lucie River, Florida	NOS	8722381	27.155	-80.1717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:42:00	\N	1	00:55:00	\N	0.5	\N	\N	Great Pocket	FL
104922	Port Salerno, Manatee Pocket, St. Lucie River, Florida	NOS	8722383	27.1517	-80.195	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:46:00	\N	0.92	00:51:00	\N	0.42	\N	\N	Port Salerno, Manatee Pocket	FL
104923	Peck Lake, ICWW, Florida	NOS	8722404	27.1133	-80.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	02:10:00	\N	1	01:13:00	\N	0.58	\N	\N	Peck Lake, ICWW	FL
104924	Gomez, South Jupiter Narrows, Florida	NOS	8722414	27.0933	-80.1367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	02:37:00	\N	1.07	01:33:00	\N	0.6	\N	\N	Gomez, South Jupiter Narrows	FL
104925	Hobe Sound bridge, Florida	NOS	8722429	27.065	-80.1233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	02:25:00	\N	1	01:28:00	\N	0.68	\N	\N	Hobe Sound bridge	FL
104926	Hobe Sound, Jupiter Island, Florida	NOS	8722445	27.0367	-80.1067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	02:12:00	\N	1	01:16:00	\N	0.75	\N	\N	Hobe Sound, Jupiter Island	FL
104927	Conch Bar, Jupiter Sound, Florida	NOS	8722471	26.9883	-80.0933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:34:00	\N	1.07	00:56:00	\N	0.74	\N	\N	Conch Bar, Jupiter Sound	FL
104928	Boy Scout Dock, Loxahatchee River, Florida	NOS	8722472	26.9867	-80.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:57:00	\N	1.36	01:01:00	\N	0.92	\N	\N	Boy Scout Dock	FL
104929	North Fork, 2 mi above entrance, Loxahatchee River, Florida	NOS	8722478	26.975	-80.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:55:00	\N	1.14	01:04:00	\N	0.86	\N	\N	North Fork, 2 miles above entrance	FL
104930	3 mi above A1A highway bridge, Loxahatchee River, Florida	NOS	8722481	26.97	-80.1267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:49:00	\N	1.14	00:56:00	\N	0.86	\N	\N	3 miles above A1A highway bridge	FL
104931	Tequesta, North Fork, Loxahatchee River, Florida	NOS	8722486	26.96	-80.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	02:13:00	\N	1	01:14:00	\N	0.75	\N	\N	Tequesta, North Fork	FL
104932	Jupiter Sound, south end, Florida	NOS	8722491	26.9517	-80.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:45:00	\N	1.36	00:22:00	\N	0.88	\N	\N	Jupiter Sound, south end	FL
104933	A1A highway bridge, Loxahatchee River, Florida	NOS	8722492	26.9467	-80.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:54:00	\N	1.14	00:34:00	\N	0.87	\N	\N	A1A highway bridge	FL
104934	Southwest Fork, 0.5 mi above entrance, Loxahatchee River, Florida	NOS	8722494	26.9433	-80.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:35:00	\N	1.42	00:41:00	\N	0.89	\N	\N	Southwest Fork, 0.5 mile above entrance	FL
104935	Jupiter Inlet, south jetty, Florida	NOS	8722495	26.9433	-80.0733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	-00:09:00	\N	1.42	-00:10:00	\N	1.08	\N	\N	Jupiter Inlet, south jetty	FL
104936	Southwest Fork (spillway), Loxahatchee River, Florida	NOS	8722496	26.935	-80.1433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:45:00	\N	1.28	00:52:00	\N	0.86	\N	\N	Southwest Fork (spillway)	FL
104937	Jupiter, Lake Worth Creek, ICWW, Florida	NOS	8722499	26.935	-80.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:12:00	\N	1.28	00:34:00	\N	0.91	\N	\N	Jupiter, Lake Worth Creek, ICWW	FL
104938	Lake Worth Creek, Day Beacon 19, ICWW, Florida	NOS	8722512	26.9117	-80.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:08:00	\N	1.21	00:29:00	\N	0.92	\N	\N	Lake Worth Creek, Day Beacon 19, ICWW	FL
104939	Donald Ross Bridge, ICWW, Florida	NOS	8722528	26.8817	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:50:00	\N	1.21	00:20:00	\N	1	\N	\N	Donald Ross Bridge, ICWW	FL
104940	North Palm Beach, Lake Worth, Florida	NOS	8722557	26.8267	-80.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:15:00	\N	1.29	-00:17:00	\N	1.22	\N	\N	North Palm Beach	FL
104941	Palm Beach, Lake Worth, Florida	NOS	8722607	26.7333	-80.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:16:00	\N	1.29	-00:11:00	\N	1.17	\N	\N	Palm Beach	FL
104942	Palm Beach, Highway 704 bridge, Lake Worth, Florida	NOS	8722621	26.705	-80.045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:40:00	\N	1.07	00:18:00	\N	1.1	\N	\N	Palm Beach, Highway 704 bridge	FL
104943	West Palm Beach Canal, Lake Worth, Florida	NOS	8722654	26.645	-80.045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:35:00	\N	1.14	00:48:00	\N	1.07	\N	\N	West Palm Beach Canal	FL
104944	Boynton Beach, Lake Worth, Florida (sub)	NOS	8722706	26.54829978942871	-80.05329895019531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	02:07:00	\N	1.07	01:05:00	\N	1.06	\N	\N	Boynton Beach, Lake Worth	FL
104945	Delray Beach, ICWW, Florida	NOS	8722746	26.4733	-80.0617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	02:07:00	\N	1.14	01:24:00	\N	1.07	\N	\N	Delray Beach, ICWW	FL
104946	Yamato, ICWW, Florida	NOS	8722784	26.4033	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:57:00	\N	1.14	01:22:00	\N	1.02	\N	\N	Yamato, ICWW	FL
104947	Deerfield Beach, Hillsboro River, Florida (sub)	NOS	8722832	26.31330555555556	-80.08169444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:03:00	\N	1.07	00:28:00	\N	1.02	\N	\N	Deerfield Beach, Hillsboro River	FL
104948	Hillsboro Beach, ICWW, Florida	NOS	8722854	26.2733	-80.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:34:00	\N	1.07	00:02:00	\N	1.06	\N	\N	Hillsboro Beach, ICWW	FL
104949	Hillsboro Inlet, USCG light station, Florida	NOS	8722861	26.2583	-80.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:03:00	\N	1.14	-00:16:00	\N	1.08	\N	\N	Hillsboro Inlet, Coast Guard Light Station	FL
104950	Hillsboro Inlet (ocean), Florida	NOS	8722862	26.2567	-80.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:00:00	\N	1.21	-00:23:00	\N	1.12	\N	\N	Hillsboro Inlet (ocean)	FL
104951	Andrews Avenue bridge, New River, Fort Lauderdale, Florida (sub)	NOS	8722937	26.1183	-80.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:51:00	\N	1.07	00:15:00	\N	0.92	\N	\N	Andrews Avenue bridge, New River	FL
104952	Bahia Mar Yacht Club, Fort Lauderdale, Florida	NOS	8722939	26.1133	-80.1083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:33:00	\N	1.21	-00:05:00	\N	1.05	\N	\N	Bahia Mar Yacht Club	FL
104953	Mayan Lake, Florida	NOS	8722946	26.1	-80.1083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:02:00	\N	1	00:20:00	\N	0.91	\N	\N	Mayan Lake	FL
104954	Port Everglades, Turning Basin, Florida	NOS	8722951	26.0917	-80.1233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	-00:09:00	\N	1.14	-00:29:00	\N	1.09	\N	\N	Port Everglades, Turning Basin	FL
104955	Whiskey Creek, north end, Florida	NOS	8722957	26.08	-80.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	-00:06:00	\N	1.28	-00:23:00	\N	1.1	\N	\N	Whiskey Creek, north end	FL
104956	Port Laudania, Dania cut-off Canal, Florida	NOS	8722968	26.06	-80.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:11:00	\N	1.21	00:01:00	\N	1	\N	\N	Port Laudania, Dania cut-off Canal	FL
104957	Whiskey Creek, south entrance, ICWW, Florida	NOS	8722971	26.055	-80.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:31:00	\N	1.14	00:04:00	\N	0.96	\N	\N	Whiskey Creek, south entrance, ICWW	FL
104958	Hollywood Beach, West Lake, north end, Florida	NOS	8722977	26.0433	-80.1267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:42:00	\N	1.07	01:08:00	\N	0.85	\N	\N	Hollywood Beach, West Lake, north end	FL
104959	Hollywood Beach, Florida	NOS	8722979	26.04	-80.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:41:00	\N	1.14	00:37:00	\N	0.91	\N	\N	Hollywood Beach	FL
104960	Hollywood Beach, West Lake, south end, Florida	NOS	8722982	26.0333	-80.1233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:45:00	\N	1.14	01:02:00	\N	0.88	\N	\N	Hollywood Beach, West Lake, south end	FL
104961	Golden Beach, ICWW, Florida	NOS	8723026	25.9667	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:57:00	\N	1.07	01:13:00	\N	0.91	\N	\N	Golden Beach, ICWW	FL
104962	Dumfoundling Bay, Florida	NOS	8723044	25.9417	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	02:07:00	\N	1	01:17:00	\N	0.88	\N	\N	Dumfoundling Bay	FL
104963	North Miami Beach, Newport Fishing Pier, Florida	NOS	8723050	25.93	-80.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:00:00	\N	1.21	-00:22:00	\N	1.08	\N	\N	North Miami Beach, Newport Fishing Pier	FL
104964	Bakers Haulover Inlet (inside), Florida	NOS	8723073	25.9033	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:37:00	\N	0.92	00:57:00	\N	0.87	\N	\N	Bakers Haulover Inlet (inside)	FL
104965	Sunny Isles, Biscayne Creek, Florida	NOS	8723087	25.9283	-80.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	02:24:00	\N	0.71	02:00:00	\N	0.77	\N	\N	Sunny Isles, Biscayne Creek	FL
104966	Biscayne Creek, ICWW, Florida	NOS	8723089	25.88	-80.1633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:39:00	\N	1	00:47:00	\N	0.93	\N	\N	Biscayne Creek, ICWW	FL
104967	Indian Creek Golf Club, ICWW, Florida	NOS	8723094	25.875	-80.1433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:46:00	\N	0.92	01:13:00	\N	0.92	\N	\N	Indian Creek Golf Club, ICWW	FL
104968	Dodge Island, Fishermans Channel, Biscayne Bay, Florida	NOS	8723155	25.77	-80.1683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:10:00	\N	1	00:34:00	\N	0.91	\N	\N	Dodge Island, Fishermans Channel	FL
104969	San Marino Island, Biscayne Bay, Florida	NOS	8723156	25.7933	-80.1633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:58:00	\N	1	00:37:00	\N	0.92	\N	\N	San Marino Island	FL
104970	Dinner Key Marina, Biscayne Bay, Florida	NOS	8723205	25.7267	-80.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:48:00	\N	0.92	00:54:00	\N	0.84	\N	\N	Dinner Key Marina	FL
104971	Key Biscayne Yacht Club, Biscayne Bay, Florida	NOS	8723232	25.6983	-80.17	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:31:00	\N	0.92	00:44:00	\N	0.86	\N	\N	Key Biscayne Yacht Club, Biscayne Bay	FL
104972	Coral Shoal, Biscayne Channel, Florida	NOS	8723251	25.6517	-80.16	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:37:00	\N	0.92	00:11:00	\N	0.88	\N	\N	Coral Shoal, Biscayne Channel	FL
104973	Soldier Key, Florida	NOS	8723303	25.59	-80.1617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:16:00	\N	0.71	00:30:00	\N	0.81	\N	\N	Soldier Key	FL
104974	Ragged Keys, Biscayne Bay, Florida	NOS	8723350	25.5333	-80.1717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:18:00	\N	1	00:43:00	\N	0.73	\N	\N	Ragged Keys, Biscayne Bay	FL
104975	Sands Key, northwest point, Biscayne Bay, Florida	NOS	8723372	25.5067	-80.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	02:26:00	\N	0.64	01:25:00	\N	0.63	\N	\N	Sands Key, northwest point, Biscayne Bay	FL
104976	Coon Point, Elliott Key, Biscayne Bay, Florida	NOS	8723391	25.48	-80.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	02:56:00	\N	0.71	01:55:00	\N	0.63	\N	\N	Coon Point, Elliott Key, Biscayne Bay	FL
104977	Sea Grape Point, Elliott Key, Florida	NOS	8723393	25.4767	-80.18	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	-00:05:00	\N	1.03	-00:25:00	\N	1.03	\N	\N	Sea Grape Point, Elliott Key	FL
104978	Billys Point, south of, Elliott Key, Biscayne Bay, Florida	NOS	8723439	25.415	-80.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	03:20:00	\N	0.64	02:08:00	\N	0.63	\N	\N	Billys Point, south of, Elliott Key, Biscayne Bay	FL
104979	Adams Key, south end, Biscayne Bay, Florida	NOS	8723453	25.3967	-80.2333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:08:00	\N	1	01:01:00	\N	0.67	\N	\N	Adams Key, south end, Biscayne Bay	FL
104980	Christmas Point, Elliott Key, Florida	NOS	8723457	25.3917	-80.23	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:37:00	\N	1.07	00:13:00	\N	0.8	\N	\N	Christmas Point, Elliott Key	FL
104981	Totten Key, west side, Biscayne Bay, Florida	NOS	8723467	25.3783	-80.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	03:21:00	\N	0.57	02:19:00	\N	0.54	\N	\N	Totten Key, west side, Biscayne Bay	FL
104982	Card Sound, western side, Florida	NOS	8723491	25.345	-80.3317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	03:40:00	\N	0.43	02:51:00	\N	0.3	\N	\N	Card Sound, western side	FL
104983	Wednesday Point, Key Largo, Card Sound, Florida	NOS	8723518	25.31	-80.2983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	03:30:00	\N	0.57	02:38:00	\N	0.34	\N	\N	Wednesday Point, Key Largo, Card Sound	FL
104984	Ocean Reef Harbor, Key Largo, Florida	NOS	8723519	25.3083	-80.2767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:17:00	\N	1.5	-00:08:00	\N	1.02	\N	\N	Ocean Reef Harbor, Key Largo	FL
104985	Cormorant Point, Key Largo, Card Sound, Florida	NOS	8723532	25.29	-80.34	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	03:01:00	\N	0.5	02:45:00	\N	0.32	\N	\N	Cormorant Point, Key Largo, Card Sound	FL
104986	Main Key, Barnes Sound, Florida	NOS	8723571	25.24	-80.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	06:16:00	\N	0.36	05:04:00	\N	0.19	\N	\N	Main Key, Barnes Sound	FL
104987	Manatee Creek, Manatee Bay, Barnes Sound, Florida	NOS	8723575	25.235	-80.43	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	06:20:00	\N	0.36	05:14:00	\N	0.18	\N	\N	Manatee Creek, Manatee Bay, Barnes Sound	FL
104988	Carysfort Reef, Florida	NOS	8723583	25.2217	-80.2117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:39:00	\N	1.36	00:19:00	\N	1.03	\N	\N	Carysfort Reef	FL
104989	Garden Cove, Key Largo, Florida	NOS	8723622	25.1717	-80.3667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:25:00	\N	1.14	-00:01:00	\N	0.94	\N	\N	Garden Cove, Key Largo	FL
104990	Flamingo, Florida Bay, Florida	NOS	8723644	25.1417	-80.9233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	07:20:00	\N	1.08	05:28:00	\N	1.47	\N	\N	Flamingo, Florida Bay	FL
104991	Largo Sound, Key Largo, Florida	NOS	8723651	25.14	-80.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	03:03:00	\N	0.5	02:13:00	\N	0.35	\N	\N	Largo Sound, Key Largo	FL
104992	Key Largo, South Sound, Key Largo, Florida	NOS	8723667	25.113333333332992	-80.41666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:49:00	\N	0.64	00:23:00	\N	0.66	\N	\N	Key Largo, South Sound, Key Largo	FL
104993	Rock Harbor, Key Largo, Florida	NOS	8723689	25.0817	-80.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:36:00	\N	1.21	00:22:00	\N	0.94	\N	\N	Rock Harbor, Key Largo	FL
104994	Point Charles, Key Largo, Florida	NOS	8723691	25.0817	-80.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:53:00	\N	0.64	00:25:00	\N	0.77	\N	\N	Point Charles, Key Largo	FL
104995	Crane Keys, north side, Florida Bay, Florida	NOS	8723746	25.005	-80.6183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	04:35:00	\N	0.21	02:52:00	\N	0.17	\N	\N	Crane Keys, north side, Florida Bay	FL
104996	Tavernier Harbor, Hawk Channel, Florida	NOS	8723747	25.005	-80.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:26:00	\N	1.36	00:07:00	\N	0.9	\N	\N	Tavernier Harbor, Hawk Channel	FL
104997	Tavernier Creek, Hwy. 1 bridge, Hawk Channel, Florida	NOS	8723748	25.0033	-80.53	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:52:00	\N	1.07	00:25:00	\N	0.6	\N	\N	Tavernier Creek, Hwy. 1 bridge, Hawk Channel	FL
104998	East Key, southern end, Florida Bay, Florida	NOS	8723752	24.9967	-80.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	04:06:00	\N	0.14	02:43:00	\N	0.22	\N	\N	East Key, southern end, Florida Bay	FL
104999	Plantation Key, Hawk Channel, Florida	NOS	8723769	24.9733	-80.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:12:00	\N	1.21	00:05:00	\N	0.96	\N	\N	Plantation Key, Hawk Channel	FL
105000	Yacht Harbor, Cowpens Anchorage, Plantation Key, Florida	NOS	8723776	24.965	-80.5683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	04:00:00	\N	0.29	02:45:00	\N	0.23	\N	\N	Yacht Harbor, Cowpens Anchorage, Plantation Key	FL
105001	Snake Creek, USCG station, Plantation Key, Florida	NOS	8723786	24.9533	-80.5867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:56:00	\N	0.5	01:08:00	\N	0.36	\N	\N	Snake Creek, USCG Station, Plantation Key	FL
105002	Snake Creek, Hwy. 1 bridge, Windley Key, Florida	NOS	8723787	24.9517	-80.5883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:56:00	\N	0.5	00:49:00	\N	0.46	\N	\N	Snake Creek, Hwy. 1 bridge, Windley Key	FL
105003	Whale Harbor, Windley Key, Hawk Channel, Florida	NOS	8723795	24.94	-80.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:51:00	\N	0.36	00:07:00	\N	0.65	\N	\N	Whale Harbor, Windley Key, Hawk Channel	FL
105004	Whale Harbor Channel, Hwy. 1 bridge, Windley Key, Florida	NOS	8723797	24.9383	-80.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:00:00	\N	0.71	00:16:00	\N	0.59	\N	\N	Whale Harbor Channel, Hwy. 1 bridge, Windley Key	FL
105005	Shell Key, northwest side, Lignumvitae Basin, Florida	NOS	8723807	24.9233	-80.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:57:00	\N	0.46	00:31:00	\N	0.46	\N	\N	Shell Key, northwest side, Lignumvitae Basin	FL
105006	Islamorada, Upper Matecumbe Key, Florida Bay, Florida	NOS	8723808	24.925	-80.6317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	02:07:00	\N	0.37	00:39:00	\N	0.37	\N	\N	Islamorada, Upper Matecumbe Key, Florida Bay	FL
105007	Shell Key Channel, Florida Bay, Florida	NOS	8723812	24.9133	-80.66	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:45:00	\N	0.78	-00:20:00	\N	0.78	\N	\N	Shell Key Channel, Florida Bay	FL
105008	Little Basin, Upper Matecumbe Key, Florida Bay, Florida	NOS	8723813	24.915	-80.64	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:15:00	\N	0.61	00:08:00	\N	0.61	\N	\N	Little Basin, Upper Matecumbe Key, Florida Bay	FL
105009	Upper Matecumbe Key, Hawk Channel, Florida	NOS	8723814	24.915	-80.6317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:49:00	\N	1.21	00:34:00	\N	0.87	\N	\N	Upper Matecumbe Key, Hawk Channel	FL
105010	Lignumvitae Key, NE side, Florida Bay, Florida	NOS	8723824	24.9033	-80.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:31:00	\N	0.52	00:09:00	\N	0.52	\N	\N	Lignumvitae Key, NE side, Florida Bay	FL
105011	Lignumvitae Key, west side, Florida Bay, Florida	NOS	8723825	24.9	-80.705	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:54:00	\N	0.47	00:32:00	\N	0.47	\N	\N	Lignumvitae Key, west side, Florida Bay	FL
105012	Upper Matecumbe Key, west end, Hawk Channel, Florida	NOS	8723828	24.8967	-80.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:14:00	\N	0.33	-01:00:00	\N	0.98	\N	\N	Upper Matecumbe Key, west end, Hawk Channel	FL
105013	Indian Key, Hawk Channel, Florida	NOS	8723843	24.8767	-80.6767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:35:00	\N	0.71	-00:58:00	\N	1.3	\N	\N	Indian Key, Hawk Channel	FL
105014	Indian Key Anchorage, Lower Matecumbe Key, Florida	NOS	8723851	24.8683	-80.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:54:00	\N	0.88	-01:25:00	\N	1.38	\N	\N	Indian Key Anchorage, Lower Matecumbe Key	FL
105015	Matecumbe Bight, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723852	24.865	-80.7167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:33:00	\N	0.38	-00:18:00	\N	0.55	\N	\N	Matecumbe Bight, Lower Matecumbe Key, Fla. Bay	FL
105016	Alligator Reef, Hawk Channel, Florida	NOS	8723861	24.85	-80.6183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	00:24:00	\N	1.36	00:08:00	\N	0.86	\N	\N	Alligator Reef, Hawk Channel	FL
105017	Matecumbe Harbor, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723862	24.8517	-80.74	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:23:00	\N	0.33	-00:25:00	\N	0.59	\N	\N	Matecumbe Harbor, Lower Matecumbe Key, Fla. Bay	FL
105018	Channel Two, east, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723868	24.845	-80.7483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:42:00	\N	0.54	-00:49:00	\N	0.85	\N	\N	Channel Two, east, Lower Matecumbe Key, Fla. Bay	FL
105019	Channel Two, west side, Hawk Channel, Florida	NOS	8723869	24.8417	-80.7533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:54:00	\N	0.75	-01:06:00	\N	1.12	\N	\N	Channel Two, west side, Hawk Channel	FL
105020	Channel Five, west side, Hawk Channel, Florida	NOS	8723872	24.84	-80.78	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:41:00	\N	0.67	-00:58:00	\N	1	\N	\N	Channel Five, west side, Hawk Channel	FL
105021	Jewfish Hole, Long Key, Florida Bay, Florida	NOS	8723873	24.83830555555556	-80.79830555555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:32:00	\N	0.38	-00:11:00	\N	0.42	\N	\N	Jewfish Hole, Long Key, Florida Bay	FL
105022	Channel Five, east side, Hawk Channel, Florida	NOS	8723874	24.8367	-80.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:42:00	\N	0.58	-00:54:00	\N	0.9	\N	\N	Channel Five, east side, Hawk Channel	FL
105023	Long Key Bight, Long Key, Florida	NOS	8723879	24.8283	-80.8083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:43:00	\N	0.62	-00:59:00	\N	1.03	\N	\N	Long Key Bight, Long Key	FL
105024	Long Key Lake, Long Key, Florida	NOS	8723887	24.82	-80.8167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:57:00	\N	0.46	00:33:00	\N	0.62	\N	\N	Long Key Lake, Long Key	FL
105025	Long Key, western end, Florida	NOS	8723899	24.8033	-80.85	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:54:00	\N	0.33	-01:01:00	\N	0.82	\N	\N	Long Key, western end	FL
105026	Conch Key, eastern end, Florida	NOS	8723906	24.7917	-80.8833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:45:00	\N	0.54	-01:09:00	\N	0.85	\N	\N	Conch Key, eastern end	FL
105027	Toms Harbor Cut, Florida	NOS	8723912	24.7833	-80.9067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:30:00	\N	0.38	-01:19:00	\N	0.37	\N	\N	Toms Harbor Cut	FL
105028	Toms Harbor Channel, Hwy. 1 bridge, Florida	NOS	8723918	24.7767	-80.9233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	04:49:00	\N	0.38	05:07:00	\N	0.38	\N	\N	Toms Harbor Channel, Hwy. 1 bridge	FL
105029	Grassy Key, north side, Florida Bay, Florida	NOS	8723921	24.7717	-80.94	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	06:48:00	\N	1.04	05:40:00	\N	0.73	\N	\N	Grassy Key, north side, Florida Bay	FL
105030	Duck Key, Hawk Channel, Florida	NOS	8723927	24.765	-80.9133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:40:00	\N	0.55	-01:11:00	\N	0.97	\N	\N	Duck Key, Hawk Channel	FL
105031	Grassy Key, south side, Hawk Channel, Florida	NOS	8723933	24.755	-80.9583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:26:00	\N	0.71	-00:52:00	\N	1.22	\N	\N	Grassy Key, south side, Hawk Channel	FL
105032	Fat Deer Key, Florida Bay, Florida	NOS	8723949	24.7333	-81.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	06:26:00	\N	0.87	05:09:00	\N	0.87	\N	\N	Fat Deer Key, Florida Bay	FL
105033	Vaca Key-Fat Deer Key bridge, Florida	NOS	8723950	24.73	-81.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:36:00	\N	0.71	-01:11:00	\N	0.95	\N	\N	Vaca Key-Fat Deer Key bridge	FL
105034	Boot Key Harbor bridge, Boot Key, Florida	NOS	8723971	24.7033	-81.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:37:00	\N	0.75	-01:03:00	\N	1.13	\N	\N	Boot Key Harbor bridge, Boot Key	FL
105035	Sombrero Key, Hawk Channel, Florida	NOS	8723999	24.6267	-81.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:39:00	\N	0.79	-01:03:00	\N	1.18	\N	\N	Sombrero Key, Hawk Channel	FL
105036	Knight Key Channel, Knight Key, Florida Bay, Florida	NOS	8724008	24.7067	-81.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:18:00	\N	0.5	-00:02:00	\N	0.54	\N	\N	Knight Key Channel, Knight Key, Florida Bay	FL
105037	Pigeon Key, south side, Hawk Channel, Florida	NOS	8724032	24.7033	-81.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:26:00	\N	0.5	-00:55:00	\N	0.81	\N	\N	Pigeon Key, south side, Hawk Channel	FL
105038	Pigeon Key, north side, Florida Bay, Florida	NOS	8724033	24.705	-81.1567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:45:00	\N	0.46	-00:10:00	\N	0.46	\N	\N	Pigeon Key, north side, Florida Bay	FL
105039	Molasses Key Channel, Molasses Keys, Florida	NOS	8724062	24.6833	-81.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:16:00	\N	0.5	-00:56:00	\N	0.79	\N	\N	Molasses Key Channel, Molasses Keys	FL
105040	Money Key, Florida	NOS	8724082	24.6833	-81.2167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:17:00	\N	0.58	00:03:00	\N	0.58	\N	\N	Money Key	FL
105041	Little Duck Key, east end, Hawk Channel, Florida	NOS	8724093	24.6817	-81.2283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:05:00	\N	0.67	-00:49:00	\N	0.67	\N	\N	Little Duck Key, east end, Hawk Channel	FL
105042	East Bahia Honda Key, south end, Florida Bay, Florida	NOS	8724094	24.775	-81.2267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	02:49:00	\N	0.69	04:04:00	\N	0.69	\N	\N	East Bahia Honda Key, south end, Florida Bay	FL
105043	Cocoanut Key, Florida Bay, Florida	NOS	8724098	24.745	-81.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	02:50:00	\N	0.55	03:52:00	\N	0.55	\N	\N	Cocoanut Key, Florida Bay	FL
105044	Missouri Key-Little Duck Key Channel, Florida	NOS	8724099	24.68	-81.235	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:36:00	\N	0.46	-00:52:00	\N	0.7	\N	\N	Missouri Key-Little Duck Key Channel	FL
105045	Missouri Key-Ohio Key Channel, west side, Florida	NOS	8724107	24.6733	-81.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:22:00	\N	0.5	-00:47:00	\N	0.77	\N	\N	Missouri Key-Ohio Key Channel, west side	FL
105046	Ohio Key-Bahia Honda Key Channel, west side, Florida	NOS	8724112	24.67	-81.2517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:14:00	\N	0.62	-00:57:00	\N	0.81	\N	\N	Ohio Key-Bahia Honda Key Channel, west side	FL
105047	West Bahia Honda Key, Florida	NOS	8724129	24.78	-81.2717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	04:01:00	\N	1	03:59:00	\N	0.97	\N	\N	West Bahia Honda Key	FL
105048	Bahia Honda Key, Bahia Honda Channel, Florida	NOS	8724138	24.655	-81.2817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:28:00	\N	0.63	-00:46:00	\N	0.86	\N	\N	Bahia Honda Key, Bahia Honda Channel	FL
105049	Horseshoe Keys, south end, Florida	NOS	8724139	24.7667	-81.2833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	03:09:00	\N	1	03:54:00	\N	0.86	\N	\N	Horseshoe Keys, south end	FL
105050	Johnson Keys, south end, Florida	NOS	8724153	24.7433	-81.3	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	02:33:00	\N	0.96	03:36:00	\N	0.72	\N	\N	Johnson Keys, south end	FL
105051	Little Pine Key, south end, Florida	NOS	8724154	24.7133	-81.3033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:07:00	\N	0.79	01:07:00	\N	0.56	\N	\N	Little Pine Key, south end	FL
105052	No Name Key, east side, Bahia Honda Channel, Florida	NOS	8724168	24.6983	-81.3183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:33:00	\N	0.83	01:35:00	\N	0.58	\N	\N	No Name Key, east side, Bahia Honda Channel	FL
105053	Johnson Keys, north end, Florida	NOS	8724172	24.7667	-81.3233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	04:22:00	\N	1.38	03:35:00	\N	1.31	\N	\N	Johnson Keys, north end	FL
105054	Little Pine Key, north end, Florida	NOS	8724177	24.75	-81.3283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	03:28:00	\N	1.21	03:38:00	\N	1.05	\N	\N	Little Pine Key, north end	FL
105055	Big Pine Key, Spanish Harbor, Florida	NOS	8724178	24.6483	-81.33	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:03:00	\N	0.42	-00:44:00	\N	0.75	\N	\N	Big Pine Key, Spanish Harbor	FL
105056	Water Key, west end, Big Spanish Channel, Florida	NOS	8724189	24.74	-81.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	02:37:00	\N	1.04	03:23:00	\N	0.81	\N	\N	Water Key, west end, Big Spanish Channel	FL
105057	Big Pine Key, Coupon Bight, Florida	NOS	8724192	24.6517	-81.35	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:49:00	\N	0.5	-00:20:00	\N	0.87	\N	\N	Big Pine Key, Coupon Bight	FL
105058	Big Pine Key, Bogie Channel Bridge, Florida	NOS	8724193	24.6967	-81.3483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	02:11:00	\N	0.83	02:10:00	\N	0.65	\N	\N	Big Pine Key, Bogie Channel Bridge	FL
105059	Porpoise Key, Big Spanish Channel, Florida	NOS	8724196	24.7183	-81.3517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	02:29:00	\N	1	03:23:00	\N	0.72	\N	\N	Porpoise Key, Big Spanish Channel	FL
105060	Crawl Key, Big Spanish Channel, Florida	NOS	8724199	24.7567	-81.3583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	04:13:00	\N	1.33	03:34:00	\N	1.33	\N	\N	Crawl Key, Big Spanish Channel	FL
105061	Big Pine Key, Doctors Arm, Bogie Channel, Florida	NOS	8724201	24.69	-81.3567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:47:00	\N	0.71	00:41:00	\N	0.63	\N	\N	Big Pine Key, Doctors Arm, Bogie Channel	FL
105062	Mayo Key, Big Spanish Channel, Florida	NOS	8724205	24.7333	-81.3617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	03:01:00	\N	1.08	03:35:00	\N	0.92	\N	\N	Mayo Key, Big Spanish Channel	FL
105063	Little Spanish Key, Spanish Banks, Florida	NOS	8724209	24.7733	-81.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	04:30:00	\N	1.62	03:25:00	\N	1.74	\N	\N	Little Spanish Key, Spanish Banks	FL
105064	Big Pine Key, Pine Channel Bridge, north side, Florida	NOS	8724211	24.67	-81.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:43:00	\N	0.33	00:03:00	\N	0.57	\N	\N	Big Pine Key, Pine Channel Bridge, north side	FL
105065	Big Pine Key, Pine Channel Bridge, south side, Florida	NOS	8724213	24.6683	-81.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:03:00	\N	0.33	-00:13:00	\N	0.67	\N	\N	Big Pine Key, Pine Channel Bridge, south side	FL
105066	Big Pine Key, Newfound Harbor Channel, Florida	NOS	8724215	24.6517	-81.375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:44:00	\N	0.46	-00:09:00	\N	0.82	\N	\N	Big Pine Key, Newfound Harbor Channel	FL
105067	Little Torch Key, Pine Channel Bridge, south side, Florida	NOS	8724223	24.665	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:57:00	\N	0.33	-00:15:00	\N	0.68	\N	\N	Little Torch Key, Pine Channel Bridge, south side	FL
105068	Little Torch Key, Pine Channel Bridge, south side, Florida (2)	NOS	8724224	24.665	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:54:00	\N	0.38	-00:13:00	\N	0.69	\N	\N	Little Torch Key, Pine Channel Bridge, south side	FL
105069	Big Pine Key, northeast shore, Florida	NOS	8724226	24.7283	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	02:30:00	\N	1.08	03:19:00	\N	0.86	\N	\N	Big Pine Key, northeast shore	FL
105070	Big Pine Key, west side, Pine Channel, Florida	NOS	8724227	24.69	-81.3833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:52:00	\N	0.42	00:21:00	\N	0.52	\N	\N	Big Pine Key, west side, Pine Channel	FL
105071	Annette Key, north end, Big Spanish Channel, Florida	NOS	8724229	24.7583	-81.39	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	04:33:00	\N	1.29	03:30:00	\N	1.44	\N	\N	Annette Key, north end, Big Spanish Channel	FL
105072	Big Pine Key, north end, Florida	NOS	8724231	24.745	-81.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	05:56:00	\N	0.83	04:24:00	\N	0.96	\N	\N	Big Pine Key, north end	FL
105073	Little Torch Key, Torch Channel, Florida	NOS	8724232	24.665	-81.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:45:00	\N	0.33	00:11:00	\N	0.57	\N	\N	Little Torch Key, Torch Channel	FL
105074	Middle Torch Key, Torch Ramrod Channel, Florida	NOS	8724237	24.6617	-81.4017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:29:00	\N	0.38	-00:16:00	\N	0.69	\N	\N	Middle Torch Key, Torch Ramrod Channel	FL
105075	Munson Island, Newfound Harbor Channel, Florida	NOS	8724238	24.6233	-81.4033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:12:00	\N	0.67	-00:40:00	\N	0.98	\N	\N	Munson Island, Newfound Harbor Channel	FL
105076	Ramrod Key, Newfound Harbor, Florida	NOS	8724239	24.65	-81.4033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:05:00	\N	0.5	-00:41:00	\N	0.9	\N	\N	Ramrod Key, Newfound Harbor	FL
105077	Howe Key, south end, Harbor Channel, Florida	NOS	8724243	24.725	-81.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	04:49:00	\N	0.62	04:43:00	\N	0.72	\N	\N	Howe Key, south end, Harbor Channel	FL
105078	Big Spanish Key, Florida	NOS	8724246	24.7883	-81.4117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	04:29:00	\N	1.5	03:19:00	\N	1.97	\N	\N	Big Spanish Key	FL
105079	Ramrod Key, Niles Channel Bridge, Florida	NOS	8724255	24.66	-81.4233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:12:00	\N	0.46	-00:13:00	\N	0.67	\N	\N	Ramrod Key, Niles Channel Bridge	FL
105080	Howe Key, northwest end, Florida	NOS	8724257	24.7583	-81.4283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	05:22:00	\N	1.33	03:29:00	\N	1.68	\N	\N	Howe Key, northwest end	FL
105081	Big Torch Key, Niles Channel, Florida	NOS	8724264	24.705	-81.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	02:05:00	\N	0.71	03:15:00	\N	0.61	\N	\N	Big Torch Key, Niles Channel	FL
105082	Summerland Key, Niles Channel South, Florida	NOS	8724266	24.6517	-81.435	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:11:00	\N	0.71	-00:36:00	\N	0.85	\N	\N	Summerland Key, Niles Channel South	FL
105083	Summerland Key, Niles Channel Bridge, Florida	NOS	8724267	24.66	-81.4367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:56:00	\N	0.58	-00:10:00	\N	0.67	\N	\N	Summerland Key, Niles Channel Bridge	FL
105084	Water Keys, south end, Harbor Channel, Florida	NOS	8724273	24.7467	-81.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	05:41:00	\N	1	03:42:00	\N	1.52	\N	\N	Water Keys, south end, Harbor Channel	FL
105085	Big Torch Key, Harbor Channel, Florida	NOS	8724274	24.7367	-81.4433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	05:51:00	\N	1.29	03:47:00	\N	1.58	\N	\N	Big Torch Key, Harbor Channel	FL
105086	Summerland Key, southwest side, Kemp Channel, Florida	NOS	8724276	24.65	-81.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:50:00	\N	0.54	-00:26:00	\N	0.81	\N	\N	Summerland Key, southwest side, Kemp Channel	FL
105087	Kemp Channel Viaduct, Florida Keys, Florida	NOS	8724292	24.6617	-81.4683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	02:04:00	\N	0.46	00:47:00	\N	0.58	\N	\N	Kemp Channel Viaduct	FL
105088	Key Lois, southeast end, Florida	NOS	8724293	24.6067	-81.47	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:45:00	\N	0.75	-01:15:00	\N	1.06	\N	\N	Key Lois, southeast end	FL
105089	Knockemdown Key, north end, Florida	NOS	8724302	24.715	-81.4783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	04:54:00	\N	1.21	03:30:00	\N	1.35	\N	\N	Knockemdown Key, north end	FL
105090	Gopher Key, Cudjoe Bay, Florida	NOS	8724306	24.6417	-81.485	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:17:00	\N	0.71	-00:46:00	\N	0.9	\N	\N	Gopher Key, Cudjoe Bay	FL
105091	Content Keys, Content Passage, Florida	NOS	8724307	24.79	-81.4833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	03:49:00	\N	1.83	02:46:00	\N	2.13	\N	\N	Content Keys, Content Passage	FL
105092	Raccoon Key, east side, Florida	NOS	8724311	24.7417	-81.4833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	05:09:00	\N	1.21	03:20:00	\N	1.5	\N	\N	Raccoon Key, east side	FL
105093	Cudjoe Key, Cudjoe Bay, Florida	NOS	8724313	24.66	-81.4917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:41:00	\N	0.71	-00:38:00	\N	0.87	\N	\N	Cudjoe Key, Cudjoe Bay	FL
105094	Sugarloaf Key, Pirates Cove, Florida	NOS	8724326	24.6533	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:41:00	\N	0.75	-00:48:00	\N	0.59	\N	\N	Sugarloaf Key, Pirates Cove	FL
105095	Sugarloaf Key, east side, Tarpon Creek, Florida	NOS	8724327	24.6283	-81.51	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:15:00	\N	0.58	-00:41:00	\N	0.89	\N	\N	Sugarloaf Key, east side, Tarpon Creek	FL
105096	Cudjoe Key, north end, Kemp Channel, Florida	NOS	8724328	24.7	-81.505	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	04:40:00	\N	1.46	03:33:00	\N	1.61	\N	\N	Cudjoe Key, north end, Kemp Channel	FL
105097	Cudjoe Key, Pirates Cove, Florida	NOS	8724332	24.6617	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	02:54:00	\N	0.79	03:50:00	\N	0.77	\N	\N	Cudjoe Key, Pirates Cove	FL
105098	Tarpon Creek, Upper Sugarloaf Sound, Florida	NOS	8724334	24.63	-81.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:17:00	\N	0.38	-00:29:00	\N	0.35	\N	\N	Tarpon Creek	FL
105099	Sugarloaf Key, northeast side, Bow Channel, Florida	NOS	8724347	24.6717	-81.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	03:24:00	\N	0.71	03:47:00	\N	1.01	\N	\N	Sugarloaf Key, northeast side, Bow Channel	FL
105100	Park Channel Bridge, Upper Sugarloaf Sound, Florida	NOS	8724353	24.655	-81.54	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	08:33:00	\N	0.29	05:47:00	\N	0.26	\N	\N	Park Channel Bridge	FL
105101	North Harris Channel, Upper Sugarloaf Sound, Florida	NOS	8724367	24.6533	-81.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	08:04:00	\N	0.25	05:32:00	\N	0.25	\N	\N	North Harris Channel	FL
105102	Sugarloaf Key, north end, Bow Channel, Florida	NOS	8724368	24.6933	-81.555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	05:20:00	\N	0.75	03:37:00	\N	1.29	\N	\N	Sugarloaf Key, north end, Bow Channel	FL
105103	Sawyer Key, inside, Cudjoe Channel, Florida	NOS	8724369	24.7583	-81.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	05:19:00	\N	0.5	02:37:00	\N	1.43	\N	\N	Sawyer Key, inside, Cudjoe Channel	FL
105104	Sawyer Key, outside, Cudjoe Channel, Florida	NOS	8724370	24.7583	-81.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	05:24:00	\N	0.5	02:45:00	\N	1.57	\N	\N	Sawyer Key, outside, Cudjoe Channel	FL
105105	Pumpkin Key, Bow Channel, Florida	NOS	8724373	24.7167	-81.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	04:39:00	\N	1.17	03:17:00	\N	1.56	\N	\N	Pumpkin Key, Bow Channel	FL
105106	Perky, Upper Sugarloaf Sound, Florida	NOS	8724378	24.6483	-81.57	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	08:25:00	\N	0.08	05:37:00	\N	0.28	\N	\N	Perky	FL
105107	Johnston Key, southwest end, Turkey Basin, Florida	NOS	8724397	24.71	-81.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	05:38:00	\N	0.5	03:26:00	\N	1.1	\N	\N	Johnston Key, southwest end, Turkey Basin	FL
105108	Saddlebunch Keys, Channel No. 3, Florida	NOS	8724405	24.6233	-81.6033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:10:00	\N	0.21	01:44:00	\N	0.43	\N	\N	Saddlebunch Keys, Channel No. 3	FL
105109	Snipe Keys, southeast end, Inner Narrows, Florida	NOS	8724409	24.6583	-81.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	05:39:00	\N	0.83	03:25:00	\N	1.28	\N	\N	Snipe Keys, southeast end, Inner Narrows	FL
105110	Saddlebunch Keys, Channel No. 4, Florida	NOS	8724417	24.615	-81.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	05:36:00	\N	0.29	04:35:00	\N	0.54	\N	\N	Saddlebunch Keys, Channel No. 4	FL
105111	Saddlebunch Keys, Similar Sound, Florida	NOS	8724422	24.6	-81.6217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	02:41:00	\N	0.21	00:39:00	\N	0.37	\N	\N	Saddlebunch Keys, Similar Sound	FL
105112	Saddlebunch Keys, Channel No. 5, Florida	NOS	8724423	24.6117	-81.6233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	06:58:00	\N	1.12	04:32:00	\N	0.66	\N	\N	Saddlebunch Keys, Channel No. 5	FL
105113	Snipe Keys, Middle Narrows, Florida	NOS	8724427	24.6667	-81.63	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	05:54:00	\N	0.67	03:44:00	\N	1.02	\N	\N	Snipe Keys, Middle Narrows	FL
105114	Bird Key, Similar Sound, Florida	NOS	8724436	24.5883	-81.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:03:00	\N	0.42	-00:21:00	\N	0.59	\N	\N	Bird Key, Similar Sound	FL
105115	Shark Key, southeast end, Similar Sound, Florida	NOS	8724438	24.6033	-81.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:51:00	\N	0.46	00:18:00	\N	0.52	\N	\N	Shark Key, southeast end, Similar Sound	FL
105116	O'Hara Key, north end, Waltz Key Basin, Florida	NOS	8724441	24.6167	-81.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	05:39:00	\N	0.83	03:53:00	\N	1.03	\N	\N	O'Hara Key, north end, Waltz Key Basin	FL
105117	Waltz Key, Waltz Key Basin, Florida	NOS	8724448	24.6467	-81.6533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	05:33:00	\N	0.96	03:53:00	\N	1.03	\N	\N	Waltz Key, Waltz Key Basin	FL
105118	Rockland Key, Rockland Channel Bridge, Florida	NOS	8724459	24.5917	-81.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	06:06:00	\N	0.88	05:02:00	\N	0.76	\N	\N	Rockland Key, Rockland Channel Bridge	FL
105119	Snipe Keys, Snipe Point, Florida	NOS	8724463	24.6917	-81.6733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	03:33:00	\N	1.29	02:15:00	\N	1.69	\N	\N	Snipe Keys, Snipe Point	FL
105120	Duck Key Point, Duck Key, Waltz Key Basin, Florida	NOS	8724474	24.6233	-81.685	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	04:57:00	\N	0.96	03:27:00	\N	1.19	\N	\N	Duck Key Point, Duck Key, Waltz Key Basin	FL
105121	Boca Chica Key, Long Point, Florida	NOS	8724485	24.6033	-81.6983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	05:22:00	\N	0.71	03:54:00	\N	0.94	\N	\N	Boca Chica Key, Long Point	FL
105122	Big Coppitt Key, northeast side, Waltz Key Basin, Florida	NOS	8724489	24.6017	-81.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	06:54:00	\N	0.33	04:21:00	\N	0.84	\N	\N	Big Coppitt Key, northeast side, Waltz Key Basin	FL
105123	Boca Chica Key, southwest end, Florida	NOS	8724499	24.5633	-81.7133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:16:00	\N	0.63	-00:14:00	\N	0.66	\N	\N	Boca Chica Key, Southwest end	FL
105124	Boca Chica Channel Bridge, Florida	NOS	8724503	24.5767	-81.7217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:29:00	\N	0.67	01:23:00	\N	0.57	\N	\N	Boca Chica Channel Bridge	FL
105125	Channel Key, west side, Florida	NOS	8724507	24.6033	-81.725	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	03:07:00	\N	0.71	03:09:00	\N	0.7	\N	\N	Channel Key, west side	FL
105126	Key Haven - Stock Island Channel, Florida	NOS	8724517	24.58	-81.7383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	02:57:00	\N	0.79	02:25:00	\N	0.73	\N	\N	Key Haven - Stock Island Channel	FL
105127	Cow Key Channel, Florida	NOS	8724527	24.57	-81.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	02:05:00	\N	0.71	01:55:00	\N	0.65	\N	\N	Cow Key Channel	FL
105128	Riviera Canal, Key West, Florida	NOS	8724529	24.565	-81.7517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	01:00:00	\N	0.63	-00:12:00	\N	0.65	\N	\N	Riveria Canal, Key West	FL
105129	Sigsbee Park, Garrison Bight Channel, Florida	NOS	8724542	24.585	-81.775	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	02:06:00	\N	0.88	01:59:00	\N	0.81	\N	\N	Sigsbee Park, Garrison Bight Channel	FL
105130	Key West, south side, White Street Pier, Florida	NOS	8724557	24.545	-81.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	-00:31:00	\N	0.92	-00:53:00	\N	1.07	\N	\N	Key West, south side, White Street Pier	FL
105131	Garden Key, Dry Tortugas, Florida	NOS	8724697	24.6267	-82.8717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103207	00:33:00	\N	1.33	00:29:00	\N	0.94	\N	\N	Garden Key, Dry Tortugas	FL
105132	Shark River entrance, Florida	NOS	8724769	25.345	-81.1267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103217	01:45:00	\N	0.98	00:57:00	\N	1.43	\N	\N	Shark River entrance	FL
105133	Lostmans River entrance, Florida	NOS	8724842	25.5533	-81.2133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103217	01:59:00	\N	0.98	01:09:00	\N	1.33	\N	\N	Lostmans River entrance	FL
105134	Onion Key, Lostmans River, Florida	NOS	8724863	25.6117	-81.1333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103217	04:53:00	\N	0.16	03:09:00	\N	0.26	\N	\N	Onion Key, Lostmans River	FL
105135	Chatham River entrance, Florida	NOS	8724891	25.69	-81.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103217	01:53:00	\N	0.66	00:59:00	\N	1.43	\N	\N	Chatham River entrance	FL
105136	Chokoloskee, Florida	NOS	8724919	25.8133	-81.3633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103217	03:14:00	\N	0.62	02:15:00	\N	1.11	\N	\N	Chokoloskee	FL
105137	Indian Key, Ten Thousand Islands, Florida	NOS	8724932	25.799999237060547	-81.4666976928711	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103217	01:19:00	\N	0.98	00:55:00	\N	1.48	\N	\N	Indian Key	FL
105138	Cape Romano, Florida	NOS	8724947	25.8533	-81.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103217	01:04:00	\N	0.98	00:43:00	\N	1.19	\N	\N	Cape Romano	FL
105139	Everglades City, Barron River, Florida	NOS	8724948	25.8583	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103217	03:26:00	\N	0.57	02:25:00	\N	0.99	\N	\N	Everglades City, Barron River	FL
105140	Cocohatchee River, US 41 bridge, Florida	NOS	8725228	26.2817	-81.8017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103217	01:28:00	\N	0.65	01:10:00	\N	0.74	\N	\N	Cocohatchee River, U.S. 41 bridge	FL
105141	Wiggins Pass, Cocohatchee River, Florida	NOS	8725235	26.29	-81.8183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103217	00:59:00	\N	0.73	00:44:00	\N	0.77	\N	\N	Wiggins Pass, Cocohatchee River	FL
105142	Estero River, Estero Bay, Florida	NOS	8725346	26.43	-81.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-00:10:00	\N	1.11	-00:45:00	\N	1.09	\N	\N	Estero River	FL
105143	Matanzas Pass (fixed bridge) Estero Island, Florida	NOS	8725366	26.4567	-81.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-01:34:00	\N	1.22	-01:10:00	\N	1.22	\N	\N	Matanzas Pass (fixed bridge) Estero Island	FL
105144	Captiva Island (outside), Florida	NOS	8725383	26.4783	-82.1833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-02:28:00	\N	1.13	-02:20:00	\N	1.13	\N	\N	Captiva Island (outside)	FL
105145	Galt Island, Pine Island Sound, Florida	NOS	8725411	26.5133	-82.1067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	00:16:00	\N	0.91	-00:25:00	\N	0.91	\N	\N	Galt Island, Pine Island Sound	FL
105146	Captiva Island, Pine Island Sound, Florida	NOS	8725417	26.5217	-82.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-00:20:00	\N	0.91	-00:46:00	\N	0.91	\N	\N	Captiva Island, Pine Island Sound	FL
105147	Iona Shores, Caloosahatchee River, Florida	NOS	8725418	26.5217	-81.965	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	01:40:00	\N	0.43	01:08:00	\N	0.43	\N	\N	Iona Shores	FL
105148	Tropical Homesites Landing, Pine Island, Florida	NOS	8725439	26.5483	-82.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	00:22:00	\N	0.87	-00:08:00	\N	0.87	\N	\N	Tropical Homesites Landing, Pine Island	FL
105149	Redfish Pass, Captiva Island (north end), Florida	NOS	8725441	26.55	-82.1967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-01:14:00	\N	0.91	-00:55:00	\N	0.91	\N	\N	Redfish Pass, Captiva Island (north end)	FL
105150	Pineland, Pine Island, Florida	NOS	8725528	26.66	-82.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	00:26:00	\N	0.83	-00:19:00	\N	0.83	\N	\N	Pineland, Pine Island	FL
105151	Placida, Gasparilla Sound, Florida	NOS	8725667	26.8333	-82.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-00:56:00	\N	0.94	-00:43:00	\N	0.59	\N	\N	Placida, Gasparilla Sound	FL
105152	Punta Gorda, Charlotte Harbor, Florida	NOS	8725744	26.9283	-82.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	01:27:00	\N	0.83	01:06:00	\N	0.83	\N	\N	Punta Gorda, Charlotte Harbor	FL
105153	Englewood, Lemon Bay, Florida	NOS	8725747	26.9333	-82.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-00:17:00	\N	0.82	-00:17:00	\N	0.66	\N	\N	Englewood, Lemon Bay	FL
105154	El Jobean, Myakka River, Florida	NOS	8725769	26.9617	-82.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	01:56:00	\N	0.83	01:38:00	\N	0.83	\N	\N	El Jobean, Myakka River	FL
105155	Venice Inlet (inside), Florida	NOS	8725889	27.1117	-82.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-01:38:00	\N	0.91	-02:02:00	\N	0.91	\N	\N	Venice Inlet (inside)	FL
105156	Sarasota, Sarasota Bay, Florida	NOS	8726083	27.3317	-82.545	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-00:58:00	\N	0.91	-01:38:00	\N	0.91	\N	\N	Sarasota, Sarasota Bay	FL
105157	Cortez, Sarasota Bay, Florida	NOS	8726217	27.4667	-82.6867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-01:25:00	\N	0.96	-02:00:00	\N	0.96	\N	\N	Cortez, Sarasota Bay	FL
105158	Anna Maria Key, Bradenton Beach, Florida	NOS	8726243	27.4967	-82.7133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-03:32:00	\N	1	-02:27:00	\N	0.99	\N	\N	Anna Maria Key, Bradenton Beach	FL
105159	Bradenton, Manatee River, Florida	NOS	8726247	27.5	-82.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-00:55:00	\N	0.95	-01:24:00	\N	0.97	\N	\N	Bradenton, Manatee River	FL
105160	Redfish Point, Manatee River, Florida	NOS	8726278	27.5267	-82.4817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	00:14:00	\N	1	-00:30:00	\N	0.92	\N	\N	Redfish Point, Manatee River	FL
105161	Anna Maria Key, city pier, Florida	NOS	8726282	27.5333	-82.73	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-02:19:00	\N	0.99	-02:10:00	\N	0.99	\N	\N	Anna Maria Key, city pier	FL
105162	Point Pinellas, Florida	NOS	8726454	27.7017	-82.64	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-00:29:00	\N	0.86	-00:22:00	\N	0.86	\N	\N	Point Pinellas	FL
105163	Shell Point, Florida	NOS	8726468	27.7183	-82.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	00:17:00	\N	0.91	00:08:00	\N	0.91	\N	\N	Shell Point	FL
105164	Gulfport, Boca Ciega Bay, Florida	NOS	8726486	27.7367	-82.7067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-01:05:00	\N	0.96	-01:32:00	\N	0.96	\N	\N	Gulfport	FL
105165	Long Key, 0.5 mi N. of Corey Causeway, Boca Ciega Bay, Florida	NOS	8726494	27.7517	-82.7533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-00:44:00	\N	1	-01:18:00	\N	0.92	\N	\N	Long Key, 0.5mi N. of Corey Causeway	FL
105166	Johns Pass, Boca Ciega Bay, Florida	NOS	8726533	27.785	-82.7817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-02:04:00	\N	1.02	-02:14:00	\N	0.97	\N	\N	Johns Pass	FL
105167	Apollo Beach, Hillsborough Bay, Tampa Bay, Florida	NOS	8726537	27.786699295043945	-82.42669677734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	00:32:00	\N	1.2	00:53:00	\N	1.1	\N	\N	APOLLO BEACH, HILLSBOROUGH BAY	FL
105168	Madeira Beach Causeway, Boca Ciega Bay, Florida	NOS	8726574	27.8083	-82.795	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-01:45:00	\N	1.18	-01:32:00	\N	1.08	\N	\N	Madeira Beach Causeway	FL
105169	Indian Rocks Beach (inside), Florida	NOS	8726625	27.8767	-82.85	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	-00:53:00	\N	0.63	-00:57:00	\N	0.65	\N	\N	Indian Rocks Beach (inside)	FL
105170	Gandy Bridge, Old Tampa Bay, Florida	NOS	8726641	27.8933	-82.5383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	00:57:00	\N	1.24	00:59:00	\N	1.12	\N	\N	Gandy Bridge, Old Tampa Bay	FL
105171	Pendola Point, Hillsborough Bay, Florida	NOS	8726651	27.8983	-82.4267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	00:05:00	\N	1.18	00:21:00	\N	1.14	\N	\N	Pendola Point, Hillsborough Bay	FL
105172	Davis Island, Hillsborough Bay, Florida	NOS	8726657	27.9083	-82.4517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	00:32:00	\N	1.24	00:03:00	\N	1.16	\N	\N	Davis Island, Hillsborough Bay	FL
105173	Bay Aristocrat Village, Old Tampa Bay, Florida	NOS	8726689	27.9417	-82.72	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	01:32:00	\N	1.37	01:01:00	\N	1.24	\N	\N	Bay Aristocrat Village, Old Tampa Bay	FL
105174	Clearwater, Florida	NOS	8726706	27.955	-82.8067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	-01:35:00	\N	0.63	-01:48:00	\N	0.65	\N	\N	Clearwater	FL
105175	Dunedin, St. Joseph Sound, Florida	NOS	8726761	28.0133	-82.7933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	-01:45:00	\N	0.79	-01:50:00	\N	0.7	\N	\N	Dunedin, St. Joseph Sound	FL
105176	Mobbly Bayou, Florida	NOS	8726769	28.0217	-82.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	02:54:00	\N	0.45	02:38:00	\N	0.71	\N	\N	Mobbly Bayou	FL
105177	Tarpon Springs, Anclote River, Florida	NOS	8726905	28.16	-82.7683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	-01:03:00	\N	0.83	-01:16:00	\N	0.77	\N	\N	Tarpon Springs, Anclote River	FL
105178	Anclote, Anclote River, Florida	NOS	8726924	28.1717	-82.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	-01:24:00	\N	0.87	-01:28:00	\N	0.78	\N	\N	Anclote, Anclote River	FL
105179	North Anclote Key, Florida	NOS	8726942	28.21	-82.84	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	-01:38:00	\N	0.86	-01:55:00	\N	0.8	\N	\N	North Anclote Key	FL
105180	Gulf Harbors, Florida	NOS	8726995	28.2433	-82.7633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	-00:52:00	\N	0.9	-01:15:00	\N	0.84	\N	\N	Gulf Harbors	FL
105181	New Port Richey, Pithlachascotee River, Florida	NOS	8727001	28.2483	-82.7233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	-00:11:00	\N	0.87	-00:58:00	\N	0.88	\N	\N	New Port Richey, Pithlachascotee River	FL
105182	Hwy. 19 bridge, Pithlachascotee River, Florida	NOS	8727012	28.2683	-82.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	-00:40:00	\N	0.84	-01:16:00	\N	0.85	\N	\N	Hwy. 19 bridge, Pithlachascotee River	FL
105183	Hudson, Hudson Creek, Florida	NOS	8727061	28.3617	-82.71	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	-01:02:00	\N	0.89	-01:12:00	\N	0.91	\N	\N	Hudson, Hudson Creek	FL
105184	Aripeka, Hammock Creek, Florida	NOS	8727097	28.4333	-82.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	00:23:00	\N	0.63	-00:37:00	\N	0.81	\N	\N	Aripeka, Hammock Creek	FL
105185	Hernando Beach, Rocky Creek, Little Pine I. Bay, Florida	NOS	8727122	28.4867	-82.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	00:58:00	\N	0.83	-00:20:00	\N	0.83	\N	\N	Hernando Beach, Rocky Creek, Little Pine I. Bay	FL
105186	Florida Power, Crystal River, Florida	NOS	8727386	28.96	-82.725	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	00:30:00	\N	0.89	-00:03:00	\N	1.04	\N	\N	Florida Power	FL
105187	Withlacoochee River entrance, Florida	NOS	8727395	29.0017	-82.7583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	00:55:00	\N	0.95	00:07:00	\N	0.91	\N	\N	Withlacoochee River entrance	FL
105188	Suwannee, Salt Creek, Florida	NOS	8727577	29.3283	-83.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	00:24:00	\N	0.83	-00:07:00	\N	0.91	\N	\N	Suwannee, Salt Creek	FL
105189	Steinhatchee River ent., Deadman Bay, Florida	NOS	8727695	29.6717	-83.39	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	00:00:00	\N	1.08	00:02:00	\N	1.03	\N	\N	Steinhatchee River ent., Deadman Bay	FL
105190	Mandalay, Aucilla River, Apalachee Bay, Florida	NOS	8727989	30.1267	-83.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103275	00:57:00	\N	0.55	00:25:00	\N	0.69	\N	\N	Mandalay, Aucilla River	FL
105191	St. Marks, St. Marks River, Apalachee Bay, Florida	NOS	8728142	30.1533	-84.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103275	01:04:00	\N	0.91	00:36:00	\N	0.93	\N	\N	St. Marks, St. Marks River	FL
105192	Bald Point, Ochlockonee Bay, Apalachee Bay, Florida	NOS	8728237	29.9483	-84.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103275	00:19:00	\N	0.7	00:33:00	\N	0.85	\N	\N	Bald Point, Ochlockonee Bay	FL
105193	Alligator Point, St. James Island, Apalachee Bay, Florida	NOS	8728288	29.9033	-84.4133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103275	00:11:00	\N	0.73	-00:08:00	\N	0.75	\N	\N	Alligator Point, St. James Island	FL
105194	Carrabelle, Carrabelle River, St. George Sound, Florida (sub)	NOS	8728464	29.85	-84.665	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103290	-02:13:00	\N	1.6	-01:25:00	\N	1.6	\N	\N	Carrabelle, Carrabelle River	FL
105195	Dog Island, west end, St. George Sound, Florida	NOS	8728465	29.785	-84.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103290	-02:38:00	\N	1.4	-01:53:00	\N	1.73	\N	\N	Dog Island, west end	FL
105196	St. George Island, east end, St. George Sound, Florida	NOS	8728548	29.6867	-84.7867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103290	-02:48:00	\N	1	-02:02:00	\N	1.13	\N	\N	St. George Island, East End	FL
105197	St. George Island, Rattlesnake Cove, St. George Sound, Florida	NOS	8728552	29.6917	-84.7917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103290	-01:35:00	\N	1.2	-01:00:00	\N	1.33	\N	\N	St. George Island, Rattlesnake Cove	FL
105198	St. George Island, 12th St. W (bayside), St. George Sound, Florida (sub)	NOS	8728626	29.6533	-84.8967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103290	-01:08:00	\N	1.26	-00:55:00	\N	1.26	\N	\N	St. George Island, 12th St. W (Bayside)	FL
105199	Apalachicola River (A&N RR bridge), Apalachicola Bay, Florida (sub)	NOS	8728711	29.7633	-85.0333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103290	00:35:00	\N	0.83	00:28:00	\N	0.85	\N	\N	Apalachicola River (A&N RR bridge)	FL
105200	West Pass, Apalachicola Bay, Florida	NOS	8728766	29.6333	-85.0967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103290	-00:27:00	\N	1	-00:27:00	\N	0.87	\N	\N	West Pass	FL
105201	Wetappo Creek, East Bay, St. Andrew Bay, Florida	NOS	8728973	30.0383	-85.3933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103330	01:40:00	\N	1.1	01:01:00	\N	1.1	\N	\N	Wetappo Creek, East Bay	FL
105202	Allanton, East Bay, St. Andrew Bay, Florida	NOS	8729015	30.03	-85.465	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103330	-01:01:00	\N	1.15	-00:16:00	\N	1.15	\N	\N	Allanton, East Bay	FL
105203	Farmdale, East Bay, St. Andrew Bay, Florida	NOS	8729017	30.0167	-85.47	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103330	-00:59:00	\N	1.17	-00:16:00	\N	1.17	\N	\N	Farmdale, East Bay	FL
105204	Laird Bayou, East Bay, St. Andrew Bay, Florida	NOS	8729045	30.1217	-85.5283	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103330	-01:05:00	\N	1.13	-00:28:00	\N	1.13	\N	\N	Laird Bayou, East Bay	FL
105205	Parker, St. Andrew Bay, Florida	NOS	8729084	30.1267	-85.6117	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103330	00:22:00	\N	1.2	-00:05:00	\N	1.2	\N	\N	Parker	FL
105206	Lynn Haven, North Bay, St. Andrew Bay, Florida	NOS	8729102	30.255	-85.6483	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103330	-01:01:00	\N	1.1	-00:31:00	\N	1.1	\N	\N	Lynn Haven, North Bay	FL
105207	Channel entrance, St. Andrew Bay, Florida	NOS	8729136	30.125	-85.73	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103330	-01:50:00	\N	1.02	-01:39:00	\N	1.02	\N	\N	Channel entrance	FL
105208	Alligator Bayou, St. Andrew Bay, Florida	NOS	8729152	30.17	-85.755	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103330	-01:10:00	\N	1.07	-00:47:00	\N	1.07	\N	\N	Alligator Bayou	FL
105209	East Pass (Destin), Choctawhatchee Bay, Florida	NOS	8729511	30.395	-86.5133	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103330	-00:34:00	\N	0.33	-00:33:00	\N	0.49	\N	\N	East Pass (Destin)	FL
105210	Shalimar, Garnier Bayou, Choctawhatchee Bay, Florida	NOS	8729538	30.435	-86.5867	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103330	03:03:00	\N	0.32	03:33:00	\N	0.32	\N	\N	Shalimar, Garnier Bayou	FL
105211	Harris, The Narrows, Florida	NOS	8729613	30.4083	-86.7317	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103330	02:51:00	\N	1.1	01:37:00	\N	1.1	\N	\N	Harris, The Narrows	FL
105212	Bay Point, Blackwater River, Pensacola Bay, Florida	NOS	8729742	30.5717	-87.005	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103330	01:27:00	\N	1.2	01:23:00	\N	1.2	\N	\N	Bay Point, Blackwater River	FL
105213	Warrington, 2 mi south of, Pensacola Bay, Florida	NOS	8729868	30.345	-87.2733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103330	-00:30:00	\N	1	-00:27:00	\N	1	\N	\N	Warrington, 2 miles south of	FL
105214	Fort McRee Breakwater, Pensacola Bay, Florida	NOS	8729887	30.3267	-87.3117	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103330	-00:34:00	\N	0.8	-01:23:00	\N	0.8	\N	\N	Fort McRee Breakwater	FL
105215	Nix Point, Perdido Bay, Florida	NOS	8729962	30.3933	-87.425	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103330	03:37:00	\N	0.33	02:29:00	\N	0.57	\N	\N	Nix Point, Perdido Bay	FL
105216	Bon Secour, Bon Secour River, Alabama	NOS	8731952	30.3033	-87.735	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103348	-01:17:00	\N	1.07	-01:13:00	\N	1.07	\N	\N	Bon Secour, Bon Secour River	AL
105217	Mobile Point (Fort Morgan), Alabama	NOS	8734635	30.2333	-88.02	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103348	-01:32:00	\N	0.8	-01:46:00	\N	0.8	\N	\N	Mobile Point (Fort Morgan)	AL
105218	Lower Hall Landing, Tensaw River, Alabama	NOS	8737182	30.8183	-87.915	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103348	03:05:00	\N	0.87	02:16:00	\N	0.87	\N	\N	Lower Hall Landing, Tensaw River	AL
105219	Bayou La Batre, Mississippi Sound, Alabama	NOS	8739051	30.3717	-88.275	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	01:14:00	\N	1.23	01:52:00	\N	1.23	\N	\N	Bayou La Batre, Mississippi Sound	AL
105220	Point of Pines, Bayou Cumbest, Mississippi	NOS	8740448	30.3867	-88.44	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	01:09:00	\N	1.25	01:49:00	\N	1.25	\N	\N	Point of Pines, Bayou Cumbest	MS
105221	Hollingsworth Point, Davis Bayou, Mississippi (sub)	NOS	8743081	30.3867	-88.7733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	01:52:00	\N	1.42	02:24:00	\N	1.42	\N	\N	Hollingsworth Point, Davis Bayou	MS
105222	Biloxi (Cadet Point), Biloxi Bay, Mississippi (sub)	NOS	8743735	30.39	-88.8567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	01:30:00	\N	1.38	02:04:00	\N	1.38	\N	\N	Biloxi (Cadet Point), Biloxi Bay	MS
105223	Turkey Creek, Bernard Bayou, Mississippi	NOS	8745375	30.4267	-89.0533	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	02:27:00	\N	1.54	03:23:00	\N	1.54	\N	\N	Turkey Creek, Bernard Bayou	MS
105224	Cat Island, Mississippi	NOS	8745799	30.2317	-89.1167	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	02:00:00	\N	1.23	02:13:00	\N	1.23	\N	\N	Cat Island	MS
105225	Pass Christian Yacht Club, Mississippi Sound, Mississippi (sub)	NOS	8746819	30.31	-89.245	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	02:04:00	\N	1.37	02:36:00	\N	1.37	\N	\N	Pass Christian Yacht Club, Mississippi Sound	MS
105226	Wolf River, Henderson Avenue bridge, Mississippi	NOS	8748038	30.358333333332993	-89.27333333333299	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	02:51:00	\N	1.36	03:18:00	\N	1.36	\N	\N	Wolf River, Henderson Avenue bridge	MS
105227	Pearlington, Pearl River, Mississippi	NOS	8749704	30.24	-89.615	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	05:31:00	\N	0.99	05:51:00	\N	0.99	\N	\N	Pearlington, Pearl River	MS
105228	Chandeleur Light, Louisiana	NOS	8760172	30.0483	-88.8717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	01:54:00	\N	0.98	01:50:00	\N	0.98	\N	\N	Chandeleur Light	LA
105229	North Pass, Mississippi River, Louisiana	NOS	8760412	29.205	-89.0367	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	00:43:00	\N	0.91	00:42:00	\N	0.91	\N	\N	North Pass, Pass a Loutre	LA
105230	Southeast Pass, Mississippi River, Louisiana	NOS	8760416	29.1167	-89.045	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	-00:28:00	\N	0.98	00:37:00	\N	0.98	\N	\N	Southeast Pass	LA
105231	Lonesome Bayou (Thomasin), Louisiana	NOS	8760424	29.2283	-89.05	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	-00:29:00	\N	0.9	00:34:00	\N	0.9	\N	\N	Lonesome Bayou (Thomasin)	LA
105232	Port Eads, South Pass, Mississippi River, Louisiana	NOS	8760579	29.015	-89.16	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	-00:17:00	\N	0.9	00:56:00	\N	0.9	\N	\N	Port Eads, South Pass	LA
105233	Breton Islands, Louisiana	NOS	8760595	29.4933	-89.1733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	02:08:00	\N	1.14	02:07:00	\N	1.14	\N	\N	Breton Islands	LA
105234	Joseph Bayou, Mississippi River, Louisiana	NOS	8760736	29.0583	-89.2717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	-00:17:00	\N	1.15	00:37:00	\N	1.15	\N	\N	Joseph Bayou	LA
105235	Comfort Island, Louisiana	NOS	8760742	29.8233	-89.27	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	02:14:00	\N	1.28	02:47:00	\N	1.28	\N	\N	Comfort Island	LA
105236	Jack Bay, Louisiana	NOS	8760841	29.3667	-89.345	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	02:48:00	\N	1	03:12:00	\N	1	\N	\N	Jack Bay	LA
105237	Southwest Pass, Mississippi River, Louisiana	NOS	8760959	28.9317	-89.4283	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	-00:13:00	\N	1.07	00:35:00	\N	1.07	\N	\N	Southwest Pass	LA
105238	Bay Gardene, Louisiana	NOS	8761108	29.5983	-89.6183	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	04:04:00	\N	1.16	04:04:00	\N	1.16	\N	\N	Bay Gardene	LA
105239	Empire Jetty, Louisiana	NOS	8761212	29.25	-89.6083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103400	-01:45:00	\N	1.23	-01:03:00	\N	1.23	\N	\N	Empire Jetty	LA
105240	Bastian Island, Louisiana	NOS	8761289	29.2867	-89.6633	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103400	00:12:00	\N	1.13	00:41:00	\N	1.13	\N	\N	Bastian Island	LA
105241	Bayou BonFouca, Route 433, Louisiana	NOS	8761473	30.2717	-89.7933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	11:31:00	\N	0.43	11:12:00	\N	0.43	\N	\N	Bayou BonFouca, Route 433	LA
105242	Chef Menteur, Chef Menteur Pass, Louisiana	NOS	8761487	30.065	-89.8	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	06:27:00	\N	0.88	06:25:00	\N	0.88	\N	\N	Chef Menteur, Chef Menteur Pass	LA
105243	Quatre Bayous Pass, Louisiana	NOS	8761557	29.31	-89.8533	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103400	00:17:00	\N	1.23	02:18:00	\N	1.23	\N	\N	Quatre Bayous Pass	LA
105244	Independence Island, Barataria Bay, Louisiana	NOS	8761677	29.31	-89.9383	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103400	01:59:00	\N	0.85	02:29:00	\N	0.85	\N	\N	Independence Island	LA
105245	Michoud Substation, ICWW, Louisiana	NOS	8761678	30.0067	-89.9367	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	06:22:00	\N	1.09	06:37:00	\N	1.09	\N	\N	Michoud Substation, ICWW	LA
105246	Barataria Pass, Louisiana	NOS	8761687	29.275	-89.945	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103400	-00:10:00	\N	1.13	01:00:00	\N	1.13	\N	\N	Barataria Pass	LA
105247	Manilla, Barataria Bay, Louisiana	NOS	8761732	29.4267	-89.9767	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103400	03:13:00	\N	0.94	02:32:00	\N	0.94	\N	\N	Manilla	LA
105248	Tchefuncta River, Lake Pontchartrain, Louisiana	NOS	8761993	30.3783	-90.16	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103385	12:21:00	\N	0.48	11:36:00	\N	0.48	\N	\N	Tchefuncta River, Lake Pontchartrain	LA
105249	Pelican Islands, Timbalier Bay, Louisiana	NOS	8762481	29.1283	-90.4233	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103400	02:26:00	\N	1.13	02:26:00	\N	1.13	\N	\N	Pelican Islands, Timbalier Bay	LA
105250	Timbalier Island, Timbalier Bay, Louisiana	NOS	8762675	29.0867	-90.5267	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103400	00:23:00	\N	1.13	00:19:00	\N	1.13	\N	\N	Timbalier Island, Timbalier Bay	LA
105251	Wine Island, Terrebonne Bay, Louisiana	NOS	8762850	29.0783	-90.5867	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103400	01:02:00	\N	1.23	01:08:00	\N	1.23	\N	\N	Wine Island, Terrebonne Bay	LA
105252	Caillou Boca, Louisiana	NOS	8763206	29.0633	-90.8067	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103400	00:48:00	\N	1.32	00:40:00	\N	1.32	\N	\N	Caillou Boca	LA
105253	Raccoon Point, Caillou Bay, Louisiana	NOS	8763506	29.0633	-90.9617	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103400	-00:20:00	\N	1.6	-00:03:00	\N	1.6	\N	\N	Raccoon Point, Caillou Bay	LA
105254	Ship Shoal Light, Louisiana	NOS	8763719	28.915	-91.0717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103400	-01:50:00	\N	1.51	-01:54:00	\N	1.51	\N	\N	Ship Shoal Light	LA
105255	Shell Island, Atchafalaya Bay, Louisiana	NOS	8764165	29.4733	-91.305	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103468	-00:39:00	\N	1.07	00:54:00	\N	1.07	\N	\N	Shell Island	LA
105256	Point Au Fer, Atchafalaya Bay, Louisiana	NOS	8764256	29.3333	-91.3533	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103468	-02:26:00	\N	1.4	-00:21:00	\N	1.4	\N	\N	Point Au Fer	LA
105257	Point Chevreuil, Atchafalaya Bay, Louisiana	NOS	8764634	29.5183	-91.555	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103468	-00:54:00	\N	1.07	01:02:00	\N	1.07	\N	\N	Point Chevreuil	LA
105258	Rabbit Island, 5 mi south of, Atchafalaya Bay, Louisiana	NOS	8764706	29.42	-91.5933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103468	-02:00:00	\N	1.4	-00:13:00	\N	1.4	\N	\N	Rabbit Island, 5 miles south of	LA
105259	Cote Blanche Island, West Cote Blanche Bay, Louisiana	NOS	8764931	29.735	-91.7133	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103468	02:16:00	\N	1	02:19:00	\N	1	\N	\N	Cote Blanche Island, West Cote Blanche Bay	LA
105260	South Point, Marsh Island, Louisiana	NOS	8765026	29.485	-91.7633	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103468	-01:57:00	\N	1.3	-00:19:00	\N	1.3	\N	\N	South Point, Marsh Island	LA
105261	Southwest Pass, Vermilion Bay, Louisiana	NOS	8765551	29.58	-92.035	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103468	-00:33:00	\N	1.14	-00:32:00	\N	1.14	\N	\N	Southwest Pass, Vermilion Bay	LA
105262	Lighthouse Point, off Marsh Island, Louisiana	NOS	8765568	29.5233	-92.0433	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103468	-02:17:00	\N	1.4	-01:16:00	\N	1.4	\N	\N	Lighthouse Point	LA
105263	Point Barrow, Trinity Bay, Galveston Bay, Texas	NOS	8770557	29.74	-94.8317	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103468	04:43:00	\N	0.79	05:48:00	\N	0.79	\N	\N	Point Barrow, Trinity Bay	TX
105264	Alligator Point, West Bay, Texas	NOS	8771801	29.1667	-95.125	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103468	02:33:00	\N	0.64	02:39:00	\N	0.64	\N	\N	Alligator Point, West Bay	TX
105266	Queen Isabella Causeway (east end), Texas	NOS	8779724	26.0783	-97.17	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103508	00:21:00	\N	0.75	00:24:00	\N	0.87	\N	\N	Queen Isabella Causeway (east end)	TX
105267	Queen Isabella Causeway (west end), Texas	NOS	8779739	26.0717	-97.1917	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103508	00:30:00	\N	0.63	00:52:00	\N	0.81	\N	\N	Queen Isabella Causeway (west end)	TX
105268	South Bay entrance, Texas	NOS	8779768	26.0517	-97.1817	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103508	00:21:00	\N	0.94	00:14:00	\N	0.91	\N	\N	South Bay entrance	TX
105269	San Nicolas Island, California	NOS	9410068	33.2667	-119.497	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	00:21:00	\N	0.88	00:10:00	\N	0.88	\N	\N	San Nicolas Island	CA
105270	Catalina Harbor, Santa Catalina Island, California	NOS	9410092	33.4317	-118.503	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	00:17:00	\N	0.94	00:11:00	\N	0.94	\N	\N	Catalina Harbor, Santa Catalina Island	CA
105271	Imperial Beach, California	NOS	9410120	32.5783	-117.135	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103515	-00:03:00	\N	0.96	00:00:00	\N	0.93	\N	\N	Imperial Beach	CA
105272	National City, San Diego Bay, California	NOS	9410152	32.665	-117.118	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103515	00:10:00	0	\N	00:04:00	0.2	\N	\N	\N	National City, San Diego Bay	CA
105273	San Diego, Quarantine Station, California	NOS	9410166	32.7033	-117.235	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103515	00:02:00	\N	0.96	-00:04:00	\N	0.96	\N	\N	San Diego, Quarantine Station	CA
105274	Balboa Pier, Newport Beach, California	NOS	9410583	33.6	-117.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	00:00:00	\N	0.96	-00:09:00	\N	0.96	\N	\N	Balboa Pier, Newport Beach	CA
105275	Santa Ana River entrance (inside), California	NOS	9410599	33.63	-117.958	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	01:47:00	\N	0.2	00:23:00	\N	0.54	\N	\N	Santa Ana River entrance (inside)	CA
105276	Cabrillo Beach, California	NOS	9410650	33.7067	-118.273	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	00:00:00	\N	1	00:00:00	\N	1	\N	\N	Cabrillo Beach	CA
105277	Long Beach, Inner Harbor, California	NOS	9410686	33.7717	-118.21	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	00:05:00	\N	0.96	00:04:00	\N	0.96	\N	\N	Long Beach, Inner Harbor	CA
105278	King Harbor, Santa Monica Bay, California	NOS	9410738	33.8467	-118.398	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	00:07:00	\N	1	00:08:00	\N	0.96	\N	\N	King Harbor, Santa Monica Bay	CA
105279	El Segundo, Santa Monica Bay, California	NOS	9410777	33.9083	-118.433	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	00:13:00	\N	0.96	00:13:00	\N	0.96	\N	\N	El Segundo, Santa Monica Bay	CA
105280	Bechers Bay, Santa Rosa Island, California	NOS	9410962	34.0083	-120.047	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	00:27:00	\N	1.03	00:27:00	\N	0.93	\N	\N	Bechers Bay, Santa Rosa Island	CA
105281	Prisoners Harbor, Santa Cruz Island, California	NOS	9410971	34.02	-119.683	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	00:18:00	\N	1.01	00:19:00	\N	0.94	\N	\N	Prisoners Harbor, Santa Cruz Island	CA
105282	Cuyler Harbor, San Miguel Island, California	NOS	9410988	34.0567	-120.355	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	00:34:00	\N	0.94	00:33:00	\N	0.94	\N	\N	Cuyler Harbor, San Miguel Island	CA
105283	Port Hueneme, California	NOS	9411065	34.1483	-119.203	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	00:13:00	0	\N	00:10:00	-0.1	\N	\N	\N	Port Hueneme	CA
105284	Ventura, California	NOS	9411189	34.2667	-119.283	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	00:16:00	0	\N	00:09:00	-0.1	\N	\N	\N	Ventura	CA
105285	Rincon Island, Mussel Shoals, Santa Barbara Channel, California (sub)	NOS	9411270	34.3483	-119.443	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	00:18:00	\N	1.05	00:20:00	\N	0.99	\N	\N	Rincon Island, Mussel Shoals	CA
105286	San Simeon, California	NOS	9412553	35.6417	-121.188	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103526	00:07:00	\N	1	00:08:00	\N	0.99	\N	\N	San Simeon	CA
105287	Carmel Cove, Carmel Bay, California	NOS	9413375	36.52	-121.94	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103528	-00:04:00	\N	0.99	-00:03:00	\N	0.97	\N	\N	Carmel Cove, Carmel Bay	CA
105288	Ocean Pier, Moss Landing, Monterey Bay, California	NOS	9413616	36.8017	-121.79	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103528	-00:01:00	\N	0.9	-00:01:00	\N	0.95	\N	\N	Moss Landing, Ocean Pier	CA
105289	General Fish Company Pier, Moss Landing, Monterey Bay, California	NOS	9413617	36.8017	-121.787	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103528	00:01:00	\N	0.95	00:01:00	\N	0.98	\N	\N	General Fish Company Pier	CA
105290	Elkhorn Slough, Highway 1 Bridge, Monterey Bay, California	NOS	9413623	36.81	-121.785	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103528	-00:02:00	\N	0.9	00:03:00	\N	0.95	\N	\N	Elkhorn Slough, Highway 1 Bridge	CA
105291	Pacific Mariculture Dock, Monterey Bay, California	NOS	9413624	36.8133	-121.758	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103528	00:07:00	\N	0.98	00:15:00	\N	1	\N	\N	Pacific Mariculture Dock	CA
105292	Elkhorn Yacht Club, Monterey Bay, California	NOS	9413626	36.8133	-121.787	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103528	00:02:00	\N	0.95	00:00:00	\N	0.97	\N	\N	Elkhorn Yacht Club	CA
105293	Santa Cruz, Monterey Bay, California	NOS	9413745	36.9583	-122.017	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103528	-00:11:00	\N	0.99	-00:06:00	\N	0.97	\N	\N	Santa Cruz, Monterey Bay	CA
105294	Ano Nuevo Island, California	NOS	9413878	37.1083	-122.338	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	-01:04:00	-0.1	\N	-01:24:00	-0.7	\N	\N	\N	Ano Nuevo Island	CA
105295	Southeast Farallon Island, California	NOS	9414262	37.7	-123	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	-00:19:00	0	\N	-00:39:00	-0.3	\N	\N	\N	Southeast Farallon Island	CA
105296	Ocean Beach, outer coast, California	NOS	9414275	37.775	-122.513	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	-00:35:00	0	\N	-00:49:00	0.1	\N	\N	\N	Ocean Beach, outer coast	CA
105297	North Point, Pier 41, San Francisco, San Francisco Bay, California (sub)	NOS	9414305	37.81	-122.413	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:11:00	0	\N	00:13:00	0.2	\N	\N	\N	San Francisco, North Point, Pier 41	CA
105298	Potrero Point, San Francisco Bay, California	NOS	9414334	37.7583	-122.383	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:46:00	0	\N	00:33:00	0.5	\N	\N	\N	Potrero Point	CA
105299	Borden Highway Bridge, San Joaquin River, California	NOS	9414367	37.93666666666701	-121.33333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	04:48:00	\N	0.64	04:28:00	\N	0.78	\N	\N	Borden Highway Bridge, San Joaquin River	CA
105300	South San Francisco, San Francisco Bay, California	NOS	9414391	37.6667	-122.39	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:56:00	0	\N	00:38:00	1.2	\N	\N	\N	South San Francisco	CA
105301	Oyster Point Marina, San Francisco Bay, California (sub)	NOS	9414392	37.665	-122.377	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:00:00	\N	1	00:41:00	\N	1.23	\N	\N	Oyster Point Marina	CA
105302	Point San Bruno, San Francisco Bay, California	NOS	9414402	37.65	-122.377	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:10:00	0.1	\N	00:38:00	1.1	\N	\N	\N	Point San Bruno	CA
105303	Seaplane Harbor, San Francisco Bay, California	NOS	9414413	37.6367	-122.383	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:03:00	0	\N	00:42:00	1.4	\N	\N	\N	Seaplane Harbor	CA
105304	Coyote Point Marina, San Francisco Bay, California	NOS	9414449	37.5917	-122.313	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:08:00	\N	1.01	00:42:00	\N	1.29	\N	\N	Coyote Point Marina	CA
105305	Bay Slough, west end, San Francisco Bay, California	NOS	9414483	37.5517	-122.243	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:28:00	\N	1	00:48:00	\N	1.35	\N	\N	Bay Slough, west end	CA
105306	Bay Slough, east end, San Francisco Bay, California	NOS	9414486	37.545	-122.222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:52:00	\N	0.77	00:49:00	\N	1.27	\N	\N	Bay Slough, east end	CA
105307	Redwood Creek Marker 8, San Francisco Bay, California (sub)	NOS	9414501	37.5333	-122.193	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:28:00	\N	1.05	00:53:00	\N	1.41	\N	\N	Redwood Creek Marker 8	CA
105308	Corkscrew Slough, San Francisco Bay, California	NOS	9414505	37.5083	-122.21	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:42:00	0.1	\N	01:03:00	2.2	\N	\N	\N	Corkscrew Slough	CA
105309	Newark Slough, San Francisco Bay, California	NOS	9414506	37.5133	-122.08	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:58:00	0.1	\N	01:11:00	2.6	\N	\N	\N	Newark Slough	CA
105310	West Point Slough, San Francisco Bay, California	NOS	9414507	37.505	-122.192	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:30:00	\N	1.04	00:56:00	\N	1.44	\N	\N	West Point Slough	CA
105311	Smith Slough, San Francisco Bay, California	NOS	9414511	37.5017	-122.223	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:58:00	0	\N	01:15:00	2.1	\N	\N	\N	Smith Slough	CA
105312	Granite Rock, Redwood Creek, San Francisco Bay, California	NOS	9414513	37.495	-122.213	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:31:00	\N	1.04	00:55:00	\N	1.43	\N	\N	Granite Rock, Redwood Creek	CA
105313	Mowry Slough, San Francisco Bay, California	NOS	9414519	37.4933	-122.042	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	02:07:00	0	\N	01:12:00	2.6	\N	\N	\N	Mowry Slough	CA
105314	Palo Alto Yacht Harbor, San Francisco Bay, California	NOS	9414525	37.4583	-122.105	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	02:14:00	\N	0.68	00:59:00	\N	1.34	\N	\N	Palo Alto Yacht Harbor	CA
105315	Calaveras Point, west of, San Francisco Bay, California	NOS	9414539	37.4667	-122.067	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:49:00	0.1	\N	01:05:00	2.8	\N	\N	\N	Calaveras Point, west of	CA
105316	Upper Guadalupe Slough, San Francisco Bay, California	NOS	9414549	37.435	-122.007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	02:13:00	\N	1.13	01:14:00	\N	1.66	\N	\N	Upper Guadalupe Slough	CA
105317	Gold Street Bridge, Alviso Slough, San Francisco Bay, California	NOS	9414551	37.4233	-121.975	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	02:21:00	\N	0.96	01:03:00	\N	1.67	\N	\N	Gold Street Bridge, Alviso Slough	CA
105318	Coyote Creek, Tributary No. 1, San Francisco Bay, California	NOS	9414561	37.4467	-121.963	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	02:45:00	-0.3	\N	01:21:00	2.6	\N	\N	\N	Coyote Creek, Tributary no.1	CA
105319	South Bay Wreck, San Francisco Bay, California	NOS	9414609	37.5517	-122.162	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:37:00	0.1	\N	01:02:00	2.2	\N	\N	\N	South Bay Wreck	CA
105320	Coyote Hills Slough entrance, San Francisco Bay, California	NOS	9414621	37.5633	-122.128	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	02:21:00	\N	0.45	00:52:00	\N	1.17	\N	\N	Coyote Hills Slough entrance	CA
105321	Alameda Creek, San Francisco Bay, California	NOS	9414632	37.595	-122.145	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	02:25:00	\N	0.27	00:57:00	\N	1.05	\N	\N	Alameda Creek	CA
105322	San Mateo Bridge (east end), San Francisco Bay, California	NOS	9414637	37.6083	-122.182	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:19:00	0	\N	00:48:00	1.8	\N	\N	\N	San Mateo Bridge (east end)	CA
105323	Oakland Airport, San Francisco Bay, California	NOS	9414711	37.7317	-122.208	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:45:00	\N	0.96	00:40:00	\N	1.15	\N	\N	Oakland Airport	CA
105324	San Leandro Channel, San Leandro Bay, San Francisco Bay, California	NOS	9414724	37.7483	-122.235	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:52:00	\N	0.98	00:42:00	\N	1.16	\N	\N	San Leandro Channel, San Leandro Bay	CA
105325	Oakland Berth 67, San Francisco Bay, California	NOS	9414763	37.795	-122.283	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:42:00	0	\N	00:33:00	0.4	\N	\N	\N	Oakland Harbor, Grove Street	CA
105326	Oakland Pier, San Francisco Bay, California	NOS	9414765	37.795	-122.33	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:48:00	0	\N	00:33:00	0.2	\N	\N	\N	Oakland Pier	CA
105327	Alameda Naval Air Station fuel pier, San Francisco Bay, California (sub)	NOS	9414767	37.7933	-122.315	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:33:00	\N	1	00:24:00	\N	1.11	\N	\N	Alameda Naval Air Station	CA
105328	Oakland Middle Harbor, San Francisco Bay, California	NOS	9414777	37.805	-122.338	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:31:00	\N	0.96	00:21:00	\N	1.07	\N	\N	Oakland Middle Harbor	CA
105329	Oakland, Matson Wharf, San Francisco Bay, California	NOS	9414779	37.81	-122.327	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:36:00	0	\N	00:28:00	0.3	\N	\N	\N	Oakland, Matson Wharf	CA
105330	Yerba Buena Island, San Francisco Bay, California	NOS	9414782	37.81	-122.36	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:33:00	\N	0.99	00:25:00	\N	1.06	\N	\N	Yerba Buena Island	CA
105331	Grant Line Canal (drawbridge), San Joaquin River, California	NOS	9414785	37.82	-121.447	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	06:20:00	\N	0.68	06:14:00	\N	0.76	\N	\N	Grant Line Canal (drawbridge)	CA
105332	Alcatraz Island, San Francisco Bay, California	NOS	9414792	37.8267	-122.417	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:18:00	0	\N	00:14:00	0	\N	\N	\N	Alcatraz Island	CA
105333	Sausalito, San Francisco Bay, California (sub)	NOS	9414806	37.8467	-122.477	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:14:00	\N	1	00:10:00	\N	0.97	\N	\N	Sausalito	CA
105334	Angel Island (west side), San Francisco Bay, California	NOS	9414817	37.86	-122.443	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:21:00	0	\N	00:13:00	-0.2	\N	\N	\N	Angel Island (west side)	CA
105335	Angel Island, East Garrison, San Francisco Bay, California	NOS	9414818	37.8633	-122.42	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:20:00	\N	1.04	00:16:00	\N	1.02	\N	\N	Angel Island, East Garrison	CA
105336	Sausalito, Corps of Engineers Dock, San Francisco Bay, California (sub)	NOS	9414819	37.865	-122.493	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:21:00	\N	1	00:10:00	\N	0.98	\N	\N	Sausalito, Corps of Engineers Dock	CA
105337	Borden Highway Bridge, Middle River, San Joaquin River, California	NOS	9414835	37.8917	-121.488	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	04:54:00	\N	0.62	04:50:00	\N	0.67	\N	\N	Borden Highway Bridge, Middle River	CA
105338	Borden Highway Bridge, Old River, San Joaquin River, California	NOS	9414836	37.8833	-121.577	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	04:35:00	\N	0.61	04:40:00	\N	0.64	\N	\N	Borden Highway Bridge, Old River	CA
105339	Point Chauncey, San Francisco Bay, California	NOS	9414837	37.8917	-122.443	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:32:00	\N	0.96	00:28:00	\N	0.98	\N	\N	Point Chauncey	CA
105340	Point Isabel, San Francisco Bay, California	NOS	9414843	37.8983	-122.32	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:33:00	0	\N	00:23:00	0.1	\N	\N	\N	Point Isabel	CA
105341	Richmond Inner Harbor, San Francisco Bay, California	NOS	9414849	37.91	-122.358	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:30:00	\N	0.98	00:16:00	\N	1.04	\N	\N	Richmond Inner Harbor	CA
105342	Holt, Whiskey Slough, San Joaquin River, California	NOS	9414866	37.935	-121.435	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	04:39:00	\N	0.68	04:18:00	\N	0.8	\N	\N	Holt, Whiskey Slough	CA
105343	Orwood, Old River, San Joaquin River, California	NOS	9414868	37.9383	-121.56	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	04:33:00	\N	0.68	04:32:00	\N	0.76	\N	\N	Orwood, Old River	CA
105344	Point San Quentin, San Francisco Bay, California	NOS	9414873	37.945	-122.475	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:50:00	\N	0.93	00:42:00	\N	0.99	\N	\N	Point San Quentin	CA
105345	Point Orient, San Francisco Bay, California	NOS	9414881	37.9583	-122.425	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:52:00	\N	0.96	00:50:00	\N	1.03	\N	\N	Point Orient	CA
105346	Stockton, San Joaquin River, California	NOS	9414883	37.9583	-121.29	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	04:33:00	\N	0.66	04:06:00	\N	0.81	\N	\N	Stockton	CA
105347	Point Bonita, Bonita Cove, San Francisco Bay, California	NOS	9414906	37.8183	-122.528	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	-00:10:00	0	\N	-00:17:00	0.3	\N	\N	\N	Point Bonita, Bonita Cove	CA
105348	Point San Pedro, San Pablo Bay, California	NOS	9415009	37.9933	-122.447	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:07:00	\N	0.92	01:02:00	\N	1.01	\N	\N	Point San Pedro	CA
105349	Gallinas, Gallinas Creek, San Pablo Bay, California	NOS	9415052	38.015	-122.503	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:25:00	\N	0.89	01:18:00	\N	1.02	\N	\N	Gallinas, Gallinas Creek	CA
105350	Davis Slough, San Joaquin River, California	NOS	9415053	38.0117	-121.638	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	02:46:00	\N	0.72	02:33:00	\N	0.68	\N	\N	Dutch Slough	CA
105351	Hercules, Refugio Landing, San Pablo Bay, California	NOS	9415074	38.0233	-122.292	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:39:00	\N	0.85	01:15:00	\N	1.05	\N	\N	Hercules, Refugio Landing	CA
105352	Irish Landing, Sand Mound Slough, San Joaquin River, California	NOS	9415095	38.0333	-121.583	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	03:34:00	\N	0.68	03:29:00	\N	0.73	\N	\N	Irish Landing, Sand Mound Slough	CA
105353	Pittsburg, New York Slough, Suisun Bay, California	NOS	9415096	38.0367	-121.88	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	01:05:00	\N	0.84	00:59:00	\N	0.83	\N	\N	Pittsburg, New York Slough	CA
105354	Benicia, California	NOS	9415111	38.0433	-122.13	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	-00:33:00	\N	1.18	-00:24:00	\N	1.09	\N	\N	Benicia	CA
105355	Bishop Cut, Disappointment Slough, San Joaquin River, California	NOS	9415117	38.045	-121.42	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	04:12:00	\N	0.66	04:12:00	\N	0.79	\N	\N	Bishop Cut, Disappointment Slough	CA
105356	Selby, California	NOS	9415142	38.0583	-122.243	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	02:04:00	0	\N	01:29:00	0.6	\N	\N	\N	Selby	CA
105357	False River, San Joaquin River, California	NOS	9415145	38.055	-121.657	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	02:45:00	\N	0.64	02:45:00	\N	0.66	\N	\N	False River	CA
105358	Prisoners Point, San Joaquin River, California	NOS	9415149	38.0617	-121.555	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	03:29:00	\N	0.69	03:25:00	\N	0.73	\N	\N	Prisoners Point	CA
105359	Vallejo, Mare Island Strait, California	NOS	9415165	38.1117	-122.273	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	02:12:00	\N	0.84	01:47:00	\N	1.02	\N	\N	Vallejo, Mare Island Strait	CA
105360	Collinsville, Sacramento River, California	NOS	9415176	38.0733	-121.848	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	01:20:00	\N	0.8	01:11:00	\N	0.8	\N	\N	Collinsville	CA
105361	Montezuma Slough, Suisun Bay, California	NOS	9415205	38.0767	-121.885	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	01:27:00	\N	0.82	01:16:00	\N	0.84	\N	\N	Montezuma Slough	CA
105362	Point Buckler, Suisun Bay, California	NOS	9415227	38.1	-122.033	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	00:22:00	\N	1.08	00:13:00	\N	1.12	\N	\N	Point Buckler	CA
105363	Inverness, Tomales Bay, California	NOS	9415228	38.1133	-122.868	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:08:00	\N	0.91	00:29:00	\N	0.94	\N	\N	Inverness, Tomales Bay	CA
105364	Threemile Slough, Sacramento River, California	NOS	9415236	38.1067	-121.7	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	01:58:00	\N	0.78	01:49:00	\N	0.82	\N	\N	Threemile Slough	CA
105365	Petaluma River entrance, San Pablo Bay, California (sub)	NOS	9415252	38.11530555555556	-122.5056666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	02:08:00	\N	0.86	01:23:00	\N	1.06	\N	\N	Petaluma River entrance	CA
105366	Terminous, South Fork, Mokelumne River, California	NOS	9415257	38.11	-121.498	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	04:11:00	\N	0.59	03:53:00	\N	0.7	\N	\N	Terminous, South Fork	CA
105367	Pierce Harbor, Goodyear Slough, Suisun Bay, California	NOS	9415266	38.1267	-122.1	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	00:41:00	\N	0.96	00:27:00	\N	1	\N	\N	Pierce Harbor, Goodyear Slough	CA
105368	Georgiana Slough entrance, Mokelumne River, California	NOS	9415287	38.125	-121.578	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	03:41:00	\N	0.59	03:29:00	\N	0.67	\N	\N	Georgiana Slough entrance	CA
105369	Meins Landing, Montezuma Slough, Suisun Bay, California	NOS	9415307	38.1367	-121.907	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	01:11:00	\N	0.93	00:57:00	\N	1.01	\N	\N	Meins Landing, Montezuma Slough	CA
105370	Reynolds, Tomales Bay, California	NOS	9415320	38.1467	-122.883	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:59:00	\N	0.83	00:26:00	\N	0.89	\N	\N	Reynolds, Tomales Bay	CA
105371	Marshall, Tomales Bay, California	NOS	9415339	38.1617	-122.893	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:16:00	-0.1	\N	00:38:00	-0.6	\N	\N	\N	Marshall, Tomales Bay	CA
105372	Hog Island, San Antonio Creek, San Pablo Bay, California	NOS	9415344	38.1617	-122.55	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	02:36:00	\N	0.79	01:47:00	\N	1.07	\N	\N	Hog Island, San Antonio Creek	CA
105373	Joice Island, Suisun Slough, Suisun Bay, California	NOS	9415379	38.18	-122.045	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	00:41:00	\N	1	00:21:00	\N	1.07	\N	\N	Joice Island, Suisun Slough	CA
105374	Blakes Landing, Tomales Bay, California	NOS	9415396	38.19	-122.917	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:15:00	\N	0.79	00:32:00	\N	0.86	\N	\N	Blakes Landing, Tomales Bay	CA
105375	Montezuma Slough Bridge, Suisun Bay, California	NOS	9415402	38.1867	-121.98	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	00:46:00	\N	0.95	00:37:00	\N	1.01	\N	\N	Montezuma Slough Bridge	CA
105376	Steamboat Slough, Snug Harbor Marina, Sacramento River, California	NOS	9415414	38.1833	-121.655	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	02:48:00	\N	0.65	02:24:00	\N	0.8	\N	\N	Steamboat Slough, Snug Harbor Marina	CA
105889	Shonian Harbor, Palau	NOS	TPT2631	7.050000190734863	134.26669311523438	:Pacific/Palau	Palau	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102712	-00:13:00	\N	1	00:07:00	\N	0.89	\N	\N	Shonian Harbor	PW
105377	Edgerley Island, Napa River, California	NOS	9415415	38.1917	-122.312	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	02:29:00	\N	0.76	02:02:00	\N	1.06	\N	\N	Edgerley Island, Napa River	CA
105378	Brazos Drawbridge, Napa River, California	NOS	9415446	38.21	-122.307	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	02:29:00	\N	0.86	02:02:00	\N	1.14	\N	\N	Brazos Drawbridge, Napa River	CA
105379	Wingo, Sonoma Creek, San Pablo Bay, California	NOS	9415447	38.21	-122.427	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	03:11:00	-0.3	\N	02:12:00	0.1	\N	\N	\N	Wingo, Sonoma Creek	CA
105380	Tomales Bay entrance, California	NOS	9415469	38.2283	-122.977	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	00:20:00	\N	0.91	-00:12:00	\N	0.87	\N	\N	Tomales Bay entrance	CA
105381	New Hope Bridge, Mokelumne River, California	NOS	9415478	38.2267	-121.49	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	04:56:00	\N	0.68	04:22:00	\N	0.73	\N	\N	New Hope Bridge	CA
105382	Suisun City, Suisun Slough, Suisun Bay, California	NOS	9415498	38.2367	-122.03	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	01:01:00	\N	1	00:36:00	\N	1.11	\N	\N	Suisun City, Suisun Slough	CA
105383	Snodgrass Slough, Sacramento River, California	NOS	9415565	38.2767	-121.495	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	05:36:00	\N	0.39	05:00:00	\N	0.49	\N	\N	Snodgrass Slough	CA
105384	Upper drawbridge, Petaluma River, San Pablo Bay, California (sub)	NOS	9415584	38.2283	-122.613	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	02:59:00	\N	0.82	02:11:00	\N	1.15	\N	\N	Upper drawbridge, Petaluma River	CA
105385	Napa, Napa River, California	NOS	9415623	38.2983	-122.28	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	02:37:00	\N	0.9	02:05:00	\N	1.22	\N	\N	Napa, Napa River	CA
105386	Bodega Harbor entrance, California	NOS	9415625	38.3083	-123.055	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	-00:16:00	0.1	\N	-00:38:00	-0.2	\N	\N	\N	Bodega Harbor entrance	CA
105387	Clarksburg, Sacramento River, California	NOS	9415846	38.4167	-121.523	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	05:02:00	\N	0.41	03:58:00	\N	0.6	\N	\N	Clarksburg	CA
105388	Fort Ross, California	NOS	9416024	38.5133	-123.245	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	-00:30:00	\N	0.96	-00:51:00	\N	0.96	\N	\N	Fort Ross	CA
105389	Sacramento, Sacramento River, California	NOS	9416174	38.58	-121.507	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103564	06:32:00	\N	0.41	05:07:00	\N	0.6	\N	\N	Sacramento	CA
105390	Westport, California	NOS	9417624	39.6333	-123.783	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103575	00:00:00	\N	0.95	00:14:00	\N	0.98	\N	\N	Westport	CA
105391	Hookton Slough, Humboldt Bay, California	NOS	9418686	40.6867	-124.222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103580	00:15:00	\N	0.98	00:06:00	\N	1.01	\N	\N	Hookton Slough	CA
105392	Elk River Railroad Bridge, Humboldt Bay, California	NOS	9418757	40.7567	-124.193	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103580	01:32:00	\N	0.31	00:19:00	\N	0.71	\N	\N	Elk River Railroad Bridge	CA
105393	Bucksport, Humboldt Bay, California	NOS	9418778	40.7783	-124.197	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103580	00:16:00	\N	1	00:17:00	\N	1.01	\N	\N	Bucksport	CA
105394	Eureka, Humboldt Bay, California	NOS	9418801	40.8067	-124.167	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103580	00:13:00	\N	1.03	00:26:00	\N	1.06	\N	\N	Eureka	CA
105395	Eureka Slough Bridge, Humboldt Bay, California	NOS	9418802	40.8067	-124.142	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103580	00:19:00	\N	1.02	00:33:00	\N	1.08	\N	\N	Eureka Slough Bridge	CA
105396	Arcata Wharf, Humboldt Bay, California	NOS	9418851	40.85	-124.117	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103580	00:54:00	0.1	\N	00:48:00	0.1	\N	\N	\N	Arcata Wharf	CA
105397	Mad River Slough, Arcata Bay, Humboldt Bay, California	NOS	9418865	40.865	-124.148	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103580	00:35:00	\N	1.07	00:43:00	\N	1.12	\N	\N	Mad River Slough, Arcata Bay	CA
105398	Trinidad Harbor, California	NOS	9419059	41.0567	-124.147	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103583	-00:03:00	\N	0.98	-00:02:00	\N	0.97	\N	\N	Trinidad Harbor	CA
105399	Brookings, Chetco Cove, Oregon	NOS	9430104	42.0433	-124.285	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103583	00:04:00	\N	1	00:01:00	\N	1	\N	\N	Brookings, Chetco Cove	OR
105400	Bandon, Coquille River, Oregon	NOS	9432373	43.12	-124.413	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103588	00:02:00	\N	0.94	-00:05:00	\N	0.92	\N	\N	Bandon, Coquille River	OR
105401	Coos Bay, Oregon	NOS	9432845	43.38	-124.215	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103588	01:28:00	\N	0.88	01:26:00	\N	0.96	\N	\N	Coos Bay	OR
105402	Empire, Coos Bay, Oregon	NOS	9432864	43.3917	-124.28	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103588	00:50:00	\N	0.88	00:37:00	\N	0.86	\N	\N	Empire	OR
105403	Sitka Dock, Coos Bay, Oregon	NOS	9432879	43.3767	-124.297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103588	00:08:00	\N	1.01	00:07:00	\N	1.01	\N	\N	Sitka Dock, Coos Bay	OR
105404	Florence, Siuslaw River, Oregon	NOS	9434032	43.96670150756836	-124.10299682617188	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103588	00:58:00	\N	0.8	00:44:00	\N	0.86	\N	\N	Florence, Siuslaw River	OR
105405	Siuslaw River entrance, Oregon	NOS	9434132	44.016700744628906	-124.12999725341797	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103588	00:03:00	\N	0.96	00:06:00	\N	0.96	\N	\N	Siuslaw River Entrance	OR
105406	Drift Creek, Alsea River, Oregon	NOS	9434938	44.4133	-123.99	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103588	01:51:00	\N	0.53	00:44:00	\N	0.83	\N	\N	Drift Creek, Alsea River	OR
105407	Toledo, Yaquina River, Oregon	NOS	9435362	44.6167	-123.937	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103583	01:17:00	\N	1.02	01:02:00	\N	1.31	\N	\N	TOLEDO	OR
105408	Yaquina USCG station, Newport, Yaquina Bay, Oregon	NOS	9435385	44.6267	-124.055	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103583	00:35:00	\N	1.11	00:39:00	\N	1.22	\N	\N	YAQUINA USCG STA, NEWPORT	OR
105409	Kernville, Siletz River, Oregon	NOS	9436031	44.8967	-124	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103583	01:53:00	\N	0.67	01:24:00	\N	0.86	\N	\N	Kernville, Siletz River	OR
105410	Taft, Siletz Bay, Oregon	NOS	9436101	44.9267	-124.013	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103583	01:13:00	\N	0.75	00:48:00	\N	0.94	\N	\N	Taft, Siletz Bay	OR
105411	Netarts, Netarts Bay, Oregon	NOS	9437262	45.43	-123.945	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103583	01:38:00	\N	0.85	01:17:00	\N	0.98	\N	\N	Netarts, Netarts Bay	OR
105412	Tillamook, Hoquarten Slough, Tillamook Bay, Oregon	NOS	9437331	45.46	-123.845	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103583	03:15:00	\N	0.58	01:52:00	\N	0.94	\N	\N	Tillamook, Hoquarten Slough	OR
105413	Barview, Tillamook Bay, Oregon	NOS	9437581	45.5683	-123.943	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103583	00:56:00	\N	0.92	00:42:00	\N	1.08	\N	\N	Barview	OR
105414	Brighton, Nehalem River, Oregon	NOS	9437815	45.67	-123.925	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103583	00:54:00	\N	1	00:51:00	\N	1.13	\N	\N	Brighton	OR
105415	Nehalem, Nehalem River, Oregon	NOS	9437908	45.71	-123.89	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103583	01:56:00	\N	0.75	01:17:00	\N	1.03	\N	\N	Nehalem	OR
105416	Astoria (Port Docks), Oregon	NOS	9439023	46.1867	-123.86	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103605	-00:03:00	0	\N	-00:08:00	-0.5	\N	\N	\N	Astoria (Port Docks), Oreg.	OR
105417	Astoria (Youngs Bay), Oregon	NOS	9439026	46.1717	-123.842	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103605	-00:14:00	0.1	\N	-00:13:00	0.1	\N	\N	\N	Astoria (Youngs Bay), Oreg.	OR
105418	Settlers Point, Oregon	NOS	9439054	46.175	-123.678	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103605	00:53:00	-0.1	\N	00:22:00	-0.5	\N	\N	\N	Settlers Point, Oreg.	OR
105419	Knappa, Knappa Slough, Oregon	NOS	9439069	46.1867	-123.588	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103605	00:58:00	\N	0.86	00:29:00	\N	0.97	\N	\N	Knappa, Knappa Slough	OR
105420	Hungry Harbor, Washington	NOS	9440563	46.2583	-123.848	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103605	-00:09:00	0.1	\N	00:04:00	-0.2	\N	\N	\N	Hungry Harbor, Wash.	WA
105421	Fort Canby, Jetty A, Washington	NOS	9440572	46.2683	-124.037	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103605	-01:05:00	\N	1.22	-00:41:00	\N	0.97	\N	\N	Fort Canby, Jetty 'A', Wash.	WA
105422	Chinook, Baker Bay, Washington	NOS	9440573	46.2717	-123.948	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103605	-00:52:00	\N	1.12	-00:30:00	\N	0.95	\N	\N	Chinook, Baker Bay, Wash.	WA
105423	Columbia River entrance (north jetty), Washington	NOS	9440574	46.2733	-124.072	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103605	-01:00:00	0.1	\N	-00:44:00	-1	\N	\N	\N	Columbia River entrance (N. Jetty)	WA
105424	Ilwaco, Baker Bay, Washington	NOS	9440597	46.3033	-124.04	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103605	00:01:00	-0.1	\N	-00:13:00	-0.8	\N	\N	\N	Ilwaco, Baker Bay, Wash.	WA
105425	Naselle River, 4 mi above swing bridge, Willapa Bay, Washington	NOS	9440662	46.3883	-123.84	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	01:02:00	\N	0.93	01:02:00	\N	1.22	\N	\N	Naselle River, 4 miles above swing bridge	WA
105426	Naselle River, swing bridge, Willapa Bay, Washington	NOS	9440691	46.43	-123.903	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	00:37:00	\N	1.08	00:42:00	\N	1.22	\N	\N	Naselle River, swing bridge	WA
105427	Paradise Point, Long Island, Willapa Bay, Washington	NOS	9440723	46.4683	-123.945	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	00:41:00	\N	1.04	00:43:00	\N	1.15	\N	\N	Paradise Point, Long Island	WA
105428	Nahcotta, Willapa Bay, Washington (sub)	NOS	9440747	46.5017	-124.023	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	00:28:00	\N	1.01	00:29:00	\N	1.13	\N	\N	Nahcotta	WA
105429	Palix River, south fork, Willapa Bay, Washington	NOS	9440813	46.5867	-123.91	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	00:31:00	\N	0.96	00:25:00	\N	1.04	\N	\N	Palix River, south fork	WA
105430	Bay Center, Palix River, Willapa Bay, Washington	NOS	9440846	46.6233	-123.945	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	00:22:00	\N	1.03	00:09:00	\N	1.04	\N	\N	Bay Center, Palix River	WA
105431	Raymond, Willapa River, Willapa Bay, Washington	NOS	9440886	46.6833	-123.755	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	00:17:00	\N	1.04	00:27:00	\N	1.13	\N	\N	Raymond, Willapa River	WA
105432	Bay City, South Bay, Grays Harbor, Washington	NOS	9441038	46.8617	-124.06	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	-00:26:00	\N	1.13	-00:01:00	\N	1.1	\N	\N	Bay City, South Bay	WA
105433	Markham, Grays Harbor, Washington	NOS	9441098	46.9067	-123.998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	-00:15:00	\N	1.02	00:05:00	\N	1.06	\N	\N	Markham	WA
105434	Point Brown, Grays Harbor, Washington	NOS	9441156	46.95	-124.128	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	-00:24:00	\N	1.04	-00:09:00	\N	1.06	\N	\N	Point Brown	WA
105435	Cosmopolis, Chehalis River, Grays Harbor, Washington	NOS	9441158	46.9667	-123.778	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	00:15:00	\N	1.12	00:26:00	\N	1.23	\N	\N	Cosmopolis, Chehalis River	WA
105436	Point Grenville, Washington	NOS	9441627	47.3033	-124.27	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	-00:44:00	\N	0.9	-00:37:00	\N	0.92	\N	\N	Point Grenville	WA
105437	James Island, Washington	NOS	9442388	47.9067	-124.647	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	-00:32:00	\N	0.96	-00:39:00	\N	0.92	\N	\N	James Island	WA
105438	Makah Bay, Washington	NOS	9442861	48.2967	-124.672	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	-00:28:00	\N	1.1	-00:25:00	\N	0.99	\N	\N	Makah Bay	WA
105439	Tatoosh Island, Cape Flattery, Strait of Juan de Fuca, Washington	NOS	9442971	48.391700744628906	-124.73699951171875	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103629	-00:10:00	\N	1	-00:08:00	\N	1.01	\N	\N	Tatoosh Island, Cape Flattery	WA
105440	Twin Rivers, Strait of Juan de Fuca, Washington	NOS	9443644	48.17499923706055	-123.94999694824219	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103629	00:59:00	\N	1.2	00:47:00	\N	0.89	\N	\N	Twin Rivers	WA
105441	Crescent Bay, Strait of Juan de Fuca, Washington	NOS	9443826	48.1617	-123.725	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	-02:02:00	\N	0.8	-02:41:00	\N	0.8	\N	\N	Crescent Bay	WA
105442	Ediz Hook, Port Angeles, Strait of Juan de Fuca, Washington	NOS	9444122	48.14	-123.413	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	-01:13:00	\N	0.9	-01:37:00	\N	0.81	\N	\N	Ediz Hook, Port Angeles	WA
105443	Dungeness, Strait of Juan de Fuca, Washington	NOS	9444471	48.1667	-123.117	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	-00:38:00	\N	0.9	-00:54:00	\N	0.9	\N	\N	Dungeness	WA
105444	Sequim Bay entrance, Strait of Juan de Fuca, Washington	NOS	9444555	48.0817	-123.043	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	-00:07:00	\N	0.94	-00:39:00	\N	0.94	\N	\N	Sequim Bay entrance	WA
105445	Gardiner, Discovery Bay, Strait of Juan de Fuca, Washington	NOS	9444705	48.0583	-122.917	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	-00:17:00	\N	0.94	-00:47:00	\N	0.94	\N	\N	Gardiner, Discovery Bay	WA
105446	Mystery Bay, Marrowstone Island, Admiralty Inlet, Washington	NOS	9444971	48.0583	-122.692	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	00:52:00	\N	0.99	00:15:00	\N	0.95	\N	\N	Mystery Bay, Marrowstone Island	WA
105447	Marrowstone Point, Admiralty Inlet, Washington	NOS	9444972	48.0917	-122.69	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	00:05:00	-0.1	\N	00:02:00	0.4	\N	\N	\N	Marrowstone Point	WA
105448	Port Ludlow, Washington	NOS	9445017	47.925	-122.68	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:14:00	\N	0.95	-00:14:00	\N	0.87	\N	\N	Port Ludlow	WA
105449	Port Gamble, Washington	NOS	9445059	47.8583	-122.58	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:05:00	\N	0.95	-00:09:00	\N	0.9	\N	\N	Port Gamble	WA
105450	Lofall, Washington	NOS	9445088	47.815	-122.657	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:06:00	\N	1.01	-00:08:00	\N	0.94	\N	\N	Lofall	WA
105451	Whitney Point, Dabob Bay, Washington	NOS	9445246	47.7617	-122.85	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:02:00	\N	1.06	-00:05:00	\N	1.01	\N	\N	Whitney Point, Dabob Bay	WA
105452	Zelatched Point, Dabob Bay, Washington	NOS	9445269	47.7117	-122.822	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:05:00	\N	1.02	-00:09:00	\N	1	\N	\N	Zelatched Point, Dabob Bay	WA
105453	Quilcene, Quilcene Bay, Dabob Bay, Washington	NOS	9445272	47.8	-122.858	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:02:00	\N	1.04	-00:08:00	\N	1	\N	\N	Quilcene, Quilcene Bay, Dabob Bay	WA
105454	Pleasant Harbor, Washington	NOS	9445293	47.665	-122.912	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:01:00	\N	1.02	-00:14:00	\N	1.01	\N	\N	Pleasant Harbor	WA
105455	Seabeck, Seabeck Bay, Washington	NOS	9445303	47.6417	-122.828	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:01:00	\N	1.06	-00:04:00	\N	1.01	\N	\N	Seabeck, Seabeck Bay	WA
105456	Triton Head, Washington	NOS	9445326	47.6033	-122.982	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:06:00	\N	1.02	-00:06:00	\N	1	\N	\N	Triton Head	WA
105457	Ayock Point, Washington	NOS	9445388	47.5083	-123.052	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:05:00	\N	1.07	-00:03:00	\N	0.99	\N	\N	Ayock Point	WA
105458	Lynch Cove Dock, Washington	NOS	9445441	47.4183	-122.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:06:00	\N	1.08	00:00:00	\N	1.07	\N	\N	Lynch Cove Dock	WA
105459	Hansville, Puget Sound, Washington	NOS	9445526	47.9183	-122.545	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:08:00	\N	0.98	-00:07:00	\N	0.92	\N	\N	Hansville	WA
105460	Kingston, Appletree Cove, Puget Sound, Washington	NOS	9445639	47.7967	-122.493	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:05:00	\N	1	-00:05:00	\N	0.97	\N	\N	Kingston, Appletree Cove	WA
105461	Port Jefferson, Puget Sound, Washington	NOS	9445683	47.7467	-122.477	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:04:00	\N	0.98	-00:03:00	\N	0.95	\N	\N	Port Jefferson	WA
105462	Poulsbo, Liberty Bay, Puget Sound, Washington	NOS	9445719	47.725	-122.638	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:12:00	\N	1.01	00:05:00	\N	1.03	\N	\N	Poulsbo, Liberty Bay	WA
105463	Port Madison, Puget Sound, Washington	NOS	9445753	47.705	-122.525	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:03:00	\N	0.99	00:09:00	\N	1	\N	\N	Port Madison	WA
105464	Brownsville, Port Orchard, Puget Sound, Washington	NOS	9445832	47.6517	-122.615	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:09:00	\N	1.03	00:07:00	\N	1.04	\N	\N	Brownsville, Port Orchard	WA
105465	Eagle Harbor, Bainbridge Island, Puget Sound, Washington	NOS	9445882	47.62	-122.515	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:05:00	\N	1.02	00:04:00	\N	1	\N	\N	Eagle Harbor, Bainbridge Island	WA
105466	Tracyton, Dyes Inlet, Puget Sound, Washington	NOS	9445901	47.61	-122.66	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:53:00	\N	0.95	00:28:00	\N	1.06	\N	\N	Tracyton, Dyes Inlet	WA
105467	Port Blakely, Puget Sound, Washington	NOS	9445913	47.5967	-122.51	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:04:00	\N	0.99	00:04:00	\N	1.01	\N	\N	Port Blakely	WA
105468	Clam Bay, Rich Passage, Puget Sound, Washington	NOS	9445938	47.5733	-122.543	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:04:00	\N	1	00:03:00	\N	1.01	\N	\N	Clam Bay, Rich Passage	WA
105469	Harper, Yukon Harbor, Puget Sound, Washington	NOS	9445993	47.5233	-122.517	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:01:00	\N	0.99	-00:06:00	\N	1.02	\N	\N	Harper, Yukon Harbor	WA
105890	West Passage, Palau	NOS	TPT2637	7.5	134.51669311523438	:Pacific/Palau	Palau	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102712	-00:41:00	0	\N	-00:21:00	-0.1	\N	\N	\N	West Passage	PW
105470	Point Vashon, Vashon Island, Puget Sound, Washington	NOS	9446025	47.5117	-122.463	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:02:00	\N	1.01	00:02:00	\N	1.02	\N	\N	Point Vashon, Vashon Island	WA
105471	Des Moines, east passage, Puget Sound, Washington	NOS	9446248	47.4	-122.328	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:08:00	\N	1.01	00:05:00	\N	1.03	\N	\N	Des Moines, East Passage	WA
105472	Burton, Quartermaster Hbr. (inside), Vashon I., Puget Sound, Washington	NOS	9446254	47.395	-122.463	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:03:00	\N	1.02	00:01:00	\N	1.06	\N	\N	Burton, Quartermaster Hbr. (inside), Vashon I.	WA
105473	Allyn, Case Inlet, Puget Sound, Washington	NOS	9446281	47.3833	-122.823	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:59:00	\N	1.07	00:48:00	\N	1.26	\N	\N	Allyn, Case Inlet	WA
105474	Vaughn, Case Inlet, Puget Sound, Washington	NOS	9446366	47.3417	-122.775	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:57:00	\N	1.06	00:51:00	\N	1.26	\N	\N	Vaughn, Case Inlet	WA
105475	Gig Harbor, Puget Sound, Washington	NOS	9446369	47.34	-122.588	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:22:00	\N	0.99	00:18:00	\N	1.05	\N	\N	Gig Harbor	WA
105476	Tahlequah, Neil Pt., Dalco Passage, Vashon I., Puget Sound, Washington	NOS	9446375	47.3333	-122.507	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:05:00	\N	1.01	00:04:00	\N	1.05	\N	\N	Tahlequah, Neil Pt., Dalco Passage, Vashon I.	WA
105477	Horsehead Bay, Carr Inlet, Puget Sound, Washington	NOS	9446451	47.3017	-122.682	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:46:00	\N	1.05	00:38:00	\N	1.2	\N	\N	Horsehead Bay, Carr Inlet	WA
105478	Tacoma Narrows Bridge, Puget Sound, Washington	NOS	9446486	47.2717	-122.552	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:23:00	\N	1.02	00:28:00	\N	1.11	\N	\N	Tacoma Narrows Bridge	WA
105479	Walkers Landing, Pickering Passage, Puget Sound, Washington	NOS	9446489	47.2817	-122.923	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:55:00	\N	1.07	00:44:00	\N	1.26	\N	\N	Walkers Landing, Pickering Passage	WA
105480	Arletta, Hale Passage, Puget Sound, Washington	NOS	9446491	47.28	-122.652	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:40:00	\N	1.04	00:31:00	\N	1.18	\N	\N	Arletta, Hale Passage	WA
105481	Home, Von Geldern Cove, Carr Inlet, Puget Sound, Washington	NOS	9446500	47.275	-122.758	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:45:00	\N	1.04	00:37:00	\N	1.19	\N	\N	Home, Von Geldern Cove, Carr Inlet	WA
105482	McMicken Island, Case Inlet, Puget Sound, Washington	NOS	9446583	47.2467	-122.862	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:52:00	\N	1.06	00:40:00	\N	1.24	\N	\N	McMicken Island, Case Inlet	WA
105483	Shelton, Oakland Bay, Puget Sound, Washington	NOS	9446628	47.215	-123.083	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	02:05:00	\N	0.92	01:26:00	\N	1.26	\N	\N	Shelton, Oakland Bay	WA
105484	Longbranch, Filucy Bay, Puget Sound, Washington	NOS	9446638	47.21	-122.753	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:47:00	\N	1.02	00:38:00	\N	1.2	\N	\N	Longbranch, Filucy Bay	WA
105485	Arcadia, Totten Inlet, Puget Sound, Washington	NOS	9446666	47.1967	-122.938	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	01:05:00	\N	1.06	00:49:00	\N	1.28	\N	\N	Arcadia, Totten Inlet	WA
105486	Devils Head, Drayton Passage, Puget Sound, Washington	NOS	9446671	47.1667	-122.763	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:50:00	\N	1.1	00:40:00	\N	1.25	\N	\N	Devils Head, Drayton Passage	WA
105487	Steilacoom, Cormorant Passage, Puget Sound, Washington	NOS	9446714	47.1733	-122.603	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:45:00	\N	1.05	00:37:00	\N	1.2	\N	\N	Steilacoom, Cormorant Passage	WA
105488	Barron Point, Little Skookum Inlet entrance, Puget Sound, Washington	NOS	9446742	47.156700134277344	-123.00800323486328	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:59:00	\N	1.06	00:50:00	\N	1.29	\N	\N	Barron Point, Little Skookum Inlet Entrance	WA
105489	Henderson Inlet, Puget Sound, Washington	NOS	9446752	47.155	-122.838	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:58:00	\N	1.06	00:47:00	\N	1.24	\N	\N	Henderson Inlet	WA
105490	Dofflemeyer Point, Boston Hbr., Budd Inlet, Puget Sound, Washington	NOS	9446800	47.1417	-122.903	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:57:00	\N	1.09	00:44:00	\N	1.28	\N	\N	Dofflemeyer Point, Boston Hbr., Budd Inlet	WA
105491	Dupont Wharf, Nisqually Reach, Puget Sound, Washington	NOS	9446828	47.1183	-122.665	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:49:00	\N	1.04	00:41:00	\N	1.2	\N	\N	Dupont Wharf, Nisqually Reach	WA
105492	Olympia, Budd Inlet, Puget Sound, Washington	NOS	9446969	47.06	-122.903	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:57:00	\N	1.08	00:45:00	\N	1.29	\N	\N	Olympia, Budd Inlet	WA
105493	Duwamish Waterway, Eighth Ave. South, Puget Sound, Washington	NOS	9447029	47.535	-122.322	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:11:00	\N	0.95	00:10:00	\N	0.97	\N	\N	Duwamish Waterway, Eighth Ave. South	WA
105494	Lockheed Shipyard, Harbor Island, Puget Sound, Washington	NOS	9447110	47.585	-122.362	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:01:00	\N	1	-00:01:00	\N	1	\N	\N	Lockheed Shipyard, Harbor Island	WA
105495	Meadow Point, Shilshole Bay, Puget Sound, Washington	NOS	9447265	47.6883	-122.403	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:01:00	\N	0.99	00:00:00	\N	0.98	\N	\N	Meadow Point, Shilshole Bay	WA
105496	Edmonds, Puget Sound, Washington	NOS	9447427	47.8133	-122.383	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:04:00	\N	0.99	00:00:00	\N	0.96	\N	\N	Edmonds	WA
105497	Glendale, Whidbey Island, Washington	NOS	9447814	47.94	-122.357	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:03:00	\N	0.99	00:01:00	\N	0.97	\N	\N	Glendale, Whidbey Island	WA
105498	Bush Point, Whidbey Island, Admiralty Inlet, Washington	NOS	9447854	48.0333	-122.607	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	00:45:00	\N	1.08	00:10:00	\N	1.09	\N	\N	Bush Point, Whidbey Island	WA
105499	Holly Farms Harbor, Holmes Harbor, Whidbey I., Washington	NOS	9447855	48.0267	-122.535	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:04:00	\N	0.99	00:01:00	\N	1.01	\N	\N	Holly Farms Harbor, Holmes Harbor, Whidbey I.	WA
105500	Sandy Point, Whidbey Island, Washington	NOS	9447856	48.035	-122.377	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:01:00	\N	1	00:03:00	\N	0.99	\N	\N	Sandy Point, Whidbey Island	WA
105501	Admiralty Head, Admiralty Inlet, Washington	NOS	9447905	48.1583	-122.668	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	00:20:00	-0.1	\N	-00:11:00	0	\N	\N	\N	Admiralty Head	WA
105502	Coupeville, Penn Cove, Whidbey Island, Washington	NOS	9447929	48.2233	-122.69	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:09:00	\N	0.99	00:15:00	\N	1.01	\N	\N	Coupeville, Penn Cove, Whidbey Island	WA
105503	Point Partridge, Whidbey Island, Strait of Juan de Fuca, Washington	NOS	9447934	48.2317	-122.765	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	-00:15:00	\N	0.92	-00:11:00	\N	0.92	\N	\N	Point Partridge, Whidbey Island	WA
105504	Sunset Beach, Whidbey Island, Strait of Juan de Fuca, Washington	NOS	9447951	48.2833	-122.728	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	-00:16:00	\N	0.95	-00:27:00	\N	0.87	\N	\N	Sunset Beach, Whidbey Island	WA
105505	Crescent Harbor, N. Whidbey Island, Washington	NOS	9447952	48.2867	-122.617	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:04:00	\N	0.99	00:04:00	\N	1.03	\N	\N	Crescent Harbor, N. Whidbey Island	WA
105506	Smith Island, Strait of Juan de Fuca, Washington	NOS	9447985	48.3167	-122.837	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	-00:25:00	\N	0.83	-00:13:00	\N	0.83	\N	\N	Smith Island	WA
105507	Ala Spit, Whidbey Island, Washington	NOS	9447993	48.3967	-122.587	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:26:00	\N	0.95	00:12:00	\N	0.92	\N	\N	Ala Spit, Whidbey Island	WA
105508	Cornet Bay, Deception Pass, Washington	NOS	9447995	48.4017	-122.623	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:26:00	\N	0.95	00:15:00	\N	0.89	\N	\N	Cornet Bay, Deception Pass	WA
105509	Kayak Point, Washington	NOS	9448094	48.1367	-122.367	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	-00:02:00	\N	0.99	00:00:00	\N	0.99	\N	\N	Kayak Point	WA
105510	La Conner, Swinomish Channel, Washington	NOS	9448558	48.3917	-122.497	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:39:00	\N	0.95	00:21:00	\N	0.9	\N	\N	La Conner, Swinomish Channel	WA
105511	Yokeko Point, Deception Pass, Washington (sub)	NOS	9448601	48.4133	-122.615	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:38:00	-0.2	\N	00:26:00	-1	\N	\N	\N	Yokeko Point, Deception Pass	WA
105512	Burrows Bay (Allan Island), Washington	NOS	9448683	48.46	-122.695	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	00:03:00	\N	0.88	00:09:00	\N	0.95	\N	\N	Burrows Bay (Allan Island)	WA
105513	Ship Harbor, Fidalgo Island, Washington	NOS	9448772	48.5067	-122.677	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	00:29:00	\N	1.02	00:18:00	\N	0.93	\N	\N	Ship Harbor, Fidalgo Island	WA
105514	Anacortes, Guemes Channel, Washington	NOS	9448794	48.5183	-122.62	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	00:33:00	\N	1	00:22:00	\N	0.96	\N	\N	Anacortes, Guemes Channel	WA
105515	Strawberry Bay, Cypress Island, Washington	NOS	9448876	48.565	-122.722	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	00:52:00	\N	0.95	00:34:00	\N	0.95	\N	\N	Strawberry Bay, Cypress Island	WA
105516	Tide Point, Cypress Island, Washington	NOS	9448918	48.5867	-122.748	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	00:41:00	\N	0.95	00:31:00	\N	0.94	\N	\N	Tide Point, Cypress Island	WA
105517	Gooseberry Point, Hale Passage, Washington	NOS	9449184	48.73	-122.67	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	01:10:00	\N	0.97	00:41:00	\N	1.04	\N	\N	Gooseberry Point	WA
105518	Bellingham, Bellingham Bay, Washington	NOS	9449211	48.745	-122.495	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	01:11:00	\N	0.94	00:43:00	\N	0.99	\N	\N	Bellingham	WA
105519	Sandy Point, Lummi Bay, Washington	NOS	9449292	48.79	-122.708	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	01:24:00	\N	1.03	00:52:00	\N	1.05	\N	\N	Sandy Point, Lummi Bay	WA
105520	Patos Island Wharf, Boundary Pass, Washington	NOS	9449704	48.7867	-122.97	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	01:30:00	0	\N	01:03:00	0.2	\N	\N	\N	Patos Island Wharf	WA
105521	Echo Bay, Sucia Islands, Strait of Georgia, Washington	NOS	9449712	48.7567	-122.897	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	01:34:00	0	\N	01:01:00	0.1	\N	\N	\N	Echo Bay, Sucia Islands	WA
105522	Orcas, Orcas Island, Washington	NOS	9449798	48.6	-122.95	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	00:56:00	\N	0.9	00:33:00	\N	0.9	\N	\N	Orcas, Orcas Island	WA
105523	Roche Harbor, San Juan Island, Haro Strait, Washington	NOS	9449834	48.61	-123.155	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	00:47:00	\N	0.99	00:33:00	\N	0.9	\N	\N	Roche Harbor, San Juan Island	WA
105524	Shaw Island, Ferry Terminal, Harney Channel, San Juan Channel, Washington	NOS	9449904	48.585	-122.928	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	00:56:00	\N	0.99	00:31:00	\N	0.9	\N	\N	Shaw Island, Ferry Terminal, Harney Channel	WA
105525	Aleck Bay, Lopez Island, Washington	NOS	9449994	48.425	-122.853	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	-00:08:00	\N	0.88	-00:18:00	\N	0.88	\N	\N	Aleck Bay, Lopez Island	WA
105526	Minnie Bay, Alaska	NOS	9450041	54.7267	-132.302	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:00:00	0.1	\N	-00:05:00	2.7	\N	\N	\N	Minnie Bay	AK
105527	Security Cove, Dall Island, Alaska	NOS	9450055	54.7483	-132.855	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:24:00	0	\N	-00:20:00	1	\N	\N	\N	Security Cove	AK
105528	Nakat Harbor, Dixon Entrance, Alaska	NOS	9450104	54.82	-130.7	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:09:00	\N	0.89	00:01:00	\N	0.95	\N	\N	Nakat Harbor, Alaska	AK
105529	American Bay, Kaigani Strait, Alaska	NOS	9450125	54.85	-132.83	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:01:00	0	\N	00:01:00	2.5	\N	\N	\N	American Bay, Kaigani Strait	AK
105530	Hunter Bay, Alaska	NOS	9450139	54.8717	-132.322	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:03:00	0.1	\N	-00:02:00	2.7	\N	\N	\N	Hunter Bay	AK
105531	Kelp Island Passage, Duke Island, Dixon Entrance, Alaska	NOS	9450142	54.8767	-131.3	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:03:00	\N	0.96	-00:04:00	\N	0.94	\N	\N	Kelp Island Passage, Duke Island	AK
105532	Elbow Bay, Alaska	NOS	9450158	54.9	-132.653	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:04:00	0.1	\N	-00:04:00	2.6	\N	\N	\N	Elbow Bay	AK
105533	Morse Cove, Duke Island, Revillagigedo Channel, Alaska	NOS	9450172	54.92	-131.255	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:15:00	\N	0.96	00:03:00	\N	0.96	\N	\N	Morse Cove, Duke Island	AK
105534	Kassa Inlet entrance, Alaska	NOS	9450176	54.9267	-132.522	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:01:00	0.1	\N	-00:03:00	2.6	\N	\N	\N	Kassa Inlet entrance	AK
105535	Ingraham Bay, Prince of Wales Island, Alaska	NOS	9450212	54.98	-132.007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:04:00	\N	0.96	00:03:00	\N	0.93	\N	\N	Ingraham Bay, Prince of Wales Island	AK
105536	Mabel Island, Alaska	NOS	9450226	55	-132.592	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:01:00	0.1	\N	-00:10:00	2.8	\N	\N	\N	Mabel Island	AK
105537	Menefee Anch., Prince of Wales Island, Alaska	NOS	9450244	55.0267	-132.013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:01:00	\N	0.89	-00:02:00	\N	0.94	\N	\N	Menefee Anch., Prince of Wales Island	AK
105538	Kah Shakes Cove, Revillagigedo Channel, Alaska	NOS	9450254	55.0417	-130.98	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:06:00	\N	0.96	00:00:00	\N	0.97	\N	\N	Kah Shakes Cove	AK
105539	Keete Island, Nutkwa Inlets, Alaska	NOS	9450258	55.0467	-132.577	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:05:00	0.1	\N	-00:13:00	2.8	\N	\N	\N	Keete Island, Nutkwa Inlets	AK
105540	Niblack Anchorage, Moira Sound, Alaska	NOS	9450271	55.0667	-132.12	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:09:00	\N	0.96	00:03:00	\N	0.94	\N	\N	Niblack Anchorage, Moira Sound	AK
105541	Sakie Bay, Dall Island, Alaska	NOS	9450272	55.0667	-133.2	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:05:00	0	\N	00:01:00	0.3	\N	\N	\N	Sakie Bay	AK
105542	Tamgas Harbor, Annette Island, Alaska	NOS	9450273	55.0667	-131.542	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	-00:08:00	\N	0.89	-00:09:00	\N	0.98	\N	\N	Tamgas Harbor, Annette Island	AK
105543	Keete Inlet, Alaska	NOS	9450281	55.08	-132.49	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:01:00	0.1	\N	-00:11:00	2.9	\N	\N	\N	Keete Inlet	AK
105544	Mud Bay, Hetta Inlet, Alaska	NOS	9450282	55.0817	-132.632	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:01:00	0.1	\N	-00:05:00	2.8	\N	\N	\N	Mud Bay	AK
105545	View Cove, Tlevak Strait, Alaska	NOS	9450283	55.0833	-133.017	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:02:00	0	\N	-00:02:00	2.8	\N	\N	\N	View Cove	AK
105546	Boca de Quadra, Revillagigedo Channel, Alaska	NOS	9450305	55.1167	-130.798	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:02:00	\N	0.98	00:00:00	\N	0.98	\N	\N	Boca de Quadra	AK
105547	Sea Otter Harbor, Dall Island, Alaska	NOS	9450312	55.1267	-133.167	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:04:00	-0.1	\N	-00:04:00	-0.2	\N	\N	\N	Sea Otter Harbor	AK
105548	Nehenta Bay, Gravina Island, Alaska	NOS	9450339	55.1667	-131.797	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	-00:01:00	\N	0.96	-00:01:00	\N	0.95	\N	\N	Nehenta Bay, Gravina Island	AK
105549	South Pass, Sukkwan Strait, Tlevak Strait, Alaska	NOS	9450341	55.1667	-132.87	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:02:00	0.1	\N	-00:02:00	2.9	\N	\N	\N	South Pass, Sukkwan Strait	AK
105550	Saltery Point, Tlevak Strait, Alaska	NOS	9450351	55.1817	-132.795	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:05:00	0.1	\N	-00:08:00	2.9	\N	\N	\N	Saltery Point	AK
105551	North Pass, west end, Tlevak Strait, Alaska	NOS	9450366	55.205	-132.94	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:06:00	0.1	\N	-00:12:00	3	\N	\N	\N	North Pass, West End	AK
105552	Copper Harbor, Hetta Inlet, Alaska	NOS	9450369	55.21	-132.625	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:08:00	0.1	\N	-00:10:00	2.8	\N	\N	\N	Copper Harbor	AK
105553	Lancaster Cove, Cholmondeley Sound, Alaska	NOS	9450373	55.2133	-132.095	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:03:00	\N	0.96	00:05:00	\N	0.98	\N	\N	Lancaster Cove, Cholmondeley Sound	AK
105554	Alva Bay, Revillagigedo Island, Alaska	NOS	9450382	55.2283	-131.133	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	-00:03:00	\N	0.96	-00:05:00	\N	0.98	\N	\N	Alva Bay, Revillagigedo Island	AK
105555	Natalia Point, Tlevak Strait, Alaska	NOS	9450387	55.2333	-133.043	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:01:00	0.1	\N	-00:05:00	2.9	\N	\N	\N	Natalia Point	AK
105556	Divide Head, Cholmondeley Sound, Alaska	NOS	9450399	55.2517	-132.3	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	-00:08:00	\N	0.96	-00:05:00	\N	0.98	\N	\N	Divide Head, Cholmondeley Sound	AK
105557	Block Island, Tlevak Strait, Alaska	NOS	9450406	55.263301849365234	-133.11500549316406	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:02:00	\N	1	00:07:00	\N	1.2	\N	\N	Block Island, Tlevak Narrows	AK
105558	Soda Bay, Tlevak Strait, Alaska	NOS	9450413	55.275	-132.967	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:07:00	0.1	\N	00:03:00	3	\N	\N	\N	Soda Bay	AK
105559	Sulzer, Hetta Inlet, Alaska	NOS	9450421	55.285	-132.622	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:08:00	0.1	\N	-00:02:00	2.9	\N	\N	\N	Sulzer	AK
105560	Mop Point, Thorne Arm, Revillagigedo Channel, Alaska	NOS	9450483	55.3833	-131.235	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	-00:03:00	\N	0.98	-00:05:00	\N	0.98	\N	\N	Mop Point, Thorne Arm	AK
105561	Ward Cove, Revillagigedo Channel, Alaska	NOS	9450492	55.3983	-131.727	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	-00:03:00	\N	0.96	-00:05:00	\N	1.02	\N	\N	Ward Cove	AK
105562	Saltery Cove, Skowl Arm, Kasaan Bay, Alaska	NOS	9450495	55.4017	-132.328	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:02:00	\N	1.01	00:04:00	\N	1.01	\N	\N	Saltery Cove, Skowl Arm	AK
105563	Vallenar Point, Alaska	NOS	9450511	55.4267	-131.847	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	-00:06:00	\N	0.96	-00:01:00	\N	0.99	\N	\N	Vallenar Point	AK
105564	Coon Island, George Inlet, Revillagigedo Channel, Alaska	NOS	9450533	55.4617	-131.505	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	-00:07:00	\N	0.96	-00:03:00	\N	0.99	\N	\N	Coon Island, George Inlet	AK
105565	Hollis Anchorage, Kasaan Bay, Alaska	NOS	9450544	55.48	-132.645	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:02:00	\N	1.01	00:06:00	\N	1.03	\N	\N	Hollis Anchorage	AK
105566	Steamboat Bay, Noyes Island, Gulf of Esquibel, Alaska	NOS	9450578	55.5333	-133.637	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:13:00	\N	0.93	-00:12:00	\N	1.04	\N	\N	Steamboat Bay, Noyes Island	AK
105567	Kasaan, Kasaan Bay, Alaska	NOS	9450581	55.535	-132.397	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:03:00	\N	1.01	00:05:00	\N	1.02	\N	\N	Kasaan	AK
105568	Cruz Pass, San Fernando Island, Bucareli Bay, Alaska	NOS	9450584	55.5417	-133.315	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:12:00	-0.1	\N	-00:15:00	0.1	\N	\N	\N	Cruz Pass, San Fernando Island	AK
105569	Loring, Naha Bay, Alaska	NOS	9450624	55.6017	-131.632	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	-00:06:00	\N	0.96	-00:02:00	\N	1.02	\N	\N	Loring, Naha Bay	AK
105570	Rudyerd Bay, Alaska	NOS	9450651	55.6417	-130.645	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:02:00	\N	0.96	00:01:00	\N	1.02	\N	\N	Rudyerd Bay	AK
105571	Anguilla Island, Gulf of Esquibel, Alaska	NOS	9450679	55.6833	-133.587	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:14:00	-0.1	\N	-00:18:00	0.4	\N	\N	\N	Anguilla Island	AK
105572	Davis River entrance, Alaska	NOS	9450729	55.76	-130.177	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:00:00	\N	0.96	-00:02:00	\N	1.08	\N	\N	Davis River entrance, Alaska	AK
105573	Port Alice, Heceta Island, Davidson Inlet, Alaska	NOS	9450768	55.8117	-133.605	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:14:00	0	\N	-00:20:00	0.9	\N	\N	\N	Port Alice, Heceta Island	AK
105574	Ratz Harbor, Prince of Wales Island, Alaska	NOS	9450815	55.88	-132.595	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:00:00	\N	0.99	00:09:00	\N	1.03	\N	\N	Ratz Harbor, Prince of Wales Island	AK
105575	Tuxekan, 0.5 mi south of, Davidson Inlet, Alaska	NOS	9450817	55.8833	-133.243	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:07:00	-0.1	\N	-00:17:00	0.9	\N	\N	\N	Tuxekan, 0.5 mile south of	AK
105576	Coronation Island, Alaska	NOS	9450829	55.9033	-134.118	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:17:00	0	\N	-00:16:00	0.8	\N	\N	\N	Coronation Island	AK
105577	Yes Cannery, Yes Bay, Alaska	NOS	9450836	55.9133	-131.797	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:01:00	\N	0.96	00:00:00	\N	1.02	\N	\N	Yes Cannery, Yes Bay	AK
105578	El Capitan Island, Davidson Inlet, Alaska	NOS	9450851	55.9367	-133.325	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:10:00	-0.1	\N	-00:11:00	0.9	\N	\N	\N	El Capitan Island	AK
105579	Edna Bay, Davidson Inlet, Alaska	NOS	9450859	55.95	-133.662	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:08:00	0	\N	-00:20:00	0.9	\N	\N	\N	Edna Bay	AK
105580	Pole Anchorage, Kosciusko Island, Alaska	NOS	9450862	55.955	-133.81	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:22:00	-0.1	\N	-00:22:00	1.4	\N	\N	\N	Pole Anchorage, Kosciusko Island	AK
105581	Fitzgibbon Cove, Alaska	NOS	9450879	55.9833	-131.175	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	-00:01:00	\N	0.96	-00:05:00	\N	1.02	\N	\N	Fitzgibbon Cove	AK
105582	Lake Bay, Alaska	NOS	9450904	56.0233	-132.92	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:01:00	\N	0.89	00:10:00	\N	1.03	\N	\N	Lake Bay	AK
105583	Beck Island, Clarence Strait, Alaska	NOS	9450906	56.0467	-132.862	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:05:00	\N	1.01	00:10:00	\N	1.05	\N	\N	Beck Island, Clarence Strait	AK
105584	Kuiu Island, Affleck Canal, Alaska	NOS	9450913	56.0369	-134.115	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:06:00	\N	0.95	-00:09:00	\N	1.09	\N	\N	Affleck Canal entrance, Kuiu Island	AK
105585	El Capitan Passage, Alaska (sub)	NOS	9450937	56.0733	-133.313	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:02:00	-0.1	\N	-00:05:00	0.9	\N	\N	\N	El Capitan Passage, S. of Devilfish Bay	AK
105586	Thorne Island, Whale Passage, Alaska	NOS	9450938	56.0583	-132.968	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:01:00	\N	0.98	00:12:00	\N	1.04	\N	\N	Thorne Island, Whale Passage	AK
105587	Point St. Albans, Alaska	NOS	9450943	56.0817	-133.97	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:13:00	0	\N	-00:17:00	1.4	\N	\N	\N	Point St. Albans	AK
105588	Blashke Island, Clarence Strait, Alaska	NOS	9450973	56.1267	-132.895	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:24:00	\N	0.93	00:13:00	\N	1.03	\N	\N	Blashke Island	AK
105589	Shakan Bay entrance, Alaska	NOS	9450982	56.14	-133.61	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:12:00	0	\N	-00:13:00	1.8	\N	\N	\N	Shakan Bay Entrance	AK
105590	Shakan Strait, Kosciusko Island, Alaska	NOS	9450987	56.1483	-133.46	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:10:00	\N	0.95	-00:07:00	\N	1.16	\N	\N	Shakan Strait, Kosciusko Island	AK
105591	Kell Bay, Affleck Canal, Kuiu Island, Alaska	NOS	9450988	56.15	-134.133	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:01:00	0	\N	00:01:00	1.3	\N	\N	\N	Kell Bay, Affleck Canal, Kuiu Island	AK
105592	Table Bay, Kuiu Island, Alaska	NOS	9451001	56.1667	-134.245	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:13:00	0	\N	-00:15:00	1.1	\N	\N	\N	Table Bay, Kuiu Island	AK
105593	Port Beauclerc, Kuiu Island, Alaska	NOS	9451082	56.2883	-133.962	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:12:00	-0.1	\N	-00:14:00	1.9	\N	\N	\N	Port Beauclerc, Kuiu Island	AK
105594	Port Malmesbury, Kuiu Island, Alaska	NOS	9451093	56.305	-134.238	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:13:00	0.1	\N	00:04:00	1.2	\N	\N	\N	Port Malmesbury, Kuiu Island	AK
105595	Port Protection, Prince of Wales Island, Alaska	NOS	9451095	56.3083	-133.6	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:11:00	0	\N	-00:13:00	2.4	\N	\N	\N	Port Protection, Prince of Wales Island.	AK
105596	Reid Bay, Alaska	NOS	9451148	56.3883	-133.883	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:19:00	0	\N	-00:11:00	2.5	\N	\N	\N	Reid Bay	AK
105597	Port Walter, Baranof Island, Alaska	NOS	9451151	56.3917	-134.66	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:13:00	0.1	\N	00:04:00	1.5	\N	\N	\N	Port Walter, Baranof Island	AK
105598	Sumner Island, Alaska	NOS	9451163	56.41	-133.793	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:12:00	0	\N	-00:19:00	2.6	\N	\N	\N	Sumner Island	AK
105599	Greys Island, Alaska	NOS	9451238	56.5217	-132.542	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:05:00	\N	0.94	00:11:00	\N	1.01	\N	\N	Greys Island	AK
105600	Dry Strait, Frederick Sound, Alaska	NOS	9451301	56.615	-132.575	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:03:00	0	\N	-00:18:00	-0.2	\N	\N	\N	Dry Strait	AK
105601	Cosmos Point, Frederick Sound, Alaska	NOS	9451335	56.6633	-132.617	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:05:00	\N	0.99	-00:05:00	\N	0.98	\N	\N	Cosmos Point	AK
105602	Dorothy Cove, Necker Bay, Baranof Island, Alaska	NOS	9451376	56.7217	-135.075	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:02:00	\N	0.95	-00:02:00	\N	0.97	\N	\N	Dorothy Cove, Necker Bay	AK
105603	Petersburg, Wrangell Narrows, Alaska	NOS	9451439	56.815	-132.957	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103674	00:37:00	\N	0.97	00:28:00	\N	1.04	\N	\N	Petersburg	AK
105604	Symonds Bay, Biorka Island, Sitka Sound, Alaska	NOS	9451468	56.8567	-135.52	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:16:00	0	\N	-00:15:00	-0.1	\N	\N	\N	Symonds Bay, Biorka Island	AK
105605	Thomas Bay, Frederick Sound, Alaska	NOS	9451561	56.9967	-132.785	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:07:00	-0.1	\N	00:07:00	-0.8	\N	\N	\N	Thomas Bay	AK
105606	Herring Bay, Frederick Sound, Alaska	NOS	9451634	57.1133	-134.38	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:07:00	\N	0.91	-00:08:00	\N	0.84	\N	\N	Herring Bay	AK
105607	Eliza Harbor, Admiralty Island, Frederick Sound, Alaska	NOS	9451706	57.1883	-134.287	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:04:00	\N	0.92	-00:06:00	\N	0.87	\N	\N	Eliza Harbor, Admiralty Island	AK
105608	Kasnyku Bay, Alaska	NOS	9451717	57.2167	-134.868	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:06:00	-0.1	\N	-00:10:00	-2.4	\N	\N	\N	Kasnyku Bay	AK
105609	Cleveland Passage, Whitney Island, Frederick Sound, Alaska	NOS	9451718	57.2183	-133.512	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:03:00	-0.1	\N	-00:01:00	-1.2	\N	\N	\N	Cleveland Passage, Whitney Island	AK
105610	Olga Point, Olga Strait, Sitka Sound, Alaska	NOS	9451725	57.2283	-135.537	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:14:00	0	\N	00:00:00	0	\N	\N	\N	Olga Point, Olga Strait	AK
105611	Cannery Cove, Pybus Bay, Frederick Sound, Alaska	NOS	9451781	57.3067	-134.133	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:06:00	\N	0.94	-00:08:00	\N	0.9	\N	\N	Cannery Cove, Pybus Bay	AK
105612	Scraggy Point, Alaska	NOS	9451802	57.3367	-135.723	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:00:00	0.1	\N	-00:09:00	-0.1	\N	\N	\N	Scraggy Point	AK
105613	Haley Anchorage, Fish Bay, Alaska	NOS	9451826	57.3717	-135.618	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:12:00	0.1	\N	00:03:00	0.2	\N	\N	\N	Haley Anchorage, Fish Bay	AK
105614	Hobart Bay, Alaska	NOS	9451851	57.4067	-133.42	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:03:00	-0.1	\N	-00:06:00	-1.1	\N	\N	\N	Hobart Bay	AK
105615	Klokachef Island, Alaska	NOS	9451858	57.4167	-135.89	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:06:00	0.1	\N	-00:10:00	-0.1	\N	\N	\N	Klokachef Island	AK
105616	Bear Bay, Alaska	NOS	9451859	57.4183	-135.583	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:29:00	0.2	\N	00:18:00	3.7	\N	\N	\N	Bear Bay	AK
105617	Killisnoo, Alaska	NOS	9451895	57.47	-134.565	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:04:00	0	\N	-00:06:00	-2.1	\N	\N	\N	Killisnoo	AK
105618	Gambier Bay (cannery wharf), Alaska	NOS	9451906	57.4833	-133.96	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:01:00	\N	0.96	-00:01:00	\N	0.92	\N	\N	Gambier Bay (cannery wharf)	AK
105619	Good Island, Gambier Bay, Alaska	NOS	9451909	57.4867	-133.898	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:04:00	\N	0.96	-00:05:00	\N	0.93	\N	\N	Good Island, Gambier Bay	AK
105620	Windham Bay, Alaska	NOS	9451962	57.5433	-133.498	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:00:00	-0.1	\N	00:00:00	-1.1	\N	\N	\N	Windham Bay	AK
105621	Nismeni Cove, Alaska	NOS	9451979	57.5617	-135.412	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:03:00	-0.1	\N	-00:15:00	-1.3	\N	\N	\N	Nismeni Cove	AK
105622	Upper Endicott Arm, North Shore, Stephens Passage, Alaska	NOS	9452005	57.5217	-133.055	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:06:00	\N	0.99	00:01:00	\N	0.98	\N	\N	Upper Endicott Arm, North Shore	AK
105623	Sawyer Island, Tracy Arm, Alaska	NOS	9452022	57.8783	-133.19	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:06:00	\N	1.01	00:02:00	\N	0.97	\N	\N	Sawyer Island, Tracy Arm	AK
105624	Holkham Bay, Wood Spit, Alaska	NOS	9452064	57.7183	-133.578	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:06:00	-0.1	\N	00:03:00	-0.8	\N	\N	\N	Holkham Bay, Wood Spit	AK
105625	Holkham Bay, Tracy Arm entrance, Alaska	NOS	9452067	57.76	-133.603	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:02:00	\N	0.96	00:01:00	\N	0.96	\N	\N	Holkham Bay, Tracy Arm Entrance	AK
105626	Port Snettisham, Crib Point, Alaska	NOS	9452082	58.0967	-133.742	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:03:00	\N	0.97	-00:03:00	\N	0.98	\N	\N	Port Snettisham, Crib Point	AK
105627	Taku Harbor, Alaska	NOS	9452123	58.0683	-134.012	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:04:00	\N	1	-00:03:00	\N	0.97	\N	\N	Taku Harbor	AK
105628	Taku Point, Taku Inlet, Alaska	NOS	9452124	58.4	-134.015	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:13:00	0	\N	00:14:00	0.4	\N	\N	\N	Taku Point, Taku Inlet	AK
105629	Rasp Ledge, Seymour Canal, Alaska	NOS	9452128	57.6783	-134.038	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:05:00	0.1	\N	00:06:00	-0.7	\N	\N	\N	Rasp Ledge, Seymour Canal	AK
105630	Greely Point, Taku Inlet, Alaska	NOS	9452133	58.2233	-134.06	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:04:00	-0.1	\N	-00:01:00	-0.6	\N	\N	\N	Greely Point, Taku Inlet	AK
105631	Young Bay, Alaska	NOS	9452249	58.1833	-134.587	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:02:00	\N	1	00:00:00	\N	1	\N	\N	Young Bay	AK
105632	Auke Bay, Alaska	NOS	9452263	58.3817	-134.645	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:03:00	0	\N	-00:06:00	-0.4	\N	\N	\N	Auke Bay	AK
105633	Barlow Cove, Mansfield Peninsula, Lynn Canal, Alaska	NOS	9452318	58.3217	-134.878	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:01:00	\N	0.99	-00:04:00	\N	0.96	\N	\N	Barlow Cove, Mansfield Peninsula	AK
105634	Funter, Funter Bay, Lynn Canal, Alaska	NOS	9452321	58.255	-134.895	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:01:00	0	\N	00:00:00	-1.1	\N	\N	\N	Funter, Funter Bay	AK
105635	Lincoln Island, Lynn Canal, Alaska	NOS	9452336	58.4983	-134.965	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:01:00	\N	1	-00:03:00	\N	0.98	\N	\N	Lincoln Island	AK
105636	Cove Point, Berner's Bay, Lynn Canal, Alaska	NOS	9452346	58.7517	-135.028	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:00:00	\N	1.02	-00:02:00	\N	1	\N	\N	Cove Point, Berner's Bay	AK
105637	Swanson Harbor, Icy Strait, Alaska	NOS	9452368	58.215	-135.127	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	00:11:00	\N	1.08	00:14:00	\N	1.41	\N	\N	Swanson Harbor	AK
105638	Tenakee Springs, Tenakee Inlet, Alaska (sub)	NOS	9452386	57.77930555555555	-135.2194722222222	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:05:00	-0.1	\N	-00:04:00	-1.5	\N	\N	\N	Tenakee Springs, Tenakee Inlet	AK
105639	William Henry Bay, Lynn Canal, Alaska	NOS	9452391	58.7133	-135.232	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:09:00	0	\N	00:02:00	-0.5	\N	\N	\N	William Henry Bay	AK
105640	Taiyasanka Harbor, Taiya Inlet, Lynn Canal, Alaska	NOS	9452434	59.3017	-135.428	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:02:00	\N	1.01	-00:04:00	\N	1.03	\N	\N	Taiyasanka Harbor, Taiya Inlet	AK
105641	Haines Inlet, Lynn Canal, Alaska	NOS	9452435	59.23	-135.433	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:06:00	0	\N	-00:09:00	0.5	\N	\N	\N	Haines Inlet	AK
105642	Excursion Inlet entrance, Icy Strait, Alaska	NOS	9452437	58.4167	-135.447	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	00:16:00	\N	1.05	00:15:00	\N	1.38	\N	\N	Excursion Inlet Entrance	AK
105643	Excursion Inlet, Icy Strait, Alaska	NOS	9452447	58.4967	-135.488	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	00:24:00	\N	1.07	00:26:00	\N	1.36	\N	\N	Excursion Inlet, North End	AK
105644	Point Adolphus, Icy Strait, Alaska	NOS	9452516	58.2867	-135.803	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	00:35:00	\N	1.11	00:29:00	\N	1.31	\N	\N	Point Adolphus	AK
105645	Mud Bay, Goose Island, Icy Strait, Alaska	NOS	9452567	58.2117	-136.035	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	00:06:00	\N	0.96	00:06:00	\N	1.2	\N	\N	Mud Bay, Goose Island	AK
105646	Elbow Passage, Klag Bay, Chichagof Island, Alaska	NOS	9452579	57.6133	-136.087	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	00:13:00	\N	1.03	00:08:00	\N	0.98	\N	\N	Elbow Passage, Klag Bay	AK
105647	Kimshan Cove, Ogden Passage, Chichagof Island, Alaska	NOS	9452583	57.6867	-136.107	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	00:06:00	\N	1.03	00:05:00	\N	0.92	\N	\N	Kimshan Cove, Ogden Passage	AK
105648	Muir Inlet, Glacier Bay, Alaska (sub)	NOS	9452584	58.9133	-136.108	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	00:49:00	\N	1.19	00:39:00	\N	1.55	\N	\N	Muir Inlet	AK
105649	Willoughby Island, Glacier Bay, Alaska	NOS	9452586	58.6083	-136.117	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	00:50:00	\N	1.16	00:41:00	\N	1.5	\N	\N	Willoughby Island	AK
105650	Inian Cove, North Inian Pass, Cross Sound, Alaska	NOS	9452629	58.2633	-136.325	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	00:03:00	\N	1.01	00:12:00	\N	1.05	\N	\N	Inian Cove, North Inian Pass	AK
105651	Wachusett Inlet, Glacier Bay, Alaska	NOS	9452632	58.9467	-136.333	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	00:50:00	\N	1.2	00:39:00	\N	1.57	\N	\N	Wachusett Inlet, Glacier Bay	AK
105654	Takanis Bay, Yakobi Island, outer coast, Alaska	NOS	9452671	57.9283	-136.52	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	-00:01:00	\N	1.03	-00:04:00	\N	0.9	\N	\N	Takanis Bay	AK
105655	Surge Bay, Yakobi Island, outer coast, Alaska	NOS	9452672	58.0183	-136.528	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	00:02:00	\N	0.96	00:00:00	\N	0.88	\N	\N	Surge Bay	AK
105653	Canoe Cove, North Pass, Lisianski Strait, Alaska	NOS	9452649	57.8467	-136.422	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	-00:01:00	\N	0.89	00:02:00	\N	0.91	\N	\N	Canoe Cove, North Pass	AK
105656	Composite Island, Glacier Bay, Alaska	NOS	9452682	58.8883	-136.573	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	00:51:00	\N	1.2	00:45:00	\N	1.54	\N	\N	Composite Island	AK
105657	Graves Harbor, Alaska	NOS	9452704	58.2767	-136.678	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	00:07:00	\N	1.03	00:04:00	\N	0.91	\N	\N	Graves Harbor	AK
105658	Dixon Harbor, Alaska	NOS	9452747	58.3833	-136.867	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	00:07:00	\N	0.96	00:07:00	\N	0.89	\N	\N	Dixon Harbor	AK
105659	Lituya Bay, 2 mi inside entrance, Alaska	NOS	9452928	58.6167	-137.65	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	00:36:00	\N	0.89	00:06:00	\N	0.87	\N	\N	Lituya Bay, 2 miles inside entrance	AK
105660	Redfield Cove, Yakutat Bay, Alaska	NOS	9453208	59.6117	-139.58	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103727	00:00:00	\N	0.92	00:01:00	\N	1	\N	\N	Redfield Cove, Yakutat Bay	AK
105661	Point Latouche, Yakutat Bay, Alaska	NOS	9453210	59.9033	-139.627	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103727	00:03:00	\N	0.93	00:06:00	\N	1	\N	\N	Point Latouche, Yakutat Bay	AK
105662	Johnstone Passage, Yakutat Bay, Alaska	NOS	9453215	59.5817	-139.702	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103727	00:03:00	\N	1	00:01:00	\N	1	\N	\N	Johnstone Passage, Yakutat Bay	AK
105663	Riou Bay, Alaska	NOS	9453456	59.885	-141.457	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103727	00:03:00	\N	1.01	00:02:00	\N	0.98	\N	\N	Icy Bay	AK
105664	Shag Rock, Orca Inlet, Alaska	NOS	9454125	60.465	-145.988	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:16:00	-0.1	\N	-00:11:00	-1.1	\N	\N	\N	Shag Rock	AK
105665	Comfort Cove, Port Gravina, Prince William Sound, Alaska	NOS	9454157	60.71	-146.085	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:06:00	-0.1	\N	-00:16:00	-0.7	\N	\N	\N	Comfort Cove, Port Gravina	AK
105666	Middleton Island (north end), Alaska	NOS	9454224	59.4617	-146.31	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:14:00	-0.1	\N	-00:21:00	-2.2	\N	\N	\N	Middleton Island (north end)	AK
105667	Landlocked Bay, Port Fidalgo, Prince William Sound, Alaska	NOS	9454296	60.8533	-146.535	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:08:00	-0.1	\N	-00:12:00	-0.7	\N	\N	\N	Landlocked Bay, Port Fidalgo	AK
105668	Jack Bay, Valdez Arm, Alaska	NOS	9454309	61.04	-146.615	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103732	-00:02:00	\N	0.99	-00:01:00	\N	0.99	\N	\N	Jack Bay	AK
105669	Johnstone Point, Hinchinbrook Island, Alaska	NOS	9454319	60.4817	-146.61	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	00:02:00	-0.1	\N	-00:07:00	-0.8	\N	\N	\N	Johnstone Point	AK
105670	Rocky Point, Valdez Arm, Alaska	NOS	9454363	60.94670104980469	-146.7550048828125	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103732	-00:03:00	\N	0.99	00:00:00	\N	0.99	\N	\N	Rocky Point	AK
105671	Busby Island, Valdez Arm, Alaska	NOS	9454374	60.8983	-146.782	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103732	-00:02:00	\N	0.98	-00:02:00	\N	0.98	\N	\N	Busby Island	AK
105672	Jackson Cove, Glacier Island, Prince William Sound, Alaska	NOS	9454507	60.88	-147.223	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:02:00	0	\N	-00:10:00	-0.6	\N	\N	\N	Jackson Cove, Glacier Island	AK
105673	Port Chalmers, Montague Island, Alaska	NOS	9454511	60.2418	-147.249	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:01:00	\N	0.97	-00:02:00	\N	0.94	\N	\N	Port Chalmers	AK
105674	Naked Island, McPherson Passage, Prince William Sound, Alaska	NOS	9454563	60.6833	-147.388	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:08:00	-0.1	\N	-00:18:00	-0.7	\N	\N	\N	Naked Island, McPherson Passage	AK
105675	Gibbon Anchorage, Green Island, Prince William Sound, Alaska	NOS	9454573	60.27	-147.438	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:06:00	-0.2	\N	-00:21:00	-0.8	\N	\N	\N	Gibbon Anchorage, Green Island	AK
105676	Patton Bay, Montague Island, Alaska	NOS	9454574	59.9067	-147.45	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:05:00	-0.1	\N	-00:12:00	-2.3	\N	\N	\N	Patton Bay	AK
105677	Louis Bay, Knight Island, Prince William Sound, Alaska	NOS	9454642	60.4617	-147.672	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	00:03:00	\N	1.04	00:00:00	\N	0.96	\N	\N	Louis Bay	AK
105678	Point Helen, Knight Island, Alaska	NOS	9454671	60.1533	-147.767	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:01:00	\N	1	-00:03:00	\N	0.92	\N	\N	Point Helen	AK
105679	Port Audrey, Knight Island, Alaska	NOS	9454673	60.3433	-147.768	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	00:03:00	\N	0.95	00:00:00	\N	0.92	\N	\N	Port Audrey	AK
105680	Macleod Harbor, Montague Island, Prince William Sound, Alaska	NOS	9454674	59.88999938964844	-147.7949981689453	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:04:00	\N	0.96	00:10:00	\N	0.89	\N	\N	Macleod Harbor	AK
105681	Latouche, Latouche Island, Prince William Sound, Alaska	NOS	9454713	60.0533	-147.907	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:02:00	0	\N	-00:05:00	-1	\N	\N	\N	Latouche, Latouche Island	AK
105682	Eshamy Bay, Knight Island Passage, Prince William Sound, Alaska	NOS	9454735	60.4483	-147.978	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	00:04:00	0	\N	00:01:00	-0.4	\N	\N	\N	Eshamy Bay, Knight Island Passage	AK
105683	Eshamy Lagoon, Prince William Sound, Alaska	NOS	9454757	60.4617	-148.045	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	00:00:00	\N	1.03	-00:11:00	\N	0.92	\N	\N	Eshamy Lagoon	AK
105684	Sawmill Bay, Evans Island, Prince William Sound, Alaska	NOS	9454764	60.0517	-148.065	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	00:03:00	0	\N	-00:03:00	-1.2	\N	\N	\N	Sawmill Bay, Evans Island	AK
105685	Chenega Island, southwest end, Prince William Sound, Alaska	NOS	9454777	60.2833	-148.113	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	00:00:00	\N	1	-00:03:00	\N	0.94	\N	\N	Chenega Island, southwest end	AK
105686	Chenega Island, Dangerous Passage, Prince William Sound, Alaska	NOS	9454787	60.33	-148.143	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	00:06:00	0	\N	-00:01:00	-0.9	\N	\N	\N	Chenega Island, Dangerous Passage	AK
105687	Applegate Island, Prince William Sound, Alaska	NOS	9454794	60.6233	-148.165	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	00:06:00	0	\N	-00:01:00	-0.6	\N	\N	\N	Applegate Island	AK
105688	Culross Bay, Wells Passage, Prince William Sound, Alaska	NOS	9454798	60.7417	-148.172	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:01:00	0	\N	-00:15:00	-0.4	\N	\N	\N	Culross Bay, Wells Passage	AK
105689	Hogg Bay, Port Bainbridge, Prince William Sound, Alaska	NOS	9454805	60.0767	-148.195	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:03:00	-0.1	\N	-00:12:00	-1.9	\N	\N	\N	Hogg Bay, Port Bainbridge	AK
105690	Long Bay entrance, Culross Passage, Prince William Sound, Alaska	NOS	9454825	60.6917	-148.263	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	00:09:00	-0.1	\N	00:03:00	-0.9	\N	\N	\N	Long Bay Entrance, Culross Passage	AK
105691	Kings Bay, Port Nellie Juan, Prince William Sound, Alaska	NOS	9454887	60.5417	-148.46	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	00:09:00	0	\N	-00:01:00	-0.6	\N	\N	\N	Kings Bay, Port Nellie Juan	AK
105692	Day Harbor, Alaska	NOS	9455036	60.01	-149.062	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103748	00:00:00	\N	1.01	-00:02:00	\N	0.99	\N	\N	Day Harbor	AK
105693	Bear Cove, Aialik Peninsula, Alaska	NOS	9455128	59.8017	-149.615	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103748	00:01:00	\N	0.97	00:01:00	\N	1	\N	\N	Bear Cove, Aialik Peninsula	AK
105694	Two Arm Bay, Harris Bay, Alaska	NOS	9455217	59.6617	-150.108	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103748	-00:05:00	\N	0.94	-00:10:00	\N	1.03	\N	\N	Two Arm Bay, Harris Bay	AK
105695	Chance Cove (Lagoon), Alaska	NOS	9455249	59.4883	-150.312	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103748	00:01:00	\N	1.01	00:00:00	\N	1.04	\N	\N	Chance Cove (Lagoon)	AK
105696	Beauty Bay, Nuka Bay, Alaska	NOS	9455304	59.5267	-150.628	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103748	00:14:00	\N	1.01	00:12:00	\N	1.08	\N	\N	Beauty Bay, Nuka Bay	AK
105697	Nuka Passage, Alaska	NOS	9455308	59.4083	-150.667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103748	00:12:00	\N	1.01	00:11:00	\N	1.09	\N	\N	Nuka Passage	AK
105698	Takoma Cove, Port Dick, Alaska	NOS	9455347	59.2617	-150.982	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103748	00:18:00	\N	1.01	00:23:00	\N	1.15	\N	\N	Takoma Cove, Port Dick	AK
105699	Picnic Harbor, Rocky Bay, Alaska	NOS	9455399	59.255	-151.42	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103748	00:21:00	\N	1.01	00:26:00	\N	1.23	\N	\N	Picnic Harbor, Rocky Bay	AK
105700	Port Chatham, Cook Inlet, Alaska	NOS	9455428	59.2133	-151.728	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	-00:34:00	\N	0.92	-00:28:00	\N	0.78	\N	\N	Port Chatham	AK
105701	Port Graham, Cook Inlet, Alaska	NOS	9455437	59.35	-151.8266666666667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	-00:14:00	0	\N	-00:08:00	-1	\N	\N	\N	Port Graham	AK
105702	Ushagat Island, Barren Islands, Cook Inlet, Alaska	NOS	9455478	58.9467	-152.268	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	-00:04:00	\N	0.76	-00:08:00	\N	0.76	\N	\N	Ushagat Island, Barren Islands	AK
105703	Tutka Bay,Kachemak Bay, Cook Inlet, Alaska	NOS	9455506	59.4317	-151.357	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	-00:01:00	0	\N	-00:01:00	0.2	\N	\N	\N	Tutka Bay,Kachemak Bay	AK
105704	Sadie Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455514	59.49	-151.365	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	-00:04:00	-0.1	\N	-00:04:00	0.1	\N	\N	\N	Sadie Cove, Kachemak Bay	AK
105705	Halibut Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455556	59.5967	-151.22	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	-00:05:00	0	\N	-00:03:00	0.7	\N	\N	\N	Halibut Cove, Kachemak Bay	AK
105706	Drift River Terminal, Cook Inlet, Alaska	NOS	9455741	60.555	-152.133	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	02:04:00	\N	1.18	01:39:00	\N	1.01	\N	\N	Drift River Terminal	AK
105707	Kenai City Pier, Cook Inlet, Alaska	NOS	9455742	60.545	-151.218	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	02:55:00	-0.1	\N	01:54:00	1.9	\N	\N	\N	Kenai City Pier	AK
105708	Snug Harbor, Cook Inlet, Alaska	NOS	9456173	60.10747222222222	-152.5816666666667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	01:15:00	0	\N	01:04:00	-2.3	\N	\N	\N	Snug Harbor, Cook Inlet	AK
105709	Tuxedni Channel, Cook Inlet, Alaska	NOS	9456204	60.1533	-152.635	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	00:53:00	0.2	\N	00:39:00	-1.3	\N	\N	\N	Tuxedni Channel	AK
105710	Oil Bay, Kamishak Bay, Cook Inlet, Alaska	NOS	9456463	59.64	-153.262	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	01:16:00	\N	0.83	01:15:00	\N	0.77	\N	\N	Oil Bay, Kamishak Bay	AK
105711	Nordyke Island, Kamishak Bay, Cook Inlet, Alaska	NOS	9456822	59.1783	-154.087	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	00:22:00	-0.2	\N	00:10:00	-2.8	\N	\N	\N	Nordyke Island, Kamishak Bay	AK
105712	Kukak, Kukak Bay, Alaska	NOS	9456835	58.3417	-154.117	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	00:05:00	\N	0.74	-00:08:00	\N	0.74	\N	\N	Kukak, Kukak Bay	AK
105713	Takli Island, Shelikof Strait, Alaska	NOS	9456992	58.0633	-154.477	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	00:03:00	\N	1	-00:09:00	\N	0.73	\N	\N	Takli Island, Shelikof Strait	AK
105714	Tonki Bay, Alaska	NOS	9457152	58.31669998168945	-152.06700134277344	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:21:00	0.2	\N	00:12:00	2.3	\N	\N	\N	Tonki Bay	AK
105715	Seal Bay, Alaska	NOS	9457201	58.3717	-152.238	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:36:00	0.3	\N	00:29:00	2.4	\N	\N	\N	Seal Bay	AK
105716	Andreon Bay, Shuyak Island, Alaska	NOS	9457259	58.5183	-152.415	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:44:00	0.3	\N	00:35:00	2.5	\N	\N	\N	Andreon Bay, Shuyak Island	AK
105717	Kodiak, Port of Kodiak, Alaska	NOS	9457261	57.7833	-152.428	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	-00:02:00	0	\N	-00:03:00	0	\N	\N	\N	Kodiak, Port of Kodiak	AK
105718	Spruce Island (north side), Alaska	NOS	9457262	57.9383	-152.417	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:08:00	0.1	\N	00:02:00	0.4	\N	\N	\N	Spruce Island (north side)	AK
105719	Perenosa Bay, Afognak Island, Alaska	NOS	9457271	58.3567	-152.448	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:39:00	0.3	\N	00:28:00	2.5	\N	\N	\N	Perenosa Bay	AK
105720	Kodiak, St. Paul Harbor, Alaska	NOS	9457283	57.745	-152.483	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	-00:02:00	0	\N	-00:05:00	-0.1	\N	\N	\N	Kodiak, St. Paul Harbor	AK
105721	Carry Inlet, Shuyak Island, Alaska	NOS	9457293	58.5867	-152.513	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	00:07:00	\N	0.73	00:06:00	\N	0.73	\N	\N	Carry Inlet	AK
105722	Redfox Bay, Shuyak Strait, Alaska	NOS	9457316	58.4533	-152.595	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	-00:02:00	-0.2	\N	-00:14:00	-4.4	\N	\N	\N	Redfox Bay, Shuyak Strait	AK
105723	Big Bay, Shuyak Island, Alaska	NOS	9457321	58.555	-152.613	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	00:15:00	\N	0.77	00:10:00	\N	0.77	\N	\N	Big Bay	AK
105724	Ugak Bay (Saltery Cove), Alaska	NOS	9457351	57.4817	-152.718	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	-00:20:00	-0.1	\N	-00:29:00	-0.3	\N	\N	\N	Ugak Bay (Saltery Cove)	AK
105725	Fox Bay, Whale Island, Alaska	NOS	9457361	57.9783	-152.755	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:37:00	0.2	\N	00:22:00	1.2	\N	\N	\N	Fox Bay, Whale Island	AK
105726	Kizhuyak Bay, Alaska	NOS	9457401	57.82	-152.9	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:11:00	0	\N	00:06:00	0.8	\N	\N	\N	Kizhuyak Bay	AK
105727	Port Hobron, Sitkalidak Island, Alaska	NOS	9457479	57.1633	-153.152	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	-00:06:00	0.1	\N	-00:18:00	-0.3	\N	\N	\N	Port Hobron, Sitkalidak Island	AK
105728	Dolphin Point, Raspberry Strait, Alaska	NOS	9457481	58.11	-153.155	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	-00:05:00	-0.1	\N	-00:25:00	-4.1	\N	\N	\N	Dolphin Point, Raspberry Strait	AK
105729	Zachar Bay, Uyak Bay, Alaska	NOS	9457648	57.5483	-153.735	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	00:00:00	\N	0.77	-00:09:00	\N	0.77	\N	\N	Zachar Bay	AK
105730	Mining Camp, Uyak Bay, Alaska	NOS	9457671	57.46	-153.817	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	-00:10:00	-0.1	\N	-00:37:00	-4.1	\N	\N	\N	Mining Camp	AK
105731	Moser Bay (Trap Point), Alaska	NOS	9457773	57.0017	-154.148	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103789	00:10:00	\N	1.01	00:11:00	\N	0.99	\N	\N	Moser Bay (Trap Point)	AK
105732	Olga Bay (A. P. A. Cannery), Alaska	NOS	9457798	57.1617	-154.228	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103789	03:54:00	\N	0.06	03:46:00	\N	0.1	\N	\N	Olga Bay (A. P. A. Cannery)	AK
105733	Kanatak Lagoon, Portage Bay, Alaska	NOS	9458365	57.52000045776367	-156.052001953125	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:51:00	0.3	\N	00:21:00	3	\N	\N	\N	Kanatak Lagoon, Portage Bay	AK
105734	Unavikshak Island, Alaska	NOS	9458762	56.4917	-157.74	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:44:00	\N	1.24	00:31:00	\N	1.05	\N	\N	Unavikshak Island	AK
105735	Nakchamik Island, Alaska	NOS	9458779	56.3517	-157.812	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:41:00	\N	1.33	00:29:00	\N	1.04	\N	\N	Nakchamik Island	AK
105736	Kujulik Bay (North Shore), Alaska	NOS	9458819	56.6133	-157.983	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:46:00	\N	1.35	00:31:00	\N	1.1	\N	\N	Kujulik Bay (North Shore)	AK
105737	Chankliut Island, Alaska	NOS	9458849	56.1467	-158.107	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:43:00	\N	1.27	00:32:00	\N	0.98	\N	\N	Chankliut Island	AK
105738	Chignik, Anchorage Bay, Alaska	NOS	9458917	56.2967	-158.4	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:44:00	\N	1.28	00:34:00	\N	1.04	\N	\N	Chignik, Anchorage Bay	AK
105739	Chiachi Island (east side), Alaska	NOS	9459085	55.8433	-159.105	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:37:00	\N	1.28	00:22:00	\N	0.89	\N	\N	Chiachi Island (east side)	AK
105740	Kupreanof Harbor, Paul Island, Alaska	NOS	9459145	55.79	-159.35	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:35:00	\N	1.28	00:19:00	\N	0.89	\N	\N	Kupreanof Harbor, Paul Island	AK
105741	Dent Point, Stepovak Bay, Alaska	NOS	9459281	55.7833	-159.88	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:33:00	\N	1.19	00:17:00	\N	0.86	\N	\N	Dent Point, Stepovak Bay	AK
105742	Sanborn Harbor, Nagai Island, Shumagin Islands, Alaska	NOS	9459311	55.155	-159.995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103799	-00:03:00	\N	0.98	00:03:00	\N	1	\N	\N	Sanborn Harbor, Nagai Island	AK
105743	Pirate Cove, Popof Island, Shumagin Islands, Alaska	NOS	9459398	55.3617	-160.36	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103799	00:03:00	\N	0.98	00:08:00	\N	1.03	\N	\N	Pirate Cove, Popof Island	AK
105744	Albatross Anchorage, Balboa Bay, Alaska	NOS	9459464	55.59	-160.613	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103799	00:03:00	\N	1.05	-00:02:00	\N	1.06	\N	\N	Albatross Anchorage, Balboa Bay	AK
105745	Beaver Bay, Alaska	NOS	9459522	55.4733	-160.84	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:02:00	\N	1.05	00:03:00	\N	1.01	\N	\N	Beaver Bay	AK
105746	Seal Cape, Coal Bay, Alaska	NOS	9459643	55.365	-161.325	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103799	00:05:00	\N	1.05	00:00:00	\N	0.98	\N	\N	Seal Cape, Coal Bay	AK
105747	Ukolnoi Island, Alaska	NOS	9459696	55.2583	-161.537	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103799	00:00:00	\N	0.98	00:07:00	\N	0.97	\N	\N	Ukolnoi Island	AK
105915	Wotje Atoll, Marshall Islands	NOS	TPT2715	9.466666666666704	170.2333333333299	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:11:00	-0.2	\N	-00:11:00	-0.2	\N	\N	\N	Wotje Atoll	MH
105748	Lenard Harbor, Cold Bay, Alaska	NOS	9459895	55.1183	-162.378	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103799	00:17:00	\N	0.98	00:12:00	\N	0.98	\N	\N	Lenard Harbor, Cold Bay	AK
105749	Peterson Bay, Sanak Islands, Alaska	NOS	9459939	54.3933	-162.637	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103799	-00:08:00	\N	1.05	-00:05:00	\N	0.83	\N	\N	Peterson Bay	AK
105750	Sanak Harbor, Sanak Islands, Alaska	NOS	9459968	54.4817	-162.812	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103799	00:03:00	\N	1.05	00:14:00	\N	0.89	\N	\N	Sanak Harbor	AK
105751	Ogliuga Island (east coast), Delarof Islands, Alaska	NOS	9461081	51.6033	-178.617	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-00:43:00	\N	0.95	00:01:00	\N	0.95	\N	\N	Ogliuga Island (east coast)	AK
105752	Lash Bay, Tanaga Island, Alaska	NOS	9461132	51.6717	-178.045	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-01:39:00	\N	1.14	-00:56:00	\N	1.14	\N	\N	Lash Bay	AK
105753	Tanaga Bay, Tanaga Island, Alaska	NOS	9461138	51.7183	-177.997	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-00:32:00	\N	1.08	-00:06:00	\N	1.08	\N	\N	Tanaga Bay	AK
105754	Hot Springs Bay, Tanaga Island, Alaska	NOS	9461162	51.7783	-177.8	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-00:12:00	\N	0.84	-00:40:00	\N	0.84	\N	\N	Hot Springs Bay	AK
105755	Cape Chunu, Kanaga Island, Alaska	NOS	9461183	51.665	-177.637	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-01:54:00	\N	1.11	-01:44:00	\N	1.11	\N	\N	Cape Chunu	AK
105756	Kanaga Bay, Kanaga Island, Alaska	NOS	9461264	51.7183	-177.2	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-01:44:00	\N	1.05	-01:39:00	\N	1.05	\N	\N	Kanaga Bay	AK
105757	Cape Chlanak, Kanaga Island, Alaska	NOS	9461276	51.71	-177.145	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-01:34:00	\N	0.92	-01:22:00	\N	0.92	\N	\N	Cape Chlanak	AK
105758	Shoal Point, Kanaga Island, Alaska	NOS	9461292	51.87	-177.068	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-00:16:00	\N	0.86	00:01:00	\N	0.86	\N	\N	Shoal Point	AK
105759	Bay of Waterfalls, Adak Island, Alaska	NOS	9461337	51.6417	-176.825	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-02:04:00	\N	0.95	-01:20:00	\N	0.95	\N	\N	Bay of Waterfalls	AK
105760	Unalga Bight, Adak Island, Alaska	NOS	9461341	51.78	-176.807	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-00:21:00	\N	0.97	-00:07:00	\N	0.97	\N	\N	Unalga Bight	AK
105761	Boot Bay, Adak Island, Alaska	NOS	9461391	51.7133	-176.53	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-02:09:00	\N	0.97	-01:38:00	\N	0.97	\N	\N	Boot Bay	AK
105762	Adak Bight, Adak Island, Alaska	NOS	9461406	51.77	-176.435	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-02:02:00	\N	1	-01:24:00	\N	1	\N	\N	Adak Bight	AK
105763	Laska Cove, Kagalaska Island, Aleutian Islands, Alaska	NOS	9461411	51.825	-176.402	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	00:07:00	\N	0.97	-00:04:00	\N	0.97	\N	\N	Laska Cove, Kagalaska Island	AK
105764	Sand Bay, Great Sitkin Island, Aleutian Islands, Alaska	NOS	9461453	51.9733	-176.085	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-00:20:00	\N	0.97	-00:05:00	\N	0.97	\N	\N	Sand Bay, Great Sitkin Island	AK
105765	Bugle Point, Great Sitkin Island, Aleutian Islands, Alaska	NOS	9461467	52.0383	-175.98	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-00:05:00	\N	0.89	00:01:00	\N	0.89	\N	\N	Bugle Point, Great Sitkin Island	AK
105766	Fenimore Pass, Aleutian Islands, Alaska	NOS	9461519	51.96	-175.588	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-00:13:00	\N	0.89	-00:04:00	\N	0.89	\N	\N	Fenimore Pass	AK
105767	Atka Pass, east end, Atka Island, Alaska	NOS	9461555	52.0067	-175.32	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-02:10:00	\N	1.24	-01:07:00	\N	1.24	\N	\N	Atka Pass, east end	AK
105768	Bechevin Bay, Atka Island, Alaska	NOS	9461582	52.0367	-175.115	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	00:04:00	\N	0.95	00:11:00	\N	0.95	\N	\N	Bechevin Bay	AK
105769	Explorer Bay, Atka Island, Alaska	NOS	9461656	52.0733	-174.568	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-02:24:00	\N	1.24	-02:43:00	\N	1.24	\N	\N	Explorer Bay	AK
105770	Sagchudak Island, Atka Island, Alaska	NOS	9461667	52.0267	-174.48	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-02:25:00	\N	1.24	-01:26:00	\N	1.24	\N	\N	Sagchudak Island	AK
105771	Martin Harbor, Korovin Bay, Atka Island, Alaska	NOS	9461693	52.2267	-174.292	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	00:21:00	\N	0.87	00:19:00	\N	0.87	\N	\N	Martin Harbor, Korovin Bay	AK
105772	Cape Utalug (4 mi west of), Atka Island, Alaska	NOS	9461704	52.1183	-174.207	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-02:32:00	\N	1.19	-01:38:00	\N	1.19	\N	\N	Cape Utalug (4 miles west of)	AK
105773	Finch Cove, Seguam Island, Aleutian Islands, Alaska	NOS	9461945	52.3917	-172.405	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	00:07:00	\N	0.87	-01:00:00	\N	0.87	\N	\N	Finch Cove, Seguam Island	AK
105774	North side, Yunaska Island, Alaska	NOS	9462144	52.6817	-170.707	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-01:29:00	\N	1.19	-01:05:00	\N	1.02	\N	\N	North side	AK
105775	East Cove, Yunaska Island, Alaska	NOS	9462161	52.6533	-170.563	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-02:35:00	\N	0.85	-01:36:00	\N	0.88	\N	\N	East Cove	AK
105776	Applegate Cove, Chuginadak Island, Aleutian Islands, Alaska	NOS	9462239	52.8617	-169.862	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-00:58:00	\N	1.27	-00:21:00	\N	1.08	\N	\N	Applegate Cove, Chuginadak Island	AK
105777	Adugak Island, Aleutian Islands, Alaska	NOS	9462317	52.9117	-169.165	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-00:56:00	\N	1.1	-00:33:00	\N	1.02	\N	\N	Adugak Island	AK
105778	Cape Sagak, Umnak Island, Alaska	NOS	9462331	52.8417	-169.043	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-03:16:00	\N	1.02	-03:03:00	\N	1.2	\N	\N	Cape Sagak	AK
105779	Okee Bay, Umnak Island, Alaska	NOS	9462354	53.0167	-168.835	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-00:43:00	\N	1.1	-00:07:00	\N	0.99	\N	\N	Okee Bay	AK
105780	Driftwood Bay, Umnak Island, Alaska	NOS	9462367	52.9583	-168.72	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-03:22:00	\N	1.1	-02:56:00	\N	1.35	\N	\N	Driftwood Bay	AK
105781	Kigul Island, Umnak Island, Alaska	NOS	9462398	53.045	-168.442	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-03:42:00	\N	1.27	-03:04:00	\N	1.37	\N	\N	Kigul Island	AK
105782	Inanudak Bay, Umnak Island, Alaska	NOS	9462408	53.2967	-168.352	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-00:30:00	\N	0.93	-00:06:00	\N	0.96	\N	\N	Inanudak Bay	AK
105783	Bogoslof Island, Aleutian Islands, Alaska	NOS	9462444	53.93	-168.033	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-00:55:00	\N	1.1	-00:30:00	\N	1.08	\N	\N	Bogoslof Island	AK
105784	Otter Point, Umnak Island, Alaska	NOS	9462465	53.3967	-167.843	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-00:40:00	\N	0.93	-00:27:00	\N	0.88	\N	\N	Otter Point	AK
105785	Chernofski Harbor, Unalaska Island, Alaska	NOS	9462501	53.395	-167.533	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-00:29:00	\N	1.1	-00:10:00	\N	1.02	\N	\N	Chernofski Harbor	AK
105786	Skan Bay, Unalaska Island, Alaska	NOS	9462554	53.61	-167.045	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-00:19:00	\N	1.1	-00:07:00	\N	1.05	\N	\N	Skan Bay	AK
105787	Kuliliak Bay, Unalaska Island, Alaska	NOS	9462557	53.4617	-167.02	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-03:35:00	\N	1.27	-03:10:00	\N	1.46	\N	\N	Kuliliak Bay	AK
105788	Raven Bay, Unalaska Island, Alaska	NOS	9462573	53.475	-166.873	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-03:48:00	\N	1.27	-03:16:00	\N	1.49	\N	\N	Raven Bay	AK
105789	Anderson Bay, Unalaska Island, Alaska	NOS	9462578	53.6783	-166.832	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	00:28:00	\N	1.1	-00:01:00	\N	1.08	\N	\N	Anderson Bay	AK
105790	Usof Bay, Unalaska Island, Alaska	NOS	9462582	53.515	-166.79	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-03:45:00	\N	1.19	-03:30:00	\N	1.55	\N	\N	Usof Bay	AK
105791	Kisselen Bay, Beaver Inlet, Unalaska Island, Alaska	NOS	9462606	53.7133	-166.572	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-03:14:00	\N	1.1	-02:59:00	\N	1.4	\N	\N	Kisselen Bay, Beaver Inlet	AK
105792	Dutch Harbor, Amaknak Island, Unalaska Island, Alaska	NOS	9462611	53.8917	-166.537	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-00:07:00	\N	1	00:00:00	\N	1	\N	\N	Dutch Harbor, Amaknak Island	AK
105793	Udagak Strait, Unalaska Island, Alaska	NOS	9462637	53.7367	-166.295	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-03:59:00	\N	1.02	-03:32:00	\N	1.37	\N	\N	Udagak Strait	AK
105794	English Bay, Unalaska Island, Alaska	NOS	9462641	53.925	-166.257	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-00:01:00	\N	0.76	00:16:00	\N	0.79	\N	\N	English Bay	AK
105795	Akutan Harbor, Akutan Island, Aleutian Islands, Alaska	NOS	9462691	54.1283	-165.808	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-00:07:00	\N	1.1	-00:17:00	\N	1.08	\N	\N	Akutan Harbor, Akutan Island	AK
105796	Cape Mordvinof, Unimak Island, Alaska	NOS	9462838	54.9283	-164.467	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	00:19:00	\N	1.36	00:26:00	\N	1.73	\N	\N	Cape Mordvinof	AK
105797	St. Catherine Cove, Unimak Island, Alaska	NOS	9462944	55.01	-163.507	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-00:18:00	\N	1.36	00:04:00	\N	1.23	\N	\N	St. Catherine Cove	AK
105798	Dora Harbor, Unimak Island, Alaska	NOS	9462971	54.71	-163.267	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103799	00:15:00	\N	1.05	00:15:00	\N	0.87	\N	\N	Dora Harbor	AK
105799	Amak Island, Bristol Bay, Alaska	NOS	9462987	55.4133	-163.115	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	01:48:00	\N	1.78	01:47:00	\N	2.13	\N	\N	Amak Island	AK
105800	Grant Point, Izembek Lagoon, Bristol Bay, Alaska	NOS	9463058	55.27	-162.9	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	04:05:00	\N	0.85	03:03:00	\N	1.23	\N	\N	Grant Point, Izembek Lagoon	AK
105801	Settlement Point, Pavlof Bay, Alaska	NOS	9463195	55.5	-161.46666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103799	00:08:00	\N	0.9	00:09:00	\N	0.98	\N	\N	Settlement Point, Pavlof Bay	AK
105802	Egegik River entrance, Alaska	NOS	9464881	58.2383	-157.5	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103826	03:47:00	\N	1.14	03:16:00	\N	1.69	\N	\N	Egegik River Ent, Bristol Bay	AK
105803	Middle Bluff, Kvichak Bay, Bristol Bay, Alaska	NOS	9465022	58.4533	-157.5	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103826	04:10:00	\N	1.14	03:56:00	\N	1.84	\N	\N	Middle Bluff, Kvichak Bay	AK
105804	King Salmon Airport, Naknek River, Alaska	NOS	9465149	58.67169952392578	-156.65699768066406	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103837	00:23:00	\N	0.67	-02:11:00	\N	0.17	\N	\N	King Salmon Airport	AK
105805	Omakstalia Point, Naknek River, Alaska	NOS	9465174	58.70669937133789	-156.7570037841797	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103837	-00:48:00	\N	1.03	-02:54:00	\N	0.44	\N	\N	Omakstalia Point	AK
105806	Black Rock, Walrus Islands, Nushagak Bay, Alaska	NOS	9465182	58.70830154418945	-160.18800354003906	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103826	04:53:00	\N	0.82	04:53:00	\N	0.8	\N	\N	Black Rock, Walrus Islands	AK
105807	Kvichak, Kvichak River, Alaska	NOS	9465342	58.97	-156.947	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103826	07:49:00	\N	0.41	05:21:00	\N	1.54	\N	\N	Kvichak	AK
105808	Goodnews Bay entrance, Alaska	NOS	9465368	59.045	-161.808	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103844	00:11:00	\N	0.95	00:04:00	\N	1.01	\N	\N	Goodnews Bay entrance	AK
105809	Apokak Creek entrance, Eenayarak River, Alaska	NOS	9466079	60.1367	-162.158	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103844	04:30:00	\N	0.79	03:18:00	\N	1.47	\N	\N	Apokak Creek entrance	AK
105810	St. Matthew Island, Bering Sea, Alaska	NOS	9466203	60.358299255371094	-172.71499633789062	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103829	00:29:00	\N	0.61	00:06:00	\N	0.61	\N	\N	St. Matthew Island	AK
105811	Pikmiktalik River entrance, Norton Sound, Alaska	NOS	9468011	63.28	-162.602	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103875	-01:13:00	\N	1.08	-01:13:00	\N	1.08	\N	\N	Pikmiktalik River entrance	AK
105812	Fossil River entrance, St. Lawrence Island, Alaska	NOS	9468123	63.4667	-170.017	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103877	-03:08:00	\N	0.67	-03:00:00	\N	1.13	\N	\N	Fossil River entrance	AK
105813	St. Michael, Norton Sound, Alaska (sub)	NOS	9468132	63.475	-162.027	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103875	-02:16:00	\N	1	-00:11:00	\N	1	\N	\N	St. Michael	AK
105814	Niyrakpak Lagoon entrance, St. Lawrence Island, Alaska	NOS	9468216	63.62	-171.383	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103877	-03:31:00	\N	0.67	-03:27:00	\N	0.83	\N	\N	Niyrakpak Lagoon entrance	AK
105815	North Bay, Stuart Island, Norton Sound, Alaska	NOS	9468226	63.6283	-162.517	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103875	-00:28:00	\N	0.72	-00:28:00	\N	0.72	\N	\N	North Bay, Stuart Island	AK
105816	Point Barrow, Alaska	NOS	9495048	71.36	-156.353	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	-00:26:00	\N	0.04	-00:37:00	\N	0.04	\N	\N	Point Barrow	AK
105817	Redhook Bay, St. Thomas, Virgin Islands	NOS	9751540	18.3267	-64.8517	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103925	00:44:00	\N	1.28	-00:46:00	\N	1.28	\N	\N	Redhook Bay, St. Thomas Island	VI
105819	Chelsea, Arthur Kill, New Jersey	NOS	TEC1645	40.6	-74.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102906	00:37:00	\N	1.05	00:23:00	\N	1.07	\N	\N	Chelsea	NJ
105820	Cape Hatteras, North Carolina	NOS	TEC2789	35.23333333333299	-75.516666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	00:01:00	\N	1.08	00:01:00	\N	1	\N	\N	Cape Hatteras	NC
105821	Hatteras Inlet, North Carolina	NOS	TEC2791	35.2	-75.733333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	00:13:00	\N	0.83	00:08:00	\N	0.66	\N	\N	Hatteras Inlet	NC
105822	Ocracoke Inlet, North Carolina	NOS	TEC2793	35.06666666666701	-76.016666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	00:11:00	\N	0.83	00:09:00	\N	0.63	\N	\N	Ocracoke Inlet	NC
105823	Shell Point, Harkers Island, Back Sound, North Carolina	NOS	TEC2801	34.68333333333299	-76.53333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	02:34:00	\N	0.83	01:52:00	\N	0.54	\N	\N	Shell Point, Harkers Island	NC
105824	N.C. State Fisheries, Bogue Sound, North Carolina	NOS	TEC2831	34.71666666666701	-76.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	01:32:00	\N	0.83	01:05:00	\N	0.66	\N	\N	N.C. State Fisheries	NC
105825	Bogue Inlet, North Carolina	NOS	TEC2837	34.650001525878906	-77.0999984741211	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	00:15:00	\N	0.83	00:13:00	\N	0.73	\N	\N	Bogue Inlet	NC
105826	Cape Fear, North Carolina	NOS	TEC2847	33.85	-77.96666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103036	00:07:00	\N	1.33	00:04:00	\N	1.47	\N	\N	Cape Fear	NC
105827	Castle Hayne, Northeast River, Cape Fear River, North Carolina	NOS	TEC2863	34.35	-77.933333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103053	02:54:00	\N	0.42	02:44:00	\N	0.42	\N	\N	Castle Hayne, Northeast River	NC
105828	Lockwoods Folly Inlet, North Carolina	NOS	TEC2869	33.916666666667005	-78.233333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103064	00:15:00	\N	1	00:04:00	\N	0.84	\N	\N	Lockwoods Folly Inlet	NC
105829	Winyah Bay entrance (south jetty), South Carolina	NOS	TEC2929	33.18333333333299	-79.15	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:24:00	\N	0.89	-00:21:00	\N	0.87	\N	\N	Winyah Bay Entrance (South Jetty)	SC
105830	Frazier Point, South Carolina	NOS	TEC2937	33.31666666666701	-79.28333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	02:07:00	\N	0.68	01:26:00	\N	0.66	\N	\N	Frazier Point	SC
105831	North Santee River Inlet, South Carolina	NOS	TEC2991	33.13333333333299	-79.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:04:00	\N	0.84	-00:09:00	\N	0.85	\N	\N	North Santee River Inlet	SC
105832	Brown Island, South Santee River, South Carolina	NOS	TEC3001	33.15	-79.33333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	01:31:00	\N	0.79	00:27:00	\N	0.78	\N	\N	Brown Island, South Santee River	SC
105833	Cape Romain, 46 mi east of, South Carolina	NOS	TEC3011	33.1	-78.433333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-01:13:00	\N	0.79	-01:05:00	\N	0.78	\N	\N	Cape Romain, 46 miles east of	SC
105834	Jack Creek entrance, Bulls Bay, South Carolina	NOS	TEC3023	32.93333333333299	-79.58333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:15:00	\N	0.95	-00:14:00	\N	0.95	\N	\N	Jack Creek entrance	SC
105835	Sullivans Island (outer coast), South Carolina	NOS	TEC3047	32.76666666666701	-79.83333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:12:00	\N	1	-00:08:00	\N	0.99	\N	\N	Sullivans Island (outer coast)	SC
105836	Shipyard Creek, 0.8 mi above entrance., South Carolina	NOS	TEC3061	32.833333333332995	-79.95	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	00:20:00	\N	1	00:34:00	\N	1.01	\N	\N	Shipyard Creek, 0.8 mile above entrance.	SC
105837	Folly Island (outer coast), South Carolina	NOS	TEC3127	32.65	-79.933333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103088	-00:14:00	\N	1	-00:08:00	\N	0.98	\N	\N	Folly Island (outer coast)	SC
105838	Euhaw Creek, 2.5 mi above entrance, Broad River, South Carolina	NOS	TEC3327	32.435	-80.85166666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:09:00	\N	0.91	01:33:00	\N	1.14	\N	\N	Euhaw Creek, 2.5 mi. above entrance	SC
105839	Tybee Creek entrance, Georgia	NOS	TEC3399	31.983333333332993	-80.85	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:05:00	\N	1	-00:09:00	\N	0.99	\N	\N	Tybee Creek entrance	GA
105840	Beach Hammock, Georgia	NOS	TEC3401	31.95	-80.933333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	-00:07:00	\N	1	-00:01:00	\N	1	\N	\N	Beach Hammock	GA
105841	Romerly Marsh Creek, Georgia	NOS	TEC3403	31.933333333332993	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	-00:03:00	\N	1.03	00:08:00	\N	1.03	\N	\N	Romerly Marsh Creek	GA
105842	Savannah Sheraton Resort Hotel, Wilmington River, Georgia	NOS	TEC3405	32	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:06:00	\N	1.14	00:14:00	\N	1.13	\N	\N	Savannah Sheraton Resort Hotel	GA
105843	Thunderbolt, Wilmington River, Georgia	NOS	TEC3407	32.03333333333299	-81.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:12:00	\N	1.14	00:32:00	\N	1.15	\N	\N	Thunderbolt	GA
105844	North entrance, Wilmington River, Georgia	NOS	TEC3409	32.06666666666701	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:44:00	\N	1.09	00:40:00	\N	1.1	\N	\N	North entrance	GA
105845	Isle of Hope, Skidaway River, Georgia	NOS	TEC3411	31.983333333332993	-81.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:28:00	\N	1.13	00:50:00	\N	1.13	\N	\N	Isle of Hope, Skidaway River	GA
105846	Egg Islands, Georgia	NOS	TEC3413	31.83333333333299	-81.08333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:10:00	\N	1.04	00:04:00	\N	1.04	\N	\N	Egg Islands	GA
105847	Coffee Bluff, Forest River, Georgia	NOS	TEC3417	31.933333333332993	-81.15	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:42:00	\N	1.09	01:05:00	\N	1.09	\N	\N	Coffee Bluff, Forest River	GA
105848	Fort McAllister, Ogeechee River, Georgia	NOS	TEC3419	31.883333333332992	-81.21666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:16:00	\N	1	00:48:00	\N	1	\N	\N	Fort McAllister, Ogeechee River	GA
105849	Highway bridge, Ogeechee River, Georgia	NOS	TEC3421	31.983333333332993	-81.28333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	04:25:00	\N	0.14	03:19:00	\N	0.15	\N	\N	Highway bridge, Ogeechee River	GA
105850	Florida Passage, Bear River, Georgia	NOS	TEC3425	31.816666666667007	-81.16666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:49:00	\N	0.95	00:46:00	\N	1.09	\N	\N	Florida Passage, Bear River	GA
105851	Cane Patch Creek entrance, Georgia	NOS	TEC3427	31.816666666667007	-81.15	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:43:00	\N	1.05	00:55:00	\N	1.05	\N	\N	Cane Patch Creek entrance	GA
105852	North Newport River, Georgia	NOS	TEC3445	31.66666666666701	-81.266666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:36:00	\N	1.09	00:56:00	\N	1.1	\N	\N	North Newport River	GA
105853	South Newport Cut, N. Newport River, Georgia	NOS	TEC3447	31.66666666666701	-81.266666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:54:00	\N	1.04	01:01:00	\N	1.08	\N	\N	South Newport Cut, N. Newport River	GA
105854	Dallas Bluff, Julienton River, Georgia	NOS	TEC3457	31.58333333333299	-81.316666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	01:04:00	\N	1.09	00:48:00	\N	1.1	\N	\N	Dallas Bluff, Julienton River	GA
105855	Blackbeard Island, Georgia	NOS	TEC3463	31.53333333333299	-81.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:22:00	\N	1	00:18:00	\N	1	\N	\N	Blackbeard Island	GA
105856	Wolf Island, south end, Georgia	NOS	TEC3491	31.33333333333299	-81.316666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:45:00	\N	1.09	00:25:00	\N	0.97	\N	\N	Wolf Island, south end	GA
105857	Hampton River entrance, Georgia	NOS	TEC3495	31.21666666666701	-81.316666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:04:00	\N	0.95	00:16:00	\N	0.96	\N	\N	Hampton River entrance	GA
105858	Jones Creek entrance, Hampton River, Georgia	NOS	TEC3497	31.3	-81.33333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:13:00	\N	1.05	01:03:00	\N	1.05	\N	\N	Jones Creek entrance, Hampton River	GA
105859	St. Simons Sound Bar, Georgia	NOS	TEC3499	31.1	-81.316666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	-00:02:00	\N	0.95	-00:01:00	\N	0.95	\N	\N	St. Simons Sound Bar	GA
105860	Allied Chemical Corp. docks, Turtle River, Georgia	NOS	TEC3515	31.183333333332993	-81.516666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:42:00	\N	1.09	01:03:00	\N	1.1	\N	\N	Allied Chemical Corp. docks	GA
105861	Highway bridge, South Brunswick River, Georgia	NOS	TEC3521	31.15	-81.566666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103099	00:49:00	\N	1.09	01:07:00	\N	1.1	\N	\N	Highway bridge, South Brunswick River	GA
105862	Below Spring Bluff, Little Satilla River, Georgia	NOS	TEC3531	31.16666666666701	-81.616666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	01:31:00	\N	1.23	01:09:00	\N	1.23	\N	\N	Below Spring Bluff	GA
105863	Burnt Fort, Satilla River, Georgia	NOS	TEC3541	30.95	-81.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103125	05:05:00	\N	0.53	03:55:00	\N	0.53	\N	\N	Burnt Fort	GA
105864	Cape Canaveral, Florida	NOS	TEC3693	28.433333333332993	-80.566666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	-00:44:00	\N	1.42	-01:06:00	\N	1.5	\N	\N	Cape Canaveral	FL
105865	Jupiter Inlet, US Highway 1 Bridge, Florida	NOS	TEC3783	26.948333333332993	-80.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:05:00	\N	1.14	00:28:00	\N	0.86	\N	\N	Jupiter Inlet, U.S. Highway 1 Bridge	FL
105866	Tequesta, Loxahatchee River, Florida	NOS	TEC3787	26.95	-80.10166666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:58:00	\N	1.14	00:59:00	\N	0.8	\N	\N	Tequesta	FL
105867	Tequesta, North Fork entrance, Loxahatchee River, Florida	NOS	TEC3789	26.95166666666701	-80.10166666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103194	01:42:00	\N	0.92	00:51:00	\N	0.78	\N	\N	Tequesta, North Fork entrance	FL
105868	Cape Sable, East Cape, Florida	NOS	TEC4165	25.116666666667008	-81.08333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103217	01:50:00	\N	0.98	01:33:00	\N	1.3	\N	\N	Cape Sable, East Cape	FL
105869	Whitewater Bay, Florida	NOS	TEC4169	25.316666666667007	-81.03333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103217	04:38:00	\N	0.33	03:53:00	\N	0.26	\N	\N	Whitewater Bay	FL
105870	Point Ybel, San Carlos Bay entrance, Florida	NOS	TEC4207	26.45	-82.016666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-01:12:00	\N	1.21	-01:50:00	\N	1.21	\N	\N	Point Ybel, San Carlos Bay entrance	FL
105871	Pass-a-Grille Beach, Boca Ciega Bay, Florida	NOS	TEC4271	27.683333333332993	-82.733333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103246	-01:30:00	\N	0.87	-01:34:00	\N	0.87	\N	\N	Pass-a-Grille Beach	FL
105872	Suwannee River entrance, Florida	NOS	TEC4299	29.28333333333299	-83.15	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	00:18:00	\N	0.95	00:06:00	\N	0.88	\N	\N	Suwannee River entrance	FL
105873	Pepperfish Keys, Florida	NOS	TEC4301	29.5	-83.366666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103268	00:24:00	\N	0.95	00:12:00	\N	0.88	\N	\N	Pepperfish Keys	FL
105874	Fishermans Rest, Florida	NOS	TEC4305	29.733333333332993	-83.53333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103275	-00:02:00	\N	0.86	-00:14:00	\N	0.93	\N	\N	Fishermans Rest	FL
105875	Rock Islands, Florida	NOS	TEC4309	29.966699600219727	-83.83329772949219	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103275	00:04:00	\N	0.91	-00:03:00	\N	0.93	\N	\N	Rock Islands	FL
105876	Milton, Blackwater River, Pensacola Bay, Florida	NOS	TEC4383	30.616666666667008	-87.03333333333299	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103330	01:47:00	\N	1.2	01:40:00	\N	1.2	\N	\N	Milton, Blackwater River	FL
105877	Paris Road Bridge (ICWW), Louisiana	NOS	TEC4445	30	-89.933333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103400	05:58:00	\N	1.04	05:53:00	\N	1.04	\N	\N	Paris Road Bridge (ICWW)	LA
105878	Bayou Rigaud, Grand Isle, Barataria Bay, Louisiana	NOS	TEC4455	29.266666666667007	-89.96666666666701	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103400	00:46:00	\N	0.94	01:32:00	\N	0.94	\N	\N	Bayou Rigaud, Grand Isle	LA
105879	Texas City, Turning Basin, Galveston Bay, Texas	NOS	TEC4513	29.383333333332992	-94.883333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103468	00:41:00	\N	1	00:33:00	\N	1	\N	\N	Texas City, Turning Basin	TX
105880	Gilchrist, East Bay, Galveston Bay, Texas	NOS	TEC4525	29.516666666667007	-94.483333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103468	04:18:00	\N	0.86	03:16:00	\N	0.86	\N	\N	Gilchrist, East Bay	TX
105881	Playa de Ponce, Puerto Rico	NOS	TEC4733	17.96666666666701	-66.616666666667	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103955	-00:13:00	\N	1.14	-00:39:00	\N	1.14	\N	\N	Playa de Ponce	PR
105882	Playa Cortada, Puerto Rico	NOS	TEC4735	17.983333333332993	-66.45	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103955	-00:37:00	\N	1.14	00:16:00	\N	1.14	\N	\N	Playa Cortada	PR
105883	Arroyo, Puerto Rico	NOS	TEC4737	17.96666666666701	-66.066666666667	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103955	00:13:00	\N	1.14	00:52:00	\N	1.14	\N	\N	Arroyo	PR
105884	Ensenada Honda, Culebra Island, Puerto Rico	NOS	TEC4749	18.3	-65.28333333333299	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103946	-00:15:00	\N	0.63	-00:34:00	\N	0.63	\N	\N	Ensenada Honda, Culebra Island	PR
105885	Pagan Island, Marianas	NOS	TPT2621	18.1333	145.76666	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102706	00:01:00	\N	0.94	00:05:00	\N	0.94	\N	\N	Pagan Island	MP
105886	Saipan Harbor, Saipan Island, Marianas	NOS	TPT2623	15.2	145.71666666667008	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102706	00:07:00	\N	0.8	00:02:00	\N	0.8	\N	\N	Saipan Harbor, Saipan Island	MP
105887	Tinian Island, Marianas	NOS	TPT2625	14.966666666667008	145.61666666667008	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102706	-00:23:00	\N	0.33	-00:02:00	\N	0.74	\N	\N	Tinian Island	MP
105888	Rota Island, Marianas	NOS	TPT2627	14.1333	145.1333	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102706	-00:06:00	\N	0.94	-00:03:00	\N	0.94	\N	\N	Rota Island	MP
105891	Ngulu Atoll, Caroline Islands, FSM	NOS	TPT2639	8.300000190734863	137.48330688476562	:Pacific/Chuuk	FSM	feet	\N	\N	\N	Reference is in time zone :Pacific/Palau; offsets not adjusted.	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102712	00:19:00	\N	0.77	00:40:00	\N	0.77	\N	\N	Ngulu Islands	FM
105892	Ifalik Atoll, Caroline Islands, FSM	NOS	TPT2647	7.25	144.45	:Pacific/Yap	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102706	-00:13:00	\N	1.33	-00:54:00	\N	1	\N	\N	Ifalik Atoll	FM
105893	Pulap Atoll, Chuuk, FSM	NOS	TPT2651	7.633333333333304	149.41666666667007	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102711	00:43:00	\N	0.74	-00:53:00	\N	0.74	\N	\N	Pulap Atoll	FM
105894	Namonuito Atoll, Caroline Islands, FSM	NOS	TPT2653	8.583333333333297	149.65	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102711	00:21:00	\N	0.69	-01:23:00	\N	0.69	\N	\N	Namonuito Atoll	FM
105895	Nomwin Atoll, Hall Islands, Chuuk, FSM	NOS	TPT2655	8.45	151.78333333332992	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102711	00:20:00	\N	0.8	-00:08:00	\N	0.8	\N	\N	Nomwin Atoll, Hall Islands	FM
105896	Murilo Atoll, Hall Islands, Chuuk, FSM	NOS	TPT2657	8.6	152.25	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102711	00:00:00	\N	0.85	-00:28:00	\N	0.85	\N	\N	Murilo Atoll, Hall Islands	FM
105897	Chuuk, Moen Island, E. Caroline Islands, FSM (sub)	NOS	TPT2659	7.45	151.85	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102711	00:11:00	\N	0.85	00:10:00	\N	0.85	\N	\N	Moen Island, Truk Islands	FM
105898	Dublon Island, Chuuk, FSM	NOS	TPT2661	7.366666666666704	151.88333333332992	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102711	00:30:00	\N	1.07	00:02:00	\N	1.07	\N	\N	Dublon Island, Truk Islands	FM
105899	Losap Atoll, Chuuk, FSM	NOS	TPT2663	6.9	152.7333333333299	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102711	00:25:00	\N	0.8	-00:03:00	\N	0.8	\N	\N	Losap Atoll	FM
105900	Namoluk Atoll, Chuuk, FSM	NOS	TPT2665	5.9	153.13333333332992	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102711	00:27:00	\N	0.8	-00:01:00	\N	0.8	\N	\N	Namoluk Atoll	FM
105901	Satawan Anchorage, Nomoi Islands, Chuuk, FSM	NOS	TPT2667	5.333333333333304	153.7333333333299	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102711	00:25:00	\N	0.96	-00:03:00	\N	0.96	\N	\N	Satawan Anchorage, Nomoi Islands	FM
105902	Bikini Atoll, Marshall Islands	NOS	TPT2687	11.6	165.55	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:19:00	0	\N	-00:19:00	0	\N	\N	\N	Bikini Atoll	MH
105903	Eniirikku Island, Bikini Atoll, Marshall Islands	NOS	TPT2689	11.5	165.33333333332993	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:16:00	\N	0.85	-00:15:00	\N	0.85	\N	\N	Eniirikku Island, Bikini Atoll	MH
105904	Rongelap Island, Rongelap Atoll, Marshall Islands	NOS	TPT2691	11.15	166.9	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:07:00	\N	0.96	-00:07:00	\N	0.96	\N	\N	Rongelap Island, Rongelap Atoll	MH
105905	Rongerik Atoll, Marshall Islands	NOS	TPT2693	11.383333333333008	167.5166666666701	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:15:00	0	\N	-00:14:00	0.1	\N	\N	\N	Rongerik Atoll	MH
105906	Ujae Atoll, Marshall Islands	NOS	TPT2695	9.033333333333296	165.6	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Ujae Atoll	MH
105907	Kwajalein Atoll (Namur Island), Marshall Islands	NOS	TPT2697	9.4	167.4833333333299	:Pacific/Kwajalein	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:05:00	0	\N	-00:02:00	0	\N	\N	\N	Kwajalein Atoll (Namur Island)	MH
105908	Ailinglapalap Atoll, Marshall Islands	NOS	TPT2701	7.283333333333304	168.75	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	00:07:00	0.3	\N	00:08:00	0.4	\N	\N	\N	Ailinglapalap Atoll	MH
105909	Jaluit Atoll (SE Pass), Marshall Islands	NOS	TPT2703	5.916666666666696	169.65	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:08:00	-0.1	\N	-00:12:00	-0.1	\N	\N	\N	Jaluit Atoll (SE Pass)	MH
105910	Ebon (Boston) Atoll, Marshall Islands	NOS	TPT2705	4.6	168.68333333332993	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:10:00	0.1	\N	-00:10:00	0.1	\N	\N	\N	Ebon (Boston) Atoll	MH
105911	Taongi Atoll, Marshall Islands	NOS	TPT2707	14.566666666667007	168.95	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:20:00	0	\N	-00:20:00	0	\N	\N	\N	Taongi Atoll	MH
105912	Bikar (Dawson) Atoll, Marshall Islands	NOS	TPT2709	12.25	170.13333333332992	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Bikar (Dawson) Atoll	MH
105913	Ailuk Atoll, Marshall Islands	NOS	TPT2711	10.216666666667008	169.9833333333299	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Ailuk Atoll	MH
105914	Likiep Atoll, Marshall Islands	NOS	TPT2713	9.816666666666704	169.31666666667007	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:01:00	0	\N	00:00:00	0.1	\N	\N	\N	Likiep Atoll	MH
105917	Maloelap Atoll, Marshall Islands	NOS	TPT2719	8.716666666666704	171.2333333333299	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:05:00	-0.1	\N	-00:04:00	0.1	\N	\N	\N	Maloelap Atoll	MH
105918	Majuro Atoll, Marshall Islands	NOS	TPT2721	7.116666666666704	171.36666666667008	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:06:00	0.1	\N	-00:05:00	0.3	\N	\N	\N	Majuro Atoll	MH
105919	Arno Atoll, Marshall Islands	NOS	TPT2723	7.133333333333304	171.7	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	-00:05:00	-0.1	\N	-00:04:00	0.6	\N	\N	\N	Arno Atoll	MH
105920	Port Rhin, Mili Atoll, Marshall Islands	NOS	TPT2725	6.233333333333296	171.8	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102710	00:04:00	0	\N	00:04:00	0.7	\N	\N	\N	Port Rhin, Mili Atoll	MH
105921	Howland Island	NOS	TPT2737	0.8	-176.63333333332992	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102695	03:46:00	0.4	\N	03:48:00	4.2	\N	\N	\N	Howland Island	\N
105922	Palmyra Island	NOS	TPT2739	5.883333333333304	-162.08333333332993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102695	01:13:00	-0.2	\N	01:19:00	0.6	\N	\N	\N	Palmyra Island	\N
105923	Waikane, Kaneohe Bay, Oahu Island, Hawaii	NOS	TPT2777	21.5	-157.85	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102699	-00:04:00	\N	1	-00:22:00	\N	1.13	\N	\N	Waikane, Kaneohe Bay	HI
105924	Laie Bay, Oahu Island, Hawaii	NOS	TPT2779	21.65	-157.93333333332993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102699	-00:32:00	\N	0.75	-00:21:00	\N	1	\N	\N	Laie Bay	HI
105925	Kihei, Maalaea Bay, Maui Island, Hawaii	NOS	TPT2797	20.78333333333299	-156.46666666667008	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102701	01:19:00	\N	0.54	01:52:00	\N	0.94	\N	\N	Kihei, Maalaea Bay	HI
105926	Lahaina, Maui Island, Hawaii	NOS	TPT2799	20.883333333332992	-156.68333333332993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102701	01:01:00	\N	0.81	01:18:00	\N	0.89	\N	\N	Lahaina	HI
105927	Smuggler Cove, Kahoolawe Island, Hawaii	NOS	TPT2803	20.516666666667007	-156.68333333332993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102695	00:03:00	0	\N	-00:15:00	0.2	\N	\N	\N	Smuggler Cove	HI
105928	Tau Island, Manua Islands, American Samoa	NOS	TPT2865	-14.21666666666667	-169.5333333333333	:Pacific/Pago_Pago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	102709	-00:24:00	\N	1	-00:25:00	\N	1.43	\N	\N	Tau Island, Manua Islands	AS
105929	Point Loma, California	NOS	TWC0405	32.666666666667005	-117.23333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103515	-00:02:00	\N	0.92	-00:09:00	\N	0.92	\N	\N	Point Loma	CA
105930	Quivira Basin, Mission Bay, California	NOS	TWC0413	32.76666666666701	-117.23333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103515	00:04:00	\N	0.95	00:05:00	\N	0.95	\N	\N	Quivira Basin, Mission Bay	CA
105931	San Clemente, California	NOS	TWC0419	33.416666666667005	-117.61666666666996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103515	-00:11:00	\N	0.92	-00:15:00	\N	0.92	\N	\N	San Clemente	CA
105932	Los Patos (highway bridge), California	NOS	TWC0427	33.71666666666701	-118.05	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	01:12:00	\N	0.6	01:00:00	\N	0.83	\N	\N	Los Patos (highway bridge)	CA
105933	Los Angeles Harbor, Mormon Island, California	NOS	TWC0439	33.75	-118.26666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	00:02:00	0	\N	00:04:00	-0.1	\N	\N	\N	Los Angeles Harbor, Mormon Island	CA
105934	Mugu Lagoon (ocean pier), California	NOS	TWC0445	34.1	-119.1	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	00:11:00	\N	0.96	00:03:00	\N	0.96	\N	\N	Mugu Lagoon (ocean pier)	CA
105935	Santa Barbara Island, California	NOS	TWC0463	33.48333333333299	-119.03333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103519	00:04:00	\N	0.92	-00:02:00	\N	0.92	\N	\N	Santa Barbara Island	CA
105936	Point Arguello, California	NOS	TWC0473	34.583333333332995	-120.65	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103526	-00:08:00	\N	0.96	-00:03:00	\N	0.96	\N	\N	Point Arguello	CA
105937	San Francisco Bar, California	NOS	TWC0509	37.76666666666701	-122.63333333333004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	-00:31:00	0	\N	-00:35:00	-0.2	\N	\N	\N	San Francisco Bar	CA
105938	Roberts Landing, 1.3 mi west of, San Francisco Bay, California	NOS	TWC0547	37.666666666667005	-122.2	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	01:28:00	0.1	\N	00:52:00	1.4	\N	\N	\N	Roberts Landing, 1.3 miles west of	CA
105939	Lakeville, Petaluma River, San Pablo Bay, California	NOS	TWC0649	38.2	-122.56666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103534	02:50:00	\N	0.81	01:59:00	\N	1.11	\N	\N	Lakeville, Petaluma River	CA
105940	Point Arena, California	NOS	TWC0771	38.95	-123.73333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103575	00:01:00	\N	0.95	00:03:00	\N	0.98	\N	\N	Point Arena	CA
105941	Mendocino, Mendocino Bay, California	NOS	TWC0777	39.3	-123.8	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103575	00:01:00	\N	0.95	00:07:00	\N	0.98	\N	\N	Mendocino, Mendocino Bay	CA
105942	Wedderburn, Rogue River, Oregon	NOS	TWC0817	42.43333333333299	-124.41666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103583	00:16:00	\N	0.92	00:09:00	\N	0.95	\N	\N	Wedderburn, Rogue River	OR
105943	Gardiner, Umpqua River, Oregon	NOS	TWC0831	43.73333333333299	-124.11666666666996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103588	01:09:00	\N	0.8	00:56:00	\N	0.88	\N	\N	Gardiner	OR
105944	Nestucca Bay entrance, Oregon	NOS	TWC0857	45.166666666667005	-123.96666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103583	01:12:00	\N	0.92	00:55:00	\N	1.1	\N	\N	Nestucca Bay entrance	OR
105945	Miami Cove, Tillamook Bay, Oregon	NOS	TWC0863	45.55	-123.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103583	01:26:00	\N	0.92	01:15:00	\N	1.06	\N	\N	Miami Cove	OR
105946	Bay City, Tillamook Bay, Oregon	NOS	TWC0865	45.51666666666701	-123.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103583	02:00:00	\N	0.83	01:33:00	\N	1.02	\N	\N	Bay City	OR
105947	Point Adams, Oregon	NOS	TWC0881	46.2	-123.95	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103605	-00:38:00	0.1	\N	-00:25:00	-0.2	\N	\N	\N	Point Adams, Oreg.	OR
105948	Warrenton, Skipanon River, Oregon	NOS	TWC0883	46.166666666667005	-123.91666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103605	-00:19:00	0.1	\N	-00:13:00	-0.1	\N	\N	\N	Warrenton, Skipanon River, Oreg.	OR
105949	Harrington Point, Washington	NOS	TWC0895	46.26666666666701	-123.65	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103605	00:52:00	-0.2	\N	00:21:00	-0.8	\N	\N	\N	Harrington Point, Wash.	WA
105950	Tarlatt Slough, Willapa Bay, Washington	NOS	TWC0933	46.37	-124.005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	01:14:00	\N	1.05	00:45:00	\N	1.05	\N	\N	Tarlatt Slough	WA
105951	Mailboat Slough, Willapa River, Willapa Bay, Washington	NOS	TWC0940	46.68833333333299	-123.81666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	00:11:00	\N	1.02	00:18:00	\N	1.07	\N	\N	Mailboat Slough, Willapa River	WA
105952	Montesano, Chehalis River, Grays Harbor, Washington	NOS	TWC0959	46.96833333333299	-123.6	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	01:45:00	\N	0.94	01:34:00	\N	0.94	\N	\N	Montesano, Chehalis River	WA
105953	Destruction Island, Washington	NOS	TWC0965	47.666666666667005	-124.48333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103623	-00:43:00	\N	1.02	-00:37:00	\N	0.98	\N	\N	Destruction Island	WA
105954	Rocky Point, Eld Inlet, Puget Sound, Washington	NOS	TWC1115	47.081666666667005	-123.005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:56:00	\N	1.1	00:39:00	\N	1.31	\N	\N	Rocky Point, Eld Inlet	WA
105955	Marysville, Quilceda Creek, Washington	NOS	TWC1125	48.045	-122.21166666666996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	00:29:00	\N	0.89	00:09:00	\N	0.95	\N	\N	Marysville, Quilceda Creek	WA
105956	Stanwood, Stillaguamish River, Washington	NOS	TWC1131	48.21666666666667	-122.3666666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103643	02:14:00	\N	0.29	00:23:00	\N	0.62	\N	\N	Stanwood, Stillaguamish River	WA
105957	Peavine Pass, Washington	NOS	TWC1165	48.6	-122.8	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	00:18:00	\N	0.92	00:34:00	\N	0.98	\N	\N	Peavine Pass	WA
105958	Point Migley, Hale Passage, Washington	NOS	TWC1173	48.75	-122.71666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	00:51:00	0	\N	00:56:00	0.1	\N	\N	\N	Point Migley	WA
105959	Ferndale, Strait of Georgia, Washington	NOS	TWC1189	48.83330154418945	-122.7166976928711	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103633	01:20:00	\N	1.04	00:49:00	\N	1.05	\N	\N	Ferndale	WA
105960	Tah Bay, Alaska	NOS	TWC1487	54.833333333332995	-132.33333333332993	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:03:00	0.1	\N	-00:04:00	2.6	\N	\N	\N	Tah Bay	AK
105961	Kasook Inlet, Sukkwan Island, Tlevak Strait, Alaska	NOS	TWC1513	55.01666666666701	-132.78333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:05:00	0	\N	-00:13:00	2.8	\N	\N	\N	Kasook Inlet, Sukkwan Island	AK
105962	Cyrus Cove, Sea Otter Sound, Davidson Inlet, Alaska	NOS	TWC1579	55.916666666667005	-133.4	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:12:00	0	\N	-00:16:00	1.1	\N	\N	\N	Cyrus Cove, Sea Otter Sound	AK
105963	Marble Island, Davidson Inlet, Alaska	NOS	TWC1583	56	-133.46666666667008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:15:00	-0.1	\N	-00:19:00	0.8	\N	\N	\N	Marble Island	AK
105964	Port McArthur, Kuiu Island, Alaska	NOS	TWC1593	56.06666666666701	-134.11666666667008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	-00:07:00	-0.1	\N	-00:11:00	0.6	\N	\N	\N	Port McArthur, Kuiu Island	AK
105965	Ideal Cove, Mitkof Island, Frederick Sound, Alaska	NOS	TWC1657	56.666666666667005	-132.63333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:05:00	0	\N	-00:09:00	-0.2	\N	\N	\N	Ideal Cove, Mitkof Island	AK
105966	Brown Cove, Frederick Sound, Alaska	NOS	TWC1659	56.88333333333299	-132.8	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:10:00	-0.1	\N	-00:14:00	-0.3	\N	\N	\N	Brown Cove	AK
105967	Portage Bay, Kupreanof Island, Frederick Sound, Alaska	NOS	TWC1663	57	-133.31666666667007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:15:00	0	\N	-00:19:00	-0.7	\N	\N	\N	Portage Bay, Kupreanof Island	AK
105968	Eliza Harbor, Liesnoi Island, Frederick Sound, Alaska	NOS	TWC1669	57.166666666667005	-134.28333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:19:00	-0.1	\N	-00:19:00	-1.9	\N	\N	\N	Eliza Harbor, Liesnoi Island	AK
105969	Port Houghton, Robert Islands, Alaska	NOS	TWC1673	57.3	-133.46666666667008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:17:00	-0.1	\N	-00:21:00	-0.8	\N	\N	\N	Port Houghton, Robert Islands	AK
105970	Windfall Harbor, Seymour Canal, Alaska	NOS	TWC1683	57.86666666666701	-134.2666666666701	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:18:00	0	\N	00:14:00	-0.2	\N	\N	\N	Windfall Harbor, Seymour Canal	AK
105971	Port Snettisham, Point Styleman, Alaska	NOS	TWC1687	57.96666666666701	-133.88333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:06:00	-0.1	\N	-00:12:00	-0.4	\N	\N	\N	Port Snettisham, Point Styleman	AK
105972	Fritz Cove, Douglas Island, Alaska	NOS	TWC1697	58.31666666666701	-134.6	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:05:00	-0.1	\N	-00:01:00	-0.3	\N	\N	\N	Fritz Cove, Douglas Island	AK
105973	Tebenkof Bay, Kuiu Island, Alaska	NOS	TWC1723	56.416666666667005	-134.13333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103707	00:11:00	0.1	\N	00:04:00	1.8	\N	\N	\N	Tebenkof Bay, Kuiu Island	AK
105974	Whitewater Bay, Admiralty Island, Alaska	NOS	TWC1731	57.23333333333299	-134.6	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:15:00	0.3	\N	-00:19:00	-2	\N	\N	\N	Whitewater Bay, Admiralty Island	AK
105975	Point Thatcher, Alaska	NOS	TWC1735	57.416666666667005	-134.85	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:11:00	0.2	\N	-00:15:00	-1.9	\N	\N	\N	Point Thatcher	AK
105976	Favorite Bay, Kootznahoo Inlet, Alaska	NOS	TWC1739	57.48333333333299	-134.55	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:15:00	0.3	\N	00:11:00	-2.8	\N	\N	\N	Favorite Bay	AK
105977	Mitchell Bay, Kootznahoo Inlet, Alaska	NOS	TWC1741	57.53333333333299	-134.4	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	01:31:00	\N	0.62	01:22:00	\N	0.67	\N	\N	Mitchell Bay	AK
105978	Freshwater Bay, Chichagof Island, Alaska	NOS	TWC1743	57.85	-135.0166666666701	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	00:00:00	0.3	\N	-00:08:00	-1.5	\N	\N	\N	Freshwater Bay, Chichagof Island	AK
105979	Point Elizabeth, Alaska	NOS	TWC1783	57.51666666666701	-135.28333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:05:00	0	\N	-00:15:00	-1.6	\N	\N	\N	Point Elizabeth	AK
105980	Lindenburg Head, Alaska	NOS	TWC1785	57.45	-135.03333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:05:00	0	\N	-00:15:00	-1.8	\N	\N	\N	Lindenburg Head	AK
105981	Fairway Island, Alaska	NOS	TWC1787	57.45	-134.88333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103715	-00:05:00	0	\N	-00:15:00	-2.1	\N	\N	\N	Fairway Island	AK
105982	Falcon Arm, Slocum Arm, Chichagof Island, Alaska	NOS	TWC1789	57.55	-135.93333333332993	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	-00:07:00	\N	1.1	-00:05:00	\N	0.96	\N	\N	Falcon Arm, Slocum Arm	AK
105983	Wingham Island, Controller Bay, Alaska	NOS	TWC1863	60.05	-144.4	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103727	00:08:00	\N	1.01	00:05:00	\N	0.99	\N	\N	Wingham Island, Controller Bay	AK
105984	Pete Dahl Slough, Copper River Delta, Alaska	NOS	TWC1867	60.38333333333299	-145.4	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	00:38:00	0	\N	00:06:00	-2.4	\N	\N	\N	Pete Dahl Slough	AK
105985	Eyak River entrance, Alaska	NOS	TWC1869	60.46666666666701	-145.66666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	00:58:00	-0.1	\N	00:14:00	-1.6	\N	\N	\N	Eyak River entrance	AK
105986	Gravel Point, Orca Inlet, Alaska	NOS	TWC1875	60.46666666666701	-145.96666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	00:31:00	0	\N	00:01:00	-0.1	\N	\N	\N	Gravel Point	AK
105987	Orca, Orca Inlet, Alaska	NOS	TWC1879	60.583333333332995	-145.71666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	00:01:00	0	\N	00:01:00	-0.2	\N	\N	\N	Orca	AK
105988	Windy Bay, Hawkins Island, Prince William Sound, Alaska	NOS	TWC1881	60.56666666666701	-145.96666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:01:00	0	\N	-00:08:00	-0.5	\N	\N	\N	Windy Bay, Hawkins Island	AK
105989	Port Etches, Hinchinbrook Island, Alaska	NOS	TWC1887	60.333333333332995	-146.55	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	00:01:00	-0.2	\N	-00:09:00	-1.3	\N	\N	\N	Port Etches	AK
105990	Hanning Bay, Montague Island, Alaska	NOS	TWC1893	59.95	-147.68333333332993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:05:00	-0.1	\N	-00:08:00	-1	\N	\N	\N	Hanning Bay	AK
105991	Smith Island, Prince William Sound, Alaska	NOS	TWC1907	60.53333333333299	-147.31666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:04:00	-0.1	\N	-00:05:00	-0.8	\N	\N	\N	Smith Island	AK
105992	Snug Corner Cove, Port Fidalgo, Prince William Sound, Alaska	NOS	TWC1909	60.73333333333299	-146.65	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103730	-00:06:00	0	\N	-00:07:00	-0.6	\N	\N	\N	Snug Corner Cove, Port Fidalgo	AK
105993	Cape Ninilchik, Cook Inlet, Alaska	NOS	TWC1979	60.01666666666701	-151.71666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	00:54:00	0.2	\N	00:41:00	1.2	\N	\N	\N	Cape Ninilchik	AK
105994	Kenai River entrance, Cook Inlet, Alaska	NOS	TWC1983	60.55	-151.28333333332992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	02:18:00	0.5	\N	01:52:00	2.7	\N	\N	\N	Kenai River entrance	AK
105995	East Foreland, Cook Inlet, Alaska	NOS	TWC1989	60.71666666666701	-151.41666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	02:58:00	0.5	\N	02:37:00	3	\N	\N	\N	East Foreland	AK
105996	Iliamna Bay, Cook Inlet, Alaska	NOS	TWC2009	59.61666666666701	-153.58333333332993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	00:16:00	\N	0.82	00:12:00	\N	0.8	\N	\N	Iliamna Bay	AK
105997	Marmot Island, Marmot Strait, Alaska	NOS	TWC2021	58.23333333333299	-151.86666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:07:00	0	\N	00:18:00	0.9	\N	\N	\N	Marmot Island, Marmot Strait	AK
105998	Izhut Bay, Alaska	NOS	TWC2023	58.21666666666701	-152.31666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:21:00	0	\N	00:12:00	0.1	\N	\N	\N	Izhut Bay	AK
105999	Kazakof Bay, Marmot Bay, Alaska	NOS	TWC2025	58.13333333333299	-152.56666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:06:00	0.2	\N	00:04:00	0.6	\N	\N	\N	Kazakof Bay, Marmot Bay	AK
106000	Kizhuyak Point, Alaska	NOS	TWC2031	57.9	-152.65	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:09:00	0.1	\N	00:05:00	0.6	\N	\N	\N	Kizhuyak Point	AK
106001	Three Saints Bay, Alaska	NOS	TWC2047	57.11666666666701	-153.5166666666701	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	-00:13:00	0.1	\N	-00:22:00	-0.2	\N	\N	\N	Three Saints Bay	AK
106002	Sitkinak Lagoon, Alaska	NOS	TWC2051	56.5	-154.13333333332992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:07:00	0.2	\N	-00:20:00	-1	\N	\N	\N	Sitkinak Lagoon	AK
106003	Village Islands, Uganik Bay, Alaska	NOS	TWC2067	57.78333333333299	-153.55	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	-00:02:00	\N	0.8	-00:15:00	\N	0.8	\N	\N	Village Islands	AK
106004	Northeast Arm, Uganik Bay, Alaska	NOS	TWC2069	57.73333333333299	-153.33333333332993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	-00:01:00	\N	0.77	-00:12:00	\N	0.77	\N	\N	Northeast Arm	AK
106005	Uganik Passage, Uganik Bay, Alaska	NOS	TWC2071	57.8	-153.3	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	00:02:00	\N	0.81	-00:07:00	\N	0.81	\N	\N	Uganik Passage	AK
106006	Viekoda Bay, Alaska	NOS	TWC2073	57.9	-153.16666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	-00:03:00	\N	0.8	-00:11:00	\N	0.8	\N	\N	Viekoda Bay	AK
106007	Onion Bay, Kupreanof Strait, Alaska	NOS	TWC2075	58.05	-153.2333333333299	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	-00:01:00	\N	0.8	00:00:00	\N	0.8	\N	\N	Onion Bay	AK
106008	Dry Spruce Island, Kupreanof Strait, Alaska	NOS	TWC2077	57.95	-153.03333333332992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	00:13:00	\N	0.77	00:02:00	\N	0.77	\N	\N	Dry Spruce Island	AK
106009	Malina Bay, Shelikof Strait, Alaska	NOS	TWC2085	58.18333333333299	-152.95	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	00:00:00	\N	0.81	-00:14:00	\N	0.81	\N	\N	Malina Bay, Shelikof Strait	AK
106010	Katmai Bay, Shelikof Strait, Alaska	NOS	TWC2095	58	-154.9833333333299	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103756	00:01:00	\N	0.71	-00:14:00	\N	0.71	\N	\N	Katmai Bay, Shelikof Strait	AK
106011	Lees Cabins, Wide Bay, Alaska	NOS	TWC2101	57.43333333333299	-156.3	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:32:00	0.2	\N	00:21:00	3.2	\N	\N	\N	Lees Cabins, Wide Bay	AK
106012	Three Star Point, Alaska	NOS	TWC2105	55.9	-159.16666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:37:00	\N	1.28	00:28:00	\N	0.9	\N	\N	Three Star Point	AK
106013	Fox Bay, Kupreanof Peninsula, Alaska	NOS	TWC2111	55.63333333333299	-159.61666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	00:33:00	\N	1.19	00:18:00	\N	0.86	\N	\N	Fox Bay, Kupreanof Peninsula	AK
106014	Mist Harbor, Nagai Island, Shumagin Islands, Alaska	NOS	TWC2119	55.13333333333299	-159.85	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103799	-00:01:00	\N	0.9	00:01:00	\N	0.97	\N	\N	Mist Harbor, Nagai Island	AK
106015	Malga Bay, Unalga Island, Aleutian Islands, Alaska	NOS	TWC2175	53.98333333333299	-166.16666666667007	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-01:05:00	\N	0.93	-00:18:00	\N	0.85	\N	\N	Malga Bay, Unalga Island	AK
106016	Kashega Bay, Unalaska Island, Alaska	NOS	TWC2187	53.46666666666701	-167.08333333332993	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-00:24:00	\N	1.19	-00:08:00	\N	1.08	\N	\N	Kashega Bay	AK
106017	Eagle Bay, Unalaska Island, Alaska	NOS	TWC2193	53.48333333333299	-166.93333333332993	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-03:16:00	\N	1.02	-02:56:00	\N	1.46	\N	\N	Eagle Bay	AK
106018	Herbert Island, west side, Aleutian Islands, Alaska	NOS	TWC2223	52.71666666666701	-170.15	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-01:51:00	\N	0.93	-01:40:00	\N	1.14	\N	\N	Herbert Island, west side	AK
106019	Amukta Island, north side, Aleutian Islands, Alaska	NOS	TWC2229	52.51666666666701	-171.2333333333299	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103808	-02:03:00	\N	1.1	-01:32:00	\N	0.94	\N	\N	Amukta Island, north side	AK
106020	Gareloi Island, Delarof Islands, Alaska	NOS	TWC2297	51.75	-178.8	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-00:30:00	\N	1	-00:08:00	\N	1	\N	\N	Gareloi Island	AK
106021	Constantine Harbor, Amchitka Island, Rat Islands, Alaska	NOS	TWC2303	51.41669845581055	179.28329467773438	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-01:06:00	\N	0.76	00:19:00	\N	0.76	\N	\N	Constantine Harbor, Amchitka Island	AK
106022	Gertrude Cove, Kiska Island, Rat Islands, Alaska	NOS	TWC2305	51.93330001831055	177.4499969482422	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-01:19:00	\N	0.86	00:02:00	\N	0.86	\N	\N	Gertrude Cove, Kiska Island	AK
106023	Kiska Harbor, Kiska Island, Rat Islands, Alaska	NOS	TWC2307	51.983299255371094	177.5500030517578	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103805	-01:13:00	\N	0.97	00:24:00	\N	0.97	\N	\N	Kiska Harbor, Kiska Island	AK
106024	Alcan Harbor, Shemya Island, Aleutian Islands, Alaska	NOS	TWC2309	52.71670150756836	174.0666961669922	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103804	-01:03:00	\N	1.03	00:00:00	\N	1.03	\N	\N	Alcan Harbor, Shemya Island	AK
106025	Otkriti Bay, Agattu Island, Aleutian Islands, Alaska	NOS	TWC2311	52.36669921875	173.61669921875	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103804	-01:13:00	\N	1.03	-01:14:00	\N	1.03	\N	\N	Otkriti Bay, Agattu Island	AK
106026	Chichagof Harbor, Attu Island, Alaska	NOS	TWC2315	52.91669845581055	173.21670532226562	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103804	00:16:00	\N	1.09	00:13:00	\N	1.09	\N	\N	Chichagof Harbor	AK
106027	Holtz Bay, Attu Island, Alaska	NOS	TWC2317	52.91669845581055	173.1667022705078	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103804	00:18:00	\N	1.12	-01:04:00	\N	1.12	\N	\N	Holtz Bay	AK
106028	Steller Cove, Attu Island, Alaska	NOS	TWC2319	52.96670150756836	172.89999389648438	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103804	00:11:00	\N	1.12	-01:13:00	\N	1.12	\N	\N	Steller Cove	AK
106029	Etienne Bay, Attu Island, Alaska	NOS	TWC2321	52.91669845581055	172.61669921875	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103804	00:03:00	\N	1.12	-01:17:00	\N	1.12	\N	\N	Etienne Bay	AK
106030	Apoon Mouth, Pastol Bay, Norton Sound, Alaska	NOS	TWC2405	63.05	-163.38333333332992	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103875	-01:30:00	\N	1.03	-01:30:00	\N	1.03	\N	\N	Apoon Mouth, Yukon River	AK
106031	Flaxman Island, Alaska	NOS	TWC2423	70.183333333333	-145.83333333332993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103776	-00:28:00	\N	0.09	-00:57:00	\N	0.08	\N	\N	Flaxman Island	AK
106053	Northeast Grave (depth 8 ft), Massachusetts Current	NOS	BOS1106_12	42.37176	-70.8618	:America/New_York	USA	knots	86	251	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northeast Grave	MA
106054	Commissioners Ledge (depth 16 ft), Massachusetts Current	NOS	BOS1107_1	42.33584	-70.91296	:America/New_York	USA	knots	29	215	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Commissioners Ledge	MA
106060	South Channel Aldridge Ledge (depth 20 ft), Massachusetts Current	NOS	BOS1109_4	42.34958	-70.91286	:America/New_York	USA	knots	45	222	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Channel Aldridge Ledge	MA
106061	South Channel Aldridge Ledge (depth 4 ft), Massachusetts Current	NOS	BOS1109_9	42.34958	-70.91286	:America/New_York	USA	knots	57	229	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Channel Aldridge Ledge	MA
106062	Deer Island, 0.7 nmi ESE of (depth 36 ft), Massachusetts Current	NOS	BOS1110_1	42.34413	-70.93888	:America/New_York	USA	knots	35	219	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.164	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deer Island, 0.7 nm ESE of	MA
106063	Deer Island, 0.7 nmi ESE of (depth 16 ft), Massachusetts Current	NOS	BOS1110_7	42.34413	-70.93888	:America/New_York	USA	knots	47	220	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deer Island, 0.7 nm ESE of	MA
106064	Deer Island, 0.7 nmi ESE of (depth 7 ft), Massachusetts Current	NOS	BOS1110_10	42.34413	-70.93888	:America/New_York	USA	knots	46	220	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deer Island, 0.7 nm ESE of	MA
106065	Boston Harbor (Deer Island Light) (depth 51 ft), Massachusetts Current	NOS	BOS1111_1	42.33778	-70.95578	:America/New_York	USA	knots	102	273	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Harbor (Deer Island Light)	MA
106066	Boston Harbor (Deer Island Light) (depth 28 ft), Massachusetts Current	NOS	BOS1111_8	42.33778	-70.95578	:America/New_York	USA	knots	100	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Harbor (Deer Island Light)	MA
106067	Boston Harbor (Deer Island Light) (depth 8 ft), Massachusetts Current	NOS	BOS1111_14	42.33778	-70.95578	:America/New_York	USA	knots	112	264	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Harbor (Deer Island Light)	MA
106068	Spectacle Island, 0.4 nmi north of (depth 33 ft), Massachusetts Current	NOS	BOS1112_1	42.33422	-70.98598	:America/New_York	USA	knots	99	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spectacle Island, 0.4nm north of	MA
106069	Spectacle Island, 0.4 nmi north of (depth 16 ft), Massachusetts Current	NOS	BOS1112_11	42.33422	-70.98598	:America/New_York	USA	knots	86	283	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spectacle Island, 0.4nm north of	MA
106070	Spectacle Island, 0.4 nmi north of (depth 3 ft), Massachusetts Current	NOS	BOS1112_19	42.33422	-70.98598	:America/New_York	USA	knots	91	284	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spectacle Island, 0.4nm north of	MA
106071	Boston Channel Light No. 5 (depth 33 ft), Massachusetts Current	NOS	BOS1113_3	42.33578	-71.00028	:America/New_York	USA	knots	119	297	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Channel Light No.5	MA
106072	Boston Channel Light No. 5 (depth 15 ft), Massachusetts Current	NOS	BOS1113_14	42.33578	-71.00028	:America/New_York	USA	knots	95	276	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.126	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Channel Light No.5	MA
106073	Boston Channel Light No. 5 (depth 3 ft), Massachusetts Current	NOS	BOS1113_21	42.33578	-71.00028	:America/New_York	USA	knots	104	283	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Channel Light No.5	MA
106074	Fort Independence, 0.1 nmi north of (depth 26 ft), Massachusetts Current	NOS	BOS1114_2	42.3418	-71.00892	:America/New_York	USA	knots	103	300	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.184	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Independence, 0.1nm north of	MA
106075	Fort Independence, 0.1 nmi north of (depth 16 ft), Massachusetts Current	NOS	BOS1114_5	42.3418	-71.00892	:America/New_York	USA	knots	108	297	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Independence, 0.1nm north of	MA
106076	Fort Independence, 0.1 nmi north of (depth 6 ft), Massachusetts Current	NOS	BOS1114_8	42.3418	-71.00892	:America/New_York	USA	knots	108	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Independence, 0.1nm north of	MA
106077	Ted William Tunnel (depth 26 ft), Massachusetts Current	NOS	BOS1115_1	42.3517	-71.02611	:America/New_York	USA	knots	125	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ted William Tunnel	MA
106078	Ted William Tunnel (depth 16 ft), Massachusetts Current	NOS	BOS1115_4	42.3517	-71.02611	:America/New_York	USA	knots	136	315	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ted William Tunnel	MA
106079	Ted William Tunnel (depth 7 ft), Massachusetts Current	NOS	BOS1115_7	42.3517	-71.02611	:America/New_York	USA	knots	124	312	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ted William Tunnel	MA
106080	Charlestown Pier 1 (depth 57 ft), Massachusetts Current	NOS	BOS1118_1	42.37996	-71.04502	:America/New_York	USA	knots	\N	357.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charlestown Pier 1	MA
106081	Charlestown Pier 1 (depth 31 ft), Massachusetts Current	NOS	BOS1118_9	42.37996	-71.04502	:America/New_York	USA	knots	\N	7.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charlestown Pier 1	MA
106082	Charlestown Pier 1 (depth 8 ft), Massachusetts Current	NOS	BOS1118_16	42.37996	-71.04502	:America/New_York	USA	knots	188	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charlestown Pier 1	MA
106083	Nixes Mate (depth 27 ft), Massachusetts Current	NOS	BOS1119_1	42.33248	-70.9394	:America/New_York	USA	knots	352	147	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nixes Mate	MA
106084	Nixes Mate (depth 14 ft), Massachusetts Current	NOS	BOS1119_5	42.33248	-70.9394	:America/New_York	USA	knots	12	176	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nixes Mate	MA
106085	Nixes Mate (depth 4 ft), Massachusetts Current	NOS	BOS1119_8	42.33248	-70.9394	:America/New_York	USA	knots	23	180	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nixes Mate	MA
106086	Lovell Island Narrows (depth 25 ft), Massachusetts Current	NOS	BOS1120_1	42.32817	-70.93313	:America/New_York	USA	knots	320	149	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovell Island Narrows	MA
106087	Lovell Island Narrows (depth 14 ft), Massachusetts Current	NOS	BOS1120_8	42.32817	-70.93313	:America/New_York	USA	knots	320	139	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovell Island Narrows	MA
106088	Lovell Island Narrows (depth 2 ft), Massachusetts Current	NOS	BOS1120_15	42.32817	-70.93313	:America/New_York	USA	knots	326	142	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovell Island Narrows	MA
106089	Georges Island, 0.4 nmi southeast of (depth 72 ft), Massachusetts Current	NOS	BOS1122_1	42.31293	-70.91995	:America/New_York	USA	knots	76	235	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 59.3 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Georges Island, 0.4nm southeast of	MA
106090	Georges Island, 0.4 nmi southeast of (depth 33 ft), Massachusetts Current	NOS	BOS1122_9	42.31293	-70.91995	:America/New_York	USA	knots	56	234	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Georges Island, 0.4nm southeast of	MA
106091	Georges Island, 0.4 nmi southeast of (depth 7 ft), Massachusetts Current	NOS	BOS1122_17	42.31293	-70.91995	:America/New_York	USA	knots	51	233	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Georges Island, 0.4nm southeast of	MA
106092	Hull Gut (depth 35 ft), Massachusetts Current	NOS	BOS1123_1	42.30338	-70.92492	:America/New_York	USA	knots	343	152	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hull Gut	MA
106093	Hull Gut (depth 22 ft), Massachusetts Current	NOS	BOS1123_5	42.30338	-70.92492	:America/New_York	USA	knots	341	159	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hull Gut	MA
106094	Hull Gut (depth 9 ft), Massachusetts Current	NOS	BOS1123_9	42.30338	-70.92492	:America/New_York	USA	knots	340	162	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hull Gut	MA
106095	The Piglets, 0.4 nmi northest of (depth 30 ft), Massachusetts Current	NOS	BOS1124_1	42.28338	-70.93093	:America/New_York	USA	knots	36	207	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Piglets, 0.4 n.mi. northest of	MA
106096	The Piglets, 0.4 nmi northest of (depth 17 ft), Massachusetts Current	NOS	BOS1124_5	42.28338	-70.93093	:America/New_York	USA	knots	41	213	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Piglets, 0.4 n.mi. northest of	MA
106097	The Piglets, 0.4 nmi northest of (depth 7 ft), Massachusetts Current	NOS	BOS1124_8	42.28338	-70.93093	:America/New_York	USA	knots	41	224	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Piglets, 0.4 n.mi. northest of	MA
106098	Jacknife Ledge (depth 32 ft), Massachusetts Current	NOS	BOS1125_1	42.25878	-70.94102	:America/New_York	USA	knots	30	203	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jacknife Ledge	MA
106099	Jacknife Ledge (depth 16 ft), Massachusetts Current	NOS	BOS1125_6	42.25878	-70.94102	:America/New_York	USA	knots	17	216	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jacknife Ledge	MA
106100	Jacknife Ledge (depth 6 ft), Massachusetts Current	NOS	BOS1125_9	42.25878	-70.94102	:America/New_York	USA	knots	24	219	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jacknife Ledge	MA
106101	Weymouth Harbor entrance (depth 29 ft), Massachusetts Current	NOS	BOS1126_1	42.2482	-70.96072	:America/New_York	USA	knots	65	249	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.174	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weymouth Harbor Entrance	MA
106102	Weymouth Harbor entrance (depth 16 ft), Massachusetts Current	NOS	BOS1126_5	42.2482	-70.96072	:America/New_York	USA	knots	73	250	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.098	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weymouth Harbor Entrance	MA
106103	Weymouth Harbor entrance (depth 6 ft), Massachusetts Current	NOS	BOS1126_8	42.2482	-70.96072	:America/New_York	USA	knots	76	250	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weymouth Harbor Entrance	MA
106104	Point Allerton, 0.65 nmi NNW of (depth 30 ft), Massachusetts Current	NOS	BOS1127_1	42.31926	-70.88706	:America/New_York	USA	knots	71	236	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Allerton, 0.65 n.mi. NNW of	MA
106105	Point Allerton, 0.65 nmi NNW of (depth 17 ft), Massachusetts Current	NOS	BOS1127_5	42.31926	-70.88706	:America/New_York	USA	knots	71	253	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Allerton, 0.65 n.mi. NNW of	MA
106106	Point Allerton, 0.65 nmi NNW of (depth 4 ft), Massachusetts Current	NOS	BOS1127_9	42.31926	-70.88706	:America/New_York	USA	knots	72	266	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Allerton, 0.65 n.mi. NNW of	MA
106107	Stellwagen Basin, east end (depth 240 ft), Massachusetts Current	NOS	BOS1130_1	42.33813	-70.532	:America/New_York	USA	knots	97	266.8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Basin, east end	MA
106108	Stellwagen Basin, east end (depth 122 ft), Massachusetts Current	NOS	BOS1130_10	42.33813	-70.532	:America/New_York	USA	knots	93	255.7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Basin, east end	MA
106109	Stellwagen Basin, east end (depth 30 ft), Massachusetts Current	NOS	BOS1130_17	42.33813	-70.532	:America/New_York	USA	knots	147	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Basin, east end	MA
106110	Stellwagen Bank, 16 nmi north of Race Point (depth 90 ft), Massachusetts Current	NOS	BOS1131_1	42.32397	-70.29397	:America/New_York	USA	knots	92	268	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 16nm North of Race Point	MA
106111	Stellwagen Bank, 16 nmi north of Race Point (depth 51 ft), Massachusetts Current	NOS	BOS1131_13	42.32397	-70.29397	:America/New_York	USA	knots	86	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.162	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 16nm North of Race Point	MA
106112	Stellwagen Bank, 16 nmi north of Race Point (depth 8 ft), Massachusetts Current	NOS	BOS1131_26	42.32397	-70.29397	:America/New_York	USA	knots	100	253	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.198	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 16nm North of Race Point	MA
106130	Spring Point, NE of (depth 7 ft), Casco Bay, Maine Current	NOS	CAB1402_10	43.65367	-70.22267	:America/New_York	USA	knots	124	343	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Point, NE of	ME
106113	Stellwagen Bank, 15 nmi NNE of Race Point (depth 210 ft), Massachusetts Current	NOS	BOS1132_1	42.31213	-70.11202	:America/New_York	USA	knots	121	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 15nm NNE of Race Point	MA
106114	Stellwagen Bank, 15 nmi NNE of Race Point (depth 105 ft), Massachusetts Current	NOS	BOS1132_9	42.31213	-70.11202	:America/New_York	USA	knots	125	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 15nm NNE of Race Point	MA
106115	Stellwagen Bank, 15 nmi NNE of Race Point (depth 27 ft), Massachusetts Current	NOS	BOS1132_15	42.31213	-70.11202	:America/New_York	USA	knots	121	254	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 15nm NNE of Race Point	MA
106116	Stellwagen Bank, 13.4 nmi SE of Eastern Pt. Light (depth 71 ft), Massachusetts Current	NOS	BOS1133_1	42.4224	-70.44982	:America/New_York	USA	knots	49	223	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 13.4nm SE of Eastern Pt. Light	MA
106117	Stellwagen Bank, 13.4 nmi SE of Eastern Pt. Light (depth 38 ft), Massachusetts Current	NOS	BOS1133_6	42.4224	-70.44982	:America/New_York	USA	knots	70	236	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 13.4nm SE of Eastern Pt. Light	MA
106118	Stellwagen Bank, 13.4 nmi SE of Eastern Pt. Light (depth 12 ft), Massachusetts Current	NOS	BOS1133_10	42.4224	-70.44982	:America/New_York	USA	knots	93	252	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 13.4nm SE of Eastern Pt. Light	MA
106119	Stellwagen Basin, 13.8 nmi SE of Eastern Pt. Light (depth 245 ft), Massachusetts Current	NOS	BOS1134_1	42.38818	-70.48302	:America/New_York	USA	knots	\N	296	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Basin, 13.8nm SE of Eastern Pt. Light	MA
106120	Stellwagen Basin, 13.8 nmi SE of Eastern Pt. Light (depth 100 ft), Massachusetts Current	NOS	BOS1134_12	42.38818	-70.48302	:America/New_York	USA	knots	\N	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Basin, 13.8nm SE of Eastern Pt. Light	MA
106121	Stellwagen Basin, 13.8 nmi SE of Eastern Pt. Light (depth 35 ft), Massachusetts Current	NOS	BOS1134_17	42.38818	-70.48302	:America/New_York	USA	knots	195	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Basin, 13.8nm SE of Eastern Pt. Light	MA
106122	Stellwagen Bank, 17 nmi ESE of Eastern Pt. Light (depth 308 ft), Massachusetts Current	NOS	BOS1135_1	42.47305	-70.31203	:America/New_York	USA	knots	108	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 17nm ESE of Eastern Pt. Light	MA
106123	Stellwagen Bank, 17 nmi ESE of Eastern Pt. Light (depth 150 ft), Massachusetts Current	NOS	BOS1135_9	42.47305	-70.31203	:America/New_York	USA	knots	95	272.7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 17nm ESE of Eastern Pt. Light	MA
106124	Stellwagen Bank, 17 nmi ESE of Eastern Pt. Light (depth 52 ft), Massachusetts Current	NOS	BOS1135_14	42.47305	-70.31203	:America/New_York	USA	knots	91	269	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 17nm ESE of Eastern Pt. Light	MA
106125	Portland Harbor entrance (depth 39 ft), Casco Bay, Maine Current	NOS	CAB1401_2	43.628	-70.2095	:America/New_York	USA	knots	140	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Harbor Entrance	ME
106126	Portland Harbor entrance (depth 19 ft), Casco Bay, Maine Current	NOS	CAB1401_8	43.628	-70.2095	:America/New_York	USA	knots	137	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Harbor Entrance	ME
106127	Portland Harbor entrance (depth 9 ft), Casco Bay, Maine Current	NOS	CAB1401_11	43.628	-70.2095	:America/New_York	USA	knots	138	310	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Harbor Entrance	ME
106128	Spring Point, NE of (depth 36 ft), Casco Bay, Maine Current	NOS	CAB1402_1	43.65367	-70.22267	:America/New_York	USA	knots	113	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Point, NE of	ME
106129	Spring Point, NE of (depth 20 ft), Casco Bay, Maine Current	NOS	CAB1402_6	43.65367	-70.22267	:America/New_York	USA	knots	123	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Point, NE of	ME
106131	Portland Breakwater Light, 0.3 nmi east of (depth 36 ft), Casco Bay, Maine Current	NOS	CAB1403_2	43.65534	-70.22783	:America/New_York	USA	knots	102	247	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Breakwater Light, 0.3 n.mi east of	ME
106132	Portland Breakwater Light, 0.3 nmi east of (depth 20 ft), Casco Bay, Maine Current	NOS	CAB1403_7	43.65534	-70.22783	:America/New_York	USA	knots	121	256	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.159	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Breakwater Light, 0.3 n.mi east of	ME
106133	Portland Breakwater Light, 0.3 nmi east of (depth 6 ft), Casco Bay, Maine Current	NOS	CAB1403_11	43.65534	-70.22783	:America/New_York	USA	knots	114	268	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Breakwater Light, 0.3 n.mi east of	ME
106134	Diamond Island Roads (depth 34 ft), Casco Bay, Maine Current	NOS	CAB1404_3	43.66253	-70.21567	:America/New_York	USA	knots	168	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Diamond Island Roads	ME
106135	Diamond Island Roads (depth 17 ft), Casco Bay, Maine Current	NOS	CAB1404_8	43.66253	-70.21567	:America/New_York	USA	knots	165	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Diamond Island Roads	ME
106136	Diamond Island Roads (depth 7 ft), Casco Bay, Maine Current	NOS	CAB1404_11	43.66253	-70.21567	:America/New_York	USA	knots	164	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.145	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Diamond Island Roads	ME
106137	Ocean Gate Terminal (depth 21 ft), Casco Bay, Maine Current	NOS	CAB1405_1	43.661	-70.24	:America/New_York	USA	knots	28	208	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.157	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocean Gate Terminal	ME
106138	Ocean Gate Terminal (depth 3 ft), Casco Bay, Maine Current	NOS	CAB1405_12	43.661	-70.24	:America/New_York	USA	knots	50	230	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocean Gate Terminal	ME
106139	State Pier, Portland Harbor (depth 30 ft), Casco Bay, Maine Current	NOS	CAB1406_1	43.65466	-70.245	:America/New_York	USA	knots	41	221	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Pier, Portland Harbor	ME
106140	State Pier, Portland Harbor (depth 17 ft), Casco Bay, Maine Current	NOS	CAB1406_5	43.65466	-70.245	:America/New_York	USA	knots	56	221	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Pier, Portland Harbor	ME
106141	State Pier, Portland Harbor (depth 3 ft), Casco Bay, Maine Current	NOS	CAB1406_9	43.65466	-70.245	:America/New_York	USA	knots	54	214	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Pier, Portland Harbor	ME
106142	Fore River, Portland River Bridge (depth 21 ft), Casco Bay, Maine Current	NOS	CAB1407_2	43.64583	-70.25733	:America/New_York	USA	knots	64	227	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fore River, Portland River Bridge	ME
106143	Fore River, Portland River Bridge (depth 5 ft), Casco Bay, Maine Current	NOS	CAB1407_7	43.64583	-70.25733	:America/New_York	USA	knots	65	229	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fore River, Portland River Bridge	ME
106144	Chandler Cove, S. ent. (depth 37 ft), Casco Bay, Maine Current	NOS	CAB1409_1	43.70698	-70.1323	:America/New_York	USA	knots	187	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chandler Cove, S. Ent	ME
106145	Chandler Cove, S. ent. (depth 17 ft), Casco Bay, Maine Current	NOS	CAB1409_7	43.70698	-70.1323	:America/New_York	USA	knots	180	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chandler Cove, S. Ent	ME
106146	Chandler Cove, S. ent. (depth 4 ft), Casco Bay, Maine Current	NOS	CAB1409_11	43.70698	-70.1323	:America/New_York	USA	knots	179	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chandler Cove, S. Ent	ME
106147	Hussey Sound, Between Long and Peaks Island (depth 70 ft), Casco Bay, Maine Current	NOS	CAB1410_1	43.670799255371094	-70.17632293701172	:America/New_York	USA	knots	140	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hussey Sound, Between Long and Peaks Island	ME
106148	Hussey Sound, Between Long and Peaks Island (depth 31 ft), Casco Bay, Maine Current	NOS	CAB1410_7	43.670799255371094	-70.17632293701172	:America/New_York	USA	knots	147	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hussey Sound, Between Long and Peaks Island	ME
106149	Hussey Sound, Between Long and Peaks Island (depth 11 ft), Casco Bay, Maine Current	NOS	CAB1410_10	43.670799255371094	-70.17632293701172	:America/New_York	USA	knots	145	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hussey Sound, Between Long and Peaks Island	ME
106150	Long Island, Mariner Ledge (depth 26 ft), Casco Bay, Maine Current	NOS	CAB1411_4	43.702	-70.16417	:America/New_York	USA	knots	194	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Long Island, Mariner Ledge	ME
106151	Long Island, Mariner Ledge (depth 9 ft), Casco Bay, Maine Current	NOS	CAB1411_9	43.702	-70.16417	:America/New_York	USA	knots	182	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Long Island, Mariner Ledge	ME
106152	Hussey Sound, Cow Island (depth 57 ft), Casco Bay, Maine Current	NOS	CAB1412_1	43.68983	-70.17834	:America/New_York	USA	knots	195	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hussey Sound, Cow Island	ME
106153	Hussey Sound, Cow Island (depth 30 ft), Casco Bay, Maine Current	NOS	CAB1412_5	43.68983	-70.17834	:America/New_York	USA	knots	185	12	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hussey Sound, Cow Island	ME
106154	Hussey Sound, Cow Island (depth 11 ft), Casco Bay, Maine Current	NOS	CAB1412_8	43.68983	-70.17834	:America/New_York	USA	knots	178	12	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hussey Sound, Cow Island	ME
106155	Cow Island, NE of (depth 39 ft), Casco Bay, Maine Current	NOS	CAB1413_2	43.69417	-70.181	:America/New_York	USA	knots	152	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cow Island, NE of	ME
106156	Cow Island, NE of (depth 13 ft), Casco Bay, Maine Current	NOS	CAB1413_6	43.69417	-70.181	:America/New_York	USA	knots	144	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cow Island, NE of	ME
106157	Lucksee Sound Between Hope and Cliff Is. (depth 40 ft), Casco Bay, Maine Current	NOS	CAB1414_1	43.69838	-70.11567	:America/New_York	USA	knots	227	51	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lucksee Sound Between Hope and Cliff Is.	ME
106158	Lucksee Sound Between Hope and Cliff Is. (depth 27 ft), Casco Bay, Maine Current	NOS	CAB1414_3	43.69838	-70.11567	:America/New_York	USA	knots	228	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lucksee Sound Between Hope and Cliff Is.	ME
106159	Lucksee Sound Between Hope and Cliff Is. (depth 14 ft), Casco Bay, Maine Current	NOS	CAB1414_5	43.69838	-70.11567	:America/New_York	USA	knots	227	50	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lucksee Sound Between Hope and Cliff Is.	ME
106160	Stepping Stones (depth 42 ft), Casco Bay, Maine Current	NOS	CAB1415_1	43.69583	-70.13267	:America/New_York	USA	knots	169	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stepping Stones	ME
106161	Stepping Stones (depth 19 ft), Casco Bay, Maine Current	NOS	CAB1415_8	43.69583	-70.13267	:America/New_York	USA	knots	191	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stepping Stones	ME
106162	Stepping Stones (depth 6 ft), Casco Bay, Maine Current	NOS	CAB1415_12	43.69583	-70.13267	:America/New_York	USA	knots	197	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stepping Stones	ME
106163	Eagle Island W. of, Broad Sound (depth 91 ft), Casco Bay, Maine Current	NOS	CAB1416_3	43.71	-70.06283	:America/New_York	USA	knots	191	340	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.263	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Island W. of., Broad Sound	ME
106164	Eagle Island W. of, Broad Sound (depth 39 ft), Casco Bay, Maine Current	NOS	CAB1416_11	43.71	-70.06283	:America/New_York	USA	knots	187	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Island W. of., Broad Sound	ME
106165	Eagle Island W. of, Broad Sound (depth 19 ft), Casco Bay, Maine Current	NOS	CAB1416_14	43.71	-70.06283	:America/New_York	USA	knots	187	351	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Island W. of., Broad Sound	ME
106166	Littlejohn Island, south of Town Ledge (depth 36 ft), Casco Bay, Maine Current	NOS	CAB1417_1	43.75417	-70.12767	:America/New_York	USA	knots	210	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Littlejohn Island, South of Town Ledge	ME
106167	Littlejohn Island, south of Town Ledge (depth 20 ft), Casco Bay, Maine Current	NOS	CAB1417_6	43.75417	-70.12767	:America/New_York	USA	knots	214	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Littlejohn Island, South of Town Ledge	ME
106168	Littlejohn Island, south of Town Ledge (depth 6 ft), Casco Bay, Maine Current	NOS	CAB1417_10	43.75417	-70.12767	:America/New_York	USA	knots	221	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Littlejohn Island, South of Town Ledge	ME
106169	Maine Kennebec Bridge, 0.2 nmi SW of (depth 19 ft), Kennebec River, Maine Current	NOS	CAB1418_1	44.088	-69.78517	:America/New_York	USA	knots	202	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.337	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Maine Kennebec Bridge, 0.2 n.mi. SW of	ME
106170	Maine Kennebec Bridge, 0.2 nmi SW of (depth 4 ft), Kennebec River, Maine Current	NOS	CAB1418_10	44.088	-69.78517	:America/New_York	USA	knots	208	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.413	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Maine Kennebec Bridge, 0.2 n.mi. SW of	ME
106171	Goose Cove, south of Chops Passage, Kennebec River (depth 27 ft), Maine Current	NOS	CAB1419_1	43.97516	-69.82667	:America/New_York	USA	knots	158	338	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.388	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goose Cove, south of Chops Passage, Kennebec River	ME
106172	Goose Cove, south of Chops Passage, Kennebec River (depth 14 ft), Maine Current	NOS	CAB1419_5	43.97516	-69.82667	:America/New_York	USA	knots	154	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.419	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goose Cove, south of Chops Passage, Kennebec River	ME
106173	Goose Cove, south of Chops Passage, Kennebec River (depth 4 ft), Maine Current	NOS	CAB1419_8	43.97516	-69.82667	:America/New_York	USA	knots	154	343	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.407	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goose Cove, south of Chops Passage, Kennebec River	ME
106174	Bath Iron Works, Kennebec River (depth 36 ft), Maine Current	NOS	CAB1420_1	43.90383	-69.80933	:America/New_York	USA	knots	176	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 38.9 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bath Iron Works, Kennebec River	ME
106175	Bath Iron Works, Kennebec River (depth 16 ft), Maine Current	NOS	CAB1420_8	43.90383	-69.80933	:America/New_York	USA	knots	178	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bath Iron Works, Kennebec River	ME
106176	Bath Iron Works, Kennebec River (depth 4 ft), Maine Current	NOS	CAB1420_12	43.90383	-69.80933	:America/New_York	USA	knots	178	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 2.8 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.242	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bath Iron Works, Kennebec River	ME
106177	Merrymeeting Bay, N of Chops Pass, Kennebec River (depth 40 ft), Maine Current	NOS	CAB1421_1	43.98433	-69.83617	:America/New_York	USA	knots	137	307	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Merrymeeting Bay, N of Chops Pass., Kennebec River	ME
106178	Merrymeeting Bay, N of Chops Pass, Kennebec River (depth 20 ft), Maine Current	NOS	CAB1421_7	43.98433	-69.83617	:America/New_York	USA	knots	120	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Merrymeeting Bay, N of Chops Pass., Kennebec River	ME
106179	Merrymeeting Bay, N of Chops Pass, Kennebec River (depth 4 ft), Maine Current	NOS	CAB1421_12	43.98433	-69.83617	:America/New_York	USA	knots	108	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.252	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Merrymeeting Bay, N of Chops Pass., Kennebec River	ME
106180	Seal Cove, Cape Elizabeth (depth 29 ft), Maine Current	NOS	CAB1423_1	43.55233	-70.21767	:America/New_York	USA	knots	\N	315.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seal Cove, Cape Elizabeth	ME
106181	Seal Cove, Cape Elizabeth (depth 19 ft), Maine Current	NOS	CAB1423_4	43.55233	-70.21767	:America/New_York	USA	knots	\N	319.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seal Cove, Cape Elizabeth	ME
106182	Seal Cove, Cape Elizabeth (depth 3 ft), Maine Current	NOS	CAB1423_9	43.55233	-70.21767	:America/New_York	USA	knots	112	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seal Cove, Cape Elizabeth	ME
106183	Saco River entrance (depth 13 ft), Maine Current	NOS	CAB1425_4	43.4621	-70.35116	:America/New_York	USA	knots	\N	272.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saco River Entrance	ME
106184	Saco River entrance (depth 1 ft), Maine Current	NOS	CAB1425_11	43.4621	-70.35116	:America/New_York	USA	knots	78	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saco River Entrance	ME
106185	Cape May Harbor entrance (depth 28 ft), New Jersey Current	NOS	CAM0001_2	38.9475	-74.87267	:America/New_York	USA	knots	143	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May Harbor entrance	NJ
106186	Cape May Harbor entrance (depth 15 ft), New Jersey Current	NOS	CAM0001_10	38.9475	-74.87267	:America/New_York	USA	knots	142	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May Harbor entrance	NJ
106187	Cape May Harbor entrance (depth 5 ft), New Jersey Current	NOS	CAM0001_16	38.9475	-74.87267	:America/New_York	USA	knots	142	324	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May Harbor entrance	NJ
106188	Hilton RR Bridge, 0.1 nmi N of (depth 31 ft), Cape Fear River, North Carolina Current	NOS	CFR1601_1	34.25918960571289	-77.94805908203125	:America/New_York	USA	knots	173	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 25.8 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hilton RR Bridge, 0.1 nm N of	NC
106189	Hilton RR Bridge, 0.1 nmi N of (depth 12 ft), Cape Fear River, North Carolina Current	NOS	CFR1601_7	34.25918960571289	-77.94805908203125	:America/New_York	USA	knots	169	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 6.1 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hilton RR Bridge, 0.1 nm N of	NC
106190	Isabel Holmes Bridge (depth 29 ft), Cape Fear River, North Carolina Current	NOS	CFR1602_1	34.252410888671875	-77.95008850097656	:America/New_York	USA	knots	224	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isabel Holmes Bridge	NC
106191	Isabel Holmes Bridge (depth 6 ft), Cape Fear River, North Carolina Current	NOS	CFR1602_8	34.252410888671875	-77.95008850097656	:America/New_York	USA	knots	215	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isabel Holmes Bridge	NC
106192	Wilmington, Northeast River (depth 34 ft), Cape Fear River, North Carolina Current	NOS	CFR1603_1	34.241939544677734	-77.95394134521484	:America/New_York	USA	knots	161	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilmington, Northeast River	NC
106193	Wilmington, Northeast River (depth 14 ft), Cape Fear River, North Carolina Current	NOS	CFR1603_13	34.241939544677734	-77.95394134521484	:America/New_York	USA	knots	169	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilmington, Northeast River	NC
106194	Wilmington, Northeast River (depth 4 ft), Cape Fear River, North Carolina Current	NOS	CFR1603_19	34.241939544677734	-77.95394134521484	:America/New_York	USA	knots	171	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilmington, Northeast River	NC
106195	Point Peter (depth 23 ft), Cape Fear River, North Carolina Current	NOS	CFR1604_1	34.242488861083984	-77.95768737792969	:America/New_York	USA	knots	133	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Peter	NC
106196	Point Peter (depth 5 ft), Cape Fear River, North Carolina Current	NOS	CFR1604_12	34.242488861083984	-77.95768737792969	:America/New_York	USA	knots	132	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.249	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Peter	NC
106197	Wilmington, USS North Carolina (depth 25 ft), Cape Fear River, North Carolina Current	NOS	CFR1605_3	34.23347854614258	-77.9503173828125	:America/New_York	USA	knots	180	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilmington, USS North Carolina	NC
106198	Wilmington, USS North Carolina (depth 5 ft), Cape Fear River, North Carolina Current	NOS	CFR1605_9	34.23347854614258	-77.9503173828125	:America/New_York	USA	knots	179	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilmington, USS North Carolina	NC
106199	State Pier, N end, sidelooking (depth 20 ft), Cape Fear River, North Carolina Current	NOS	CFR1607_1	34.207801818847656	-77.9554214477539	:America/New_York	USA	knots	192	11	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Pier, N end, sidelooking	NC
106200	State Pier, N end, sidelooking (depth 151 ft), Cape Fear River, North Carolina Current	NOS	CFR1607_9	34.207801818847656	-77.9554214477539	:America/New_York	USA	knots	185	11	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Pier, N end, sidelooking	NC
106201	State Pier, N end, sidelooking (depth 315 ft), Cape Fear River, North Carolina Current	NOS	CFR1607_19	34.207801818847656	-77.9554214477539	:America/New_York	USA	knots	185	7	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.289	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Pier, N end, sidelooking	NC
106202	Dram Tree Point (depth 32 ft), Cape Fear River, North Carolina Current	NOS	CFR1608_2	34.190608978271484	-77.9577407836914	:America/New_York	USA	knots	178	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dram Tree Point	NC
106203	Dram Tree Point (depth 6 ft), Cape Fear River, North Carolina Current	NOS	CFR1608_10	34.190608978271484	-77.9577407836914	:America/New_York	USA	knots	181	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.375	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dram Tree Point	NC
106204	Port of Wilmington, south end (depth 43 ft), Cape Fear River, North Carolina Current	NOS	CFR1609_3	34.17580032348633	-77.9569091796875	:America/New_York	USA	knots	182	5	\N	\N	Depth provided in the stations list was duplicated for all bins.  Depth is as\nspecified in the harcon record.  Unknown whether it is below surface or chart\ndatum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.241	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of Wilmington, South End	NC
106205	Port of Wilmington, south end (depth 200 ft), Cape Fear River, North Carolina Current	NOS	CFR1609_15	34.17580032348633	-77.9569091796875	:America/New_York	USA	knots	174	357	\N	\N	Depth provided in the stations list was duplicated for all bins.  Depth is as\nspecified in the harcon record.  Unknown whether it is below surface or chart\ndatum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.371	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of Wilmington, South End	NC
106206	Port of Wilmington, south end (depth 331 ft), Cape Fear River, North Carolina Current	NOS	CFR1609_25	34.17580032348633	-77.9569091796875	:America/New_York	USA	knots	173	355	\N	\N	Depth provided in the stations list was duplicated for all bins.  Depth is as\nspecified in the harcon record.  Unknown whether it is below surface or chart\ndatum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of Wilmington, South End	NC
106207	Lower Brunswick Range (depth 39 ft), Cape Fear River, North Carolina Current	NOS	CFR1610_1	34.155941009521484	-77.95828247070312	:America/New_York	USA	knots	147	324	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.255	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Brunswick Range	NC
106208	Lower Brunswick Range (depth 16 ft), Cape Fear River, North Carolina Current	NOS	CFR1610_8	34.155941009521484	-77.95828247070312	:America/New_York	USA	knots	141	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Brunswick Range	NC
106209	Lower Brunswick Range (depth 9 ft), Cape Fear River, North Carolina Current	NOS	CFR1610_10	34.155941009521484	-77.95828247070312	:America/New_York	USA	knots	140	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Brunswick Range	NC
106210	Upper Big I Range (depth 36 ft), Cape Fear River, North Carolina Current	NOS	CFR1611_1	34.135501861572266	-77.94210052490234	:America/New_York	USA	knots	136	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.279	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upper Big I Range	NC
106211	Upper Big I Range (depth 20 ft), Cape Fear River, North Carolina Current	NOS	CFR1611_6	34.135501861572266	-77.94210052490234	:America/New_York	USA	knots	124	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upper Big I Range	NC
106212	Upper Big I Range (depth 6 ft), Cape Fear River, North Carolina Current	NOS	CFR1611_10	34.135501861572266	-77.94210052490234	:America/New_York	USA	knots	126	310	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.203	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upper Big I Range	NC
106213	Campbell Island, east side (depth 35 ft), Cape Fear River, North Carolina Current	NOS	CFR1612_1	34.119911193847656	-77.93521881103516	:America/New_York	USA	knots	187	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.184	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Campbell Island, East Side	NC
106214	Campbell Island, east side (depth 15 ft), Cape Fear River, North Carolina Current	NOS	CFR1612_7	34.119911193847656	-77.93521881103516	:America/New_York	USA	knots	185	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Campbell Island, East Side	NC
106215	Campbell Island, east side (depth 9 ft), Cape Fear River, North Carolina Current	NOS	CFR1612_9	34.119911193847656	-77.93521881103516	:America/New_York	USA	knots	189	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Campbell Island, East Side	NC
106216	Keg Island, west side (depth 30 ft), Cape Fear River, North Carolina Current	NOS	CFR1613_1	34.09700012207031	-77.93463897705078	:America/New_York	USA	knots	167	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Keg Island, West Side	NC
106217	Keg Island, west side (depth 7 ft), Cape Fear River, North Carolina Current	NOS	CFR1613_8	34.09700012207031	-77.93463897705078	:America/New_York	USA	knots	161	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.396	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Keg Island, West Side	NC
106218	Doctor Point, 0.6 nmi NNW of (depth 32 ft), Cape Fear River, North Carolina Current	NOS	CFR1614_1	34.07883071899414	-77.93205261230469	:America/New_York	USA	knots	163	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Doctor Point, 0.6 NM NNW of	NC
106219	Doctor Point, 0.6 nmi NNW of (depth 16 ft), Cape Fear River, North Carolina Current	NOS	CFR1614_6	34.07883071899414	-77.93205261230469	:America/New_York	USA	knots	166	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Doctor Point, 0.6 NM NNW of	NC
106220	Doctor Point, 0.6 nmi NNW of (depth 6 ft), Cape Fear River, North Carolina Current	NOS	CFR1614_9	34.07883071899414	-77.93205261230469	:America/New_York	USA	knots	166	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.384	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Doctor Point, 0.6 NM NNW of	NC
106221	Myrtle Sound, south end, ICW (depth 16 ft), Cape Fear River, North Carolina Current	NOS	CFR1615_1	34.07929992675781	-77.8843994140625	:America/New_York	USA	knots	233	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Myrtle Sound, south end, ICW	NC
106222	Snows Cut, ICW (depth 3 ft), Cape Fear River, North Carolina Current	NOS	CFR1616_4	34.05580139160156	-77.89900207519531	:America/New_York	USA	knots	254	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snows Cut, ICW	NC
106223	Orton Point, 0.5 nmi S of (depth 38 ft), Cape Fear River, North Carolina Current	NOS	CFR1617_1	34.047340393066406	-77.94104766845703	:America/New_York	USA	knots	179	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.272	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orton Point, 0.5 NM S of	NC
106224	Orton Point, 0.5 nmi S of (depth 15 ft), Cape Fear River, North Carolina Current	NOS	CFR1617_8	34.047340393066406	-77.94104766845703	:America/New_York	USA	knots	181	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orton Point, 0.5 NM S of	NC
106225	Orton Point, 0.5 nmi S of (depth 8 ft), Cape Fear River, North Carolina Current	NOS	CFR1617_10	34.047340393066406	-77.94104766845703	:America/New_York	USA	knots	189	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.268	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orton Point, 0.5 NM S of	NC
106226	Upper Midnight Channel (depth 33 ft), Cape Fear River, North Carolina Current	NOS	CFR1618_2	34.02907943725586	-77.94080352783203	:America/New_York	USA	knots	183	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upper Midnight Channel	NC
106227	Upper Midnight Channel (depth 20 ft), Cape Fear River, North Carolina Current	NOS	CFR1618_6	34.02907943725586	-77.94080352783203	:America/New_York	USA	knots	188	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upper Midnight Channel	NC
106228	Upper Midnight Channel (depth 7 ft), Cape Fear River, North Carolina Current	NOS	CFR1618_10	34.02907943725586	-77.94080352783203	:America/New_York	USA	knots	183	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upper Midnight Channel	NC
106229	Reaves Point, 0.9 nmi NE of (depth 33 ft), Cape Fear River, North Carolina Current	NOS	CFR1619_1	34.005950927734375	-77.94020080566406	:America/New_York	USA	knots	205	20	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reaves Point, 0.9 NM NE of	NC
106230	Reaves Point, 0.9 nmi NE of (depth 20 ft), Cape Fear River, North Carolina Current	NOS	CFR1619_5	34.005950927734375	-77.94020080566406	:America/New_York	USA	knots	191	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reaves Point, 0.9 NM NE of	NC
106231	Reaves Point, 0.9 nmi NE of (depth 10 ft), Cape Fear River, North Carolina Current	NOS	CFR1619_8	34.005950927734375	-77.94020080566406	:America/New_York	USA	knots	191	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reaves Point, 0.9 NM NE of	NC
106232	Sunny Point, 0.5 nmi SE of (depth 12 ft), Cape Fear River, North Carolina Current	NOS	CFR1620_1	33.978248596191406	-77.94994354248047	:America/New_York	USA	knots	190	17	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunny Point, 0.5 nm SE of	NC
106233	Sunny Point, 0.5 nmi SE of (depth 18 ft), Cape Fear River, North Carolina Current	NOS	CFR1620_3	33.978248596191406	-77.94994354248047	:America/New_York	USA	knots	178	14	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunny Point, 0.5 nm SE of	NC
106286	Hog Neck (depth 28 ft), Buzzards Bay, Massachusetts Current	NOS	COD0905_1	41.72389	-70.63938	:America/New_York	USA	knots	208	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hog Neck	MA
106234	Sunny Point, 0.5 nmi SE of (depth 35 ft), Cape Fear River, North Carolina Current	NOS	CFR1620_8	33.978248596191406	-77.94994354248047	:America/New_York	USA	knots	178	0	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.182	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunny Point, 0.5 nm SE of	NC
106235	Snows Marsh Channel (depth 12 ft), Cape Fear River, North Carolina Current	NOS	CFR1621_1	33.93717956542969	-77.9778823852539	:America/New_York	USA	knots	262	49	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snows Marsh Channel	NC
106236	Snows Marsh Channel (depth 25 ft), Cape Fear River, North Carolina Current	NOS	CFR1621_5	33.93717956542969	-77.9778823852539	:America/New_York	USA	knots	239	51	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snows Marsh Channel	NC
106237	Snows Marsh Channel (depth 38 ft), Cape Fear River, North Carolina Current	NOS	CFR1621_9	33.93717956542969	-77.9778823852539	:America/New_York	USA	knots	247	54	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snows Marsh Channel	NC
106238	Southport at Dutchman Creek, ICW (depth 12 ft), Cape Fear River, North Carolina Current	NOS	CFR1622_1	33.91761016845703	-78.0430679321289	:America/New_York	USA	knots	117	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport at Dutchman Creek, ICW	NC
106239	Southport at Dutchman Creek, ICW (depth 4 ft), Cape Fear River, North Carolina Current	NOS	CFR1622_6	33.91761016845703	-78.0430679321289	:America/New_York	USA	knots	119	295	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport at Dutchman Creek, ICW	NC
106240	Oak Island Bridge, ICW (depth 11 ft), Cape Fear River, North Carolina Current	NOS	CFR1623_3	33.921661376953125	-78.07276153564453	:America/New_York	USA	knots	86	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.276	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oak Island Bridge, ICW	NC
106241	Southport (depth 37 ft), Cape Fear River, North Carolina Current	NOS	CFR1624_1	33.91537857055664	-78.01215362548828	:America/New_York	USA	knots	225	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport	NC
106242	Southport (depth 20 ft), Cape Fear River, North Carolina Current	NOS	CFR1624_6	33.91537857055664	-78.01215362548828	:America/New_York	USA	knots	231	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport	NC
106243	Southport (depth 7 ft), Cape Fear River, North Carolina Current	NOS	CFR1624_10	33.91537857055664	-78.01215362548828	:America/New_York	USA	knots	235	48	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.595	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport	NC
106244	Fort Caswell (depth 12 ft), Cape Fear River, North Carolina Current	NOS	CFR1625_1	33.888328552246094	-78.00763702392578	:America/New_York	USA	knots	161	12	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.265	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Caswell	NC
106245	Fort Caswell (depth 18 ft), Cape Fear River, North Carolina Current	NOS	CFR1625_3	33.888328552246094	-78.00763702392578	:America/New_York	USA	knots	161	6	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Caswell	NC
106246	Fort Caswell (depth 28 ft), Cape Fear River, North Carolina Current	NOS	CFR1625_6	33.888328552246094	-78.00763702392578	:America/New_York	USA	knots	162	347	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Caswell	NC
106247	Bald Head Shoal (depth 12 ft), Cape Fear River, North Carolina Current	NOS	CFR1626_1	33.8543586730957	-78.0271987915039	:America/New_York	USA	knots	208	13	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.388	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bald Head Shoal	NC
106248	Bald Head Shoal (depth 28 ft), Cape Fear River, North Carolina Current	NOS	CFR1626_6	33.8543586730957	-78.0271987915039	:America/New_York	USA	knots	203	13	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bald Head Shoal	NC
106249	Cedar Point, 4.7 nmi east of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	CHB0301_6	38.2985	-76.273	:America/New_York	USA	knots	144	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cedar Point, 4.7 n.mi. east of	MD
106250	Cedar Point, 4.7 nmi east of (depth 5 ft), Chesapeake Bay, Maryland Current	NOS	CHB0301_14	38.2985	-76.273	:America/New_York	USA	knots	145	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.187	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cedar Point, 4.7 n.mi. east of	MD
106251	Love Point, 2.0 nmi north of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	CHB0302_10	39.074	-76.30317	:America/New_York	USA	knots	240	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Love Point, 2.0 nmi north of	MD
106252	Love Point, 2.0 nmi north of (depth 5 ft), Chesapeake Bay, Maryland Current	NOS	CHB0302_18	39.074	-76.30317	:America/New_York	USA	knots	238	67	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Love Point, 2.0 nmi north of	MD
106253	Smith Point Light, 5.0 nmi NW of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	CHB0303_7	37.93652	-76.26135	:America/New_York	USA	knots	125	296	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Point Light, 5.0 n.mi. NW of	MD
106254	Smith Point Light, 5.0 nmi NW of (depth 5 ft), Chesapeake Bay, Maryland Current	NOS	CHB0303_16	37.93652	-76.26135	:America/New_York	USA	knots	125	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.304	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Point Light, 5.0 n.mi. NW of	MD
106255	James Island, 1.6 nmi SW of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	CHB0304_4	38.48573	-76.36457	:America/New_York	USA	knots	156	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	James Island, 1.6 n.mi. SW of	MD
106256	James Island, 1.6 nmi SW of (depth 5 ft), Chesapeake Bay, Maryland Current	NOS	CHB0304_13	38.48573	-76.36457	:America/New_York	USA	knots	165	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	James Island, 1.6 n.mi. SW of	MD
106257	0.75 nmi west, Thimble Shoal Channel (depth 39 ft), Chesapeake Bay, Virginia Current	NOS	CHB9902_1	36.97739	-76.1242	:America/New_York	USA	knots	96	281	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.157	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.75nm west, Thimble Shoal Channel	VA
106258	0.75 nmi west, Thimble Shoal Channel (depth 29 ft), Chesapeake Bay, Virginia Current	NOS	CHB9902_4	36.97739	-76.1242	:America/New_York	USA	knots	101	284	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.75nm west, Thimble Shoal Channel	VA
106259	0.75 nmi west, Thimble Shoal Channel (depth 16 ft), Chesapeake Bay, Virginia Current	NOS	CHB9902_8	36.97739	-76.1242	:America/New_York	USA	knots	111	289	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.179	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.75nm west, Thimble Shoal Channel	VA
106260	0.75 nmi west, Thimble Shoal Channel (depth 6 ft), Chesapeake Bay, Virginia Current	NOS	CHB9902_11	36.97739	-76.1242	:America/New_York	USA	knots	113	288	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.75nm west, Thimble Shoal Channel	VA
106261	Hampton Roads entrance, midchannel (depth 61 ft), Virginia Current	NOS	CHB9903_1	36.99428	-76.30527	:America/New_York	USA	knots	55	229	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hampton Roads entrance, midchannel	VA
106262	Hampton Roads entrance, midchannel (depth 44 ft), Virginia Current	NOS	CHB9903_6	36.99428	-76.30527	:America/New_York	USA	knots	59	241	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hampton Roads entrance, midchannel	VA
106263	Hampton Roads entrance, midchannel (depth 31 ft), Virginia Current	NOS	CHB9903_10	36.99428	-76.30527	:America/New_York	USA	knots	65	243	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hampton Roads entrance, midchannel	VA
106264	Hampton Roads entrance, midchannel (depth 15 ft), Virginia Current	NOS	CHB9903_15	36.99428	-76.30527	:America/New_York	USA	knots	62	244	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hampton Roads entrance, midchannel	VA
106265	Hampton Roads entrance, midchannel (depth 8 ft), Virginia Current	NOS	CHB9903_17	36.99428	-76.30527	:America/New_York	USA	knots	59	243	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hampton Roads entrance, midchannel	VA
106266	0.15 nmi WSW of Pier No. 2 (depth 42 ft), Newport News, Hampton Roads, Virginia Current	NOS	CHB9904_1	36.97925	-76.44348	:America/New_York	USA	knots	165	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.15nm WSW of Pier No.2	VA
106267	0.15 nmi WSW of Pier No. 2 (depth 29 ft), Newport News, Hampton Roads, Virginia Current	NOS	CHB9904_5	36.97925	-76.44348	:America/New_York	USA	knots	162	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.15nm WSW of Pier No.2	VA
106268	0.15 nmi WSW of Pier No. 2 (depth 15 ft), Newport News, Hampton Roads, Virginia Current	NOS	CHB9904_9	36.97925	-76.44348	:America/New_York	USA	knots	161	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.15nm WSW of Pier No.2	VA
106269	0.15 nmi WSW of Pier No. 2 (depth 6 ft), Newport News, Hampton Roads, Virginia Current	NOS	CHB9904_12	36.97925	-76.44348	:America/New_York	USA	knots	161	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.15nm WSW of Pier No.2	VA
106270	Craney Island Reach (depth 43 ft), Elizabeth River, Virginia Current	NOS	CHB9905_1	36.89053	-76.33575	:America/New_York	USA	knots	4	182	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.184	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Craney Island Reach	VA
106271	Craney Island Reach (depth 33 ft), Elizabeth River, Virginia Current	NOS	CHB9905_4	36.89053	-76.33575	:America/New_York	USA	knots	8	185	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.166	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Craney Island Reach	VA
106272	Craney Island Reach (depth 17 ft), Elizabeth River, Virginia Current	NOS	CHB9905_9	36.89053	-76.33575	:America/New_York	USA	knots	4	184	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Craney Island Reach	VA
106273	Craney Island Reach (depth 7 ft), Elizabeth River, Virginia Current	NOS	CHB9905_12	36.89053	-76.33575	:America/New_York	USA	knots	9	184	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Craney Island Reach	VA
106274	Cape Cod Canal, east end (depth 34 ft), Massachusetts Current	NOS	COD0901_2	41.77553	-70.49932	:America/New_York	USA	knots	231	48	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, east end	MA
106275	Cape Cod Canal, east end (depth 15 ft), Massachusetts Current	NOS	COD0901_8	41.77553	-70.49932	:America/New_York	USA	knots	232	53	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, east end	MA
106276	Cape Cod Canal, east end (depth 8 ft), Massachusetts Current	NOS	COD0901_10	41.77553	-70.49932	:America/New_York	USA	knots	233	53	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, east end	MA
106277	Sagamore Bridge (depth 42 ft), Cape Cod Canal, Massachusetts Current	NOS	COD0902_1	41.77617	-70.5433	:America/New_York	USA	knots	256	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sagamore Bridge	MA
106278	Sagamore Bridge (depth 26 ft), Cape Cod Canal, Massachusetts Current	NOS	COD0902_6	41.77617	-70.5433	:America/New_York	USA	knots	259	79	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sagamore Bridge	MA
106279	Sagamore Bridge (depth 6 ft), Cape Cod Canal, Massachusetts Current	NOS	COD0902_12	41.77617	-70.5433	:America/New_York	USA	knots	260	77	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sagamore Bridge	MA
106280	Bournedale (depth 46 ft), Cape Cod Canal, Massachusetts Current	NOS	COD0903_1	41.76654	-70.56702	:America/New_York	USA	knots	214	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bournedale	MA
106281	Bournedale (depth 30 ft), Cape Cod Canal, Massachusetts Current	NOS	COD0903_6	41.76654	-70.56702	:America/New_York	USA	knots	217	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bournedale	MA
106282	Bournedale (depth 13 ft), Cape Cod Canal, Massachusetts Current	NOS	COD0903_11	41.76654	-70.56702	:America/New_York	USA	knots	219	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bournedale	MA
106283	Cape Cod Canal, Railroad Bridge, midchannel (depth 71 ft), Massachusetts Current	NOS	COD0904_5	41.74268	-70.61418	:America/New_York	USA	knots	\N	67.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, Railroad Bridge, midchannel	MA
106284	Cape Cod Canal, Railroad Bridge, midchannel (depth 13 ft), Massachusetts Current	NOS	COD0904_15	41.74268	-70.61418	:America/New_York	USA	knots	248	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 201.8 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, Railroad Bridge, midchannel	MA
106285	Cape Cod Canal, Railroad Bridge, midchannel (depth 399 ft), Massachusetts Current	NOS	COD0904_30	41.74268	-70.61418	:America/New_York	USA	knots	\N	61.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, Railroad Bridge, midchannel	MA
106289	Abiels ledge (depth 31 ft), Buzzards Bay, Massachusetts Current	NOS	COD0906_1	41.68973	-70.67081	:America/New_York	USA	knots	235	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Abiels ledge	MA
106290	Abiels ledge (depth 15 ft), Buzzards Bay, Massachusetts Current	NOS	COD0906_11	41.68973	-70.67081	:America/New_York	USA	knots	235	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Abiels ledge	MA
106291	Abiels ledge (depth 3 ft), Buzzards Bay, Massachusetts Current	NOS	COD0906_18	41.68973	-70.67081	:America/New_York	USA	knots	236	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.222	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Abiels ledge	MA
106292	Cleveland Ledge (depth 34 ft), Buzzards Bay, Massachusetts Current	NOS	COD0907_1	41.63223	-70.69685	:America/New_York	USA	knots	217	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cleveland Ledge	MA
106293	Cleveland Ledge (depth 15 ft), Buzzards Bay, Massachusetts Current	NOS	COD0907_7	41.63223	-70.69685	:America/New_York	USA	knots	213	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cleveland Ledge	MA
106294	Cleveland Ledge (depth 8 ft), Buzzards Bay, Massachusetts Current	NOS	COD0907_9	41.63223	-70.69685	:America/New_York	USA	knots	212	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cleveland Ledge	MA
106295	West Island, 1 mi southeast of (depth 27 ft), Buzzards Bay, Massachusetts Current	NOS	COD0908_1	41.5657	-70.81098	:America/New_York	USA	knots	243	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Island, 1 mile Southeast of	MA
106296	West Island, 1 mi southeast of (depth 15 ft), Buzzards Bay, Massachusetts Current	NOS	COD0908_8	41.5657	-70.81098	:America/New_York	USA	knots	233	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Island, 1 mile Southeast of	MA
106297	West Island, 1 mi southeast of (depth 4 ft), Buzzards Bay, Massachusetts Current	NOS	COD0908_15	41.5657	-70.81098	:America/New_York	USA	knots	225	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Island, 1 mile Southeast of	MA
106298	New Bedford Hurricane Barrier (depth 24 ft), Buzzards Bay, Massachusetts Current	NOS	COD0909_1	41.62324	-70.90509	:America/New_York	USA	knots	134	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Bedford Hurricane Barrier	MA
106299	New Bedford Hurricane Barrier (depth 14 ft), Buzzards Bay, Massachusetts Current	NOS	COD0909_4	41.62324	-70.90509	:America/New_York	USA	knots	134	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.146	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Bedford Hurricane Barrier	MA
106300	New Bedford Hurricane Barrier (depth 4 ft), Buzzards Bay, Massachusetts Current	NOS	COD0909_7	41.62324	-70.90509	:America/New_York	USA	knots	134	320	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.271	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Bedford Hurricane Barrier	MA
106301	North end (depth 17 ft), Woods Hole, Massachusetts Current	NOS	COD0910_1	41.52297	-70.693	:America/New_York	USA	knots	13	197	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North end	MA
106302	North end (depth 4 ft), Woods Hole, Massachusetts Current	NOS	COD0910_9	41.52297	-70.693	:America/New_York	USA	knots	4	195	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North end	MA
106303	Woods Hole, The Strait (depth 21 ft), Massachusetts Current	NOS	COD0911_1	41.51929	-70.68289	:America/New_York	USA	knots	274	96	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.579	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woods Hole, The Strait	MA
106304	Woods Hole, The Strait (depth 14 ft), Massachusetts Current	NOS	COD0911_5	41.51929	-70.68289	:America/New_York	USA	knots	267	79	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woods Hole, The Strait	MA
106305	Woods Hole, The Strait (depth 5 ft), Massachusetts Current	NOS	COD0911_11	41.51929	-70.68289	:America/New_York	USA	knots	261	77	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woods Hole, The Strait	MA
106306	Juniper Point (depth 29 ft), Woods Hole, Massachusetts Current	NOS	COD0912_1	41.51588	-70.67167	:America/New_York	USA	knots	333	169	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juniper Point	MA
106307	Juniper Point (depth 15 ft), Woods Hole, Massachusetts Current	NOS	COD0912_5	41.51588	-70.67167	:America/New_York	USA	knots	333	166	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juniper Point	MA
106308	Juniper Point (depth 5 ft), Woods Hole, Massachusetts Current	NOS	COD0912_8	41.51588	-70.67167	:America/New_York	USA	knots	331	165	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juniper Point	MA
106309	Robinsons Hole, Nashuon Point (depth 24 ft), Massachusetts Current	NOS	COD0913_1	41.44972	-70.8067	:America/New_York	USA	knots	329	157	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robinsons Hole, Nashuon Point	MA
106310	Robinsons Hole, Nashuon Point (depth 14 ft), Massachusetts Current	NOS	COD0913_7	41.44972	-70.8067	:America/New_York	USA	knots	330	153	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robinsons Hole, Nashuon Point	MA
106311	Robinsons Hole, Nashuon Point (depth 4 ft), Massachusetts Current	NOS	COD0913_13	41.44972	-70.8067	:America/New_York	USA	knots	332	151	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robinsons Hole, Nashuon Point	MA
106312	Middle (depth 40 ft), Quicks Hole, Massachusetts Current	NOS	COD0914_1	41.44269	-70.84825	:America/New_York	USA	knots	336	153	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle	MA
106313	Middle (depth 17 ft), Quicks Hole, Massachusetts Current	NOS	COD0914_8	41.44269	-70.84825	:America/New_York	USA	knots	329	156	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle	MA
106314	Middle (depth 7 ft), Quicks Hole, Massachusetts Current	NOS	COD0914_11	41.44269	-70.84825	:America/New_York	USA	knots	327	157	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle	MA
106315	Canapitsit Channel (depth 4 ft), Massachusetts Current	NOS	COD0915_1	41.42414	-70.90788	:America/New_York	USA	knots	312	131	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.225	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Canapitsit Channel	MA
106316	Point Woronzof, 1.2 nmi NE of (depth 85 ft), Cook Inlet, Alaska Current	NOS	COI0206_3	61.21685	-149.98435	:America/Anchorage	USA	knots	271	106	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 87.6 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Woronzof, 1.2nm NE of	AK
106317	Point Woronzof, 1.2 nmi NE of (depth 58 ft), Cook Inlet, Alaska Current	NOS	COI0206_7	61.21685	-149.98435	:America/Anchorage	USA	knots	268	94	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 61.4 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.188	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Woronzof, 1.2nm NE of	AK
106318	Point Woronzof, 1.2 nmi NE of (depth 26 ft), Cook Inlet, Alaska Current	NOS	COI0206_12	61.21685	-149.98435	:America/Anchorage	USA	knots	262	84	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 28.5 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.413	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Woronzof, 1.2nm NE of	AK
106319	Fire Island, 1.0 nmi east of (depth 28 ft), Cook Inlet, Alaska Current	NOS	COI0207_2	61.17923	-150.12553	:America/Anchorage	USA	knots	271	95	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.0nm east of	AK
106320	Fire Island, 1.0 nmi east of (depth 14 ft), Cook Inlet, Alaska Current	NOS	COI0207_6	61.17923	-150.12553	:America/Anchorage	USA	knots	266	95	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.0nm east of	AK
106321	Fire Island, 1.0 nmi east of (depth 2 ft), Cook Inlet, Alaska Current	NOS	COI0207_10	61.17923	-150.12553	:America/Anchorage	USA	knots	258	95	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.0nm east of	AK
106322	Fire Island, 1.0 nmi north of (depth 41 ft), Cook Inlet, Alaska Current	NOS	COI0213_2	61.19218	-150.17585	:America/Anchorage	USA	knots	265	76	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 44.8 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.0nm north of	AK
106323	Fire Island, 1.0 nmi north of (depth 25 ft), Cook Inlet, Alaska Current	NOS	COI0213_6	61.19218	-150.17585	:America/Anchorage	USA	knots	265	76	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 31.7 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.0nm north of	AK
106324	Fire Island, 1.0 nmi north of (depth 15 ft), Cook Inlet, Alaska Current	NOS	COI0213_10	61.19218	-150.17585	:America/Anchorage	USA	knots	264	77	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 18.6 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.0nm north of	AK
106325	Knik Arm, NW of Anchorage (depth 23 ft), Cook Inlet, Alaska Current	NOS	COI0301_5	61.27822	-149.89452	:America/Anchorage	USA	knots	187	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.464	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Knik Arm, NW of Anchorage	AK
106326	Knik Arm, NW of Anchorage (depth 16 ft), Cook Inlet, Alaska Current	NOS	COI0301_7	61.27822	-149.89452	:America/Anchorage	USA	knots	189	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.473	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Knik Arm, NW of Anchorage	AK
106327	Knik Arm, NW of Anchorage (depth 10 ft), Cook Inlet, Alaska Current	NOS	COI0301_9	61.27822	-149.89452	:America/Anchorage	USA	knots	192	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.471	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Knik Arm, NW of Anchorage	AK
106328	Knik Arm, east side (depth 30 ft), Cook Inlet, Alaska Current	NOS	COI0302_4	61.27463	-149.88222	:America/Anchorage	USA	knots	206	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.513	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Knik Arm, east side	AK
106329	Knik Arm, east side (depth 17 ft), Cook Inlet, Alaska Current	NOS	COI0302_8	61.27463	-149.88222	:America/Anchorage	USA	knots	209	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.484	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Knik Arm, east side	AK
106330	Knik Arm, east side (depth 10 ft), Cook Inlet, Alaska Current	NOS	COI0302_10	61.27463	-149.88222	:America/Anchorage	USA	knots	210	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.448	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Knik Arm, east side	AK
106331	Port Mackenzie, south of (depth 71 ft), Cook Inlet, Alaska Current	NOS	COI0303_1	61.25225	-149.92067	:America/Anchorage	USA	knots	213	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.501	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Mackenzie, south of	AK
106332	Port Mackenzie, south of (depth 41 ft), Cook Inlet, Alaska Current	NOS	COI0303_10	61.25225	-149.92067	:America/Anchorage	USA	knots	214	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.696	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Mackenzie, south of	AK
106333	Port Mackenzie, south of (depth 22 ft), Cook Inlet, Alaska Current	NOS	COI0303_16	61.25225	-149.92067	:America/Anchorage	USA	knots	214	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.829	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Mackenzie, south of	AK
106334	Port Mackenzie, south of (depth 15 ft), Cook Inlet, Alaska Current	NOS	COI0303_18	61.25225	-149.92067	:America/Anchorage	USA	knots	214	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.868	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Mackenzie, south of	AK
106335	Fire Island Shoal, northwest of (depth 22 ft), Cook Inlet, Alaska Current	NOS	COI0306_6	61.16085	-150.56492	:America/Anchorage	USA	knots	272	91	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.234	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island Shoal, northwest of	AK
106336	Fire Island Shoal, northwest of (depth 16 ft), Cook Inlet, Alaska Current	NOS	COI0306_8	61.16085	-150.56492	:America/Anchorage	USA	knots	272	91	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.324	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island Shoal, northwest of	AK
106337	Fire Island Shoal, northwest of (depth 9 ft), Cook Inlet, Alaska Current	NOS	COI0306_10	61.16085	-150.56492	:America/Anchorage	USA	knots	271	92	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.395	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island Shoal, northwest of	AK
106338	Beluga Shoal, south of (depth 31 ft), Cook Inlet, Alaska Current	NOS	COI0307_5	61.10137	-150.56155	:America/Anchorage	USA	knots	256	86	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beluga Shoal, south of	AK
106339	Beluga Shoal, south of (depth 21 ft), Cook Inlet, Alaska Current	NOS	COI0307_8	61.10137	-150.56155	:America/Anchorage	USA	knots	257	86	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.245	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beluga Shoal, south of	AK
106340	Beluga Shoal, south of (depth 15 ft), Cook Inlet, Alaska Current	NOS	COI0307_10	61.10137	-150.56155	:America/Anchorage	USA	knots	258	86	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.287	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beluga Shoal, south of	AK
106341	Kennedy entrance (depth 100 ft), Cook Inlet, Alaska Current	NOS	COI0418_15	59.0658	-151.98232	:America/Anchorage	USA	knots	119	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kennedy Entrance	AK
106342	Kennedy entrance (depth 47 ft), Cook Inlet, Alaska Current	NOS	COI0418_19	59.0658	-151.98232	:America/Anchorage	USA	knots	114	307	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kennedy Entrance	AK
106343	Kennedy entrance (depth 21 ft), Cook Inlet, Alaska Current	NOS	COI0418_21	59.0658	-151.98232	:America/Anchorage	USA	knots	110	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kennedy Entrance	AK
106344	Anchor Point, 15 nmi west of (depth 75 ft), Cook Inlet, Alaska Current	NOS	COI0419_9	59.83933	-152.36833	:America/Anchorage	USA	knots	203	28	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, 15nm west of	AK
106345	Anchor Point, 15 nmi west of (depth 49 ft), Cook Inlet, Alaska Current	NOS	COI0419_13	59.83933	-152.36833	:America/Anchorage	USA	knots	200	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.495	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, 15nm west of	AK
106346	Anchor Point, 15 nmi west of (depth 23 ft), Cook Inlet, Alaska Current	NOS	COI0419_17	59.83933	-152.36833	:America/Anchorage	USA	knots	198	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.537	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, 15nm west of	AK
106347	Anchor Point, 8 nmi west of (depth 59 ft), Cook Inlet, Alaska Current	NOS	COI0420_7	59.8187	-152.15553	:America/Anchorage	USA	knots	197	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, 8nm west of	AK
106348	Anchor Point, 8 nmi west of (depth 39 ft), Cook Inlet, Alaska Current	NOS	COI0420_10	59.8187	-152.15553	:America/Anchorage	USA	knots	198	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, 8nm west of	AK
106349	Anchor Point, 8 nmi west of (depth 13 ft), Cook Inlet, Alaska Current	NOS	COI0420_14	59.8187	-152.15553	:America/Anchorage	USA	knots	200	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.109	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, 8nm west of	AK
106350	Barabara Point (depth 147 ft), Cook Inlet, Alaska Current	NOS	COI0421_1	59.57542	-151.6519	:America/Anchorage	USA	knots	258	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barabara Point	AK
106351	Barabara Point (depth 82 ft), Cook Inlet, Alaska Current	NOS	COI0421_11	59.57542	-151.6519	:America/Anchorage	USA	knots	\N	66.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barabara Point	AK
106352	Barabara Point (depth 23 ft), Cook Inlet, Alaska Current	NOS	COI0421_20	59.57542	-151.6519	:America/Anchorage	USA	knots	\N	44.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barabara Point	AK
106353	Glacier Spit (depth 146 ft), Cook Inlet, Alaska Current	NOS	COI0422_1	59.66667	-151.19163	:America/Anchorage	USA	knots	233	46	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Spit	AK
106354	Glacier Spit (depth 87 ft), Cook Inlet, Alaska Current	NOS	COI0422_10	59.66667	-151.19163	:America/Anchorage	USA	knots	230	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Spit	AK
106355	Glacier Spit (depth 14 ft), Cook Inlet, Alaska Current	NOS	COI0422_21	59.66667	-151.19163	:America/Anchorage	USA	knots	234	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Spit	AK
106356	The Forelands (depth 66 ft), Cook Inlet, Alaska Current	NOS	COI0502_1	60.72067	-151.55733	:America/Anchorage	USA	knots	198	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Forelands	AK
106357	The Forelands (depth 37 ft), Cook Inlet, Alaska Current	NOS	COI0502_4	60.72067	-151.55733	:America/Anchorage	USA	knots	200	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Forelands	AK
106358	The Forelands (depth 17 ft), Cook Inlet, Alaska Current	NOS	COI0502_6	60.72067	-151.55733	:America/Anchorage	USA	knots	201	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Forelands	AK
106359	East Foreland (depth 119 ft), Cook Inlet, Alaska Current	NOS	COI0503_1	60.71727	-151.43297	:America/Anchorage	USA	knots	179	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Foreland	AK
106360	East Foreland (depth 80 ft), Cook Inlet, Alaska Current	NOS	COI0503_5	60.71727	-151.43297	:America/Anchorage	USA	knots	184	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Foreland	AK
106361	East Foreland (depth 21 ft), Cook Inlet, Alaska Current	NOS	COI0503_11	60.71727	-151.43297	:America/Anchorage	USA	knots	191	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Foreland	AK
106362	Nikiski, 0.8 mi west of (depth 92 ft), Cook Inlet, Alaska Current	NOS	COI0504_1	60.68338	-151.41787	:America/Anchorage	USA	knots	167	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.264	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikiski, 0.8 mile west of	AK
106363	Nikiski, 0.8 mi west of (depth 52 ft), Cook Inlet, Alaska Current	NOS	COI0504_7	60.68338	-151.41787	:America/Anchorage	USA	knots	170	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.189	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikiski, 0.8 mile west of	AK
106364	Nikiski, 0.8 mi west of (depth 20 ft), Cook Inlet, Alaska Current	NOS	COI0504_12	60.68338	-151.41787	:America/Anchorage	USA	knots	173	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikiski, 0.8 mile west of	AK
106365	West Foreland, south of (depth 38 ft), Cook Inlet, Alaska Current	NOS	COI0505_1	60.59667	-151.73981	:America/Anchorage	USA	knots	232	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Foreland, south of	AK
106366	West Foreland, south of (depth 18 ft), Cook Inlet, Alaska Current	NOS	COI0505_4	60.59667	-151.73981	:America/Anchorage	USA	knots	231	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.292	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Foreland, south of	AK
106367	West Foreland, south of (depth 11 ft), Cook Inlet, Alaska Current	NOS	COI0505_5	60.59667	-151.73981	:America/Anchorage	USA	knots	230	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.335	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Foreland, south of	AK
106368	Kenai River, north of (depth 45 ft), Cook Inlet, Alaska Current	NOS	COI0506_1	60.58083	-151.44453	:America/Anchorage	USA	knots	181	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.195	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kenai River, north of	AK
106369	Kenai River, north of (depth 26 ft), Cook Inlet, Alaska Current	NOS	COI0506_4	60.58083	-151.44453	:America/Anchorage	USA	knots	182	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kenai River, north of	AK
106370	Kenai River, north of (depth 12 ft), Cook Inlet, Alaska Current	NOS	COI0506_6	60.58083	-151.44453	:America/Anchorage	USA	knots	183	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kenai River, north of	AK
106371	Drift River Terminal (depth 42 ft), Cook Inlet, Alaska Current	NOS	COI0507_3	60.5517	-152.12773	:America/Anchorage	USA	knots	228	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.175	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drift River Terminal	AK
106372	Drift River Terminal (depth 29 ft), Cook Inlet, Alaska Current	NOS	COI0507_5	60.5517	-152.12773	:America/Anchorage	USA	knots	229	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drift River Terminal	AK
106373	Drift River Terminal (depth 15 ft), Cook Inlet, Alaska Current	NOS	COI0507_7	60.5517	-152.12773	:America/Anchorage	USA	knots	230	47	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drift River Terminal	AK
106374	Kalgin Island, east of (depth 117 ft), Cook Inlet, Alaska Current	NOS	COI0508_1	60.48295	-151.67325	:America/Anchorage	USA	knots	189	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, east of	AK
106375	Kalgin Island, east of (depth 58 ft), Cook Inlet, Alaska Current	NOS	COI0508_7	60.48295	-151.67325	:America/Anchorage	USA	knots	192	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.487	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, east of	AK
106376	Kalgin Island, east of (depth 28 ft), Cook Inlet, Alaska Current	NOS	COI0508_10	60.48295	-151.67325	:America/Anchorage	USA	knots	194	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.752	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, east of	AK
106377	Harriot Point, west of (depth 259 ft), Cook Inlet, Alaska Current	NOS	COI0509_1	60.37918	-152.1817	:America/Anchorage	USA	knots	184	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harriot Point, west of	AK
106378	Harriot Point, west of (depth 161 ft), Cook Inlet, Alaska Current	NOS	COI0509_11	60.37918	-152.1817	:America/Anchorage	USA	knots	188	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harriot Point, west of	AK
106379	Harriot Point, west of (depth 43 ft), Cook Inlet, Alaska Current	NOS	COI0509_23	60.37918	-152.1817	:America/Anchorage	USA	knots	193	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harriot Point, west of	AK
106380	Kalgin Island, southeast of (depth 58 ft), Cook Inlet, Alaska Current	NOS	COI0510_1	60.24802	-151.75453	:America/Anchorage	USA	knots	203	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, southeast of	AK
106381	Kalgin Island, southeast of (depth 32 ft), Cook Inlet, Alaska Current	NOS	COI0510_5	60.24802	-151.75453	:America/Anchorage	USA	knots	203	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, southeast of	AK
106382	Kalgin Island, southeast of (depth 18 ft), Cook Inlet, Alaska Current	NOS	COI0510_7	60.24802	-151.75453	:America/Anchorage	USA	knots	204	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.238	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, southeast of	AK
106383	Cape Ninilchik, west of (depth 184 ft), Cook Inlet, Alaska Current	NOS	COI0511_1	60.02327	-152.12018	:America/Anchorage	USA	knots	205	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Ninilchik, west of	AK
106384	Cape Ninilchik, west of (depth 89 ft), Cook Inlet, Alaska Current	NOS	COI0511_11	60.02327	-152.12018	:America/Anchorage	USA	knots	209	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 85.3 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Ninilchik, west of	AK
106385	Cape Ninilchik, west of (depth 36 ft), Cook Inlet, Alaska Current	NOS	COI0511_16	60.02327	-152.12018	:America/Anchorage	USA	knots	216	32	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.45	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Ninilchik, west of	AK
106386	Seldovia (depth 56 ft), Cook Inlet, Alaska Current	NOS	COI0513_1	59.4828	-151.75505	:America/Anchorage	USA	knots	235	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seldovia	AK
106387	Seldovia (depth 36 ft), Cook Inlet, Alaska Current	NOS	COI0513_3	59.4828	-151.75505	:America/Anchorage	USA	knots	235	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seldovia	AK
106388	Seldovia (depth 16 ft), Cook Inlet, Alaska Current	NOS	COI0513_5	59.4828	-151.75505	:America/Anchorage	USA	knots	236	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seldovia	AK
106389	Augustine Island (depth 208 ft), Cook Inlet, Alaska Current	NOS	COI0514_1	59.3018	-152.93028	:America/Anchorage	USA	knots	186	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Augustine Island	AK
106390	Augustine Island (depth 119 ft), Cook Inlet, Alaska Current	NOS	COI0514_10	59.3018	-152.93028	:America/Anchorage	USA	knots	182	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Augustine Island	AK
106391	Augustine Island (depth 21 ft), Cook Inlet, Alaska Current	NOS	COI0514_20	59.3018	-152.93028	:America/Anchorage	USA	knots	177	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Augustine Island	AK
106392	Kachemak Bay, southwest of (depth 244 ft), Cook Inlet, Alaska Current	NOS	COI0515_1	59.31487	-152.36497	:America/Anchorage	USA	knots	178	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kachemak Bay, southwest of	AK
106393	Kachemak Bay, southwest of (depth 136 ft), Cook Inlet, Alaska Current	NOS	COI0515_12	59.31487	-152.36497	:America/Anchorage	USA	knots	179	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kachemak Bay, southwest of	AK
106394	Kachemak Bay, southwest of (depth 57 ft), Cook Inlet, Alaska Current	NOS	COI0515_20	59.31487	-152.36497	:America/Anchorage	USA	knots	171	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kachemak Bay, southwest of	AK
106395	Kachemak Bay, southwest of (depth 27 ft), Cook Inlet, Alaska Current	NOS	COI0515_23	59.31487	-152.36497	:America/Anchorage	USA	knots	167	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kachemak Bay, southwest of	AK
106397	Port Graham (depth 75 ft), Cook Inlet, Alaska Current	NOS	COI0516_5	59.40002	-151.9659	:America/Anchorage	USA	knots	204	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Graham	AK
106398	Port Graham (depth 25 ft), Cook Inlet, Alaska Current	NOS	COI0516_10	59.40002	-151.9659	:America/Anchorage	USA	knots	203	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Graham	AK
106399	Cape Douglas (depth 455 ft), Cook Inlet, Alaska Current	NOS	COI0517_1	58.89005	-153.1842	:America/Anchorage	USA	knots	165	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Douglas	AK
106400	Cape Douglas (depth 337 ft), Cook Inlet, Alaska Current	NOS	COI0517_7	58.89005	-153.1842	:America/Anchorage	USA	knots	168	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.105	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Douglas	AK
106401	Cape Douglas (depth 199 ft), Cook Inlet, Alaska Current	NOS	COI0517_14	58.89005	-153.1842	:America/Anchorage	USA	knots	164	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Douglas	AK
106402	Stevenson Passage (depth 388 ft), Cook Inlet, Alaska Current	NOS	COI0519_3	58.808	-152.40778	:America/Anchorage	USA	knots	95	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.299	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stevenson Passage	AK
106403	Stevenson Passage (depth 240 ft), Cook Inlet, Alaska Current	NOS	COI0519_12	58.808	-152.40778	:America/Anchorage	USA	knots	103	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.307	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stevenson Passage	AK
106404	Stevenson Passage (depth 60 ft), Cook Inlet, Alaska Current	NOS	COI0519_23	58.808	-152.40778	:America/Anchorage	USA	knots	121	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.273	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stevenson Passage	AK
106405	West Amatuli Island, north (depth 238 ft), Cook Inlet, Alaska Current	NOS	COI0520_20	59.049198150634766	-152.15185546875	:America/Anchorage	USA	knots	111	299	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Amatuli Island, North	AK
106406	West Amatuli Island, north (depth 120 ft), Cook Inlet, Alaska Current	NOS	COI0520_29	59.049198150634766	-152.15185546875	:America/Anchorage	USA	knots	119	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.299	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Amatuli Island, North	AK
106407	Cape Elizabeth (depth 229 ft), Cook Inlet, Alaska Current	NOS	COI0521_1	59.12072	-151.89483	:America/Anchorage	USA	knots	128	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Elizabeth	AK
106408	Cape Elizabeth (depth 137 ft), Cook Inlet, Alaska Current	NOS	COI0521_8	59.12072	-151.89483	:America/Anchorage	USA	knots	130	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Elizabeth	AK
106409	Cape Elizabeth (depth 32 ft), Cook Inlet, Alaska Current	NOS	COI0521_16	59.12072	-151.89483	:America/Anchorage	USA	knots	125	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Elizabeth	AK
106410	Port Chatham (depth 70 ft), Cook Inlet, Alaska Current	NOS	COI0522_1	59.21125	-151.78703	:America/Anchorage	USA	knots	223	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Chatham	AK
106411	Port Chatham (depth 40 ft), Cook Inlet, Alaska Current	NOS	COI0522_4	59.21125	-151.78703	:America/Anchorage	USA	knots	224	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Chatham	AK
106412	Port Chatham (depth 21 ft), Cook Inlet, Alaska Current	NOS	COI0522_6	59.21125	-151.78703	:America/Anchorage	USA	knots	230	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Chatham	AK
106413	Chugach Passage (depth 221 ft), Cook Inlet, Alaska Current	NOS	COI0523_1	59.16658	-151.77543	:America/Anchorage	USA	knots	173	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.251	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chugach Passage	AK
106414	Chugach Passage (depth 129 ft), Cook Inlet, Alaska Current	NOS	COI0523_8	59.16658	-151.77543	:America/Anchorage	USA	knots	175	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.301	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chugach Passage	AK
106415	Chugach Passage (depth 37 ft), Cook Inlet, Alaska Current	NOS	COI0523_15	59.16658	-151.77543	:America/Anchorage	USA	knots	176	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.336	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chugach Passage	AK
106416	Chugach Passage, east of (depth 52 ft), Cook Inlet, Alaska Current	NOS	COI0524_1	59.13387	-151.7055	:America/Anchorage	USA	knots	75	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chugach Passage, east of	AK
106417	Chugach Passage, east of (depth 32 ft), Cook Inlet, Alaska Current	NOS	COI0524_3	59.13387	-151.7055	:America/Anchorage	USA	knots	77	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chugach Passage, east of	AK
106418	Chugach Passage, east of (depth 12 ft), Cook Inlet, Alaska Current	NOS	COI0524_5	59.13387	-151.7055	:America/Anchorage	USA	knots	76	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chugach Passage, east of	AK
106419	Tesoro Pier (depth 55 ft), Cook Inlet, Alaska Current	NOS	COI0801_1	60.6869	-151.4037	:America/Anchorage	USA	knots	154	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.691	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tesoro Pier	AK
106420	Tesoro Pier (depth 35 ft), Cook Inlet, Alaska Current	NOS	COI0801_4	60.6869	-151.4037	:America/Anchorage	USA	knots	151	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.657	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tesoro Pier	AK
106421	Tesoro Pier (depth 15 ft), Cook Inlet, Alaska Current	NOS	COI0801_7	60.6869	-151.4037	:America/Anchorage	USA	knots	149	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.576	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tesoro Pier	AK
106422	Unocal Pier, south of (depth 51 ft), Cook Inlet, Alaska Current	NOS	COI0802_1	60.66782	-151.39162	:America/Anchorage	USA	knots	152	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.331	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unocal Pier, south of	AK
106423	Unocal Pier, south of (depth 32 ft), Cook Inlet, Alaska Current	NOS	COI0802_4	60.66782	-151.39162	:America/Anchorage	USA	knots	154	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.244	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unocal Pier, south of	AK
106424	Unocal Pier, south of (depth 12 ft), Cook Inlet, Alaska Current	NOS	COI0802_7	60.66782	-151.39162	:America/Anchorage	USA	knots	155	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unocal Pier, south of	AK
106425	Homer Spit (depth 198 ft), Cook Inlet, Alaska Current	NOS	COI1201_1	59.5925	-151.40017	:America/Anchorage	USA	knots	222	46	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Homer Spit	AK
106426	Homer Spit (depth 87 ft), Cook Inlet, Alaska Current	NOS	COI1201_18	59.5925	-151.40017	:America/Anchorage	USA	knots	236	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Homer Spit	AK
106427	Homer Spit (depth 21 ft), Cook Inlet, Alaska Current	NOS	COI1201_28	59.5925	-151.40017	:America/Anchorage	USA	knots	203	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Homer Spit	AK
106428	Point Pogishi, southwest of (depth 101 ft), Cook Inlet, Alaska Current	NOS	COI1202_1	59.42247	-151.91688	:America/Anchorage	USA	knots	210	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.163	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Pogishi, southwest of	AK
106429	Point Pogishi, southwest of (depth 61 ft), Cook Inlet, Alaska Current	NOS	COI1202_7	59.42247	-151.91688	:America/Anchorage	USA	knots	215	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.178	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Pogishi, southwest of	AK
106430	Point Pogishi, southwest of (depth 15 ft), Cook Inlet, Alaska Current	NOS	COI1202_14	59.42247	-151.91688	:America/Anchorage	USA	knots	218	32	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Pogishi, southwest of	AK
106431	Anchor Point, west of (depth 104 ft), Cook Inlet, Alaska Current	NOS	COI1203_1	59.74383	-152.03417	:America/Anchorage	USA	knots	170	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, west of	AK
106432	Anchor Point, west of (depth 58 ft), Cook Inlet, Alaska Current	NOS	COI1203_8	59.74383	-152.03417	:America/Anchorage	USA	knots	176	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, west of	AK
106433	Anchor Point, west of (depth 12 ft), Cook Inlet, Alaska Current	NOS	COI1203_15	59.74383	-152.03417	:America/Anchorage	USA	knots	182	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, west of	AK
106434	North Forelands, 2.5 nmi northeast of (depth 66 ft), Cook Inlet, Alaska Current	NOS	COI1204_1	61.05982	-151.08065	:America/Anchorage	USA	knots	214	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Forelands, 2.5nm northeast of	AK
106435	North Forelands, 2.5 nmi northeast of (depth 39 ft), Cook Inlet, Alaska Current	NOS	COI1204_9	61.05982	-151.08065	:America/Anchorage	USA	knots	215	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.305	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Forelands, 2.5nm northeast of	AK
106436	North Forelands, 2.5 nmi northeast of (depth 10 ft), Cook Inlet, Alaska Current	NOS	COI1204_18	61.05982	-151.08065	:America/Anchorage	USA	knots	220	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.526	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Forelands, 2.5nm northeast of	AK
106437	Kalgin Island, 4 nmi east of (depth 169 ft), Cook Inlet, Alaska Current	NOS	COI1205_1	60.47183	-151.70633	:America/Anchorage	USA	knots	184	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, 4nm east of	AK
106438	Kalgin Island, 4 nmi east of (depth 97 ft), Cook Inlet, Alaska Current	NOS	COI1205_12	60.47183	-151.70633	:America/Anchorage	USA	knots	189	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.453	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, 4nm east of	AK
106439	Kalgin Island, 4 nmi east of (depth 18 ft), Cook Inlet, Alaska Current	NOS	COI1205_24	60.47183	-151.70633	:America/Anchorage	USA	knots	193	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.937	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, 4nm east of	AK
106440	Point Possession, northeast of (depth 137 ft), Cook Inlet, Alaska Current	NOS	COI1207_1	61.0566	-150.36035	:America/Anchorage	USA	knots	291	107	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Possession, northeast of	AK
106441	Point Possession, northeast of (depth 78 ft), Cook Inlet, Alaska Current	NOS	COI1207_10	61.0566	-150.36035	:America/Anchorage	USA	knots	295	104	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Possession, northeast of	AK
106442	Point Possession, northeast of (depth 19 ft), Cook Inlet, Alaska Current	NOS	COI1207_19	61.0566	-150.36035	:America/Anchorage	USA	knots	296	101	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Possession, northeast of	AK
106443	Fire Island, 1.2 nmi south of (depth 80 ft), Cook Inlet, Alaska Current	NOS	COI1208_1	61.1036	-150.26492	:America/Anchorage	USA	knots	322	116	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.157	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.2nm south of	AK
106444	Fire Island, 1.2 nmi south of (depth 47 ft), Cook Inlet, Alaska Current	NOS	COI1208_11	61.1036	-150.26492	:America/Anchorage	USA	knots	317	113	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.2nm south of	AK
106445	Fire Island, 1.2 nmi south of (depth 11 ft), Cook Inlet, Alaska Current	NOS	COI1208_22	61.1036	-150.26492	:America/Anchorage	USA	knots	315	110	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.2nm south of	AK
106446	Fire Island, 0.8 nmi north of (depth 49 ft), Cook Inlet, Alaska Current	NOS	COI1209_2	61.18483	-150.2015	:America/Anchorage	USA	knots	268	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 0.8nm north of	AK
106447	Fire Island, 0.8 nmi north of (depth 16 ft), Cook Inlet, Alaska Current	NOS	COI1209_12	61.18483	-150.2015	:America/Anchorage	USA	knots	271	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 0.8nm north of	AK
106448	Fire Island, 0.8 nmi north of (depth 6 ft), Cook Inlet, Alaska Current	NOS	COI1209_15	61.18483	-150.2015	:America/Anchorage	USA	knots	271	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 0.8nm north of	AK
106449	Middle Ground Shoal, east of (depth 102 ft), Cook Inlet, Alaska Current	NOS	COI1210_1	60.88697	-151.23268	:America/Anchorage	USA	knots	235	51	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Ground Shoal, east of	AK
106450	Middle Ground Shoal, east of (depth 43 ft), Cook Inlet, Alaska Current	NOS	COI1210_10	60.88697	-151.23268	:America/Anchorage	USA	knots	239	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Ground Shoal, east of	AK
106451	Middle Ground Shoal, east of (depth 17 ft), Cook Inlet, Alaska Current	NOS	COI1210_14	60.88697	-151.23268	:America/Anchorage	USA	knots	240	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.308	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Ground Shoal, east of	AK
106452	Delaware Bay entrance (depth 96 ft), Delaware Current	NOS	DEB0002_7	38.85362	-75.07703	:America/New_York	USA	knots	149	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.265	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware Bay Entrance	DE
106453	Delaware Bay entrance (depth 57 ft), Delaware Current	NOS	DEB0002_13	38.85362	-75.07703	:America/New_York	USA	knots	154	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.239	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware Bay Entrance	DE
106454	Delaware Bay entrance (depth 37 ft), Delaware Current	NOS	DEB0002_16	38.85362	-75.07703	:America/New_York	USA	knots	155	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.174	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware Bay Entrance	DE
106455	Delaware Bay entrance (depth 18 ft), Delaware Current	NOS	DEB0002_19	38.85362	-75.07703	:America/New_York	USA	knots	152	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware Bay Entrance	DE
106456	Delaware Bay entrance channel (depth 44 ft), Delaware Current	NOS	DEB2101_1	38.78129959106445	-75.04299926757812	:America/New_York	USA	knots	156	312	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.163	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware Bay Entrance Channel	DE
106457	Delaware Bay entrance channel (depth 15 ft), Delaware Current	NOS	DEB2101_10	38.78129959106445	-75.04299926757812	:America/New_York	USA	knots	158	316	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.582	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware Bay Entrance Channel	DE
106458	Delaware Bay entrance channel (depth 5 ft), Delaware Current	NOS	DEB2101_13	38.78129959106445	-75.04299926757812	:America/New_York	USA	knots	158	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.731	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware Bay Entrance Channel	DE
106459	Cape Henlopen, 2 mi NE of (depth 78 ft), Delaware Current	NOS	DEB2102_2	38.81990051269531	-75.05280303955078	:America/New_York	USA	knots	136	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Henlopen, 2 mi NE of	DE
106460	Cape Henlopen, 2 mi NE of (depth 28 ft), Delaware Current	NOS	DEB2102_17	38.81990051269531	-75.05280303955078	:America/New_York	USA	knots	142	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Henlopen, 2 mi NE of	DE
106461	Cape Henlopen, 2 mi NE of (depth 15 ft), Delaware Current	NOS	DEB2102_21	38.81990051269531	-75.05280303955078	:America/New_York	USA	knots	141	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Henlopen, 2 mi NE of	DE
106462	Cape Henlopen, 5 mi north of (depth 61 ft), Delaware Current	NOS	DEB2103_1	38.883399963378906	-75.08329772949219	:America/New_York	USA	knots	159	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.182	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Henlopen, 5 mi north of	DE
106463	Cape Henlopen, 5 mi north of (depth 15 ft), Delaware Current	NOS	DEB2103_15	38.883399963378906	-75.08329772949219	:America/New_York	USA	knots	166	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Henlopen, 5 mi north of	DE
106464	Cape Henlopen, 5 mi north of (depth 9 ft), Delaware Current	NOS	DEB2103_17	38.883399963378906	-75.08329772949219	:America/New_York	USA	knots	169	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Henlopen, 5 mi north of	DE
106465	Cape May Canal, west end (depth 16 ft), New Jersey Current	NOS	DEB2104_3	38.96839904785156	-74.97239685058594	:America/New_York	USA	knots	190	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May Canal, West End	NJ
106466	Cape May Canal, west end (depth 5 ft), New Jersey Current	NOS	DEB2104_10	38.96839904785156	-74.97239685058594	:America/New_York	USA	knots	194	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.237	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May Canal, West End	NJ
106467	Cape May Canal, west end (depth 2 ft), New Jersey Current	NOS	DEB2104_12	38.96839904785156	-74.97239685058594	:America/New_York	USA	knots	193	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.269	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May Canal, West End	NJ
106468	Brandywine Shoal Light, 0.5 nmi west of (depth 41 ft), New Jersey Current	NOS	DEB2105_1	38.98820114135742	-75.12650299072266	:America/New_York	USA	knots	141	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Shoal Light, 0.5 nm west of	NJ
106469	Brandywine Shoal Light, 0.5 nmi west of (depth 15 ft), New Jersey Current	NOS	DEB2105_9	38.98820114135742	-75.12650299072266	:America/New_York	USA	knots	151	329	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.105	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Shoal Light, 0.5 nm west of	NJ
106470	Brandywine Shoal Light, 0.5 nmi west of (depth 5 ft), New Jersey Current	NOS	DEB2105_12	38.98820114135742	-75.12650299072266	:America/New_York	USA	knots	154	329	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Shoal Light, 0.5 nm west of	NJ
106471	Big Stone Beach Anchorage, Buoy G (depth 41 ft), Delaware Current	NOS	DEB2106_2	38.963199615478516	-75.17939758300781	:America/New_York	USA	knots	146	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Big Stone Beach Anchorage, buoy "G"	DE
106472	Big Stone Beach Anchorage, Buoy G (depth 15 ft), Delaware Current	NOS	DEB2106_10	38.963199615478516	-75.17939758300781	:America/New_York	USA	knots	162	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Big Stone Beach Anchorage, buoy "G"	DE
106473	Big Stone Beach Anchorage, Buoy G (depth 8 ft), Delaware Current	NOS	DEB2106_12	38.963199615478516	-75.17939758300781	:America/New_York	USA	knots	165	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Big Stone Beach Anchorage, buoy "G"	DE
106474	Brandywine Range at Miah Maull Range (depth 36 ft), New Jersey Current	NOS	DEB2107_1	39.087501525878906	-75.19129943847656	:America/New_York	USA	knots	145	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Range at Miah Maull Range	NJ
106475	Brandywine Range at Miah Maull Range (depth 16 ft), New Jersey Current	NOS	DEB2107_7	39.087501525878906	-75.19129943847656	:America/New_York	USA	knots	159	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Range at Miah Maull Range	NJ
106476	Brandywine Range at Miah Maull Range (depth 6 ft), New Jersey Current	NOS	DEB2107_10	39.087501525878906	-75.19129943847656	:America/New_York	USA	knots	162	343	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.249	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Range at Miah Maull Range	NJ
106477	Cross Ledge Light (depth 39 ft), Delaware Current	NOS	DEB2108_1	39.17470169067383	-75.2699966430664	:America/New_York	USA	knots	169	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.159	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Ledge Light	DE
106478	Cross Ledge Light (depth 20 ft), Delaware Current	NOS	DEB2108_7	39.17470169067383	-75.2699966430664	:America/New_York	USA	knots	186	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Ledge Light	DE
106479	Cross Ledge Light (depth 6 ft), Delaware Current	NOS	DEB2108_11	39.17470169067383	-75.2699966430664	:America/New_York	USA	knots	185	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.343	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Ledge Light	DE
106480	Ben Davis Point, 3.2 nmi southwest of (depth 26 ft), Delaware Current	NOS	DEB2109_3	39.2681999206543	-75.34539794921875	:America/New_York	USA	knots	137	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ben Davis Point, 3.2 nm southwest of	DE
106481	Ben Davis Point, 3.2 nmi southwest of (depth 13 ft), Delaware Current	NOS	DEB2109_7	39.2681999206543	-75.34539794921875	:America/New_York	USA	knots	144	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ben Davis Point, 3.2 nm southwest of	DE
106482	Ben Davis Point, 3.2 nmi southwest of (depth 3 ft), Delaware Current	NOS	DEB2109_10	39.2681999206543	-75.34539794921875	:America/New_York	USA	knots	147	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ben Davis Point, 3.2 nm southwest of	DE
106483	Arnold Point, 1.8 nmi WSW of (depth 35 ft), New Jersey Current	NOS	DEB2110_1	39.376800537109375	-75.46620178222656	:America/New_York	USA	knots	135	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arnold Point, 1.8 nm WSW of	NJ
106484	Arnold Point, 1.8 nmi WSW of (depth 15 ft), New Jersey Current	NOS	DEB2110_7	39.376800537109375	-75.46620178222656	:America/New_York	USA	knots	148	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arnold Point, 1.8 nm WSW of	NJ
106485	Arnold Point, 1.8 nmi WSW of (depth 6 ft), New Jersey Current	NOS	DEB2110_10	39.376800537109375	-75.46620178222656	:America/New_York	USA	knots	146	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arnold Point, 1.8 nm WSW of	NJ
106486	Baker Range Channel (depth 11 ft), New Jersey Current	NOS	DEB2111_1	39.469398498535156	-75.55999755859375	:America/New_York	USA	knots	184	331	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baker Range Channel	NJ
106487	Baker Range Channel (depth 38 ft), New Jersey Current	NOS	DEB2111_9	39.469398498535156	-75.55999755859375	:America/New_York	USA	knots	175	322	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baker Range Channel	NJ
106488	Reedy Island Wreck (depth 48 ft), Delaware Current	NOS	DEB2112_1	39.537498474121094	-75.54180145263672	:America/New_York	USA	knots	200	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 43.7 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Island Wreck	DE
106489	Reedy Island Wreck (depth 18 ft), Delaware Current	NOS	DEB2112_9	39.537498474121094	-75.54180145263672	:America/New_York	USA	knots	197	12	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.312	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Island Wreck	DE
106490	Reedy Island Wreck (depth 4 ft), Delaware Current	NOS	DEB2112_13	39.537498474121094	-75.54180145263672	:America/New_York	USA	knots	197	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.335	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Island Wreck	DE
106491	Chesapeake and Delaware Canal entrance (depth 12 ft), Delaware Current	NOS	DEB2113_2	39.56439971923828	-75.55490112304688	:America/New_York	USA	knots	134	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake and Delaware Canal Entrance	DE
106492	Chesapeake and Delaware Canal entrance (depth 15 ft), Delaware Current	NOS	DEB2113_4	39.56439971923828	-75.55490112304688	:America/New_York	USA	knots	134	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake and Delaware Canal Entrance	DE
106493	Chesapeake and Delaware Canal entrance (depth 20 ft), Delaware Current	NOS	DEB2113_7	39.56439971923828	-75.55490112304688	:America/New_York	USA	knots	134	356	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake and Delaware Canal Entrance	DE
106494	Chesapeake and Delaware Canal entrance (depth 30 ft), Delaware Current	NOS	DEB2113_13	39.56439971923828	-75.55490112304688	:America/New_York	USA	knots	136	359	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake and Delaware Canal Entrance	DE
106495	Salem River entrance, east of marker 11 (depth 20 ft), New Jersey Current	NOS	DEB2114_1	39.57080078125	-75.502197265625	:America/New_York	USA	knots	242	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Salem River Entrance, east of marker 11	NJ
106496	Salem River entrance, east of marker 11 (depth 15 ft), New Jersey Current	NOS	DEB2114_4	39.57080078125	-75.502197265625	:America/New_York	USA	knots	243	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Salem River Entrance, east of marker 11	NJ
106497	Salem River entrance, east of marker 11 (depth 1 ft), New Jersey Current	NOS	DEB2114_12	39.57080078125	-75.502197265625	:America/New_York	USA	knots	242	71	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Salem River Entrance, east of marker 11	NJ
106498	Pea Patch Island (depth 37 ft), Delaware Current	NOS	DEB2115_1	39.592201232910156	-75.56069946289062	:America/New_York	USA	knots	160	330	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pea Patch Island	DE
106499	Pea Patch Island (depth 14 ft), Delaware Current	NOS	DEB2115_8	39.592201232910156	-75.56069946289062	:America/New_York	USA	knots	155	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.174	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pea Patch Island	DE
106500	Pea Patch Island (depth 4 ft), Delaware Current	NOS	DEB2115_11	39.592201232910156	-75.56069946289062	:America/New_York	USA	knots	155	338	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.201	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pea Patch Island	DE
106501	Kelly Point, 0.7 nmi N of (depth 7 ft), Delaware Current	NOS	DEB2116_1	39.65679931640625	-75.54100036621094	:America/New_York	USA	knots	206	29	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.294	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kelly Point, 0.7nm N of	DE
106502	Kelly Point, 0.7 nmi N of (depth 15 ft), Delaware Current	NOS	DEB2116_3	39.65679931640625	-75.54100036621094	:America/New_York	USA	knots	202	25	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kelly Point, 0.7nm N of	DE
106503	Kelly Point, 0.7 nmi N of (depth 41 ft), Delaware Current	NOS	DEB2116_11	39.65679931640625	-75.54100036621094	:America/New_York	USA	knots	203	18	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kelly Point, 0.7nm N of	DE
106504	Deepwater Point, 0.5 nmi NW of (depth 47 ft), Delaware Current	NOS	DEB2117_1	39.70130157470703	-75.5105972290039	:America/New_York	USA	knots	203	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deepwater Point, 0.5 nm NW of	DE
106505	Deepwater Point, 0.5 nmi NW of (depth 14 ft), Delaware Current	NOS	DEB2117_11	39.70130157470703	-75.5105972290039	:America/New_York	USA	knots	208	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deepwater Point, 0.5 nm NW of	DE
106506	Deepwater Point, 0.5 nmi NW of (depth 8 ft), Delaware Current	NOS	DEB2117_13	39.70130157470703	-75.5105972290039	:America/New_York	USA	knots	208	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deepwater Point, 0.5 nm NW of	DE
106507	Edgemoor (depth 11 ft), Delaware Current	NOS	DEB2118_2	39.747501373291016	-75.49089813232422	:America/New_York	USA	knots	198	10	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgemoor	DE
106508	Edgemoor (depth 18 ft), Delaware Current	NOS	DEB2118_4	39.747501373291016	-75.49089813232422	:America/New_York	USA	knots	198	9	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgemoor	DE
106509	Edgemoor (depth 41 ft), Delaware Current	NOS	DEB2118_11	39.747501373291016	-75.49089813232422	:America/New_York	USA	knots	197	11	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgemoor	DE
106510	Marcus Hook Bar (north) (depth 23 ft), Delaware Current	NOS	DEB2119_1	39.79330062866211	-75.43379974365234	:America/New_York	USA	knots	247	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marcus Hook Bar (north)	DE
106511	Marcus Hook Bar (north) (depth 16 ft), Delaware Current	NOS	DEB2119_3	39.79330062866211	-75.43379974365234	:America/New_York	USA	knots	248	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.212	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marcus Hook Bar (north)	DE
106512	Marcus Hook Bar (north) (depth 6 ft), Delaware Current	NOS	DEB2119_6	39.79330062866211	-75.43379974365234	:America/New_York	USA	knots	248	65	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.245	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marcus Hook Bar (north)	DE
106513	Eddystone (depth 34 ft), Pennsylvania Current	NOS	DEB2121_1	39.850399017333984	-75.33480072021484	:America/New_York	USA	knots	249	71	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eddystone	PA
106514	Eddystone (depth 14 ft), Pennsylvania Current	NOS	DEB2121_13	39.850399017333984	-75.33480072021484	:America/New_York	USA	knots	252	70	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.146	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eddystone	PA
106515	Eddystone (depth 3 ft), Pennsylvania Current	NOS	DEB2121_20	39.850399017333984	-75.33480072021484	:America/New_York	USA	knots	253	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eddystone	PA
106516	Crab Point, 0.5 mi east of (depth 48 ft), New Jersey Current	NOS	DEB2122_1	39.8468017578125	-75.28299713134766	:America/New_York	USA	knots	276	95	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crab Point, 0.5 mi East of	NJ
106517	Crab Point, 0.5 mi east of (depth 15 ft), New Jersey Current	NOS	DEB2122_11	39.8468017578125	-75.28299713134766	:America/New_York	USA	knots	273	96	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crab Point, 0.5 mi East of	NJ
106518	Crab Point, 0.5 mi east of (depth 9 ft), New Jersey Current	NOS	DEB2122_13	39.8468017578125	-75.28299713134766	:America/New_York	USA	knots	272	96	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crab Point, 0.5 mi East of	NJ
106519	Mantua Creek, US 44 Bridge, Paulsboro (depth 13 ft), New Jersey Current	NOS	DEB2123_16	39.83150100708008	-75.23600006103516	:America/New_York	USA	knots	21	193	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 54.1 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.297	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mantua Creek US 44 Bridge Paulsboro	NJ
106520	Mantua Creek Anchorage (depth 34 ft), Pennsylvania Current	NOS	DEB2124_1	39.856998443603516	-75.2417984008789	:America/New_York	USA	knots	243	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.192	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mantua Creek Anchorage	PA
106521	Mantua Creek Anchorage (depth 14 ft), Pennsylvania Current	NOS	DEB2124_7	39.856998443603516	-75.2417984008789	:America/New_York	USA	knots	242	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.283	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mantua Creek Anchorage	PA
106522	Mantua Creek Anchorage (depth 8 ft), Pennsylvania Current	NOS	DEB2124_9	39.856998443603516	-75.2417984008789	:America/New_York	USA	knots	242	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mantua Creek Anchorage	PA
106523	Girard Point (depth 6 ft), Pennsylvania Current	NOS	DEB2126_3	39.89250183105469	-75.19509887695312	:America/New_York	USA	knots	130	314	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Girard Point	PA
106524	Gloucester Point (depth 44 ft), New Jersey Current	NOS	DEB2128_1	39.897300720214844	-75.1322021484375	:America/New_York	USA	knots	205	20	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gloucester Point	NJ
106525	Gloucester Point (depth 15 ft), New Jersey Current	NOS	DEB2128_10	39.897300720214844	-75.1322021484375	:America/New_York	USA	knots	202	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gloucester Point	NJ
106526	Gloucester Point (depth 8 ft), New Jersey Current	NOS	DEB2128_12	39.897300720214844	-75.1322021484375	:America/New_York	USA	knots	201	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gloucester Point	NJ
106527	Kaighn Point (depth 37 ft), New Jersey Current	NOS	DEB2129_1	39.928199768066406	-75.13529968261719	:America/New_York	USA	knots	166	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kaighn Point	NJ
106528	Kaighn Point (depth 14 ft), New Jersey Current	NOS	DEB2129_8	39.928199768066406	-75.13529968261719	:America/New_York	USA	knots	170	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.112	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kaighn Point	NJ
106529	Kaighn Point (depth 8 ft), New Jersey Current	NOS	DEB2129_10	39.928199768066406	-75.13529968261719	:America/New_York	USA	knots	170	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kaighn Point	NJ
106530	Fisher Point (depth 7 ft), Pennsylvania Current	NOS	DEB2130_1	39.97850036621094	-75.07599639892578	:America/New_York	USA	knots	233	87	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.452	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fisher Point	PA
106531	Fisher Point (depth 15 ft), Pennsylvania Current	NOS	DEB2130_3	39.97850036621094	-75.07599639892578	:America/New_York	USA	knots	234	86	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.355	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fisher Point	PA
106532	Fisher Point (depth 41 ft), Pennsylvania Current	NOS	DEB2130_11	39.97850036621094	-75.07599639892578	:America/New_York	USA	knots	238	81	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fisher Point	PA
106533	Frankford Range at Tacony Range (depth 7 ft), New Jersey Current	NOS	DEB2131_1	40.01530075073242	-75.03230285644531	:America/New_York	USA	knots	256	62	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Frankford Range at Tacony Range	NJ
106534	Frankford Range at Tacony Range (depth 15 ft), New Jersey Current	NOS	DEB2131_3	40.01530075073242	-75.03230285644531	:America/New_York	USA	knots	254	59	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.157	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Frankford Range at Tacony Range	NJ
106535	Frankford Range at Tacony Range (depth 35 ft), New Jersey Current	NOS	DEB2131_9	40.01530075073242	-75.03230285644531	:America/New_York	USA	knots	251	59	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Frankford Range at Tacony Range	NJ
106536	Edgewater Range at Devlin Range (depth 32 ft), Pennsylvania Current	NOS	DEB2132_1	40.077598571777344	-74.8865966796875	:America/New_York	USA	knots	250	70	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.268	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgewater Range at Devlin Range	PA
106537	Edgewater Range at Devlin Range (depth 16 ft), Pennsylvania Current	NOS	DEB2132_6	40.077598571777344	-74.8865966796875	:America/New_York	USA	knots	252	71	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.321	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgewater Range at Devlin Range	PA
106538	Edgewater Range at Devlin Range (depth 6 ft), Pennsylvania Current	NOS	DEB2132_9	40.077598571777344	-74.8865966796875	:America/New_York	USA	knots	253	72	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.318	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgewater Range at Devlin Range	PA
106539	Florence Bend (depth 11 ft), New Jersey Current	NOS	DEB2133_1	40.12730026245117	-74.81580352783203	:America/New_York	USA	knots	304	105	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.486	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Florence Bend	NJ
106540	Florence Bend (depth 14 ft), New Jersey Current	NOS	DEB2133_2	40.12730026245117	-74.81580352783203	:America/New_York	USA	knots	304	106	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.478	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Florence Bend	NJ
106541	Florence Bend (depth 37 ft), New Jersey Current	NOS	DEB2133_9	40.12730026245117	-74.81580352783203	:America/New_York	USA	knots	299	113	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.294	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Florence Bend	NJ
106542	Newbold Island, north of, main channel (depth 7 ft), New Jersey Current	NOS	DEB2134_1	40.13370132446289	-74.75890350341797	:America/New_York	USA	knots	258	55	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.263	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newbold Island north of, Main Channel	NJ
106543	Newbold Island, north of, main channel (depth 15 ft), New Jersey Current	NOS	DEB2134_3	40.13370132446289	-74.75890350341797	:America/New_York	USA	knots	257	56	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.251	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newbold Island north of, Main Channel	NJ
106544	Newbold Island, north of, main channel (depth 31 ft), New Jersey Current	NOS	DEB2134_8	40.13370132446289	-74.75890350341797	:America/New_York	USA	knots	258	60	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newbold Island north of, Main Channel	NJ
106545	Estes Head, Eastport (depth 78 ft), Maine Current	NOS	EPT0003_4	44.88793	-66.99565	:America/New_York	USA	knots	79	271	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Estes Head, Eastport	ME
106546	Estes Head, Eastport (depth 52 ft), Maine Current	NOS	EPT0003_8	44.88793	-66.99565	:America/New_York	USA	knots	85	266	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Estes Head, Eastport	ME
106547	Estes Head, Eastport (depth 32 ft), Maine Current	NOS	EPT0003_11	44.88793	-66.99565	:America/New_York	USA	knots	88	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Estes Head, Eastport	ME
106548	Estes Head, Eastport (depth 13 ft), Maine Current	NOS	EPT0003_14	44.88793	-66.99565	:America/New_York	USA	knots	90	260	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Estes Head, Eastport	ME
106549	Robbinston, St. Croix River (depth 58 ft), Maine Current	NOS	EPT0004_4	45.0763	-67.10097	:America/New_York	USA	knots	171	340	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 56.9 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robbinston, St. Croix River	ME
106550	Robbinston, St. Croix River (depth 32 ft), Maine Current	NOS	EPT0004_8	45.0763	-67.10097	:America/New_York	USA	knots	166	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 30.7 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robbinston, St. Croix River	ME
106551	Robbinston, St. Croix River (depth 12 ft), Maine Current	NOS	EPT0004_11	45.0763	-67.10097	:America/New_York	USA	knots	165	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robbinston, St. Croix River	ME
106552	St. Marys River entrance (depth 42 ft), Cumberland Sound, Florida Current	NOS	FEB1102_1	30.70792	-81.44463	:America/New_York	USA	knots	92	271	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Mary's River Entrance	FL
106553	St. Marys River entrance (depth 25 ft), Cumberland Sound, Florida Current	NOS	FEB1102_6	30.70792	-81.44463	:America/New_York	USA	knots	93	272	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Mary's River Entrance	FL
106554	St. Marys River entrance (depth 8 ft), Cumberland Sound, Florida Current	NOS	FEB1102_11	30.70792	-81.44463	:America/New_York	USA	knots	93	272	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Mary's River Entrance	FL
106555	Quarantine Reach, 0.4 nmi W of Fort Clinch (depth 46 ft), Florida Current	NOS	FEB1103_1	30.7047	-81.462	:America/New_York	USA	knots	65	226	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quarantine Reach, 0.4nm W of Fort Clinch	FL
106556	Quarantine Reach, 0.4 nmi W of Fort Clinch (depth 27 ft), Florida Current	NOS	FEB1103_7	30.7047	-81.462	:America/New_York	USA	knots	47	232	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quarantine Reach, 0.4nm W of Fort Clinch	FL
106557	Quarantine Reach, 0.4 nmi W of Fort Clinch (depth 7 ft), Florida Current	NOS	FEB1103_13	30.7047	-81.462	:America/New_York	USA	knots	34	235	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quarantine Reach, 0.4nm W of Fort Clinch	FL
106558	Old Fernandina, Amelia River, Old Town Reach (depth 24 ft), Florida Current	NOS	FEB1104_1	30.68604	-81.46074	:America/New_York	USA	knots	10	193	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Fernandina, Amelia River, Old Town Reach	FL
106559	Old Fernandina, Amelia River, Old Town Reach (depth 14 ft), Florida Current	NOS	FEB1104_4	30.68604	-81.46074	:America/New_York	USA	knots	15	189	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Fernandina, Amelia River, Old Town Reach	FL
106560	Old Fernandina, Amelia River, Old Town Reach (depth 4 ft), Florida Current	NOS	FEB1104_7	30.68604	-81.46074	:America/New_York	USA	knots	18	188	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Fernandina, Amelia River, Old Town Reach	FL
106561	Fernandina Beach, City Front Reach, Amelia River (depth 29 ft), Florida Current	NOS	FEB1107_1	30.67019	-81.46789	:America/New_York	USA	knots	59	239	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 19.5 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.109	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fernandina Beach, City Front Reach, Amelia River	FL
106562	Fernandina Beach, City Front Reach, Amelia River (depth 11 ft), Florida Current	NOS	FEB1107_6	30.67019	-81.46789	:America/New_York	USA	knots	63	239	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fernandina Beach, City Front Reach, Amelia River	FL
106563	Fernandina Beach, City Front Reach, Amelia River (depth 5 ft), Florida Current	NOS	FEB1107_10	30.67019	-81.46789	:America/New_York	USA	knots	68	240	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fernandina Beach, City Front Reach, Amelia River	FL
106564	South jetty (depth 34 ft), St. Marys River, Cumberland Sound, Florida Current	NOS	FEB1108_1	30.70693	-81.39861	:America/New_York	USA	knots	114	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.146	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	south jetty	FL
106565	South jetty (depth 18 ft), St. Marys River, Cumberland Sound, Florida Current	NOS	FEB1108_6	30.70693	-81.39861	:America/New_York	USA	knots	112	329	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	south jetty	FL
106566	South jetty (depth 8 ft), St. Marys River, Cumberland Sound, Florida Current	NOS	FEB1108_9	30.70693	-81.39861	:America/New_York	USA	knots	110	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.267	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	south jetty	FL
106567	Key West, 0.3 mi W of Ft. Taylor (depth 14 ft), Florida Current	NOS	FLK1301_1	24.54798	-81.81686	:America/New_York	USA	knots	186	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West, 0.3 mi. W of Ft. Taylor	FL
106568	Key West, 0.3 mi W of Ft. Taylor (depth 4 ft), Florida Current	NOS	FLK1301_4	24.54798	-81.81686	:America/New_York	USA	knots	187	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West, 0.3 mi. W of Ft. Taylor	FL
106569	Main Ship Channel entrance (depth 17 ft), Key West, Florida Current	NOS	FLK1302_2	24.47071	-81.81177	:America/New_York	USA	knots	182	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Main Ship Channel Entrance	FL
106570	Main Ship Channel entrance (depth 4 ft), Key West, Florida Current	NOS	FLK1302_6	24.47071	-81.81177	:America/New_York	USA	knots	187	339	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Main Ship Channel Entrance	FL
106571	Key West Channel, Cut-A Cut-B Turn (depth 26 ft), Florida Current	NOS	FLK1303_1	24.52603	-81.81819	:America/New_York	USA	knots	161	324	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West Channel, Cut-A Cut-B Turn	FL
106572	Key West Channel, Cut-A Cut-B Turn (depth 6 ft), Florida Current	NOS	FLK1303_7	24.52603	-81.81819	:America/New_York	USA	knots	164	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West Channel, Cut-A Cut-B Turn	FL
106573	Southwest channel (depth 20 ft), Key West, Florida Current	NOS	FLK1304_1	24.53421	-81.83212	:America/New_York	USA	knots	202	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southwest channel	FL
106574	Southwest channel (depth 3 ft), Key West, Florida Current	NOS	FLK1304_6	24.53421	-81.83212	:America/New_York	USA	knots	202	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southwest channel	FL
106575	Key West Harbor Range channel (depth 19 ft), Florida Current	NOS	FLK1306_1	24.56301	-81.80934	:America/New_York	USA	knots	212	32	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West Harbor Range channel	FL
106576	Key West Harbor Range channel (depth 6 ft), Florida Current	NOS	FLK1306_5	24.56301	-81.80934	:America/New_York	USA	knots	215	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West Harbor Range channel	FL
106577	Turning Basin (depth 23 ft), Key West, Florida Current	NOS	FLK1307_1	24.56389	-81.80622	:America/New_York	USA	knots	24	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turning Basin	FL
106578	Turning Basin (depth 6 ft), Key West, Florida Current	NOS	FLK1307_6	24.56389	-81.80622	:America/New_York	USA	knots	210	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turning Basin	FL
106579	Man of War Harbor (depth 16 ft), Florida Current	NOS	FLK1308_1	24.58701	-81.80624	:America/New_York	USA	knots	182	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Man of War Harbor	FL
106580	Man of War Harbor (depth 3 ft), Florida Current	NOS	FLK1308_5	24.58701	-81.80624	:America/New_York	USA	knots	187	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Man of War Harbor	FL
106581	Fleming Key, north of (depth 9 ft), Florida Current	NOS	FLK1309_1	24.59673	-81.7986	:America/New_York	USA	knots	241	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fleming Key, North of	FL
106582	Fleming Key, north of (depth 2 ft), Florida Current	NOS	FLK1309_5	24.59673	-81.7986	:America/New_York	USA	knots	242	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.332	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fleming Key, North of	FL
106583	Fleming Key Cut (depth 17 ft), Florida Current	NOS	FLK1310_1	24.56814	-81.80182	:America/New_York	USA	knots	274	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.458	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fleming Key Cut	FL
106584	Fleming Key Cut (depth 4 ft), Florida Current	NOS	FLK1310_5	24.56814	-81.80182	:America/New_York	USA	knots	279	68	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.551	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fleming Key Cut	FL
106585	Northwest Channel, W of Calda Bank (depth 22 ft), Key West, Florida Current	NOS	FLK1313_1	24.61539	-81.87154	:America/New_York	USA	knots	144	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northwest Channel, W of Calda Bank	FL
106586	Northwest Channel, W of Calda Bank (depth 5 ft), Key West, Florida Current	NOS	FLK1313_6	24.61539	-81.87154	:America/New_York	USA	knots	145	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northwest Channel, W of Calda Bank	FL
106587	Northwest Channel, W of Middle Ground (depth 17 ft), Key West, Florida Current	NOS	FLK1315_1	24.56827	-81.83502	:America/New_York	USA	knots	140	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northwest Channel, W of Middle Ground	FL
106588	Northwest Channel, W of Middle Ground (depth 4 ft), Key West, Florida Current	NOS	FLK1315_5	24.56827	-81.83502	:America/New_York	USA	knots	162	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northwest Channel, W of Middle Ground	FL
106589	Boca Grande Channel (depth 12 ft), Florida Current	NOS	FLK1316_1	24.56656	-82.06678	:America/New_York	USA	knots	191	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boca Grande Channel	FL
106590	Boca Grande Channel (depth 2 ft), Florida Current	NOS	FLK1316_7	24.56656	-82.06678	:America/New_York	USA	knots	190	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boca Grande Channel	FL
106591	New Ground (depth 32 ft), Florida Current	NOS	FLK1317_1	24.65071	-82.4162	:America/New_York	USA	knots	259	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Ground	FL
106592	New Ground (depth 6 ft), Florida Current	NOS	FLK1317_9	24.65071	-82.4162	:America/New_York	USA	knots	260	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Ground	FL
106593	Moser Channel, between Molasses and Pigeon Keys (depth 9 ft), Florida Current	NOS	FLK1324_1	24.698169708251953	-81.16924285888672	:America/New_York	USA	knots	163	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moser Channel, between Molasses and Pigeon Keys	FL
106594	Moser Channel, between Molasses and Pigeon Keys (depth 3 ft), Florida Current	NOS	FLK1324_5	24.698169708251953	-81.16924285888672	:America/New_York	USA	knots	164	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.143	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moser Channel, between Molasses and Pigeon Keys	FL
106595	Loggerhead Key, east of (depth 8 ft), Florida Current	NOS	FLK1325_1	24.61617	-81.45322	:America/New_York	USA	knots	154	330	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Loggerhead Key, East of	FL
106596	Loggerhead Key, east of (depth 2 ft), Florida Current	NOS	FLK1325_5	24.61617	-81.45322	:America/New_York	USA	knots	158	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Loggerhead Key, East of	FL
106597	Bahia Honda Harbor (depth 4 ft), Florida Current	NOS	FLK1327_4	24.6563	-81.28848	:America/New_York	USA	knots	183	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bahia Honda Harbor	FL
106598	Fort Pierce Inlet entrance (depth 33 ft), Florida Current	NOS	FPI0901_1	27.47114	-80.29258	:America/New_York	USA	knots	77	260	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pierce Inlet Entrance	FL
106599	Fort Pierce Inlet entrance (depth 23 ft), Florida Current	NOS	FPI0901_4	27.47114	-80.29258	:America/New_York	USA	knots	79	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pierce Inlet Entrance	FL
106600	Fort Pierce Inlet entrance (depth 16 ft), Florida Current	NOS	FPI0901_6	27.47114	-80.29258	:America/New_York	USA	knots	80	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pierce Inlet Entrance	FL
106601	Fort Pierce Inlet entrance (depth 6 ft), Florida Current	NOS	FPI0901_9	27.47114	-80.29258	:America/New_York	USA	knots	81	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.159	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pierce Inlet Entrance	FL
106602	Inner Range, north of USCG station (depth 21 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0902_1	27.46641	-80.30824	:America/New_York	USA	knots	61	243	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Inner Range, north of USCG station	FL
106603	Inner Range, north of USCG station (depth 14 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0902_3	27.46641	-80.30824	:America/New_York	USA	knots	65	243	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Inner Range, north of USCG station	FL
106604	Inner Range, north of USCG station (depth 5 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0902_6	27.46641	-80.30824	:America/New_York	USA	knots	76	242	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Inner Range, north of USCG station	FL
106605	South Bridge (ICW) (depth 16 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0903_1	27.45997	-80.3192	:America/New_York	USA	knots	53	232	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Bridge (ICW)	FL
106606	South Bridge (ICW) (depth 9 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0903_5	27.45997	-80.3192	:America/New_York	USA	knots	36	236	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Bridge (ICW)	FL
106607	South Bridge (ICW) (depth 3 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0903_9	27.45997	-80.3192	:America/New_York	USA	knots	31	238	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Bridge (ICW)	FL
106608	Turning Basin (depth 19 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0904_1	27.46014	-80.32093	:America/New_York	USA	knots	23	218	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turning Basin	FL
106609	Turning Basin (depth 16 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0904_2	27.46014	-80.32093	:America/New_York	USA	knots	22	219	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turning Basin	FL
106610	Turning Basin (depth 6 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0904_5	27.46014	-80.32093	:America/New_York	USA	knots	20	218	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turning Basin	FL
106611	Barbers Point entrance (depth 166 ft), Oahu Island, Hawaii Current	NOS	HAI1103_1	21.31235	-158.13288	:Pacific/Honolulu	USA	knots	340	165	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barbers Point Entrance	HI
106612	Barbers Point entrance (depth 94 ft), Oahu Island, Hawaii Current	NOS	HAI1103_12	21.31235	-158.13288	:Pacific/Honolulu	USA	knots	345	151	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barbers Point Entrance	HI
106613	Barbers Point entrance (depth 22 ft), Oahu Island, Hawaii Current	NOS	HAI1103_23	21.31235	-158.13288	:Pacific/Honolulu	USA	knots	350	152	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.224	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barbers Point Entrance	HI
106614	South of Barbers Point (depth 224 ft), Oahu Island, Hawaii Current	NOS	HAI1105_1	21.2696	-158.10157	:Pacific/Honolulu	USA	knots	293	112	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South of Barbers Point	HI
106615	South of Barbers Point (depth 136 ft), Oahu Island, Hawaii Current	NOS	HAI1105_10	21.2696	-158.10157	:Pacific/Honolulu	USA	knots	289	115	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South of Barbers Point	HI
106616	South of Barbers Point (depth 27 ft), Oahu Island, Hawaii Current	NOS	HAI1105_21	21.2696	-158.10157	:Pacific/Honolulu	USA	knots	285	122	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.112	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South of Barbers Point	HI
106617	Diamond Head (depth 186 ft), Oahu Island, Hawaii Current	NOS	HAI1106_1	21.2395	-157.8058	:Pacific/Honolulu	USA	knots	104	290	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Diamond Head	HI
106618	Diamond Head (depth 107 ft), Oahu Island, Hawaii Current	NOS	HAI1106_13	21.2395	-157.8058	:Pacific/Honolulu	USA	knots	96	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Diamond Head	HI
106619	Diamond Head (depth 22 ft), Oahu Island, Hawaii Current	NOS	HAI1106_26	21.2395	-157.8058	:Pacific/Honolulu	USA	knots	97	274	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Diamond Head	HI
106620	Iroquois Point, Pearl Harbor (depth 64 ft), Oahu Island, Hawaii Current	NOS	HAI1110_1	21.33498	-157.97023	:Pacific/Honolulu	USA	knots	\N	6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Iroquois Point, Pearl Harbor	HI
106621	Iroquois Point, Pearl Harbor (depth 35 ft), Oahu Island, Hawaii Current	NOS	HAI1110_10	21.33498	-157.97023	:Pacific/Honolulu	USA	knots	181	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Iroquois Point, Pearl Harbor	HI
106622	Iroquois Point, Pearl Harbor (depth 9 ft), Oahu Island, Hawaii Current	NOS	HAI1110_18	21.33498	-157.97023	:Pacific/Honolulu	USA	knots	180	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.098	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Iroquois Point, Pearl Harbor	HI
106623	Makapu'u Point (depth 257 ft), Oahu Island, Hawaii Current	NOS	HAI1111_1	21.26423	-157.60542	:Pacific/Honolulu	USA	knots	70	210	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Makapu'u Point	HI
106624	Makapu'u Point (depth 109 ft), Oahu Island, Hawaii Current	NOS	HAI1111_16	21.26423	-157.60542	:Pacific/Honolulu	USA	knots	42	217	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.271	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Makapu'u Point	HI
106625	Makapu'u Point (depth 41 ft), Oahu Island, Hawaii Current	NOS	HAI1111_23	21.26423	-157.60542	:Pacific/Honolulu	USA	knots	42	217	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.239	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Makapu'u Point	HI
106626	Kahuku Point (depth 189 ft), Oahu Island, Hawaii Current	NOS	HAI1112_1	21.72998	-157.98995	:Pacific/Honolulu	USA	knots	76	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kahuku Point	HI
106627	Kahuku Point (depth 110 ft), Oahu Island, Hawaii Current	NOS	HAI1112_13	21.72998	-157.98995	:Pacific/Honolulu	USA	knots	79	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kahuku Point	HI
106628	Kahuku Point (depth 25 ft), Oahu Island, Hawaii Current	NOS	HAI1112_26	21.72998	-157.98995	:Pacific/Honolulu	USA	knots	73	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kahuku Point	HI
106629	Laau Point, southwest of (depth 181 ft), Molokai Island, Hawaii Current	NOS	HAI1113_1	21.07645	-157.3616	:Pacific/Honolulu	USA	knots	340	160	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Laau Point, Southwest of	HI
106630	Laau Point, southwest of (depth 103 ft), Molokai Island, Hawaii Current	NOS	HAI1113_13	21.07645	-157.3616	:Pacific/Honolulu	USA	knots	338	170	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Laau Point, Southwest of	HI
106631	Laau Point, southwest of (depth 24 ft), Molokai Island, Hawaii Current	NOS	HAI1113_25	21.07645	-157.3616	:Pacific/Honolulu	USA	knots	340	172	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Laau Point, Southwest of	HI
106632	Pailalo Channel (depth 244 ft), Molokai Island, Hawaii Current	NOS	HAI1115_1	21.08695	-156.73148	:Pacific/Honolulu	USA	knots	33	227	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pailalo Channel	HI
106633	Pailalo Channel (depth 136 ft), Molokai Island, Hawaii Current	NOS	HAI1115_12	21.08695	-156.73148	:Pacific/Honolulu	USA	knots	39	229	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pailalo Channel	HI
106634	Pailalo Channel (depth 28 ft), Molokai Island, Hawaii Current	NOS	HAI1115_23	21.08695	-156.73148	:Pacific/Honolulu	USA	knots	39	233	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.175	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pailalo Channel	HI
106635	Kalohi Channel (depth 237 ft), Hawaii Current	NOS	HAI1116_1	21.0033	-156.95883	:Pacific/Honolulu	USA	knots	96	281	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalohi Channel	HI
106636	Kalohi Channel (depth 139 ft), Hawaii Current	NOS	HAI1116_11	21.0033	-156.95883	:Pacific/Honolulu	USA	knots	102	283	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalohi Channel	HI
106637	Kalohi Channel (depth 21 ft), Hawaii Current	NOS	HAI1116_22	21.0033	-156.95883	:Pacific/Honolulu	USA	knots	106	284	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 30.7 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalohi Channel	HI
106638	Hawea Point (depth 243 ft), Maui Island, Hawaii Current	NOS	HAI1118_1	21.00178	-156.69182	:Pacific/Honolulu	USA	knots	34	230	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawea Point	HI
106639	Hawea Point (depth 99 ft), Maui Island, Hawaii Current	NOS	HAI1118_23	21.00178	-156.69182	:Pacific/Honolulu	USA	knots	21	208	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.364	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawea Point	HI
106640	Hawea Point (depth 27 ft), Maui Island, Hawaii Current	NOS	HAI1118_34	21.00178	-156.69182	:Pacific/Honolulu	USA	knots	14	215	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.431	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawea Point	HI
106641	Auau Channel (depth 210 ft), Maui Island, Hawaii Current	NOS	HAI1119_1	20.86727	-156.74717	:Pacific/Honolulu	USA	knots	342	164	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Auau Channel	HI
106642	Auau Channel (depth 105 ft), Maui Island, Hawaii Current	NOS	HAI1119_17	20.86727	-156.74717	:Pacific/Honolulu	USA	knots	344	172	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.282	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Auau Channel	HI
106643	Auau Channel (depth 26 ft), Maui Island, Hawaii Current	NOS	HAI1119_29	20.86727	-156.74717	:Pacific/Honolulu	USA	knots	347	168	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.293	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Auau Channel	HI
106644	Lahaina (depth 49 ft), Maui Island, Hawaii Current	NOS	HAI1120_1	20.86845	-156.68528	:Pacific/Honolulu	USA	knots	334	139	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.203	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lahaina	HI
106645	Lahaina (depth 29 ft), Maui Island, Hawaii Current	NOS	HAI1120_7	20.86845	-156.68528	:Pacific/Honolulu	USA	knots	333	137	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.244	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lahaina	HI
106646	Lahaina (depth 7 ft), Maui Island, Hawaii Current	NOS	HAI1120_14	20.86845	-156.68528	:Pacific/Honolulu	USA	knots	330	134	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.276	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lahaina	HI
106647	Alalakeiki Channel (depth 56 ft), Maui Island, Hawaii Current	NOS	HAI1121_28	20.61252	-156.50812	:Pacific/Honolulu	USA	knots	\N	330.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alalakeiki Channel	HI
106648	Upolu Point (depth 204 ft), Hawaii Island, Hawaii Current	NOS	HAI1127_1	20.26502	-155.90157	:Pacific/Honolulu	USA	knots	28	241	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.381	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upolu Point	HI
106649	Upolu Point (depth 100 ft), Hawaii Island, Hawaii Current	NOS	HAI1127_17	20.26502	-155.90157	:Pacific/Honolulu	USA	knots	34	237	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upolu Point	HI
106650	Upolu Point (depth 34 ft), Hawaii Island, Hawaii Current	NOS	HAI1127_27	20.26502	-155.90157	:Pacific/Honolulu	USA	knots	30	241	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.626	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upolu Point	HI
106740	Cape Trinity (depth 106 ft), Sitkinak Strait, Alaska Current	NOS	KOD0918_13	56.74982	-154.201	:America/Anchorage	USA	knots	131	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.201	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Trinity	AK
106651	Humboldt Bay ent., 0.1 nmi NE of South Spit Light (depth 30 ft), California Current	NOS	HUB0202_4	40.75792	-124.23278	:America/Los_Angeles	USA	knots	346	171	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldt Bay Entr., 0.1nm NE of South Spit Light	CA
106652	Humboldt Bay ent., 0.1 nmi NE of South Spit Light (depth 14 ft), California Current	NOS	HUB0202_9	40.75792	-124.23278	:America/Los_Angeles	USA	knots	341	168	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.299	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldt Bay Entr., 0.1nm NE of South Spit Light	CA
106653	North Bay Channel, west of Eureka (depth 28 ft), Humboldt Bay, California Current	NOS	HUB0203_2	40.78715	-124.19268	:America/Los_Angeles	USA	knots	200	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 29.2 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Bay Channel, west of Eureka	CA
106654	North Bay Channel, west of Eureka (depth 15 ft), Humboldt Bay, California Current	NOS	HUB0203_6	40.78715	-124.19268	:America/Los_Angeles	USA	knots	197	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 16.1 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Bay Channel, west of Eureka	CA
106655	South Spit, 0.1 nmi E of (depth 15 ft), Humboldt Bay, California Current	NOS	HUB0207_3	40.74785	-124.2241	:America/Los_Angeles	USA	knots	2	178	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 17.0 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Spit, 0.1 n.mi. E of	CA
106656	Humboldy Bay Bar Channel, 0.4 nmi WNW of (depth 31 ft), Humboldt Bay, California Current	NOS	HUB0401_1	40.76688	-124.25298	:America/Los_Angeles	USA	knots	230	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldy Bay Bar Channel, 0.4 nm WNW of	CA
106657	Humboldy Bay Bar Channel, 0.4 nmi WNW of (depth 4 ft), Humboldt Bay, California Current	NOS	HUB0401_9	40.76688	-124.25298	:America/Los_Angeles	USA	knots	232	48	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldy Bay Bar Channel, 0.4 nm WNW of	CA
106658	Humboldt Bay entrance channel (depth 34 ft), California Current	NOS	HUB0402_1	40.7651	-124.23753	:America/Los_Angeles	USA	knots	323	141	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldt Bay Entrance Channel	CA
106659	Humboldt Bay entrance channel (depth 15 ft), California Current	NOS	HUB0402_7	40.7651	-124.23753	:America/Los_Angeles	USA	knots	323	140	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldt Bay Entrance Channel	CA
106660	Haverstraw (depth 20 ft), Hudson River (midchannel), New York Current	NOS	HUR0401_1	41.20917	-73.95133	:America/New_York	USA	knots	162	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haverstraw	NY
106661	Haverstraw (depth 12 ft), Hudson River (midchannel), New York Current	NOS	HUR0401_6	41.20917	-73.95133	:America/New_York	USA	knots	166	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haverstraw	NY
106662	Haverstraw (depth 4 ft), Hudson River (midchannel), New York Current	NOS	HUR0401_11	41.20917	-73.95133	:America/New_York	USA	knots	165	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.275	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haverstraw	NY
106663	Tappan Zee Bridge (depth 35 ft), Hudson River (midchannel), New York Current	NOS	HUR0502_1	41.06743	-73.88154	:America/New_York	USA	knots	178	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tappan Zee Bridge	NY
106664	Tappan Zee Bridge (depth 16 ft), Hudson River (midchannel), New York Current	NOS	HUR0502_7	41.06743	-73.88154	:America/New_York	USA	knots	174	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tappan Zee Bridge	NY
106665	Tappan Zee Bridge (depth 5 ft), Hudson River (midchannel), New York Current	NOS	HUR0502_10	41.06743	-73.88154	:America/New_York	USA	knots	175	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tappan Zee Bridge	NY
106666	Stony Point (depth 83 ft), Hudson River (midchannel), New York Current	NOS	HUR0503_1	41.24158	-73.96668	:America/New_York	USA	knots	170	338	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stony Point	NY
106667	Stony Point (depth 50 ft), Hudson River (midchannel), New York Current	NOS	HUR0503_11	41.24158	-73.96668	:America/New_York	USA	knots	165	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stony Point	NY
106668	Stony Point (depth 14 ft), Hudson River (midchannel), New York Current	NOS	HUR0503_22	41.24158	-73.96668	:America/New_York	USA	knots	154	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.237	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stony Point	NY
106669	Bear Mountain Bridge (depth 88 ft), Hudson River (midchannel), New York Current	NOS	HUR0504_1	41.31592	-73.98385	:America/New_York	USA	knots	161	339	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Mountain Bridge	NY
106670	Bear Mountain Bridge (depth 52 ft), Hudson River (midchannel), New York Current	NOS	HUR0504_12	41.31592	-73.98385	:America/New_York	USA	knots	167	343	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Mountain Bridge	NY
106671	Bear Mountain Bridge (depth 13 ft), Hudson River (midchannel), New York Current	NOS	HUR0504_24	41.31592	-73.98385	:America/New_York	USA	knots	180	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.311	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Mountain Bridge	NY
106672	Newburgh Beacon Bridge (depth 24 ft), Hudson River (midchannel), New York Current	NOS	HUR0506_1	41.51658	-73.99168	:America/New_York	USA	knots	168	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newburgh Beacon Bridge	NY
106673	Newburgh Beacon Bridge (depth 17 ft), Hudson River (midchannel), New York Current	NOS	HUR0506_3	41.51658	-73.99168	:America/New_York	USA	knots	169	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newburgh Beacon Bridge	NY
106674	Newburgh Beacon Bridge (depth 4 ft), Hudson River (midchannel), New York Current	NOS	HUR0506_7	41.51658	-73.99168	:America/New_York	USA	knots	171	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newburgh Beacon Bridge	NY
106675	Roseton (depth 41 ft), Hudson River (midchannel), New York Current	NOS	HUR0507_1	41.56247	-73.97053	:America/New_York	USA	knots	215	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roseton	NY
106676	Roseton (depth 15 ft), Hudson River (midchannel), New York Current	NOS	HUR0507_9	41.56247	-73.97053	:America/New_York	USA	knots	214	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roseton	NY
106677	Roseton (depth 5 ft), Hudson River (midchannel), New York Current	NOS	HUR0507_12	41.56247	-73.97053	:America/New_York	USA	knots	213	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roseton	NY
106678	Kingston Point, south of (depth 30 ft), Hudson River (midchannel), New York Current	NOS	HUR0509_1	41.91827	-73.9595	:America/New_York	USA	knots	178	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingston Point, south of	NY
106679	Kingston Point, south of (depth 17 ft), Hudson River (midchannel), New York Current	NOS	HUR0509_5	41.91827	-73.9595	:America/New_York	USA	knots	177	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingston Point, south of	NY
106680	Kingston Point, south of (depth 4 ft), Hudson River (midchannel), New York Current	NOS	HUR0509_9	41.91827	-73.9595	:America/New_York	USA	knots	177	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingston Point, south of	NY
106681	George Washington Bridge (depth 63 ft), Hudson River (midchannel), New York Current	NOS	HUR0611_1	40.84958	-73.94982	:America/New_York	USA	knots	177	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	George Washington Bridge	NY
106682	George Washington Bridge (depth 40 ft), Hudson River (midchannel), New York Current	NOS	HUR0611_8	40.84958	-73.94982	:America/New_York	USA	knots	198	12	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	George Washington Bridge	NY
106683	George Washington Bridge (depth 14 ft), Hudson River (midchannel), New York Current	NOS	HUR0611_16	40.84958	-73.94982	:America/New_York	USA	knots	203	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.237	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	George Washington Bridge	NY
106684	Kingston-Rhinecliff Bridge (depth 27 ft), Hudson River (midchannel), New York Current	NOS	HUR0612_1	41.97708	-73.95225	:America/New_York	USA	knots	190	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingston-Rhinecliff Bridge	NY
106685	Kingston-Rhinecliff Bridge (depth 14 ft), Hudson River (midchannel), New York Current	NOS	HUR0612_5	41.97708	-73.95225	:America/New_York	USA	knots	191	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingston-Rhinecliff Bridge	NY
106686	Kingston-Rhinecliff Bridge (depth 4 ft), Hudson River (midchannel), New York Current	NOS	HUR0612_8	41.97708	-73.95225	:America/New_York	USA	knots	192	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingston-Rhinecliff Bridge	NY
106687	Silver Point, south of (depth 31 ft), Hudson River (midchannel), New York Current	NOS	HUR0613_1	42.13818	-73.90852	:America/New_York	USA	knots	205	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Silver Point, south of	NY
106688	Silver Point, south of (depth 14 ft), Hudson River (midchannel), New York Current	NOS	HUR0613_6	42.13818	-73.90852	:America/New_York	USA	knots	205	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Silver Point, south of	NY
106689	Silver Point, south of (depth 4 ft), Hudson River (midchannel), New York Current	NOS	HUR0613_9	42.13818	-73.90852	:America/New_York	USA	knots	205	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Silver Point, south of	NY
106690	Hudson (depth 40 ft), Hudson River (midchannel), New York Current	NOS	HUR0614_1	42.24792	-73.8184	:America/New_York	USA	knots	238	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.308	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson	NY
106691	Hudson (depth 24 ft), Hudson River (midchannel), New York Current	NOS	HUR0614_6	42.24792	-73.8184	:America/New_York	USA	knots	242	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.378	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson	NY
106692	Hudson (depth 14 ft), Hudson River (midchannel), New York Current	NOS	HUR0614_9	42.24792	-73.8184	:America/New_York	USA	knots	242	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.384	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson	NY
106693	Coxsackie (depth 31 ft), Hudson River (midchannel), New York Current	NOS	HUR0615_1	42.35135	-73.78992	:America/New_York	USA	knots	184	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coxsackie	NY
106694	Coxsackie (depth 14 ft), Hudson River (midchannel), New York Current	NOS	HUR0615_6	42.35135	-73.78992	:America/New_York	USA	knots	189	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coxsackie	NY
106695	Coxsackie (depth 4 ft), Hudson River (midchannel), New York Current	NOS	HUR0615_9	42.35135	-73.78992	:America/New_York	USA	knots	190	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.236	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coxsackie	NY
106696	Houghtaling Island, south of (depth 27 ft), Hudson River (midchannel), New York Current	NOS	HUR0616_1	42.42258	-73.77995	:America/New_York	USA	knots	181	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.145	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Houghtaling Island, south of	NY
106697	Houghtaling Island, south of (depth 14 ft), Hudson River (midchannel), New York Current	NOS	HUR0616_5	42.42258	-73.77995	:America/New_York	USA	knots	180	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.164	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Houghtaling Island, south of	NY
106698	Houghtaling Island, south of (depth 4 ft), Hudson River (midchannel), New York Current	NOS	HUR0616_8	42.42258	-73.77995	:America/New_York	USA	knots	180	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Houghtaling Island, south of	NY
106699	Castleton-on-Hudson Bridge (depth 32 ft), Hudson River (midchannel), New York Current	NOS	HUR0617_1	42.50435	-73.77738	:America/New_York	USA	knots	229	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Castleton-on-Hudson Bridge	NY
106700	Castleton-on-Hudson Bridge (depth 16 ft), Hudson River (midchannel), New York Current	NOS	HUR0617_6	42.50435	-73.77738	:America/New_York	USA	knots	232	50	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Castleton-on-Hudson Bridge	NY
106701	Castleton-on-Hudson Bridge (depth 6 ft), Hudson River (midchannel), New York Current	NOS	HUR0617_9	42.50435	-73.77738	:America/New_York	USA	knots	233	51	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Castleton-on-Hudson Bridge	NY
106702	Port of Albany (depth 30 ft), Hudson River (midchannel), New York Current	NOS	HUR0618_1	42.62317	-73.75558	:America/New_York	USA	knots	200	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of Albany	NY
106703	Port of Albany (depth 16 ft), Hudson River (midchannel), New York Current	NOS	HUR0618_5	42.62317	-73.75558	:America/New_York	USA	knots	198	20	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.143	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of Albany	NY
106704	Port of Albany (depth 7 ft), Hudson River (midchannel), New York Current	NOS	HUR0618_8	42.62317	-73.75558	:America/New_York	USA	knots	198	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of Albany	NY
106705	Mid-Hudson Suspension Bridge (depth 48 ft), Hudson River (midchannel), New York Current	NOS	HUR0620_1	41.70182	-73.94593	:America/New_York	USA	knots	185	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.162	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mid-Hudson Suspension Bridge	NY
106706	Mid-Hudson Suspension Bridge (depth 32 ft), Hudson River (midchannel), New York Current	NOS	HUR0620_6	41.70182	-73.94593	:America/New_York	USA	knots	186	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mid-Hudson Suspension Bridge	NY
106707	Mid-Hudson Suspension Bridge (depth 16 ft), Hudson River (midchannel), New York Current	NOS	HUR0620_11	41.70182	-73.94593	:America/New_York	USA	knots	188	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.166	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mid-Hudson Suspension Bridge	NY
106708	Johns Pass entrance (depth 8 ft), Florida Current	NOS	JOP1101_1	27.77815	-82.78722	:America/New_York	USA	knots	223	51	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.172	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johns Pass Entrance	FL
106709	Johns Pass entrance (depth 2 ft), Florida Current	NOS	JOP1101_5	27.77815	-82.78722	:America/New_York	USA	knots	222	53	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.246	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johns Pass Entrance	FL
106710	Johns Pass Bridge, north span (depth 16 ft), Florida Current	NOS	JOP1103_1	27.78331	-82.78216	:America/New_York	USA	knots	209	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johns Pass Bridge, north span	FL
106711	Johns Pass Bridge, north span (depth 3 ft), Florida Current	NOS	JOP1103_9	27.78331	-82.78216	:America/New_York	USA	knots	209	34	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johns Pass Bridge, north span	FL
106712	Johns Pass Bridge, 0.3 nmi north of (depth 11 ft), Florida Current	NOS	JOP1104_1	27.78499	-82.77988	:America/New_York	USA	knots	235	47	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.208	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johns Pass Bridge, 0.3nm north of	FL
106713	Johns Pass Bridge, 0.3 nmi north of (depth 3 ft), Florida Current	NOS	JOP1104_6	27.78499	-82.77988	:America/New_York	USA	knots	228	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.223	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johns Pass Bridge, 0.3nm north of	FL
106714	Cliff Point, 1.8 mi NE of (depth 208 ft), Chiniak Bay, Alaska Current	NOS	KOD0901_1	57.73559	-152.38463	:America/Anchorage	USA	knots	\N	289	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cliff Point, 1.8miles NE of	AK
106715	Cliff Point, 1.8 mi NE of (depth 25 ft), Chiniak Bay, Alaska Current	NOS	KOD0901_29	57.73559	-152.38463	:America/Anchorage	USA	knots	\N	241	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cliff Point, 1.8miles NE of	AK
106716	Kodiak Harbor Narrows (depth 33 ft), Chiniak Bay, Alaska Current	NOS	KOD0903_1	57.78918	-152.394	:America/Anchorage	USA	knots	220	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kodiak Harbor Narrows	AK
106717	Kodiak Harbor Narrows (depth 16 ft), Chiniak Bay, Alaska Current	NOS	KOD0903_6	57.78918	-152.394	:America/Anchorage	USA	knots	228	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kodiak Harbor Narrows	AK
106718	Kodiak Harbor Narrows (depth 6 ft), Chiniak Bay, Alaska Current	NOS	KOD0903_9	57.78918	-152.394	:America/Anchorage	USA	knots	228	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.163	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kodiak Harbor Narrows	AK
106719	Woody Island, north of (depth 99 ft), Chiniak Bay, Alaska Current	NOS	KOD0904_1	57.80578	-152.33434	:America/Anchorage	USA	knots	243	51	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woody Island, north of	AK
106720	Woody Island, north of (depth 59 ft), Chiniak Bay, Alaska Current	NOS	KOD0904_7	57.80578	-152.33434	:America/Anchorage	USA	knots	246	50	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woody Island, north of	AK
106721	Woody Island, north of (depth 14 ft), Chiniak Bay, Alaska Current	NOS	KOD0904_14	57.80578	-152.33434	:America/Anchorage	USA	knots	241	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woody Island, north of	AK
106722	Woody Channel (depth 85 ft), Chiniak Bay, Alaska Current	NOS	KOD0905_1	57.78043	-152.36638	:America/Anchorage	USA	knots	203	20	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woody Channel	AK
106723	Woody Channel (depth 49 ft), Chiniak Bay, Alaska Current	NOS	KOD0905_12	57.78043	-152.36638	:America/Anchorage	USA	knots	204	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woody Channel	AK
106724	Woody Channel (depth 16 ft), Chiniak Bay, Alaska Current	NOS	KOD0905_22	57.78043	-152.36638	:America/Anchorage	USA	knots	203	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woody Channel	AK
106725	Cape Chiniak (depth 223 ft), Chiniak Bay, Alaska Current	NOS	KOD0906_1	57.60784	-152.08979	:America/Anchorage	USA	knots	200	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chiniak	AK
106726	Cape Chiniak (depth 125 ft), Chiniak Bay, Alaska Current	NOS	KOD0906_16	57.60784	-152.08979	:America/Anchorage	USA	knots	201	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chiniak	AK
106727	Cape Chiniak (depth 26 ft), Chiniak Bay, Alaska Current	NOS	KOD0906_31	57.60784	-152.08979	:America/Anchorage	USA	knots	189	12	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chiniak	AK
106728	Ugak Bay entrance (depth 112 ft), Alaska Current	NOS	KOD0907_15	57.3995	-152.53466	:America/Anchorage	USA	knots	\N	237.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ugak Bay Entrance	AK
106729	Ugak Bay entrance (depth 27 ft), Alaska Current	NOS	KOD0907_28	57.3995	-152.53466	:America/Anchorage	USA	knots	\N	292	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ugak Bay Entrance	AK
106730	Geese Island, south of (depth 79 ft), Sitkinak Strait, Alaska Current	NOS	KOD0915_1	56.68618	-153.92006	:America/Anchorage	USA	knots	110	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Geese Island, south of	AK
106731	Geese Island, south of (depth 46 ft), Sitkinak Strait, Alaska Current	NOS	KOD0915_6	56.68618	-153.92006	:America/Anchorage	USA	knots	112	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Geese Island, south of	AK
106732	Geese Island, south of (depth 13 ft), Sitkinak Strait, Alaska Current	NOS	KOD0915_11	56.68618	-153.92006	:America/Anchorage	USA	knots	111	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Geese Island, south of	AK
106733	Cape Sitkinak, east of (depth 169 ft), Sitkinak Strait, Alaska Current	NOS	KOD0916_1	56.57744	-153.79126	:America/Anchorage	USA	knots	151	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Sitkinak, east of	AK
106734	Cape Sitkinak, east of (depth 97 ft), Sitkinak Strait, Alaska Current	NOS	KOD0916_12	56.57744	-153.79126	:America/Anchorage	USA	knots	144	338	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.366	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Sitkinak, east of	AK
106735	Cape Sitkinak, east of (depth 25 ft), Sitkinak Strait, Alaska Current	NOS	KOD0916_23	56.57744	-153.79126	:America/Anchorage	USA	knots	139	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.462	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Sitkinak, east of	AK
106736	Sitkinak Strait, southwest entrance (depth 81 ft), Alaska Current	NOS	KOD0917_1	56.65504	-154.13396	:America/Anchorage	USA	knots	112	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.256	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitkinak Strait, southwest entrance	AK
106737	Sitkinak Strait, southwest entrance (depth 48 ft), Alaska Current	NOS	KOD0917_6	56.65504	-154.13396	:America/Anchorage	USA	knots	113	297	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.261	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitkinak Strait, southwest entrance	AK
106738	Sitkinak Strait, southwest entrance (depth 15 ft), Alaska Current	NOS	KOD0917_11	56.65504	-154.13396	:America/Anchorage	USA	knots	114	296	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.266	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitkinak Strait, southwest entrance	AK
106739	Cape Trinity (depth 185 ft), Sitkinak Strait, Alaska Current	NOS	KOD0918_1	56.74982	-154.201	:America/Anchorage	USA	knots	114	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Trinity	AK
106741	Cape Trinity (depth 27 ft), Sitkinak Strait, Alaska Current	NOS	KOD0918_25	56.74982	-154.201	:America/Anchorage	USA	knots	130	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Trinity	AK
106742	Russian Harbor (depth 93 ft), Sitkinak Strait, Alaska Current	NOS	KOD0919_1	56.73967	-154.03397	:America/Anchorage	USA	knots	137	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Russian Harbor	AK
106743	Russian Harbor (depth 54 ft), Sitkinak Strait, Alaska Current	NOS	KOD0919_7	56.73967	-154.03397	:America/Anchorage	USA	knots	128	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Russian Harbor	AK
106744	Russian Harbor (depth 14 ft), Sitkinak Strait, Alaska Current	NOS	KOD0919_13	56.73967	-154.03397	:America/Anchorage	USA	knots	120	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Russian Harbor	AK
106745	Approach to Alitak Bay (depth 89 ft), Alaska Current	NOS	KOD0920_1	56.78384	-154.64118	:America/Anchorage	USA	knots	236	67	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Approach to Alitak Bay	AK
106746	Approach to Alitak Bay (depth 56 ft), Alaska Current	NOS	KOD0920_6	56.78384	-154.64118	:America/Anchorage	USA	knots	225	70	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Approach to Alitak Bay	AK
106747	Approach to Alitak Bay (depth 17 ft), Alaska Current	NOS	KOD0920_12	56.78384	-154.64118	:America/Anchorage	USA	knots	210	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Approach to Alitak Bay	AK
106748	Cape Ikolik, Shelikof Strait (depth 197 ft), Alaska Current	NOS	KOD0921_1	57.28605	-154.82843	:America/Anchorage	USA	knots	200	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Ikolik, Shelikof Strait	AK
106749	Cape Ikolik, Shelikof Strait (depth 112 ft), Alaska Current	NOS	KOD0921_14	57.28605	-154.82843	:America/Anchorage	USA	knots	205	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Ikolik, Shelikof Strait	AK
106750	Cape Ikolik, Shelikof Strait (depth 27 ft), Alaska Current	NOS	KOD0921_27	57.28605	-154.82843	:America/Anchorage	USA	knots	228	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.211	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Ikolik, Shelikof Strait	AK
106751	Cape Grant, Shelikof Strait (depth 164 ft), Alaska Current	NOS	KOD0922_1	57.41718	-154.76648	:America/Anchorage	USA	knots	204	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Grant, Shelikof Strait	AK
106752	Cape Grant, Shelikof Strait (depth 98 ft), Alaska Current	NOS	KOD0922_11	57.41718	-154.76648	:America/Anchorage	USA	knots	207	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Grant, Shelikof Strait	AK
106753	Cape Grant, Shelikof Strait (depth 26 ft), Alaska Current	NOS	KOD0922_22	57.41718	-154.76648	:America/Anchorage	USA	knots	211	20	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Grant, Shelikof Strait	AK
106754	Uyak Anchorage, Uyak Bay (depth 56 ft), Alaska Current	NOS	KOD0923_1	57.63732	-153.99539	:America/Anchorage	USA	knots	\N	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uyak Anchorage, Uyak Bay	AK
106755	Uyak Anchorage, Uyak Bay (depth 33 ft), Alaska Current	NOS	KOD0923_8	57.63732	-153.99539	:America/Anchorage	USA	knots	\N	310	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uyak Anchorage, Uyak Bay	AK
106756	Uyak Anchorage, Uyak Bay (depth 14 ft), Alaska Current	NOS	KOD0923_14	57.63732	-153.99539	:America/Anchorage	USA	knots	\N	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uyak Anchorage, Uyak Bay	AK
106757	Larsen Bay, Uyak Bay (depth 33 ft), Alaska Current	NOS	KOD0924_1	57.54221	-153.98831	:America/Anchorage	USA	knots	111	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Larsen Bay, Uyak Bay	AK
106758	Larsen Bay, Uyak Bay (depth 14 ft), Alaska Current	NOS	KOD0924_7	57.54221	-153.98831	:America/Anchorage	USA	knots	105	296	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Larsen Bay, Uyak Bay	AK
106759	Larsen Bay, Uyak Bay (depth 7 ft), Alaska Current	NOS	KOD0924_9	57.54221	-153.98831	:America/Anchorage	USA	knots	104	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Larsen Bay, Uyak Bay	AK
106760	Cape Kuliuk, Shelikof Strait (depth 169 ft), Alaska Current	NOS	KOD0925_1	57.79352	-154.03236	:America/Anchorage	USA	knots	226	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kuliuk, Shelikof Strait	AK
106761	Cape Kuliuk, Shelikof Strait (depth 97 ft), Alaska Current	NOS	KOD0925_12	57.79352	-154.03236	:America/Anchorage	USA	knots	234	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kuliuk, Shelikof Strait	AK
106762	Cape Kuliuk, Shelikof Strait (depth 25 ft), Alaska Current	NOS	KOD0925_23	57.79352	-154.03236	:America/Anchorage	USA	knots	274	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kuliuk, Shelikof Strait	AK
106763	Steep Cape, Shelikof Strait (depth 88 ft), Alaska Current	NOS	KOD0926_11	58.21452	-153.22028	:America/Anchorage	USA	knots	\N	57.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.105	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steep Cape, Shelikof Strait	AK
106764	Steep Cape, Shelikof Strait (depth 23 ft), Alaska Current	NOS	KOD0926_21	58.21452	-153.22028	:America/Anchorage	USA	knots	\N	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steep Cape, Shelikof Strait	AK
106765	2.5 nmi east of Outlet Cape (depth 156 ft), Kupreanof Strait, Alaska Current	NOS	KOD0928_1	57.99757	-153.15648	:America/Anchorage	USA	knots	88	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2.5nm east of Outlet Cape	AK
106766	2.5 nmi east of Outlet Cape (depth 91 ft), Kupreanof Strait, Alaska Current	NOS	KOD0928_11	57.99757	-153.15648	:America/Anchorage	USA	knots	111	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2.5nm east of Outlet Cape	AK
106767	2.5 nmi east of Outlet Cape (depth 19 ft), Kupreanof Strait, Alaska Current	NOS	KOD0928_22	57.99757	-153.15648	:America/Anchorage	USA	knots	125	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2.5nm east of Outlet Cape	AK
106768	Chernof Point, 0.8 mi off (depth 71 ft), Kupreanof Strait, Alaska Current	NOS	KOD0929_1	57.96041	-152.90063	:America/Anchorage	USA	knots	85	278	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.105	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chernof Point, 0.8mile off	AK
106769	Chernof Point, 0.8 mi off (depth 41 ft), Kupreanof Strait, Alaska Current	NOS	KOD0929_10	57.96041	-152.90063	:America/Anchorage	USA	knots	88	276	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.184	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chernof Point, 0.8mile off	AK
106770	Chernof Point, 0.8 mi off (depth 15 ft), Kupreanof Strait, Alaska Current	NOS	KOD0929_18	57.96041	-152.90063	:America/Anchorage	USA	knots	90	276	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.221	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chernof Point, 0.8mile off	AK
106771	Whale Passage, northwest entrance (depth 83 ft), Alaska Current	NOS	KOD0930_1	57.93959	-152.86278	:America/Anchorage	USA	knots	111	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.396	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Passage, Northwest Entrance	AK
106772	Whale Passage, northwest entrance (depth 50 ft), Alaska Current	NOS	KOD0930_6	57.93959	-152.86278	:America/Anchorage	USA	knots	113	301	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.496	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Passage, Northwest Entrance	AK
106773	Whale Passage, northwest entrance (depth 18 ft), Alaska Current	NOS	KOD0930_11	57.93959	-152.86278	:America/Anchorage	USA	knots	112	301	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.454	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Passage, Northwest Entrance	AK
106774	Whale Passage, off Bird Point (depth 73 ft), Alaska Current	NOS	KOD0931_1	57.91885	-152.79529	:America/Anchorage	USA	knots	119	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Passage, off Bird Point	AK
106775	Whale Passage, off Bird Point (depth 43 ft), Alaska Current	NOS	KOD0931_10	57.91885	-152.79529	:America/Anchorage	USA	knots	119	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Passage, off Bird Point	AK
106776	Whale Passage, off Bird Point (depth 14 ft), Alaska Current	NOS	KOD0931_19	57.91885	-152.79529	:America/Anchorage	USA	knots	117	310	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Passage, off Bird Point	AK
106777	Shag Rocks (depth 169 ft), Whale Passage, Alaska Current	NOS	KOD0932_1	57.90752	-152.77663	:America/Anchorage	USA	knots	117	269	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shag Rocks	AK
106778	Shag Rocks (depth 97 ft), Whale Passage, Alaska Current	NOS	KOD0932_12	57.90752	-152.77663	:America/Anchorage	USA	knots	119	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.408	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shag Rocks	AK
106779	Shag Rocks (depth 24 ft), Whale Passage, Alaska Current	NOS	KOD0932_23	57.90752	-152.77663	:America/Anchorage	USA	knots	120	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shag Rocks	AK
106780	Narrow Strait, off Ouzinkie Point (depth 84 ft), Alaska Current	NOS	KOD0933_1	57.9121	-152.52407	:America/Anchorage	USA	knots	117	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Narrow Strait, off Ouzinkie Point	AK
106781	Narrow Strait, off Ouzinkie Point (depth 51 ft), Alaska Current	NOS	KOD0933_6	57.9121	-152.52407	:America/Anchorage	USA	knots	120	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Narrow Strait, off Ouzinkie Point	AK
106782	Narrow Strait, off Ouzinkie Point (depth 12 ft), Alaska Current	NOS	KOD0933_12	57.9121	-152.52407	:America/Anchorage	USA	knots	121	310	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Narrow Strait, off Ouzinkie Point	AK
106783	Afognak Strait, east entrance (depth 97 ft), Alaska Current	NOS	KOD0934_1	57.99474	-152.68417	:America/Anchorage	USA	knots	107	284.3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Afognak Strait, East Entrance	AK
106784	Afognak Strait, east entrance (depth 57 ft), Alaska Current	NOS	KOD0934_7	57.99474	-152.68417	:America/Anchorage	USA	knots	107	285	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.281	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Afognak Strait, East Entrance	AK
106785	Afognak Strait, east entrance (depth 11 ft), Alaska Current	NOS	KOD0934_14	57.99474	-152.68417	:America/Anchorage	USA	knots	105	251	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.245	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Afognak Strait, East Entrance	AK
106786	Raspberry Strait, south of Muskomee Bay (depth 169 ft), Alaska Current	NOS	KOD0935_1	58.07176	-153.06462	:America/Anchorage	USA	knots	348	163	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raspberry Strait, south of Muskomee Bay	AK
106787	Raspberry Strait, south of Muskomee Bay (depth 97 ft), Alaska Current	NOS	KOD0935_12	58.07176	-153.06462	:America/Anchorage	USA	knots	\N	157.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raspberry Strait, south of Muskomee Bay	AK
106788	Raspberry Strait, south of Muskomee Bay (depth 25 ft), Alaska Current	NOS	KOD0935_23	58.07176	-153.06462	:America/Anchorage	USA	knots	\N	157	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raspberry Strait, south of Muskomee Bay	AK
106789	Black Cape, Shelikof Strait (depth 95 ft), Alaska Current	NOS	KOD0936_1	58.40572	-152.90728	:America/Anchorage	USA	knots	\N	181.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Black Cape, Shelikof Strait	AK
106790	Black Cape, Shelikof Strait (depth 55 ft), Alaska Current	NOS	KOD0936_7	58.40572	-152.90728	:America/Anchorage	USA	knots	4	187.6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Black Cape, Shelikof Strait	AK
106791	Black Cape, Shelikof Strait (depth 16 ft), Alaska Current	NOS	KOD0936_13	58.40572	-152.90728	:America/Anchorage	USA	knots	20	196.1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Black Cape, Shelikof Strait	AK
106792	Alligator Island, Shelikof Strait (depth 61 ft), Alaska Current	NOS	KOD0937_7	58.46107	-152.82645	:America/Anchorage	USA	knots	\N	224.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alligator Island, Shelikof Strait	AK
107537	Hood Canal Bridge (depth 209 ft), Washington Current	NOS	PUG1603_1	47.854740142822266	-122.6294174194336	:America/Los_Angeles	USA	knots	37	223	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Bridge	WA
106793	Alligator Island, Shelikof Strait (depth 15 ft), Alaska Current	NOS	KOD0937_14	58.46107	-152.82645	:America/Anchorage	USA	knots	35	236.2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alligator Island, Shelikof Strait	AK
106794	Lighthouse Point, Shuyak Island (depth 188 ft), Alaska Current	NOS	KOD0938_12	58.48523	-152.67029	:America/Anchorage	USA	knots	\N	252	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lighthouse Point, Shuyak Island	AK
106795	Lighthouse Point, Shuyak Island (depth 70 ft), Alaska Current	NOS	KOD0938_24	58.48523	-152.67029	:America/Anchorage	USA	knots	61	242	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lighthouse Point, Shuyak Island	AK
106796	Cape Current Narrows, Shuyak Strait (depth 99 ft), Alaska Current	NOS	KOD0939_1	58.46688	-152.49512	:America/Anchorage	USA	knots	102	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Current Narrows, Shuyak Strait	AK
106797	Cape Current Narrows, Shuyak Strait (depth 57 ft), Alaska Current	NOS	KOD0939_14	58.46688	-152.49512	:America/Anchorage	USA	knots	96	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Current Narrows, Shuyak Strait	AK
106798	Cape Current Narrows, Shuyak Strait (depth 14 ft), Alaska Current	NOS	KOD0939_27	58.46688	-152.49512	:America/Anchorage	USA	knots	93	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Current Narrows, Shuyak Strait	AK
106799	East Shuyak Strait entrance (depth 134 ft), Alaska Current	NOS	KOD0940_11	58.4579	-152.42785	:America/Anchorage	USA	knots	\N	197.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Shuyak Strait Entrance	AK
106800	East Shuyak Strait entrance (depth 25 ft), Alaska Current	NOS	KOD0940_22	58.4579	-152.42785	:America/Anchorage	USA	knots	110	140	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Shuyak Strait Entrance	AK
106801	Tonki Cape, east of (depth 138 ft), Marmot Strait, Alaska Current	NOS	KOD0941_1	58.34598	-151.91508	:America/Anchorage	USA	knots	164	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tonki Cape, east of	AK
106802	Tonki Cape, east of (depth 85 ft), Marmot Strait, Alaska Current	NOS	KOD0941_9	58.34598	-151.91508	:America/Anchorage	USA	knots	160	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tonki Cape, east of	AK
106803	Tonki Cape, east of (depth 26 ft), Marmot Strait, Alaska Current	NOS	KOD0941_18	58.34598	-151.91508	:America/Anchorage	USA	knots	156	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tonki Cape, east of	AK
106804	Marmot Island, west of (depth 169 ft), Marmot Strait, Alaska Current	NOS	KOD0942_1	58.24443	-151.93232	:America/Anchorage	USA	knots	186	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marmot Island, west of	AK
106805	Marmot Island, west of (depth 97 ft), Marmot Strait, Alaska Current	NOS	KOD0942_12	58.24443	-151.93232	:America/Anchorage	USA	knots	191	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marmot Island, west of	AK
106806	Marmot Island, west of (depth 24 ft), Marmot Strait, Alaska Current	NOS	KOD0942_23	58.24443	-151.93232	:America/Anchorage	USA	knots	194	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marmot Island, west of	AK
106807	Marmot Island, southwest of (depth 180 ft), Marmot Strait, Alaska Current	NOS	KOD0943_1	58.17085	-151.96862	:America/Anchorage	USA	knots	206	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marmot Island, southwest of	AK
106808	Marmot Island, southwest of (depth 101 ft), Marmot Strait, Alaska Current	NOS	KOD0943_13	58.17085	-151.96862	:America/Anchorage	USA	knots	207	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marmot Island, southwest of	AK
106809	Marmot Island, southwest of (depth 22 ft), Marmot Strait, Alaska Current	NOS	KOD0943_25	58.17085	-151.96862	:America/Anchorage	USA	knots	209	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marmot Island, southwest of	AK
106810	North of Perevalnie Island, Shuyak Island (depth 144 ft), Alaska Current	NOS	KOD0944_1	58.65111	-152.39663	:America/Anchorage	USA	knots	74	274	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North of Perevalnie Island, Shuyak Island	AK
106811	North of Perevalnie Island, Shuyak Island (depth 85 ft), Alaska Current	NOS	KOD0944_10	58.65111	-152.39663	:America/Anchorage	USA	knots	89	274	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North of Perevalnie Island, Shuyak Island	AK
106812	North of Perevalnie Island, Shuyak Island (depth 20 ft), Alaska Current	NOS	KOD0944_20	58.65111	-152.39663	:America/Anchorage	USA	knots	89	269	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.277	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North of Perevalnie Island, Shuyak Island	AK
106813	The Race (depth 45 ft), Long Island Sound, New York Current	NOS	LIS1001_1	41.22818	-72.06252	:America/New_York	USA	knots	105	295	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Race	NY
106814	The Race (depth 25 ft), Long Island Sound, New York Current	NOS	LIS1001_7	41.22818	-72.06252	:America/New_York	USA	knots	108	292	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Race	NY
106815	The Race (depth 6 ft), Long Island Sound, New York Current	NOS	LIS1001_13	41.22818	-72.06252	:America/New_York	USA	knots	106	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.39	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Race	NY
106816	Wicopesset island, NE of (depth 44 ft), Block Island Sound, Rhode Island Current	NOS	LIS1002_1	41.29841	-71.90096	:America/New_York	USA	knots	141	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wicopesset island, NE of	RI
106817	Wicopesset island, NE of (depth 25 ft), Block Island Sound, Rhode Island Current	NOS	LIS1002_7	41.29841	-71.90096	:America/New_York	USA	knots	132	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wicopesset island, NE of	RI
106818	Wicopesset island, NE of (depth 8 ft), Block Island Sound, Rhode Island Current	NOS	LIS1002_12	41.29841	-71.90096	:America/New_York	USA	knots	125	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.298	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wicopesset island, NE of	RI
106819	Thames River approach (depth 35 ft), Long Island Sound, Connecticut Current	NOS	LIS1003_1	41.29387	-72.07842	:America/New_York	USA	knots	51	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thames River Approach	CT
106820	Thames River approach (depth 15 ft), Long Island Sound, Connecticut Current	NOS	LIS1003_7	41.29387	-72.07842	:America/New_York	USA	knots	65	271	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thames River Approach	CT
106821	Thames River approach (depth 5 ft), Long Island Sound, Connecticut Current	NOS	LIS1003_10	41.29387	-72.07842	:America/New_York	USA	knots	71	268	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thames River Approach	CT
106822	New London Harbor entrance (depth 31 ft), Long Island Sound, Connecticut Current	NOS	LIS1004_1	41.31875	-72.08173	:America/New_York	USA	knots	\N	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London Harbor entrance	CT
106823	New London Harbor entrance (depth 15 ft), Long Island Sound, Connecticut Current	NOS	LIS1004_6	41.31875	-72.08173	:America/New_York	USA	knots	\N	335	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London Harbor entrance	CT
106824	New London Harbor entrance (depth 2 ft), Long Island Sound, Connecticut Current	NOS	LIS1004_10	41.31875	-72.08173	:America/New_York	USA	knots	167	316	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London Harbor entrance	CT
106825	Fort Trumbull State Park (depth 31 ft), Long Island Sound, Connecticut Current	NOS	LIS1005_1	41.34544	-72.08629	:America/New_York	USA	knots	\N	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.112	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Trumbull State Park	CT
106826	Fort Trumbull State Park (depth 14 ft), Long Island Sound, Connecticut Current	NOS	LIS1005_6	41.34544	-72.08629	:America/New_York	USA	knots	\N	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Trumbull State Park	CT
106827	Fort Trumbull State Park (depth 5 ft), Long Island Sound, Connecticut Current	NOS	LIS1005_9	41.34544	-72.08629	:America/New_York	USA	knots	169	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Trumbull State Park	CT
106828	New London State Pier (depth 57 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1006_1	41.35728	-72.08673	:America/New_York	USA	knots	164	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London State Pier	CT
106829	New London State Pier (depth 31 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1006_9	41.35728	-72.08673	:America/New_York	USA	knots	172	351	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London State Pier	CT
106830	New London State Pier (depth 14 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1006_14	41.35728	-72.08673	:America/New_York	USA	knots	178	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London State Pier	CT
106831	US Coast Guard Academy (depth 32 ft), Long Island Sound, Connecticut Current	NOS	LIS1007_1	41.37373	-72.0895	:America/New_York	USA	knots	184	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	U.S. Coast Guard Academy	CT
106832	US Coast Guard Academy (depth 16 ft), Long Island Sound, Connecticut Current	NOS	LIS1007_6	41.37373	-72.0895	:America/New_York	USA	knots	179	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	U.S. Coast Guard Academy	CT
106833	US Coast Guard Academy (depth 9 ft), Long Island Sound, Connecticut Current	NOS	LIS1007_8	41.37373	-72.0895	:America/New_York	USA	knots	182	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	U.S. Coast Guard Academy	CT
106834	Smith Cove (depth 31 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1008_1	41.39658	-72.09592	:America/New_York	USA	knots	179	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Cove	CT
106835	Smith Cove (depth 14 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1008_6	41.39658	-72.09592	:America/New_York	USA	knots	184	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Cove	CT
106836	Smith Cove (depth 5 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1008_9	41.39658	-72.09592	:America/New_York	USA	knots	181	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.222	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Cove	CT
106837	Allyn Point (depth 19 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1009_1	41.44296	-72.0856	:America/New_York	USA	knots	184	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allyn Point	CT
106838	Allyn Point (depth 12 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1009_5	41.44296	-72.0856	:America/New_York	USA	knots	182	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allyn Point	CT
106839	Allyn Point (depth 4 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1009_10	41.44296	-72.0856	:America/New_York	USA	knots	195	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allyn Point	CT
106840	Great Gull Island, SW of (depth 29 ft), Long Island Sound, New York Current	NOS	LIS1010_1	41.19444	-72.13363	:America/New_York	USA	knots	164	332	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Gull Island, SW of	NY
106841	Great Gull Island, SW of (depth 16 ft), Long Island Sound, New York Current	NOS	LIS1010_9	41.19444	-72.13363	:America/New_York	USA	knots	157	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.144	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Gull Island, SW of	NY
106842	Great Gull Island, SW of (depth 3 ft), Long Island Sound, New York Current	NOS	LIS1010_17	41.19444	-72.13363	:America/New_York	USA	knots	147	320	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.294	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Gull Island, SW of	NY
106843	Plum Island, 3 nmi north of, Buoy PI (depth 131 ft), Long Island Sound, New York Current	NOS	LIS1011_1	41.22245	-72.17709	:America/New_York	USA	knots	82	253	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.167	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Island, 3nm. North of, Buoy PI	NY
106844	Plum Island, 3 nmi north of, Buoy PI (depth 79 ft), Long Island Sound, New York Current	NOS	LIS1011_9	41.22245	-72.17709	:America/New_York	USA	knots	79	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Island, 3nm. North of, Buoy PI	NY
107538	Hood Canal Bridge (depth 111 ft), Washington Current	NOS	PUG1603_11	47.854740142822266	-122.6294174194336	:America/Los_Angeles	USA	knots	45	223	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Bridge	WA
106845	Plum Island, 3 nmi north of, Buoy PI (depth 20 ft), Long Island Sound, New York Current	NOS	LIS1011_18	41.22245	-72.17709	:America/New_York	USA	knots	81	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.303	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Island, 3nm. North of, Buoy PI	NY
106846	Plum Gut (depth 158 ft), Long Island Sound, New York Current	NOS	LIS1012_1	41.15917	-72.2075	:America/New_York	USA	knots	121	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Gut	NY
106847	Plum Gut (depth 99 ft), Long Island Sound, New York Current	NOS	LIS1012_10	41.15917	-72.2075	:America/New_York	USA	knots	124	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.177	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Gut	NY
106848	Plum Gut (depth 25 ft), Long Island Sound, New York Current	NOS	LIS1012_21	41.15917	-72.2075	:America/New_York	USA	knots	116	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 26.4 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.392	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Gut	NY
106849	Saybrook Breakwater Light (depth 19 ft), Long Island Sound, Connecticut Current	NOS	LIS1013_1	41.2582	-72.34207	:America/New_York	USA	knots	104	287	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saybrook Breakwater Light	CT
106850	Saybrook Breakwater Light (depth 14 ft), Long Island Sound, Connecticut Current	NOS	LIS1013_4	41.2582	-72.34207	:America/New_York	USA	knots	105	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saybrook Breakwater Light	CT
106851	Saybrook Breakwater Light (depth 5 ft), Long Island Sound, Connecticut Current	NOS	LIS1013_10	41.2582	-72.34207	:America/New_York	USA	knots	103	249	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saybrook Breakwater Light	CT
106852	I-95 Bridge (depth 23 ft), Connecticut River, Long Island Sound, Connecticut Current	NOS	LIS1014_1	41.3182	-72.34583	:America/New_York	USA	knots	182	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-95 Bridge	CT
106853	I-95 Bridge (depth 14 ft), Connecticut River, Long Island Sound, Connecticut Current	NOS	LIS1014_6	41.3182	-72.34583	:America/New_York	USA	knots	169	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-95 Bridge	CT
106854	I-95 Bridge (depth 3 ft), Connecticut River, Long Island Sound, Connecticut Current	NOS	LIS1014_13	41.3182	-72.34583	:America/New_York	USA	knots	166	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.447	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-95 Bridge	CT
106855	Saybrook Channel (depth 13 ft), Connecticut River, Long Island Sound, Connecticut Current	NOS	LIS1015_1	41.2833	-72.34757	:America/New_York	USA	knots	186	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saybrook Channel	CT
106856	Saybrook Channel (depth 2 ft), Connecticut River, Long Island Sound, Connecticut Current	NOS	LIS1015_8	41.2833	-72.34757	:America/New_York	USA	knots	180	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.343	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saybrook Channel	CT
106857	Cornfield Point, 4 mi south of, Buoy CF (depth 124 ft), New York Current	NOS	LIS1016_1	41.18945	-72.3696	:America/New_York	USA	knots	69	240	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cornfield Point, 4 miles south of, Buoy CF	NY
106858	Cornfield Point, 4 mi south of, Buoy CF (depth 71 ft), New York Current	NOS	LIS1016_9	41.18945	-72.3696	:America/New_York	USA	knots	67	244	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cornfield Point, 4 miles south of, Buoy CF	NY
106859	Cornfield Point, 4 mi south of, Buoy CF (depth 19 ft), New York Current	NOS	LIS1016_17	41.18945	-72.3696	:America/New_York	USA	knots	65	245	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.193	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cornfield Point, 4 miles south of, Buoy CF	NY
106860	Six Mile Reef, 2 mi south of, Buoy TE (depth 88 ft), Long Island Sound, New York Current	NOS	LIS1017_1	41.1345	-72.48927	:America/New_York	USA	knots	82	247	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.172	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six Mile Reef, 2 miles south of, Buoy TE	NY
106861	Six Mile Reef, 2 mi south of, Buoy TE (depth 49 ft), Long Island Sound, New York Current	NOS	LIS1017_7	41.1345	-72.48927	:America/New_York	USA	knots	74	252	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six Mile Reef, 2 miles south of, Buoy TE	NY
106862	Six Mile Reef, 2 mi south of, Buoy TE (depth 16 ft), Long Island Sound, New York Current	NOS	LIS1017_12	41.1345	-72.48927	:America/New_York	USA	knots	73	255	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six Mile Reef, 2 miles south of, Buoy TE	NY
106863	Six Mile Reef, 1 mi south of (depth 58 ft), Long Island Sound, New York Current	NOS	LIS1018_1	41.16835	-72.4994	:America/New_York	USA	knots	73	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six mile Reef, 1 mile south of	NY
106864	Six Mile Reef, 1 mi south of (depth 35 ft), Long Island Sound, New York Current	NOS	LIS1018_8	41.16835	-72.4994	:America/New_York	USA	knots	75	257	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six mile Reef, 1 mile south of	NY
106865	Six Mile Reef, 1 mi south of (depth 15 ft), Long Island Sound, New York Current	NOS	LIS1018_14	41.16835	-72.4994	:America/New_York	USA	knots	77	250	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six mile Reef, 1 mile south of	NY
106866	Six Mile Reef, 1 mi west of (depth 36 ft), Long Island Sound, Connecticut Current	NOS	LIS1019_1	41.17973	-72.55177	:America/New_York	USA	knots	87	278	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six Mile Reef, 1 mile west of	CT
106867	Six Mile Reef, 1 mi west of (depth 26 ft), Long Island Sound, Connecticut Current	NOS	LIS1019_4	41.17973	-72.55177	:America/New_York	USA	knots	86	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six Mile Reef, 1 mile west of	CT
106868	Six Mile Reef, 1 mi west of (depth 13 ft), Long Island Sound, Connecticut Current	NOS	LIS1019_8	41.17973	-72.55177	:America/New_York	USA	knots	87	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six Mile Reef, 1 mile west of	CT
106869	Roanoke Point, 2 mi NE of (depth 62 ft), Long Island Sound, New York Current	NOS	LIS1020_1	41.00697	-72.66322	:America/New_York	USA	knots	103	287	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roanoke Point, 2 miles NE of	NY
106870	Roanoke Point, 2 mi NE of (depth 39 ft), Long Island Sound, New York Current	NOS	LIS1020_8	41.00697	-72.66322	:America/New_York	USA	knots	106	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roanoke Point, 2 miles NE of	NY
106871	Roanoke Point, 2 mi NE of (depth 16 ft), Long Island Sound, New York Current	NOS	LIS1020_15	41.00697	-72.66322	:America/New_York	USA	knots	93	271	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roanoke Point, 2 miles NE of	NY
106872	Branford Reef, 5.0 mi south of (depth 69 ft), Long Island Sound, Connecticut Current	NOS	LIS1021_1	41.14443	-72.82798	:America/New_York	USA	knots	106	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Branford Reef, 5.0 miles south of	CT
106873	Branford Reef, 5.0 mi south of (depth 39 ft), Long Island Sound, Connecticut Current	NOS	LIS1021_10	41.14443	-72.82798	:America/New_York	USA	knots	96	273	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Branford Reef, 5.0 miles south of	CT
106874	Branford Reef, 5.0 mi south of (depth 6 ft), Long Island Sound, Connecticut Current	NOS	LIS1021_20	41.14443	-72.82798	:America/New_York	USA	knots	84	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Branford Reef, 5.0 miles south of	CT
106875	New Haven Harbor, Tanker Terminal (depth 30 ft), Long Island Sound, Connecticut Current	NOS	LIS1022_1	41.29507	-72.909	:America/New_York	USA	knots	\N	19	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor, Tanker Terminal	CT
106876	New Haven Harbor, Tanker Terminal (depth 21 ft), Long Island Sound, Connecticut Current	NOS	LIS1022_4	41.29507	-72.909	:America/New_York	USA	knots	209	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor, Tanker Terminal	CT
106877	New Haven Harbor, Tanker Terminal (depth 11 ft), Long Island Sound, Connecticut Current	NOS	LIS1022_7	41.29507	-72.909	:America/New_York	USA	knots	218	33.6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor, Tanker Terminal	CT
107539	Hood Canal Bridge (depth 22 ft), Washington Current	NOS	PUG1603_20	47.854740142822266	-122.6294174194336	:America/Los_Angeles	USA	knots	46	219	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Bridge	WA
106878	New Haven Harbor entrance (depth 31 ft), Long Island Sound, Connecticut Current	NOS	LIS1023_1	41.22238	-72.90932	:America/New_York	USA	knots	106	295	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor entrance	CT
106879	New Haven Harbor entrance (depth 14 ft), Long Island Sound, Connecticut Current	NOS	LIS1023_6	41.22238	-72.90932	:America/New_York	USA	knots	117	288	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor entrance	CT
106880	New Haven Harbor entrance (depth 4 ft), Long Island Sound, Connecticut Current	NOS	LIS1023_9	41.22238	-72.90932	:America/New_York	USA	knots	122	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor entrance	CT
106881	New Haven Harbor, Gateway Terminal approach (depth 31 ft), Connecticut Current	NOS	LIS1024_1	41.28267	-72.91197	:America/New_York	USA	knots	\N	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor, Gateway Terminal Approach	CT
106882	New Haven Harbor, Gateway Terminal approach (depth 18 ft), Connecticut Current	NOS	LIS1024_5	41.28267	-72.91197	:America/New_York	USA	knots	\N	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor, Gateway Terminal Approach	CT
106883	New Haven Harbor, Gateway Terminal approach (depth 8 ft), Connecticut Current	NOS	LIS1024_8	41.28267	-72.91197	:America/New_York	USA	knots	\N	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor, Gateway Terminal Approach	CT
106884	Port Jefferson Harbor entrance (depth 31 ft), Long Island Sound, New York Current	NOS	LIS1025_1	40.9699	-73.09165	:America/New_York	USA	knots	1	154	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.144	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Jefferson Harbor entrance	NY
106885	Port Jefferson Harbor entrance (depth 15 ft), Long Island Sound, New York Current	NOS	LIS1025_11	40.9699	-73.09165	:America/New_York	USA	knots	342	149	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Jefferson Harbor entrance	NY
106886	Port Jefferson Harbor entrance (depth 3 ft), Long Island Sound, New York Current	NOS	LIS1025_18	40.9699	-73.09165	:America/New_York	USA	knots	336	150	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Jefferson Harbor entrance	NY
106887	Stratford Point, 3.5 mi south of (depth 43 ft), Long Island Sound, Connecticut Current	NOS	LIS1026_1	41.08998	-73.10452	:America/New_York	USA	knots	67	249	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stratford Point, 3.5 miles south of	CT
106888	Stratford Point, 3.5 mi south of (depth 16 ft), Long Island Sound, Connecticut Current	NOS	LIS1026_9	41.08998	-73.10452	:America/New_York	USA	knots	71	251	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stratford Point, 3.5 miles south of	CT
106889	Stratford Point, 3.5 mi south of (depth 6 ft), Long Island Sound, Connecticut Current	NOS	LIS1026_12	41.08998	-73.10452	:America/New_York	USA	knots	70	247	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stratford Point, 3.5 miles south of	CT
106890	Stratford Shoal, 2 mi south of (depth 114 ft), Long Island Sound, New York Current	NOS	LIS1027_1	41.02297	-73.10477	:America/New_York	USA	knots	99	261	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stratford Shoal, 2 miles south of	NY
106891	Stratford Shoal, 2 mi south of (depth 68 ft), Long Island Sound, New York Current	NOS	LIS1027_8	41.02297	-73.10477	:America/New_York	USA	knots	93	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stratford Shoal, 2 miles south of	NY
106892	Stratford Shoal, 2 mi south of (depth 22 ft), Long Island Sound, New York Current	NOS	LIS1027_15	41.02297	-73.10477	:America/New_York	USA	knots	79	272	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stratford Shoal, 2 miles south of	NY
106893	Bridgeport Harbor, Tongue Point (depth 30 ft), Long Island Sound, Connecticut Current	NOS	LIS1028_1	41.16668	-73.17533	:America/New_York	USA	knots	\N	40	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport Harbor, Tongue Point	CT
106894	Bridgeport Harbor, Tongue Point (depth 15 ft), Long Island Sound, Connecticut Current	NOS	LIS1028_10	41.16668	-73.17533	:America/New_York	USA	knots	\N	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport Harbor, Tongue Point	CT
106895	Bridgeport Harbor, Tongue Point (depth 4 ft), Long Island Sound, Connecticut Current	NOS	LIS1028_17	41.16668	-73.17533	:America/New_York	USA	knots	\N	44.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport Harbor, Tongue Point	CT
106896	Bridgeport Harbor entrance (depth 31 ft), Long Island Sound, Connecticut Current	NOS	LIS1029_1	41.12138	-73.18945	:America/New_York	USA	knots	62	254	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport Harbor Entrance	CT
106897	Bridgeport Harbor entrance (depth 15 ft), Long Island Sound, Connecticut Current	NOS	LIS1029_11	41.12138	-73.18945	:America/New_York	USA	knots	58	256	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport Harbor Entrance	CT
106898	Bridgeport Harbor entrance (depth 5 ft), Long Island Sound, Connecticut Current	NOS	LIS1029_17	41.12138	-73.18945	:America/New_York	USA	knots	58	256	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport Harbor Entrance	CT
106899	Eatons Neck, 2.5 mi east of (depth 41 ft), Long Island Sound, New York Current	NOS	LIS1030_1	40.95742	-73.34198	:America/New_York	USA	knots	122	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck, 2.5 miles east of	NY
106900	Eatons Neck, 2.5 mi east of (depth 18 ft), Long Island Sound, New York Current	NOS	LIS1030_8	40.95742	-73.34198	:America/New_York	USA	knots	128	279	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck, 2.5 miles east of	NY
106901	Eatons Neck, 2.5 mi east of (depth 5 ft), Long Island Sound, New York Current	NOS	LIS1030_12	40.95742	-73.34198	:America/New_York	USA	knots	125	276	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck, 2.5 miles east of	NY
106902	Norwalk Harbor (depth 11 ft), Long Island Sound, Connecticut Current	NOS	LIS1031_1	41.08535	-73.4024	:America/New_York	USA	knots	151	329	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Norwalk Harbor	CT
106903	Norwalk Harbor (depth 2 ft), Long Island Sound, Connecticut Current	NOS	LIS1031_6	41.08535	-73.4024	:America/New_York	USA	knots	148	339	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Norwalk Harbor	CT
106904	Eatons Neck, 3 mi north of (depth 92 ft), Long Island Sound, Connecticut Current	NOS	LIS1032_1	41.00505	-73.405	:America/New_York	USA	knots	83	249	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck, 3 miles north of	CT
106905	Eatons Neck, 3 mi north of (depth 49 ft), Long Island Sound, Connecticut Current	NOS	LIS1032_14	41.00505	-73.405	:America/New_York	USA	knots	80	264	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck, 3 miles north of	CT
106906	Eatons Neck, 3 mi north of (depth 10 ft), Long Island Sound, Connecticut Current	NOS	LIS1032_26	41.00505	-73.405	:America/New_York	USA	knots	76	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck, 3 miles north of	CT
106907	The Cows, 2 mi SE of (depth 86 ft), Long Island Sound, Connecticut Current	NOS	LIS1033_1	40.98858	-73.49582	:America/New_York	USA	knots	81	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Cows, 2 miles SE of	CT
106908	The Cows, 2 mi SE of (depth 47 ft), Long Island Sound, Connecticut Current	NOS	LIS1033_7	40.98858	-73.49582	:America/New_York	USA	knots	80	253	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Cows, 2 miles SE of	CT
106909	The Cows, 2 mi SE of (depth 14 ft), Long Island Sound, Connecticut Current	NOS	LIS1033_12	40.98858	-73.49582	:America/New_York	USA	knots	72	243	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Cows, 2 miles SE of	CT
106910	Stamford Harbor entrance (depth 14 ft), Long Island Sound, Connecticut Current	NOS	LIS1034_1	41.01535	-73.53695	:America/New_York	USA	knots	174	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stamford Harbor entrance	CT
106911	Stamford Harbor entrance (depth 3 ft), Long Island Sound, Connecticut Current	NOS	LIS1034_8	41.01535	-73.53695	:America/New_York	USA	knots	175	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stamford Harbor entrance	CT
106912	Matinecock Point, 1.7 mi northwest of (depth 46 ft), Long Island Sound, New York Current	NOS	LIS1035_1	40.92455	-73.65585	:America/New_York	USA	knots	72	251	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matinecock Point, 1.7 miles northwest of	NY
106913	Matinecock Point, 1.7 mi northwest of (depth 30 ft), Long Island Sound, New York Current	NOS	LIS1035_6	40.92455	-73.65585	:America/New_York	USA	knots	63	244	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matinecock Point, 1.7 miles northwest of	NY
106914	Matinecock Point, 1.7 mi northwest of (depth 10 ft), Long Island Sound, New York Current	NOS	LIS1035_12	40.92455	-73.65585	:America/New_York	USA	knots	55	233	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matinecock Point, 1.7 miles northwest of	NY
106915	Execution Rocks (depth 96 ft), Long Island Sound, New York Current	NOS	LIS1036_1	40.87325	-73.7334	:America/New_York	USA	knots	219	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Execution Rocks	NY
106916	Execution Rocks (depth 50 ft), Long Island Sound, New York Current	NOS	LIS1036_8	40.87325	-73.7334	:America/New_York	USA	knots	232	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Execution Rocks	NY
106917	Execution Rocks (depth 11 ft), Long Island Sound, New York Current	NOS	LIS1036_14	40.87325	-73.7334	:America/New_York	USA	knots	232	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Execution Rocks	NY
106918	Hart Island, southeast of (depth 98 ft), Long Island Sound, New York Current	NOS	LIS1037_1	40.8432	-73.76225	:America/New_York	USA	knots	189	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.126	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hart Island, southeast of	NY
106919	Hart Island, southeast of (depth 59 ft), Long Island Sound, New York Current	NOS	LIS1037_7	40.8432	-73.76225	:America/New_York	USA	knots	194	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hart Island, southeast of	NY
106920	Hart Island, southeast of (depth 13 ft), Long Island Sound, New York Current	NOS	LIS1037_14	40.8432	-73.76225	:America/New_York	USA	knots	201	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hart Island, southeast of	NY
106921	Throgs Neck Bridge (depth 59 ft), Long Island Sound, New York Current	NOS	LIS1038_1	40.80105	-73.7921	:America/New_York	USA	knots	289	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Throgs Neck Bridge	NY
106922	Throgs Neck Bridge (depth 36 ft), Long Island Sound, New York Current	NOS	LIS1038_8	40.80105	-73.7921	:America/New_York	USA	knots	268	105	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Throgs Neck Bridge	NY
106923	Throgs Neck Bridge (depth 14 ft), Long Island Sound, New York Current	NOS	LIS1038_15	40.80105	-73.7921	:America/New_York	USA	knots	262	106	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Throgs Neck Bridge	NY
106924	Lake Worth Inlet entrance (depth 28 ft), Florida Current	NOS	LWI0901_1	26.77298	-80.0362	:America/New_York	USA	knots	85	268	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth Inlet Entrance	FL
106925	Lake Worth Inlet entrance (depth 15 ft), Florida Current	NOS	LWI0901_5	26.77298	-80.0362	:America/New_York	USA	knots	86	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth Inlet Entrance	FL
106926	Lake Worth Inlet entrance (depth 5 ft), Florida Current	NOS	LWI0901_8	26.77298	-80.0362	:America/New_York	USA	knots	92	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.172	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth Inlet Entrance	FL
106927	North Turning Basin (depth 8 ft), Lake Worth Inlet, Florida Current	NOS	LWI0904_1	26.77126	-80.0504	:America/New_York	USA	knots	168	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Turning Basin	FL
106928	North Turning Basin (depth 3 ft), Lake Worth Inlet, Florida Current	NOS	LWI0904_4	26.77126	-80.0504	:America/New_York	USA	knots	170	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Turning Basin	FL
106929	South Jetty (depth 38 ft), Government Cut, Miami Harbor, Florida Current	NOS	MIH0802_1	25.760429	-80.126877	:America/New_York	USA	knots	115	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Jetty	FL
106930	South Jetty (depth 15 ft), Government Cut, Miami Harbor, Florida Current	NOS	MIH0802_8	25.760429	-80.126877	:America/New_York	USA	knots	117	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Jetty	FL
106931	South Jetty (depth 9 ft), Government Cut, Miami Harbor, Florida Current	NOS	MIH0802_10	25.760429	-80.126877	:America/New_York	USA	knots	118	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Jetty	FL
106932	West entrance, south side (depth 34 ft), Government Cut, Miami Harbor, Florida Current	NOS	MIH0804_1	25.7646	-80.137428	:America/New_York	USA	knots	90	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West entrance, south side	FL
106933	West entrance, south side (depth 14 ft), Government Cut, Miami Harbor, Florida Current	NOS	MIH0804_7	25.7646	-80.137428	:America/New_York	USA	knots	94	289	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.408	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West entrance, south side	FL
106934	West entrance, south side (depth 4 ft), Government Cut, Miami Harbor, Florida Current	NOS	MIH0804_10	25.7646	-80.137428	:America/New_York	USA	knots	97	290	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.385	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West entrance, south side	FL
106935	Fisher Island Turning Basin (depth 36 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0805_1	25.767771	-80.143417	:America/New_York	USA	knots	111	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fisher Island Turning Basin	FL
106936	Fisher Island Turning Basin (depth 16 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0805_7	25.767771	-80.143417	:America/New_York	USA	knots	119	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fisher Island Turning Basin	FL
106937	Fisher Island Turning Basin (depth 9 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0805_9	25.767771	-80.143417	:America/New_York	USA	knots	123	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.207	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fisher Island Turning Basin	FL
106938	Pilot House (depth 31 ft), Fishermans Channel, Miami Harbor, Florida Current	NOS	MIH0806_1	25.765779	-80.145821	:America/New_York	USA	knots	85	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilot House	FL
106939	Pilot House (depth 14 ft), Fishermans Channel, Miami Harbor, Florida Current	NOS	MIH0806_6	25.765779	-80.145821	:America/New_York	USA	knots	86	255	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilot House	FL
106940	Pilot House (depth 5 ft), Fishermans Channel, Miami Harbor, Florida Current	NOS	MIH0806_9	25.765779	-80.145821	:America/New_York	USA	knots	86	255	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.207	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilot House	FL
106941	Norris Cut (depth 34 ft), Fishermans Channel, Miami Harbor, Florida Current	NOS	MIH0807_1	25.764971	-80.151131	:America/New_York	USA	knots	92	276	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Norris Cut	FL
106942	Norris Cut (depth 14 ft), Fishermans Channel, Miami Harbor, Florida Current	NOS	MIH0807_7	25.764971	-80.151131	:America/New_York	USA	knots	88	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Norris Cut	FL
106943	Norris Cut (depth 7 ft), Fishermans Channel, Miami Harbor, Florida Current	NOS	MIH0807_9	25.764971	-80.151131	:America/New_York	USA	knots	89	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Norris Cut	FL
106944	Main Ship Channel (depth 33 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0808_1	25.77335	-80.156921	:America/New_York	USA	knots	116	292	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Main Ship Channel	FL
106945	Main Ship Channel (depth 16 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0808_6	25.77335	-80.156921	:America/New_York	USA	knots	112	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Main Ship Channel	FL
106946	Main Ship Channel (depth 6 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0808_9	25.77335	-80.156921	:America/New_York	USA	knots	110	295	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Main Ship Channel	FL
106947	Lummus Island, SW corner (depth 14 ft), Fishermans Channel, Miami Harbor, Florida Current	NOS	MIH0809_2	25.765129	-80.161552	:America/New_York	USA	knots	89	269	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lummus Island, SW corner	FL
106948	Lummus Island, SW corner (depth 4 ft), Fishermans Channel, Miami Harbor, Florida Current	NOS	MIH0809_5	25.765129	-80.161552	:America/New_York	USA	knots	91	268	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lummus Island, SW corner	FL
106949	Lummus Island Turning Basin (depth 34 ft), Miami Harbor, Florida Current	NOS	MIH0810_1	25.767651	-80.167747	:America/New_York	USA	knots	60	260.1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lummus Island Turning Basin	FL
106950	Lummus Island Turning Basin (depth 14 ft), Miami Harbor, Florida Current	NOS	MIH0810_7	25.767651	-80.167747	:America/New_York	USA	knots	99	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lummus Island Turning Basin	FL
106951	Lummus Island Turning Basin (depth 7 ft), Miami Harbor, Florida Current	NOS	MIH0810_9	25.767651	-80.167747	:America/New_York	USA	knots	121	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lummus Island Turning Basin	FL
106952	Dodge Island Cut, west end (depth 28 ft), Miami Harbor, Florida Current	NOS	MIH0811_1	25.772949	-80.178497	:America/New_York	USA	knots	77	266	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island Cut, west end	FL
106953	Dodge Island Cut, west end (depth 15 ft), Miami Harbor, Florida Current	NOS	MIH0811_5	25.772949	-80.178497	:America/New_York	USA	knots	89	271	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island Cut, west end	FL
106954	Dodge Island Cut, west end (depth 5 ft), Miami Harbor, Florida Current	NOS	MIH0811_8	25.772949	-80.178497	:America/New_York	USA	knots	85	253	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island Cut, west end	FL
106955	Dodge Island, SE Turning Basin (depth 30 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0812_1	25.78178	-80.180603	:America/New_York	USA	knots	104	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island, SE Turning Basin	FL
106956	Dodge Island, SE Turning Basin (depth 14 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0812_6	25.78178	-80.180603	:America/New_York	USA	knots	119	307	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island, SE Turning Basin	FL
106957	Dodge Island, SE Turning Basin (depth 4 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0812_9	25.78178	-80.180603	:America/New_York	USA	knots	118	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island, SE Turning Basin	FL
106958	Dodge Island, NW Turning Basin (depth 30 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0813_1	25.7855	-80.183952	:America/New_York	USA	knots	\N	317.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island, NW Turning Basin	FL
106959	Dodge Island, NW Turning Basin (depth 17 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0813_5	25.7855	-80.183952	:America/New_York	USA	knots	163	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island, NW Turning Basin	FL
106960	Dodge Island, NW Turning Basin (depth 7 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0813_8	25.7855	-80.183952	:America/New_York	USA	knots	173	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.098	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island, NW Turning Basin	FL
106961	Miami River entrance (depth 12 ft), Miami Harbor, Florida Current	NOS	MIH0814_1	25.77038	-80.187477	:America/New_York	USA	knots	51	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami River Entrance	FL
106962	Miami River entrance (depth 2 ft), Miami Harbor, Florida Current	NOS	MIH0814_7	25.77038	-80.187477	:America/New_York	USA	knots	90	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami River Entrance	FL
106963	Miami Harbor entrance (depth 35 ft), Government Cut, Florida Current	NOS	MIH0901_1	25.76405	-80.13394	:America/New_York	USA	knots	115	292	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami Harbor Entrance	FL
106964	Miami Harbor entrance (depth 22 ft), Government Cut, Florida Current	NOS	MIH0901_5	25.76405	-80.13394	:America/New_York	USA	knots	113	292	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami Harbor Entrance	FL
106965	Miami Harbor entrance (depth 15 ft), Government Cut, Florida Current	NOS	MIH0901_7	25.76405	-80.13394	:America/New_York	USA	knots	113	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami Harbor Entrance	FL
106966	Miami Harbor entrance (depth 8 ft), Government Cut, Florida Current	NOS	MIH0901_9	25.76405	-80.13394	:America/New_York	USA	knots	114	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami Harbor Entrance	FL
106967	Mobile Bay entrance, off Mobile Point (depth 11 ft), Alabama Current	NOS	MOB1101_2	30.22703	-88.03458	:America/Chicago	USA	knots	201	14	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mobile Bay Entrance, off Mobile Point	AL
106968	Mobile Bay entrance, off Mobile Point (depth 25 ft), Alabama Current	NOS	MOB1101_10	30.22703	-88.03458	:America/Chicago	USA	knots	198	7	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mobile Bay Entrance, off Mobile Point	AL
106969	Mobile Bay entrance, off Mobile Point (depth 41 ft), Alabama Current	NOS	MOB1101_20	30.22703	-88.03458	:America/Chicago	USA	knots	205	357	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mobile Bay Entrance, off Mobile Point	AL
106970	Petit Bois Island, Dauphin Island, between (depth 5 ft), Alabama Current	NOS	MOB1104_3	30.22178	-88.3708	:America/Chicago	USA	knots	172	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Petit Bois Island, Dauphin Island, between	AL
106971	Horn Island, Petit Bois Island, between (depth 7 ft), Mississippi Current	NOS	MOB1105_3	30.22569	-88.53994	:America/Chicago	USA	knots	172	48	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horn Island, Petit Bois Island, between	MS
106972	Dauphin Island Causeway (depth 7 ft), Mobile Bay, Alabama Current	NOS	MOB1106_4	30.28926	-88.1287	:America/Chicago	USA	knots	242	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dauphin Island Causeway	AL
106973	Sandy Hook Channel, Front Range Light (depth 31 ft), New York Harbor, New Jersey Current	NOS	NYH1901_1	40.48740005493164	-73.99330139160156	:America/New_York	USA	knots	138	303	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandy Hook Channel, Front Range Light	NJ
106974	Sandy Hook Channel, Front Range Light (depth 15 ft), New York Harbor, New Jersey Current	NOS	NYH1901_6	40.48740005493164	-73.99330139160156	:America/New_York	USA	knots	132	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandy Hook Channel, Front Range Light	NJ
106975	Sandy Hook Channel, Front Range Light (depth 5 ft), New York Harbor, New Jersey Current	NOS	NYH1901_9	40.48740005493164	-73.99330139160156	:America/New_York	USA	knots	122	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.348	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandy Hook Channel, Front Range Light	NJ
106976	Chapel Hill Channel, south end (depth 7 ft), Sandy Hook Bay, New Jersey Current	NOS	NYH1902_1	40.475799560546875	-74.04969787597656	:America/New_York	USA	knots	57	254	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chapel Hill Channel, South End	NJ
106977	Chapel Hill Channel, south end (depth 18 ft), Sandy Hook Bay, New Jersey Current	NOS	NYH1902_4	40.475799560546875	-74.04969787597656	:America/New_York	USA	knots	49	257	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chapel Hill Channel, South End	NJ
106978	Chapel Hill Channel, south end (depth 21 ft), Sandy Hook Bay, New Jersey Current	NOS	NYH1902_5	40.475799560546875	-74.04969787597656	:America/New_York	USA	knots	48	262	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chapel Hill Channel, South End	NJ
106979	Ambrose Channel (depth 28 ft), New York Harbor entrance, New Jersey Current	NOS	NYH1903_1	40.516700744628906	-73.97470092773438	:America/New_York	USA	knots	119	290	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ambrose Channel	NJ
106980	Ambrose Channel (depth 15 ft), New York Harbor entrance, New Jersey Current	NOS	NYH1903_9	40.516700744628906	-73.97470092773438	:America/New_York	USA	knots	121	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.242	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ambrose Channel	NJ
106981	Ambrose Channel (depth 5 ft), New York Harbor entrance, New Jersey Current	NOS	NYH1903_15	40.516700744628906	-73.97470092773438	:America/New_York	USA	knots	118	299	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.364	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ambrose Channel	NJ
106982	Rockaway Inlet Jetty, 1 nmi SW of (depth 40 ft), Jamaica Bay, New York Current	NOS	NYH1904_1	40.53300094604492	-73.96080017089844	:America/New_York	USA	knots	120	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockaway Inlet Jetty, 1 nm SW of	NY
106983	Rockaway Inlet Jetty, 1 nmi SW of (depth 17 ft), Jamaica Bay, New York Current	NOS	NYH1904_8	40.53300094604492	-73.96080017089844	:America/New_York	USA	knots	144	307	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockaway Inlet Jetty, 1 nm SW of	NY
106984	Rockaway Inlet Jetty, 1 nmi SW of (depth 7 ft), Jamaica Bay, New York Current	NOS	NYH1904_11	40.53300094604492	-73.96080017089844	:America/New_York	USA	knots	139	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockaway Inlet Jetty, 1 nm SW of	NY
106985	Rockaway Inlet entrance (depth 23 ft), Jamaica Bay, New York Current	NOS	NYH1905_1	40.562198638916016	-73.9365005493164	:America/New_York	USA	knots	243	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockaway Inlet Entrance	NY
106986	Rockaway Inlet entrance (depth 14 ft), Jamaica Bay, New York Current	NOS	NYH1905_6	40.562198638916016	-73.9365005493164	:America/New_York	USA	knots	243	77	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.184	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockaway Inlet Entrance	NY
106987	Rockaway Inlet entrance (depth 5 ft), Jamaica Bay, New York Current	NOS	NYH1905_12	40.562198638916016	-73.9365005493164	:America/New_York	USA	knots	244	79	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockaway Inlet Entrance	NY
106988	Ward Point Bend (depth 7 ft), Raritan Bay, New York Current	NOS	NYH1906_1	40.493099212646484	-74.25070190429688	:America/New_York	USA	knots	135	309	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ward Point Bend	NY
106989	Ward Point Bend (depth 15 ft), Raritan Bay, New York Current	NOS	NYH1906_3	40.493099212646484	-74.25070190429688	:America/New_York	USA	knots	141	307	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ward Point Bend	NY
106990	Ward Point Bend (depth 28 ft), Raritan Bay, New York Current	NOS	NYH1906_7	40.493099212646484	-74.25070190429688	:America/New_York	USA	knots	145	311	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ward Point Bend	NY
106991	Tremley Point (depth 27 ft), Arthur Kill, New York Current	NOS	NYH1908_2	40.58890151977539	-74.20600128173828	:America/New_York	USA	knots	205	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tremley Point	NY
106992	Tremley Point (depth 7 ft), Arthur Kill, New York Current	NOS	NYH1908_8	40.58890151977539	-74.20600128173828	:America/New_York	USA	knots	211	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tremley Point	NY
106993	Gulfport, Arthur Kill (depth 21 ft), New Jersey Current	NOS	NYH1909_6	40.62889862060547	-74.20320129394531	:America/New_York	USA	knots	202	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulfport, Arthur Kill	NJ
106994	Gulfport, Arthur Kill (depth 8 ft), New Jersey Current	NOS	NYH1909_10	40.62889862060547	-74.20320129394531	:America/New_York	USA	knots	197	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulfport, Arthur Kill	NJ
106995	Middle Reach, Newark Bay (depth 30 ft), New Jersey Current	NOS	NYH1913_4	40.676300048828125	-74.13520050048828	:America/New_York	USA	knots	210	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Reach, Newark Bay	NJ
106996	Middle Reach, Newark Bay (depth 7 ft), New Jersey Current	NOS	NYH1913_11	40.676300048828125	-74.13520050048828	:America/New_York	USA	knots	197	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Reach, Newark Bay	NJ
106997	Constable Hook approach (depth 35 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1914_1	40.650699615478516	-74.06060028076172	:America/New_York	USA	knots	215	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Constable Hook Approach	NY
106998	Constable Hook approach (depth 15 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1914_7	40.650699615478516	-74.06060028076172	:America/New_York	USA	knots	213	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Constable Hook Approach	NY
106999	Constable Hook approach (depth 9 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1914_9	40.650699615478516	-74.06060028076172	:America/New_York	USA	knots	211	29	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.292	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Constable Hook Approach	NY
107000	Robbins Reef Light, 0.6 nmi E of (depth 11 ft), New York Harbor, New York Current	NOS	NYH1915_2	40.65520095825195	-74.05069732666016	:America/New_York	USA	knots	208	12	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.215	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robbins Reef Light, 0.6 nm E of	NY
107001	Robbins Reef Light, 0.6 nmi E of (depth 24 ft), New York Harbor, New York Current	NOS	NYH1915_6	40.65520095825195	-74.05069732666016	:America/New_York	USA	knots	205	9	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robbins Reef Light, 0.6 nm E of	NY
107002	Robbins Reef Light, 0.6 nmi E of (depth 37 ft), New York Harbor, New York Current	NOS	NYH1915_10	40.65520095825195	-74.05069732666016	:America/New_York	USA	knots	207	14	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.162	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robbins Reef Light, 0.6 nm E of	NY
107003	Gowanus Bay entrance (depth 28 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1917_1	40.662498474121094	-74.01809692382812	:America/New_York	USA	knots	171	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gowanus Bay Entrance	NY
107004	Gowanus Bay entrance (depth 15 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1917_5	40.662498474121094	-74.01809692382812	:America/New_York	USA	knots	168	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gowanus Bay Entrance	NY
107005	Red Hook Channel (depth 3 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1918_1	40.672298431396484	-74.0239028930664	:America/New_York	USA	knots	167	16	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Hook Channel	NY
107006	Red Hook Channel (depth 21 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1918_6	40.672298431396484	-74.0239028930664	:America/New_York	USA	knots	141	333	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Hook Channel	NY
107007	Red Hook Channel (depth 31 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1918_9	40.672298431396484	-74.0239028930664	:America/New_York	USA	knots	138	326	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Hook Channel	NY
107008	Dimond Reef (depth 11 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1919_3	40.697898864746094	-74.02130126953125	:America/New_York	USA	knots	137	10	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.536	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dimond Reef	NY
107009	Dimond Reef (depth 18 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1919_5	40.697898864746094	-74.02130126953125	:America/New_York	USA	knots	159	11	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.514	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dimond Reef	NY
107010	Dimond Reef (depth 31 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1919_9	40.697898864746094	-74.02130126953125	:America/New_York	USA	knots	279	23	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.355	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dimond Reef	NY
107011	Brooklyn Bridge (depth 44 ft), East River, New York Current	NOS	NYH1920_1	40.70600128173828	-73.9977035522461	:America/New_York	USA	knots	225	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.105	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Bridge	NY
107012	Brooklyn Bridge (depth 14 ft), East River, New York Current	NOS	NYH1920_10	40.70600128173828	-73.9977035522461	:America/New_York	USA	knots	233	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.109	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Bridge	NY
107013	Brooklyn Bridge (depth 8 ft), East River, New York Current	NOS	NYH1920_12	40.70600128173828	-73.9977035522461	:America/New_York	USA	knots	234	47	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Bridge	NY
107014	Corlears Hook (depth 39 ft), East River, New York Current	NOS	NYH1921_1	40.70949935913086	-73.97640228271484	:America/New_York	USA	knots	250	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Corlears Hook	NY
107015	Corlears Hook (depth 16 ft), East River, New York Current	NOS	NYH1921_8	40.70949935913086	-73.97640228271484	:America/New_York	USA	knots	239	70	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Corlears Hook	NY
107016	Corlears Hook (depth 7 ft), East River, New York Current	NOS	NYH1921_11	40.70949935913086	-73.97640228271484	:America/New_York	USA	knots	237	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Corlears Hook	NY
107017	Newtown Creek (depth 28 ft), East River, New York Current	NOS	NYH1922_1	40.73469924926758	-73.9656982421875	:America/New_York	USA	knots	178	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newtown Creek	NY
107018	Newtown Creek (depth 15 ft), East River, New York Current	NOS	NYH1922_5	40.73469924926758	-73.9656982421875	:America/New_York	USA	knots	180	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newtown Creek	NY
107019	Newtown Creek (depth 5 ft), East River, New York Current	NOS	NYH1922_8	40.73469924926758	-73.9656982421875	:America/New_York	USA	knots	181	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.208	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newtown Creek	NY
107020	Hell Gate (depth 32 ft), East River, New York Current	NOS	NYH1924_1	40.77830123901367	-73.93830108642578	:America/New_York	USA	knots	232	50	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.356	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hell Gate	NY
107021	Hell Gate (depth 15 ft), East River, New York Current	NOS	NYH1924_6	40.77830123901367	-73.93830108642578	:America/New_York	USA	knots	239	46	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.393	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hell Gate	NY
107022	Hell Gate (depth 6 ft), East River, New York Current	NOS	NYH1924_9	40.77830123901367	-73.93830108642578	:America/New_York	USA	knots	241	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.417	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hell Gate	NY
107023	Harlem River, south end (depth 5 ft), New York Current	NOS	NYH1926_5	40.78609848022461	-73.93689727783203	:America/New_York	USA	knots	33	210	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harlem River, south end	NY
107024	Hudson River entrance (depth 43 ft), Hudson River (midchannel), New Jersey Current	NOS	NYH1927_2	40.70759963989258	-74.02529907226562	:America/New_York	USA	knots	184	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.249	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson River Entrance	NJ
107025	Hudson River entrance (depth 23 ft), Hudson River (midchannel), New Jersey Current	NOS	NYH1927_8	40.70759963989258	-74.02529907226562	:America/New_York	USA	knots	185	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson River Entrance	NJ
107026	Hudson River entrance (depth 7 ft), Hudson River (midchannel), New Jersey Current	NOS	NYH1927_13	40.70759963989258	-74.02529907226562	:America/New_York	USA	knots	183	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.396	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson River Entrance	NJ
107027	Hudson River, Pier 92 (depth 35 ft), Hudson River (midchannel), New York Current	NOS	NYH1928_3	40.77069854736328	-74.00279998779297	:America/New_York	USA	knots	209	34	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson River, Pier 92	NY
107028	Hudson River, Pier 92 (depth 19 ft), Hudson River (midchannel), New York Current	NOS	NYH1928_8	40.77069854736328	-74.00279998779297	:America/New_York	USA	knots	211	28	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson River, Pier 92	NY
107029	Hudson River, Pier 92 (depth 6 ft), Hudson River (midchannel), New York Current	NOS	NYH1928_12	40.77069854736328	-74.00279998779297	:America/New_York	USA	knots	212	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.453	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson River, Pier 92	NY
107030	Spuyten Duyvil (depth 45 ft), Hudson River (midchannel), New York Current	NOS	NYH1930_3	40.877899169921875	-73.92870330810547	:America/New_York	USA	knots	215	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spuyten Duyvil	NY
107031	Spuyten Duyvil (depth 29 ft), Hudson River (midchannel), New York Current	NOS	NYH1930_8	40.877899169921875	-73.92870330810547	:America/New_York	USA	knots	223	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spuyten Duyvil	NY
107032	Spuyten Duyvil (depth 9 ft), Hudson River (midchannel), New York Current	NOS	NYH1930_14	40.877899169921875	-73.92870330810547	:America/New_York	USA	knots	215	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.246	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spuyten Duyvil	NY
107033	Marine Parkway Bridge, Rockaway Inlet (depth 30 ft), Jamaica Bay, New York Current	NOS	NYH1931_6	40.57149887084961	-73.88369750976562	:America/New_York	USA	knots	266	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marine Parkway Bridge, Rockaway Inlet	NY
107034	Marine Parkway Bridge, Rockaway Inlet (depth 15 ft), Jamaica Bay, New York Current	NOS	NYH1931_15	40.57149887084961	-73.88369750976562	:America/New_York	USA	knots	265	76	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marine Parkway Bridge, Rockaway Inlet	NY
107035	Marine Parkway Bridge, Rockaway Inlet (depth 6 ft), Jamaica Bay, New York Current	NOS	NYH1931_21	40.57149887084961	-73.88369750976562	:America/New_York	USA	knots	257	77	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marine Parkway Bridge, Rockaway Inlet	NY
107036	Raritan River entrance, Victory Bridge (depth 14 ft), New Jersey Current	NOS	NYH1932_9	40.50920104980469	-74.29060363769531	:America/New_York	USA	knots	134	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raritan River Entrance, Victory Bridge	NJ
107037	Raritan River entrance, Victory Bridge (depth 3 ft), New Jersey Current	NOS	NYH1932_16	40.50920104980469	-74.29060363769531	:America/New_York	USA	knots	133	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raritan River Entrance, Victory Bridge	NJ
107038	Highlands Bridge, Shrewsbury River (depth 16 ft), New Jersey Current	NOS	NYH1933_5	40.396400451660156	-73.97979736328125	:America/New_York	USA	knots	357	178	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 67.3 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Highlands Bridge, Shrewsbury River	NJ
107039	Canarsie (midchannel), Jamaica Bay (depth 15 ft), New York Current	NOS	NYH1934_9	40.62699890136719	-73.88200378417969	:America/New_York	USA	knots	252	83	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Canarsie (midchannel), Jamaica Bay	NY
107040	Canarsie (midchannel), Jamaica Bay (depth 5 ft), New York Current	NOS	NYH1934_15	40.62699890136719	-73.88200378417969	:America/New_York	USA	knots	255	85	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Canarsie (midchannel), Jamaica Bay	NY
107041	San Diego Bay entrance (depth 33 ft), California Current	NOS	PCT0031_1	32.68170166015625	-117.2300033569336	:America/Los_Angeles	USA	knots	173	355	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Diego Bay Entrance	CA
107042	Oakland, Yerba Buena Island (depth 13 ft), San Francisco Bay, California Current	NOS	PCT0336_1	37.80979919433594	-122.35070037841797	:America/Los_Angeles	USA	knots	338	167	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.126	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland, Yerba Buena Island	CA
107043	Richmond (depth 14 ft), San Francisco Bay, California Current	NOS	PCT0666_2	37.929298400878906	-122.42500305175781	:America/Los_Angeles	USA	knots	147	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond	CA
107044	Grays Harbor entrance (depth 12 ft), Washington Current	NOS	PCT1291_1	46.92250061035156	-124.13300323486328	:America/Los_Angeles	USA	knots	242	61	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grays Harbor Entrance	WA
107045	Kvichak Bay (off Naknek River entrance) (depth 10 ft), Alaska Current	NOS	PCT5776_1	58.70000076293945	-157.25	:America/Anchorage	USA	knots	239	53	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kvichak Bay (off Naknek River entrance)	AK
107046	Snub Point, Penobscot River (depth 26 ft), Maine Current	NOS	PEB0604_1	44.70945	-68.84107	:America/New_York	USA	knots	176	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snub Point, Penobscot River	ME
107047	Snub Point, Penobscot River (depth 17 ft), Maine Current	NOS	PEB0604_4	44.70945	-68.84107	:America/New_York	USA	knots	179	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snub Point, Penobscot River	ME
107048	Snub Point, Penobscot River (depth 7 ft), Maine Current	NOS	PEB0604_7	44.70945	-68.84107	:America/New_York	USA	knots	182	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.304	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snub Point, Penobscot River	ME
107049	Winterport, Penobscot River (depth 14 ft), Maine Current	NOS	PEB0605_1	44.63132	-68.8424	:America/New_York	USA	knots	210	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.241	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Winterport, Penobscot River	ME
107050	Winterport, Penobscot River (depth 7 ft), Maine Current	NOS	PEB0605_3	44.63132	-68.8424	:America/New_York	USA	knots	212	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Winterport, Penobscot River	ME
107051	Frankfort Flats at Marsh River, Penobscot River (depth 11 ft), Maine Current	NOS	PEB0606_1	44.6049	-68.84673	:America/New_York	USA	knots	109	273	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Frankfort Flats at Marsh River, Penobscot River	ME
107052	Bucksport, Penobscot River (depth 45 ft), Maine Current	NOS	PEB0607_2	44.57132	-68.8077	:America/New_York	USA	knots	123	300	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bucksport, Penobscot River	ME
107053	Bucksport, Penobscot River (depth 32 ft), Maine Current	NOS	PEB0607_4	44.57132	-68.8077	:America/New_York	USA	knots	118	290	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bucksport, Penobscot River	ME
107054	Bucksport, Penobscot River (depth 12 ft), Maine Current	NOS	PEB0607_7	44.57132	-68.8077	:America/New_York	USA	knots	113	292	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.115	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bucksport, Penobscot River	ME
107055	Penobscot Narrows Bridge (depth 36 ft), Maine Current	NOS	PEB0608_1	44.56227	-68.80053	:America/New_York	USA	knots	201	29	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.306	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Penobscot Narrows Bridge	ME
107056	Penobscot Narrows Bridge (depth 26 ft), Maine Current	NOS	PEB0608_4	44.56227	-68.80053	:America/New_York	USA	knots	201	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Penobscot Narrows Bridge	ME
107057	Penobscot Narrows Bridge (depth 13 ft), Maine Current	NOS	PEB0608_8	44.56227	-68.80053	:America/New_York	USA	knots	210	34	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Penobscot Narrows Bridge	ME
107058	Odom Ledge, Penobscot River (depth 29 ft), Maine Current	NOS	PEB0609_4	44.51673	-68.80317	:America/New_York	USA	knots	193	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.363	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Odom Ledge, Penobscot River	ME
107059	Odom Ledge, Penobscot River (depth 16 ft), Maine Current	NOS	PEB0609_6	44.51673	-68.80317	:America/New_York	USA	knots	177	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Odom Ledge, Penobscot River	ME
107060	Fort Point Ledge, Penobscot Bay (depth 71 ft), Maine Current	NOS	PEB0610_1	44.46425	-68.81155	:America/New_York	USA	knots	273	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.377	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point Ledge, Penobscot Bay	ME
107061	Fort Point Ledge, Penobscot Bay (depth 45 ft), Maine Current	NOS	PEB0610_5	44.46425	-68.81155	:America/New_York	USA	knots	258	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.242	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point Ledge, Penobscot Bay	ME
107062	Fort Point Ledge, Penobscot Bay (depth 25 ft), Maine Current	NOS	PEB0610_8	44.46425	-68.81155	:America/New_York	USA	knots	248	53	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point Ledge, Penobscot Bay	ME
107063	Hosmer Ledge, Castine Harbor (depth 52 ft), Maine Current	NOS	PEB0611_1	44.38345	-68.79	:America/New_York	USA	knots	245	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hosmer Ledge, Castine Harbor	ME
107064	Hosmer Ledge, Castine Harbor (depth 33 ft), Maine Current	NOS	PEB0611_4	44.38345	-68.79	:America/New_York	USA	knots	241	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hosmer Ledge, Castine Harbor	ME
107065	Hosmer Ledge, Castine Harbor (depth 13 ft), Maine Current	NOS	PEB0611_7	44.38345	-68.79	:America/New_York	USA	knots	240	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hosmer Ledge, Castine Harbor	ME
107066	Port Everglades entrance (depth 35 ft), Florida Current	NOS	PEV0901_1	26.09318	-80.10549	:America/New_York	USA	knots	77	251	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Everglades Entrance	FL
107067	Port Everglades entrance (depth 22 ft), Florida Current	NOS	PEV0901_5	26.09318	-80.10549	:America/New_York	USA	knots	75	255	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Everglades Entrance	FL
107068	Port Everglades entrance (depth 16 ft), Florida Current	NOS	PEV0901_7	26.09318	-80.10549	:America/New_York	USA	knots	75	257	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Everglades Entrance	FL
107069	Port Everglades entrance (depth 9 ft), Florida Current	NOS	PEV0901_9	26.09318	-80.10549	:America/New_York	USA	knots	77	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Everglades Entrance	FL
107070	Turning Basin (depth 34 ft), Port Everglades, Florida Current	NOS	PEV0902_1	26.09486	-80.11741	:America/New_York	USA	knots	\N	339.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turning Basin	FL
107071	Turning Basin (depth 14 ft), Port Everglades, Florida Current	NOS	PEV0902_7	26.09486	-80.11741	:America/New_York	USA	knots	\N	333.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turning Basin	FL
107072	Turning Basin (depth 4 ft), Port Everglades, Florida Current	NOS	PEV0902_10	26.09486	-80.11741	:America/New_York	USA	knots	173	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turning Basin	FL
107073	17th Street Bridge (depth 12 ft), Port Everglades, Florida Current	NOS	PEV0903_1	26.09973	-80.1191	:America/New_York	USA	knots	184	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	17th Street Bridge	FL
107074	17th Street Bridge (depth 9 ft), Port Everglades, Florida Current	NOS	PEV0903_2	26.09973	-80.1191	:America/New_York	USA	knots	184	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	17th Street Bridge	FL
107075	17th Street Bridge (depth 6 ft), Port Everglades, Florida Current	NOS	PEV0903_3	26.09973	-80.1191	:America/New_York	USA	knots	184	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	17th Street Bridge	FL
107076	South entrance (ICW) (depth 31 ft), Port Everglades, Florida Current	NOS	PEV0904_1	26.08733	-80.11312	:America/New_York	USA	knots	351	168	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Entrance (ICW)	FL
107077	South entrance (ICW) (depth 15 ft), Port Everglades, Florida Current	NOS	PEV0904_7	26.08733	-80.11312	:America/New_York	USA	knots	350	171	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 11.3 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Entrance (ICW)	FL
107078	South entrance (ICW) (depth 5 ft), Port Everglades, Florida Current	NOS	PEV0904_9	26.08733	-80.11312	:America/New_York	USA	knots	353	173	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Entrance (ICW)	FL
107079	South Port, at the terminals (depth 26 ft), Port Everglades, Florida Current	NOS	PEV0905_1	26.0744	-80.11385	:America/New_York	USA	knots	355	175	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Port, at the terminals	FL
107080	South Port, at the terminals (depth 16 ft), Port Everglades, Florida Current	NOS	PEV0905_4	26.0744	-80.11385	:America/New_York	USA	knots	356	175	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Port, at the terminals	FL
107081	South Port, at the terminals (depth 6 ft), Port Everglades, Florida Current	NOS	PEV0905_7	26.0744	-80.11385	:America/New_York	USA	knots	356	175	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Port, at the terminals	FL
107082	Portsmouth Harbor entrance (depth 44 ft), New Hampshire Current	NOS	PIR0701_1	43.06237	-70.70532	:America/New_York	USA	knots	178	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portsmouth Harbor Entrance	NH
107083	Portsmouth Harbor entrance (depth 25 ft), New Hampshire Current	NOS	PIR0701_7	43.06237	-70.70532	:America/New_York	USA	knots	196	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portsmouth Harbor Entrance	NH
107084	Portsmouth Harbor entrance (depth 8 ft), New Hampshire Current	NOS	PIR0701_12	43.06237	-70.70532	:America/New_York	USA	knots	194	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portsmouth Harbor Entrance	NH
107085	Fort Point (depth 39 ft), Portsmouth Harbor, Maine Current	NOS	PIR0702_1	43.0745	-70.70675	:America/New_York	USA	knots	138	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.341	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	ME
107086	Fort Point (depth 19 ft), Portsmouth Harbor, Maine Current	NOS	PIR0702_7	43.0745	-70.70675	:America/New_York	USA	knots	104	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	ME
107087	Fort Point (depth 6 ft), Portsmouth Harbor, Maine Current	NOS	PIR0702_11	43.0745	-70.70675	:America/New_York	USA	knots	98	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.211	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	ME
107088	Little Harbor entrance (depth 12 ft), Portsmouth Harbor, New Hampshire Current	NOS	PIR0703_1	43.0554	-70.71568	:America/New_York	USA	knots	122	316	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Little Harbor entrance	NH
107089	Little Harbor entrance (depth 3 ft), Portsmouth Harbor, New Hampshire Current	NOS	PIR0703_7	43.0554	-70.71568	:America/New_York	USA	knots	107	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Little Harbor entrance	NH
107090	Henderson Point, west of (depth 59 ft), Portsmouth Harbor, Maine Current	NOS	PIR0704_1	43.07488	-70.73838	:America/New_York	USA	knots	160	340	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Henderson Point, west of	ME
107091	Henderson Point, west of (depth 32 ft), Portsmouth Harbor, Maine Current	NOS	PIR0704_9	43.07488	-70.73838	:America/New_York	USA	knots	147	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Henderson Point, west of	ME
107092	Henderson Point, west of (depth 10 ft), Portsmouth Harbor, Maine Current	NOS	PIR0704_16	43.07488	-70.73838	:America/New_York	USA	knots	138	285	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Henderson Point, west of	ME
107093	Memorial Bridge (depth 58 ft), Maine Current	NOS	PIR0705_1	43.07938	-70.75208	:America/New_York	USA	knots	93	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Memorial Bridge	ME
107094	Memorial Bridge (depth 31 ft), Maine Current	NOS	PIR0705_9	43.07938	-70.75208	:America/New_York	USA	knots	101	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Memorial Bridge	ME
107095	Memorial Bridge (depth 8 ft), Maine Current	NOS	PIR0705_16	43.07938	-70.75208	:America/New_York	USA	knots	105	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Memorial Bridge	ME
107096	Sara Long Bridge (depth 33 ft), Maine Current	NOS	PIR0706_1	43.0887	-70.76198	:America/New_York	USA	knots	158	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sara Long Bridge	ME
107097	Sara Long Bridge (depth 19 ft), Maine Current	NOS	PIR0706_5	43.0887	-70.76198	:America/New_York	USA	knots	155	332	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.225	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sara Long Bridge	ME
107098	Sara Long Bridge (depth 6 ft), Maine Current	NOS	PIR0706_9	43.0887	-70.76198	:America/New_York	USA	knots	153	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.309	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sara Long Bridge	ME
107099	I-95 Bridge (depth 48 ft), New Hampshire Current	NOS	PIR0707_1	43.09282	-70.76708	:America/New_York	USA	knots	142	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-95 Bridge	NH
107100	I-95 Bridge (depth 29 ft), New Hampshire Current	NOS	PIR0707_7	43.09282	-70.76708	:America/New_York	USA	knots	129	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-95 Bridge	NH
107101	I-95 Bridge (depth 6 ft), New Hampshire Current	NOS	PIR0707_14	43.09282	-70.76708	:America/New_York	USA	knots	123	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.391	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-95 Bridge	NH
107102	Schiller Station (depth 52 ft), New Hampshire Current	NOS	PIR0708_1	43.09738	-70.78108	:America/New_York	USA	knots	168	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Schiller Station	NH
107103	Schiller Station (depth 29 ft), New Hampshire Current	NOS	PIR0708_8	43.09738	-70.78108	:America/New_York	USA	knots	162	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Schiller Station	NH
107104	Schiller Station (depth 9 ft), New Hampshire Current	NOS	PIR0708_14	43.09738	-70.78108	:America/New_York	USA	knots	157	329	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Schiller Station	NH
107105	Frankfort Island, south of (depth 37 ft), New Hampshire Current	NOS	PIR0709_1	43.11412	-70.80525	:America/New_York	USA	knots	129	303	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Frankfort Island, south of	NH
107106	Frankfort Island, south of (depth 24 ft), New Hampshire Current	NOS	PIR0709_5	43.11412	-70.80525	:America/New_York	USA	knots	130	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Frankfort Island, south of	NH
107107	Frankfort Island, south of (depth 7 ft), New Hampshire Current	NOS	PIR0709_10	43.11412	-70.80525	:America/New_York	USA	knots	130	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Frankfort Island, south of	NH
107108	General Sullivan Bridge (depth 15 ft), New Hampshire Current	NOS	PIR0710_1	43.11785	-70.82608	:America/New_York	USA	knots	71	243	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	General Sullivan Bridge	NH
107109	General Sullivan Bridge (depth 8 ft), New Hampshire Current	NOS	PIR0710_5	43.11785	-70.82608	:America/New_York	USA	knots	75	238	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	General Sullivan Bridge	NH
107110	General Sullivan Bridge (depth 3 ft), New Hampshire Current	NOS	PIR0710_8	43.11785	-70.82608	:America/New_York	USA	knots	78	238	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	General Sullivan Bridge	NH
107111	Furber Strait (depth 25 ft), New Hampshire Current	NOS	PIR0711_1	43.09112	-70.86135	:America/New_York	USA	knots	1	198	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Furber Strait	NH
107112	Furber Strait (depth 14 ft), New Hampshire Current	NOS	PIR0711_8	43.09112	-70.86135	:America/New_York	USA	knots	7	200	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Furber Strait	NH
107113	Furber Strait (depth 4 ft), New Hampshire Current	NOS	PIR0711_14	43.09112	-70.86135	:America/New_York	USA	knots	15	201	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Furber Strait	NH
107114	Agate Passage, south end (depth 25 ft), Puget Sound, Washington Current	NOS	PUG1501_1	47.711021423339844	-122.56714630126953	:America/Los_Angeles	USA	knots	21	200	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
107115	Agate Passage, south end (depth 22 ft), Puget Sound, Washington Current	NOS	PUG1501_2	47.711021423339844	-122.56714630126953	:America/Los_Angeles	USA	knots	\N	200.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
107116	Agate Passage, south end (depth 19 ft), Puget Sound, Washington Current	NOS	PUG1501_3	47.711021423339844	-122.56714630126953	:America/Los_Angeles	USA	knots	\N	200.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
107117	Agate Passage, south end (depth 15 ft), Puget Sound, Washington Current	NOS	PUG1501_4	47.711021423339844	-122.56714630126953	:America/Los_Angeles	USA	knots	\N	200	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
107118	Agate Passage, south end (depth 12 ft), Puget Sound, Washington Current	NOS	PUG1501_5	47.711021423339844	-122.56714630126953	:America/Los_Angeles	USA	knots	\N	199.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
107119	Agate Passage, south end (depth 9 ft), Puget Sound, Washington Current	NOS	PUG1501_6	47.711021423339844	-122.56714630126953	:America/Los_Angeles	USA	knots	16	203	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
107120	Agate Passage, south end (depth 5 ft), Puget Sound, Washington Current	NOS	PUG1501_7	47.711021423339844	-122.56714630126953	:America/Los_Angeles	USA	knots	\N	199.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
107121	Agate Passage, south end (depth 2 ft), Puget Sound, Washington Current	NOS	PUG1501_8	47.711021423339844	-122.56714630126953	:America/Los_Angeles	USA	knots	\N	198.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
107122	Alki Point, 1 mi west of (depth 641 ft), Puget Sound, Washington Current	NOS	PUG1502_1	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107123	Alki Point, 1 mi west of (depth 627 ft), Puget Sound, Washington Current	NOS	PUG1502_2	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107124	Alki Point, 1 mi west of (depth 614 ft), Puget Sound, Washington Current	NOS	PUG1502_3	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107125	Alki Point, 1 mi west of (depth 601 ft), Puget Sound, Washington Current	NOS	PUG1502_4	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	186.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107126	Alki Point, 1 mi west of (depth 588 ft), Puget Sound, Washington Current	NOS	PUG1502_5	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	186.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107127	Alki Point, 1 mi west of (depth 575 ft), Puget Sound, Washington Current	NOS	PUG1502_6	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	186.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.145	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107128	Alki Point, 1 mi west of (depth 562 ft), Puget Sound, Washington Current	NOS	PUG1502_7	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107129	Alki Point, 1 mi west of (depth 549 ft), Puget Sound, Washington Current	NOS	PUG1502_8	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107130	Alki Point, 1 mi west of (depth 536 ft), Puget Sound, Washington Current	NOS	PUG1502_9	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107131	Alki Point, 1 mi west of (depth 522 ft), Puget Sound, Washington Current	NOS	PUG1502_10	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107132	Alki Point, 1 mi west of (depth 509 ft), Puget Sound, Washington Current	NOS	PUG1502_11	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	188.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107133	Alki Point, 1 mi west of (depth 496 ft), Puget Sound, Washington Current	NOS	PUG1502_12	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	188.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107134	Alki Point, 1 mi west of (depth 483 ft), Puget Sound, Washington Current	NOS	PUG1502_13	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	8	189	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107135	Alki Point, 1 mi west of (depth 470 ft), Puget Sound, Washington Current	NOS	PUG1502_14	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	189.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107136	Alki Point, 1 mi west of (depth 457 ft), Puget Sound, Washington Current	NOS	PUG1502_15	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	190.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107137	Alki Point, 1 mi west of (depth 444 ft), Puget Sound, Washington Current	NOS	PUG1502_16	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	190.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107138	Alki Point, 1 mi west of (depth 431 ft), Puget Sound, Washington Current	NOS	PUG1502_17	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	190.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107139	Alki Point, 1 mi west of (depth 417 ft), Puget Sound, Washington Current	NOS	PUG1502_18	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	190.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107140	Alki Point, 1 mi west of (depth 404 ft), Puget Sound, Washington Current	NOS	PUG1502_19	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	191	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107141	Alki Point, 1 mi west of (depth 391 ft), Puget Sound, Washington Current	NOS	PUG1502_20	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	191	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107142	Alki Point, 1 mi west of (depth 378 ft), Puget Sound, Washington Current	NOS	PUG1502_21	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	190.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107143	Alki Point, 1 mi west of (depth 365 ft), Puget Sound, Washington Current	NOS	PUG1502_22	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	190.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107144	Alki Point, 1 mi west of (depth 352 ft), Puget Sound, Washington Current	NOS	PUG1502_23	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	190	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107145	Alki Point, 1 mi west of (depth 339 ft), Puget Sound, Washington Current	NOS	PUG1502_24	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	189.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107146	Alki Point, 1 mi west of (depth 326 ft), Puget Sound, Washington Current	NOS	PUG1502_25	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	189	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107147	Alki Point, 1 mi west of (depth 312 ft), Puget Sound, Washington Current	NOS	PUG1502_26	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	188.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107148	Alki Point, 1 mi west of (depth 299 ft), Puget Sound, Washington Current	NOS	PUG1502_27	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107149	Alki Point, 1 mi west of (depth 286 ft), Puget Sound, Washington Current	NOS	PUG1502_28	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107150	Alki Point, 1 mi west of (depth 273 ft), Puget Sound, Washington Current	NOS	PUG1502_29	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	186.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107151	Alki Point, 1 mi west of (depth 260 ft), Puget Sound, Washington Current	NOS	PUG1502_30	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	185.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107152	Alki Point, 1 mi west of (depth 247 ft), Puget Sound, Washington Current	NOS	PUG1502_31	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	184.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107153	Alki Point, 1 mi west of (depth 234 ft), Puget Sound, Washington Current	NOS	PUG1502_32	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	183.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107154	Alki Point, 1 mi west of (depth 221 ft), Puget Sound, Washington Current	NOS	PUG1502_33	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	182.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107155	Alki Point, 1 mi west of (depth 207 ft), Puget Sound, Washington Current	NOS	PUG1502_34	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	182.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107156	Alki Point, 1 mi west of (depth 194 ft), Puget Sound, Washington Current	NOS	PUG1502_35	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	359	187	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107157	Alki Point, 1 mi west of (depth 181 ft), Puget Sound, Washington Current	NOS	PUG1502_36	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	181.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107158	Alki Point, 1 mi west of (depth 168 ft), Puget Sound, Washington Current	NOS	PUG1502_37	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	182.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107159	Alki Point, 1 mi west of (depth 155 ft), Puget Sound, Washington Current	NOS	PUG1502_38	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	184.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107160	Alki Point, 1 mi west of (depth 142 ft), Puget Sound, Washington Current	NOS	PUG1502_39	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	188	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107161	Alki Point, 1 mi west of (depth 129 ft), Puget Sound, Washington Current	NOS	PUG1502_40	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	191.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107162	Alki Point, 1 mi west of (depth 116 ft), Puget Sound, Washington Current	NOS	PUG1502_41	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	195.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.247	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107163	Alki Point, 1 mi west of (depth 102 ft), Puget Sound, Washington Current	NOS	PUG1502_42	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	199.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.277	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107164	Alki Point, 1 mi west of (depth 89 ft), Puget Sound, Washington Current	NOS	PUG1502_43	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	205.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.305	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107165	Alki Point, 1 mi west of (depth 76 ft), Puget Sound, Washington Current	NOS	PUG1502_44	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	31	201	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.325	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107166	Alki Point, 1 mi west of (depth 63 ft), Puget Sound, Washington Current	NOS	PUG1502_45	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	216.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.337	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107167	Alki Point, 1 mi west of (depth 50 ft), Puget Sound, Washington Current	NOS	PUG1502_46	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	221	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.335	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
107168	Edmonds, 2.5 mi west of (depth 500 ft), Puget Sound, Washington Current	NOS	PUG1503_1	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	162.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107169	Edmonds, 2.5 mi west of (depth 487 ft), Puget Sound, Washington Current	NOS	PUG1503_2	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	162.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107170	Edmonds, 2.5 mi west of (depth 474 ft), Puget Sound, Washington Current	NOS	PUG1503_3	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.164	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107171	Edmonds, 2.5 mi west of (depth 461 ft), Puget Sound, Washington Current	NOS	PUG1503_4	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107172	Edmonds, 2.5 mi west of (depth 448 ft), Puget Sound, Washington Current	NOS	PUG1503_5	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107173	Edmonds, 2.5 mi west of (depth 435 ft), Puget Sound, Washington Current	NOS	PUG1503_6	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.145	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107174	Edmonds, 2.5 mi west of (depth 422 ft), Puget Sound, Washington Current	NOS	PUG1503_7	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107175	Edmonds, 2.5 mi west of (depth 409 ft), Puget Sound, Washington Current	NOS	PUG1503_8	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107176	Edmonds, 2.5 mi west of (depth 395 ft), Puget Sound, Washington Current	NOS	PUG1503_9	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107177	Edmonds, 2.5 mi west of (depth 382 ft), Puget Sound, Washington Current	NOS	PUG1503_10	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107178	Edmonds, 2.5 mi west of (depth 369 ft), Puget Sound, Washington Current	NOS	PUG1503_11	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107179	Edmonds, 2.5 mi west of (depth 356 ft), Puget Sound, Washington Current	NOS	PUG1503_12	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107180	Edmonds, 2.5 mi west of (depth 343 ft), Puget Sound, Washington Current	NOS	PUG1503_13	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107181	Edmonds, 2.5 mi west of (depth 330 ft), Puget Sound, Washington Current	NOS	PUG1503_14	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107182	Edmonds, 2.5 mi west of (depth 317 ft), Puget Sound, Washington Current	NOS	PUG1503_15	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	346	167	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107183	Edmonds, 2.5 mi west of (depth 304 ft), Puget Sound, Washington Current	NOS	PUG1503_16	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107184	Edmonds, 2.5 mi west of (depth 290 ft), Puget Sound, Washington Current	NOS	PUG1503_17	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107185	Edmonds, 2.5 mi west of (depth 277 ft), Puget Sound, Washington Current	NOS	PUG1503_18	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107186	Edmonds, 2.5 mi west of (depth 264 ft), Puget Sound, Washington Current	NOS	PUG1503_19	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107187	Edmonds, 2.5 mi west of (depth 251 ft), Puget Sound, Washington Current	NOS	PUG1503_20	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107188	Edmonds, 2.5 mi west of (depth 238 ft), Puget Sound, Washington Current	NOS	PUG1503_21	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107189	Edmonds, 2.5 mi west of (depth 225 ft), Puget Sound, Washington Current	NOS	PUG1503_22	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	165	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107190	Edmonds, 2.5 mi west of (depth 212 ft), Puget Sound, Washington Current	NOS	PUG1503_23	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	165.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107191	Edmonds, 2.5 mi west of (depth 199 ft), Puget Sound, Washington Current	NOS	PUG1503_24	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	166.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107192	Edmonds, 2.5 mi west of (depth 185 ft), Puget Sound, Washington Current	NOS	PUG1503_25	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	166.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107193	Edmonds, 2.5 mi west of (depth 172 ft), Puget Sound, Washington Current	NOS	PUG1503_26	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	167.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107194	Edmonds, 2.5 mi west of (depth 159 ft), Puget Sound, Washington Current	NOS	PUG1503_27	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	167.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107195	Edmonds, 2.5 mi west of (depth 146 ft), Puget Sound, Washington Current	NOS	PUG1503_28	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	168.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107196	Edmonds, 2.5 mi west of (depth 133 ft), Puget Sound, Washington Current	NOS	PUG1503_29	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	355	161	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107197	Edmonds, 2.5 mi west of (depth 120 ft), Puget Sound, Washington Current	NOS	PUG1503_30	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	169.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107198	Edmonds, 2.5 mi west of (depth 107 ft), Puget Sound, Washington Current	NOS	PUG1503_31	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	170.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107199	Edmonds, 2.5 mi west of (depth 94 ft), Puget Sound, Washington Current	NOS	PUG1503_32	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	171.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107200	Edmonds, 2.5 mi west of (depth 80 ft), Puget Sound, Washington Current	NOS	PUG1503_33	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	172.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107201	Edmonds, 2.5 mi west of (depth 67 ft), Puget Sound, Washington Current	NOS	PUG1503_34	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	358	161	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.226	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107202	Edmonds, 2.5 mi west of (depth 54 ft), Puget Sound, Washington Current	NOS	PUG1503_35	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	173.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.248	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
107203	Eagle Harbor entrance (depth 32 ft), Puget Sound, Washington Current	NOS	PUG1505_1	47.619571685791016	-122.49530029296875	:America/Los_Angeles	USA	knots	\N	328	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance to Eagle Harbor	WA
107204	Eagle Harbor entrance (depth 9 ft), Puget Sound, Washington Current	NOS	PUG1505_8	47.619571685791016	-122.49530029296875	:America/Los_Angeles	USA	knots	137	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance to Eagle Harbor	WA
107205	Harbor Island West (depth 48 ft), Puget Sound, Washington Current	NOS	PUG1507_1	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	189.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
107206	Harbor Island West (depth 45 ft), Puget Sound, Washington Current	NOS	PUG1507_2	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	187	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
107207	Harbor Island West (depth 41 ft), Puget Sound, Washington Current	NOS	PUG1507_3	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	185.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
107238	Port Washington Narrows, Warren Ave. Bridge (depth 4 ft), Washington Current	NOS	PUG1510_6	47.57957077026367	-122.63065338134766	:America/Los_Angeles	USA	knots	99	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Washington Narrows, Warren Ave. Bridge	WA
107208	Harbor Island West (depth 38 ft), Puget Sound, Washington Current	NOS	PUG1507_4	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	183.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
107209	Harbor Island West (depth 35 ft), Puget Sound, Washington Current	NOS	PUG1507_5	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	182.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.112	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
107210	Harbor Island West (depth 31 ft), Puget Sound, Washington Current	NOS	PUG1507_6	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	181	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
107211	Harbor Island West (depth 28 ft), Puget Sound, Washington Current	NOS	PUG1507_7	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	179.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
107212	Harbor Island West (depth 25 ft), Puget Sound, Washington Current	NOS	PUG1507_8	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	178.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
107213	Harbor Island West (depth 22 ft), Puget Sound, Washington Current	NOS	PUG1507_9	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	356	177	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
107214	Harbor Island West (depth 18 ft), Puget Sound, Washington Current	NOS	PUG1507_10	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	178.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
107215	Harbor Island West (depth 15 ft), Puget Sound, Washington Current	NOS	PUG1507_11	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	180.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
107216	Harbor Island West (depth 12 ft), Puget Sound, Washington Current	NOS	PUG1507_12	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	180.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
107217	Harbor Island West (depth 9 ft), Puget Sound, Washington Current	NOS	PUG1507_13	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	1	178	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
107218	Liberty Bay (entrance), Port Orchard (depth 37 ft), Puget Sound, Washington Current	NOS	PUG1508_1	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	110	296	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
107219	Liberty Bay (entrance), Port Orchard (depth 33 ft), Puget Sound, Washington Current	NOS	PUG1508_2	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	\N	293	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
107220	Liberty Bay (entrance), Port Orchard (depth 30 ft), Puget Sound, Washington Current	NOS	PUG1508_3	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	\N	293.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
107221	Liberty Bay (entrance), Port Orchard (depth 27 ft), Puget Sound, Washington Current	NOS	PUG1508_4	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	\N	293.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
107222	Liberty Bay (entrance), Port Orchard (depth 24 ft), Puget Sound, Washington Current	NOS	PUG1508_5	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	124	288	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
107223	Liberty Bay (entrance), Port Orchard (depth 20 ft), Puget Sound, Washington Current	NOS	PUG1508_6	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	\N	295.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
107224	Liberty Bay (entrance), Port Orchard (depth 17 ft), Puget Sound, Washington Current	NOS	PUG1508_7	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	\N	295.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
107225	Liberty Bay (entrance), Port Orchard (depth 14 ft), Puget Sound, Washington Current	NOS	PUG1508_8	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	\N	296.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
107226	Liberty Bay (entrance), Port Orchard (depth 10 ft), Puget Sound, Washington Current	NOS	PUG1508_9	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	\N	297	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
107227	Liberty Bay (entrance), Port Orchard (depth 7 ft), Puget Sound, Washington Current	NOS	PUG1508_10	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	313	287	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
107228	Point Jefferson, east of (depth 71 ft), Puget Sound, Washington Current	NOS	PUG1509_1	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	14	212	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
107229	Point Jefferson, east of (depth 65 ft), Puget Sound, Washington Current	NOS	PUG1509_2	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	\N	203.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
107230	Point Jefferson, east of (depth 58 ft), Puget Sound, Washington Current	NOS	PUG1509_3	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	\N	205.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
107231	Point Jefferson, east of (depth 51 ft), Puget Sound, Washington Current	NOS	PUG1509_4	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	\N	206.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
107232	Point Jefferson, east of (depth 45 ft), Puget Sound, Washington Current	NOS	PUG1509_5	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	21	214	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
107233	Point Jefferson, east of (depth 38 ft), Puget Sound, Washington Current	NOS	PUG1509_6	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	\N	209.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
107234	Point Jefferson, east of (depth 32 ft), Puget Sound, Washington Current	NOS	PUG1509_7	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	\N	211.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
107235	Point Jefferson, east of (depth 25 ft), Puget Sound, Washington Current	NOS	PUG1509_8	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	\N	212.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.176	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
107236	Point Jefferson, east of (depth 19 ft), Puget Sound, Washington Current	NOS	PUG1509_9	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	31	217	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
107237	Port Washington Narrows, Warren Ave. Bridge (depth 21 ft), Washington Current	NOS	PUG1510_1	47.57957077026367	-122.63065338134766	:America/Los_Angeles	USA	knots	102	279	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Washington Narrows, Warren Ave. Bridge	WA
107239	President Point, 1.5 mi east of (depth 308 ft), Puget Sound, Washington Current	NOS	PUG1511_20	47.76712	-122.4319	:America/Los_Angeles	USA	knots	331	161	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Point, 1.5 miles east of	WA
107240	President Point, 1.5 mi east of (depth 176 ft), Puget Sound, Washington Current	NOS	PUG1511_30	47.76712	-122.4319	:America/Los_Angeles	USA	knots	341	158	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Point, 1.5 miles east of	WA
107241	President Point, 1.5 mi east of (depth 71 ft), Puget Sound, Washington Current	NOS	PUG1511_38	47.76712	-122.4319	:America/Los_Angeles	USA	knots	3	177	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Point, 1.5 miles east of	WA
107242	Restoration Point (depth 140 ft), Puget Sound, Washington Current	NOS	PUG1512_1	47.57884979248047	-122.46871948242188	:America/Los_Angeles	USA	knots	45	151	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Restoration Point	WA
107243	Restoration Point (depth 81 ft), Puget Sound, Washington Current	NOS	PUG1512_10	47.57884979248047	-122.46871948242188	:America/Los_Angeles	USA	knots	42	142	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.246	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Restoration Point	WA
107244	Restoration Point (depth 22 ft), Puget Sound, Washington Current	NOS	PUG1512_19	47.57884979248047	-122.46871948242188	:America/Los_Angeles	USA	knots	52	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.429	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Restoration Point	WA
107245	Rich Passage, east end (depth 70 ft), Puget Sound, Washington Current	NOS	PUG1513_1	47.57001876831055	-122.52980041503906	:America/Los_Angeles	USA	knots	108	314	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, East end	WA
107246	Rich Passage, east end (depth 38 ft), Puget Sound, Washington Current	NOS	PUG1513_6	47.57001876831055	-122.52980041503906	:America/Los_Angeles	USA	knots	127	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, East end	WA
107247	Rich Passage, east end (depth 11 ft), Puget Sound, Washington Current	NOS	PUG1513_10	47.57001876831055	-122.52980041503906	:America/Los_Angeles	USA	knots	139	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, East end	WA
107248	Rich Passage, west end (depth 57 ft), Puget Sound, Washington Current	NOS	PUG1514_1	47.58993148803711	-122.56233215332031	:America/Los_Angeles	USA	knots	53	235	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.112	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, West end	WA
107249	Rich Passage, west end (depth 51 ft), Puget Sound, Washington Current	NOS	PUG1514_2	47.58993148803711	-122.56233215332031	:America/Los_Angeles	USA	knots	\N	234.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, West end	WA
107250	Rich Passage, west end (depth 44 ft), Puget Sound, Washington Current	NOS	PUG1514_3	47.58993148803711	-122.56233215332031	:America/Los_Angeles	USA	knots	\N	235.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, West end	WA
107251	Rich Passage, west end (depth 38 ft), Puget Sound, Washington Current	NOS	PUG1514_4	47.58993148803711	-122.56233215332031	:America/Los_Angeles	USA	knots	\N	235.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, West end	WA
107252	Rich Passage, west end (depth 31 ft), Puget Sound, Washington Current	NOS	PUG1514_5	47.58993148803711	-122.56233215332031	:America/Los_Angeles	USA	knots	55	238	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, West end	WA
107253	Rich Passage, west end (depth 25 ft), Puget Sound, Washington Current	NOS	PUG1514_6	47.58993148803711	-122.56233215332031	:America/Los_Angeles	USA	knots	\N	236.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, West end	WA
107254	Rich Passage, west end (depth 18 ft), Puget Sound, Washington Current	NOS	PUG1514_7	47.58993148803711	-122.56233215332031	:America/Los_Angeles	USA	knots	\N	236.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, West end	WA
107255	Rich Passage, west end (depth 12 ft), Puget Sound, Washington Current	NOS	PUG1514_8	47.58993148803711	-122.56233215332031	:America/Los_Angeles	USA	knots	55	239	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, West end	WA
107256	West Point, west of (depth 108 ft), Puget Sound, Washington Current	NOS	PUG1515_1	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	21	228	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
107257	West Point, west of (depth 101 ft), Puget Sound, Washington Current	NOS	PUG1515_2	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	218.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
107258	West Point, west of (depth 95 ft), Puget Sound, Washington Current	NOS	PUG1515_3	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	218.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.188	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
107259	West Point, west of (depth 88 ft), Puget Sound, Washington Current	NOS	PUG1515_4	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	217.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
107260	West Point, west of (depth 81 ft), Puget Sound, Washington Current	NOS	PUG1515_5	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	217.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.192	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
107261	West Point, west of (depth 75 ft), Puget Sound, Washington Current	NOS	PUG1515_6	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	217.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.193	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
107262	West Point, west of (depth 68 ft), Puget Sound, Washington Current	NOS	PUG1515_7	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	217.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
107263	West Point, west of (depth 62 ft), Puget Sound, Washington Current	NOS	PUG1515_8	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	217.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.193	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
107264	West Point, west of (depth 55 ft), Puget Sound, Washington Current	NOS	PUG1515_9	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	216.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
107265	West Point, west of (depth 49 ft), Puget Sound, Washington Current	NOS	PUG1515_10	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	357	230	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
107266	West Point, west of (depth 42 ft), Puget Sound, Washington Current	NOS	PUG1515_11	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	215.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.178	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
107267	West Point, west of (depth 35 ft), Puget Sound, Washington Current	NOS	PUG1515_12	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	214.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
107268	West Point, west of (depth 29 ft), Puget Sound, Washington Current	NOS	PUG1515_13	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	213.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
107269	West Point, west of (depth 22 ft), Puget Sound, Washington Current	NOS	PUG1515_14	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	212.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
107270	West Point, west of (depth 16 ft), Puget Sound, Washington Current	NOS	PUG1515_15	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	341	234	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
107271	Alki Point, west of (depth 195 ft), Puget Sound, Washington Current	NOS	PUG1516_5	47.57606887817383	-122.4278335571289	:America/Los_Angeles	USA	knots	4	200	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, West of	WA
107272	Alki Point, west of (depth 103 ft), Puget Sound, Washington Current	NOS	PUG1516_12	47.57606887817383	-122.4278335571289	:America/Los_Angeles	USA	knots	6	213	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, West of	WA
107273	Alki Point, west of (depth 38 ft), Puget Sound, Washington Current	NOS	PUG1516_17	47.57606887817383	-122.4278335571289	:America/Los_Angeles	USA	knots	4	215	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, West of	WA
107274	Blake Island, S of (depth 241 ft), Puget Sound, Washington Current	NOS	PUG1517_1	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	161.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.372	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107275	Blake Island, S of (depth 231 ft), Puget Sound, Washington Current	NOS	PUG1517_2	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	164.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.392	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107276	Blake Island, S of (depth 221 ft), Puget Sound, Washington Current	NOS	PUG1517_3	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	166.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.407	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107277	Blake Island, S of (depth 211 ft), Puget Sound, Washington Current	NOS	PUG1517_4	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	168.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107278	Blake Island, S of (depth 201 ft), Puget Sound, Washington Current	NOS	PUG1517_5	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	170.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.432	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107279	Blake Island, S of (depth 191 ft), Puget Sound, Washington Current	NOS	PUG1517_6	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	172.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.444	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107280	Blake Island, S of (depth 182 ft), Puget Sound, Washington Current	NOS	PUG1517_7	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	173.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.454	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107281	Blake Island, S of (depth 172 ft), Puget Sound, Washington Current	NOS	PUG1517_8	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	350	218	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.465	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107282	Blake Island, S of (depth 162 ft), Puget Sound, Washington Current	NOS	PUG1517_9	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	176.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.476	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107283	Blake Island, S of (depth 152 ft), Puget Sound, Washington Current	NOS	PUG1517_10	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	177.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.488	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107284	Blake Island, S of (depth 142 ft), Puget Sound, Washington Current	NOS	PUG1517_11	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	177.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107285	Blake Island, S of (depth 132 ft), Puget Sound, Washington Current	NOS	PUG1517_12	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	178.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.512	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107286	Blake Island, S of (depth 122 ft), Puget Sound, Washington Current	NOS	PUG1517_13	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	179	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.524	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107287	Blake Island, S of (depth 113 ft), Puget Sound, Washington Current	NOS	PUG1517_14	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	179.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.538	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107288	Blake Island, S of (depth 103 ft), Puget Sound, Washington Current	NOS	PUG1517_15	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	179.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.551	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107289	Blake Island, S of (depth 93 ft), Puget Sound, Washington Current	NOS	PUG1517_16	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	349	237	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.564	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107290	Blake Island, S of (depth 83 ft), Puget Sound, Washington Current	NOS	PUG1517_17	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	179.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107291	Blake Island, S of (depth 73 ft), Puget Sound, Washington Current	NOS	PUG1517_18	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	179.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.588	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107292	Blake Island, S of (depth 63 ft), Puget Sound, Washington Current	NOS	PUG1517_19	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	180.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.599	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107293	Blake Island, S of (depth 54 ft), Puget Sound, Washington Current	NOS	PUG1517_20	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	180.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.607	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107294	Blake Island, S of (depth 44 ft), Puget Sound, Washington Current	NOS	PUG1517_21	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	350	244	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.612	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107295	Blake Island, S of (depth 34 ft), Puget Sound, Washington Current	NOS	PUG1517_22	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	186.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.562	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
107296	Anderson Point, east of, Colvos Passage (depth 154 ft), Puget Sound, Washington Current	NOS	PUG1518_10	47.43943	-122.52578	:America/Los_Angeles	USA	knots	351	181	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.524	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anderson Point, East of, Colvos Passage	WA
107297	Anderson Point, east of, Colvos Passage (depth 62 ft), Puget Sound, Washington Current	NOS	PUG1518_17	47.43943	-122.52578	:America/Los_Angeles	USA	knots	353	185	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.548	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anderson Point, East of, Colvos Passage	WA
107298	Anderson Point, east of, Colvos Passage (depth 35 ft), Puget Sound, Washington Current	NOS	PUG1518_19	47.43943	-122.52578	:America/Los_Angeles	USA	knots	356	183	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.537	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anderson Point, East of, Colvos Passage	WA
107299	Point Richmond, east of, Colvos Passage (depth 241 ft), Puget Sound, Washington Current	NOS	PUG1519_3	47.37662124633789	-122.52867126464844	:America/Los_Angeles	USA	knots	4	157	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.498	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, East of, Colvos Passage	WA
107300	Point Richmond, east of, Colvos Passage (depth 110 ft), Puget Sound, Washington Current	NOS	PUG1519_13	47.37662124633789	-122.52867126464844	:America/Los_Angeles	USA	knots	359	162	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.589	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, East of, Colvos Passage	WA
107301	Point Richmond, east of, Colvos Passage (depth 44 ft), Puget Sound, Washington Current	NOS	PUG1519_18	47.37662124633789	-122.52867126464844	:America/Los_Angeles	USA	knots	356	143	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.571	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, East of, Colvos Passage	WA
107302	Dolphin Point, 1.3 mi east of (depth 218 ft), Puget Sound, Washington Current	NOS	PUG1520_22	47.501548767089844	-122.42357635498047	:America/Los_Angeles	USA	knots	\N	178.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolphin Point, 1.3 miles East of	WA
107303	Dolphin Point, 1.3 mi east of (depth 139 ft), Puget Sound, Washington Current	NOS	PUG1520_28	47.501548767089844	-122.42357635498047	:America/Los_Angeles	USA	knots	343	184	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolphin Point, 1.3 miles East of	WA
107304	Dolphin Point, 1.3 mi east of (depth 48 ft), Puget Sound, Washington Current	NOS	PUG1520_35	47.501548767089844	-122.42357635498047	:America/Los_Angeles	USA	knots	343	186	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolphin Point, 1.3 miles East of	WA
107305	Browns Point, 1.6 mi north of (depth 461 ft), Puget Sound, Washington Current	NOS	PUG1521_1	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	225	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.203	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107306	Browns Point, 1.6 mi north of (depth 448 ft), Puget Sound, Washington Current	NOS	PUG1521_2	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	224.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.208	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107307	Browns Point, 1.6 mi north of (depth 435 ft), Puget Sound, Washington Current	NOS	PUG1521_3	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	223.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.211	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107308	Browns Point, 1.6 mi north of (depth 422 ft), Puget Sound, Washington Current	NOS	PUG1521_4	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	223.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.208	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107309	Browns Point, 1.6 mi north of (depth 408 ft), Puget Sound, Washington Current	NOS	PUG1521_5	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	224	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107310	Browns Point, 1.6 mi north of (depth 395 ft), Puget Sound, Washington Current	NOS	PUG1521_6	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	224.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.214	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107311	Browns Point, 1.6 mi north of (depth 382 ft), Puget Sound, Washington Current	NOS	PUG1521_7	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	224.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.218	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107312	Browns Point, 1.6 mi north of (depth 369 ft), Puget Sound, Washington Current	NOS	PUG1521_8	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	225	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.221	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107313	Browns Point, 1.6 mi north of (depth 356 ft), Puget Sound, Washington Current	NOS	PUG1521_9	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	225.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.222	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107314	Browns Point, 1.6 mi north of (depth 343 ft), Puget Sound, Washington Current	NOS	PUG1521_10	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	225.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.221	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107315	Browns Point, 1.6 mi north of (depth 330 ft), Puget Sound, Washington Current	NOS	PUG1521_11	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	226.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.218	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107316	Browns Point, 1.6 mi north of (depth 317 ft), Puget Sound, Washington Current	NOS	PUG1521_12	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	227	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.212	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107317	Browns Point, 1.6 mi north of (depth 303 ft), Puget Sound, Washington Current	NOS	PUG1521_13	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	227.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.204	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107318	Browns Point, 1.6 mi north of (depth 290 ft), Puget Sound, Washington Current	NOS	PUG1521_14	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	47	228	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107319	Browns Point, 1.6 mi north of (depth 277 ft), Puget Sound, Washington Current	NOS	PUG1521_15	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	230.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.184	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107320	Browns Point, 1.6 mi north of (depth 264 ft), Puget Sound, Washington Current	NOS	PUG1521_16	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	232.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.174	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107321	Browns Point, 1.6 mi north of (depth 251 ft), Puget Sound, Washington Current	NOS	PUG1521_17	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	233.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107322	Browns Point, 1.6 mi north of (depth 238 ft), Puget Sound, Washington Current	NOS	PUG1521_18	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	234.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107323	Browns Point, 1.6 mi north of (depth 225 ft), Puget Sound, Washington Current	NOS	PUG1521_19	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	234.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107324	Browns Point, 1.6 mi north of (depth 212 ft), Puget Sound, Washington Current	NOS	PUG1521_20	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	235.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107325	Browns Point, 1.6 mi north of (depth 199 ft), Puget Sound, Washington Current	NOS	PUG1521_21	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	235	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107326	Browns Point, 1.6 mi north of (depth 185 ft), Puget Sound, Washington Current	NOS	PUG1521_22	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	234.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107457	Drayton Passage (depth 52 ft), Puget Sound, Washington Current	NOS	PUG1537_15	47.17258071899414	-122.7414779663086	:America/Los_Angeles	USA	knots	23	210	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drayton Passage	WA
107327	Browns Point, 1.6 mi north of (depth 172 ft), Puget Sound, Washington Current	NOS	PUG1521_23	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	234	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107328	Browns Point, 1.6 mi north of (depth 159 ft), Puget Sound, Washington Current	NOS	PUG1521_24	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	49	232	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107329	Browns Point, 1.6 mi north of (depth 146 ft), Puget Sound, Washington Current	NOS	PUG1521_25	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	230.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107330	Browns Point, 1.6 mi north of (depth 133 ft), Puget Sound, Washington Current	NOS	PUG1521_26	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	229	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107331	Browns Point, 1.6 mi north of (depth 120 ft), Puget Sound, Washington Current	NOS	PUG1521_27	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	227.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.145	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107332	Browns Point, 1.6 mi north of (depth 107 ft), Puget Sound, Washington Current	NOS	PUG1521_28	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	226.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107333	Browns Point, 1.6 mi north of (depth 94 ft), Puget Sound, Washington Current	NOS	PUG1521_29	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	227.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107334	Browns Point, 1.6 mi north of (depth 80 ft), Puget Sound, Washington Current	NOS	PUG1521_30	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	228.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107335	Browns Point, 1.6 mi north of (depth 67 ft), Puget Sound, Washington Current	NOS	PUG1521_31	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	229.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.191	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107336	Browns Point, 1.6 mi north of (depth 54 ft), Puget Sound, Washington Current	NOS	PUG1521_32	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	230.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107337	Browns Point, 1.6 mi north of (depth 41 ft), Puget Sound, Washington Current	NOS	PUG1521_33	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	232.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.209	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107338	Browns Point, 1.6 mi north of (depth 28 ft), Puget Sound, Washington Current	NOS	PUG1521_34	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	42	234	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.205	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
107339	Dalco Passage (depth 187 ft), Puget Sound, Washington Current	NOS	PUG1522_3	47.32511901855469	-122.5246810913086	:America/Los_Angeles	USA	knots	124	288	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.278	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
107340	Dalco Passage (depth 128 ft), Puget Sound, Washington Current	NOS	PUG1522_12	47.32511901855469	-122.5246810913086	:America/Los_Angeles	USA	knots	130	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.408	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
107458	Drayton Passage (depth 19 ft), Puget Sound, Washington Current	NOS	PUG1537_20	47.17258071899414	-122.7414779663086	:America/Los_Angeles	USA	knots	31	215	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drayton Passage	WA
107341	Dalco Passage (depth 23 ft), Puget Sound, Washington Current	NOS	PUG1522_28	47.32511901855469	-122.5246810913086	:America/Los_Angeles	USA	knots	\N	309.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.501	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
107342	Gig Harbor entrance (depth 54 ft), Puget Sound, Washington Current	NOS	PUG1523_1	47.32415008544922	-122.57186889648438	:America/Los_Angeles	USA	knots	3	192	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor Entrance	WA
107343	Gig Harbor entrance (depth 31 ft), Puget Sound, Washington Current	NOS	PUG1523_8	47.32415008544922	-122.57186889648438	:America/Los_Angeles	USA	knots	357	198	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor Entrance	WA
107344	Gig Harbor entrance (depth 11 ft), Puget Sound, Washington Current	NOS	PUG1523_14	47.32415008544922	-122.57186889648438	:America/Los_Angeles	USA	knots	7	198	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor Entrance	WA
107345	The Narrows, north end (midstream) (depth 139 ft), Puget Sound, Washington Current	NOS	PUG1524_1	47.305999755859375	-122.55003356933594	:America/Los_Angeles	USA	knots	331	132	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, North end - midstream	WA
107346	The Narrows, north end (midstream) (depth 87 ft), Puget Sound, Washington Current	NOS	PUG1524_9	47.305999755859375	-122.55003356933594	:America/Los_Angeles	USA	knots	335	141	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.224	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, North end - midstream	WA
107347	The Narrows, north end (midstream) (depth 40 ft), Puget Sound, Washington Current	NOS	PUG1524_16	47.305999755859375	-122.55003356933594	:America/Los_Angeles	USA	knots	337	145	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, North end - midstream	WA
107348	The Narrows, north end (west side) (depth 193 ft), Puget Sound, Washington Current	NOS	PUG1526_5	47.30400085449219	-122.55674743652344	:America/Los_Angeles	USA	knots	324	144	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, North End (west side)	WA
107349	The Narrows, north end (west side) (depth 95 ft), Puget Sound, Washington Current	NOS	PUG1526_20	47.30400085449219	-122.55674743652344	:America/Los_Angeles	USA	knots	326	148	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.933	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, North End (west side)	WA
107350	The Narrows, north end (west side) (depth 42 ft), Puget Sound, Washington Current	NOS	PUG1526_28	47.30400085449219	-122.55674743652344	:America/Los_Angeles	USA	knots	329	152	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, North End (west side)	WA
107351	The Narrows, 0.3 mi north of bridge (depth 141 ft), Puget Sound, Washington Current	NOS	PUG1527_1	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	42	213	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107352	The Narrows, 0.3 mi north of bridge (depth 134 ft), Puget Sound, Washington Current	NOS	PUG1527_2	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	216.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107353	The Narrows, 0.3 mi north of bridge (depth 128 ft), Puget Sound, Washington Current	NOS	PUG1527_3	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	216.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107354	The Narrows, 0.3 mi north of bridge (depth 121 ft), Puget Sound, Washington Current	NOS	PUG1527_4	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	216.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107355	The Narrows, 0.3 mi north of bridge (depth 115 ft), Puget Sound, Washington Current	NOS	PUG1527_5	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	216	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107356	The Narrows, 0.3 mi north of bridge (depth 108 ft), Puget Sound, Washington Current	NOS	PUG1527_6	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	215.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107357	The Narrows, 0.3 mi north of bridge (depth 102 ft), Puget Sound, Washington Current	NOS	PUG1527_7	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	215.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107358	The Narrows, 0.3 mi north of bridge (depth 95 ft), Puget Sound, Washington Current	NOS	PUG1527_8	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	214.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107359	The Narrows, 0.3 mi north of bridge (depth 88 ft), Puget Sound, Washington Current	NOS	PUG1527_9	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	214.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107360	The Narrows, 0.3 mi north of bridge (depth 82 ft), Puget Sound, Washington Current	NOS	PUG1527_10	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	214	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107361	The Narrows, 0.3 mi north of bridge (depth 75 ft), Puget Sound, Washington Current	NOS	PUG1527_11	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	213.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107362	The Narrows, 0.3 mi north of bridge (depth 69 ft), Puget Sound, Washington Current	NOS	PUG1527_12	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	42	204	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107363	The Narrows, 0.3 mi north of bridge (depth 62 ft), Puget Sound, Washington Current	NOS	PUG1527_13	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	212.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107364	The Narrows, 0.3 mi north of bridge (depth 56 ft), Puget Sound, Washington Current	NOS	PUG1527_14	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	211.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107365	The Narrows, 0.3 mi north of bridge (depth 49 ft), Puget Sound, Washington Current	NOS	PUG1527_15	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	211.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107366	The Narrows, 0.3 mi north of bridge (depth 43 ft), Puget Sound, Washington Current	NOS	PUG1527_16	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	210.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107367	The Narrows, 0.3 mi north of bridge (depth 36 ft), Puget Sound, Washington Current	NOS	PUG1527_17	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	209.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107368	The Narrows, 0.3 mi north of bridge (depth 29 ft), Puget Sound, Washington Current	NOS	PUG1527_18	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	209.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107369	The Narrows, 0.3 mi north of bridge (depth 23 ft), Puget Sound, Washington Current	NOS	PUG1527_19	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	40	198	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107459	Devils Head, west of (depth 191 ft), Puget Sound, Washington Current	NOS	PUG1538_5	47.16067123413086	-122.78936767578125	:America/Los_Angeles	USA	knots	159	324	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devils Head, West of	WA
107370	The Narrows, 0.3 mi north of bridge (depth 16 ft), Puget Sound, Washington Current	NOS	PUG1527_20	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	206.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
107371	The Narrows, south end (midstream) (depth 131 ft), Puget Sound, Washington Current	NOS	PUG1528_1	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	32	222	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107372	The Narrows, south end (midstream) (depth 125 ft), Puget Sound, Washington Current	NOS	PUG1528_2	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	217	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107373	The Narrows, south end (midstream) (depth 118 ft), Puget Sound, Washington Current	NOS	PUG1528_3	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	216.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107374	The Narrows, south end (midstream) (depth 112 ft), Puget Sound, Washington Current	NOS	PUG1528_4	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	216.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107375	The Narrows, south end (midstream) (depth 105 ft), Puget Sound, Washington Current	NOS	PUG1528_5	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	216.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107376	The Narrows, south end (midstream) (depth 98 ft), Puget Sound, Washington Current	NOS	PUG1528_6	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	216.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107377	The Narrows, south end (midstream) (depth 92 ft), Puget Sound, Washington Current	NOS	PUG1528_7	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	216.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107378	The Narrows, south end (midstream) (depth 85 ft), Puget Sound, Washington Current	NOS	PUG1528_8	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	216.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107379	The Narrows, south end (midstream) (depth 79 ft), Puget Sound, Washington Current	NOS	PUG1528_9	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	216	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107380	The Narrows, south end (midstream) (depth 72 ft), Puget Sound, Washington Current	NOS	PUG1528_10	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	215.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107381	The Narrows, south end (midstream) (depth 66 ft), Puget Sound, Washington Current	NOS	PUG1528_11	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	215.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107382	The Narrows, south end (midstream) (depth 59 ft), Puget Sound, Washington Current	NOS	PUG1528_12	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	215.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107383	The Narrows, south end (midstream) (depth 52 ft), Puget Sound, Washington Current	NOS	PUG1528_13	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	28	221	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107384	The Narrows, south end (midstream) (depth 46 ft), Puget Sound, Washington Current	NOS	PUG1528_14	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	214.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107385	The Narrows, south end (midstream) (depth 39 ft), Puget Sound, Washington Current	NOS	PUG1528_15	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	214.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107386	The Narrows, south end (midstream) (depth 33 ft), Puget Sound, Washington Current	NOS	PUG1528_16	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	213.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107387	The Narrows, south end (midstream) (depth 26 ft), Puget Sound, Washington Current	NOS	PUG1528_17	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	26	220	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107388	The Narrows, south end (midstream) (depth 20 ft), Puget Sound, Washington Current	NOS	PUG1528_18	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	213.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
107389	Hale Passage, east end (depth 77 ft), Puget Sound, Washington Current	NOS	PUG1529_1	47.24789810180664	-122.59559631347656	:America/Los_Angeles	USA	knots	151	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.241	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, East end	WA
107390	Hale Passage, east end (depth 44 ft), Puget Sound, Washington Current	NOS	PUG1529_6	47.24789810180664	-122.59559631347656	:America/Los_Angeles	USA	knots	145	330	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, East end	WA
107391	Hale Passage, east end (depth 11 ft), Puget Sound, Washington Current	NOS	PUG1529_11	47.24789810180664	-122.59559631347656	:America/Los_Angeles	USA	knots	145	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, East end	WA
107392	Hale Passage, west end (depth 70 ft), Puget Sound, Washington Current	NOS	PUG1530_1	47.28137969970703	-122.66311645507812	:America/Los_Angeles	USA	knots	113	282	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.349	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, West end	WA
107393	Hale Passage, west end (depth 40 ft), Puget Sound, Washington Current	NOS	PUG1530_10	47.28137969970703	-122.66311645507812	:America/Los_Angeles	USA	knots	99	283	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.461	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, West end	WA
107394	Hale Passage, west end (depth 14 ft), Puget Sound, Washington Current	NOS	PUG1530_18	47.28137969970703	-122.66311645507812	:America/Los_Angeles	USA	knots	105	283	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, West end	WA
107395	Gibson Point, 0.8 mi east of (depth 199 ft), Puget Sound, Washington Current	NOS	PUG1531_1	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	204.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107396	Gibson Point, 0.8 mi east of (depth 189 ft), Puget Sound, Washington Current	NOS	PUG1531_2	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	205.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107397	Gibson Point, 0.8 mi east of (depth 179 ft), Puget Sound, Washington Current	NOS	PUG1531_3	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	205.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107398	Gibson Point, 0.8 mi east of (depth 169 ft), Puget Sound, Washington Current	NOS	PUG1531_4	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	205.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107399	Gibson Point, 0.8 mi east of (depth 159 ft), Puget Sound, Washington Current	NOS	PUG1531_5	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	206	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.166	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107400	Gibson Point, 0.8 mi east of (depth 149 ft), Puget Sound, Washington Current	NOS	PUG1531_6	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	29	205	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107401	Gibson Point, 0.8 mi east of (depth 140 ft), Puget Sound, Washington Current	NOS	PUG1531_7	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	206.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107402	Gibson Point, 0.8 mi east of (depth 130 ft), Puget Sound, Washington Current	NOS	PUG1531_8	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	206.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107403	Gibson Point, 0.8 mi east of (depth 120 ft), Puget Sound, Washington Current	NOS	PUG1531_9	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	206.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107404	Gibson Point, 0.8 mi east of (depth 110 ft), Puget Sound, Washington Current	NOS	PUG1531_10	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	207.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107405	Gibson Point, 0.8 mi east of (depth 100 ft), Puget Sound, Washington Current	NOS	PUG1531_11	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	207.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107406	Gibson Point, 0.8 mi east of (depth 90 ft), Puget Sound, Washington Current	NOS	PUG1531_12	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	207.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107407	Gibson Point, 0.8 mi east of (depth 81 ft), Puget Sound, Washington Current	NOS	PUG1531_13	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	34	204	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107408	Gibson Point, 0.8 mi east of (depth 71 ft), Puget Sound, Washington Current	NOS	PUG1531_14	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	208.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107409	Gibson Point, 0.8 mi east of (depth 61 ft), Puget Sound, Washington Current	NOS	PUG1531_15	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	208.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107410	Gibson Point, 0.8 mi east of (depth 51 ft), Puget Sound, Washington Current	NOS	PUG1531_16	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	209.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107411	Gibson Point, 0.8 mi east of (depth 41 ft), Puget Sound, Washington Current	NOS	PUG1531_17	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	210.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107412	Gibson Point, 0.8 mi east of (depth 31 ft), Puget Sound, Washington Current	NOS	PUG1531_18	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	42	204	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
107413	Steilacoom, 0.8 mi north of (depth 242 ft), Puget Sound, Washington Current	NOS	PUG1532_1	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	210.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107414	Steilacoom, 0.8 mi north of (depth 229 ft), Puget Sound, Washington Current	NOS	PUG1532_2	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	211	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107415	Steilacoom, 0.8 mi north of (depth 216 ft), Puget Sound, Washington Current	NOS	PUG1532_3	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	211.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107416	Steilacoom, 0.8 mi north of (depth 203 ft), Puget Sound, Washington Current	NOS	PUG1532_4	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	212.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107417	Steilacoom, 0.8 mi north of (depth 190 ft), Puget Sound, Washington Current	NOS	PUG1532_5	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	212.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107418	Steilacoom, 0.8 mi north of (depth 177 ft), Puget Sound, Washington Current	NOS	PUG1532_6	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	37	205	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107419	Steilacoom, 0.8 mi north of (depth 164 ft), Puget Sound, Washington Current	NOS	PUG1532_7	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	214.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107420	Steilacoom, 0.8 mi north of (depth 151 ft), Puget Sound, Washington Current	NOS	PUG1532_8	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	215.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107421	Steilacoom, 0.8 mi north of (depth 137 ft), Puget Sound, Washington Current	NOS	PUG1532_9	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	216.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107422	Steilacoom, 0.8 mi north of (depth 124 ft), Puget Sound, Washington Current	NOS	PUG1532_10	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	218.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107423	Steilacoom, 0.8 mi north of (depth 111 ft), Puget Sound, Washington Current	NOS	PUG1532_11	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	220.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107424	Steilacoom, 0.8 mi north of (depth 98 ft), Puget Sound, Washington Current	NOS	PUG1532_12	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	221.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107425	Steilacoom, 0.8 mi north of (depth 85 ft), Puget Sound, Washington Current	NOS	PUG1532_13	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	55	213	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107426	Steilacoom, 0.8 mi north of (depth 72 ft), Puget Sound, Washington Current	NOS	PUG1532_14	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	224.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107427	Steilacoom, 0.8 mi north of (depth 59 ft), Puget Sound, Washington Current	NOS	PUG1532_15	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	224.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107428	Steilacoom, 0.8 mi north of (depth 45 ft), Puget Sound, Washington Current	NOS	PUG1532_16	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	51	215	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107429	Steilacoom, 0.8 mi north of (depth 32 ft), Puget Sound, Washington Current	NOS	PUG1532_17	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	225.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
107430	Ketron Island, west of (depth 261 ft), Puget Sound, Washington Current	NOS	PUG1533_1	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	194.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107431	Ketron Island, west of (depth 248 ft), Puget Sound, Washington Current	NOS	PUG1533_2	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	195.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107432	Ketron Island, west of (depth 235 ft), Puget Sound, Washington Current	NOS	PUG1533_3	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	195.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.162	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107433	Ketron Island, west of (depth 222 ft), Puget Sound, Washington Current	NOS	PUG1533_4	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	195.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107434	Ketron Island, west of (depth 208 ft), Puget Sound, Washington Current	NOS	PUG1533_5	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	194.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107435	Ketron Island, west of (depth 195 ft), Puget Sound, Washington Current	NOS	PUG1533_6	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	194.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107436	Ketron Island, west of (depth 182 ft), Puget Sound, Washington Current	NOS	PUG1533_7	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	194.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107437	Ketron Island, west of (depth 169 ft), Puget Sound, Washington Current	NOS	PUG1533_8	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	195.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107438	Ketron Island, west of (depth 156 ft), Puget Sound, Washington Current	NOS	PUG1533_9	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	196.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107439	Ketron Island, west of (depth 143 ft), Puget Sound, Washington Current	NOS	PUG1533_10	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	12	206	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107440	Ketron Island, west of (depth 130 ft), Puget Sound, Washington Current	NOS	PUG1533_11	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	200.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107441	Ketron Island, west of (depth 117 ft), Puget Sound, Washington Current	NOS	PUG1533_12	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	202.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107442	Ketron Island, west of (depth 103 ft), Puget Sound, Washington Current	NOS	PUG1533_13	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	203.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107443	Ketron Island, west of (depth 90 ft), Puget Sound, Washington Current	NOS	PUG1533_14	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	12	208	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107444	Ketron Island, west of (depth 77 ft), Puget Sound, Washington Current	NOS	PUG1533_15	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	200.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107445	Ketron Island, west of (depth 64 ft), Puget Sound, Washington Current	NOS	PUG1533_16	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	197.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107446	Ketron Island, west of (depth 51 ft), Puget Sound, Washington Current	NOS	PUG1533_17	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	193.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107447	Ketron Island, west of (depth 38 ft), Puget Sound, Washington Current	NOS	PUG1533_18	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	10	193	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
107448	Nisqually Reach, 0.5 mi south of Lyle Point (depth 177 ft), Washington Current	NOS	PUG1534_1	47.11692810058594	-122.6988525390625	:America/Los_Angeles	USA	knots	77	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nisqually Reach, 0.5 miles South of Lyle Point	WA
107449	Nisqually Reach, 0.5 mi south of Lyle Point (depth 68 ft), Washington Current	NOS	PUG1534_12	47.11692810058594	-122.6988525390625	:America/Los_Angeles	USA	knots	86	257	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nisqually Reach, 0.5 miles South of Lyle Point	WA
107450	Nisqually Reach, 0.5 mi south of Lyle Point (depth 29 ft), Washington Current	NOS	PUG1534_16	47.11692810058594	-122.6988525390625	:America/Los_Angeles	USA	knots	88	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nisqually Reach, 0.5 miles South of Lyle Point	WA
107451	Balch Passage, NE of Eagle Island (depth 60 ft), Puget Sound, Washington Current	NOS	PUG1535_1	47.19062042236328	-122.6915512084961	:America/Los_Angeles	USA	knots	108	288	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Balch Passage, NE of Eagle Island	WA
107452	Balch Passage, NE of Eagle Island (depth 30 ft), Puget Sound, Washington Current	NOS	PUG1535_10	47.19062042236328	-122.6915512084961	:America/Los_Angeles	USA	knots	108	288	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.315	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Balch Passage, NE of Eagle Island	WA
107453	Balch Passage, NE of Eagle Island (depth 11 ft), Puget Sound, Washington Current	NOS	PUG1535_16	47.19062042236328	-122.6915512084961	:America/Los_Angeles	USA	knots	104	287	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.311	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Balch Passage, NE of Eagle Island	WA
107454	Pitt Passage, NE of Pitt Island (depth 23 ft), Puget Sound, Washington Current	NOS	PUG1536_1	47.22383117675781	-122.71137237548828	:America/Los_Angeles	USA	knots	23	202	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.287	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pitt Passage, NE of Pitt Island	WA
107455	Pitt Passage, NE of Pitt Island (depth 7 ft), Puget Sound, Washington Current	NOS	PUG1536_6	47.22383117675781	-122.71137237548828	:America/Los_Angeles	USA	knots	29	196	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.318	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pitt Passage, NE of Pitt Island	WA
107456	Drayton Passage (depth 118 ft), Puget Sound, Washington Current	NOS	PUG1537_5	47.17258071899414	-122.7414779663086	:America/Los_Angeles	USA	knots	34	213	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drayton Passage	WA
107460	Devils Head, west of (depth 83 ft), Puget Sound, Washington Current	NOS	PUG1538_16	47.16067123413086	-122.78936767578125	:America/Los_Angeles	USA	knots	153	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devils Head, West of	WA
107461	Devils Head, west of (depth 24 ft), Puget Sound, Washington Current	NOS	PUG1538_22	47.16067123413086	-122.78936767578125	:America/Los_Angeles	USA	knots	156	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.227	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devils Head, West of	WA
107462	Dana Passage (depth 88 ft), Puget Sound, Washington Current	NOS	PUG1539_1	47.16310119628906	-122.86810302734375	:America/Los_Angeles	USA	knots	43	232	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dana Passage	WA
107463	Dana Passage (depth 43 ft), Puget Sound, Washington Current	NOS	PUG1539_8	47.16310119628906	-122.86810302734375	:America/Los_Angeles	USA	knots	48	239	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.167	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dana Passage	WA
107464	Dana Passage (depth 16 ft), Puget Sound, Washington Current	NOS	PUG1539_12	47.16310119628906	-122.86810302734375	:America/Los_Angeles	USA	knots	49	242	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.176	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dana Passage	WA
107465	Budd Inlet entrance (depth 71 ft), Puget Sound, Washington Current	NOS	PUG1540_1	47.140159606933594	-122.92144775390625	:America/Los_Angeles	USA	knots	2	170	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Budd Inlet Entrance	WA
107466	Budd Inlet entrance (depth 32 ft), Puget Sound, Washington Current	NOS	PUG1540_7	47.140159606933594	-122.92144775390625	:America/Los_Angeles	USA	knots	4	172	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Budd Inlet Entrance	WA
107467	Budd Inlet entrance (depth 12 ft), Puget Sound, Washington Current	NOS	PUG1540_10	47.140159606933594	-122.92144775390625	:America/Los_Angeles	USA	knots	10	184	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Budd Inlet Entrance	WA
107468	Peale Passage, south end (depth 35 ft), Puget Sound, Washington Current	NOS	PUG1541_1	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	159	338	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
107469	Peale Passage, south end (depth 32 ft), Puget Sound, Washington Current	NOS	PUG1541_2	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	\N	338.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
107470	Peale Passage, south end (depth 29 ft), Puget Sound, Washington Current	NOS	PUG1541_3	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	\N	338.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
107471	Peale Passage, south end (depth 26 ft), Puget Sound, Washington Current	NOS	PUG1541_4	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	\N	339.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
107472	Peale Passage, south end (depth 22 ft), Puget Sound, Washington Current	NOS	PUG1541_5	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	157	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
107473	Peale Passage, south end (depth 19 ft), Puget Sound, Washington Current	NOS	PUG1541_6	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	\N	341.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
107474	Peale Passage, south end (depth 16 ft), Puget Sound, Washington Current	NOS	PUG1541_7	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	\N	342.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
107475	Peale Passage, south end (depth 12 ft), Puget Sound, Washington Current	NOS	PUG1541_8	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	\N	343.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
107476	Peale Passage, south end (depth 9 ft), Puget Sound, Washington Current	NOS	PUG1541_9	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	16	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
107477	Peale Passage, south end (depth 6 ft), Puget Sound, Washington Current	NOS	PUG1541_10	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	\N	342.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
107478	Peale Passage, north end (depth 17 ft), Puget Sound, Washington Current	NOS	PUG1542_1	47.21752166748047	-122.9146499633789	:America/Los_Angeles	USA	knots	132	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, North end	WA
107479	Peale Passage, north end (depth 14 ft), Puget Sound, Washington Current	NOS	PUG1542_2	47.21752166748047	-122.9146499633789	:America/Los_Angeles	USA	knots	\N	314.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, North end	WA
107480	Peale Passage, north end (depth 11 ft), Puget Sound, Washington Current	NOS	PUG1542_3	47.21752166748047	-122.9146499633789	:America/Los_Angeles	USA	knots	\N	315.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, North end	WA
107481	Peale Passage, north end (depth 7 ft), Puget Sound, Washington Current	NOS	PUG1542_4	47.21752166748047	-122.9146499633789	:America/Los_Angeles	USA	knots	\N	316.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, North end	WA
107482	Peale Passage, north end (depth 4 ft), Puget Sound, Washington Current	NOS	PUG1542_5	47.21752166748047	-122.9146499633789	:America/Los_Angeles	USA	knots	135	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, North end	WA
107483	Peale Passage, north end (depth 1 ft), Puget Sound, Washington Current	NOS	PUG1542_6	47.21752166748047	-122.9146499633789	:America/Los_Angeles	USA	knots	\N	318.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, North end	WA
107484	Squaxin Passage, north of Hunter Point (depth 32 ft), Puget Sound, Washington Current	NOS	PUG1543_1	47.17626953125	-122.91899871826172	:America/Los_Angeles	USA	knots	107	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Squaxin Passage, North of Hunter Point	WA
107485	Squaxin Passage, north of Hunter Point (depth 18 ft), Puget Sound, Washington Current	NOS	PUG1543_5	47.17626953125	-122.91899871826172	:America/Los_Angeles	USA	knots	108	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Squaxin Passage, North of Hunter Point	WA
107486	Squaxin Passage, north of Hunter Point (depth 5 ft), Puget Sound, Washington Current	NOS	PUG1543_9	47.17626953125	-122.91899871826172	:America/Los_Angeles	USA	knots	110	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Squaxin Passage, North of Hunter Point	WA
107487	Totten Inlet entrance (depth 67 ft), Puget Sound, Washington Current	NOS	PUG1544_3	47.18825149536133	-122.94537353515625	:America/Los_Angeles	USA	knots	52	229	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.195	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Totten Inlet Entrance	WA
107488	Totten Inlet entrance (depth 41 ft), Puget Sound, Washington Current	NOS	PUG1544_7	47.18825149536133	-122.94537353515625	:America/Los_Angeles	USA	knots	39	227	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Totten Inlet Entrance	WA
107489	Totten Inlet entrance (depth 14 ft), Puget Sound, Washington Current	NOS	PUG1544_11	47.18825149536133	-122.94537353515625	:America/Los_Angeles	USA	knots	31	222	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Totten Inlet Entrance	WA
107490	Libby Point, Hammersley Inlet (depth 19 ft), Puget Sound, Washington Current	NOS	PUG1545_1	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	77	261	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
107491	Libby Point, Hammersley Inlet (depth 18 ft), Puget Sound, Washington Current	NOS	PUG1545_2	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	\N	259.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.301	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
107492	Libby Point, Hammersley Inlet (depth 16 ft), Puget Sound, Washington Current	NOS	PUG1545_3	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	\N	259.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
107493	Libby Point, Hammersley Inlet (depth 15 ft), Puget Sound, Washington Current	NOS	PUG1545_4	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	\N	259.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.352	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
107494	Libby Point, Hammersley Inlet (depth 13 ft), Puget Sound, Washington Current	NOS	PUG1545_5	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	\N	259.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.377	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
107495	Libby Point, Hammersley Inlet (depth 11 ft), Puget Sound, Washington Current	NOS	PUG1545_6	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	\N	259.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.399	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
107496	Libby Point, Hammersley Inlet (depth 10 ft), Puget Sound, Washington Current	NOS	PUG1545_7	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	\N	259.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.419	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
107497	Libby Point, Hammersley Inlet (depth 8 ft), Puget Sound, Washington Current	NOS	PUG1545_8	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	\N	259.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.437	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
107498	Libby Point, Hammersley Inlet (depth 6 ft), Puget Sound, Washington Current	NOS	PUG1545_9	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	\N	259.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.452	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
107499	Libby Point, Hammersley Inlet (depth 5 ft), Puget Sound, Washington Current	NOS	PUG1545_10	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	84	254	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.448	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
107500	Pickering Passage, west of Squaxin Island (depth 52 ft), Puget Sound, Washington Current	NOS	PUG1546_1	47.21928024291992	-122.93451690673828	:America/Los_Angeles	USA	knots	13	191	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, West of Squaxin Island	WA
107501	Pickering Passage, west of Squaxin Island (depth 29 ft), Puget Sound, Washington Current	NOS	PUG1546_8	47.21928024291992	-122.93451690673828	:America/Los_Angeles	USA	knots	6	194	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, West of Squaxin Island	WA
107502	Pickering Passage, west of Squaxin Island (depth 9 ft), Puget Sound, Washington Current	NOS	PUG1546_14	47.21928024291992	-122.93451690673828	:America/Los_Angeles	USA	knots	3	194	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, West of Squaxin Island	WA
107503	Pickering Passage, off Graham Point (depth 59 ft), Puget Sound, Washington Current	NOS	PUG1547_1	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	27	207	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107504	Pickering Passage, off Graham Point (depth 56 ft), Puget Sound, Washington Current	NOS	PUG1547_2	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	206.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107505	Pickering Passage, off Graham Point (depth 53 ft), Puget Sound, Washington Current	NOS	PUG1547_3	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	205.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107520	Pickering Passage, north end (depth 78 ft), Puget Sound, Washington Current	NOS	PUG1548_1	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	69	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
107506	Pickering Passage, off Graham Point (depth 49 ft), Puget Sound, Washington Current	NOS	PUG1547_4	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	204.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107507	Pickering Passage, off Graham Point (depth 46 ft), Puget Sound, Washington Current	NOS	PUG1547_5	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	203.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107508	Pickering Passage, off Graham Point (depth 43 ft), Puget Sound, Washington Current	NOS	PUG1547_6	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	202.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107509	Pickering Passage, off Graham Point (depth 39 ft), Puget Sound, Washington Current	NOS	PUG1547_7	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	202	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107510	Pickering Passage, off Graham Point (depth 36 ft), Puget Sound, Washington Current	NOS	PUG1547_8	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	201.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107511	Pickering Passage, off Graham Point (depth 33 ft), Puget Sound, Washington Current	NOS	PUG1547_9	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	200.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107512	Pickering Passage, off Graham Point (depth 30 ft), Puget Sound, Washington Current	NOS	PUG1547_10	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	22	198	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107513	Pickering Passage, off Graham Point (depth 26 ft), Puget Sound, Washington Current	NOS	PUG1547_11	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	199.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107514	Pickering Passage, off Graham Point (depth 23 ft), Puget Sound, Washington Current	NOS	PUG1547_12	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	199.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107515	Pickering Passage, off Graham Point (depth 20 ft), Puget Sound, Washington Current	NOS	PUG1547_13	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	199.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107516	Pickering Passage, off Graham Point (depth 16 ft), Puget Sound, Washington Current	NOS	PUG1547_14	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	198.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107517	Pickering Passage, off Graham Point (depth 13 ft), Puget Sound, Washington Current	NOS	PUG1547_15	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	198.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107518	Pickering Passage, off Graham Point (depth 10 ft), Puget Sound, Washington Current	NOS	PUG1547_16	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	19	198	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107519	Pickering Passage, off Graham Point (depth 7 ft), Puget Sound, Washington Current	NOS	PUG1547_17	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	198.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
107521	Pickering Passage, north end (depth 71 ft), Puget Sound, Washington Current	NOS	PUG1548_2	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	\N	255.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.098	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
107522	Pickering Passage, north end (depth 65 ft), Puget Sound, Washington Current	NOS	PUG1548_3	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	\N	255.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
107523	Pickering Passage, north end (depth 58 ft), Puget Sound, Washington Current	NOS	PUG1548_4	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	\N	255.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
107524	Pickering Passage, north end (depth 52 ft), Puget Sound, Washington Current	NOS	PUG1548_5	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	\N	254.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
107525	Pickering Passage, north end (depth 45 ft), Puget Sound, Washington Current	NOS	PUG1548_6	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	64	260	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
107526	Pickering Passage, north end (depth 39 ft), Puget Sound, Washington Current	NOS	PUG1548_7	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	\N	251.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
107527	Pickering Passage, north end (depth 32 ft), Puget Sound, Washington Current	NOS	PUG1548_8	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	\N	249.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
107528	Pickering Passage, north end (depth 25 ft), Puget Sound, Washington Current	NOS	PUG1548_9	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	\N	246.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
107529	Pickering Passage, north end (depth 19 ft), Puget Sound, Washington Current	NOS	PUG1548_10	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	52	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
107530	Pickering Passage, north end (depth 12 ft), Puget Sound, Washington Current	NOS	PUG1548_11	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	\N	244.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
107531	Hazel Point (depth 154 ft), Hood Canal, Washington Current	NOS	PUG1601_1	47.69123840332031	-122.76278686523438	:America/Los_Angeles	USA	knots	20	193	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hazel Point	WA
107532	Hazel Point (depth 88 ft), Hood Canal, Washington Current	NOS	PUG1601_11	47.69123840332031	-122.76278686523438	:America/Los_Angeles	USA	knots	23	200	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hazel Point	WA
107533	Hazel Point (depth 23 ft), Hood Canal, Washington Current	NOS	PUG1601_21	47.69123840332031	-122.76278686523438	:America/Los_Angeles	USA	knots	13	181	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hazel Point	WA
107534	South Point (depth 178 ft), Hood Canal, Washington Current	NOS	PUG1602_1	47.821659088134766	-122.67671966552734	:America/Los_Angeles	USA	knots	41	234	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Point	WA
107535	South Point (depth 43 ft), Hood Canal, Washington Current	NOS	PUG1602_42	47.821659088134766	-122.67671966552734	:America/Los_Angeles	USA	knots	42	231	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Point	WA
107536	South Point (depth 24 ft), Hood Canal, Washington Current	NOS	PUG1602_48	47.821659088134766	-122.67671966552734	:America/Los_Angeles	USA	knots	41	230	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Point	WA
107540	Port Gamble Bay entrance (depth 32 ft), Hood Canal, Washington Current	NOS	PUG1604_1	47.85472106933594	-122.57817840576172	:America/Los_Angeles	USA	knots	20	204	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Gamble Bay Entrance	WA
107541	Port Gamble Bay entrance (depth 10 ft), Hood Canal, Washington Current	NOS	PUG1604_8	47.85472106933594	-122.57817840576172	:America/Los_Angeles	USA	knots	14	197	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Gamble Bay Entrance	WA
107542	Possession Sound entrance (depth 322 ft), Washington Current	NOS	PUG1605_20	47.89929962158203	-122.36009979248047	:America/Los_Angeles	USA	knots	199	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Possession Sound Entrance	WA
107543	Possession Sound entrance (depth 190 ft), Washington Current	NOS	PUG1605_30	47.89929962158203	-122.36009979248047	:America/Los_Angeles	USA	knots	198	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Possession Sound Entrance	WA
107544	Possession Sound entrance (depth 59 ft), Washington Current	NOS	PUG1605_40	47.89929962158203	-122.36009979248047	:America/Los_Angeles	USA	knots	204	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Possession Sound Entrance	WA
107545	Point No Point, 1.2 mi E of (depth 567 ft), Puget Sound, Washington Current	NOS	PUG1606_1	47.91249084472656	-122.50196838378906	:America/Los_Angeles	USA	knots	321	149	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.433	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 1.2 mi. E of	WA
107546	Point No Point, 1.2 mi E of (depth 108 ft), Puget Sound, Washington Current	NOS	PUG1606_36	47.91249084472656	-122.50196838378906	:America/Los_Angeles	USA	knots	338	164	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.285	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 1.2 mi. E of	WA
107547	Point No Point, 1.2 mi E of (depth 69 ft), Puget Sound, Washington Current	NOS	PUG1606_39	47.91249084472656	-122.50196838378906	:America/Los_Angeles	USA	knots	336	164	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.321	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 1.2 mi. E of	WA
107548	Point No Point, 2.1 mi E of (depth 240 ft), Puget Sound, Washington Current	NOS	PUG1607_1	47.918880462646484	-122.484130859375	:America/Los_Angeles	USA	knots	327	135	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.203	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 2.1 mi. E of	WA
107549	Point No Point, 2.1 mi E of (depth 57 ft), Puget Sound, Washington Current	NOS	PUG1607_29	47.918880462646484	-122.484130859375	:America/Los_Angeles	USA	knots	330	134	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.261	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 2.1 mi. E of	WA
107550	Point No Point, 2.1 mi E of (depth 31 ft), Puget Sound, Washington Current	NOS	PUG1607_33	47.918880462646484	-122.484130859375	:America/Los_Angeles	USA	knots	331	129	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.293	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 2.1 mi. E of	WA
107551	Hood Canal entrance, Foulweather Bluff (depth 255 ft), Washington Current	NOS	PUG1608_1	47.92837905883789	-122.6388168334961	:America/Los_Angeles	USA	knots	0	173	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Entrance, Foulweather Bluff	WA
107552	Hood Canal entrance, Foulweather Bluff (depth 78 ft), Washington Current	NOS	PUG1608_28	47.92837905883789	-122.6388168334961	:America/Los_Angeles	USA	knots	352	164	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Entrance, Foulweather Bluff	WA
107553	Hood Canal entrance, Foulweather Bluff (depth 32 ft), Washington Current	NOS	PUG1608_35	47.92837905883789	-122.6388168334961	:America/Los_Angeles	USA	knots	340	153	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Entrance, Foulweather Bluff	WA
107554	West of Mukilteo (depth 272 ft), Washington Current	NOS	PUG1609_20	47.948951721191406	-122.32846069335938	:America/Los_Angeles	USA	knots	205	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Mukilteo	WA
107555	West of Mukilteo (depth 140 ft), Washington Current	NOS	PUG1609_30	47.948951721191406	-122.32846069335938	:America/Los_Angeles	USA	knots	205	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Mukilteo	WA
107556	West of Mukilteo (depth 62 ft), Washington Current	NOS	PUG1609_36	47.948951721191406	-122.32846069335938	:America/Los_Angeles	USA	knots	198	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Mukilteo	WA
107557	Foulweather Bluff, 1.9 mi NE of (depth 125 ft), Puget Sound, Washington Current	NOS	PUG1610_17	47.95429992675781	-122.57859802246094	:America/Los_Angeles	USA	knots	305	141	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff, 1.9 mi. NE of	WA
107558	Foulweather Bluff, 1.9 mi NE of (depth 27 ft), Puget Sound, Washington Current	NOS	PUG1610_32	47.95429992675781	-122.57859802246094	:America/Los_Angeles	USA	knots	304	125	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.297	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff, 1.9 mi. NE of	WA
107559	Foulweather Bluff, 1.9 mi NE of (depth 20 ft), Puget Sound, Washington Current	NOS	PUG1610_33	47.95429992675781	-122.57859802246094	:America/Los_Angeles	USA	knots	302	125	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff, 1.9 mi. NE of	WA
107560	Olele Point, 1.8 mi ENE of (depth 148 ft), Admiralty Inlet, Washington Current	NOS	PUG1611_10	47.97880935668945	-122.64549255371094	:America/Los_Angeles	USA	knots	333	189	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olele Point, 1.8 mi. ENE of	WA
107561	Olele Point, 1.8 mi ENE of (depth 66 ft), Admiralty Inlet, Washington Current	NOS	PUG1611_35	47.97880935668945	-122.64549255371094	:America/Los_Angeles	USA	knots	340	169	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olele Point, 1.8 mi. ENE of	WA
107562	Olele Point, 1.8 mi ENE of (depth 20 ft), Admiralty Inlet, Washington Current	NOS	PUG1611_49	47.97880935668945	-122.64549255371094	:America/Los_Angeles	USA	knots	342	149	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olele Point, 1.8 mi. ENE of	WA
107563	Clinton Ferry Terminal (depth 80 ft), Washington Current	NOS	PUG1612_1	47.96899	-122.34507	:America/Los_Angeles	USA	knots	184	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Ferry Terminal	WA
107564	Clinton Ferry Terminal (depth 47 ft), Washington Current	NOS	PUG1612_6	47.96899	-122.34507	:America/Los_Angeles	USA	knots	187	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Ferry Terminal	WA
107565	Clinton Ferry Terminal (depth 21 ft), Washington Current	NOS	PUG1612_10	47.96899	-122.34507	:America/Los_Angeles	USA	knots	178	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Ferry Terminal	WA
107566	Port Townsend Canal (depth 15 ft), Admiralty Inlet, Washington Current	NOS	PUG1614_1	48.032470703125	-122.73261260986328	:America/Los_Angeles	USA	knots	323	145	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.619	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Townsend Canal	WA
107567	Port Townsend Canal (depth 5 ft), Admiralty Inlet, Washington Current	NOS	PUG1614_7	48.032470703125	-122.73261260986328	:America/Los_Angeles	USA	knots	323	140	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.836	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Townsend Canal	WA
107568	Nodule Point, 0.5 mi SE of (depth 65 ft), Admiralty Inlet, Washington Current	NOS	PUG1615_1	48.028709411621094	-122.660888671875	:America/Los_Angeles	USA	knots	347	162	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.214	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nodule Point, 0.5 mi. SE of	WA
107569	Nodule Point, 0.5 mi SE of (depth 25 ft), Admiralty Inlet, Washington Current	NOS	PUG1615_13	48.028709411621094	-122.660888671875	:America/Los_Angeles	USA	knots	353	162	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.573	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nodule Point, 0.5 mi. SE of	WA
107570	Nodule Point, 0.5 mi SE of (depth 9 ft), Admiralty Inlet, Washington Current	NOS	PUG1615_18	48.028709411621094	-122.660888671875	:America/Los_Angeles	USA	knots	357	162	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.589	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nodule Point, 0.5 mi. SE of	WA
107571	Admiralty Inlet (off Bush Point) (depth 193 ft), Washington Current	NOS	PUG1616_6	48.03348159790039	-122.63764953613281	:America/Los_Angeles	USA	knots	0	176	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Admiralty Inlet (off Bush Point)	WA
107572	Admiralty Inlet (off Bush Point) (depth 68 ft), Washington Current	NOS	PUG1616_25	48.03348159790039	-122.63764953613281	:America/Los_Angeles	USA	knots	349	181	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.312	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Admiralty Inlet (off Bush Point)	WA
107573	Admiralty Inlet (off Bush Point) (depth 29 ft), Washington Current	NOS	PUG1616_31	48.03348159790039	-122.63764953613281	:America/Los_Angeles	USA	knots	347	180	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.529	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Admiralty Inlet (off Bush Point)	WA
107574	Bush Point Light, 0.5 mi NW of (depth 208 ft), Admiralty Inlet, Washington Current	NOS	PUG1617_14	48.03084182739258	-122.61334228515625	:America/Los_Angeles	USA	knots	348	187	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.294	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bush Point Light, 0.5 mile NW of	WA
107575	Bush Point Light, 0.5 mi NW of (depth 77 ft), Admiralty Inlet, Washington Current	NOS	PUG1617_34	48.03084182739258	-122.61334228515625	:America/Los_Angeles	USA	knots	338	189	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bush Point Light, 0.5 mile NW of	WA
107576	Bush Point Light, 0.5 mi NW of (depth 44 ft), Admiralty Inlet, Washington Current	NOS	PUG1617_39	48.03084182739258	-122.61334228515625	:America/Los_Angeles	USA	knots	336	189	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bush Point Light, 0.5 mile NW of	WA
107577	Camano Head-Sandy Point, passage (depth 209 ft), Washington Current	NOS	PUG1618_15	48.0478515625	-122.38896942138672	:America/Los_Angeles	USA	knots	119	303	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Camano Head-Sandy Point, passage	WA
107578	Camano Head-Sandy Point, passage (depth 78 ft), Washington Current	NOS	PUG1618_35	48.0478515625	-122.38896942138672	:America/Los_Angeles	USA	knots	117	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Camano Head-Sandy Point, passage	WA
107579	Camano Head-Sandy Point, passage (depth 32 ft), Washington Current	NOS	PUG1618_42	48.0478515625	-122.38896942138672	:America/Los_Angeles	USA	knots	117	303	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Camano Head-Sandy Point, passage	WA
107580	Marrowstone Point, 0.8 mi NE of (depth 151 ft), Admiralty Inlet, Washington Current	NOS	PUG1619_9	48.10633087158203	-122.67247009277344	:America/Los_Angeles	USA	knots	344	119	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.269	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 0.8 mi. NE of	WA
107581	Marrowstone Point, 0.8 mi NE of (depth 75 ft), Admiralty Inlet, Washington Current	NOS	PUG1619_32	48.10633087158203	-122.67247009277344	:America/Los_Angeles	USA	knots	346	124	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 0.8 mi. NE of	WA
107582	Marrowstone Point, 0.8 mi NE of (depth 29 ft), Admiralty Inlet, Washington Current	NOS	PUG1619_46	48.10633087158203	-122.67247009277344	:America/Los_Angeles	USA	knots	349	129	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 0.8 mi. NE of	WA
107583	Marrowstone Point, 1.65 mi NE of (depth 144 ft), Admiralty Inlet, Washington Current	NOS	PUG1620_10	48.119300842285156	-122.66226959228516	:America/Los_Angeles	USA	knots	315	139	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.301	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 1.65 mi. NE of	WA
107584	Marrowstone Point, 1.65 mi NE of (depth 79 ft), Admiralty Inlet, Washington Current	NOS	PUG1620_20	48.119300842285156	-122.66226959228516	:America/Los_Angeles	USA	knots	326	142	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 1.65 mi. NE of	WA
107585	Marrowstone Point, 1.65 mi NE of (depth 26 ft), Admiralty Inlet, Washington Current	NOS	PUG1620_28	48.119300842285156	-122.66226959228516	:America/Los_Angeles	USA	knots	333	145	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 1.65 mi. NE of	WA
107586	West of Camano Island (depth 180 ft), Washington Current	NOS	PUG1622_3	48.169681549072266	-122.5531997680664	:America/Los_Angeles	USA	knots	159	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Camano Island	WA
107587	West of Camano Island (depth 69 ft), Washington Current	NOS	PUG1622_20	48.169681549072266	-122.5531997680664	:America/Los_Angeles	USA	knots	151	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Camano Island	WA
107588	West of Camano Island (depth 23 ft), Washington Current	NOS	PUG1622_27	48.169681549072266	-122.5531997680664	:America/Los_Angeles	USA	knots	159	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Camano Island	WA
107589	Point Wilson, 0.6 mi NE of (depth 118 ft), Admiralty Inlet, Washington Current	NOS	PUG1623_14	48.150108337402344	-122.745361328125	:America/Los_Angeles	USA	knots	325	132	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 0.6 mi. NE of	WA
107590	Point Wilson, 0.6 mi NE of (depth 56 ft), Admiralty Inlet, Washington Current	NOS	PUG1623_33	48.150108337402344	-122.745361328125	:America/Los_Angeles	USA	knots	322	124	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 0.6 mi. NE of	WA
107591	Point Wilson, 0.6 mi NE of (depth 17 ft), Admiralty Inlet, Washington Current	NOS	PUG1623_45	48.150108337402344	-122.745361328125	:America/Los_Angeles	USA	knots	321	120	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.261	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 0.6 mi. NE of	WA
107592	Point Wilson, 1.6 mi NE of (depth 149 ft), Admiralty Inlet, Washington Current	NOS	PUG1624_8	48.156898498535156	-122.72599792480469	:America/Los_Angeles	USA	knots	316	116	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 1.6 mi. NE of	WA
107593	Point Wilson, 1.6 mi NE of (depth 87 ft), Admiralty Inlet, Washington Current	NOS	PUG1624_27	48.156898498535156	-122.72599792480469	:America/Los_Angeles	USA	knots	316	117	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 1.6 mi. NE of	WA
107594	Point Wilson, 1.6 mi NE of (depth 21 ft), Admiralty Inlet, Washington Current	NOS	PUG1624_47	48.156898498535156	-122.72599792480469	:America/Los_Angeles	USA	knots	319	126	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 1.6 mi. NE of	WA
107595	Point Wilson, 2.7 mi NE of (depth 118 ft), Admiralty Inlet, Washington Current	NOS	PUG1625_15	48.16706848144531	-122.70738983154297	:America/Los_Angeles	USA	knots	333	135	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 2.7 mi. NE of	WA
107596	Point Wilson, 2.7 mi NE of (depth 56 ft), Admiralty Inlet, Washington Current	NOS	PUG1625_34	48.16706848144531	-122.70738983154297	:America/Los_Angeles	USA	knots	333	137	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 2.7 mi. NE of	WA
107597	Point Wilson, 2.7 mi NE of (depth 20 ft), Admiralty Inlet, Washington Current	NOS	PUG1625_45	48.16706848144531	-122.70738983154297	:America/Los_Angeles	USA	knots	333	138	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 2.7 mi. NE of	WA
107598	Skagit Bay, 1 mi north of Rocky Point (depth 54 ft), Washington Current	NOS	PUG1626_7	48.2671012878418	-122.52960205078125	:America/Los_Angeles	USA	knots	243	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. north of Rocky Point	WA
107599	Skagit Bay, 1 mi north of Rocky Point (depth 28 ft), Washington Current	NOS	PUG1626_15	48.2671012878418	-122.52960205078125	:America/Los_Angeles	USA	knots	246	51	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. north of Rocky Point	WA
107600	Skagit Bay, 1 mi north of Rocky Point (depth 12 ft), Washington Current	NOS	PUG1626_20	48.2671012878418	-122.52960205078125	:America/Los_Angeles	USA	knots	234	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. north of Rocky Point	WA
107601	Skagit Bay, 1 mi south of Goat Island (depth 52 ft), Washington Current	NOS	PUG1627_5	48.34477996826172	-122.54505157470703	:America/Los_Angeles	USA	knots	154	332	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. south of Goat Island	WA
107602	Skagit Bay, 1 mi south of Goat Island (depth 32 ft), Washington Current	NOS	PUG1627_11	48.34477996826172	-122.54505157470703	:America/Los_Angeles	USA	knots	149	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. south of Goat Island	WA
107603	Skagit Bay, 1 mi south of Goat Island (depth 12 ft), Washington Current	NOS	PUG1627_17	48.34477996826172	-122.54505157470703	:America/Los_Angeles	USA	knots	147	329	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. south of Goat Island	WA
107604	Skagit Bay channel, SW of Hope Island (depth 39 ft), Washington Current	NOS	PUG1628_4	48.397830963134766	-122.57955169677734	:America/Los_Angeles	USA	knots	174	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay channel, SW of Hope Island	WA
107605	Skagit Bay channel, SW of Hope Island (depth 26 ft), Washington Current	NOS	PUG1628_8	48.397830963134766	-122.57955169677734	:America/Los_Angeles	USA	knots	168	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay channel, SW of Hope Island	WA
107606	Skagit Bay channel, SW of Hope Island (depth 10 ft), Washington Current	NOS	PUG1628_13	48.397830963134766	-122.57955169677734	:America/Los_Angeles	USA	knots	170	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay channel, SW of Hope Island	WA
107607	Yokeko Point, Deception Pass (depth 27 ft), Rosario Strait, Washington Current	NOS	PUG1629_3	48.4127197265625	-122.61316680908203	:America/Los_Angeles	USA	knots	226	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yokeko Point, Deception Pass	WA
107608	Yokeko Point, Deception Pass (depth 14 ft), Rosario Strait, Washington Current	NOS	PUG1629_7	48.4127197265625	-122.61316680908203	:America/Los_Angeles	USA	knots	228	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yokeko Point, Deception Pass	WA
107609	Yokeko Point, Deception Pass (depth 7 ft), Rosario Strait, Washington Current	NOS	PUG1629_9	48.4127197265625	-122.61316680908203	:America/Los_Angeles	USA	knots	230	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yokeko Point, Deception Pass	WA
107610	Kanem Point, 1.5 mi SW of Protection Island (depth 97 ft), Washington Current	NOS	PUG1630_30	48.10765075683594	-122.97364807128906	:America/Los_Angeles	USA	knots	289	121	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanem Point, 1.5 mi. SW of Protection Island	WA
107611	Kanem Point, 1.5 mi SW of Protection Island (depth 55 ft), Washington Current	NOS	PUG1630_43	48.10765075683594	-122.97364807128906	:America/Los_Angeles	USA	knots	284	125	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.188	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanem Point, 1.5 mi. SW of Protection Island	WA
107612	Kanem Point, 1.5 mi SW of Protection Island (depth 22 ft), Washington Current	NOS	PUG1630_53	48.10765075683594	-122.97364807128906	:America/Los_Angeles	USA	knots	279	117	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanem Point, 1.5 mi. SW of Protection Island	WA
107613	Violet Point, 3.7 mi NW of Protection Island (depth 112 ft), Washington Current	NOS	PUG1631_4	48.161399841308594	-122.96810150146484	:America/Los_Angeles	USA	knots	304	107	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Violet Point, 3.7 mi. NW of Protection Island	WA
107614	Violet Point, 3.7 mi NW of Protection Island (depth 40 ft), Washington Current	NOS	PUG1631_26	48.161399841308594	-122.96810150146484	:America/Los_Angeles	USA	knots	297	103	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Violet Point, 3.7 mi. NW of Protection Island	WA
107615	Violet Point, 3.7 mi NW of Protection Island (depth 17 ft), Washington Current	NOS	PUG1631_33	48.161399841308594	-122.96810150146484	:America/Los_Angeles	USA	knots	290	102	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Violet Point, 3.7 mi. NW of Protection Island	WA
107616	Smith Island, 5.5 mi WNW of (depth 220 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1632_14	48.32455062866211	-122.96475219726562	:America/Los_Angeles	USA	knots	253	78	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 5.5 mi. WNW of	WA
107617	Smith Island, 5.5 mi WNW of (depth 141 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1632_26	48.32455062866211	-122.96475219726562	:America/Los_Angeles	USA	knots	253	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 5.5 mi. WNW of	WA
107618	Smith Island, 5.5 mi WNW of (depth 43 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1632_41	48.32455062866211	-122.96475219726562	:America/Los_Angeles	USA	knots	255	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 5.5 mi. WNW of	WA
107619	Smith Island, 3.4 mi ESE of (depth 134 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1634_1	48.29637908935547	-122.77632141113281	:America/Los_Angeles	USA	knots	230	102	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
107620	Smith Island, 3.4 mi ESE of (depth 56 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1634_25	48.29637908935547	-122.77632141113281	:America/Los_Angeles	USA	knots	218	109	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.617	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
107621	Smith Island, 3.4 mi ESE of (depth 20 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1634_36	48.29637908935547	-122.77632141113281	:America/Los_Angeles	USA	knots	218	114	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.663	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
107622	New Dungeness Light, 2.8 mi NNW of (depth 360 ft), Washington Current	NOS	PUG1635_11	48.23347854614258	-123.13343048095703	:America/Los_Angeles	USA	knots	244	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Dungeness Light, 2.8 mi. NNW of	WA
107623	New Dungeness Light, 2.8 mi NNW of (depth 71 ft), Washington Current	NOS	PUG1635_55	48.23347854614258	-123.13343048095703	:America/Los_Angeles	USA	knots	273	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.346	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Dungeness Light, 2.8 mi. NNW of	WA
107624	New Dungeness Light, 2.8 mi NNW of (depth 52 ft), Washington Current	NOS	PUG1635_58	48.23347854614258	-123.13343048095703	:America/Los_Angeles	USA	knots	273	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.405	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Dungeness Light, 2.8 mi. NNW of	WA
107625	Discovery Island, 7.6 mi SSE of (depth 244 ft), Washington Current	NOS	PUG1636_1	48.30015182495117	-123.16716003417969	:America/Los_Angeles	USA	knots	220	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 7.6 mi. SSE of	WA
107626	Discovery Island, 7.6 mi SSE of (depth 120 ft), Washington Current	NOS	PUG1636_20	48.30015182495117	-123.16716003417969	:America/Los_Angeles	USA	knots	245	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 7.6 mi. SSE of	WA
107627	Discovery Island, 7.6 mi SSE of (depth 28 ft), Washington Current	NOS	PUG1636_34	48.30015182495117	-123.16716003417969	:America/Los_Angeles	USA	knots	240	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.187	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 7.6 mi. SSE of	WA
107628	Ediz Hook Light, 5.3 mi ENE of (depth 179 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1637_5	48.18227005004883	-123.28150177001953	:America/Los_Angeles	USA	knots	260	78	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.385	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 5.3 mi. ENE of	WA
107629	Ediz Hook Light, 5.3 mi ENE of (depth 28 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1637_28	48.18227005004883	-123.28150177001953	:America/Los_Angeles	USA	knots	258	88	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.59	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 5.3 mi. ENE of	WA
107630	Ediz Hook Light, 5.3 mi ENE of (depth 22 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1637_29	48.18227005004883	-123.28150177001953	:America/Los_Angeles	USA	knots	257	88	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.517	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 5.3 mi. ENE of	WA
107631	Ediz Hook Light, 1.2 mi N of (depth 184 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1638_7	48.166690826416016	-123.41581726074219	:America/Los_Angeles	USA	knots	279	112	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 1.2 miles N of	WA
107632	Ediz Hook Light, 1.2 mi N of (depth 85 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1638_17	48.166690826416016	-123.41581726074219	:America/Los_Angeles	USA	knots	282	90	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.293	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 1.2 miles N of	WA
107633	Ediz Hook Light, 1.2 mi N of (depth 36 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1638_22	48.166690826416016	-123.41581726074219	:America/Los_Angeles	USA	knots	283	89	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.358	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 1.2 miles N of	WA
107634	Angeles Pt., 2 mi NNE of (depth 61 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1639_1	48.176998138427734	-123.52694702148438	:America/Los_Angeles	USA	knots	304	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Angeles Pt., 2 mi. NNE of	WA
107635	Angeles Pt., 2 mi NNE of (depth 25 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1639_12	48.176998138427734	-123.52694702148438	:America/Los_Angeles	USA	knots	300	75	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.257	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Angeles Pt., 2 mi. NNE of	WA
107636	Angeles Pt., 2 mi NNE of (depth 12 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1639_16	48.176998138427734	-123.52694702148438	:America/Los_Angeles	USA	knots	300	75	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Angeles Pt., 2 mi. NNE of	WA
107637	Race Rocks, 4.5 mi S of (depth 394 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1640_1	48.223201751708984	-123.53230285644531	:America/Los_Angeles	USA	knots	\N	89.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.277	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Race Rocks, 4.5 mi. S of	WA
107638	Race Rocks, 4.5 mi S of (depth 237 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1640_9	48.223201751708984	-123.53230285644531	:America/Los_Angeles	USA	knots	274	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Race Rocks, 4.5 mi. S of	WA
107639	Race Rocks, 4.5 mi S of (depth 60 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1640_18	48.223201751708984	-123.53230285644531	:America/Los_Angeles	USA	knots	268	91	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.596	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Race Rocks, 4.5 mi. S of	WA
107640	Pillar Point, 6 mi NNE of (depth 297 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1641_36	48.29999923706055	-124.03739929199219	:America/Los_Angeles	USA	knots	273	93	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point, 6 mi. NNE of	WA
107641	Pillar Point, 6 mi NNE of (depth 74 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1641_70	48.29999923706055	-124.03739929199219	:America/Los_Angeles	USA	knots	293	114	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.417	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point, 6 mi. NNE of	WA
107642	Pillar Point, 6 mi NNE of (depth 41 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1641_75	48.29999923706055	-124.03739929199219	:America/Los_Angeles	USA	knots	290	115	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.288	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point, 6 mi. NNE of	WA
107643	Strait of Juan de Fuca entrance (depth 102 ft), Washington Current	NOS	PUG1642_49	48.449981689453125	-124.58380126953125	:America/Los_Angeles	USA	knots	306	113	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.564	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Juan de Fuca Entrance	WA
107644	Strait of Juan de Fuca entrance (depth 89 ft), Washington Current	NOS	PUG1642_50	48.449981689453125	-124.58380126953125	:America/Los_Angeles	USA	knots	\N	125.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.574	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Juan de Fuca Entrance	WA
107645	Deception Pass (Narrows) (depth 123 ft), Rosario Strait, Washington Current	NOS	PUG1701_1	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	102.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.338	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107646	Deception Pass (Narrows) (depth 119 ft), Rosario Strait, Washington Current	NOS	PUG1701_2	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	101.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.527	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107647	Deception Pass (Narrows) (depth 116 ft), Rosario Strait, Washington Current	NOS	PUG1701_3	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	100.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.618	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107648	Deception Pass (Narrows) (depth 113 ft), Rosario Strait, Washington Current	NOS	PUG1701_4	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	100	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107649	Deception Pass (Narrows) (depth 110 ft), Rosario Strait, Washington Current	NOS	PUG1701_5	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	99.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.685	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107650	Deception Pass (Narrows) (depth 106 ft), Rosario Strait, Washington Current	NOS	PUG1701_6	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	98.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.697	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107651	Deception Pass (Narrows) (depth 103 ft), Rosario Strait, Washington Current	NOS	PUG1701_7	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	97.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.704	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107652	Deception Pass (Narrows) (depth 100 ft), Rosario Strait, Washington Current	NOS	PUG1701_8	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	97.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.708	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107653	Deception Pass (Narrows) (depth 96 ft), Rosario Strait, Washington Current	NOS	PUG1701_9	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	96.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.708	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107654	Deception Pass (Narrows) (depth 93 ft), Rosario Strait, Washington Current	NOS	PUG1701_10	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	95.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.702	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107655	Deception Pass (Narrows) (depth 90 ft), Rosario Strait, Washington Current	NOS	PUG1701_11	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	94.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.691	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107656	Deception Pass (Narrows) (depth 87 ft), Rosario Strait, Washington Current	NOS	PUG1701_12	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	94.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.675	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107657	Deception Pass (Narrows) (depth 83 ft), Rosario Strait, Washington Current	NOS	PUG1701_13	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	93.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107658	Deception Pass (Narrows) (depth 80 ft), Rosario Strait, Washington Current	NOS	PUG1701_14	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	93.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.645	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107659	Deception Pass (Narrows) (depth 77 ft), Rosario Strait, Washington Current	NOS	PUG1701_15	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	93.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.633	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107660	Deception Pass (Narrows) (depth 73 ft), Rosario Strait, Washington Current	NOS	PUG1701_16	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	93	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.625	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107661	Deception Pass (Narrows) (depth 70 ft), Rosario Strait, Washington Current	NOS	PUG1701_17	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	92.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107662	Deception Pass (Narrows) (depth 67 ft), Rosario Strait, Washington Current	NOS	PUG1701_18	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	270	96	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.619	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107663	Deception Pass (Narrows) (depth 64 ft), Rosario Strait, Washington Current	NOS	PUG1701_19	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	92.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.619	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107664	Deception Pass (Narrows) (depth 60 ft), Rosario Strait, Washington Current	NOS	PUG1701_20	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	93	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.623	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107665	Deception Pass (Narrows) (depth 57 ft), Rosario Strait, Washington Current	NOS	PUG1701_21	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	93.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.628	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107666	Deception Pass (Narrows) (depth 54 ft), Rosario Strait, Washington Current	NOS	PUG1701_22	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	93.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.634	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107667	Deception Pass (Narrows) (depth 50 ft), Rosario Strait, Washington Current	NOS	PUG1701_23	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	93.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.641	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107668	Deception Pass (Narrows) (depth 47 ft), Rosario Strait, Washington Current	NOS	PUG1701_24	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	270	98	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.647	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107669	Deception Pass (Narrows) (depth 44 ft), Rosario Strait, Washington Current	NOS	PUG1701_25	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	94.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.653	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107670	Deception Pass (Narrows) (depth 41 ft), Rosario Strait, Washington Current	NOS	PUG1701_26	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	95.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.657	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107671	Deception Pass (Narrows) (depth 37 ft), Rosario Strait, Washington Current	NOS	PUG1701_27	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	95.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107672	Deception Pass (Narrows) (depth 34 ft), Rosario Strait, Washington Current	NOS	PUG1701_28	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	96.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107673	Deception Pass (Narrows) (depth 31 ft), Rosario Strait, Washington Current	NOS	PUG1701_29	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	97.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.656	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107674	Deception Pass (Narrows) (depth 28 ft), Rosario Strait, Washington Current	NOS	PUG1701_30	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	98.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.649	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107675	Deception Pass (Narrows) (depth 24 ft), Rosario Strait, Washington Current	NOS	PUG1701_31	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	99.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.638	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107676	Deception Pass (Narrows) (depth 21 ft), Rosario Strait, Washington Current	NOS	PUG1701_32	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	100.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.624	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107677	Deception Pass (Narrows) (depth 18 ft), Rosario Strait, Washington Current	NOS	PUG1701_33	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	277	108	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.618	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107678	Deception Pass (Narrows) (depth 14 ft), Rosario Strait, Washington Current	NOS	PUG1701_34	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	102.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.652	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
107679	Rosario Strait (depth 195 ft), Washington Current	NOS	PUG1702_1	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	340.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107680	Rosario Strait (depth 185 ft), Washington Current	NOS	PUG1702_2	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	345.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107681	Rosario Strait (depth 175 ft), Washington Current	NOS	PUG1702_3	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	349	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107682	Rosario Strait (depth 165 ft), Washington Current	NOS	PUG1702_4	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	352.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107683	Rosario Strait (depth 155 ft), Washington Current	NOS	PUG1702_5	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	354.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.201	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107684	Rosario Strait (depth 145 ft), Washington Current	NOS	PUG1702_6	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	357	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107685	Rosario Strait (depth 135 ft), Washington Current	NOS	PUG1702_7	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	358.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.276	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107686	Rosario Strait (depth 126 ft), Washington Current	NOS	PUG1702_8	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	0.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.311	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107687	Rosario Strait (depth 116 ft), Washington Current	NOS	PUG1702_9	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	183	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.345	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107688	Rosario Strait (depth 106 ft), Washington Current	NOS	PUG1702_10	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	2.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.376	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107689	Rosario Strait (depth 96 ft), Washington Current	NOS	PUG1702_11	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	3.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.406	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107690	Rosario Strait (depth 86 ft), Washington Current	NOS	PUG1702_12	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	3.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.433	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107691	Rosario Strait (depth 76 ft), Washington Current	NOS	PUG1702_13	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	187	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.458	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107692	Rosario Strait (depth 67 ft), Washington Current	NOS	PUG1702_14	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	4.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.478	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107693	Rosario Strait (depth 57 ft), Washington Current	NOS	PUG1702_15	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	4.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.493	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107694	Rosario Strait (depth 47 ft), Washington Current	NOS	PUG1702_16	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	190	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.501	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107695	Rosario Strait (depth 37 ft), Washington Current	NOS	PUG1702_17	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.501	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
107696	San Juan Channel, south entrance (depth 114 ft), Washington Current	NOS	PUG1703_13	48.46100997924805	-122.9520263671875	:America/Los_Angeles	USA	knots	169	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 141.0 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan Channel, south entrance	WA
107697	San Juan Channel, south entrance (depth 92 ft), Washington Current	NOS	PUG1703_16	48.46100997924805	-122.9520263671875	:America/Los_Angeles	USA	knots	169	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.507	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan Channel, south entrance	WA
107698	San Juan Channel, south entrance (depth 75 ft), Washington Current	NOS	PUG1703_17	48.46100997924805	-122.9520263671875	:America/Los_Angeles	USA	knots	168	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.494	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan Channel, south entrance	WA
107699	Peavine Pass, west entrance (depth 48 ft), Rosario Strait, Washington Current	NOS	PUG1704_1	48.58707809448242	-122.81925964355469	:America/Los_Angeles	USA	knots	235	50	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.401	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peavine Pass, west entrance	WA
107700	Peavine Pass, west entrance (depth 19 ft), Rosario Strait, Washington Current	NOS	PUG1704_10	48.58707809448242	-122.81925964355469	:America/Los_Angeles	USA	knots	232	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.613	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peavine Pass, west entrance	WA
107701	Peavine Pass, west entrance (depth 9 ft), Rosario Strait, Washington Current	NOS	PUG1704_13	48.58707809448242	-122.81925964355469	:America/Los_Angeles	USA	knots	231	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.629	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peavine Pass, west entrance	WA
107702	Obstruction Pass, north of Obstruction Island (depth 54 ft), Washington Current	NOS	PUG1705_1	48.603271484375	-122.81272888183594	:America/Los_Angeles	USA	knots	274	100	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Obstruction Pass, north of Obstruction Island	WA
107703	Obstruction Pass, north of Obstruction Island (depth 15 ft), Washington Current	NOS	PUG1705_13	48.603271484375	-122.81272888183594	:America/Los_Angeles	USA	knots	286	88	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Obstruction Pass, north of Obstruction Island	WA
107704	Obstruction Pass, north of Obstruction Island (depth 8 ft), Washington Current	NOS	PUG1705_15	48.603271484375	-122.81272888183594	:America/Los_Angeles	USA	knots	286	87	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Obstruction Pass, north of Obstruction Island	WA
107705	Peapod Rocks Light, 1.2 nmi south of (depth 170 ft), Rosario Strait, Washington Current	NOS	PUG1706_1	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	218	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
107706	Peapod Rocks Light, 1.2 nmi south of (depth 157 ft), Rosario Strait, Washington Current	NOS	PUG1706_2	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	\N	36.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
107707	Peapod Rocks Light, 1.2 nmi south of (depth 144 ft), Rosario Strait, Washington Current	NOS	PUG1706_3	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	\N	35.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
107708	Peapod Rocks Light, 1.2 nmi south of (depth 131 ft), Rosario Strait, Washington Current	NOS	PUG1706_4	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	\N	34.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.225	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
107709	Peapod Rocks Light, 1.2 nmi south of (depth 118 ft), Rosario Strait, Washington Current	NOS	PUG1706_5	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	\N	33.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.246	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
107710	Peapod Rocks Light, 1.2 nmi south of (depth 104 ft), Rosario Strait, Washington Current	NOS	PUG1706_6	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	\N	32.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.264	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
107711	Peapod Rocks Light, 1.2 nmi south of (depth 91 ft), Rosario Strait, Washington Current	NOS	PUG1706_7	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	\N	31.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
107712	Peapod Rocks Light, 1.2 nmi south of (depth 78 ft), Rosario Strait, Washington Current	NOS	PUG1706_8	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	218	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.296	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
107713	Peapod Rocks Light, 1.2 nmi south of (depth 65 ft), Rosario Strait, Washington Current	NOS	PUG1706_9	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	\N	30.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
107714	Peapod Rocks Light, 1.2 nmi south of (depth 52 ft), Rosario Strait, Washington Current	NOS	PUG1706_10	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	\N	30.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.333	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
107715	Peapod Rocks Light, 1.2 nmi south of (depth 39 ft), Rosario Strait, Washington Current	NOS	PUG1706_11	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	220	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.358	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
107792	Wasp Passage narrows (depth 60 ft), San Juan Channel, Washington Current	NOS	PUG1721_2	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	66	264	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107716	Sinclair Island, 1.0 nmi NE of (depth 171 ft), Rosario Strait, Washington Current	NOS	PUG1707_6	48.64419937133789	-122.65872192382812	:America/Los_Angeles	USA	knots	131	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.309	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sinclair Island, 1.0 nm NE of	WA
107717	Sinclair Island, 1.0 nmi NE of (depth 99 ft), Rosario Strait, Washington Current	NOS	PUG1707_17	48.64419937133789	-122.65872192382812	:America/Los_Angeles	USA	knots	131	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.292	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sinclair Island, 1.0 nm NE of	WA
107718	Sinclair Island, 1.0 nmi NE of (depth 26 ft), Rosario Strait, Washington Current	NOS	PUG1707_28	48.64419937133789	-122.65872192382812	:America/Los_Angeles	USA	knots	131	324	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.305	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sinclair Island, 1.0 nm NE of	WA
107719	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 234 ft), Washington Current	NOS	PUG1708_1	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	332.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
107720	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 220 ft), Washington Current	NOS	PUG1708_2	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	334.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
107721	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 207 ft), Washington Current	NOS	PUG1708_3	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	335.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
107722	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 194 ft), Washington Current	NOS	PUG1708_4	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	337.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
107723	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 181 ft), Washington Current	NOS	PUG1708_5	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	338	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
107724	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 168 ft), Washington Current	NOS	PUG1708_6	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	338.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
107725	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 155 ft), Washington Current	NOS	PUG1708_7	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	339.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
107726	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 142 ft), Washington Current	NOS	PUG1708_8	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	340.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
107727	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 129 ft), Washington Current	NOS	PUG1708_9	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	340.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
107728	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 115 ft), Washington Current	NOS	PUG1708_10	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	152	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
107729	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 102 ft), Washington Current	NOS	PUG1708_11	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	341.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
107730	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 89 ft), Washington Current	NOS	PUG1708_12	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	341.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
107731	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 76 ft), Washington Current	NOS	PUG1708_13	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	341.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
107732	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 63 ft), Washington Current	NOS	PUG1708_14	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	152	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
107733	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 50 ft), Washington Current	NOS	PUG1708_15	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	340.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
107734	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 37 ft), Washington Current	NOS	PUG1708_16	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	151	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
107735	Clark Island, 1.6 nmi north of (depth 180 ft), Rosario Strait, Washington Current	NOS	PUG1709_10	48.731258392333984	-122.77337646484375	:America/Los_Angeles	USA	knots	150	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clark Island, 1.6 nm north of	WA
107736	Clark Island, 1.6 nmi north of (depth 48 ft), Rosario Strait, Washington Current	NOS	PUG1709_30	48.731258392333984	-122.77337646484375	:America/Los_Angeles	USA	knots	157	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clark Island, 1.6 nm north of	WA
107737	Clark Island, 1.6 nmi north of (depth 29 ft), Rosario Strait, Washington Current	NOS	PUG1709_33	48.731258392333984	-122.77337646484375	:America/Los_Angeles	USA	knots	159	335	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clark Island, 1.6 nm north of	WA
107738	Hale Passage, east of Lummi Point (depth 44 ft), Rosario Strait, Washington Current	NOS	PUG1710_3	48.7348518371582	-122.68016815185547	:America/Los_Angeles	USA	knots	158	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east of Lummi Point	WA
107739	Hale Passage, east of Lummi Point (depth 27 ft), Rosario Strait, Washington Current	NOS	PUG1710_8	48.7348518371582	-122.68016815185547	:America/Los_Angeles	USA	knots	167	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east of Lummi Point	WA
107740	Hale Passage, east of Lummi Point (depth 8 ft), Rosario Strait, Washington Current	NOS	PUG1710_14	48.7348518371582	-122.68016815185547	:America/Los_Angeles	USA	knots	177	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east of Lummi Point	WA
107741	Matia Island, west of (depth 336 ft), Rosario Strait, Washington Current	NOS	PUG1711_4	48.774879455566406	-122.84097290039062	:America/Los_Angeles	USA	knots	135	299	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matia Island, west of	WA
107742	Matia Island, west of (depth 87 ft), Rosario Strait, Washington Current	NOS	PUG1711_23	48.774879455566406	-122.84097290039062	:America/Los_Angeles	USA	knots	149	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matia Island, west of	WA
107743	Matia Island, west of (depth 47 ft), Rosario Strait, Washington Current	NOS	PUG1711_26	48.774879455566406	-122.84097290039062	:America/Los_Angeles	USA	knots	153	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.144	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matia Island, west of	WA
107744	Parker Reef Light, north of (depth 189 ft), Rosario Strait, Washington Current	NOS	PUG1712_1	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	108.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107745	Parker Reef Light, north of (depth 182 ft), Rosario Strait, Washington Current	NOS	PUG1712_2	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	107.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107746	Parker Reef Light, north of (depth 176 ft), Rosario Strait, Washington Current	NOS	PUG1712_3	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	105.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107747	Parker Reef Light, north of (depth 169 ft), Rosario Strait, Washington Current	NOS	PUG1712_4	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	103.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107748	Parker Reef Light, north of (depth 163 ft), Rosario Strait, Washington Current	NOS	PUG1712_5	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	102.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107749	Parker Reef Light, north of (depth 156 ft), Rosario Strait, Washington Current	NOS	PUG1712_6	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	100.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107750	Parker Reef Light, north of (depth 150 ft), Rosario Strait, Washington Current	NOS	PUG1712_7	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	99.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107751	Parker Reef Light, north of (depth 143 ft), Rosario Strait, Washington Current	NOS	PUG1712_8	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	97.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107752	Parker Reef Light, north of (depth 136 ft), Rosario Strait, Washington Current	NOS	PUG1712_9	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	96.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107753	Parker Reef Light, north of (depth 130 ft), Rosario Strait, Washington Current	NOS	PUG1712_10	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	280	91	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107754	Parker Reef Light, north of (depth 123 ft), Rosario Strait, Washington Current	NOS	PUG1712_11	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	93.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107755	Parker Reef Light, north of (depth 117 ft), Rosario Strait, Washington Current	NOS	PUG1712_12	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	91.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107756	Parker Reef Light, north of (depth 110 ft), Rosario Strait, Washington Current	NOS	PUG1712_13	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	90.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107757	Parker Reef Light, north of (depth 104 ft), Rosario Strait, Washington Current	NOS	PUG1712_14	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	89	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107758	Parker Reef Light, north of (depth 97 ft), Rosario Strait, Washington Current	NOS	PUG1712_15	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	87.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107759	Parker Reef Light, north of (depth 90 ft), Rosario Strait, Washington Current	NOS	PUG1712_16	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	86.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107760	Parker Reef Light, north of (depth 84 ft), Rosario Strait, Washington Current	NOS	PUG1712_17	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	85.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107761	Parker Reef Light, north of (depth 77 ft), Rosario Strait, Washington Current	NOS	PUG1712_18	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	84.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107762	Parker Reef Light, north of (depth 71 ft), Rosario Strait, Washington Current	NOS	PUG1712_19	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	83.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107763	Parker Reef Light, north of (depth 64 ft), Rosario Strait, Washington Current	NOS	PUG1712_20	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	82.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107764	Parker Reef Light, north of (depth 58 ft), Rosario Strait, Washington Current	NOS	PUG1712_21	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	81.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107765	Parker Reef Light, north of (depth 51 ft), Rosario Strait, Washington Current	NOS	PUG1712_22	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	80.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.172	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107766	Parker Reef Light, north of (depth 45 ft), Rosario Strait, Washington Current	NOS	PUG1712_23	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	257	81	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.205	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107767	Parker Reef Light, north of (depth 38 ft), Rosario Strait, Washington Current	NOS	PUG1712_24	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	78.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.237	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107768	Parker Reef Light, north of (depth 31 ft), Rosario Strait, Washington Current	NOS	PUG1712_25	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	254	79	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.268	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107769	Parker Reef Light, north of (depth 25 ft), Rosario Strait, Washington Current	NOS	PUG1712_26	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	75.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.272	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
107770	Patos Island, south of Toe Point (depth 63 ft), Rosario Strait, Washington Current	NOS	PUG1713_10	48.77206039428711	-122.93370056152344	:America/Los_Angeles	USA	knots	196	46	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.267	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island, south of Toe Point	WA
107771	Patos Island, south of Toe Point (depth 30 ft), Rosario Strait, Washington Current	NOS	PUG1713_20	48.77206039428711	-122.93370056152344	:America/Los_Angeles	USA	knots	191	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.356	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island, south of Toe Point	WA
107772	Patos Island, south of Toe Point (depth 14 ft), Rosario Strait, Washington Current	NOS	PUG1713_25	48.77206039428711	-122.93370056152344	:America/Los_Angeles	USA	knots	188	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.396	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island, south of Toe Point	WA
107773	Patos Island Light, 1.4 nmi west of (depth 191 ft), Rosario Strait, Washington Current	NOS	PUG1714_16	48.773128509521484	-123.00579071044922	:America/Los_Angeles	USA	knots	225	40	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.419	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island Light, 1.4 nm west of	WA
107774	Patos Island Light, 1.4 nmi west of (depth 99 ft), Rosario Strait, Washington Current	NOS	PUG1714_23	48.773128509521484	-123.00579071044922	:America/Los_Angeles	USA	knots	215	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.469	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island Light, 1.4 nm west of	WA
107775	Patos Island Light, 1.4 nmi west of (depth 46 ft), Rosario Strait, Washington Current	NOS	PUG1714_27	48.773128509521484	-123.00579071044922	:America/Los_Angeles	USA	knots	209	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.443	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island Light, 1.4 nm west of	WA
107776	President Channel, east of Point Disney (depth 200 ft), Washington Current	NOS	PUG1715_28	48.6733512878418	-123.00598907470703	:America/Los_Angeles	USA	knots	\N	41.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Channel, East of Point Disney	WA
107777	President Channel, east of Point Disney (depth 108 ft), Washington Current	NOS	PUG1715_35	48.6733512878418	-123.00598907470703	:America/Los_Angeles	USA	knots	219	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.369	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Channel, East of Point Disney	WA
107778	President Channel, east of Point Disney (depth 69 ft), Washington Current	NOS	PUG1715_38	48.6733512878418	-123.00598907470703	:America/Los_Angeles	USA	knots	218	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.502	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Channel, East of Point Disney	WA
107779	Turn Point, Boundary Pass (depth 208 ft), Washington Current	NOS	PUG1717_28	48.69121170043945	-123.24501037597656	:America/Los_Angeles	USA	knots	232	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.407	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point, Boundary Pass	WA
107780	Turn Point, Boundary Pass (depth 168 ft), Washington Current	NOS	PUG1717_31	48.69121170043945	-123.24501037597656	:America/Los_Angeles	USA	knots	235	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.393	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point, Boundary Pass	WA
107781	Turn Point, Boundary Pass (depth 116 ft), Washington Current	NOS	PUG1717_35	48.69121170043945	-123.24501037597656	:America/Los_Angeles	USA	knots	236	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.297	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point, Boundary Pass	WA
107782	Haro Strait, 1.2 nmi west of Kellett Bluff (depth 204 ft), Washington Current	NOS	PUG1718_29	48.58871841430664	-123.225830078125	:America/Los_Angeles	USA	knots	178	340	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haro Strait, 1.2 nm west of Kellett Bluff	WA
107783	Haro Strait, 1.2 nmi west of Kellett Bluff (depth 106 ft), Washington Current	NOS	PUG1718_34	48.58871841430664	-123.225830078125	:America/Los_Angeles	USA	knots	179	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haro Strait, 1.2 nm west of Kellett Bluff	WA
107784	Haro Strait, 1.2 nmi west of Kellett Bluff (depth 66 ft), Washington Current	NOS	PUG1718_36	48.58871841430664	-123.225830078125	:America/Los_Angeles	USA	knots	179	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.384	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haro Strait, 1.2 nm west of Kellett Bluff	WA
107785	Spieden Channel, north of Limestone Point (depth 205 ft), Washington Current	NOS	PUG1719_7	48.627830505371094	-123.11164855957031	:America/Los_Angeles	USA	knots	282	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.341	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spieden Channel, north of Limestone Point	WA
107786	Spieden Channel, north of Limestone Point (depth 60 ft), Washington Current	NOS	PUG1719_18	48.627830505371094	-123.11164855957031	:America/Los_Angeles	USA	knots	282	85	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.634	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spieden Channel, north of Limestone Point	WA
107787	Spieden Channel, north of Limestone Point (depth 47 ft), Washington Current	NOS	PUG1719_19	48.627830505371094	-123.11164855957031	:America/Los_Angeles	USA	knots	281	85	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.665	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spieden Channel, north of Limestone Point	WA
107788	Spring Passage, south entrance (depth 62 ft), San Juan Channel, Washington Current	NOS	PUG1720_11	48.611541748046875	-123.03410339355469	:America/Los_Angeles	USA	knots	151	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Passage, south entrance	WA
107789	Spring Passage, south entrance (depth 26 ft), San Juan Channel, Washington Current	NOS	PUG1720_22	48.611541748046875	-123.03410339355469	:America/Los_Angeles	USA	knots	149	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Passage, south entrance	WA
107790	Spring Passage, south entrance (depth 13 ft), San Juan Channel, Washington Current	NOS	PUG1720_26	48.611541748046875	-123.03410339355469	:America/Los_Angeles	USA	knots	148	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Passage, south entrance	WA
107791	Wasp Passage narrows (depth 64 ft), San Juan Channel, Washington Current	NOS	PUG1721_1	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	256.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107793	Wasp Passage narrows (depth 57 ft), San Juan Channel, Washington Current	NOS	PUG1721_3	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	255.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107794	Wasp Passage narrows (depth 54 ft), San Juan Channel, Washington Current	NOS	PUG1721_4	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	254.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107795	Wasp Passage narrows (depth 50 ft), San Juan Channel, Washington Current	NOS	PUG1721_5	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	254.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107796	Wasp Passage narrows (depth 47 ft), San Juan Channel, Washington Current	NOS	PUG1721_6	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	253.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107797	Wasp Passage narrows (depth 44 ft), San Juan Channel, Washington Current	NOS	PUG1721_7	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	253	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107798	Wasp Passage narrows (depth 41 ft), San Juan Channel, Washington Current	NOS	PUG1721_8	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	252.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107799	Wasp Passage narrows (depth 37 ft), San Juan Channel, Washington Current	NOS	PUG1721_9	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	251.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107800	Wasp Passage narrows (depth 34 ft), San Juan Channel, Washington Current	NOS	PUG1721_10	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	251.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107801	Wasp Passage narrows (depth 31 ft), San Juan Channel, Washington Current	NOS	PUG1721_11	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	62	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107802	Wasp Passage narrows (depth 27 ft), San Juan Channel, Washington Current	NOS	PUG1721_12	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	250.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107803	Wasp Passage narrows (depth 24 ft), San Juan Channel, Washington Current	NOS	PUG1721_13	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	249.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107804	Wasp Passage narrows (depth 21 ft), San Juan Channel, Washington Current	NOS	PUG1721_14	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	249.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107805	Wasp Passage narrows (depth 18 ft), San Juan Channel, Washington Current	NOS	PUG1721_15	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	248.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107806	Wasp Passage narrows (depth 14 ft), San Juan Channel, Washington Current	NOS	PUG1721_16	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	248.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107807	Wasp Passage narrows (depth 11 ft), San Juan Channel, Washington Current	NOS	PUG1721_17	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	60	256	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
107808	Harney Channel, north of Point Hudson (depth 99 ft), San Juan Channel, Washington Current	NOS	PUG1722_1	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	257.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107809	Harney Channel, north of Point Hudson (depth 95 ft), San Juan Channel, Washington Current	NOS	PUG1722_2	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	257.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107810	Harney Channel, north of Point Hudson (depth 92 ft), San Juan Channel, Washington Current	NOS	PUG1722_3	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	258.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107811	Harney Channel, north of Point Hudson (depth 89 ft), San Juan Channel, Washington Current	NOS	PUG1722_4	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	259	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107812	Harney Channel, north of Point Hudson (depth 85 ft), San Juan Channel, Washington Current	NOS	PUG1722_5	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	259.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107813	Harney Channel, north of Point Hudson (depth 82 ft), San Juan Channel, Washington Current	NOS	PUG1722_6	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	72	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107814	Harney Channel, north of Point Hudson (depth 79 ft), San Juan Channel, Washington Current	NOS	PUG1722_7	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	260.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107815	Harney Channel, north of Point Hudson (depth 76 ft), San Juan Channel, Washington Current	NOS	PUG1722_8	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	260.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107816	Harney Channel, north of Point Hudson (depth 72 ft), San Juan Channel, Washington Current	NOS	PUG1722_9	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	260.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107817	Harney Channel, north of Point Hudson (depth 69 ft), San Juan Channel, Washington Current	NOS	PUG1722_10	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	260.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107818	Harney Channel, north of Point Hudson (depth 66 ft), San Juan Channel, Washington Current	NOS	PUG1722_11	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	260.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107819	Harney Channel, north of Point Hudson (depth 62 ft), San Juan Channel, Washington Current	NOS	PUG1722_12	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107863	Point Colville, 3.0 nmi east of (depth 165 ft), Rosario Strait, Washington Current	NOS	PUG1727_10	48.41249084472656	-122.7402572631836	:America/Los_Angeles	USA	knots	174	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.207	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 3.0 nm east of (Lawson Reef, 1 nm	WA
107820	Harney Channel, north of Point Hudson (depth 59 ft), San Juan Channel, Washington Current	NOS	PUG1722_13	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107821	Harney Channel, north of Point Hudson (depth 56 ft), San Juan Channel, Washington Current	NOS	PUG1722_14	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107822	Harney Channel, north of Point Hudson (depth 53 ft), San Juan Channel, Washington Current	NOS	PUG1722_15	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107823	Harney Channel, north of Point Hudson (depth 49 ft), San Juan Channel, Washington Current	NOS	PUG1722_16	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107824	Harney Channel, north of Point Hudson (depth 46 ft), San Juan Channel, Washington Current	NOS	PUG1722_17	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107825	Harney Channel, north of Point Hudson (depth 43 ft), San Juan Channel, Washington Current	NOS	PUG1722_18	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107826	Harney Channel, north of Point Hudson (depth 39 ft), San Juan Channel, Washington Current	NOS	PUG1722_19	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107827	Harney Channel, north of Point Hudson (depth 36 ft), San Juan Channel, Washington Current	NOS	PUG1722_20	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	78	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107828	Harney Channel, north of Point Hudson (depth 33 ft), San Juan Channel, Washington Current	NOS	PUG1722_21	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107829	Harney Channel, north of Point Hudson (depth 30 ft), San Juan Channel, Washington Current	NOS	PUG1722_22	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107830	Harney Channel, north of Point Hudson (depth 26 ft), San Juan Channel, Washington Current	NOS	PUG1722_23	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107831	Harney Channel, north of Point Hudson (depth 23 ft), San Juan Channel, Washington Current	NOS	PUG1722_24	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107832	Harney Channel, north of Point Hudson (depth 20 ft), San Juan Channel, Washington Current	NOS	PUG1722_25	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107833	Harney Channel, north of Point Hudson (depth 16 ft), San Juan Channel, Washington Current	NOS	PUG1722_26	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107834	Harney Channel, north of Point Hudson (depth 13 ft), San Juan Channel, Washington Current	NOS	PUG1722_27	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	78	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107835	Harney Channel, north of Point Hudson (depth 10 ft), San Juan Channel, Washington Current	NOS	PUG1722_28	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	260.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
107836	Upright Channel narrows (depth 136 ft), San Juan Channel, Washington Current	NOS	PUG1723_1	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	50.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.368	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107837	Upright Channel narrows (depth 129 ft), San Juan Channel, Washington Current	NOS	PUG1723_2	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	49.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107838	Upright Channel narrows (depth 123 ft), San Juan Channel, Washington Current	NOS	PUG1723_3	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	48.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.371	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107839	Upright Channel narrows (depth 116 ft), San Juan Channel, Washington Current	NOS	PUG1723_4	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	47.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.371	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107840	Upright Channel narrows (depth 110 ft), San Juan Channel, Washington Current	NOS	PUG1723_5	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	46.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.371	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107841	Upright Channel narrows (depth 103 ft), San Juan Channel, Washington Current	NOS	PUG1723_6	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	46.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107842	Upright Channel narrows (depth 97 ft), San Juan Channel, Washington Current	NOS	PUG1723_7	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	232	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.368	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107843	Upright Channel narrows (depth 90 ft), San Juan Channel, Washington Current	NOS	PUG1723_8	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	45.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.366	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107844	Upright Channel narrows (depth 84 ft), San Juan Channel, Washington Current	NOS	PUG1723_9	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	44.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.363	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107845	Upright Channel narrows (depth 77 ft), San Juan Channel, Washington Current	NOS	PUG1723_10	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	44.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.359	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107846	Upright Channel narrows (depth 70 ft), San Juan Channel, Washington Current	NOS	PUG1723_11	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	44.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.355	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107847	Upright Channel narrows (depth 64 ft), San Juan Channel, Washington Current	NOS	PUG1723_12	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	44.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107848	Upright Channel narrows (depth 57 ft), San Juan Channel, Washington Current	NOS	PUG1723_13	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	231	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.345	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107849	Upright Channel narrows (depth 51 ft), San Juan Channel, Washington Current	NOS	PUG1723_14	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	44.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.339	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107850	Upright Channel narrows (depth 44 ft), San Juan Channel, Washington Current	NOS	PUG1723_15	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	44.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.333	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107851	Upright Channel narrows (depth 38 ft), San Juan Channel, Washington Current	NOS	PUG1723_16	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	44	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107852	Upright Channel narrows (depth 31 ft), San Juan Channel, Washington Current	NOS	PUG1723_17	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	43.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107853	Upright Channel narrows (depth 24 ft), San Juan Channel, Washington Current	NOS	PUG1723_18	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	230	40	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.311	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
107854	South Haro Strait, south of Lime Kiln Light (depth 212 ft), Washington Current	NOS	PUG1724_27	48.49797058105469	-123.15989685058594	:America/Los_Angeles	USA	knots	145	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Haro Strait, south of Lime Kiln Light	WA
107855	South Haro Strait, south of Lime Kiln Light (depth 159 ft), Washington Current	NOS	PUG1724_29	48.49797058105469	-123.15989685058594	:America/Los_Angeles	USA	knots	144	315	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Haro Strait, south of Lime Kiln Light	WA
107856	South Haro Strait, south of Lime Kiln Light (depth 107 ft), Washington Current	NOS	PUG1724_31	48.49797058105469	-123.15989685058594	:America/Los_Angeles	USA	knots	147	310	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.226	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Haro Strait, south of Lime Kiln Light	WA
107857	Cherry Point, 1.8 nmi southeast of (depth 41 ft), Rosario Strait, Washington Current	NOS	PUG1725_10	48.83378982543945	-122.7279281616211	:America/Los_Angeles	USA	knots	167	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point, 1.8 nm southeast of	WA
107858	Cherry Point, 1.8 nmi southeast of (depth 24 ft), Rosario Strait, Washington Current	NOS	PUG1725_20	48.83378982543945	-122.7279281616211	:America/Los_Angeles	USA	knots	161	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point, 1.8 nm southeast of	WA
107859	Cherry Point, 1.8 nmi southeast of (depth 8 ft), Rosario Strait, Washington Current	NOS	PUG1725_30	48.83378982543945	-122.7279281616211	:America/Los_Angeles	USA	knots	156	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point, 1.8 nm southeast of	WA
107860	Strait of Georgia, 4.5 nmi SW of Point Roberts (depth 189 ft), Washington Current	NOS	PUG1726_11	48.93888854980469	-123.16513061523438	:America/Los_Angeles	USA	knots	107	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Georgia, 4.5 nm SW of Point Roberts	WA
107861	Strait of Georgia, 4.5 nmi SW of Point Roberts (depth 70 ft), Washington Current	NOS	PUG1726_29	48.93888854980469	-123.16513061523438	:America/Los_Angeles	USA	knots	120	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Georgia, 4.5 nm SW of Point Roberts	WA
107862	Strait of Georgia, 4.5 nmi SW of Point Roberts (depth 31 ft), Washington Current	NOS	PUG1726_35	48.93888854980469	-123.16513061523438	:America/Los_Angeles	USA	knots	129	332	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Georgia, 4.5 nm SW of Point Roberts	WA
107864	Point Colville, 3.0 nmi east of (depth 47 ft), Rosario Strait, Washington Current	NOS	PUG1727_28	48.41249084472656	-122.7402572631836	:America/Los_Angeles	USA	knots	186	20	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 3.0 nm east of (Lawson Reef, 1 nm	WA
107865	Point Colville, 3.0 nmi east of (depth 34 ft), Rosario Strait, Washington Current	NOS	PUG1727_30	48.41249084472656	-122.7402572631836	:America/Los_Angeles	USA	knots	186	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 3.0 nm east of (Lawson Reef, 1 nm	WA
107866	Point Colville, 1.4 nmi east of (depth 134 ft), Rosario Strait, Washington Current	NOS	PUG1728_10	48.41809844970703	-122.78119659423828	:America/Los_Angeles	USA	knots	205	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 1.4 nm east of	WA
107867	Point Colville, 1.4 nmi east of (depth 56 ft), Rosario Strait, Washington Current	NOS	PUG1728_22	48.41809844970703	-122.78119659423828	:America/Los_Angeles	USA	knots	207	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.244	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 1.4 nm east of	WA
107868	Point Colville, 1.4 nmi east of (depth 29 ft), Rosario Strait, Washington Current	NOS	PUG1728_26	48.41809844970703	-122.78119659423828	:America/Los_Angeles	USA	knots	207	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 1.4 nm east of	WA
107869	Belle Rock Light, east of (depth 115 ft), Rosario Strait, Washington Current	NOS	PUG1729_7	48.49679183959961	-122.73079681396484	:America/Los_Angeles	USA	knots	202	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Belle Rock Light, east of	WA
107870	Belle Rock Light, east of (depth 62 ft), Rosario Strait, Washington Current	NOS	PUG1729_15	48.49679183959961	-122.73079681396484	:America/Los_Angeles	USA	knots	211	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.331	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Belle Rock Light, east of	WA
107871	Belle Rock Light, east of (depth 23 ft), Rosario Strait, Washington Current	NOS	PUG1729_21	48.49679183959961	-122.73079681396484	:America/Los_Angeles	USA	knots	219	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.431	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Belle Rock Light, east of	WA
107872	Lopez Pass (depth 58 ft), Rosario Strait, Washington Current	NOS	PUG1730_4	48.479740142822266	-122.81890869140625	:America/Los_Angeles	USA	knots	92	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lopez Pass	WA
107873	Lopez Pass (depth 35 ft), Rosario Strait, Washington Current	NOS	PUG1730_11	48.479740142822266	-122.81890869140625	:America/Los_Angeles	USA	knots	91	276	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.368	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lopez Pass	WA
107874	Lopez Pass (depth 15 ft), Rosario Strait, Washington Current	NOS	PUG1730_17	48.479740142822266	-122.81890869140625	:America/Los_Angeles	USA	knots	90	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.385	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lopez Pass	WA
107875	Fauntleroy Point Light, east of (depth 93 ft), Rosario Strait, Washington Current	NOS	PUG1731_7	48.52158	-122.77066	:America/Los_Angeles	USA	knots	146	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fauntleroy Point Light, east of	WA
107876	Fauntleroy Point Light, east of (depth 54 ft), Rosario Strait, Washington Current	NOS	PUG1731_13	48.52158	-122.77066	:America/Los_Angeles	USA	knots	153	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.357	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fauntleroy Point Light, east of	WA
107877	Fauntleroy Point Light, east of (depth 21 ft), Rosario Strait, Washington Current	NOS	PUG1731_18	48.52158	-122.77066	:America/Los_Angeles	USA	knots	157	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.394	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fauntleroy Point Light, east of	WA
107878	Strawberry Island, west of (depth 164 ft), Rosario Strait, Washington Current	NOS	PUG1732_5	48.56095886230469	-122.75430297851562	:America/Los_Angeles	USA	knots	156	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strawberry Island, west of	WA
107879	Strawberry Island, west of (depth 46 ft), Rosario Strait, Washington Current	NOS	PUG1732_23	48.56095886230469	-122.75430297851562	:America/Los_Angeles	USA	knots	172	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.464	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strawberry Island, west of	WA
107880	Strawberry Island, west of (depth 33 ft), Rosario Strait, Washington Current	NOS	PUG1732_25	48.56095886230469	-122.75430297851562	:America/Los_Angeles	USA	knots	174	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.463	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strawberry Island, west of	WA
107925	Allan Pass (depth 21 ft), Rosario Strait, Washington Current	NOS	PUG1737_23	48.471588134765625	-122.69982147216797	:America/Los_Angeles	USA	knots	77	289	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.495	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allan Pass	WA
107881	Thatcher Pass (depth 146 ft), Rosario Strait, Washington Current	NOS	PUG1733_4	48.52743148803711	-122.80397033691406	:America/Los_Angeles	USA	knots	84	256	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.238	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thatcher Pass	WA
107882	Thatcher Pass (depth 61 ft), Rosario Strait, Washington Current	NOS	PUG1733_17	48.52743148803711	-122.80397033691406	:America/Los_Angeles	USA	knots	90	255	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.386	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thatcher Pass	WA
107883	Thatcher Pass (depth 28 ft), Rosario Strait, Washington Current	NOS	PUG1733_22	48.52743148803711	-122.80397033691406	:America/Los_Angeles	USA	knots	93	256	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.417	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thatcher Pass	WA
107884	Guemes Channel, west entrance (depth 53 ft), Rosario Strait, Washington Current	NOS	PUG1734_1	48.521240234375	-122.65218353271484	:America/Los_Angeles	USA	knots	253	85	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, West Entrance	WA
107885	Guemes Channel, west entrance (depth 24 ft), Rosario Strait, Washington Current	NOS	PUG1734_10	48.521240234375	-122.65218353271484	:America/Los_Angeles	USA	knots	253	83	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, West Entrance	WA
107886	Guemes Channel, west entrance (depth 11 ft), Rosario Strait, Washington Current	NOS	PUG1734_14	48.521240234375	-122.65218353271484	:America/Los_Angeles	USA	knots	252	83	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.739	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, West Entrance	WA
107887	Guemes Channel, east entrance (depth 52 ft), Rosario Strait, Washington Current	NOS	PUG1735_1	48.52769088745117	-122.60601043701172	:America/Los_Angeles	USA	knots	253	75	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, East Entrance	WA
107888	Guemes Channel, east entrance (depth 25 ft), Rosario Strait, Washington Current	NOS	PUG1735_9	48.52769088745117	-122.60601043701172	:America/Los_Angeles	USA	knots	263	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, East Entrance	WA
107889	Guemes Channel, east entrance (depth 9 ft), Rosario Strait, Washington Current	NOS	PUG1735_14	48.52769088745117	-122.60601043701172	:America/Los_Angeles	USA	knots	268	75	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, East Entrance	WA
107890	Saddle Bag Island Passage (depth 238 ft), Rosario Strait, Washington Current	NOS	PUG1736_1	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	7.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.333	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107891	Saddle Bag Island Passage (depth 232 ft), Rosario Strait, Washington Current	NOS	PUG1736_2	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	4.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107892	Saddle Bag Island Passage (depth 225 ft), Rosario Strait, Washington Current	NOS	PUG1736_3	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	1.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.308	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107893	Saddle Bag Island Passage (depth 218 ft), Rosario Strait, Washington Current	NOS	PUG1736_4	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	358.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.296	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107894	Saddle Bag Island Passage (depth 212 ft), Rosario Strait, Washington Current	NOS	PUG1736_5	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	356.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.283	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107895	Saddle Bag Island Passage (depth 205 ft), Rosario Strait, Washington Current	NOS	PUG1736_6	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	354.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.272	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107926	Allan Pass (depth 11 ft), Rosario Strait, Washington Current	NOS	PUG1737_26	48.471588134765625	-122.69982147216797	:America/Los_Angeles	USA	knots	75	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.475	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allan Pass	WA
107896	Saddle Bag Island Passage (depth 199 ft), Rosario Strait, Washington Current	NOS	PUG1736_7	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	353.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107897	Saddle Bag Island Passage (depth 192 ft), Rosario Strait, Washington Current	NOS	PUG1736_8	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	352.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.252	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107898	Saddle Bag Island Passage (depth 186 ft), Rosario Strait, Washington Current	NOS	PUG1736_9	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	351.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.244	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107899	Saddle Bag Island Passage (depth 179 ft), Rosario Strait, Washington Current	NOS	PUG1736_10	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	351.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.237	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107900	Saddle Bag Island Passage (depth 172 ft), Rosario Strait, Washington Current	NOS	PUG1736_11	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	351.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107901	Saddle Bag Island Passage (depth 166 ft), Rosario Strait, Washington Current	NOS	PUG1736_12	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	351.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.226	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107902	Saddle Bag Island Passage (depth 159 ft), Rosario Strait, Washington Current	NOS	PUG1736_13	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	351.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.221	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107903	Saddle Bag Island Passage (depth 153 ft), Rosario Strait, Washington Current	NOS	PUG1736_14	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	351.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.216	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107904	Saddle Bag Island Passage (depth 146 ft), Rosario Strait, Washington Current	NOS	PUG1736_15	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	352.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.211	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107905	Saddle Bag Island Passage (depth 140 ft), Rosario Strait, Washington Current	NOS	PUG1736_16	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	352.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.207	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107906	Saddle Bag Island Passage (depth 133 ft), Rosario Strait, Washington Current	NOS	PUG1736_17	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	353.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107907	Saddle Bag Island Passage (depth 127 ft), Rosario Strait, Washington Current	NOS	PUG1736_18	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	353.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107908	Saddle Bag Island Passage (depth 120 ft), Rosario Strait, Washington Current	NOS	PUG1736_19	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	353.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.191	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107909	Saddle Bag Island Passage (depth 113 ft), Rosario Strait, Washington Current	NOS	PUG1736_20	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	354.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107910	Saddle Bag Island Passage (depth 107 ft), Rosario Strait, Washington Current	NOS	PUG1736_21	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	354.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107911	Saddle Bag Island Passage (depth 100 ft), Rosario Strait, Washington Current	NOS	PUG1736_22	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	354.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.174	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107912	Saddle Bag Island Passage (depth 94 ft), Rosario Strait, Washington Current	NOS	PUG1736_23	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	354.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.167	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107913	Saddle Bag Island Passage (depth 87 ft), Rosario Strait, Washington Current	NOS	PUG1736_24	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	179	351	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107914	Saddle Bag Island Passage (depth 81 ft), Rosario Strait, Washington Current	NOS	PUG1736_25	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	353.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107915	Saddle Bag Island Passage (depth 74 ft), Rosario Strait, Washington Current	NOS	PUG1736_26	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	353.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.146	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107916	Saddle Bag Island Passage (depth 67 ft), Rosario Strait, Washington Current	NOS	PUG1736_27	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	352.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107917	Saddle Bag Island Passage (depth 61 ft), Rosario Strait, Washington Current	NOS	PUG1736_28	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	350.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107918	Saddle Bag Island Passage (depth 54 ft), Rosario Strait, Washington Current	NOS	PUG1736_29	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	349.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107919	Saddle Bag Island Passage (depth 48 ft), Rosario Strait, Washington Current	NOS	PUG1736_30	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	173	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107920	Saddle Bag Island Passage (depth 41 ft), Rosario Strait, Washington Current	NOS	PUG1736_31	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	346.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107921	Saddle Bag Island Passage (depth 35 ft), Rosario Strait, Washington Current	NOS	PUG1736_32	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	345.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.115	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107922	Saddle Bag Island Passage (depth 28 ft), Rosario Strait, Washington Current	NOS	PUG1736_33	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	345.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107923	Saddle Bag Island Passage (depth 22 ft), Rosario Strait, Washington Current	NOS	PUG1736_34	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	166	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
107924	Allan Pass (depth 93 ft), Rosario Strait, Washington Current	NOS	PUG1737_1	48.471588134765625	-122.69982147216797	:America/Los_Angeles	USA	knots	85	283	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allan Pass	WA
107927	Burrows Pass (depth 100 ft), Rosario Strait, Washington Current	NOS	PUG1738_1	48.48952102661133	-122.68672180175781	:America/Los_Angeles	USA	knots	95	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.465	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrows Pass	WA
107928	Burrows Pass (depth 28 ft), Rosario Strait, Washington Current	NOS	PUG1738_23	48.48952102661133	-122.68672180175781	:America/Los_Angeles	USA	knots	89	283	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.433	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrows Pass	WA
107929	Burrows Pass (depth 15 ft), Rosario Strait, Washington Current	NOS	PUG1738_27	48.48952102661133	-122.68672180175781	:America/Los_Angeles	USA	knots	87	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.423	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrows Pass	WA
107930	Bellingham Channel South (depth 118 ft), Rosario Strait, Washington Current	NOS	PUG1739_1	48.53963088989258	-122.68343353271484	:America/Los_Angeles	USA	knots	224	65	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel South	WA
107931	Bellingham Channel South (depth 33 ft), Rosario Strait, Washington Current	NOS	PUG1739_27	48.53963088989258	-122.68343353271484	:America/Los_Angeles	USA	knots	217	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel South	WA
107932	Bellingham Channel South (depth 19 ft), Rosario Strait, Washington Current	NOS	PUG1739_31	48.53963088989258	-122.68343353271484	:America/Los_Angeles	USA	knots	216	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.381	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel South	WA
107933	Bellingham Channel, off Cypress Head Light (depth 119 ft), Washington Current	NOS	PUG1740_10	48.55854034423828	-122.66175842285156	:America/Los_Angeles	USA	knots	194	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.302	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel, off Cypress Head Light	WA
107934	Bellingham Channel, off Cypress Head Light (depth 50 ft), Washington Current	NOS	PUG1740_17	48.55854034423828	-122.66175842285156	:America/Los_Angeles	USA	knots	191	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.457	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel, off Cypress Head Light	WA
107935	Bellingham Channel, off Cypress Head Light (depth 31 ft), Washington Current	NOS	PUG1740_19	48.55854034423828	-122.66175842285156	:America/Los_Angeles	USA	knots	190	20	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.484	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel, off Cypress Head Light	WA
107936	Bellingham Channel north entrance (depth 171 ft), Rosario Strait, Washington Current	NOS	PUG1741_5	48.592811584472656	-122.65767669677734	:America/Los_Angeles	USA	knots	212	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.341	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel North Entrance	WA
107937	Bellingham Channel north entrance (depth 47 ft), Rosario Strait, Washington Current	NOS	PUG1741_24	48.592811584472656	-122.65767669677734	:America/Los_Angeles	USA	knots	228	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.39	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel North Entrance	WA
107938	Bellingham Channel north entrance (depth 27 ft), Rosario Strait, Washington Current	NOS	PUG1741_27	48.592811584472656	-122.65767669677734	:America/Los_Angeles	USA	knots	230	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.377	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel North Entrance	WA
107939	Cattle Point, 1.2 nmi SE of (depth 117 ft), San Juan Channel, Washington Current	NOS	PUG1742_15	48.43436813354492	-122.94660949707031	:America/Los_Angeles	USA	knots	186	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.421	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 1.2 nm SE of	WA
107940	Cattle Point, 1.2 nmi SE of (depth 78 ft), San Juan Channel, Washington Current	NOS	PUG1742_18	48.43436813354492	-122.94660949707031	:America/Los_Angeles	USA	knots	183	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 1.2 nm SE of	WA
107941	Cattle Point, 1.2 nmi SE of (depth 39 ft), San Juan Channel, Washington Current	NOS	PUG1742_21	48.43436813354492	-122.94660949707031	:America/Los_Angeles	USA	knots	183	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 1.2 nm SE of	WA
107942	Cattle Point, 4.6 nmi SW of (depth 187 ft), San Juan Channel, Washington Current	NOS	PUG1743_14	48.384010314941406	-123.01567077636719	:America/Los_Angeles	USA	knots	179	47	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 4.6 nm SW of	WA
107943	Cattle Point, 4.6 nmi SW of (depth 105 ft), San Juan Channel, Washington Current	NOS	PUG1743_19	48.384010314941406	-123.01567077636719	:America/Los_Angeles	USA	knots	227	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 4.6 nm SW of	WA
107944	Cattle Point, 4.6 nmi SW of (depth 55 ft), San Juan Channel, Washington Current	NOS	PUG1743_22	48.384010314941406	-123.01567077636719	:America/Los_Angeles	USA	knots	228	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.143	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 4.6 nm SW of	WA
107945	Discovery Island, 3.0 nmi NE of (depth 160 ft), Washington Current	NOS	PUG1744_13	48.45206832885742	-123.15544128417969	:America/Los_Angeles	USA	knots	153	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.322	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 3.0 nm NE of	WA
107946	Discovery Island, 3.0 nmi NE of (depth 68 ft), Washington Current	NOS	PUG1744_20	48.45206832885742	-123.15544128417969	:America/Los_Angeles	USA	knots	157	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 3.0 nm NE of	WA
107947	Discovery Island, 3.0 nmi NE of (depth 41 ft), Washington Current	NOS	PUG1744_22	48.45206832885742	-123.15544128417969	:America/Los_Angeles	USA	knots	160	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 3.0 nm NE of	WA
107948	Point George, west of (depth 283 ft), San Juan Channel, Washington Current	NOS	PUG1745_10	48.55670928955078	-122.99848175048828	:America/Los_Angeles	USA	knots	139	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point George, west of	WA
107949	Point George, west of (depth 119 ft), San Juan Channel, Washington Current	NOS	PUG1745_20	48.55670928955078	-122.99848175048828	:America/Los_Angeles	USA	knots	155	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point George, west of	WA
107950	Point George, west of (depth 53 ft), San Juan Channel, Washington Current	NOS	PUG1745_24	48.55670928955078	-122.99848175048828	:America/Los_Angeles	USA	knots	152	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point George, west of	WA
107951	Pear Point, east of (depth 112 ft), San Juan Channel, Washington Current	NOS	PUG1746_4	48.51139831542969	-122.9529037475586	:America/Los_Angeles	USA	knots	203	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pear Point, east of	WA
107952	Pear Point, east of (depth 59 ft), San Juan Channel, Washington Current	NOS	PUG1746_8	48.51139831542969	-122.9529037475586	:America/Los_Angeles	USA	knots	196	29	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.247	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pear Point, east of	WA
107953	Pear Point, east of (depth 32 ft), San Juan Channel, Washington Current	NOS	PUG1746_10	48.51139831542969	-122.9529037475586	:America/Los_Angeles	USA	knots	192	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.291	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pear Point, east of	WA
107954	College Fiord (depth 163 ft), Port Wells, Prince William Sound, Alaska Current	NOS	PWS0701_1	60.98983	-148.0467	:America/Anchorage	USA	knots	167	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.216	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	College Fiord	AK
107955	College Fiord (depth 98 ft), Port Wells, Prince William Sound, Alaska Current	NOS	PWS0701_6	60.98983	-148.0467	:America/Anchorage	USA	knots	175	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	College Fiord	AK
107956	College Fiord (depth 32 ft), Port Wells, Prince William Sound, Alaska Current	NOS	PWS0701_11	60.98983	-148.0467	:America/Anchorage	USA	knots	\N	28.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	College Fiord	AK
107957	Point Culross (depth 381 ft), Port Wells, Prince William Sound, Alaska Current	NOS	PWS0704_1	60.75442	-148.12186	:America/Anchorage	USA	knots	108	303	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Culross	AK
107958	Point Culross (depth 223 ft), Port Wells, Prince William Sound, Alaska Current	NOS	PWS0704_13	60.75442	-148.12186	:America/Anchorage	USA	knots	114	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Culross	AK
107959	Point Culross (depth 53 ft), Port Wells, Prince William Sound, Alaska Current	NOS	PWS0704_26	60.75442	-148.12186	:America/Anchorage	USA	knots	116	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Culross	AK
107960	Perry Passage (depth 225 ft), Port Wells, Prince William Sound, Alaska Current	NOS	PWS0706_9	60.67099	-148.01548	:America/Anchorage	USA	knots	\N	326	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Perry Passage	AK
107961	Perry Passage (depth 48 ft), Port Wells, Prince William Sound, Alaska Current	NOS	PWS0706_18	60.67099	-148.01548	:America/Anchorage	USA	knots	\N	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Perry Passage	AK
107962	Crafton Island - Knight Island Pass (depth 255 ft), Prince William Sound, Alaska Current	NOS	PWS0708_3	60.50249	-147.89787	:America/Anchorage	USA	knots	184	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crafton Island - Knight Island Pass	AK
107963	Crafton Island - Knight Island Pass (depth 176 ft), Prince William Sound, Alaska Current	NOS	PWS0708_9	60.50249	-147.89787	:America/Anchorage	USA	knots	177	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crafton Island - Knight Island Pass	AK
107964	Crafton Island - Knight Island Pass (depth 97 ft), Prince William Sound, Alaska Current	NOS	PWS0708_15	60.50249	-147.89787	:America/Anchorage	USA	knots	\N	354.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crafton Island - Knight Island Pass	AK
107965	W. of Johnson Bay (depth 282 ft), Prince William Sound, Alaska Current	NOS	PWS0710_1	60.35899	-147.93291	:America/Anchorage	USA	knots	233	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	W. of Johnson Bay	AK
107966	W. of Johnson Bay (depth 164 ft), Prince William Sound, Alaska Current	NOS	PWS0710_10	60.35899	-147.93291	:America/Anchorage	USA	knots	189	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	W. of Johnson Bay	AK
107967	W. of Johnson Bay (depth 33 ft), Prince William Sound, Alaska Current	NOS	PWS0710_20	60.35899	-147.93291	:America/Anchorage	USA	knots	199	16.6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	W. of Johnson Bay	AK
107968	Bainbridge Pass (depth 131 ft), Prince William Sound, Alaska Current	NOS	PWS0713_1	60.1291	-148.20235	:America/Anchorage	USA	knots	234	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.256	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bainbridge Pass	AK
107969	Bainbridge Pass (depth 75 ft), Prince William Sound, Alaska Current	NOS	PWS0713_18	60.1291	-148.20235	:America/Anchorage	USA	knots	235	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.276	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bainbridge Pass	AK
107970	Bainbridge Pass (depth 16 ft), Prince William Sound, Alaska Current	NOS	PWS0713_36	60.1291	-148.20235	:America/Anchorage	USA	knots	235	34	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.337	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bainbridge Pass	AK
107971	Prince of Wales Pass (depth 237 ft), Prince William Sound, Alaska Current	NOS	PWS0714_1	60.0362	-148.13448	:America/Anchorage	USA	knots	203	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Prince of Wales Pass	AK
107972	Prince of Wales Pass (depth 138 ft), Prince William Sound, Alaska Current	NOS	PWS0714_11	60.0362	-148.13448	:America/Anchorage	USA	knots	202	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Prince of Wales Pass	AK
107973	Prince of Wales Pass (depth 30 ft), Prince William Sound, Alaska Current	NOS	PWS0714_22	60.0362	-148.13448	:America/Anchorage	USA	knots	202	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.207	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Prince of Wales Pass	AK
107974	Sawmill Bay ent., Evans Island (depth 158 ft), Prince William Sound, Alaska Current	NOS	PWS0715_1	60.0591	-147.97423	:America/Anchorage	USA	knots	243	50	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sawmill Bay Entr., Evans Island	AK
107975	Sawmill Bay ent., Evans Island (depth 79 ft), Prince William Sound, Alaska Current	NOS	PWS0715_7	60.0591	-147.97423	:America/Anchorage	USA	knots	235	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sawmill Bay Entr., Evans Island	AK
107976	Sawmill Bay ent., Evans Island (depth 14 ft), Prince William Sound, Alaska Current	NOS	PWS0715_12	60.0591	-147.97423	:America/Anchorage	USA	knots	234	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.192	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sawmill Bay Entr., Evans Island	AK
107977	Elrington Passage (depth 295 ft), Prince William Sound, Alaska Current	NOS	PWS0716_1	59.97951	-148.1167	:America/Anchorage	USA	knots	231	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elrington Passage	AK
107978	Elrington Passage (depth 180 ft), Prince William Sound, Alaska Current	NOS	PWS0716_8	59.97951	-148.1167	:America/Anchorage	USA	knots	229	51	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elrington Passage	AK
107979	Elrington Passage (depth 49 ft), Prince William Sound, Alaska Current	NOS	PWS0716_16	59.97951	-148.1167	:America/Anchorage	USA	knots	232	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elrington Passage	AK
107980	Latouche Pass (depth 108 ft), Prince William Sound, Alaska Current	NOS	PWS0717_1	59.97666	-148.04645	:America/Anchorage	USA	knots	223	27	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.234	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Latouche Pass	AK
107981	Latouche Pass (depth 62 ft), Prince William Sound, Alaska Current	NOS	PWS0717_8	59.97666	-148.04645	:America/Anchorage	USA	knots	220	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Latouche Pass	AK
107982	Latouche Pass (depth 23 ft), Prince William Sound, Alaska Current	NOS	PWS0717_14	59.97666	-148.04645	:America/Anchorage	USA	knots	217	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.367	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Latouche Pass	AK
107983	Montague Strait (depth 290 ft), Prince William Sound, Alaska Current	NOS	PWS0719_1	59.9146	-147.96072	:America/Anchorage	USA	knots	228	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Strait	AK
107984	Montague Strait (depth 172 ft), Prince William Sound, Alaska Current	NOS	PWS0719_7	59.9146	-147.96072	:America/Anchorage	USA	knots	236	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Strait	AK
107985	Montague Strait (depth 54 ft), Prince William Sound, Alaska Current	NOS	PWS0719_13	59.9146	-147.96072	:America/Anchorage	USA	knots	236	47	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Strait	AK
107986	Wooded Island (depth 156 ft), Hinchinbrook entrance, Prince William Sound, Alaska Current	NOS	PWS0721_1	59.86825	-147.28112	:America/Anchorage	USA	knots	231	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wooded Island	AK
107987	Wooded Island (depth 97 ft), Hinchinbrook entrance, Prince William Sound, Alaska Current	NOS	PWS0721_10	59.86825	-147.28112	:America/Anchorage	USA	knots	208	65	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.309	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wooded Island	AK
107988	Wooded Island (depth 25 ft), Hinchinbrook entrance, Prince William Sound, Alaska Current	NOS	PWS0721_21	59.86825	-147.28112	:America/Anchorage	USA	knots	204	81	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.692	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wooded Island	AK
107989	Snug Harbor (depth 280 ft), Prince William Sound, Alaska Current	NOS	PWS0723_1	60.2758	-147.63456	:America/Anchorage	USA	knots	\N	10.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snug Harbor	AK
107990	Snug Harbor (depth 162 ft), Prince William Sound, Alaska Current	NOS	PWS0723_10	60.2758	-147.63456	:America/Anchorage	USA	knots	291	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snug Harbor	AK
107991	Snug Harbor (depth 57 ft), Prince William Sound, Alaska Current	NOS	PWS0723_18	60.2758	-147.63456	:America/Anchorage	USA	knots	\N	19	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.259	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snug Harbor	AK
107992	Green Island Pass (depth 163 ft), Prince William Sound, Alaska Current	NOS	PWS0724_3	60.26732	-147.30157	:America/Anchorage	USA	knots	201	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Island Pass	AK
107993	Green Island Pass (depth 104 ft), Prince William Sound, Alaska Current	NOS	PWS0724_9	60.26732	-147.30157	:America/Anchorage	USA	knots	\N	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.191	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Island Pass	AK
107994	Green Island Pass (depth 35 ft), Prince William Sound, Alaska Current	NOS	PWS0724_16	60.26732	-147.30157	:America/Anchorage	USA	knots	214	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.22	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Island Pass	AK
108390	Pier 23 (depth 17 ft), San Francisco Bay, California Current	NOS	SFB1206_7	37.8053	-122.39728	:America/Los_Angeles	USA	knots	322	144	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.248	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pier 23	CA
107995	Montague Point (depth 277 ft), Prince William Sound, Alaska Current	NOS	PWS0725_1	60.39838	-147.09389	:America/Anchorage	USA	knots	261	88	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Point	AK
107996	Montague Point (depth 158 ft), Prince William Sound, Alaska Current	NOS	PWS0725_10	60.39838	-147.09389	:America/Anchorage	USA	knots	279	99	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Point	AK
107997	Montague Point (depth 40 ft), Prince William Sound, Alaska Current	NOS	PWS0725_19	60.39838	-147.09389	:America/Anchorage	USA	knots	323	92	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.386	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Point	AK
107998	Bear Cape (depth 566 ft), Hinchinbrook entrance, Prince William Sound, Alaska Current	NOS	PWS0726_1	60.35199	-146.74626	:America/Anchorage	USA	knots	171	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Cape	AK
107999	Bear Cape (depth 251 ft), Hinchinbrook entrance, Prince William Sound, Alaska Current	NOS	PWS0726_13	60.35199	-146.74626	:America/Anchorage	USA	knots	176	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Cape	AK
108000	Johnstone Point (depth 231 ft), Prince William Sound, Alaska Current	NOS	PWS0727_1	60.48874	-146.61651	:America/Anchorage	USA	knots	241	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johnstone Point	AK
108001	Johnstone Point (depth 139 ft), Prince William Sound, Alaska Current	NOS	PWS0727_8	60.48874	-146.61651	:America/Anchorage	USA	knots	252	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johnstone Point	AK
108002	Johnstone Point (depth 34 ft), Prince William Sound, Alaska Current	NOS	PWS0727_16	60.48874	-146.61651	:America/Anchorage	USA	knots	250	65	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.206	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johnstone Point	AK
108003	Cape Hinchinbrook approach (depth 181 ft), Prince William Sound, Alaska Current	NOS	PWS0729_1	60.22488	-146.22623	:America/Anchorage	USA	knots	84	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Hinchinbrook Approach	AK
108004	Cape Hinchinbrook approach (depth 115 ft), Prince William Sound, Alaska Current	NOS	PWS0729_6	60.22488	-146.22623	:America/Anchorage	USA	knots	\N	280	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Hinchinbrook Approach	AK
108005	Cape Hinchinbrook approach (depth 37 ft), Prince William Sound, Alaska Current	NOS	PWS0729_12	60.22488	-146.22623	:America/Anchorage	USA	knots	\N	291.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.294	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Hinchinbrook Approach	AK
108006	Middle Ground Shoal, north of (depth 185 ft), Prince William Sound, Alaska Current	NOS	PWS0731_1	60.55797	-146.36622	:America/Anchorage	USA	knots	270	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Ground Shoal, north of	AK
108007	Middle Ground Shoal, north of (depth 119 ft), Prince William Sound, Alaska Current	NOS	PWS0731_6	60.55797	-146.36622	:America/Anchorage	USA	knots	272	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Ground Shoal, north of	AK
108008	Middle Ground Shoal, north of (depth 41 ft), Prince William Sound, Alaska Current	NOS	PWS0731_12	60.55797	-146.36622	:America/Anchorage	USA	knots	283	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Ground Shoal, north of	AK
108009	Channel Island (depth 150 ft), Prince William Sound, Alaska Current	NOS	PWS0732_1	60.60438	-145.84024	:America/Anchorage	USA	knots	251	89	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Channel Island	AK
108010	Channel Island (depth 84 ft), Prince William Sound, Alaska Current	NOS	PWS0732_6	60.60438	-145.84024	:America/Anchorage	USA	knots	249	73.3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Channel Island	AK
108011	Channel Island (depth 32 ft), Prince William Sound, Alaska Current	NOS	PWS0732_10	60.60438	-145.84024	:America/Anchorage	USA	knots	247	83	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Channel Island	AK
108012	Salmo Point (depth 75 ft), Prince William Sound, Alaska Current	NOS	PWS0733_1	60.61672	-145.77075	:America/Anchorage	USA	knots	245	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Salmo Point	AK
108013	Salmo Point (depth 49 ft), Prince William Sound, Alaska Current	NOS	PWS0733_5	60.61672	-145.77075	:America/Anchorage	USA	knots	241	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Salmo Point	AK
108014	Salmo Point (depth 16 ft), Prince William Sound, Alaska Current	NOS	PWS0733_10	60.61672	-145.77075	:America/Anchorage	USA	knots	237	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.309	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Salmo Point	AK
108015	Old Log Boom (depth 44 ft), Prince William Sound, Alaska Current	NOS	PWS0734_1	60.5723	-145.74343	:America/Anchorage	USA	knots	35	218	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Log Boom	AK
108016	Old Log Boom (depth 31 ft), Prince William Sound, Alaska Current	NOS	PWS0734_3	60.5723	-145.74343	:America/Anchorage	USA	knots	34	221	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Log Boom	AK
108017	Old Log Boom (depth 12 ft), Prince William Sound, Alaska Current	NOS	PWS0734_6	60.5723	-145.74343	:America/Anchorage	USA	knots	36	221	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Log Boom	AK
108018	Mud Bay (depth 40 ft), Prince William Sound, Alaska Current	NOS	PWS0735_1	60.54765	-145.84088	:America/Anchorage	USA	knots	63	256	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mud Bay	AK
108019	Mud Bay (depth 27 ft), Prince William Sound, Alaska Current	NOS	PWS0735_5	60.54765	-145.84088	:America/Anchorage	USA	knots	63	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mud Bay	AK
108020	Mud Bay (depth 14 ft), Prince William Sound, Alaska Current	NOS	PWS0735_9	60.54765	-145.84088	:America/Anchorage	USA	knots	62	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mud Bay	AK
108021	Port Gravina (depth 312 ft), Prince William Sound, Alaska Current	NOS	PWS0736_1	60.60636	-146.38952	:America/Anchorage	USA	knots	\N	42.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Gravina	AK
108022	Port Gravina (depth 181 ft), Prince William Sound, Alaska Current	NOS	PWS0736_11	60.60636	-146.38952	:America/Anchorage	USA	knots	267	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Gravina	AK
108023	Port Gravina (depth 50 ft), Prince William Sound, Alaska Current	NOS	PWS0736_21	60.60636	-146.38952	:America/Anchorage	USA	knots	\N	86	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Gravina	AK
108024	Between Naked and Eleanor Islands (depth 244 ft), Prince William Sound, Alaska Current	NOS	PWS0739_1	60.607669830322266	-147.4893341064453	:America/Anchorage	USA	knots	149	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Between Naked and Eleanor Islands	AK
108025	Between Naked and Eleanor Islands (depth 139 ft), Prince William Sound, Alaska Current	NOS	PWS0739_9	60.607669830322266	-147.4893341064453	:America/Anchorage	USA	knots	132	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Between Naked and Eleanor Islands	AK
108026	Between Naked and Eleanor Islands (depth 34 ft), Prince William Sound, Alaska Current	NOS	PWS0739_17	60.607669830322266	-147.4893341064453	:America/Anchorage	USA	knots	137	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Between Naked and Eleanor Islands	AK
108027	Storey Island and Peak Island, between (depth 292 ft), Alaska Current	NOS	PWS0740_1	60.72666931152344	-147.30482482910156	:America/Anchorage	USA	knots	\N	2.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Storey Island and Peak Island, between	AK
108028	Storey Island and Peak Island, between (depth 177 ft), Alaska Current	NOS	PWS0740_8	60.72666931152344	-147.30482482910156	:America/Anchorage	USA	knots	\N	315.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Storey Island and Peak Island, between	AK
108029	Storey Island and Peak Island, between (depth 46 ft), Alaska Current	NOS	PWS0740_16	60.72666931152344	-147.30482482910156	:America/Anchorage	USA	knots	117	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Storey Island and Peak Island, between	AK
108030	Storey Island, north of (depth 261 ft), Prince William Sound, Alaska Current	NOS	PWS0741_2	60.75041	-147.40586	:America/Anchorage	USA	knots	86	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Storey Island, north of	AK
108031	Storey Island, north of (depth 179 ft), Prince William Sound, Alaska Current	NOS	PWS0741_7	60.75041	-147.40586	:America/Anchorage	USA	knots	90	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Storey Island, north of	AK
108032	Storey Island, north of (depth 48 ft), Prince William Sound, Alaska Current	NOS	PWS0741_15	60.75041	-147.40586	:America/Anchorage	USA	knots	92	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Storey Island, north of	AK
108033	Outpost Island (depth 319 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0742_1	60.83539	-147.44942	:America/Anchorage	USA	knots	\N	306.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Outpost Island	AK
108034	Outpost Island (depth 106 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0742_14	60.83539	-147.44942	:America/Anchorage	USA	knots	81	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Outpost Island	AK
108035	Outpost Island (depth 73 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0742_16	60.83539	-147.44942	:America/Anchorage	USA	knots	75	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Outpost Island	AK
108036	Slipper Point (depth 235 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0743_2	60.90998	-147.26555	:America/Anchorage	USA	knots	\N	42	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Slipper Point	AK
108037	Slipper Point (depth 143 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0743_9	60.90998	-147.26555	:America/Anchorage	USA	knots	233	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Slipper Point	AK
108038	Slipper Point (depth 25 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0743_18	60.90998	-147.26555	:America/Anchorage	USA	knots	244	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Slipper Point	AK
108039	Finski Point (depth 223 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0744_3	60.90195	-147.06415	:America/Anchorage	USA	knots	134	311.5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Finski Point	AK
108040	Finski Point (depth 131 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0744_10	60.90195	-147.06415	:America/Anchorage	USA	knots	143	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Finski Point	AK
108041	Finski Point (depth 13 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0744_19	60.90195	-147.06415	:America/Anchorage	USA	knots	140	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Finski Point	AK
108042	Valdez Narrows (depth 329 ft), Valdez Arm, Prince William Sound, Alaska Current	NOS	PWS0745_5	61.06976	-146.66077	:America/Anchorage	USA	knots	201	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valdez Narrows	AK
108043	Valdez Narrows (depth 231 ft), Valdez Arm, Prince William Sound, Alaska Current	NOS	PWS0745_10	61.06976	-146.66077	:America/Anchorage	USA	knots	209	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valdez Narrows	AK
108044	Valdez Narrows (depth 133 ft), Valdez Arm, Prince William Sound, Alaska Current	NOS	PWS0745_15	61.06976	-146.66077	:America/Anchorage	USA	knots	220	34	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valdez Narrows	AK
108045	St. Andrew Bay entrance (depth 31 ft), Florida Current	NOS	SAB0803_1	30.121771	-85.729721	:America/Chicago	USA	knots	221	47	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Andrew Bay Entrance	FL
108046	St. Andrew Bay entrance (depth 18 ft), Florida Current	NOS	SAB0803_5	30.121771	-85.729721	:America/Chicago	USA	knots	225	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Andrew Bay Entrance	FL
108047	St. Andrew Bay entrance (depth 5 ft), Florida Current	NOS	SAB0803_9	30.121771	-85.729721	:America/Chicago	USA	knots	230	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Andrew Bay Entrance	FL
108048	Paper Mill (depth 27 ft), St. Andrew Bay, Florida Current	NOS	SAB0805_1	30.130449	-85.631622	:America/Chicago	USA	knots	238	60.2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Paper Mill	FL
108049	Paper Mill (depth 16 ft), St. Andrew Bay, Florida Current	NOS	SAB0805_8	30.130449	-85.631622	:America/Chicago	USA	knots	245	86	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Paper Mill	FL
108050	Paper Mill (depth 3 ft), St. Andrew Bay, Florida Current	NOS	SAB0805_16	30.130449	-85.631622	:America/Chicago	USA	knots	249	70.9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.236	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Paper Mill	FL
108051	Redfish Point (depth 32 ft), St. Andrew Bay, Florida Current	NOS	SAB0806_1	30.14402	-85.6668	:America/Chicago	USA	knots	303	129	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redfish Point	FL
108052	Redfish Point (depth 19 ft), St. Andrew Bay, Florida Current	NOS	SAB0806_5	30.14402	-85.6668	:America/Chicago	USA	knots	310	118	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redfish Point	FL
108053	Redfish Point (depth 5 ft), St. Andrew Bay, Florida Current	NOS	SAB0806_9	30.14402	-85.6668	:America/Chicago	USA	knots	319	101	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redfish Point	FL
108054	Courtney Point, 0.75 mi SE of (depth 30 ft), St. Andrew Bay, Florida Current	NOS	SAB0807_1	30.138729	-85.699181	:America/Chicago	USA	knots	273	68	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Courtney Point, 0.75mi. SE of	FL
108055	Courtney Point, 0.75 mi SE of (depth 20 ft), St. Andrew Bay, Florida Current	NOS	SAB0807_4	30.138729	-85.699181	:America/Chicago	USA	knots	256	65	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.115	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Courtney Point, 0.75mi. SE of	FL
108056	Courtney Point, 0.75 mi SE of (depth 7 ft), St. Andrew Bay, Florida Current	NOS	SAB0807_8	30.138729	-85.699181	:America/Chicago	USA	knots	210	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Courtney Point, 0.75mi. SE of	FL
108057	Courtney Point, 0.4 mi ESE of (depth 56 ft), St. Andrew Bay, Florida Current	NOS	SAB0808_1	30.14423	-85.703331	:America/Chicago	USA	knots	\N	41.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Courtney Point, 0.4mi. ESE of	FL
108058	Courtney Point, 0.4 mi ESE of (depth 11 ft), St. Andrew Bay, Florida Current	NOS	SAB0808_5	30.14423	-85.703331	:America/Chicago	USA	knots	190	22.5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 49.2 ft.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Courtney Point, 0.4mi. ESE of	FL
108059	Courtney Point, 0.4 mi ESE of (depth 4 ft), St. Andrew Bay, Florida Current	NOS	SAB0808_9	30.14423	-85.703331	:America/Chicago	USA	knots	174	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 42.6 ft.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.302	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Courtney Point, 0.4mi. ESE of	FL
108060	Bear Point, 0.6 nmi E of (depth 27 ft), St. Andrew Bay, Florida Current	NOS	SAB0809_1	30.164351	-85.713417	:America/Chicago	USA	knots	\N	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.226	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Point, 0.6nm E of	FL
108061	Bear Point, 0.6 nmi E of (depth 14 ft), St. Andrew Bay, Florida Current	NOS	SAB0809_5	30.164351	-85.713417	:America/Chicago	USA	knots	137	312	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Point, 0.6nm E of	FL
108062	Bear Point, 0.6 nmi E of (depth 4 ft), St. Andrew Bay, Florida Current	NOS	SAB0809_8	30.164351	-85.713417	:America/Chicago	USA	knots	120	297	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Point, 0.6nm E of	FL
108063	Long Point, West Bay (depth 4 ft), St. Andrew Bay, Florida Current	NOS	SAB0812_1	30.23925	-85.749832	:America/Chicago	USA	knots	173	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Long Point, West Bay	FL
108064	Wrangell Narrows (off Petersburg) (depth 25 ft), Alaska Current	NOS	SEA0103_2	56.815	-132.96278	:America/Juneau	USA	knots	51	247	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 23.7 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrangell Narrows (off Petersburg)	AK
108065	Wrangell Narrows (off Petersburg) (depth 15 ft), Alaska Current	NOS	SEA0103_5	56.815	-132.96278	:America/Juneau	USA	knots	56	247	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 13.8 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrangell Narrows (off Petersburg)	AK
108066	Wrangell Narrows (off Petersburg) (depth 4 ft), Alaska Current	NOS	SEA0103_8	56.815	-132.96278	:America/Juneau	USA	knots	62	246	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrangell Narrows (off Petersburg)	AK
108067	South Ledge (depth 23 ft), Wrangell Narrows, Alaska Current	NOS	SEA0104_2	56.62056	-132.96344	:America/Juneau	USA	knots	218	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.319	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Ledge	AK
108068	South Ledge (depth 16 ft), Wrangell Narrows, Alaska Current	NOS	SEA0104_4	56.62056	-132.96344	:America/Juneau	USA	knots	218	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.321	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Ledge	AK
108069	South Ledge (depth 7 ft), Wrangell Narrows, Alaska Current	NOS	SEA0104_7	56.62056	-132.96344	:America/Juneau	USA	knots	218	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.338	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Ledge	AK
108070	Sergius Narrows (depth 44 ft), Peril Strait, Alaska Current	NOS	SEA0202_5	57.40702	-135.63115	:America/Juneau	USA	knots	242	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.438	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sergius Narrows	AK
108071	Sergius Narrows (depth 31 ft), Peril Strait, Alaska Current	NOS	SEA0202_7	57.40702	-135.63115	:America/Juneau	USA	knots	241	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.436	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sergius Narrows	AK
108072	Sergius Narrows (depth 18 ft), Peril Strait, Alaska Current	NOS	SEA0202_9	57.40702	-135.63115	:America/Juneau	USA	knots	241	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.433	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sergius Narrows	AK
108073	Kakul Narrows (depth 58 ft), Peril Strait, Alaska Current	NOS	SEA0203_16	57.3699	-135.6925	:America/Juneau	USA	knots	209	27	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.211	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kakul Narrows	AK
108074	Kakul Narrows (depth 19 ft), Peril Strait, Alaska Current	NOS	SEA0203_19	57.3699	-135.6925	:America/Juneau	USA	knots	211	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.207	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kakul Narrows	AK
108075	Whitestone Narrows, S of Whitestone Point (depth 43 ft), Neva Strait, Alaska Current	NOS	SEA0204_2	57.24495	-135.5639	:America/Juneau	USA	knots	339	163	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whitestone Narrows, S of Whitestone Point	AK
108076	Whitestone Narrows, S of Whitestone Point (depth 16 ft), Neva Strait, Alaska Current	NOS	SEA0204_6	57.24495	-135.5639	:America/Juneau	USA	knots	338	161	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.098	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whitestone Narrows, S of Whitestone Point	AK
108077	Creek Point, 0.44 nmi SE of (depth 15 ft), Olga Strait, Alaska Current	NOS	SEA0205_5	57.21014	-135.49492	:America/Juneau	USA	knots	141	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Creek Point, 0.44 n.mi. SE of	AK
108078	Povorotni Island, 0.23 nmi WSW of (depth 89 ft), Peril Strait, Alaska Current	NOS	SEA0302_6	57.5105	-135.56167	:America/Juneau	USA	knots	156	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Povorotni Island, 0.23 n.mi. WSW of	AK
108079	Povorotni Island, 0.23 nmi WSW of (depth 50 ft), Peril Strait, Alaska Current	NOS	SEA0302_9	57.5105	-135.56167	:America/Juneau	USA	knots	158	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Povorotni Island, 0.23 n.mi. WSW of	AK
108080	Povorotni Island, 0.23 nmi WSW of (depth 10 ft), Peril Strait, Alaska Current	NOS	SEA0302_12	57.5105	-135.56167	:America/Juneau	USA	knots	159	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Povorotni Island, 0.23 n.mi. WSW of	AK
108081	Big Rose Island, 0.2 nmi SE of (depth 92 ft), Peril Strait, Alaska Current	NOS	SEA0303_3	57.45308	-135.5373	:America/Juneau	USA	knots	221	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Big Rose Island, 0.2 n.mi. SE of	AK
108082	Big Rose Island, 0.2 nmi SE of (depth 32 ft), Peril Strait, Alaska Current	NOS	SEA0303_12	57.45308	-135.5373	:America/Juneau	USA	knots	212	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Big Rose Island, 0.2 n.mi. SE of	AK
108083	Big Rose Island, 0.2 nmi SE of (depth 12 ft), Peril Strait, Alaska Current	NOS	SEA0303_15	57.45308	-135.5373	:America/Juneau	USA	knots	212	42	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 13.1 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Big Rose Island, 0.2 n.mi. SE of	AK
108084	Suloia Point, 0.32 nmi ENE of (depth 92 ft), Peril Strait, Alaska Current	NOS	SEA0304_12	57.39217	-135.64105	:America/Juneau	USA	knots	113	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.284	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Suloia Point, 0.32 n.mi. ENE of	AK
108085	Suloia Point, 0.32 nmi ENE of (depth 65 ft), Peril Strait, Alaska Current	NOS	SEA0304_14	57.39217	-135.64105	:America/Juneau	USA	knots	114	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.323	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Suloia Point, 0.32 n.mi. ENE of	AK
108086	Suloia Point, 0.32 nmi ENE of (depth 26 ft), Peril Strait, Alaska Current	NOS	SEA0304_17	57.39217	-135.64105	:America/Juneau	USA	knots	113	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.346	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Suloia Point, 0.32 n.mi. ENE of	AK
108087	Zeal Point, 0.34 nmi SSW of (depth 48 ft), Neva Strait, Alaska Current	NOS	SEA0306_7	57.2869	-135.6079	:America/Juneau	USA	knots	345	170	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Zeal Point, 0.34 n.mi. SSW of	AK
108088	Zeal Point, 0.34 nmi SSW of (depth 29 ft), Neva Strait, Alaska Current	NOS	SEA0306_10	57.2869	-135.6079	:America/Juneau	USA	knots	347	165	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Zeal Point, 0.34 n.mi. SSW of	AK
108089	Zeal Point, 0.34 nmi SSW of (depth 16 ft), Neva Strait, Alaska Current	NOS	SEA0306_12	57.2869	-135.6079	:America/Juneau	USA	knots	346	163	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.062	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Zeal Point, 0.34 n.mi. SSW of	AK
108090	Tracy Arm Bar (depth 32 ft), Stephens Passage, Alaska Current	NOS	SEA0307_18	57.77973	-133.63224	:America/Juneau	USA	knots	226	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 28.8 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.473	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tracy Arm Bar	AK
108091	Shrubby Island, east of (depth 308 ft), Clarence Strait, Alaska Current	NOS	SEA0401_1	56.22667	-132.90867	:America/Juneau	USA	knots	314	151	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shrubby Island, east of	AK
108092	Shrubby Island, east of (depth 72 ft), Clarence Strait, Alaska Current	NOS	SEA0401_25	56.22667	-132.90867	:America/Juneau	USA	knots	327	149	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shrubby Island, east of	AK
108093	Shrubby Island, east of (depth 61 ft), Clarence Strait, Alaska Current	NOS	SEA0401_26	56.22667	-132.90867	:America/Juneau	USA	knots	326	149	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shrubby Island, east of	AK
108094	Snow Passage, southern approach (depth 260 ft), Clarence Strait, Alaska Current	NOS	SEA0402_1	56.25633	-132.9405	:America/Juneau	USA	knots	336	159	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.459	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Passage, southern approach	AK
108095	Snow Passage, southern approach (depth 44 ft), Clarence Strait, Alaska Current	NOS	SEA0402_23	56.25633	-132.9405	:America/Juneau	USA	knots	329	162	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Passage, southern approach	AK
108096	Snow Passage, southern approach (depth 14 ft), Clarence Strait, Alaska Current	NOS	SEA0402_26	56.25633	-132.9405	:America/Juneau	USA	knots	328	163	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Passage, southern approach	AK
108097	Snow Passage Narrows (depth 299 ft), Clarence Strait, Alaska Current	NOS	SEA0403_1	56.279	-132.953	:America/Juneau	USA	knots	337	154	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.163	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Passage Narrows	AK
108098	Snow Passage Narrows (depth 43 ft), Clarence Strait, Alaska Current	NOS	SEA0403_27	56.279	-132.953	:America/Juneau	USA	knots	333	153	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Passage Narrows	AK
108099	Snow Passage Narrows (depth 23 ft), Clarence Strait, Alaska Current	NOS	SEA0403_29	56.279	-132.953	:America/Juneau	USA	knots	331	153	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.224	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Passage Narrows	AK
108100	Round Island Light (depth 104 ft), Clarence Strait, Alaska Current	NOS	SEA0404_1	56.31417	-133.094	:America/Juneau	USA	knots	315	144	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Round Island Light	AK
108101	Round Island Light (depth 32 ft), Clarence Strait, Alaska Current	NOS	SEA0404_12	56.31417	-133.094	:America/Juneau	USA	knots	318	146	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Round Island Light	AK
108102	Round Island Light (depth 19 ft), Clarence Strait, Alaska Current	NOS	SEA0404_14	56.31417	-133.094	:America/Juneau	USA	knots	318	148	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Round Island Light	AK
108103	Vichnefski Rock Light (depth 289 ft), Sumner Strait, Alaska Current	NOS	SEA0405_1	56.446	-133.0195	:America/Juneau	USA	knots	237	29	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.159	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vichnefski Rock Light	AK
108104	Vichnefski Rock Light (depth 54 ft), Sumner Strait, Alaska Current	NOS	SEA0405_25	56.446	-133.0195	:America/Juneau	USA	knots	227	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 52.9 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vichnefski Rock Light	AK
108105	Vichnefski Rock Light (depth 35 ft), Sumner Strait, Alaska Current	NOS	SEA0405_27	56.446	-133.0195	:America/Juneau	USA	knots	226	50	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 33.2 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vichnefski Rock Light	AK
108106	Killisnoo Harbor (depth 90 ft), Chatham Strait, Alaska Current	NOS	SEA0406_1	57.46322	-134.56463	:America/Juneau	USA	knots	321	152	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Killisnoo Harbor	AK
108107	Killisnoo Harbor (depth 12 ft), Chatham Strait, Alaska Current	NOS	SEA0406_25	57.46322	-134.56463	:America/Juneau	USA	knots	321	142	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Killisnoo Harbor	AK
108108	Western Channel (depth 110 ft), Sitka Sound, Alaska Current	NOS	SEA0409_1	57.0503	-135.39578	:America/Juneau	USA	knots	193	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Western Channel	AK
108109	Western Channel (depth 64 ft), Sitka Sound, Alaska Current	NOS	SEA0409_8	57.0503	-135.39578	:America/Juneau	USA	knots	193	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Western Channel	AK
108110	Western Channel (depth 18 ft), Sitka Sound, Alaska Current	NOS	SEA0409_15	57.0503	-135.39578	:America/Juneau	USA	knots	210	29	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Western Channel	AK
108111	The Brother, east of (depth 488 ft), Stephens Passage, Alaska Current	NOS	SEA0502_1	57.32245	-133.7334	:America/Juneau	USA	knots	164	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Brother, east of	AK
108112	The Brother, east of (depth 173 ft), Stephens Passage, Alaska Current	NOS	SEA0502_13	57.32245	-133.7334	:America/Juneau	USA	knots	207	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Brother, east of	AK
108113	The Brother, east of (depth 68 ft), Stephens Passage, Alaska Current	NOS	SEA0502_17	57.32245	-133.7334	:America/Juneau	USA	knots	\N	50.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Brother, east of	AK
108114	The Five Fingers (depth 250 ft), Stephens Passage, Alaska Current	NOS	SEA0503_1	57.26632	-133.60353	:America/Juneau	USA	knots	164	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Five Fingers	AK
108115	The Five Fingers (depth 158 ft), Stephens Passage, Alaska Current	NOS	SEA0503_8	57.26632	-133.60353	:America/Juneau	USA	knots	208	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Five Fingers	AK
108116	The Five Fingers (depth 40 ft), Stephens Passage, Alaska Current	NOS	SEA0503_17	57.26632	-133.60353	:America/Juneau	USA	knots	215	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Five Fingers	AK
108117	Turnabout Island (depth 261 ft), Frederick Sound, Alaska Current	NOS	SEA0504_1	57.11598	-133.92482	:America/Juneau	USA	knots	244	71	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turnabout Island	AK
108118	Turnabout Island (depth 156 ft), Frederick Sound, Alaska Current	NOS	SEA0504_9	57.11598	-133.92482	:America/Juneau	USA	knots	252	77	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turnabout Island	AK
108119	Turnabout Island (depth 51 ft), Frederick Sound, Alaska Current	NOS	SEA0504_17	57.11598	-133.92482	:America/Juneau	USA	knots	260	80	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.144	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turnabout Island	AK
108120	Kake Harbor (depth 98 ft), Keku Strait, Alaska Current	NOS	SEA0505_1	56.96571	-133.95223	:America/Juneau	USA	knots	296	115	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kake Harbor	AK
108121	Kake Harbor (depth 45 ft), Keku Strait, Alaska Current	NOS	SEA0505_9	56.96571	-133.95223	:America/Juneau	USA	knots	300	110	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kake Harbor	AK
108122	Kake Harbor (depth 19 ft), Keku Strait, Alaska Current	NOS	SEA0505_13	56.96571	-133.95223	:America/Juneau	USA	knots	304	122	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kake Harbor	AK
108123	Hawk Inlet, Hawk Point (depth 78 ft), Chatham Strait, Alaska Current	NOS	SEA0507_2	58.09733	-134.77512	:America/Juneau	USA	knots	182	335	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawk Inlet, Hawk Point	AK
108124	Hawk Inlet, Hawk Point (depth 59 ft), Chatham Strait, Alaska Current	NOS	SEA0507_5	58.09733	-134.77512	:America/Juneau	USA	knots	181	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawk Inlet, Hawk Point	AK
108125	Hawk Inlet, Hawk Point (depth 13 ft), Chatham Strait, Alaska Current	NOS	SEA0507_12	58.09733	-134.77512	:America/Juneau	USA	knots	178	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.342	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawk Inlet, Hawk Point	AK
108126	The Eye Opener (depth 108 ft), Sumner Strait, Alaska Current	NOS	SEA0601_1	56.37623	-133.24576	:America/Juneau	USA	knots	283	89	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.146	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Eye Opener	AK
108127	The Eye Opener (depth 62 ft), Sumner Strait, Alaska Current	NOS	SEA0601_8	56.37623	-133.24576	:America/Juneau	USA	knots	276	100	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Eye Opener	AK
108128	The Eye Opener (depth 16 ft), Sumner Strait, Alaska Current	NOS	SEA0601_15	56.37623	-133.24576	:America/Juneau	USA	knots	272	103	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Eye Opener	AK
108129	Red Bay entrance (depth 95 ft), Sumner Strait, Alaska Current	NOS	SEA0602_1	56.32918	-133.30283	:America/Juneau	USA	knots	126	251	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bay Entrance	AK
108130	Red Bay entrance (depth 63 ft), Sumner Strait, Alaska Current	NOS	SEA0602_6	56.32918	-133.30283	:America/Juneau	USA	knots	100	238	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bay Entrance	AK
108131	Red Bay entrance (depth 17 ft), Sumner Strait, Alaska Current	NOS	SEA0602_13	56.32918	-133.30283	:America/Juneau	USA	knots	20	210	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bay Entrance	AK
108132	Sumner Island, east of (depth 328 ft), Sumner Strait, Alaska Current	NOS	SEA0603_1	56.40549	-133.74774	:America/Juneau	USA	knots	191	330	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.224	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sumner Island, east of	AK
108133	Sumner Island, east of (depth 229 ft), Sumner Strait, Alaska Current	NOS	SEA0603_11	56.40549	-133.74774	:America/Juneau	USA	knots	213	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.343	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sumner Island, east of	AK
108134	Sumner Island, east of (depth 150 ft), Sumner Strait, Alaska Current	NOS	SEA0603_19	56.40549	-133.74774	:America/Juneau	USA	knots	226	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.277	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sumner Island, east of	AK
108135	Helm Rock (depth 128 ft), Sumner Strait, Alaska Current	NOS	SEA0604_2	56.37537	-133.66786	:America/Juneau	USA	knots	233	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Helm Rock	AK
108136	Helm Rock (depth 80 ft), Sumner Strait, Alaska Current	NOS	SEA0604_7	56.37537	-133.66786	:America/Juneau	USA	knots	234	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.34	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Helm Rock	AK
108137	Helm Rock (depth 30 ft), Sumner Strait, Alaska Current	NOS	SEA0604_12	56.37537	-133.66786	:America/Juneau	USA	knots	240	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.787	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Helm Rock	AK
108138	Mariposa Reef, 3 mi south of (depth 322 ft), Sumner Strait, Alaska Current	NOS	SEA0605_1	56.33161	-133.72589	:America/Juneau	USA	knots	229	42	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.307	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mariposa Reef, 3 miles south of	AK
108139	Mariposa Reef, 3 mi south of (depth 184 ft), Sumner Strait, Alaska Current	NOS	SEA0605_8	56.33161	-133.72589	:America/Juneau	USA	knots	222	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.527	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mariposa Reef, 3 miles south of	AK
108140	Mariposa Reef, 3 mi south of (depth 46 ft), Sumner Strait, Alaska Current	NOS	SEA0605_15	56.33161	-133.72589	:America/Juneau	USA	knots	\N	32.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.813	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mariposa Reef, 3 miles south of	AK
108141	Calder Rocks (depth 186 ft), Sumner Strait, Alaska Current	NOS	SEA0608_1	56.23982	-133.73993	:America/Juneau	USA	knots	176	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Calder Rocks	AK
108142	Calder Rocks (depth 107 ft), Sumner Strait, Alaska Current	NOS	SEA0608_9	56.23982	-133.73993	:America/Juneau	USA	knots	198	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Calder Rocks	AK
108143	Calder Rocks (depth 38 ft), Sumner Strait, Alaska Current	NOS	SEA0608_16	56.23982	-133.73993	:America/Juneau	USA	knots	\N	29.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Calder Rocks	AK
108144	Amelius Island, 1 mi east of (depth 105 ft), Sumner Strait, Alaska Current	NOS	SEA0609_1	56.17779	-133.84177	:America/Juneau	USA	knots	228	78	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.212	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Amelius Island, 1 mile east of	AK
108145	Amelius Island, 1 mi east of (depth 66 ft), Sumner Strait, Alaska Current	NOS	SEA0609_5	56.17779	-133.84177	:America/Juneau	USA	knots	\N	57.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Amelius Island, 1 mile east of	AK
108146	Amelius Island, 1 mi east of (depth 16 ft), Sumner Strait, Alaska Current	NOS	SEA0609_10	56.17779	-133.84177	:America/Juneau	USA	knots	\N	49.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.409	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Amelius Island, 1 mile east of	AK
108147	Shakan Light, 2.4 mi west of (depth 202 ft), Sumner Strait, Alaska Current	NOS	SEA0610_1	56.1455	-133.69709	:America/Juneau	USA	knots	\N	337.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Light, 2.4 miles west of	AK
108148	Shakan Light, 2.4 mi west of (depth 114 ft), Sumner Strait, Alaska Current	NOS	SEA0610_10	56.1455	-133.69709	:America/Juneau	USA	knots	256	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Light, 2.4 miles west of	AK
108149	Shakan Light, 2.4 mi west of (depth 25 ft), Sumner Strait, Alaska Current	NOS	SEA0610_19	56.1455	-133.69709	:America/Juneau	USA	knots	212	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Light, 2.4 miles west of	AK
108391	Pier 23 (depth 4 ft), San Francisco Bay, California Current	NOS	SFB1206_11	37.8053	-122.39728	:America/Los_Angeles	USA	knots	323	143	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.441	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pier 23	CA
108150	Shipley Bay entrance (depth 153 ft), Sumner Strait, Alaska Current	NOS	SEA0611_1	56.09037	-133.68957	:America/Juneau	USA	knots	235	79	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shipley Bay Entrance	AK
108151	Shipley Bay entrance (depth 94 ft), Sumner Strait, Alaska Current	NOS	SEA0611_7	56.09037	-133.68957	:America/Juneau	USA	knots	233	76	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shipley Bay Entrance	AK
108152	Shipley Bay entrance (depth 35 ft), Sumner Strait, Alaska Current	NOS	SEA0611_13	56.09037	-133.68957	:America/Juneau	USA	knots	238	71	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.109	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shipley Bay Entrance	AK
108153	Shakan Strait, west end (depth 41 ft), Sumner Strait, Alaska Current	NOS	SEA0612_1	56.12992	-133.57493	:America/Juneau	USA	knots	320	143	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Strait, west end	AK
108154	Shakan Strait, west end (depth 28 ft), Sumner Strait, Alaska Current	NOS	SEA0612_3	56.12992	-133.57493	:America/Juneau	USA	knots	316	146	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Strait, west end	AK
108155	Shakan Strait, west end (depth 15 ft), Sumner Strait, Alaska Current	NOS	SEA0612_5	56.12992	-133.57493	:America/Juneau	USA	knots	314	152	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Strait, west end	AK
108156	Shakan Strait Rock (depth 70 ft), Sumner Strait, Alaska Current	NOS	SEA0613_1	56.12743	-133.49875	:America/Juneau	USA	knots	233	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Strait Rock	AK
108157	Shakan Strait Rock (depth 44 ft), Sumner Strait, Alaska Current	NOS	SEA0613_5	56.12743	-133.49875	:America/Juneau	USA	knots	237	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Strait Rock	AK
108158	Shakan Strait Rock (depth 17 ft), Sumner Strait, Alaska Current	NOS	SEA0613_9	56.12743	-133.49875	:America/Juneau	USA	knots	241	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Strait Rock	AK
108159	El Capitan Strait, northwest entrance (depth 20 ft), El Capitan Passage, Alaska Current	NOS	SEA0614_1	56.15352	-133.45707	:America/Juneau	USA	knots	246	75	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	El Capitan Strait, northwest entrance	AK
108160	El Capitan Strait, northwest entrance (depth 14 ft), El Capitan Passage, Alaska Current	NOS	SEA0614_2	56.15352	-133.45707	:America/Juneau	USA	knots	235	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	El Capitan Strait, northwest entrance	AK
108161	Dry Pass (depth 16 ft), Sumner Strait, Alaska Current	NOS	SEA0616_5	56.16123	-133.39945	:America/Juneau	USA	knots	286	120	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dry Pass	AK
108162	Dry Pass (depth 6 ft), Sumner Strait, Alaska Current	NOS	SEA0616_11	56.16123	-133.39945	:America/Juneau	USA	knots	275	115	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dry Pass	AK
108163	Affleck Canal (depth 229 ft), Sumner Strait, Alaska Current	NOS	SEA0617_8	56.10349	-134.06615	:America/Juneau	USA	knots	179	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Affleck Canal	AK
108164	Affleck Canal (depth 124 ft), Sumner Strait, Alaska Current	NOS	SEA0617_12	56.10349	-134.06615	:America/Juneau	USA	knots	175	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Affleck Canal	AK
108165	Fairway Island, 2 nmi east of (depth 110 ft), Sumner Strait, Alaska Current	NOS	SEA0618_1	56.04959	-133.98963	:America/Juneau	USA	knots	240	109	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fairway Island, 2nm east of	AK
108166	Fairway Island, 2 nmi east of (depth 64 ft), Sumner Strait, Alaska Current	NOS	SEA0618_8	56.04959	-133.98963	:America/Juneau	USA	knots	153	91	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fairway Island, 2nm east of	AK
108167	Fairway Island, 2 nmi east of (depth 25 ft), Sumner Strait, Alaska Current	NOS	SEA0618_14	56.04959	-133.98963	:America/Juneau	USA	knots	257	89	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fairway Island, 2nm east of	AK
108168	Fairway Island, SW of (depth 182 ft), Sumner Strait, Alaska Current	NOS	SEA0619_1	56.03688	-134.07526	:America/Juneau	USA	knots	206	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fairway Island, SW of	AK
108169	Fairway Island, SW of (depth 117 ft), Sumner Strait, Alaska Current	NOS	SEA0619_6	56.03688	-134.07526	:America/Juneau	USA	knots	189	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fairway Island, SW of	AK
108170	Fairway Island, SW of (depth 38 ft), Sumner Strait, Alaska Current	NOS	SEA0619_12	56.03688	-134.07526	:America/Juneau	USA	knots	197	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.233	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fairway Island, SW of	AK
108171	Coronation Island - Spanish Island, between (depth 129 ft), Sumner Strait, Alaska Current	NOS	SEA0621_1	55.92551	-134.12815	:America/Juneau	USA	knots	91	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coronation Island - Spanish Island, between	AK
108172	Coronation Island - Spanish Island, between (depth 83 ft), Sumner Strait, Alaska Current	NOS	SEA0621_8	55.92551	-134.12815	:America/Juneau	USA	knots	97	264	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coronation Island - Spanish Island, between	AK
108173	Coronation Island - Spanish Island, between (depth 37 ft), Sumner Strait, Alaska Current	NOS	SEA0621_15	55.92551	-134.12815	:America/Juneau	USA	knots	99	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coronation Island - Spanish Island, between	AK
108174	Warren Channel (depth 92 ft), Sumner Strait, Alaska Current	NOS	SEA0622_1	55.93346	-133.83525	:America/Juneau	USA	knots	160	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.222	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Warren Channel	AK
108175	Warren Channel (depth 52 ft), Sumner Strait, Alaska Current	NOS	SEA0622_5	55.93346	-133.83525	:America/Juneau	USA	knots	164	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Warren Channel	AK
108176	Warren Channel (depth 23 ft), Sumner Strait, Alaska Current	NOS	SEA0622_8	55.93346	-133.83525	:America/Juneau	USA	knots	171	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.171	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Warren Channel	AK
108177	Whale Rock, 1.0 nmi SE of (depth 252 ft), Alaska Current	NOS	SEA0624_1	55.83345	-133.67503	:America/Juneau	USA	knots	242	71	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Rock, 1.0 nm SE of	AK
108178	Whale Rock, 1.0 nmi SE of (depth 147 ft), Alaska Current	NOS	SEA0624_9	55.83345	-133.67503	:America/Juneau	USA	knots	234	81	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Rock, 1.0 nm SE of	AK
108179	Whale Rock, 1.0 nmi SE of (depth 42 ft), Alaska Current	NOS	SEA0624_17	55.83345	-133.67503	:America/Juneau	USA	knots	236	80	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Rock, 1.0 nm SE of	AK
108180	Tokeen Bay (depth 58 ft), Alaska Current	NOS	SEA0625_1	56.00262	-133.45682	:America/Juneau	USA	knots	274	75	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tokeen Bay	AK
108181	Tokeen Bay (depth 38 ft), Alaska Current	NOS	SEA0625_4	56.00262	-133.45682	:America/Juneau	USA	knots	268	70	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tokeen Bay	AK
108182	Tokeen Bay (depth 12 ft), Alaska Current	NOS	SEA0625_8	56.00262	-133.45682	:America/Juneau	USA	knots	260	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tokeen Bay	AK
108183	South entrance (depth 278 ft), El Capitan Passage, Alaska Current	NOS	SEA0626_1	55.89663	-133.36525	:America/Juneau	USA	knots	194	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South entrance	AK
108184	South entrance (depth 159 ft), El Capitan Passage, Alaska Current	NOS	SEA0626_10	55.89663	-133.36525	:America/Juneau	USA	knots	187	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South entrance	AK
108185	South entrance (depth 41 ft), El Capitan Passage, Alaska Current	NOS	SEA0626_19	55.89663	-133.36525	:America/Juneau	USA	knots	204	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South entrance	AK
108186	Tuxekan Passage, north of Kutegi Point (depth 64 ft), Alaska Current	NOS	SEA0627_1	55.908	-133.27065	:America/Juneau	USA	knots	167	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tuxekan Passage, north of Kutegi Point	AK
108187	Tuxekan Passage, north of Kutegi Point (depth 38 ft), Alaska Current	NOS	SEA0627_5	55.908	-133.27065	:America/Juneau	USA	knots	163	324	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tuxekan Passage, north of Kutegi Point	AK
108188	Tuxekan Passage, north of Kutegi Point (depth 17 ft), Alaska Current	NOS	SEA0627_8	55.908	-133.27065	:America/Juneau	USA	knots	155	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tuxekan Passage, north of Kutegi Point	AK
108189	Sea Otter Sound (depth 266 ft), Alaska Current	NOS	SEA0628_1	55.84245	-133.51345	:America/Juneau	USA	knots	304	127	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Otter Sound	AK
108190	Sea Otter Sound (depth 147 ft), Alaska Current	NOS	SEA0628_10	55.84245	-133.51345	:America/Juneau	USA	knots	307	118	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Otter Sound	AK
108191	Sea Otter Sound (depth 82 ft), Alaska Current	NOS	SEA0628_15	55.84245	-133.51345	:America/Juneau	USA	knots	305	128	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Otter Sound	AK
108192	Karheen Passage, west of Cob Island (depth 76 ft), Alaska Current	NOS	SEA0629_1	55.79676	-133.30957	:America/Juneau	USA	knots	337	173	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Karheen Passage, west of Cob Island	AK
108193	Karheen Passage, west of Cob Island (depth 46 ft), Alaska Current	NOS	SEA0629_10	55.79676	-133.30957	:America/Juneau	USA	knots	335	166	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Karheen Passage, west of Cob Island	AK
108194	Karheen Passage, west of Cob Island (depth 14 ft), Alaska Current	NOS	SEA0629_20	55.79676	-133.30957	:America/Juneau	USA	knots	333	161	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Karheen Passage, west of Cob Island	AK
108195	Tonowek Narrows (depth 108 ft), Alaska Current	NOS	SEA0630_2	55.75918	-133.33546	:America/Juneau	USA	knots	214	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tonowek Narrows	AK
108196	Tonowek Narrows (depth 62 ft), Alaska Current	NOS	SEA0630_16	55.75918	-133.33546	:America/Juneau	USA	knots	219	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tonowek Narrows	AK
108197	Tonowek Narrows (depth 16 ft), Alaska Current	NOS	SEA0630_30	55.75918	-133.33546	:America/Juneau	USA	knots	224	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tonowek Narrows	AK
108198	Boca de Finas (depth 60 ft), Alaska Current	NOS	SEA0632_12	55.69768	-133.58734	:America/Juneau	USA	knots	315	125	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boca de Finas	AK
108199	Dead Tree Point (depth 102 ft), Alaska Current	NOS	SEA0633_2	55.74561	-133.67059	:America/Juneau	USA	knots	332	156	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dead Tree Point	AK
108200	Dead Tree Point (depth 62 ft), Alaska Current	NOS	SEA0633_8	55.74561	-133.67059	:America/Juneau	USA	knots	352	154	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dead Tree Point	AK
108201	Dead Tree Point (depth 23 ft), Alaska Current	NOS	SEA0633_14	55.74561	-133.67059	:America/Juneau	USA	knots	347	154	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dead Tree Point	AK
108202	Timbered Island (depth 79 ft), Alaska Current	NOS	SEA0634_1	55.69388	-133.78426	:America/Juneau	USA	knots	202	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Timbered Island	AK
108203	Timbered Island (depth 53 ft), Alaska Current	NOS	SEA0634_5	55.69388	-133.78426	:America/Juneau	USA	knots	209	32	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Timbered Island	AK
108204	Timbered Island (depth 14 ft), Alaska Current	NOS	SEA0634_11	55.69388	-133.78426	:America/Juneau	USA	knots	203	28	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Timbered Island	AK
108205	Saint Nicholas Channel, north (depth 121 ft), Alaska Current	NOS	SEA0635_2	55.52955	-133.56271	:America/Juneau	USA	knots	196	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saint Nicholas Channel, north	AK
108206	Saint Nicholas Channel, north (depth 81 ft), Alaska Current	NOS	SEA0635_6	55.52955	-133.56271	:America/Juneau	USA	knots	198	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saint Nicholas Channel, north	AK
108207	Saint Nicholas Channel, north (depth 22 ft), Alaska Current	NOS	SEA0635_12	55.52955	-133.56271	:America/Juneau	USA	knots	184	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saint Nicholas Channel, north	AK
108208	Saint Nicholas Channel, south end (depth 146 ft), Alaska Current	NOS	SEA0636_2	55.45502	-133.63084	:America/Juneau	USA	knots	216	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saint Nicholas Channel, south end	AK
108209	Saint Nicholas Channel, south end (depth 87 ft), Alaska Current	NOS	SEA0636_8	55.45502	-133.63084	:America/Juneau	USA	knots	209	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saint Nicholas Channel, south end	AK
108210	Saint Nicholas Channel, south end (depth 28 ft), Alaska Current	NOS	SEA0636_14	55.45502	-133.63084	:America/Juneau	USA	knots	211	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saint Nicholas Channel, south end	AK
108211	Portillo Channel (depth 74 ft), Alaska Current	NOS	SEA0637_1	55.49249	-133.42566	:America/Juneau	USA	knots	159	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portillo Channel	AK
108212	Portillo Channel (depth 47 ft), Alaska Current	NOS	SEA0637_5	55.49249	-133.42566	:America/Juneau	USA	knots	155	338	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portillo Channel	AK
108213	Portillo Channel (depth 15 ft), Alaska Current	NOS	SEA0637_10	55.49249	-133.42566	:America/Juneau	USA	knots	170	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portillo Channel	AK
108214	San Christoval Chanel, Larz Lt., 0.25 nmi N of (depth 104 ft), Alaska Current	NOS	SEA0638_1	55.58824	-133.3305	:America/Juneau	USA	knots	100	307	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Christoval Chanel, Larz Lt., 0.25nm N of	AK
108215	San Christoval Chanel, Larz Lt., 0.25 nmi N of (depth 65 ft), Alaska Current	NOS	SEA0638_5	55.58824	-133.3305	:America/Juneau	USA	knots	107	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Christoval Chanel, Larz Lt., 0.25nm N of	AK
108216	San Christoval Chanel, Larz Lt., 0.25 nmi N of (depth 16 ft), Alaska Current	NOS	SEA0638_10	55.58824	-133.3305	:America/Juneau	USA	knots	106	315	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Christoval Chanel, Larz Lt., 0.25nm N of	AK
108217	San Christoval Rock (depth 42 ft), Alaska Current	NOS	SEA0639_1	55.562721	-133.29922	:America/Juneau	USA	knots	124	307	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Christoval Rock	AK
108218	San Christoval Rock (depth 29 ft), Alaska Current	NOS	SEA0639_3	55.562721	-133.29922	:America/Juneau	USA	knots	126	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Christoval Rock	AK
108219	San Christoval Rock (depth 15 ft), Alaska Current	NOS	SEA0639_5	55.562721	-133.29922	:America/Juneau	USA	knots	126	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Christoval Rock	AK
108220	Arriaga Passage, west end (depth 95 ft), Alaska Current	NOS	SEA0641_1	55.57189	-133.73307	:America/Juneau	USA	knots	274	68	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arriaga Passage, west end	AK
108221	Arriaga Passage, west end (depth 62 ft), Alaska Current	NOS	SEA0641_3	55.57189	-133.73307	:America/Juneau	USA	knots	267	65	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arriaga Passage, west end	AK
108222	Arriaga Passage, west end (depth 29 ft), Alaska Current	NOS	SEA0641_5	55.57189	-133.73307	:America/Juneau	USA	knots	265	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arriaga Passage, west end	AK
108223	Point Rosary, west of (depth 327 ft), Alaska Current	NOS	SEA0703_1	55.27037	-133.5224	:America/Juneau	USA	knots	\N	27.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Rosary, west of	AK
108224	Point Rosary, west of (depth 196 ft), Alaska Current	NOS	SEA0703_9	55.27037	-133.5224	:America/Juneau	USA	knots	\N	9.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Rosary, west of	AK
108225	Point Rosary, west of (depth 48 ft), Alaska Current	NOS	SEA0703_18	55.27037	-133.5224	:America/Juneau	USA	knots	199	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Rosary, west of	AK
108226	Point Verde (depth 93 ft), Ulloa Channel, Alaska Current	NOS	SEA0704_1	55.29915	-133.26773	:America/Juneau	USA	knots	343	136.6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Verde	AK
108227	Point Verde (depth 54 ft), Ulloa Channel, Alaska Current	NOS	SEA0704_4	55.29915	-133.26773	:America/Juneau	USA	knots	\N	129	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Verde	AK
108228	Point Verde (depth 14 ft), Ulloa Channel, Alaska Current	NOS	SEA0704_7	55.29915	-133.26773	:America/Juneau	USA	knots	315	134	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Verde	AK
108229	Eagle Point (depth 246 ft), Meares Passage, Alaska Current	NOS	SEA0705_2	55.22023	-133.24109	:America/Juneau	USA	knots	\N	1.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Point	AK
108230	Eagle Point (depth 148 ft), Meares Passage, Alaska Current	NOS	SEA0705_7	55.22023	-133.24109	:America/Juneau	USA	knots	184	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Point	AK
108231	Eagle Point (depth 30 ft), Meares Passage, Alaska Current	NOS	SEA0705_13	55.22023	-133.24109	:America/Juneau	USA	knots	283	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Point	AK
108232	Tlevak Narrows, Turn Point, east of (depth 77 ft), Tlevak Strait, Alaska Current	NOS	SEA0706_1	55.26486	-133.12236	:America/Juneau	USA	knots	327	127	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.242	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tlevak Narrows, Turn Point, east of	AK
108233	Tlevak Narrows, Turn Point, east of (depth 44 ft), Tlevak Strait, Alaska Current	NOS	SEA0706_11	55.26486	-133.12236	:America/Juneau	USA	knots	333	120	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.677	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tlevak Narrows, Turn Point, east of	AK
108234	Tlevak Narrows, Turn Point, east of (depth 14 ft), Tlevak Strait, Alaska Current	NOS	SEA0706_20	55.26486	-133.12236	:America/Juneau	USA	knots	330	120	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.72	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tlevak Narrows, Turn Point, east of	AK
108235	Cape Chacon, south of (depth 357 ft), Dixon Entrance, Alaska Current	NOS	SEA0708_1	54.62556	-132.05715	:America/Juneau	USA	knots	264	88	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chacon, south of	AK
108236	Cape Chacon, south of (depth 200 ft), Dixon Entrance, Alaska Current	NOS	SEA0708_7	54.62556	-132.05715	:America/Juneau	USA	knots	261	76	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.225	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chacon, south of	AK
108237	Cape Chacon, south of (depth 42 ft), Dixon Entrance, Alaska Current	NOS	SEA0708_13	54.62556	-132.05715	:America/Juneau	USA	knots	254	156	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.558	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chacon, south of	AK
108238	Happy Harbor, Kasaan Island, Kasaan Bay (depth 295 ft), Clarence Strait, Alaska Current	NOS	SEA0709_1	55.50378	-132.3162	:America/Juneau	USA	knots	\N	292.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Happy Harbor, Kasaan Island, Kasaan Bay	AK
108582	Akutan Pass (depth 207 ft), Aleutian Islands, Alaska Current	NOS	UNI1010_1	54.02455	-166.09753	:America/Nome	USA	knots	98	295	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.494	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan Pass	AK
108239	Happy Harbor, Kasaan Island, Kasaan Bay (depth 176 ft), Clarence Strait, Alaska Current	NOS	SEA0709_7	55.50378	-132.3162	:America/Juneau	USA	knots	124	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Happy Harbor, Kasaan Island, Kasaan Bay	AK
108240	Happy Harbor, Kasaan Island, Kasaan Bay (depth 39 ft), Clarence Strait, Alaska Current	NOS	SEA0709_14	55.50378	-132.3162	:America/Juneau	USA	knots	118	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Happy Harbor, Kasaan Island, Kasaan Bay	AK
108241	Grindall Island, south of (depth 220 ft), Clarence Strait, Alaska Current	NOS	SEA0710_1	55.41102	-132.12643	:America/Juneau	USA	knots	75	280	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grindall Island, south of	AK
108242	Grindall Island, south of (depth 122 ft), Clarence Strait, Alaska Current	NOS	SEA0710_11	55.41102	-132.12643	:America/Juneau	USA	knots	108	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grindall Island, south of	AK
108243	Grindall Island, south of (depth 24 ft), Clarence Strait, Alaska Current	NOS	SEA0710_21	55.41102	-132.12643	:America/Juneau	USA	knots	183	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grindall Island, south of	AK
108244	East of the airport (depth 87 ft), Tongass Narrows, Alaska Current	NOS	SEA0711_1	55.35408	-131.69973	:America/Juneau	USA	knots	117	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.357	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	east of the airport	AK
108245	East of the airport (depth 55 ft), Tongass Narrows, Alaska Current	NOS	SEA0711_6	55.35408	-131.69973	:America/Juneau	USA	knots	128	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	east of the airport	AK
108246	East of the airport (depth 15 ft), Tongass Narrows, Alaska Current	NOS	SEA0711_12	55.35408	-131.69973	:America/Juneau	USA	knots	133	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.264	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	east of the airport	AK
108247	Pennock Island, east channel (depth 101 ft), Tongass Narrows, Alaska Current	NOS	SEA0712_1	55.31227	-131.59635	:America/Juneau	USA	knots	\N	310	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pennock Island, East Channel	AK
108248	Pennock Island, east channel (depth 62 ft), Tongass Narrows, Alaska Current	NOS	SEA0712_7	55.31227	-131.59635	:America/Juneau	USA	knots	132	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pennock Island, East Channel	AK
108249	Pennock Island, east channel (depth 16 ft), Tongass Narrows, Alaska Current	NOS	SEA0712_14	55.31227	-131.59635	:America/Juneau	USA	knots	139	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.146	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pennock Island, East Channel	AK
108250	Walden Rocks, 0.4 mi north of (depth 115 ft), Nichols Passage, Alaska Current	NOS	SEA0713_1	55.2785	-131.61152	:America/Juneau	USA	knots	231	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.227	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Walden Rocks, 0.4 mile north of	AK
108251	Walden Rocks, 0.4 mi north of (depth 76 ft), Nichols Passage, Alaska Current	NOS	SEA0713_4	55.2785	-131.61152	:America/Juneau	USA	knots	233	47	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Walden Rocks, 0.4 mile north of	AK
108252	Walden Rocks, 0.4 mi north of (depth 23 ft), Nichols Passage, Alaska Current	NOS	SEA0713_8	55.2785	-131.61152	:America/Juneau	USA	knots	207	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Walden Rocks, 0.4 mile north of	AK
108253	Pennock Island, west channel (depth 80 ft), Tongass Narrows, Alaska Current	NOS	SEA0714_1	55.30143	-131.61598	:America/Juneau	USA	knots	\N	335.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pennock Island, West Channel	AK
108254	Pennock Island, west channel (depth 41 ft), Tongass Narrows, Alaska Current	NOS	SEA0714_4	55.30143	-131.61598	:America/Juneau	USA	knots	145	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pennock Island, West Channel	AK
108255	Pennock Island, west channel (depth 14 ft), Tongass Narrows, Alaska Current	NOS	SEA0714_6	55.30143	-131.61598	:America/Juneau	USA	knots	149	296	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pennock Island, West Channel	AK
108256	Juneau Harbor, N of (depth 79 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0801_1	58.29641	-134.42468	:America/Juneau	USA	knots	\N	327.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau Harbor, N of	AK
108257	Juneau Harbor, N of (depth 50 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0801_4	58.29641	-134.42468	:America/Juneau	USA	knots	150	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau Harbor, N of	AK
108258	Juneau Harbor, N of (depth 10 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0801_8	58.29641	-134.42468	:America/Juneau	USA	knots	147	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau Harbor, N of	AK
108259	Juneau Harbor, S of (depth 53 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0803_1	58.284779	-134.39763	:America/Juneau	USA	knots	138	314	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau Harbor, S of	AK
108260	Juneau Harbor, S of (depth 33 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0803_4	58.284779	-134.39763	:America/Juneau	USA	knots	145	314	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau Harbor, S of	AK
108261	Juneau Harbor, S of (depth 13 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0803_7	58.284779	-134.39763	:America/Juneau	USA	knots	150	315	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.177	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau Harbor, S of	AK
108262	N of Ship Creek (depth 81 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0804_1	58.257439	-134.33604	:America/Juneau	USA	knots	131	324	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	N of Ship Creek	AK
108263	N of Ship Creek (depth 54 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0804_3	58.257439	-134.33604	:America/Juneau	USA	knots	136	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	N of Ship Creek	AK
108264	N of Ship Creek (depth 15 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0804_6	58.257439	-134.33604	:America/Juneau	USA	knots	144	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	N of Ship Creek	AK
108265	Point Salisbury, west of (depth 67 ft), Stephens Passage, Alaska Current	NOS	SEA0805_9	58.209221	-134.24968	:America/Juneau	USA	knots	\N	318.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Salisbury, west of	AK
108266	Point Salisbury, west of (depth 21 ft), Stephens Passage, Alaska Current	NOS	SEA0805_16	58.209221	-134.24968	:America/Juneau	USA	knots	149	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Salisbury, west of	AK
108267	Point Coke, SE of, Tracy Arm (depth 289 ft), Stephens Passage, Alaska Current	NOS	SEA0810_1	57.776031	-133.64967	:America/Juneau	USA	knots	277	90	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Coke, SE of, Tracy Arm	AK
108268	Point Coke, SE of, Tracy Arm (depth 170 ft), Stephens Passage, Alaska Current	NOS	SEA0810_7	57.776031	-133.64967	:America/Juneau	USA	knots	260	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Coke, SE of, Tracy Arm	AK
108269	Point Coke, SE of, Tracy Arm (depth 33 ft), Stephens Passage, Alaska Current	NOS	SEA0810_14	57.776031	-133.64967	:America/Juneau	USA	knots	262	85	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.299	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Coke, SE of, Tracy Arm	AK
108270	Point Astley, NE of, Tracy Arm (depth 289 ft), Stephens Passage, Alaska Current	NOS	SEA0811_1	57.730019	-133.63124	:America/Juneau	USA	knots	291	106.5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Astley, NE of, Tracy Arm	AK
108271	Point Astley, NE of, Tracy Arm (depth 170 ft), Stephens Passage, Alaska Current	NOS	SEA0811_7	57.730019	-133.63124	:America/Juneau	USA	knots	209	55.8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Astley, NE of, Tracy Arm	AK
108272	Point Astley, NE of, Tracy Arm (depth 33 ft), Stephens Passage, Alaska Current	NOS	SEA0811_14	57.730019	-133.63124	:America/Juneau	USA	knots	218	115	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Astley, NE of, Tracy Arm	AK
108273	Tantallon Point, SW of (depth 184 ft), Stephens Passage, Alaska Current	NOS	SEA0812_1	58.172871	-134.2881	:America/Juneau	USA	knots	96	275.1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.179	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tantallon Point, SW of	AK
108274	Tantallon Point, SW of (depth 116 ft), Stephens Passage, Alaska Current	NOS	SEA0812_8	58.172871	-134.2881	:America/Juneau	USA	knots	95	274.6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.209	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tantallon Point, SW of	AK
108275	Tantallon Point, SW of (depth 37 ft), Stephens Passage, Alaska Current	NOS	SEA0812_16	58.172871	-134.2881	:America/Juneau	USA	knots	96	269	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tantallon Point, SW of	AK
108276	Point Young (depth 81 ft), Stephens Passage, Alaska Current	NOS	SEA0813_1	58.20903	-134.55865	:America/Juneau	USA	knots	84	270.4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.422	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Young	AK
108277	Point Young (depth 55 ft), Stephens Passage, Alaska Current	NOS	SEA0813_3	58.20903	-134.55865	:America/Juneau	USA	knots	89	275.9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.377	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Young	AK
108278	Point Young (depth 16 ft), Stephens Passage, Alaska Current	NOS	SEA0813_6	58.20903	-134.55865	:America/Juneau	USA	knots	80	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Young	AK
108279	Portland Island, SW of (depth 175 ft), Stephens Passage, Alaska Current	NOS	SEA0814_1	58.31937	-134.7119	:America/Juneau	USA	knots	15	212	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Island, SW of	AK
108280	Portland Island, SW of (depth 24 ft), Stephens Passage, Alaska Current	NOS	SEA0814_24	58.31937	-134.7119	:America/Juneau	USA	knots	\N	157.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Island, SW of	AK
108281	Piling Point, east of (depth 138 ft), Stephens Passage, Alaska Current	NOS	SEA0816_1	58.3281	-134.78336	:America/Juneau	USA	knots	326	147.1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.176	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piling Point, east of	AK
108282	Piling Point, east of (depth 79 ft), Stephens Passage, Alaska Current	NOS	SEA0816_10	58.3281	-134.78336	:America/Juneau	USA	knots	\N	151	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.265	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piling Point, east of	AK
108283	Piling Point, east of (depth 20 ft), Stephens Passage, Alaska Current	NOS	SEA0816_19	58.3281	-134.78336	:America/Juneau	USA	knots	321	140	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piling Point, east of	AK
108284	Saginaw Channel, 2 mi E of Point Retreat (depth 106 ft), Stephens Passage, Alaska Current	NOS	SEA0818_1	58.405	-134.885	:America/Juneau	USA	knots	355	151	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saginaw Channel, 2 miles E of Point Retreat	AK
108285	Saginaw Channel, 2 mi E of Point Retreat (depth 67 ft), Stephens Passage, Alaska Current	NOS	SEA0818_4	58.405	-134.885	:America/Juneau	USA	knots	347	146	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saginaw Channel, 2 miles E of Point Retreat	AK
108286	Saginaw Channel, 2 mi E of Point Retreat (depth 15 ft), Stephens Passage, Alaska Current	NOS	SEA0818_8	58.405	-134.885	:America/Juneau	USA	knots	345	148	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saginaw Channel, 2 miles E of Point Retreat	AK
108287	North Pass, Lincoln Island (depth 230 ft), Lynn Canal, Alaska Current	NOS	SEA0819_1	58.474739	-134.9323	:America/Juneau	USA	knots	169	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Pass, Lincoln Island	AK
108288	North Pass, Lincoln Island (depth 131 ft), Lynn Canal, Alaska Current	NOS	SEA0819_11	58.474739	-134.9323	:America/Juneau	USA	knots	166	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Pass, Lincoln Island	AK
108583	Akutan Pass (depth 128 ft), Aleutian Islands, Alaska Current	NOS	UNI1010_13	54.02455	-166.09753	:America/Nome	USA	knots	102	299	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.757	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan Pass	AK
108289	North Pass, Lincoln Island (depth 33 ft), Lynn Canal, Alaska Current	NOS	SEA0819_21	58.474739	-134.9323	:America/Juneau	USA	knots	161	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Pass, Lincoln Island	AK
108290	Point Retreat, 1 mi west of (depth 413 ft), Lynn Canal, Alaska Current	NOS	SEA0820_1	58.416779	-134.9666	:America/Juneau	USA	knots	\N	354.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Retreat, 1 mile west of	AK
108291	Point Retreat, 1 mi west of (depth 232 ft), Lynn Canal, Alaska Current	NOS	SEA0820_12	58.416779	-134.9666	:America/Juneau	USA	knots	213	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Retreat, 1 mile west of	AK
108292	Point Retreat, 1 mi west of (depth 52 ft), Lynn Canal, Alaska Current	NOS	SEA0820_23	58.416779	-134.9666	:America/Juneau	USA	knots	243	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Retreat, 1 mile west of	AK
108293	Vanderbilt Reef, 2 mi west of (depth 534 ft), Lynn Canal, Alaska Current	NOS	SEA0822_1	58.603531	-135.04314	:America/Juneau	USA	knots	\N	31.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vanderbilt Reef, 2 miles west of	AK
108294	Vanderbilt Reef, 2 mi west of (depth 298 ft), Lynn Canal, Alaska Current	NOS	SEA0822_10	58.603531	-135.04314	:America/Juneau	USA	knots	\N	52.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vanderbilt Reef, 2 miles west of	AK
108295	Vanderbilt Reef, 2 mi west of (depth 88 ft), Lynn Canal, Alaska Current	NOS	SEA0822_18	58.603531	-135.04314	:America/Juneau	USA	knots	175	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vanderbilt Reef, 2 miles west of	AK
108296	Low Point, Taiya Inlet entrance (depth 185 ft), Lynn Canal, Alaska Current	NOS	SEA0825_1	59.267231	-135.38091	:America/Juneau	USA	knots	\N	9.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Low Point, Taiya Inlet entrance	AK
108297	Low Point, Taiya Inlet entrance (depth 106 ft), Lynn Canal, Alaska Current	NOS	SEA0825_9	59.267231	-135.38091	:America/Juneau	USA	knots	\N	13	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Low Point, Taiya Inlet entrance	AK
108298	Low Point, Taiya Inlet entrance (depth 37 ft), Lynn Canal, Alaska Current	NOS	SEA0825_16	59.267231	-135.38091	:America/Juneau	USA	knots	186	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Low Point, Taiya Inlet entrance	AK
108299	Battery Point, Chilkoot Inlet (depth 241 ft), Lynn Canal, Alaska Current	NOS	SEA0826_1	59.216881	-135.35043	:America/Juneau	USA	knots	186	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Battery Point, Chilkoot Inlet	AK
108300	Battery Point, Chilkoot Inlet (depth 133 ft), Lynn Canal, Alaska Current	NOS	SEA0826_12	59.216881	-135.35043	:America/Juneau	USA	knots	181	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Battery Point, Chilkoot Inlet	AK
108301	Battery Point, Chilkoot Inlet (depth 35 ft), Lynn Canal, Alaska Current	NOS	SEA0826_22	59.216881	-135.35043	:America/Juneau	USA	knots	177	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Battery Point, Chilkoot Inlet	AK
108302	Glacier Point, Chilkat Inlet (depth 341 ft), Lynn Canal, Alaska Current	NOS	SEA0827_1	59.104671	-135.3732	:America/Juneau	USA	knots	153	329	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Point, Chilkat Inlet	AK
108303	Glacier Point, Chilkat Inlet (depth 194 ft), Lynn Canal, Alaska Current	NOS	SEA0827_10	59.104671	-135.3732	:America/Juneau	USA	knots	147	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Point, Chilkat Inlet	AK
108304	Glacier Point, Chilkat Inlet (depth 46 ft), Lynn Canal, Alaska Current	NOS	SEA0827_19	59.104671	-135.3732	:America/Juneau	USA	knots	146	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Point, Chilkat Inlet	AK
108305	South Inian Pass, west end (depth 139 ft), Cross Sound, Alaska Current	NOS	SEA0830_1	58.227909	-136.35449	:America/Juneau	USA	knots	266	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.179	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Inian Pass, west end	AK
108306	South Inian Pass, west end (depth 80 ft), Cross Sound, Alaska Current	NOS	SEA0830_10	58.227909	-136.35449	:America/Juneau	USA	knots	270	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.187	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Inian Pass, west end	AK
108307	South Inian Pass, west end (depth 21 ft), Cross Sound, Alaska Current	NOS	SEA0830_19	58.227909	-136.35449	:America/Juneau	USA	knots	270	68	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Inian Pass, west end	AK
108308	Port Althrop ent., east of George Island (depth 239 ft), Cross Sound, Alaska Current	NOS	SEA0831_1	58.201672	-136.36292	:America/Juneau	USA	knots	195	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.41	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Althrop entr, east of George Island	AK
108309	Port Althrop ent., east of George Island (depth 134 ft), Cross Sound, Alaska Current	NOS	SEA0831_17	58.201672	-136.36292	:America/Juneau	USA	knots	161	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.453	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Althrop entr, east of George Island	AK
108310	Port Althrop ent., east of George Island (depth 29 ft), Cross Sound, Alaska Current	NOS	SEA0831_33	58.201672	-136.36292	:America/Juneau	USA	knots	159	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.645	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Althrop entr, east of George Island	AK
108311	Cape Spencer, 3 mi south of (depth 236 ft), Cross Sound, Alaska Current	NOS	SEA0832_1	58.150318	-136.63261	:America/Juneau	USA	knots	227	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Spencer, 3 miles south of	AK
108312	Cape Spencer, 3 mi south of (depth 137 ft), Cross Sound, Alaska Current	NOS	SEA0832_11	58.150318	-136.63261	:America/Juneau	USA	knots	242	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.345	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Spencer, 3 miles south of	AK
108313	Cape Spencer, 3 mi south of (depth 39 ft), Cross Sound, Alaska Current	NOS	SEA0832_21	58.150318	-136.63261	:America/Juneau	USA	knots	228	88	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.498	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Spencer, 3 miles south of	AK
108314	Yakobi Rock, 1 mi west of (depth 419 ft), Cross Sound, Alaska Current	NOS	SEA0833_1	58.082668	-136.59917	:America/Juneau	USA	knots	\N	30.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yakobi Rock, 1 mile west of	AK
108315	Yakobi Rock, 1 mi west of (depth 235 ft), Cross Sound, Alaska Current	NOS	SEA0833_8	58.082668	-136.59917	:America/Juneau	USA	knots	217	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yakobi Rock, 1 mile west of	AK
108316	Yakobi Rock, 1 mi west of (depth 77 ft), Cross Sound, Alaska Current	NOS	SEA0833_14	58.082668	-136.59917	:America/Juneau	USA	knots	219	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yakobi Rock, 1 mile west of	AK
108317	Point Hogan, south passage (depth 138 ft), Alaska Current	NOS	SEA0835_1	57.68816	-136.256	:America/Juneau	USA	knots	\N	54.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Hogan, South Passage	AK
108318	Point Hogan, south passage (depth 79 ft), Alaska Current	NOS	SEA0835_10	57.68816	-136.256	:America/Juneau	USA	knots	243	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.062	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Hogan, South Passage	AK
108319	Point Hogan, south passage (depth 20 ft), Alaska Current	NOS	SEA0835_19	57.68816	-136.256	:America/Juneau	USA	knots	241	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Hogan, South Passage	AK
108320	Elbow Passage, south of Klag Island (depth 83 ft), Alaska Current	NOS	SEA0837_1	57.613762	-136.09943	:America/Juneau	USA	knots	223	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elbow Passage, south of Klag Island	AK
108321	Elbow Passage, south of Klag Island (depth 47 ft), Alaska Current	NOS	SEA0837_12	57.613762	-136.09943	:America/Juneau	USA	knots	263	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elbow Passage, south of Klag Island	AK
108322	Elbow Passage, south of Klag Island (depth 14 ft), Alaska Current	NOS	SEA0837_22	57.613762	-136.09943	:America/Juneau	USA	knots	269	42	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.272	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elbow Passage, south of Klag Island	AK
108323	Lituya Bay entrance (depth 29 ft), Alaska Current	NOS	SEA0838_1	58.614288	-137.6601	:America/Yakutat	USA	knots	205	29	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.581	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lituya Bay Entrance	AK
108324	Lituya Bay entrance (depth 16 ft), Alaska Current	NOS	SEA0838_5	58.614288	-137.6601	:America/Yakutat	USA	knots	207	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.477	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lituya Bay Entrance	AK
108325	Lituya Bay entrance (depth 6 ft), Alaska Current	NOS	SEA0838_8	58.614288	-137.6601	:America/Yakutat	USA	knots	207	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.309	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lituya Bay Entrance	AK
108326	Sisters Reef (depth 326 ft), Alaska Current	NOS	SEA0839_1	58.184361	-135.32483	:America/Juneau	USA	knots	\N	150.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sisters Reef	AK
108327	Sisters Reef (depth 195 ft), Alaska Current	NOS	SEA0839_9	58.184361	-135.32483	:America/Juneau	USA	knots	331	158	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sisters Reef	AK
108328	Sisters Reef (depth 47 ft), Alaska Current	NOS	SEA0839_18	58.184361	-135.32483	:America/Juneau	USA	knots	296	130	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sisters Reef	AK
108329	South Passage (depth 229 ft), Alaska Current	NOS	SEA0843_1	58.235569	-136.09892	:America/Juneau	USA	knots	273	109	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Passage	AK
108330	South Passage (depth 131 ft), Alaska Current	NOS	SEA0843_16	58.235569	-136.09892	:America/Juneau	USA	knots	275	105	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.201	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Passage	AK
108331	South Passage (depth 32 ft), Alaska Current	NOS	SEA0843_31	58.235569	-136.09892	:America/Juneau	USA	knots	274	92	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.469	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Passage	AK
108332	North Passage (depth 238 ft), Alaska Current	NOS	SEA0845_1	58.318218	-136.11786	:America/Juneau	USA	knots	232	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.406	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Passage	AK
108333	North Passage (depth 133 ft), Alaska Current	NOS	SEA0845_17	58.318218	-136.11786	:America/Juneau	USA	knots	263	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Passage	AK
108334	North Passage (depth 34 ft), Alaska Current	NOS	SEA0845_32	58.318218	-136.11786	:America/Juneau	USA	knots	239	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.208	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Passage	AK
108335	Beardslee Island, west of, Glacier Bay (depth 158 ft), Alaska Current	NOS	SEA0847_1	58.467072	-136.03453	:America/Juneau	USA	knots	155	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beardslee Island, West of, Glacier Bay	AK
108336	Beardslee Island, west of, Glacier Bay (depth 86 ft), Alaska Current	NOS	SEA0847_12	58.467072	-136.03453	:America/Juneau	USA	knots	159	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beardslee Island, West of, Glacier Bay	AK
108337	Beardslee Island, west of, Glacier Bay (depth 20 ft), Alaska Current	NOS	SEA0847_22	58.467072	-136.03453	:America/Juneau	USA	knots	185	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beardslee Island, West of, Glacier Bay	AK
108338	Hugh Miller Inlet, Glacier Bay (depth 209 ft), Alaska Current	NOS	SEA0850_1	58.7494	-136.37325	:America/Juneau	USA	knots	\N	347.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hugh Miller Inlet, Glacier Bay	AK
108339	Hugh Miller Inlet, Glacier Bay (depth 117 ft), Alaska Current	NOS	SEA0850_8	58.7494	-136.37325	:America/Juneau	USA	knots	\N	327.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hugh Miller Inlet, Glacier Bay	AK
108340	Hugh Miller Inlet, Glacier Bay (depth 25 ft), Alaska Current	NOS	SEA0850_15	58.7494	-136.37325	:America/Juneau	USA	knots	128	307	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hugh Miller Inlet, Glacier Bay	AK
108341	Lisianski Strait, north of Rock Point (depth 119 ft), Cross Sound, Alaska Current	NOS	SEA0851_1	58.005741	-136.35194	:America/Juneau	USA	knots	284	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lisianski Strait, north of Rock Point	AK
108342	Lisianski Strait, north of Rock Point (depth 67 ft), Cross Sound, Alaska Current	NOS	SEA0851_9	58.005741	-136.35194	:America/Juneau	USA	knots	275	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.216	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lisianski Strait, north of Rock Point	AK
108343	Lisianski Strait, north of Rock Point (depth 14 ft), Cross Sound, Alaska Current	NOS	SEA0851_17	58.005741	-136.35194	:America/Juneau	USA	knots	268	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.39	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lisianski Strait, north of Rock Point	AK
108344	Klawock Narrows, north of Fish Egg Island (depth 55 ft), Alaska Current	NOS	SEA0901_1	55.50733	-133.17993	:America/Juneau	USA	knots	281	102	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Klawock Narrows, north of Fish Egg Island	AK
108345	Klawock Narrows, north of Fish Egg Island (depth 35 ft), Alaska Current	NOS	SEA0901_3	55.50733	-133.17993	:America/Juneau	USA	knots	281	102	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Klawock Narrows, north of Fish Egg Island	AK
108346	Klawock Narrows, north of Fish Egg Island (depth 15 ft), Alaska Current	NOS	SEA0901_5	55.50733	-133.17993	:America/Juneau	USA	knots	269	100	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Klawock Narrows, north of Fish Egg Island	AK
108347	Pleasant Island, southwest of (depth 336 ft), Alaska Current	NOS	SEA1001_1	58.30968	-135.7382	:America/Juneau	USA	knots	318	87	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pleasant Island, southwest of	AK
108348	Pleasant Island, southwest of (depth 205 ft), Alaska Current	NOS	SEA1001_6	58.30968	-135.7382	:America/Juneau	USA	knots	309	92	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.189	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pleasant Island, southwest of	AK
108349	Pleasant Island, southwest of (depth 48 ft), Alaska Current	NOS	SEA1001_12	58.30968	-135.7382	:America/Juneau	USA	knots	323	93	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pleasant Island, southwest of	AK
108350	Glacier Bay entrance, off Point Gustavus (depth 174 ft), Alaska Current	NOS	SEA1002_1	58.38242	-135.94617	:America/Juneau	USA	knots	185	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.622	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, off Point Gustavus	AK
108351	Glacier Bay entrance, off Point Gustavus (depth 101 ft), Alaska Current	NOS	SEA1002_12	58.38242	-135.94617	:America/Juneau	USA	knots	187	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.623	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, off Point Gustavus	AK
108352	Glacier Bay entrance, off Point Gustavus (depth 23 ft), Alaska Current	NOS	SEA1002_24	58.38242	-135.94617	:America/Juneau	USA	knots	187	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.493	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, off Point Gustavus	AK
108353	Glacier Bay entrance, midchannel (depth 192 ft), Alaska Current	NOS	SEA1003_1	58.38213	-135.97673	:America/Juneau	USA	knots	159	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.6	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, midchannel	AK
108354	Glacier Bay entrance, midchannel (depth 113 ft), Alaska Current	NOS	SEA1003_13	58.38213	-135.97673	:America/Juneau	USA	knots	160	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.559	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, midchannel	AK
108355	Glacier Bay entrance, midchannel (depth 28 ft), Alaska Current	NOS	SEA1003_26	58.38213	-135.97673	:America/Juneau	USA	knots	158	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.497	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, midchannel	AK
108356	Glacier Bay entrance, off Point Carolus (depth 161 ft), Alaska Current	NOS	SEA1004_1	58.38275	-136.0155	:America/Juneau	USA	knots	166	312	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.756	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, off Point Carolus	AK
108357	Glacier Bay entrance, off Point Carolus (depth 89 ft), Alaska Current	NOS	SEA1004_12	58.38275	-136.0155	:America/Juneau	USA	knots	172	288	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-1.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, off Point Carolus	AK
108358	Glacier Bay entrance, off Point Carolus (depth 17 ft), Alaska Current	NOS	SEA1004_23	58.38275	-136.0155	:America/Juneau	USA	knots	174	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-1.244	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, off Point Carolus	AK
108359	South Inian Pass, east end (depth 199 ft), Cross Sound, Alaska Current	NOS	SEA1005_1	58.2241	-136.30842	:America/Juneau	USA	knots	229	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Inian Pass, east end	AK
108360	South Inian Pass, east end (depth 113 ft), Cross Sound, Alaska Current	NOS	SEA1005_14	58.2241	-136.30842	:America/Juneau	USA	knots	239	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.159	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Inian Pass, east end	AK
108361	South Inian Pass, east end (depth 28 ft), Cross Sound, Alaska Current	NOS	SEA1005_27	58.2241	-136.30842	:America/Juneau	USA	knots	246	76	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.236	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Inian Pass, east end	AK
108362	North Inian Pass, east end (depth 95 ft), Cross Sound, Alaska Current	NOS	SEA1006_30	58.28403	-136.36993	:America/Juneau	USA	knots	131	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Inian Pass, east end	AK
108363	North Inian Pass, west end (depth 843 ft), Cross Sound, Alaska Current	NOS	SEA1007_2	58.28328	-136.38465	:America/Juneau	USA	knots	\N	105.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.596	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Inian Pass, west end	AK
108364	North Inian Pass, west end (depth 502 ft), Cross Sound, Alaska Current	NOS	SEA1007_15	58.28328	-136.38465	:America/Juneau	USA	knots	\N	69.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Inian Pass, west end	AK
108365	North Inian Pass, west end (depth 135 ft), Cross Sound, Alaska Current	NOS	SEA1007_29	58.28328	-136.38465	:America/Juneau	USA	knots	232	78	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Inian Pass, west end	AK
108366	Cross Sound entrance, NW of Cape Bingham (depth 552 ft), Alaska Current	NOS	SEA1008_17	58.1225	-136.56735	:America/Juneau	USA	knots	\N	6.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Sound Entrance, NW of Cape Bingham	AK
108367	Cross Sound entrance, NW of Cape Bingham (depth 106 ft), Alaska Current	NOS	SEA1008_34	58.1225	-136.56735	:America/Juneau	USA	knots	218	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Sound Entrance, NW of Cape Bingham	AK
108368	Cross Sound entrance, midchannel (depth 696 ft), Alaska Current	NOS	SEA1009_11	58.1531	-136.58747	:America/Juneau	USA	knots	\N	5.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Sound Entrance, midchannel	AK
108369	Cross Sound entrance, midchannel (depth 408 ft), Alaska Current	NOS	SEA1009_22	58.1531	-136.58747	:America/Juneau	USA	knots	\N	40.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Sound Entrance, midchannel	AK
108370	Cross Sound entrance, midchannel (depth 119 ft), Alaska Current	NOS	SEA1009_33	58.1531	-136.58747	:America/Juneau	USA	knots	225	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.258	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Sound Entrance, midchannel	AK
108371	Cross Sound entrance, SE of Cape Spencer Lt. (depth 250 ft), Alaska Current	NOS	SEA1010_1	58.17712	-136.61642	:America/Juneau	USA	knots	219	53	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Sound Entrance, SE of Cape Spencer Lt.	AK
108372	Cross Sound entrance, SE of Cape Spencer Lt. (depth 142 ft), Alaska Current	NOS	SEA1010_12	58.17712	-136.61642	:America/Juneau	USA	knots	232	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.328	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Sound Entrance, SE of Cape Spencer Lt.	AK
108373	Cross Sound entrance, SE of Cape Spencer Lt. (depth 34 ft), Alaska Current	NOS	SEA1010_23	58.17712	-136.61642	:America/Juneau	USA	knots	231	89	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.436	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Sound Entrance, SE of Cape Spencer Lt.	AK
108374	San Francisco Bay entrance (outside) (depth 124 ft), California Current	NOS	SFB1201_10	37.8106	-122.502	:America/Los_Angeles	USA	knots	235	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco Bay Entrance (Outside)	CA
108375	San Francisco Bay entrance (outside) (depth 58 ft), California Current	NOS	SFB1201_20	37.8106	-122.502	:America/Los_Angeles	USA	knots	238	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.326	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco Bay Entrance (Outside)	CA
108376	San Francisco Bay entrance (outside) (depth 19 ft), California Current	NOS	SFB1201_26	37.8106	-122.502	:America/Los_Angeles	USA	knots	239	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.493	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco Bay Entrance (Outside)	CA
108377	Golden Gate Bridge, 0.88 nmi NE of (depth 126 ft), California Current	NOS	SFB1202_1	37.82922	-122.46202	:America/Los_Angeles	USA	knots	213	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golden Gate Bridge, 0.88 nm NE of	CA
108378	Golden Gate Bridge, 0.88 nmi NE of (depth 54 ft), California Current	NOS	SFB1202_12	37.82922	-122.46202	:America/Los_Angeles	USA	knots	231	48	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golden Gate Bridge, 0.88 nm NE of	CA
108379	Golden Gate Bridge, 0.88 nmi NE of (depth 21 ft), California Current	NOS	SFB1202_17	37.82922	-122.46202	:America/Los_Angeles	USA	knots	238	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.265	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golden Gate Bridge, 0.88 nm NE of	CA
108380	Golden Gate Bridge, 0.46 nmi E of (depth 200 ft), California Current	NOS	SFB1203_5	37.82007	-122.473	:America/Los_Angeles	USA	knots	235	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.495	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golden Gate Bridge, 0.46 nm E of	CA
108381	Golden Gate Bridge, 0.46 nmi E of (depth 69 ft), California Current	NOS	SFB1203_15	37.82007	-122.473	:America/Los_Angeles	USA	knots	253	71	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.188	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golden Gate Bridge, 0.46 nm E of	CA
108382	Golden Gate Bridge, 0.46 nmi E of (depth 30 ft), California Current	NOS	SFB1203_18	37.82007	-122.473	:America/Los_Angeles	USA	knots	257	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golden Gate Bridge, 0.46 nm E of	CA
108383	Alcatraz Island, southwest of (depth 57 ft), San Francisco Bay, California Current	NOS	SFB1204_1	37.81425	-122.432	:America/Los_Angeles	USA	knots	260	88	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alcatraz Island, southwest of	CA
108384	Alcatraz Island, southwest of (depth 21 ft), San Francisco Bay, California Current	NOS	SFB1204_12	37.81425	-122.432	:America/Los_Angeles	USA	knots	264	89	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alcatraz Island, southwest of	CA
108385	Alcatraz Island, southwest of (depth 2 ft), San Francisco Bay, California Current	NOS	SFB1204_18	37.81425	-122.432	:America/Los_Angeles	USA	knots	271	86	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.171	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alcatraz Island, southwest of	CA
108386	North Point, Pier 35, north of (depth 57 ft), San Francisco Bay, California Current	NOS	SFB1205_1	37.81423	-122.407	:America/Los_Angeles	USA	knots	282	113	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Point, Pier 35, north of	CA
108387	North Point, Pier 35, north of (depth 28 ft), San Francisco Bay, California Current	NOS	SFB1205_10	37.81423	-122.407	:America/Los_Angeles	USA	knots	296	109	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Point, Pier 35, north of	CA
108388	North Point, Pier 35, north of (depth 12 ft), San Francisco Bay, California Current	NOS	SFB1205_15	37.81423	-122.407	:America/Los_Angeles	USA	knots	300	106	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.126	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Point, Pier 35, north of	CA
108389	Pier 23 (depth 37 ft), San Francisco Bay, California Current	NOS	SFB1206_1	37.8053	-122.39728	:America/Los_Angeles	USA	knots	320	146	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pier 23	CA
108392	Bay Bridge, Pier D (depth 65 ft), San Francisco Bay, California Current	NOS	SFB1207_1	37.80093	-122.37387	:America/Los_Angeles	USA	knots	324	124	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Bridge, Pier D	CA
108393	Bay Bridge, Pier D (depth 35 ft), San Francisco Bay, California Current	NOS	SFB1207_10	37.80093	-122.37387	:America/Los_Angeles	USA	knots	317	132	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Bridge, Pier D	CA
108394	Bay Bridge, Pier D (depth 9 ft), San Francisco Bay, California Current	NOS	SFB1207_18	37.80093	-122.37387	:America/Los_Angeles	USA	knots	305	144	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.159	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Bridge, Pier D	CA
108395	Bay Bridge, Span B-C (depth 87 ft), San Francisco Bay, California Current	NOS	SFB1208_1	37.79748	-122.37387	:America/Los_Angeles	USA	knots	355	148	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.226	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Bridge, Span B-C	CA
108396	Bay Bridge, Span B-C (depth 38 ft), San Francisco Bay, California Current	NOS	SFB1208_16	37.79748	-122.37387	:America/Los_Angeles	USA	knots	338	147	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.105	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Bridge, Span B-C	CA
108397	Bay Bridge, Span B-C (depth 11 ft), San Francisco Bay, California Current	NOS	SFB1208_24	37.79748	-122.37387	:America/Los_Angeles	USA	knots	320	158	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Bridge, Span B-C	CA
108398	Yerba Buena Island, west of (midchannel) (depth 84 ft), California Current	NOS	SFB1209_1	37.81003	-122.38307	:America/Los_Angeles	USA	knots	320	120	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yerba Buena Island, west of (midchannel)	CA
108399	Yerba Buena Island, west of (midchannel) (depth 39 ft), California Current	NOS	SFB1209_15	37.81003	-122.38307	:America/Los_Angeles	USA	knots	329	136	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yerba Buena Island, west of (midchannel)	CA
108400	Yerba Buena Island, west of (midchannel) (depth 12 ft), California Current	NOS	SFB1209_23	37.81003	-122.38307	:America/Los_Angeles	USA	knots	331	143	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.215	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yerba Buena Island, west of (midchannel)	CA
108401	Treasure Island, 0.78 nmi NW of (depth 22 ft), San Francisco Bay, California Current	NOS	SFB1210_1	37.83733	-122.38717	:America/Los_Angeles	USA	knots	288	121	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Treasure Island, 0.78 NM NW of	CA
108402	Treasure Island, 0.78 nmi NW of (depth 14 ft), San Francisco Bay, California Current	NOS	SFB1210_6	37.83733	-122.38717	:America/Los_Angeles	USA	knots	294	122	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Treasure Island, 0.78 NM NW of	CA
108403	Treasure Island, 0.78 nmi NW of (depth 3 ft), San Francisco Bay, California Current	NOS	SFB1210_13	37.83733	-122.38717	:America/Los_Angeles	USA	knots	302	126	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Treasure Island, 0.78 NM NW of	CA
108404	Alcatraz Island, 0.5 mi north of (depth 74 ft), San Francisco Bay, California Current	NOS	SFB1211_1	37.83513	-122.42013	:America/Los_Angeles	USA	knots	237	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alcatraz Island, 0.5 mile north of	CA
108405	Alcatraz Island, 0.5 mi north of (depth 29 ft), San Francisco Bay, California Current	NOS	SFB1211_15	37.83513	-122.42013	:America/Los_Angeles	USA	knots	271	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alcatraz Island, 0.5 mile north of	CA
108406	Alcatraz Island, 0.5 mi north of (depth 6 ft), San Francisco Bay, California Current	NOS	SFB1211_22	37.83513	-122.42013	:America/Los_Angeles	USA	knots	293	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alcatraz Island, 0.5 mile north of	CA
108407	Raccoon Strait (depth 71 ft), San Francisco Bay, California Current	NOS	SFB1212_1	37.87192	-122.44197	:America/Los_Angeles	USA	knots	\N	62.2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raccoon Strait	CA
108408	Raccoon Strait (depth 38 ft), San Francisco Bay, California Current	NOS	SFB1212_6	37.87192	-122.44197	:America/Los_Angeles	USA	knots	\N	58.7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raccoon Strait	CA
108409	Raccoon Strait (depth 19 ft), San Francisco Bay, California Current	NOS	SFB1212_9	37.87192	-122.44197	:America/Los_Angeles	USA	knots	\N	56.6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raccoon Strait	CA
108410	Oakland Inner Harbor Channel (depth 40 ft), San Francisco Bay, California Current	NOS	SFB1213_1	37.795	-122.3183	:America/Los_Angeles	USA	knots	287	105	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor Channel	CA
108411	Oakland Inner Harbor Channel (depth 17 ft), San Francisco Bay, California Current	NOS	SFB1213_8	37.795	-122.3183	:America/Los_Angeles	USA	knots	285	103	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor Channel	CA
108412	Oakland Inner Harbor Channel (depth 4 ft), San Francisco Bay, California Current	NOS	SFB1213_12	37.795	-122.3183	:America/Los_Angeles	USA	knots	286	108	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor Channel	CA
108413	Oakland Inner Harbor Reach (depth 45 ft), San Francisco Bay, California Current	NOS	SFB1214_1	37.7929	-122.28552	:America/Los_Angeles	USA	knots	\N	98.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor Reach	CA
108414	Oakland Inner Harbor Reach (depth 20 ft), San Francisco Bay, California Current	NOS	SFB1214_16	37.7929	-122.28552	:America/Los_Angeles	USA	knots	279	102	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor Reach	CA
108415	Oakland Inner Harbor Reach (depth 4 ft), San Francisco Bay, California Current	NOS	SFB1214_26	37.7929	-122.28552	:America/Los_Angeles	USA	knots	284	100	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor Reach	CA
108416	Brooklyn Basin (depth 28 ft), San Francisco Bay, California Current	NOS	SFB1215_1	37.78523	-122.26055	:America/Los_Angeles	USA	knots	293	111	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Basin	CA
108417	Brooklyn Basin (depth 15 ft), San Francisco Bay, California Current	NOS	SFB1215_5	37.78523	-122.26055	:America/Los_Angeles	USA	knots	289	113	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Basin	CA
108418	Brooklyn Basin (depth 5 ft), San Francisco Bay, California Current	NOS	SFB1215_8	37.78523	-122.26055	:America/Los_Angeles	USA	knots	290	114	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Basin	CA
108419	Alameda Estuary, southeast end (depth 15 ft), San Francisco Bay, California Current	NOS	SFB1216_1	37.76146	-122.22391	:America/Los_Angeles	USA	knots	358	181	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alameda Estuary, southeast end	CA
108420	Alameda Estuary, southeast end (depth 2 ft), San Francisco Bay, California Current	NOS	SFB1216_9	37.76146	-122.22391	:America/Los_Angeles	USA	knots	1	178	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alameda Estuary, southeast end	CA
108421	Rincon Point (depth 58 ft), San Francisco Bay, California Current	NOS	SFB1217_1	37.79027	-122.3734	:America/Los_Angeles	USA	knots	321	143	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rincon Point	CA
108422	Rincon Point (depth 22 ft), San Francisco Bay, California Current	NOS	SFB1217_12	37.79027	-122.3734	:America/Los_Angeles	USA	knots	330	148	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rincon Point	CA
108423	Rincon Point (depth 9 ft), San Francisco Bay, California Current	NOS	SFB1217_16	37.79027	-122.3734	:America/Los_Angeles	USA	knots	333	149	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rincon Point	CA
108424	Emeryville Marina (depth 5 ft), San Francisco Bay, California Current	NOS	SFB1218_1	37.84332	-122.32537	:America/Los_Angeles	USA	knots	\N	157	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Emeryville Marina	CA
108425	Point Bonita, 0.95 nmi SSE of (depth 96 ft), California Current	NOS	SFB1220_1	37.8011	-122.5184	:America/Los_Angeles	USA	knots	234	71	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.258	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Bonita, 0.95 nm SSE of	CA
108426	Point Bonita, 0.95 nmi SSE of (depth 44 ft), California Current	NOS	SFB1220_9	37.8011	-122.5184	:America/Los_Angeles	USA	knots	236	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Bonita, 0.95 nm SSE of	CA
108427	Point Bonita, 0.95 nmi SSE of (depth 17 ft), California Current	NOS	SFB1220_13	37.8011	-122.5184	:America/Los_Angeles	USA	knots	238	70	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Bonita, 0.95 nm SSE of	CA
108428	San Francisco Bar, north of ship channel (depth 25 ft), California Current	NOS	SFB1221_1	37.78529	-122.614	:America/Los_Angeles	USA	knots	260	84	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco Bar, north of ship channel	CA
108429	San Francisco Bar, north of ship channel (depth 15 ft), California Current	NOS	SFB1221_4	37.78529	-122.614	:America/Los_Angeles	USA	knots	260	75	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.172	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco Bar, north of ship channel	CA
108430	San Francisco Bar, north of ship channel (depth 5 ft), California Current	NOS	SFB1221_7	37.78529	-122.614	:America/Los_Angeles	USA	knots	260	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco Bar, north of ship channel	CA
108431	San Francisco traffic separation zone buoy (depth 84 ft), California Current	NOS	SFB1222_1	37.7505	-122.6996	:America/Los_Angeles	USA	knots	261	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco traffic separation zone buoy	CA
108432	San Francisco traffic separation zone buoy (depth 45 ft), California Current	NOS	SFB1222_7	37.7505	-122.6996	:America/Los_Angeles	USA	knots	258	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco traffic separation zone buoy	CA
108433	San Francisco traffic separation zone buoy (depth 12 ft), California Current	NOS	SFB1222_12	37.7505	-122.6996	:America/Los_Angeles	USA	knots	233	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco traffic separation zone buoy	CA
108434	San Francisco southern traffic lane, N end (depth 105 ft), California Current	NOS	SFB1223_1	37.64458	-122.6954	:America/Los_Angeles	USA	knots	\N	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco southern traffic lane, N end	CA
108435	San Francisco southern traffic lane, N end (depth 53 ft), California Current	NOS	SFB1223_9	37.64458	-122.6954	:America/Los_Angeles	USA	knots	\N	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco southern traffic lane, N end	CA
108436	San Francisco southern traffic lane, N end (depth 13 ft), California Current	NOS	SFB1223_15	37.64458	-122.6954	:America/Los_Angeles	USA	knots	192	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco southern traffic lane, N end	CA
108437	Dumbarton Highway Bridge (depth 40 ft), San Francisco Bay, California Current	NOS	SFB1301_1	37.50175	-122.11598	:America/Los_Angeles	USA	knots	318	138	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dumbarton Highway Bridge	CA
108438	Dumbarton Highway Bridge (depth 17 ft), San Francisco Bay, California Current	NOS	SFB1301_8	37.50175	-122.11598	:America/Los_Angeles	USA	knots	319	140	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dumbarton Highway Bridge	CA
108439	Dumbarton Highway Bridge (depth 4 ft), San Francisco Bay, California Current	NOS	SFB1301_12	37.50175	-122.11598	:America/Los_Angeles	USA	knots	320	139	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dumbarton Highway Bridge	CA
108440	Redwood Point, 1.7 nmi east of (depth 30 ft), San Francisco Bay, California Current	NOS	SFB1302_1	37.53062	-122.1601	:America/Los_Angeles	USA	knots	305	121	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redwood Point, 1.7nm East of	CA
108441	Redwood Point, 1.7 nmi east of (depth 20 ft), San Francisco Bay, California Current	NOS	SFB1302_4	37.53062	-122.1601	:America/Los_Angeles	USA	knots	305	125	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redwood Point, 1.7nm East of	CA
108442	Redwood Point, 1.7 nmi east of (depth 7 ft), San Francisco Bay, California Current	NOS	SFB1302_8	37.53062	-122.1601	:America/Los_Angeles	USA	knots	305	127	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redwood Point, 1.7nm East of	CA
108443	Redwood Creek (depth 20 ft), San Francisco Bay, California Current	NOS	SFB1304_1	37.52575	-122.1991	:America/Los_Angeles	USA	knots	49	233	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redwood Creek	CA
108444	Redwood Creek (depth 4 ft), San Francisco Bay, California Current	NOS	SFB1304_6	37.52575	-122.1991	:America/Los_Angeles	USA	knots	51	234	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redwood Creek	CA
108445	San Mateo Bridge (depth 30 ft), San Francisco Bay, California Current	NOS	SFB1305_1	37.58778	-122.25018	:America/Los_Angeles	USA	knots	300	135	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Mateo Bridge	CA
108446	San Mateo Bridge (depth 21 ft), San Francisco Bay, California Current	NOS	SFB1305_4	37.58778	-122.25018	:America/Los_Angeles	USA	knots	299	136	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Mateo Bridge	CA
108447	San Mateo Bridge (depth 11 ft), San Francisco Bay, California Current	NOS	SFB1305_7	37.58778	-122.25018	:America/Los_Angeles	USA	knots	298	136	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Mateo Bridge	CA
108448	Coyote Point, 2.3 nmi NNE of (depth 22 ft), San Francisco Bay, California Current	NOS	SFB1306_1	37.62555	-122.29607	:America/Los_Angeles	USA	knots	322	144	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coyote Point, 2.3 nmi. NNE of	CA
108449	Coyote Point, 2.3 nmi NNE of (depth 12 ft), San Francisco Bay, California Current	NOS	SFB1306_4	37.62555	-122.29607	:America/Los_Angeles	USA	knots	324	144	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coyote Point, 2.3 nmi. NNE of	CA
108450	Coyote Point, 2.3 nmi NNE of (depth 3 ft), San Francisco Bay, California Current	NOS	SFB1306_7	37.62555	-122.29607	:America/Los_Angeles	USA	knots	325	144	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coyote Point, 2.3 nmi. NNE of	CA
108451	Mulford Gardens Channel approach (depth 4 ft), San Francisco Bay, California Current	NOS	SFB1307_4	37.65008	-122.26282	:America/Los_Angeles	USA	knots	321	138	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mulford Gardens Channel Approach	CA
108452	Hunters Point, 1.6 nmi SE of (depth 24 ft), San Francisco Bay, California Current	NOS	SFB1308_1	37.69603	-122.33815	:America/Los_Angeles	USA	knots	22	201	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hunters Point, 1.6nm SE of	CA
108453	Hunters Point, 1.6 nmi SE of (depth 5 ft), San Francisco Bay, California Current	NOS	SFB1308_7	37.69603	-122.33815	:America/Los_Angeles	USA	knots	23	202	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hunters Point, 1.6nm SE of	CA
108454	Point Chauncey, 1.3 mi east of (depth 40 ft), San Francisco Bay, California Current	NOS	SFB1309_1	37.89082	-122.41878	:America/Los_Angeles	USA	knots	168	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Chauncey, 1.3 miles east of	CA
108455	Point Chauncey, 1.3 mi east of (depth 24 ft), San Francisco Bay, California Current	NOS	SFB1309_6	37.89082	-122.41878	:America/Los_Angeles	USA	knots	170	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Chauncey, 1.3 miles east of	CA
108456	Point Chauncey, 1.3 mi east of (depth 7 ft), San Francisco Bay, California Current	NOS	SFB1309_11	37.89082	-122.41878	:America/Los_Angeles	USA	knots	173	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Chauncey, 1.3 miles east of	CA
108457	Point Chauncey, 1.25 nmi north of (depth 31 ft), San Francisco Bay, California Current	NOS	SFB1310_1	37.9153	-122.44607	:America/Los_Angeles	USA	knots	168	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Chauncey, 1.25 nm north of	CA
108458	Point Chauncey, 1.25 nmi north of (depth 18 ft), San Francisco Bay, California Current	NOS	SFB1310_5	37.9153	-122.44607	:America/Los_Angeles	USA	knots	173	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Chauncey, 1.25 nm north of	CA
108459	Point Chauncey, 1.25 nmi north of (depth 5 ft), San Francisco Bay, California Current	NOS	SFB1310_9	37.9153	-122.44607	:America/Los_Angeles	USA	knots	177	351	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.315	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Chauncey, 1.25 nm north of	CA
108460	Point San Pablo, midchannel (depth 60 ft), San Pablo Bay, California Current	NOS	SFB1312_1	37.96888	-122.43913	:America/Los_Angeles	USA	knots	199	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point San Pablo, midchannel	CA
108461	Point San Pablo, midchannel (depth 30 ft), San Pablo Bay, California Current	NOS	SFB1312_10	37.96888	-122.43913	:America/Los_Angeles	USA	knots	203	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point San Pablo, midchannel	CA
108462	Point San Pablo, midchannel (depth 11 ft), San Pablo Bay, California Current	NOS	SFB1312_16	37.96888	-122.43913	:America/Los_Angeles	USA	knots	199	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point San Pablo, midchannel	CA
108463	Petaluma River approach (Buoys 3 and 4) (depth 2 ft), San Pablo Bay, California Current	NOS	SFB1313_4	38.04349899291992	-122.42633056640625	:America/Los_Angeles	USA	knots	179	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Petaluma River approach (Buoys 3 and 4)	CA
108464	Pinole Point, 1.27 nmi NNW of (depth 32 ft), San Pablo Bay, California Current	NOS	SFB1314_1	38.03083	-122.37715	:America/Los_Angeles	USA	knots	223	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Point, 1.27 nmi. NNW of	CA
108465	Pinole Point, 1.27 nmi NNW of (depth 19 ft), San Pablo Bay, California Current	NOS	SFB1314_5	38.03083	-122.37715	:America/Los_Angeles	USA	knots	228	47	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Point, 1.27 nmi. NNW of	CA
108466	Pinole Point, 1.27 nmi NNW of (depth 5 ft), San Pablo Bay, California Current	NOS	SFB1314_9	38.03083	-122.37715	:America/Los_Angeles	USA	knots	232	50	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Point, 1.27 nmi. NNW of	CA
108467	Pinole Shoal (depth 23 ft), San Pablo Bay, California Current	NOS	SFB1315_1	38.04757	-122.33413	:America/Los_Angeles	USA	knots	250	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Shoal	CA
108468	Pinole Shoal (depth 19 ft), San Pablo Bay, California Current	NOS	SFB1315_2	38.04757	-122.33413	:America/Los_Angeles	USA	knots	\N	71.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Shoal	CA
108469	Pinole Shoal (depth 16 ft), San Pablo Bay, California Current	NOS	SFB1315_3	38.04757	-122.33413	:America/Los_Angeles	USA	knots	\N	72.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Shoal	CA
108470	Pinole Shoal (depth 13 ft), San Pablo Bay, California Current	NOS	SFB1315_4	38.04757	-122.33413	:America/Los_Angeles	USA	knots	\N	73.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Shoal	CA
108471	Pinole Shoal (depth 10 ft), San Pablo Bay, California Current	NOS	SFB1315_5	38.04757	-122.33413	:America/Los_Angeles	USA	knots	\N	73.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Shoal	CA
108472	Pinole Shoal (depth 6 ft), San Pablo Bay, California Current	NOS	SFB1315_6	38.04757	-122.33413	:America/Los_Angeles	USA	knots	255	75	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Shoal	CA
108473	Pinole Shoal (depth 3 ft), San Pablo Bay, California Current	NOS	SFB1315_7	38.04757	-122.33413	:America/Los_Angeles	USA	knots	\N	76	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.256	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Shoal	CA
108474	Davis Point, 1.0 nmi NW of (depth 33 ft), San Pablo Bay, California Current	NOS	SFB1316_1	38.0619	-122.27668	:America/Los_Angeles	USA	knots	267	78	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Davis Point, 1.0 nmi. NW of	CA
108475	Davis Point, 1.0 nmi NW of (depth 17 ft), San Pablo Bay, California Current	NOS	SFB1316_6	38.0619	-122.27668	:America/Los_Angeles	USA	knots	266	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.188	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Davis Point, 1.0 nmi. NW of	CA
108584	Akutan Pass (depth 30 ft), Aleutian Islands, Alaska Current	NOS	UNI1010_28	54.02455	-166.09753	:America/Nome	USA	knots	103	301	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan Pass	AK
108476	Davis Point, 1.0 nmi NW of (depth 7 ft), San Pablo Bay, California Current	NOS	SFB1316_9	38.0619	-122.27668	:America/Los_Angeles	USA	knots	266	87	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Davis Point, 1.0 nmi. NW of	CA
108477	Mare Island Strait, NE of Pier 34 (depth 29 ft), Carquinez Strait, California Current	NOS	SFB1317_1	38.07725	-122.24565	:America/Los_Angeles	USA	knots	175	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mare Island Strait, NE of Pier 34	CA
108478	Mare Island Strait, NE of Pier 34 (depth 15 ft), Carquinez Strait, California Current	NOS	SFB1317_5	38.07725	-122.24565	:America/Los_Angeles	USA	knots	169	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mare Island Strait, NE of Pier 34	CA
108479	Mare Island Strait, NE of Pier 34 (depth 6 ft), Carquinez Strait, California Current	NOS	SFB1317_8	38.07725	-122.24565	:America/Los_Angeles	USA	knots	167	351	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mare Island Strait, NE of Pier 34	CA
108480	Carquinez Bridge, I-80 (depth 72 ft), Carquinez Strait, California Current	NOS	SFB1318_1	38.06237	-122.22753	:America/Los_Angeles	USA	knots	280	94	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.234	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carquinez Bridge, I-80	CA
108481	Carquinez Bridge, I-80 (depth 39 ft), Carquinez Strait, California Current	NOS	SFB1318_6	38.06237	-122.22753	:America/Los_Angeles	USA	knots	270	93	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carquinez Bridge, I-80	CA
108482	Carquinez Bridge, I-80 (depth 20 ft), Carquinez Strait, California Current	NOS	SFB1318_9	38.06237	-122.22753	:America/Los_Angeles	USA	knots	269	92	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.282	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carquinez Bridge, I-80	CA
108483	Carquinez Strait (depth 42 ft), California Current	NOS	SFB1319_1	38.06138	-122.21823	:America/Los_Angeles	USA	knots	282	94	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.164	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carquinez Strait	CA
108484	Carquinez Strait (depth 25 ft), California Current	NOS	SFB1319_6	38.06138	-122.21823	:America/Los_Angeles	USA	knots	290	95	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carquinez Strait	CA
108485	Carquinez Strait (depth 12 ft), California Current	NOS	SFB1319_10	38.06138	-122.21823	:America/Los_Angeles	USA	knots	289	98	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carquinez Strait	CA
108486	Dillon Point (depth 97 ft), Carquinez Strait, California Current	NOS	SFB1320_1	38.0589	-122.19305	:America/Los_Angeles	USA	knots	258	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dillon Point	CA
108487	Dillon Point (depth 45 ft), Carquinez Strait, California Current	NOS	SFB1320_9	38.0589	-122.19305	:America/Los_Angeles	USA	knots	264	98	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.317	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dillon Point	CA
108488	Dillon Point (depth 19 ft), Carquinez Strait, California Current	NOS	SFB1320_13	38.0589	-122.19305	:America/Los_Angeles	USA	knots	275	92	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.319	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dillon Point	CA
108489	Grizzly Bay entrance (depth 2 ft), Suisun Bay, California Current	NOS	SFB1322_4	38.10318	-122.05248	:America/Los_Angeles	USA	knots	228	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grizzly Bay entrance	CA
108490	Roe Island Channel (depth 29 ft), Suisun Bay, California Current	NOS	SFB1323_1	38.06507	-122.03445	:America/Los_Angeles	USA	knots	269	96	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roe Island Channel	CA
108491	Roe Island Channel (depth 16 ft), Suisun Bay, California Current	NOS	SFB1323_5	38.06507	-122.03445	:America/Los_Angeles	USA	knots	272	99	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roe Island Channel	CA
108492	Roe Island Channel (depth 6 ft), Suisun Bay, California Current	NOS	SFB1323_8	38.06507	-122.03445	:America/Los_Angeles	USA	knots	276	93	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.248	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roe Island Channel	CA
108493	Middle Point Lt., 0.18 nmi NNW of (depth 30 ft), Suisun Bay, California Current	NOS	SFB1324_1	38.05752	-121.99303	:America/Los_Angeles	USA	knots	274	103	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Point Lt., 0.18 nmi. NNW of	CA
108494	Middle Point Lt., 0.18 nmi NNW of (depth 17 ft), Suisun Bay, California Current	NOS	SFB1324_5	38.05752	-121.99303	:America/Los_Angeles	USA	knots	277	103	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Point Lt., 0.18 nmi. NNW of	CA
108495	Middle Point Lt., 0.18 nmi NNW of (depth 7 ft), Suisun Bay, California Current	NOS	SFB1324_8	38.05752	-121.99303	:America/Los_Angeles	USA	knots	279	101	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Point Lt., 0.18 nmi. NNW of	CA
108496	Simmons Point, 0.6 nmi ESE of (depth 32 ft), Suisun Bay, California Current	NOS	SFB1325_1	38.04812	-121.9225	:America/Los_Angeles	USA	knots	281	98	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Simmons Point, 0.6nm ESE of	CA
108497	Simmons Point, 0.6 nmi ESE of (depth 19 ft), Suisun Bay, California Current	NOS	SFB1325_5	38.04812	-121.9225	:America/Los_Angeles	USA	knots	280	98	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Simmons Point, 0.6nm ESE of	CA
108498	Simmons Point, 0.6 nmi ESE of (depth 6 ft), Suisun Bay, California Current	NOS	SFB1325_9	38.04812	-121.9225	:America/Los_Angeles	USA	knots	281	102	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.175	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Simmons Point, 0.6nm ESE of	CA
108499	New York Slough, 0.6 mi E of Pt. Emmet (depth 32 ft), Suisun Bay, California Current	NOS	SFB1326_1	38.0325	-121.86908	:America/Los_Angeles	USA	knots	291	109	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New York Slough, 0.6miles E of Pt. Emmet	CA
108500	New York Slough, 0.6 mi E of Pt. Emmet (depth 19 ft), Suisun Bay, California Current	NOS	SFB1326_5	38.0325	-121.86908	:America/Los_Angeles	USA	knots	286	109	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New York Slough, 0.6miles E of Pt. Emmet	CA
108501	New York Slough, 0.6 mi E of Pt. Emmet (depth 5 ft), Suisun Bay, California Current	NOS	SFB1326_9	38.0325	-121.86908	:America/Los_Angeles	USA	knots	283	109	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New York Slough, 0.6miles E of Pt. Emmet	CA
108502	Antioch Point (depth 48 ft), San Joaquin River, California Current	NOS	SFB1327_1	38.02395	-121.82258	:America/Los_Angeles	USA	knots	329	142	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Antioch Point	CA
108503	Antioch Point (depth 22 ft), San Joaquin River, California Current	NOS	SFB1327_9	38.02395	-121.82258	:America/Los_Angeles	USA	knots	321	138	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Antioch Point	CA
108504	Antioch Point (depth 9 ft), San Joaquin River, California Current	NOS	SFB1327_13	38.02395	-121.82258	:America/Los_Angeles	USA	knots	314	141	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Antioch Point	CA
108505	West Island, north of (depth 26 ft), San Joaquin River, California Current	NOS	SFB1328_1	38.02485	-121.79005	:America/Los_Angeles	USA	knots	256	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Island, north of	CA
108506	West Island, north of (depth 13 ft), San Joaquin River, California Current	NOS	SFB1328_5	38.02485	-121.79005	:America/Los_Angeles	USA	knots	255	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Island, north of	CA
108507	West Island, north of (depth 3 ft), San Joaquin River, California Current	NOS	SFB1328_8	38.02485	-121.79005	:America/Los_Angeles	USA	knots	255	76	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.232	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Island, north of	CA
108508	Antioch, Route 160 bridge (depth 30 ft), San Joaquin River, California Current	NOS	SFB1329_1	38.02697	-121.75307	:America/Los_Angeles	USA	knots	276	93	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Antioch, Route 160 bridge	CA
108509	Antioch, Route 160 bridge (depth 17 ft), San Joaquin River, California Current	NOS	SFB1329_5	38.02697	-121.75307	:America/Los_Angeles	USA	knots	277	95	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Antioch, Route 160 bridge	CA
108510	Antioch, Route 160 bridge (depth 7 ft), San Joaquin River, California Current	NOS	SFB1329_8	38.02697	-121.75307	:America/Los_Angeles	USA	knots	277	96	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Antioch, Route 160 bridge	CA
108511	Entrance, 0.7 nmi SW of Chain Island (depth 48 ft), Sacramento River, California Current	NOS	SFB1330_1	38.05847	-121.8712	:America/Los_Angeles	USA	knots	226	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance, 0.7nm SW of Chain Island	CA
108512	Entrance, 0.7 nmi SW of Chain Island (depth 22 ft), Sacramento River, California Current	NOS	SFB1330_9	38.05847	-121.8712	:America/Los_Angeles	USA	knots	225	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance, 0.7nm SW of Chain Island	CA
108513	Entrance, 0.7 nmi SW of Chain Island (depth 9 ft), Sacramento River, California Current	NOS	SFB1330_13	38.05847	-121.8712	:America/Los_Angeles	USA	knots	226	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance, 0.7nm SW of Chain Island	CA
108514	Point Sacramento, 0.2 nmi NE of (depth 32 ft), Sacramento River, California Current	NOS	SFB1331_1	38.0643	-121.83372	:America/Los_Angeles	USA	knots	275	101	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Sacramento, 0.2nm NE of	CA
108515	Point Sacramento, 0.2 nmi NE of (depth 15 ft), Sacramento River, California Current	NOS	SFB1331_11	38.0643	-121.83372	:America/Los_Angeles	USA	knots	281	98	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Sacramento, 0.2nm NE of	CA
108516	Point Sacramento, 0.2 nmi NE of (depth 4 ft), Sacramento River, California Current	NOS	SFB1331_18	38.0643	-121.83372	:America/Los_Angeles	USA	knots	283	98	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Sacramento, 0.2nm NE of	CA
108517	Sacramento River Light 14 (depth 26 ft), California Current	NOS	SFB1332_1	38.07715	-121.76393	:America/Los_Angeles	USA	knots	234	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sacramento River Light 14	CA
108518	Sacramento River Light 14 (depth 14 ft), California Current	NOS	SFB1332_8	38.07715	-121.76393	:America/Los_Angeles	USA	knots	236	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sacramento River Light 14	CA
108519	Sacramento River Light 14 (depth 3 ft), California Current	NOS	SFB1332_15	38.07715	-121.76393	:America/Los_Angeles	USA	knots	235	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sacramento River Light 14	CA
108520	Shark River entrance (depth 15 ft), New Jersey Current	NOS	SHR9901_2	40.1873	-74.0126	:America/New_York	USA	knots	97	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shark River Entrance	NJ
108521	Shark River entrance (depth 5 ft), New Jersey Current	NOS	SHR9901_14	40.1873	-74.0126	:America/New_York	USA	knots	98	273	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shark River Entrance	NJ
108522	Dames Point, 0.23 nmi ESE of (depth 31 ft), St. Johns River, Florida Current	NOS	SJR0301_2	30.3865	-81.55383	:America/New_York	USA	knots	69	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point, 0.23 n.mi. ESE of	FL
108523	Dames Point, 0.23 nmi ESE of (depth 14 ft), St. Johns River, Florida Current	NOS	SJR0301_7	30.3865	-81.55383	:America/New_York	USA	knots	68	256	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.308	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point, 0.23 n.mi. ESE of	FL
108524	Dames Point, 0.23 nmi ESE of (depth 5 ft), St. Johns River, Florida Current	NOS	SJR0301_10	30.3865	-81.55383	:America/New_York	USA	knots	66	244	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.368	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point, 0.23 n.mi. ESE of	FL
108525	Chaseville Turn (depth 30 ft), St. Johns River, Florida Current	NOS	SJR0302_2	30.37833	-81.62833	:America/New_York	USA	knots	17	186	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chaseville Turn	FL
108526	Chaseville Turn (depth 14 ft), St. Johns River, Florida Current	NOS	SJR0302_7	30.37833	-81.62833	:America/New_York	USA	knots	3	166	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chaseville Turn	FL
108527	Chaseville Turn (depth 4 ft), St. Johns River, Florida Current	NOS	SJR0302_10	30.37833	-81.62833	:America/New_York	USA	knots	339	165	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chaseville Turn	FL
108528	St. Johns Bar Cut, 0.7 nmi east of jetties (depth 31 ft), Florida Current	NOS	SJR0304_2	30.398	-81.39717	:America/New_York	USA	knots	122	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns Bar Cut, 0.7 n.mi. east of jetties	FL
108529	St. Johns Bar Cut, 0.7 nmi east of jetties (depth 14 ft), Florida Current	NOS	SJR0304_7	30.398	-81.39717	:America/New_York	USA	knots	95	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns Bar Cut, 0.7 n.mi. east of jetties	FL
108530	St. Johns Bar Cut, 0.7 nmi east of jetties (depth 5 ft), Florida Current	NOS	SJR0304_10	30.398	-81.39717	:America/New_York	USA	knots	91	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.613	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns Bar Cut, 0.7 n.mi. east of jetties	FL
108531	St. Johns River ent. (between jetties) (depth 30 ft), Florida Current	NOS	SJR9801_4	30.40067	-81.386	:America/New_York	USA	knots	80	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns River Ent. (between jetties)	FL
108532	St. Johns River ent. (between jetties) (depth 16 ft), Florida Current	NOS	SJR9801_8	30.40067	-81.386	:America/New_York	USA	knots	81	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns River Ent. (between jetties)	FL
108533	St. Johns River ent. (between jetties) (depth 10 ft), Florida Current	NOS	SJR9801_10	30.40067	-81.386	:America/New_York	USA	knots	81	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.178	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns River Ent. (between jetties)	FL
108534	Trout River Cut (depth 32 ft), St. Johns River, Florida Current	NOS	SJR9806_1	30.38358	-81.62785	:America/New_York	USA	knots	23	205	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trout River Cut	FL
108535	Trout River Cut (depth 15 ft), St. Johns River, Florida Current	NOS	SJR9806_6	30.38358	-81.62785	:America/New_York	USA	knots	25	191	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 16.4 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trout River Cut	FL
108536	Trout River Cut (depth 6 ft), St. Johns River, Florida Current	NOS	SJR9806_9	30.38358	-81.62785	:America/New_York	USA	knots	5	193	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trout River Cut	FL
108537	Blount Island, east of (depth 30 ft), St. Johns River, Florida Current	NOS	SJR9807_2	30.39228	-81.50872	:America/New_York	USA	knots	99	264	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 39.4 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blount Island, East of	FL
108538	Blount Island, east of (depth 16 ft), St. Johns River, Florida Current	NOS	SJR9807_6	30.39228	-81.50872	:America/New_York	USA	knots	90	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 26.2 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.109	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blount Island, East of	FL
108539	Blount Island, east of (depth 7 ft), St. Johns River, Florida Current	NOS	SJR9807_9	30.39228	-81.50872	:America/New_York	USA	knots	79	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 16.4 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.399	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blount Island, East of	FL
108540	Lydia Ann Channel, S end (depth 3 ft), Texas Current	NOS	STX1801_5	27.85260009765625	-97.05480194091797	:America/Chicago	USA	knots	201	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.416	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lydia Ann Channel, S end	TX
108541	Murray Shoal (depth 4 ft), Texas Current	NOS	STX1802_5	27.89929962158203	-97.05139923095703	:America/Chicago	USA	knots	175	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Murray Shoal	TX
108542	ICW Laguna Madre, 2.25 nmi S of Arroyo Colorado Cut (depth 3 ft), Texas Current	NOS	STX1812_2	26.327899932861328	-97.30970001220703	:America/Chicago	USA	knots	164	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICW Laguna Madre, 2.25 nm S of Arroyo Colorado Cut	TX
108543	ICW Laguna Madre, Light 69 (depth 4 ft), Texas Current	NOS	STX1813_3	26.107500076293945	-97.21160125732422	:America/Chicago	USA	knots	147	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICW Laguna Madre, Light 69	TX
108544	Queen Isabella Causeway Bridge (depth 17 ft), Laguna Madre, Texas Current	NOS	STX1814_14	26.082399368286133	-97.19779968261719	:America/Chicago	USA	knots	136	312	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 93.5 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Queen Isabella Causeway Bridge	TX
108545	Port Isabel, Pontoon Swing Bridge (depth 8 ft), Texas Current	NOS	STX1815_4	26.071800231933594	-97.19950103759766	:America/Chicago	USA	knots	219	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Isabel, Pontoon Swing Bridge	TX
108546	Brownsville Ship Channel, east end (depth 18 ft), Texas Current	NOS	STX1817_2	26.03499984741211	-97.2197036743164	:America/Chicago	USA	knots	62	241	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brownsville Ship Channel, east end	TX
108547	Laguna Madre Channel, SW end (depth 3 ft), Texas Current	NOS	STX1818_4	26.046600341796875	-97.1980972290039	:America/Chicago	USA	knots	86	266	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Laguna Madre Channel, SW end	TX
108548	Laguna Madre Channel, NE end (depth 8 ft), Texas Current	NOS	STX1819_2	26.066499710083008	-97.1675033569336	:America/Chicago	USA	knots	99	277	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.191	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Laguna Madre Channel, NE end	TX
108549	Laguna Madre Channel, NE end (depth 15 ft), Texas Current	NOS	STX1819_6	26.066499710083008	-97.1675033569336	:America/Chicago	USA	knots	97	277	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Laguna Madre Channel, NE end	TX
108550	Brazos Santiago Pass entrance (depth 32 ft), Texas Current	NOS	STX1820_1	26.065200805664062	-97.14939880371094	:America/Chicago	USA	knots	95	282	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brazos Santiago Pass Entrance	TX
108551	Brazos Santiago Pass entrance (depth 16 ft), Texas Current	NOS	STX1820_6	26.065200805664062	-97.14939880371094	:America/Chicago	USA	knots	92	278	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brazos Santiago Pass Entrance	TX
108552	Brazos Santiago Pass entrance (depth 6 ft), Texas Current	NOS	STX1820_9	26.065200805664062	-97.14939880371094	:America/Chicago	USA	knots	94	276	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brazos Santiago Pass Entrance	TX
108553	Brazos Santiago Pass (SPIP) (depth 17 ft), Texas Current	NOS	STX1821_29	26.0674991607666	-97.15480041503906	:America/Chicago	USA	knots	90	276	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 383.9 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brazos Santiago Pass (SPIP)	TX
108554	Port Isabel Channel, north end (depth 28 ft), Texas Current	NOS	STX1822_13	26.05419921875	-97.21150207519531	:America/Chicago	USA	knots	167	358	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 86.9 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Isabel Channel, North End	TX
108555	Unimak Pass, east entrance (depth 236 ft), Aleutian Islands, Alaska Current	NOS	UNI1001_1	54.29981	-164.51693	:America/Nome	USA	knots	98	292	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, East Entrance	AK
108556	Unimak Pass, east entrance (depth 131 ft), Aleutian Islands, Alaska Current	NOS	UNI1001_9	54.29981	-164.51693	:America/Nome	USA	knots	89	280	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, East Entrance	AK
108557	Unimak Pass, east entrance (depth 26 ft), Aleutian Islands, Alaska Current	NOS	UNI1001_17	54.29981	-164.51693	:America/Nome	USA	knots	90	279	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.271	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, East Entrance	AK
108558	Unimak Pass (depth 213 ft), Aleutian Islands, Alaska Current	NOS	UNI1002_1	54.30863	-164.74683	:America/Nome	USA	knots	114	285	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass	AK
108559	Unimak Pass (depth 121 ft), Aleutian Islands, Alaska Current	NOS	UNI1002_15	54.30863	-164.74683	:America/Nome	USA	knots	116	285	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass	AK
108560	Unimak Pass (depth 29 ft), Aleutian Islands, Alaska Current	NOS	UNI1002_29	54.30863	-164.74683	:America/Nome	USA	knots	118	280	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.208	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass	AK
108561	Ugamak Strait, off Kaligagan Island (depth 126 ft), Aleutian Islands, Alaska Current	NOS	UNI1003_1	54.15457	-164.87092	:America/Nome	USA	knots	132	329	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.385	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ugamak Strait, off Kaligagan Island	AK
108562	Ugamak Strait, off Kaligagan Island (depth 60 ft), Aleutian Islands, Alaska Current	NOS	UNI1003_11	54.15457	-164.87092	:America/Nome	USA	knots	131	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.389	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ugamak Strait, off Kaligagan Island	AK
108563	Ugamak Strait, off Kaligagan Island (depth 27 ft), Aleutian Islands, Alaska Current	NOS	UNI1003_16	54.15457	-164.87092	:America/Nome	USA	knots	132	340	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ugamak Strait, off Kaligagan Island	AK
108564	Unimak Pass, north approach (depth 216 ft), Aleutian Islands, Alaska Current	NOS	UNI1004_1	54.44831	-165.09124	:America/Nome	USA	knots	154	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.279	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, North Approach	AK
108565	Unimak Pass, north approach (depth 133 ft), Aleutian Islands, Alaska Current	NOS	UNI1004_6	54.44831	-165.09124	:America/Nome	USA	knots	144	339	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.524	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, North Approach	AK
108566	Unimak Pass, north approach (depth 35 ft), Aleutian Islands, Alaska Current	NOS	UNI1004_12	54.44831	-165.09124	:America/Nome	USA	knots	132	330	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.902	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, North Approach	AK
108567	Unimak Pass, west approach (depth 245 ft), Aleutian Islands, Alaska Current	NOS	UNI1005_1	54.36695	-165.36433	:America/Nome	USA	knots	130	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, West Approach	AK
108568	Unimak Pass, west approach (depth 137 ft), Aleutian Islands, Alaska Current	NOS	UNI1005_12	54.36695	-165.36433	:America/Nome	USA	knots	131	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.191	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, West Approach	AK
108569	Unimak Pass, west approach (depth 28 ft), Aleutian Islands, Alaska Current	NOS	UNI1005_23	54.36695	-165.36433	:America/Nome	USA	knots	130	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, West Approach	AK
108570	Avatanak Strait (depth 247 ft), Aleutian Islands, Alaska Current	NOS	UNI1006_1	54.11279	-165.47573	:America/Nome	USA	knots	229	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Avatanak Strait	AK
108571	Avatanak Strait (depth 159 ft), Aleutian Islands, Alaska Current	NOS	UNI1006_10	54.11279	-165.47573	:America/Nome	USA	knots	233	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.345	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Avatanak Strait	AK
108572	Avatanak Strait (depth 40 ft), Aleutian Islands, Alaska Current	NOS	UNI1006_22	54.11279	-165.47573	:America/Nome	USA	knots	237	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.558	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Avatanak Strait	AK
108573	Akun Strait (depth 76 ft), Aleutian Islands, Alaska Current	NOS	UNI1007_1	54.1337	-165.65111	:America/Nome	USA	knots	159	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akun Strait	AK
108574	Akun Strait (depth 47 ft), Aleutian Islands, Alaska Current	NOS	UNI1007_10	54.1337	-165.65111	:America/Nome	USA	knots	148	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akun Strait	AK
108575	Akun Strait (depth 14 ft), Aleutian Islands, Alaska Current	NOS	UNI1007_20	54.1337	-165.65111	:America/Nome	USA	knots	141	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.222	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akun Strait	AK
108576	Akutan Bay (depth 248 ft), Aleutian Islands, Alaska Current	NOS	UNI1008_1	54.18252	-165.72444	:America/Nome	USA	knots	120	305.1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan Bay	AK
108577	Akutan Bay (depth 140 ft), Aleutian Islands, Alaska Current	NOS	UNI1008_12	54.18252	-165.72444	:America/Nome	USA	knots	117	300.8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.098	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan Bay	AK
108578	Akutan Bay (depth 32 ft), Aleutian Islands, Alaska Current	NOS	UNI1008_23	54.18252	-165.72444	:America/Nome	USA	knots	114	295.5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan Bay	AK
108579	Baby Pass (depth 133 ft), Aleutian Islands, Alaska Current	NOS	UNI1009_1	53.9812	-166.07178	:America/Nome	USA	knots	126	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baby Pass	AK
108580	Baby Pass (depth 87 ft), Aleutian Islands, Alaska Current	NOS	UNI1009_8	53.9812	-166.07178	:America/Nome	USA	knots	128	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.174	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baby Pass	AK
108581	Baby Pass (depth 22 ft), Aleutian Islands, Alaska Current	NOS	UNI1009_18	53.9812	-166.07178	:America/Nome	USA	knots	129	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.386	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baby Pass	AK
108585	Unalga Pass (depth 157 ft), Aleutian Islands, Alaska Current	NOS	UNI1011_1	53.95372	-166.21471	:America/Nome	USA	knots	138	316	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.423	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalga Pass	AK
108586	Unalga Pass (depth 98 ft), Aleutian Islands, Alaska Current	NOS	UNI1011_10	53.95372	-166.21471	:America/Nome	USA	knots	144	314	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.493	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalga Pass	AK
108587	Unalga Pass (depth 26 ft), Aleutian Islands, Alaska Current	NOS	UNI1011_21	53.95372	-166.21471	:America/Nome	USA	knots	147	315	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.642	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalga Pass	AK
108588	Udagak Strait (narrows) (depth 108 ft), Aleutian Islands, Alaska Current	NOS	UNI1012_2	53.73414	-166.28904	:America/Nome	USA	knots	88	268	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Udagak Strait (narrows)	AK
108589	Udagak Strait (narrows) (depth 65 ft), Aleutian Islands, Alaska Current	NOS	UNI1012_15	53.73414	-166.28904	:America/Nome	USA	knots	95	272	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.288	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Udagak Strait (narrows)	AK
108590	Udagak Strait (narrows) (depth 19 ft), Aleutian Islands, Alaska Current	NOS	UNI1012_29	53.73414	-166.28904	:America/Nome	USA	knots	94	273	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.291	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Udagak Strait (narrows)	AK
108591	Priest Rock (depth 139 ft), Aleutian Islands, Alaska Current	NOS	UNI1013_1	54.01858	-166.37567	:America/Nome	USA	knots	69	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.315	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Priest Rock	AK
108592	Priest Rock (depth 73 ft), Aleutian Islands, Alaska Current	NOS	UNI1013_11	54.01858	-166.37567	:America/Nome	USA	knots	72	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.401	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Priest Rock	AK
108593	Priest Rock (depth 14 ft), Aleutian Islands, Alaska Current	NOS	UNI1013_20	54.01858	-166.37567	:America/Nome	USA	knots	71	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.461	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Priest Rock	AK
108594	Captains Bay (depth 61 ft), Aleutian Islands, Alaska Current	NOS	UNI1016_1	53.87716	-166.56829	:America/Nome	USA	knots	\N	196	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Captains Bay	AK
108595	Captains Bay (depth 41 ft), Aleutian Islands, Alaska Current	NOS	UNI1016_4	53.87716	-166.56829	:America/Nome	USA	knots	\N	200	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Captains Bay	AK
108596	Captains Bay (depth 15 ft), Aleutian Islands, Alaska Current	NOS	UNI1016_8	53.87716	-166.56829	:America/Nome	USA	knots	\N	189.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Captains Bay	AK
108597	Cape Kovrizhka (depth 192 ft), Aleutian Islands, Alaska Current	NOS	UNI1017_1	53.84524	-167.18199	:America/Nome	USA	knots	\N	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.163	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kovrizhka	AK
108598	Cape Kovrizhka (depth 103 ft), Aleutian Islands, Alaska Current	NOS	UNI1017_10	53.84524	-167.18199	:America/Nome	USA	knots	\N	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.429	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kovrizhka	AK
108599	Cape Kovrizhka (depth 25 ft), Aleutian Islands, Alaska Current	NOS	UNI1017_18	53.84524	-167.18199	:America/Nome	USA	knots	\N	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.53	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kovrizhka	AK
108600	Paso Point (depth 266 ft), Aleutian Islands, Alaska Current	NOS	UNI1018_1	53.41249	-167.69747	:America/Nome	USA	knots	227	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Paso Point	AK
108601	Paso Point (depth 167 ft), Aleutian Islands, Alaska Current	NOS	UNI1018_7	53.41249	-167.69747	:America/Nome	USA	knots	227	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Paso Point	AK
108602	Paso Point (depth 36 ft), Aleutian Islands, Alaska Current	NOS	UNI1018_15	53.41249	-167.69747	:America/Nome	USA	knots	218	48	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.369	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Paso Point	AK
108603	Umnak Pass (depth 254 ft), Aleutian Islands, Alaska Current	NOS	UNI1019_1	53.36238	-167.81982	:America/Nome	USA	knots	228	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.371	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Umnak Pass	AK
108604	Umnak Pass (depth 146 ft), Aleutian Islands, Alaska Current	NOS	UNI1019_12	53.36238	-167.81982	:America/Nome	USA	knots	228	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.569	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Umnak Pass	AK
108605	Umnak Pass (depth 38 ft), Aleutian Islands, Alaska Current	NOS	UNI1019_23	53.36238	-167.81982	:America/Nome	USA	knots	227	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Umnak Pass	AK
108606	Konets Head (depth 176 ft), Aleutian Islands, Alaska Current	NOS	UNI1020_1	53.32598	-167.90066	:America/Nome	USA	knots	288	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Konets Head	AK
108607	Konets Head (depth 104 ft), Aleutian Islands, Alaska Current	NOS	UNI1020_12	53.32598	-167.90066	:America/Nome	USA	knots	232	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.253	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Konets Head	AK
108608	Konets Head (depth 32 ft), Aleutian Islands, Alaska Current	NOS	UNI1020_23	53.32598	-167.90066	:America/Nome	USA	knots	235	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Konets Head	AK
108609	Sedanka Pass (depth 197 ft), Aleutian Islands, Alaska Current	NOS	UNI1021_1	53.85121	-166.07639	:America/Nome	USA	knots	138	330	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sedanka Pass	AK
108610	Sedanka Pass (depth 111 ft), Aleutian Islands, Alaska Current	NOS	UNI1021_14	53.85121	-166.07639	:America/Nome	USA	knots	141	338	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sedanka Pass	AK
108611	Sedanka Pass (depth 26 ft), Aleutian Islands, Alaska Current	NOS	UNI1021_27	53.85121	-166.07639	:America/Nome	USA	knots	132	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sedanka Pass	AK
108612	Derbin Strait (depth 220 ft), Aleutian Islands, Alaska Current	NOS	UNI1022_1	54.08391	-165.22707	:America/Nome	USA	knots	125	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Derbin Strait	AK
108613	Derbin Strait (depth 132 ft), Aleutian Islands, Alaska Current	NOS	UNI1022_10	54.08391	-165.22707	:America/Nome	USA	knots	133	314	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Derbin Strait	AK
108614	Derbin Strait (depth 33 ft), Aleutian Islands, Alaska Current	NOS	UNI1022_20	54.08391	-165.22707	:America/Nome	USA	knots	139	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.458	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Derbin Strait	AK
108615	Bishop Point, Unalaska Island (depth 114 ft), Aleutian Islands, Alaska Current	NOS	UNI1023_1	53.97871	-166.95646	:America/Nome	USA	knots	248	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bishop Point, Unalaska Island	AK
108616	Bishop Point, Unalaska Island (depth 68 ft), Aleutian Islands, Alaska Current	NOS	UNI1023_8	53.97871	-166.95646	:America/Nome	USA	knots	255	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bishop Point, Unalaska Island	AK
108617	Bishop Point, Unalaska Island (depth 16 ft), Aleutian Islands, Alaska Current	NOS	UNI1023_16	53.97871	-166.95646	:America/Nome	USA	knots	261	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bishop Point, Unalaska Island	AK
108618	Cape Cheerful, Unalaska Island (depth 151 ft), Aleutian Islands, Alaska Current	NOS	UNI1024_1	54.02659	-166.6724	:America/Nome	USA	knots	83	269	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cheerful, Unalaska Island	AK
108619	Cape Cheerful, Unalaska Island (depth 92 ft), Aleutian Islands, Alaska Current	NOS	UNI1024_10	54.02659	-166.6724	:America/Nome	USA	knots	87	279	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cheerful, Unalaska Island	AK
108620	Cape Cheerful, Unalaska Island (depth 20 ft), Aleutian Islands, Alaska Current	NOS	UNI1024_21	54.02659	-166.6724	:America/Nome	USA	knots	88	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.205	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cheerful, Unalaska Island	AK
108621	Isanotski Strait (False Pass Cnry) (depth 15 ft), Alaska Current	NOS	UNI1901_1	54.86669921875	-163.39999389648438	:America/Nome	USA	knots	178	358	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 4.9 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.419	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isanotski Strait (False Pass Cnry)	AK
108622	Cape Cod Canal, west end (depth 110 ft), Massachusetts Current	NOS	ca0101_8	41.73749923706055	-70.6249008178711	:America/New_York	USA	knots	\N	45	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, West End	MA
108623	Cape Cod Canal, west end (depth 189 ft), Massachusetts Current	NOS	ca0101_14	41.73749923706055	-70.6249008178711	:America/New_York	USA	knots	\N	40	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.209	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, West End	MA
108624	Cape Cod Canal, west end (depth 13 ft), Massachusetts Current	NOS	ca0101_20	41.73749923706055	-70.6249008178711	:America/New_York	USA	knots	217	41	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 267.4 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, West End	MA
108625	Chesapeake Bay ent., 2.0 nmi N of Cape Henry Lt. (depth 22 ft), Virginia Current	NOS	cb0102_4	36.9594	-76.0128	:America/New_York	USA	knots	112	297	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Ent., 2.0 n.mi. N of Cape Henry Lt.	VA
108626	Chesapeake Bay ent., 2.0 nmi N of Cape Henry Lt. (depth 38 ft), Virginia Current	NOS	cb0102_9	36.9594	-76.0128	:America/New_York	USA	knots	105	293	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.223	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Ent., 2.0 n.mi. N of Cape Henry Lt.	VA
108627	Chesapeake Bay ent., 2.0 nmi N of Cape Henry Lt. (depth 55 ft), Virginia Current	NOS	cb0102_14	36.9594	-76.0128	:America/New_York	USA	knots	101	281	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.192	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Ent., 2.0 n.mi. N of Cape Henry Lt.	VA
108628	York River entrance channel (SE end) (depth 14 ft), Virginia Current	NOS	cb0201_2	37.14	-76.13383	:America/New_York	USA	knots	168	347	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	York River Entrance Channel (SE end)	VA
108629	York River entrance channel (SE end) (depth 32 ft), Virginia Current	NOS	cb0201_7	37.14	-76.13383	:America/New_York	USA	knots	175	346	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 30.8 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.229	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	York River Entrance Channel (SE end)	VA
108630	York River entrance channel (SE end) (depth 41 ft), Virginia Current	NOS	cb0201_10	37.14	-76.13383	:America/New_York	USA	knots	158	339	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	York River Entrance Channel (SE end)	VA
108631	Thimble Shoal Channel, 2.4 nmi east of Ft. Monroe (depth 15 ft), Virginia Current	NOS	cb0301_2	37.0112	-76.2495	:America/New_York	USA	knots	85	286	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.196	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thimble Shoal Channel, 2.4 n.mi east of Ft. Monroe	VA
108632	Thimble Shoal Channel, 2.4 nmi east of Ft. Monroe (depth 22 ft), Virginia Current	NOS	cb0301_4	37.0112	-76.2495	:America/New_York	USA	knots	84	286	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thimble Shoal Channel, 2.4 n.mi east of Ft. Monroe	VA
108633	Thimble Shoal Channel, 2.4 nmi east of Ft. Monroe (depth 35 ft), Virginia Current	NOS	cb0301_8	37.0112	-76.2495	:America/New_York	USA	knots	76	280	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thimble Shoal Channel, 2.4 n.mi east of Ft. Monroe	VA
108634	Thimble Shoal Channel, 2.4 nmi east of Ft. Monroe (depth 55 ft), Virginia Current	NOS	cb0301_14	37.0112	-76.2495	:America/New_York	USA	knots	61	274	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.476	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thimble Shoal Channel, 2.4 n.mi east of Ft. Monroe	VA
108635	Sewells Point (Naval Station Norfolk) (depth 21 ft), Hampton Roads, Virginia Current	NOS	cb0402_4	36.96295	-76.33388	:America/New_York	USA	knots	10	202	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.398	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sewells Point (Naval Station Norfolk)	VA
108636	Sewells Point (Naval Station Norfolk) (depth 34 ft), Hampton Roads, Virginia Current	NOS	cb0402_8	36.96295	-76.33388	:America/New_York	USA	knots	8	198	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.289	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sewells Point (Naval Station Norfolk)	VA
108637	Sewells Point (Naval Station Norfolk) (depth 44 ft), Hampton Roads, Virginia Current	NOS	cb0402_11	36.96295	-76.33388	:America/New_York	USA	knots	6	190	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sewells Point (Naval Station Norfolk)	VA
110515	Mill Creek, Alaska Current	NOS	PCT3091_1	56.45	-132.21667	:America/Juneau	USA	knots	330	150	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:44:00	\N	0.9	00:23:00	\N	0.6	00:31:00	00:13:00	Mill Creek	AK
108638	Newport News Channel, west end (depth 15 ft), Hampton Roads, Virginia Current	NOS	cb0601_2	36.95602	-76.41448	:America/New_York	USA	knots	100	285	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.221	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newport News Channel, west end	VA
108639	Newport News Channel, west end (depth 21 ft), Hampton Roads, Virginia Current	NOS	cb0601_4	36.95602	-76.41448	:America/New_York	USA	knots	98	284	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newport News Channel, west end	VA
108640	Newport News Channel, west end (depth 31 ft), Hampton Roads, Virginia Current	NOS	cb0601_7	36.95602	-76.41448	:America/New_York	USA	knots	98	287	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newport News Channel, west end	VA
108641	James River entrance (depth 11 ft), Virginia Current	NOS	cb0701_25	36.96233	-76.42417	:America/New_York	USA	knots	118	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 169.0 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	James River Entrance	VA
108642	Bluff Point, 7.2 nmi east of (depth 22 ft), Chesapeake Bay, Virginia Current	NOS	cb0801_4	37.67442	-76.15462	:America/New_York	USA	knots	175	337	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bluff Point, 7.2 n.mi. east of	VA
108643	Bluff Point, 7.2 nmi east of (depth 32 ft), Chesapeake Bay, Virginia Current	NOS	cb0801_7	37.67442	-76.15462	:America/New_York	USA	knots	176	343	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bluff Point, 7.2 n.mi. east of	VA
108644	Bluff Point, 7.2 nmi east of (depth 42 ft), Chesapeake Bay, Virginia Current	NOS	cb0801_10	37.67442	-76.15462	:America/New_York	USA	knots	210	345	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bluff Point, 7.2 n.mi. east of	VA
108645	Piney Point, 1.1 nmi south of (depth 22 ft), Potomac River, Maryland Current	NOS	cb0901_4	38.09098	-76.52975	:America/New_York	USA	knots	124	314	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piney Point, 1.1 n.mi. south of	MD
108646	Piney Point, 1.1 nmi south of (depth 32 ft), Potomac River, Maryland Current	NOS	cb0901_7	38.09098	-76.52975	:America/New_York	USA	knots	121	317	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piney Point, 1.1 n.mi. south of	MD
108647	Piney Point, 1.1 nmi south of (depth 55 ft), Potomac River, Maryland Current	NOS	cb0901_14	38.09098	-76.52975	:America/New_York	USA	knots	112	329	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piney Point, 1.1 n.mi. south of	MD
108648	Cove Point, 1.0 nmi N of (depth 10 ft), Chesapeake Bay, Maryland Current	NOS	cb1001_20	38.4026985168457	-76.38390350341797	:America/New_York	USA	knots	138	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 265.7 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cove Point, 1.0 n.mi. N of	MD
108649	Chesapeake Bay Bridge, 0.5 nmi S of (LB91) (depth 14 ft), Maryland Current	NOS	cb1102_2	38.97999954223633	-76.38999938964844	:America/New_York	USA	knots	219	30	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Bridge, 0.5nm S of (LB91)	MD
108650	Chesapeake Bay Bridge, 0.5 nmi S of (LB91) (depth 24 ft), Maryland Current	NOS	cb1102_5	38.97999954223633	-76.38999938964844	:America/New_York	USA	knots	219	30	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Bridge, 0.5nm S of (LB91)	MD
108651	Chesapeake Bay Bridge, 0.5 nmi S of (LB91) (depth 34 ft), Maryland Current	NOS	cb1102_8	38.97999954223633	-76.38999938964844	:America/New_York	USA	knots	209	19	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Bridge, 0.5nm S of (LB91)	MD
108652	Swan Point, 2.6 nmi west of (depth 26 ft), Chesapeake Bay, Maryland Current	NOS	cb1201_1	39.14083	-76.32947	:America/New_York	USA	knots	162	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Swan Point, 2.6 n.mi. west of	MD
108653	Swan Point, 2.6 nmi west of (depth 16 ft), Chesapeake Bay, Maryland Current	NOS	cb1201_4	39.14083	-76.32947	:America/New_York	USA	knots	196	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Swan Point, 2.6 n.mi. west of	MD
108654	Swan Point, 2.6 nmi west of (depth 7 ft), Chesapeake Bay, Maryland Current	NOS	cb1201_7	39.14083	-76.32947	:America/New_York	USA	knots	192	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.126	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Swan Point, 2.6 n.mi. west of	MD
105652	Miner Island, Lisianski Inlet, Alaska	NOS	9452633	58.01	-136.342	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	103725	-00:06:00	\N	0.96	-00:08:00	\N	0.94	\N	\N	Miner Island	AK
108655	Chesapeake and Delaware Canal, Chesapeake City (depth 59 ft), Maryland Current	NOS	cb1301_4	39.53053	-75.82762	:America/New_York	USA	knots	\N	86.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake and Delaware Canal, Chesapeake City	MD
108656	Chesapeake and Delaware Canal, Chesapeake City (depth 164 ft), Maryland Current	NOS	cb1301_12	39.53053	-75.82762	:America/New_York	USA	knots	\N	88	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake and Delaware Canal, Chesapeake City	MD
108657	Chesapeake and Delaware Canal, Chesapeake City (depth 8 ft), Maryland Current	NOS	cb1301_20	39.53053	-75.82762	:America/New_York	USA	knots	278	97	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 269.0 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake and Delaware Canal, Chesapeake City	MD
108658	Newport News Shipbuilding (depth 22 ft), Hampton Roads, Virginia Current	NOS	cb1401_40	36.98379898071289	-76.443603515625	:America/New_York	USA	knots	159	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 528.2 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newport News Shipbuilding	VA
108660	Enbridge (depth 44 ft), Corpus Christi Channel, Texas Current	NOS	cc0401_10	27.8177	-97.2093	:America/Chicago	USA	knots	65	246	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 136.2 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Enbridge	TX
108661	Harbor Island, Aransas Channel (depth 11 ft), Texas Current	NOS	cc0501_12	27.84673	-97.06076	:America/Chicago	USA	knots	160	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 162.1 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.333	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island, Aransas Channel	TX
108662	Harbor Island, Aransas Channel (depth 398 ft), Texas Current	NOS	cc0501_30	27.84673	-97.06076	:America/Chicago	USA	knots	\N	330.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.198	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island, Aransas Channel	TX
108663	Corpus Christi Channel UT Marine Science (depth 15 ft), Texas Current	NOS	cc0601_32	27.83972	-97.0725	:America/Chicago	USA	knots	69	246	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 424.9 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Corpus Christi Channel UT Marine Science	TX
108664	Cherry Point (depth 47 ft), Rosario Strait, Washington Current	NOS	cp0101_20	48.86275	-122.76098	:America/Los_Angeles	USA	knots	179	7	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 267.4 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point	WA
108665	Reedy Point (depth 35 ft), Delaware Current	NOS	db0201_1	39.55860137939453	-75.55149841308594	:America/New_York	USA	knots	168	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Point	DE
108666	Reedy Point (depth 15 ft), Delaware Current	NOS	db0201_7	39.55860137939453	-75.55149841308594	:America/New_York	USA	knots	162	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.222	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Point	DE
108667	Reedy Point (depth 6 ft), Delaware Current	NOS	db0201_10	39.55860137939453	-75.55149841308594	:America/New_York	USA	knots	160	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.266	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Point	DE
108668	Philadelphia, Penns Landing (depth 39 ft), Pennsylvania Current	NOS	db0301_22	39.94620132446289	-75.13960266113281	:America/New_York	USA	knots	187	4	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 295.3 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.388	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Philadelphia, Penns Landing	PA
108669	Delaware Bay Channel LB 10 (depth 12 ft), Delaware Current	NOS	db0502_1	38.94013	-75.10486	:America/New_York	USA	knots	157	341	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware Bay Channel LB 10	DE
108670	Petty Island, Delaware River (depth 10 ft), Pennsylvania Current	NOS	db1935_3	39.96730041503906	-75.11720275878906	:America/New_York	USA	knots	238	59	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Petty Island, Delaware River	PA
108671	Petty Island, Delaware River (depth 16 ft), Pennsylvania Current	NOS	db1935_5	39.96730041503906	-75.11720275878906	:America/New_York	USA	knots	237	59	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Petty Island, Delaware River	PA
108672	Petty Island, Delaware River (depth 30 ft), Pennsylvania Current	NOS	db1935_9	39.96730041503906	-75.11720275878906	:America/New_York	USA	knots	235	59	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Petty Island, Delaware River	PA
108673	Surfside Bridge (depth 30 ft), Freeport, Texas Current	NOS	fr0201_2	28.955	-95.2939	:America/Chicago	USA	knots	\N	42.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Surfside Bridge	TX
108674	Surfside Bridge (depth 15 ft), Freeport, Texas Current	NOS	fr0201_6	28.955	-95.2939	:America/Chicago	USA	knots	222	42	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 82.0 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Surfside Bridge	TX
108675	Surfside Bridge (depth 135 ft), Freeport, Texas Current	NOS	fr0201_10	28.955	-95.2939	:America/Chicago	USA	knots	\N	46.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Surfside Bridge	TX
108676	Morgans Point (depth 19 ft), Galveston Bay, Texas Current	NOS	g02010_1	29.68160057067871	-94.9822998046875	:America/Chicago	USA	knots	169	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Morgans Point	TX
108677	Morgans Point (depth 9 ft), Galveston Bay, Texas Current	NOS	g02010_4	29.68160057067871	-94.9822998046875	:America/Chicago	USA	knots	172	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.179	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Morgans Point	TX
108678	Galveston Causeway RR. bridge (depth 10 ft), Galveston Bay, Texas Current	NOS	g05010_26	29.29747	-94.885818	:America/Chicago	USA	knots	99	266	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 177.2 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.205	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Causeway RR. bridge	TX
108679	Galveston Bay entrance channel, LB 11 (depth 13 ft), Texas Current	NOS	g06010_1	29.34222	-94.74083	:America/Chicago	USA	knots	77	282	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.236	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Bay Entrance Channel, LB 11	TX
108680	Fred Hartman Br., Houston Ship Channel (depth 25 ft), Galveston Bay, Texas Current	NOS	g08010_30	29.7035	-95.01892	:America/Chicago	USA	knots	136	314	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 398.6 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.205	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fred Hartman Br., Houston Ship Channel	TX
108681	Galveston Channel, west end (depth 30 ft), Galveston Bay, Texas Current	NOS	g09010_30	29.30940055847168	-94.82060241699219	:America/Chicago	USA	knots	112	289	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 397.0 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Channel, west end	TX
108682	Galveston Channel, east end (depth 36 ft), Galveston Bay, Texas Current	NOS	g11010_28	29.3182	-94.781	:America/Chicago	USA	knots	28	211	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 370.7 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Channel, East End	TX
108683	Ship Island, 1.0 nmi S of, LB 22 (depth 11 ft), Mississippi Sound, Mississippi Current	NOS	gp0101_1	30.19406	-88.98917	:America/Chicago	USA	knots	114	308	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 1.0 nm S of, LB 22	MS
108684	Ship Island, 1.0 nmi S of, LB 22 (depth 18 ft), Mississippi Sound, Mississippi Current	NOS	gp0101_3	30.19406	-88.98917	:America/Chicago	USA	knots	\N	298.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 1.0 nm S of, LB 22	MS
108685	Ship Island, 1.0 nmi S of, LB 22 (depth 24 ft), Mississippi Sound, Mississippi Current	NOS	gp0101_5	30.19406	-88.98917	:America/Chicago	USA	knots	\N	314.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 1.0 nm S of, LB 22	MS
108686	Ship Island, 0.5 nmi NW of, LB 26 (depth 11 ft), Mississippi Sound, Mississippi Current	NOS	gp0201_1	30.2162	-88.99442	:America/Chicago	USA	knots	\N	33.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 0.5 nm NW of, LB 26	MS
108687	Ship Island, 0.5 nmi NW of, LB 26 (depth 15 ft), Mississippi Sound, Mississippi Current	NOS	gp0201_2	30.2162	-88.99442	:America/Chicago	USA	knots	216	9	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 0.5 nm NW of, LB 26	MS
108688	Ship Island, 0.5 nmi NW of, LB 26 (depth 18 ft), Mississippi Sound, Mississippi Current	NOS	gp0201_3	30.2162	-88.99442	:America/Chicago	USA	knots	\N	26.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 0.5 nm NW of, LB 26	MS
108689	Ship Island, 1.8 nmi NNW of, DM 32 (depth 10 ft), Mississippi Sound, Mississippi Current	NOS	gp0301_5	30.23917	-89	:America/Chicago	USA	knots	184	26	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 70.5 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 1.8 nm NNW of, DM 32	MS
108690	Ship Island, 1.8 nmi NNW of, DM 32 (depth 202 ft), Mississippi Sound, Mississippi Current	NOS	gp0301_15	30.23917	-89	:America/Chicago	USA	knots	\N	20.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 1.8 nm NNW of, DM 32	MS
108691	Ship Island, 1.8 nmi NNW of, DM 32 (depth 399 ft), Mississippi Sound, Mississippi Current	NOS	gp0301_30	30.23917	-89	:America/Chicago	USA	knots	\N	20.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 1.8 nm NNW of, DM 32	MS
108692	Humboldt Bay entrance channel LB 9 (depth 11 ft), California Current	NOS	hb0201_1	40.75699996948242	-124.22339630126953	:America/Los_Angeles	USA	knots	232	111	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.246	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldt Bay Entrance Channel LB 9	CA
108693	Humboldt Bay entrance channel LB 9 (depth 21 ft), California Current	NOS	hb0201_4	40.75699996948242	-124.22339630126953	:America/Los_Angeles	USA	knots	247	106	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.224	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldt Bay Entrance Channel LB 9	CA
108694	Humboldt Bay entrance channel LB 9 (depth 37 ft), California Current	NOS	hb0201_9	40.75699996948242	-124.22339630126953	:America/Los_Angeles	USA	knots	259	98	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldt Bay Entrance Channel LB 9	CA
108695	Hookton Channel Day Marker 3 (depth 59 ft), Humboldt Bay, California Current	NOS	hb0302_2	40.74399948120117	-124.22450256347656	:America/Los_Angeles	USA	knots	\N	191.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hookton Channel Day Marker 3	CA
108696	Hookton Channel Day Marker 3 (depth 16 ft), Humboldt Bay, California Current	NOS	hb0302_5	40.74399948120117	-124.22450256347656	:America/Los_Angeles	USA	knots	9	195	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 137.8 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hookton Channel Day Marker 3	CA
108697	Hookton Channel Day Marker 3 (depth 217 ft), Humboldt Bay, California Current	NOS	hb0302_8	40.74399948120117	-124.22450256347656	:America/Los_Angeles	USA	knots	\N	191.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hookton Channel Day Marker 3	CA
108698	North Bay Channel, Chevron Pier (depth 15 ft), Humboldt Bay, California Current	NOS	hb0401_15	40.7775	-124.19661	:America/Los_Angeles	USA	knots	206	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 400.3 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Bay Channel, Chevron Pier	CA
108699	Bar Cut, 0.6 nmi ENE of St. Johns Point (depth 12 ft), St. Johns River, Florida Current	NOS	jx0101_1	30.39994	-81.37367	:America/New_York	USA	knots	58	275	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.448	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bar Cut, 0.6 n.mi. ENE of St. John's Point	FL
108700	Bar Cut, 0.6 nmi ENE of St. Johns Point (depth 25 ft), St. Johns River, Florida Current	NOS	jx0101_5	30.39994	-81.37367	:America/New_York	USA	knots	61	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bar Cut, 0.6 n.mi. ENE of St. John's Point	FL
108701	Bar Cut, 0.6 nmi ENE of St. Johns Point (depth 35 ft), St. Johns River, Florida Current	NOS	jx0101_8	30.39994	-81.37367	:America/New_York	USA	knots	72	247	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bar Cut, 0.6 n.mi. ENE of St. John's Point	FL
108702	Mayport Basin entrance (depth 12 ft), St. Johns River, Florida Current	NOS	jx0201_1	30.39889	-81.39469	:America/New_York	USA	knots	93	280	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport Basin Entrance	FL
108703	Mayport Basin entrance (depth 22 ft), St. Johns River, Florida Current	NOS	jx0201_4	30.39889	-81.39469	:America/New_York	USA	knots	84	276	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport Basin Entrance	FL
108704	Mayport Basin entrance (depth 35 ft), St. Johns River, Florida Current	NOS	jx0201_8	30.39889	-81.39469	:America/New_York	USA	knots	73	276	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.204	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport Basin Entrance	FL
108705	ICW Intersection (depth 12 ft), St. Johns River, Florida Current	NOS	jx0301_1	30.38275	-81.45556	:America/New_York	USA	knots	102	292	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.389	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICW Intersection	FL
108706	ICW Intersection (depth 22 ft), St. Johns River, Florida Current	NOS	jx0301_4	30.38275	-81.45556	:America/New_York	USA	knots	94	291	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.326	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICW Intersection	FL
108707	ICW Intersection (depth 35 ft), St. Johns River, Florida Current	NOS	jx0301_8	30.38275	-81.45556	:America/New_York	USA	knots	89	296	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICW Intersection	FL
108708	Mile Point LB 20 (depth 11 ft), St. Johns River, Florida Current	NOS	jx0302_1	30.38433	-81.44217	:America/New_York	USA	knots	36	203	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.293	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mile Point LB 20	FL
108709	Mile Point LB 20 (depth 17 ft), St. Johns River, Florida Current	NOS	jx0302_3	30.38433	-81.44217	:America/New_York	USA	knots	38	203	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.178	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mile Point LB 20	FL
108710	Mile Point LB 20 (depth 27 ft), St. Johns River, Florida Current	NOS	jx0302_6	30.38433	-81.44217	:America/New_York	USA	knots	35	213	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mile Point LB 20	FL
108711	St. Johns Bluff (depth 12 ft), St. Johns River, Florida Current	NOS	jx0401_1	30.39037	-81.49678	:America/New_York	USA	knots	82	269	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.293	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns Bluff	FL
108712	St. Johns Bluff (depth 22 ft), St. Johns River, Florida Current	NOS	jx0401_4	30.39037	-81.49678	:America/New_York	USA	knots	72	267	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns Bluff	FL
108713	St. Johns Bluff (depth 32 ft), St. Johns River, Florida Current	NOS	jx0401_7	30.39037	-81.49678	:America/New_York	USA	knots	71	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 30.8 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.251	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns Bluff	FL
108714	Dames Point Bridge (depth 56 ft), St. Johns River, Florida Current	NOS	jx0501_4	30.38599967956543	-81.55789947509766	:America/New_York	USA	knots	\N	266.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.261	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point Bridge	FL
108715	Dames Point Bridge (depth 15 ft), St. Johns River, Florida Current	NOS	jx0501_13	30.38599967956543	-81.55789947509766	:America/New_York	USA	knots	87	257	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 173.9 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point Bridge	FL
108716	Dames Point Bridge (depth 240 ft), St. Johns River, Florida Current	NOS	jx0501_18	30.38599967956543	-81.55789947509766	:America/New_York	USA	knots	\N	257.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.311	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point Bridge	FL
108717	Reddie Point (depth 12 ft), St. Johns River, Florida Current	NOS	jx0601_1	30.39118	-81.62606	:America/New_York	USA	knots	36	176	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reddie Point	FL
108718	Reddie Point (depth 16 ft), St. Johns River, Florida Current	NOS	jx0601_2	30.39118	-81.62606	:America/New_York	USA	knots	\N	204.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reddie Point	FL
108719	Reddie Point (depth 19 ft), St. Johns River, Florida Current	NOS	jx0601_3	30.39118	-81.62606	:America/New_York	USA	knots	\N	205.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reddie Point	FL
108720	Reddie Point (depth 22 ft), St. Johns River, Florida Current	NOS	jx0601_4	30.39118	-81.62606	:America/New_York	USA	knots	40	170	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reddie Point	FL
108721	Reddie Point (depth 25 ft), St. Johns River, Florida Current	NOS	jx0601_5	30.39118	-81.62606	:America/New_York	USA	knots	\N	200.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.171	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reddie Point	FL
108722	Reddie Point (depth 29 ft), St. Johns River, Florida Current	NOS	jx0601_6	30.39118	-81.62606	:America/New_York	USA	knots	\N	197.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reddie Point	FL
108723	Reddie Point (depth 32 ft), St. Johns River, Florida Current	NOS	jx0601_7	30.39118	-81.62606	:America/New_York	USA	knots	\N	195.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reddie Point	FL
108724	Reddie Point (depth 35 ft), St. Johns River, Florida Current	NOS	jx0601_8	30.39118	-81.62606	:America/New_York	USA	knots	29	164	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reddie Point	FL
108725	Acosta Bridge (depth 15 ft), St. Johns River, Florida Current	NOS	jx0701_20	30.32266	-81.66461	:America/New_York	USA	knots	77	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 267.4 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Acosta Bridge	FL
108726	St. Marys entrance, LB 13 (depth 14 ft), Cumberland Sound, Florida Current	NOS	kb0101_2	30.7103	-81.3731	:America/New_York	USA	knots	95	320	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.234	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Marys Entrance, LB 13	FL
108727	St. Marys entrance, LB 13 (depth 21 ft), Cumberland Sound, Florida Current	NOS	kb0101_4	30.7103	-81.3731	:America/New_York	USA	knots	94	317	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.195	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Marys Entrance, LB 13	FL
108728	St. Marys entrance, LB 13 (depth 31 ft), Cumberland Sound, Florida Current	NOS	kb0101_7	30.7103	-81.3731	:America/New_York	USA	knots	92	317	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Marys Entrance, LB 13	FL
108729	St. Marys entrance, LB 19 (depth 11 ft), Florida Current	NOS	kb0102_1	30.7089	-81.4148	:America/New_York	USA	knots	71	276	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.307	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Marys Entrance, LB 19	FL
108730	St. Marys entrance, LB 19 (depth 21 ft), Florida Current	NOS	kb0102_4	30.7089	-81.4148	:America/New_York	USA	knots	77	272	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Marys Entrance, LB 19	FL
108731	St. Marys entrance, LB 19 (depth 34 ft), Florida Current	NOS	kb0102_8	30.7089	-81.4148	:America/New_York	USA	knots	75	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.062	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Marys Entrance, LB 19	FL
108732	Range A, LB 23, St. Marys River (depth 11 ft), Cumberland Sound, Georgia Current	NOS	kb0201_1	30.71049	-81.45926	:America/New_York	USA	knots	98	295	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A, LB 23, St Marys River	GA
108733	Range A, LB 23, St. Marys River (depth 14 ft), Cumberland Sound, Georgia Current	NOS	kb0201_2	30.71049	-81.45926	:America/New_York	USA	knots	97	296	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A, LB 23, St Marys River	GA
108734	Range A, LB 23, St. Marys River (depth 24 ft), Cumberland Sound, Georgia Current	NOS	kb0201_5	30.71049	-81.45926	:America/New_York	USA	knots	90	299	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A, LB 23, St Marys River	GA
108735	Range A2, LB 29, Cumberland Sound (depth 11 ft), Georgia Current	NOS	kb0301_1	30.72482	-81.48445	:America/New_York	USA	knots	182	341	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.144	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A2, LB 29, Cumberland Sound	GA
108736	Range A2, LB 29, Cumberland Sound (depth 18 ft), Georgia Current	NOS	kb0301_3	30.72482	-81.48445	:America/New_York	USA	knots	167	340	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A2, LB 29, Cumberland Sound	GA
108737	Range A2, LB 29, Cumberland Sound (depth 24 ft), Georgia Current	NOS	kb0301_5	30.72482	-81.48445	:America/New_York	USA	knots	149	339	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A2, LB 29, Cumberland Sound	GA
108738	Range E, LB 43, Cumberland Sound (depth 11 ft), East River, Georgia Current	NOS	kb0401_1	30.77505	-81.48902	:America/New_York	USA	knots	156	2	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range E, LB 43, Cumberland Sound	GA
108739	Range E, LB 43, Cumberland Sound (depth 21 ft), East River, Georgia Current	NOS	kb0401_4	30.77505	-81.48902	:America/New_York	USA	knots	160	9	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range E, LB 43, Cumberland Sound	GA
108740	Kings Bay, Site VI (depth 28 ft), Cumberland Sound, Georgia Current	NOS	kb0501_15	30.7883	-81.4967	:America/New_York	USA	knots	144	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 200.1 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kings Bay, Site VI	GA
108741	Kings Bay, North Turning Basin (depth 10 ft), Cumberland Sound, Georgia Current	NOS	kb0601_2	30.81	-81.5203	:America/New_York	USA	knots	174	355	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kings Bay, North Turning Basin	GA
108742	Kings Bay, North Turning Basin (depth 16 ft), Cumberland Sound, Georgia Current	NOS	kb0601_4	30.81	-81.5203	:America/New_York	USA	knots	173	352	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kings Bay, North Turning Basin	GA
108743	Kings Bay, North Turning Basin (depth 26 ft), Cumberland Sound, Georgia Current	NOS	kb0601_7	30.81	-81.5203	:America/New_York	USA	knots	169	349	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kings Bay, North Turning Basin	GA
108744	Rich Passage, LB 8 (depth 11 ft), Puget Sound, Washington Current	NOS	ks0101_1	47.5933	-122.5426	:America/Los_Angeles	USA	knots	103	318	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, LB 8	WA
108745	Rich Passage, LB 8 (depth 14 ft), Puget Sound, Washington Current	NOS	ks0101_2	47.5933	-122.5426	:America/Los_Angeles	USA	knots	105	318	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, LB 8	WA
108746	Rich Passage, LB 8 (depth 31 ft), Puget Sound, Washington Current	NOS	ks0101_7	47.5933	-122.5426	:America/Los_Angeles	USA	knots	109	313	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.157	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, LB 8	WA
108747	Bangor, Hood Canal LB B (depth 14 ft), Washington Current	NOS	ks0201_2	47.75782	-122.73057	:America/Los_Angeles	USA	knots	358	181	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 12.8 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.228	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor, Hood Canal LB B	WA
108748	Bangor, Hood Canal LB B (depth 28 ft), Washington Current	NOS	ks0201_6	47.75782	-122.73057	:America/Los_Angeles	USA	knots	354	179	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 25.9 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor, Hood Canal LB B	WA
108749	Bangor, Hood Canal LB B (depth 41 ft), Washington Current	NOS	ks0201_10	47.75782	-122.73057	:America/Los_Angeles	USA	knots	352	179	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 39.0 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor, Hood Canal LB B	WA
108750	Queens Gate (depth 35 ft), California Current	NOS	lb0101_6	33.717	-118.1879	:America/Los_Angeles	USA	knots	257	48	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.062	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Queens Gate	CA
108751	Calcasieu Pass, Cameron Fishing Pier (depth 17 ft), Louisiana Current	NOS	lc0201_20	29.76513	-93.34293	:America/Chicago	USA	knots	173	353	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 267.4 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.324	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Calcasieu Pass, Cameron Fishing Pier	LA
108752	Lake Charles City Docks (depth 21 ft), Louisiana Current	NOS	lc0301_20	30.2178	-93.2495	:America/Chicago	USA	knots	289	115	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 267.4 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.393	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Charles City Docks	LA
108753	Matagorda Ship Channel Marker 19 (depth 15 ft), Matagorda Bay, Texas Current	NOS	mg0101_17	28.44769	-96.35619	:America/Chicago	USA	knots	163	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 226.4 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.172	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matagorda Ship Channel Marker 19	TX
108754	Matagorda entrance channel (depth 15 ft), Matagorda Bay, Texas Current	NOS	mg0201_20	28.42667	-96.33	:America/Chicago	USA	knots	124	306	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 264.1 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matagorda Entrance Channel	TX
108755	Bergen Point (depth 37 ft), Kill Van Kull, New York Current	NOS	n01010_1	40.6422004699707	-74.15129852294922	:America/New_York	USA	knots	110	299	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.252	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bergen Point	NY
108756	Bergen Point (depth 14 ft), Kill Van Kull, New York Current	NOS	n01010_8	40.6422004699707	-74.15129852294922	:America/New_York	USA	knots	133	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bergen Point	NY
108757	Bayonne Bridge (depth 16 ft), Kill Van Kull, New York Current	NOS	n02010_8	40.641700744628906	-74.14330291748047	:America/New_York	USA	knots	78	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bayonne Bridge	NY
108758	The Narrows (depth 29 ft), New York Harbor entrance, New York Current	NOS	n03020_2	40.60639953613281	-74.03800201416016	:America/New_York	USA	knots	134	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows	NY
108759	The Narrows (depth 13 ft), New York Harbor entrance, New York Current	NOS	n03020_7	40.60639953613281	-74.03800201416016	:America/New_York	USA	knots	143	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.299	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows	NY
108760	The Narrows (depth 6 ft), New York Harbor entrance, New York Current	NOS	n03020_9	40.60639953613281	-74.03800201416016	:America/New_York	USA	knots	144	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.407	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows	NY
108761	Gowanus Flats LBB 32 (depth 11 ft), Upper Bay, New York Harbor, New York Current	NOS	n05010_1	40.67210006713867	-74.03990173339844	:America/New_York	USA	knots	197	29	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.462	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gowanus Flats LBB 32	NY
108762	Gowanus Flats LBB 32 (depth 28 ft), Upper Bay, New York Harbor, New York Current	NOS	n05010_6	40.67210006713867	-74.03990173339844	:America/New_York	USA	knots	191	26	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gowanus Flats LBB 32	NY
108763	Gowanus Flats LBB 32 (depth 44 ft), Upper Bay, New York Harbor, New York Current	NOS	n05010_11	40.67210006713867	-74.03990173339844	:America/New_York	USA	knots	194	25	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.175	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gowanus Flats LBB 32	NY
108764	Kill Van Kull LB 14, east of Bayonne Bridge (depth 11 ft), New Jersey Current	NOS	n06010_1	40.64358	-74.13889	:America/New_York	USA	knots	75	248	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kill Van Kull LB 14, east of Bayonne Bridge	NJ
108765	Kill Van Kull LB 14, east of Bayonne Bridge (depth 25 ft), New Jersey Current	NOS	n06010_4	40.64358	-74.13889	:America/New_York	USA	knots	78	247	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 21.5 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kill Van Kull LB 14, east of Bayonne Bridge	NJ
108766	Kill Van Kull LB 14, east of Bayonne Bridge (depth 41 ft), New Jersey Current	NOS	n06010_10	40.64358	-74.13889	:America/New_York	USA	knots	82	248	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.159	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kill Van Kull LB 14, east of Bayonne Bridge	NJ
108767	Newark Bay entrance LB 18 (depth 15 ft), New Jersey Current	NOS	n07010_2	40.64708	-74.1555	:America/New_York	USA	knots	155	0	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.201	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newark Bay Entrance LB 18	NJ
108768	Newark Bay entrance LB 18 (depth 22 ft), New Jersey Current	NOS	n07010_4	40.64708	-74.1555	:America/New_York	USA	knots	149	357	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.236	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newark Bay Entrance LB 18	NJ
108769	Newark Bay entrance LB 18 (depth 32 ft), New Jersey Current	NOS	n07010_7	40.64708	-74.1555	:America/New_York	USA	knots	119	4	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.218	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newark Bay Entrance LB 18	NJ
108659	UTMSI Research Pier (midchannel) (depth 20 ft), Port Aransas, Texas Current	NOS	cc0302_30	27.83810043334961	-97.052001953125	:America/Chicago	USA	knots	122	300	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 398.6 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UTSMI Research Pier (midchannel)	TX
108770	Providence River, Fox Point Reach (depth 31 ft), Narragansett Bay, Rhode Island Current	NOS	nb0101_2	41.8087	-71.39747	:America/New_York	USA	knots	\N	341.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Providence River, Fox Point Reach	RI
108771	Providence River, Fox Point Reach (depth 11 ft), Narragansett Bay, Rhode Island Current	NOS	nb0101_8	41.8087	-71.39747	:America/New_York	USA	knots	141	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Providence River, Fox Point Reach	RI
108772	Fall River entrance (depth 30 ft), Narragansett Bay, Massachusetts Current	NOS	nb0201_1	41.6999	-71.17842	:America/New_York	USA	knots	239	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fall River entrance	MA
108773	Fall River entrance (depth 23 ft), Narragansett Bay, Massachusetts Current	NOS	nb0201_3	41.6999	-71.17842	:America/New_York	USA	knots	\N	59.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.198	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fall River entrance	MA
108774	Fall River entrance (depth 13 ft), Narragansett Bay, Massachusetts Current	NOS	nb0201_6	41.6999	-71.17842	:America/New_York	USA	knots	242	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fall River entrance	MA
108775	Quonset Point (depth 8 ft), Narragansett Bay, Rhode Island Current	NOS	nb0301_7	41.5834	-71.3957	:America/New_York	USA	knots	194	27	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quonset Point	RI
108776	Groton, Thames River, Pier 6 (depth 42 ft), Long Island Sound, Connecticut Current	NOS	nl0101_9	41.39175	-72.0923	:America/New_York	USA	knots	132	311	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 124.7 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Groton, Thames River, Pier 6	CT
108777	Portsmouth Harbor, Gangway Rocks LB13 (depth 14 ft), New Hampshire Current	NOS	pm0101_2	43.0784	-70.7467	:America/New_York	USA	knots	121	289	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.237	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portsmouth Harbor, Gangway Rocks LB13	NH
108778	Portsmouth Harbor, Gangway Rocks LB13 (depth 21 ft), New Hampshire Current	NOS	pm0101_4	43.0784	-70.7467	:America/New_York	USA	knots	121	287	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portsmouth Harbor, Gangway Rocks LB13	NH
108779	Portsmouth Harbor, Gangway Rocks LB13 (depth 28 ft), New Hampshire Current	NOS	pm0101_6	43.0784	-70.7467	:America/New_York	USA	knots	120	284	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.175	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portsmouth Harbor, Gangway Rocks LB13	NH
108780	Horn Island Pass, LB 17 (depth 12 ft), Mississippi Sound, Mississippi Current	NOS	ps0201_1	30.21503	-88.51089	:America/Chicago	USA	knots	228	23	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.157	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horn Island Pass, LB 17	MS
108781	Horn Island Pass, LB 17 (depth 25 ft), Mississippi Sound, Mississippi Current	NOS	ps0201_5	30.21503	-88.51089	:America/Chicago	USA	knots	221	25	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horn Island Pass, LB 17	MS
108782	Benicia Bridge (depth 15 ft), Suisun Bay, California Current	NOS	s06010_16	38.03463	-122.12525	:America/Los_Angeles	USA	knots	242	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 213.3 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Benicia Bridge	CA
108783	Southampton Shoal Channel, LB 6 (depth 15 ft), San Francisco Bay, California Current	NOS	s08010_2	37.91625	-122.42233	:America/Los_Angeles	USA	knots	169	359	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southampton Shoal Channel, LB 6	CA
108784	Southampton Shoal Channel, LB 6 (depth 22 ft), San Francisco Bay, California Current	NOS	s08010_4	37.91625	-122.42233	:America/Los_Angeles	USA	knots	168	358	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.115	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southampton Shoal Channel, LB 6	CA
108785	Southampton Shoal Channel, LB 6 (depth 35 ft), San Francisco Bay, California Current	NOS	s08010_8	37.91625	-122.42233	:America/Los_Angeles	USA	knots	170	356	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southampton Shoal Channel, LB 6	CA
108786	Oakland Outer Harbor entrance, LB 3 (depth 14 ft), San Francisco Bay, California Current	NOS	s09010_2	37.8082	-122.34434	:America/Los_Angeles	USA	knots	359	191	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Outer Harbor Entrance, LB 3	CA
108787	Oakland Outer Harbor entrance, LB 3 (depth 24 ft), San Francisco Bay, California Current	NOS	s09010_4	37.8082	-122.34434	:America/Los_Angeles	USA	knots	1	194	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 20.7 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Outer Harbor Entrance, LB 3	CA
108788	Oakland Outer Harbor entrance, LB 3 (depth 37 ft), San Francisco Bay, California Current	NOS	s09010_9	37.8082	-122.34434	:America/Los_Angeles	USA	knots	16	203	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Outer Harbor Entrance, LB 3	CA
108789	Oakland Inner Harbor LB4 (depth 14 ft), San Francisco Bay, California Current	NOS	s10010_2	37.80097	-122.34775	:America/Los_Angeles	USA	knots	348	165	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor LB4	CA
108790	Oakland Inner Harbor LB4 (depth 21 ft), San Francisco Bay, California Current	NOS	s10010_4	37.80097	-122.34775	:America/Los_Angeles	USA	knots	348	161	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor LB4	CA
108791	Oakland Inner Harbor LB4 (depth 27 ft), San Francisco Bay, California Current	NOS	s10010_6	37.80097	-122.34775	:America/Los_Angeles	USA	knots	347	157	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.126	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor LB4	CA
108792	Sabine Pass, USCG base (depth 267 ft), Texas Current	NOS	sn0201_20	29.7286	-93.87	:America/Chicago	USA	knots	\N	327.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass, USCG Base	TX
108793	Sabine Pass, USCG base (depth 4 ft), Texas Current	NOS	sn0201_30	29.7286	-93.87	:America/Chicago	USA	knots	146	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 398.6 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass, USCG Base	TX
108794	Sabine Pass, USCG base (depth 530 ft), Texas Current	NOS	sn0201_40	29.7286	-93.87	:America/Chicago	USA	knots	\N	323.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass, USCG Base	TX
108795	Sabine Front Range, Point Hunt, NW of (depth 7 ft), Sabine Pass, Louisiana Current	NOS	sn0301_5	29.75806	-93.89	:America/Chicago	USA	knots	166	335	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 70.5 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Front Range, Point Hunt, NW of	LA
108796	Sabine Front Range, Point Hunt, NW of (depth 136 ft), Sabine Pass, Louisiana Current	NOS	sn0301_10	29.75806	-93.89	:America/Chicago	USA	knots	\N	334.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Front Range, Point Hunt, NW of	LA
108797	Sabine Front Range, Point Hunt, NW of (depth 202 ft), Sabine Pass, Louisiana Current	NOS	sn0301_15	29.75806	-93.89	:America/Chicago	USA	knots	\N	328.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.062	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Front Range, Point Hunt, NW of	LA
108798	Rainbow Bridge (depth 71 ft), Sabine Pass, Texas Current	NOS	sn0501_5	29.98111	-93.87111	:America/Chicago	USA	knots	\N	281.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rainbow Bridge	TX
108799	Rainbow Bridge (depth 12 ft), Sabine Pass, Texas Current	NOS	sn0501_17	29.98111	-93.87111	:America/Chicago	USA	knots	108	285	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 228.0 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rainbow Bridge	TX
108800	Rainbow Bridge (depth 307 ft), Sabine Pass, Texas Current	NOS	sn0501_23	29.98111	-93.87111	:America/Chicago	USA	knots	\N	287.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.192	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rainbow Bridge	TX
108801	Port Arthur (depth 16 ft), Sabine Pass, Texas Current	NOS	sn0701_20	29.86671	-93.93111	:America/Chicago	USA	knots	210	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 267.4 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Arthur	TX
108814	Eastport, Friar Roads, Maine Current	NOS	ACT0091_1	44.9	-66.98333	:America/New_York	USA	knots	40	210	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106547	00:00:00	\N	1.2	00:00:00	\N	1.2	00:00:00	00:00:00	Eastport, Friar Roads	ME
108802	Sabine Pass, Cheniere LNG (depth 412 ft), Louisiana Current	NOS	sn0801_31	29.742399215698242	-93.87370300292969	:America/Chicago	USA	knots	\N	332.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.273	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass, Cheniere LNG	LA
108803	Sabine Pass, Cheniere LNG (depth 504 ft), Louisiana Current	NOS	sn0801_38	29.742399215698242	-93.87370300292969	:America/Chicago	USA	knots	\N	335.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.403	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass, Cheniere LNG	LA
108804	Sabine Pass, Cheniere LNG (depth 8 ft), Louisiana Current	NOS	sn0801_45	29.742399215698242	-93.87370300292969	:America/Chicago	USA	knots	155	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 595.5 ft.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.491	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass, Cheniere LNG	LA
108805	Sunshine Skyway Bridge (depth 36 ft), Tampa Bay, Florida Current	NOS	t01010_3	27.62065	-82.65525	:America/New_York	USA	knots	236	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunshine Skyway Bridge	FL
108806	Sunshine Skyway Bridge (depth 16 ft), Tampa Bay, Florida Current	NOS	t01010_9	27.62065	-82.65525	:America/New_York	USA	knots	238	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunshine Skyway Bridge	FL
108807	Sunshine Skyway Bridge (depth 10 ft), Tampa Bay, Florida Current	NOS	t01010_11	27.62065	-82.65525	:America/New_York	USA	knots	239	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunshine Skyway Bridge	FL
108808	Old Tampa Bay entrance (Port Tampa) (depth 32 ft), Florida Current	NOS	t02010_2	27.86287	-82.55373	:America/New_York	USA	knots	210	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Tampa Bay Entrance (Port Tampa)	FL
108809	Old Tampa Bay entrance (Port Tampa) (depth 16 ft), Florida Current	NOS	t02010_7	27.86287	-82.55373	:America/New_York	USA	knots	211	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Tampa Bay Entrance (Port Tampa)	FL
108810	Old Tampa Bay entrance (Port Tampa) (depth 9 ft), Florida Current	NOS	t02010_9	27.86287	-82.55373	:America/New_York	USA	knots	212	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Tampa Bay Entrance (Port Tampa)	FL
108811	Port Manatee Channel entrance (depth 26 ft), Tampa Bay, Florida Current	NOS	t03010_4	27.66395	-82.59877	:America/New_York	USA	knots	217	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Manatee Channel Entrance	FL
108812	Port Manatee Channel entrance (depth 17 ft), Tampa Bay, Florida Current	NOS	t03010_7	27.66395	-82.59877	:America/New_York	USA	knots	218	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Manatee Channel Entrance	FL
108813	Port Manatee Channel entrance (depth 7 ft), Tampa Bay, Florida Current	NOS	t03010_10	27.66395	-82.59877	:America/New_York	USA	knots	219	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Manatee Channel Entrance	FL
108815	Western Passage, off Kendall Head, Maine Current	NOS	ACT0101_1	44.93167	-67	:America/New_York	USA	knots	142	319	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106547	00:40:00	\N	1.3	00:11:00	\N	1.4	00:27:00	00:13:00	Western Passage, off Kendall Head	ME
108816	Western Passage, off Frost Ledge, Maine Current	NOS	ACT0106_1	44.965	-67.03167	:America/New_York	USA	knots	150	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106547	00:15:00	\N	0.7	00:04:00	\N	0.9	00:33:00	-00:16:00	Western Passage, off Frost Ledge	ME
108817	Pond Point, 7.6 mi SSE of, Maine Current	NOS	ACT0111_1	44.335	-67.50333	:America/New_York	USA	knots	215	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	00:24:00	\N	1.1	00:04:00	\N	0.7	00:03:00	-01:10:00	Pond Point, 7.6 miles SSE of	ME
108818	Moosabec Reach, east end, Maine Current	NOS	ACT0116_1	44.5285	-67.57267	:America/New_York	USA	knots	258	110	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-03:10:00	\N	0.9	-02:44:00	\N	1.5	-02:55:00	-02:50:00	Moosabec Reach, east end	ME
108819	Moosabec Reach, west end, Maine Current	NOS	ACT0121_1	44.52083	-67.65	:America/New_York	USA	knots	253	92	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:15:00	\N	1.1	-01:19:00	\N	1.5	-01:53:00	-01:37:00	Moosabec Reach, west end	ME
108820	Casco Passage, east end, Blue Hill Bay, Maine Current	NOS	ACT0131_1	44.195	-68.465	:America/New_York	USA	knots	284	86	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:29:00	\N	0.6	-01:20:00	\N	1	-01:57:00	-00:39:00	Casco Passage, east end, Blue Hill Bay	ME
108821	Hat Island, SE of, Jericho Bay, Maine Current	NOS	ACT0136_1	44.13333	-68.495	:America/New_York	USA	knots	124	318	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:51:00	\N	1.2	-00:11:00	\N	1.3	-01:12:00	-00:27:00	Hat Island, SE of, Jericho Bay	ME
108822	Clam I., NW of, Deer I. Thorofare (depth 14 ft), Maine Current	NOS	ACT0141_1	44.1645	-68.60383	:America/New_York	USA	knots	199	4	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-02:17:00	\N	0.2	00:09:00	\N	0.3	-02:24:00	-00:34:00	Clam I., NW of, Deer I. Thorofare	ME
108823	Grog Island, E of, Deer Island Thorofare (depth 14 ft), Maine Current	NOS	ACT0146_1	44.162	-68.6205	:America/New_York	USA	knots	235	20	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-03:02:00	\N	0.3	-01:58:00	\N	0.3	-02:26:00	-02:04:00	Grog Island, E of, Deer Island Thorofare	ME
108824	Russ Island, N of, Deer Island Thorofare (depth 14 ft), Maine Current	NOS	ACT0151_1	44.153	-68.64633	:America/New_York	USA	knots	265	74	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-02:47:00	\N	0.6	-01:46:00	\N	0.6	-02:22:00	-02:06:00	Russ Island, N of, Deer Island Thorofare	ME
108825	Isle au Haut, 0.8 mi E of Rich's Pt (depth 11 ft), Maine Current	NOS	ACT0161_1	44.08333	-68.58333	:America/New_York	USA	knots	139	336	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:50:00	\N	1.4	-00:43:00	\N	2.1	-01:03:00	-00:44:00	Isle au Haut, 0.8 mile E of Rich's Pt	ME
108826	Mark Island, north of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0166_1	44.13667	-68.70283	:America/New_York	USA	knots	164	13	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	00:07:00	\N	0.4	-00:37:00	\N	0.4	-00:28:00	-02:04:00	Mark Island, north of	ME
108827	Widow Island-Stimpson Island, between (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0171_1	44.1325	-68.825	:America/New_York	USA	knots	118	302	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:39:00	\N	0.5	-00:25:00	\N	0.9	-00:53:00	00:27:00	Widow Island-Stimpson Island, between	ME
108828	Eagle Island, 0.4 nmi S of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0176_1	44.19383	-68.78217	:America/New_York	USA	knots	147	336	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:17:00	\N	0.9	-00:31:00	\N	1.3	-00:28:00	-01:57:00	Eagle Island, 0.4 nautical mile S of	ME
108829	Burnt Island-Oak Island, between (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0181_1	44.19117	-68.81883	:America/New_York	USA	knots	98	290	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:28:00	\N	1.2	-00:55:00	\N	1	-00:28:00	-01:59:00	Burnt Island-Oak Island, between	ME
108830	Butter I., 0.3 nmi SE of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0186_1	44.22217	-68.77783	:America/New_York	USA	knots	194	50	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:07:00	\N	0.6	-01:50:00	\N	0.4	-02:53:00	-00:02:00	Butter I., 0.3 nautical mile SE of	ME
108831	Bradbury Island, ESE of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0191_1	44.23383	-68.7345	:America/New_York	USA	knots	225	25	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:27:00	\N	0.6	00:07:00	\N	0.7	00:01:00	-00:30:00	Bradbury Island, ESE of	ME
108832	Compass Island, 0.4 nmi ENE of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0196_1	44.21667	-68.8555	:America/New_York	USA	knots	175	15	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:32:00	\N	0.3	-00:58:00	\N	0.4	-01:54:00	-01:02:00	Compass Island, 0.4 nmi. ENE of	ME
108833	Scrag Island, 0.3 nmi SW of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0201_1	44.22217	-68.84367	:America/New_York	USA	knots	197	10	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:26:00	\N	0.3	-00:03:00	\N	0.6	-00:55:00	-00:32:00	Scrag Island, 0.3 nautical mile SW of	ME
108834	Great Spruce Head Island, west of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0206_1	44.23833	-68.83633	:America/New_York	USA	knots	174	3	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:50:00	\N	0.3	-00:30:00	\N	0.4	-01:24:00	-00:03:00	Great Spruce Head Island, west of	ME
108912	Fiddler Ledge, north of, Kennebec River, Maine Current	NOS	ACT0616_1	43.880001068115234	-69.79666900634766	:America/New_York	USA	knots	113	267	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106175	00:08:00	\N	1.26	00:01:00	\N	0.99	00:09:00	-00:24:00	Fiddler Ledge, north of	ME
108835	Pickering Island, south of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0216_1	44.2605	-68.75633	:America/New_York	USA	knots	150	300	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-02:08:00	\N	0.6	-01:13:00	\N	0.9	-02:55:00	-01:33:00	Pickering Island, south of	ME
108836	Little Eaton Island, NNE of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0221_1	44.27417	-68.73117	:America/New_York	USA	knots	106	300	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	00:10:00	\N	0.3	00:36:00	\N	0.6	-00:53:00	00:25:00	Little Eaton Island, NNE of	ME
108837	Hog Island, ESE of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0231_1	44.27533	-68.78117	:America/New_York	USA	knots	180	24	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:22:00	\N	0.5	00:22:00	\N	0.4	-00:23:00	-00:10:00	Hog Island, ESE of	ME
108838	Little Deer I.-Sheep I., between (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0236_1	44.27967	-68.72383	:America/New_York	USA	knots	124	310	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:23:00	\N	0.6	-00:13:00	\N	0.9	-00:23:00	00:56:00	Little Deer I.-Sheep I., between	ME
108839	Swains Ledge, 0.3 nmi SW of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0246_1	44.2855	-68.73117	:America/New_York	USA	knots	170	358	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:38:00	\N	0.4	00:02:00	\N	0.7	-00:56:00	-00:32:00	Swains Ledge, 0.3 nautical mile SW of	ME
108840	Pond Island-Western Island, between (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0251_1	44.293	-68.81667	:America/New_York	USA	knots	172	356	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:05:00	\N	0.6	-00:49:00	\N	0.6	-01:54:00	-01:33:00	Pond Island-Western Island, between	ME
108841	Birch Island, northwest of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0256_1	44.30283	-68.75583	:America/New_York	USA	knots	200	22	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:01:00	\N	0.2	-01:07:00	\N	0.4	-01:54:00	-00:33:00	Birch Island, northwest of	ME
108842	Pumpkin Island, north of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0281_1	44.31333	-68.74033	:America/New_York	USA	knots	90	290	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-02:14:00	\N	0.3	-01:46:00	\N	0.4	-03:24:00	-01:31:00	Pumpkin Island, north of	ME
108843	Islesboro Harbor, NE of, Penobscot Bay (depth 75 ft), Maine Current	NOS	ACT0291_1	44.31617	-68.87967	:America/New_York	USA	knots	166	4	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:56:00	\N	0.3	-00:36:00	\N	0.4	-01:14:00	-01:13:00	Islesboro Harbor, NE of, Penobscot Bay	ME
108844	Islesboro Harbor, NE of, Penobscot Bay (depth 15 ft), Maine Current	NOS	ACT0296_1	44.31717	-68.87783	:America/New_York	USA	knots	154	334	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:54:00	\N	0.3	-00:30:00	\N	0.1	00:16:00	-00:59:00	Islesboro Harbor, NE of, Penobscot Bay	ME
108845	Turtle Head Pt., ESE of, Penobscot Bay (depth 15 ft), Maine Current	NOS	ACT0311_1	44.37617	-68.85467	:America/New_York	USA	knots	171	338	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107054	-01:02:00	\N	0.4	-01:10:00	\N	0.3	-00:36:00	00:24:00	Turtle Head Pt., ESE of, Penobscot Bay	ME
108846	Turtle Head Pt., ESE of, Penobscot Bay (depth 40 ft), Maine Current	NOS	ACT0311_2	44.37617	-68.85467	:America/New_York	USA	knots	155	319	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107054	-00:32:00	\N	0.4	-01:18:00	\N	0.2	-00:55:00	-00:31:00	Turtle Head Pt., ESE of, Penobscot Bay	ME
108847	Dice Head, west of, Penobscot Bay (depth 15 ft), Maine Current	NOS	ACT0321_1	44.3795	-68.84533	:America/New_York	USA	knots	198	28	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107054	-00:48:00	\N	0.3	-01:23:00	\N	0.2	-01:52:00	-00:27:00	Dice Head, west of, Penobscot Bay	ME
108848	Dice Head, west of, Penobscot Bay (depth 58 ft), Maine Current	NOS	ACT0321_2	44.3795	-68.84533	:America/New_York	USA	knots	178	334	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107054	00:34:00	\N	0.3	-00:39:00	\N	0.2	-00:09:00	00:25:00	Dice Head, west of, Penobscot Bay	ME
108849	Dice Head, west of, Penobscot Bay (depth 96 ft), Maine Current	NOS	ACT0321_3	44.3795	-68.84533	:America/New_York	USA	knots	135	312	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107054	00:24:00	\N	0.3	-00:32:00	\N	0.3	00:37:00	00:34:00	Dice Head, west of, Penobscot Bay	ME
108913	Doubling Point, south of, Kennebec River, Maine Current	NOS	ACT0621_1	43.880001068115234	-69.80667114257812	:America/New_York	USA	knots	127	300	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106175	00:13:00	\N	1.46	-00:22:00	\N	1.35	-00:10:00	-00:23:00	Doubling Point, south of	ME
108850	Jones Point, Bagaduce River (depth 15 ft), Maine Current	NOS	ACT0331_1	44.42583	-68.75833	:America/New_York	USA	knots	237	53	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107054	00:21:00	\N	2.1	-00:03:00	\N	1.8	-00:13:00	00:21:00	Jones Point, Bagaduce River	ME
108851	Verona I., N of, Easter Ch., Penobscot R (depth 10 ft), Maine Current	NOS	ACT0346_1	44.56783	-68.78117	:America/New_York	USA	knots	116	273	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107054	00:18:00	\N	0.9	00:07:00	\N	0.3	02:18:00	-00:54:00	Verona I., N of, Easter Ch., Penobscot R	ME
108852	Oak Point, Penobscot River (depth 15 ft), Maine Current	NOS	ACT0371_1	44.66833	-68.813	:America/New_York	USA	knots	219	26	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107054	01:09:00	\N	0.9	00:16:00	\N	0.6	00:05:00	00:21:00	Oak Point, Penobscot River	ME
108853	Oak Point, Penobscot River (depth 35 ft), Maine Current	NOS	ACT0371_2	44.66833	-68.813	:America/New_York	USA	knots	258	337	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107054	-00:50:00	\N	0.9	00:10:00	\N	0.7	-00:53:00	00:01:00	Oak Point, Penobscot River	ME
108854	Andrews Island, ESE of (depth 15 ft), West Penobscot Bay, Maine Current	NOS	ACT0381_1	43.99417	-69.013	:America/New_York	USA	knots	155	11	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:45:00	\N	0.6	-00:20:00	\N	0.6	-00:30:00	-00:32:00	Andrews Island, ESE of	ME
108855	Andrews Island, ESE of (depth 75 ft), West Penobscot Bay, Maine Current	NOS	ACT0381_2	43.99417	-69.013	:America/New_York	USA	knots	188	342	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:38:00	\N	0.6	-00:32:00	\N	1.2	-01:25:00	00:03:00	Andrews Island, ESE of	ME
108856	Little Hurricane Island, southwest of (depth 15 ft), West Penobscot Bay, Maine Current	NOS	ACT0386_1	44.023	-68.91783	:America/New_York	USA	knots	157	331	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	00:16:00	\N	0.7	-00:26:00	\N	0.7	-00:15:00	00:05:00	Little Hurricane Island, southwest of	ME
108857	Little Hurricane Island, southwest of (depth 40 ft), West Penobscot Bay, Maine Current	NOS	ACT0386_2	44.023	-68.91783	:America/New_York	USA	knots	125	300	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:06:00	\N	0.6	-00:11:00	\N	0.9	-00:28:00	-00:04:00	Little Hurricane Island, southwest of	ME
108858	Heron Neck, Green Island (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0391_1	44.02967	-68.873	:America/New_York	USA	knots	165	344	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:14:00	\N	0.6	-00:35:00	\N	1.5	-01:57:00	-00:35:00	Heron Neck, Green Island	ME
108859	Triangle Ledge, SSE of (depth 15 ft), Isle au Haut Bay, Maine Current	NOS	ACT0401_1	44.04117	-68.758	:America/New_York	USA	knots	197	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	00:12:00	\N	0.9	00:07:00	\N	1	00:04:00	-00:03:00	Triangle Ledge, SSE of	ME
108860	Triangle Ledge, SSE of (depth 40 ft), Isle au Haut Bay, Maine Current	NOS	ACT0401_2	44.04117	-68.758	:America/New_York	USA	knots	180	317	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:46:00	\N	0.6	-00:15:00	\N	0.9	-01:30:00	-00:09:00	Triangle Ledge, SSE of	ME
108861	Moore Harbor, W of (depth 15 ft), Isle au Haut Bay, Maine Current	NOS	ACT0406_1	44.04217	-68.6925	:America/New_York	USA	knots	135	344	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:09:00	\N	1	00:44:00	\N	0.6	-00:10:00	00:07:00	Moore Harbor, W of	ME
108862	Moore Harbor, W of (depth 75 ft), Isle au Haut Bay, Maine Current	NOS	ACT0406_2	44.04217	-68.6925	:America/New_York	USA	knots	165	337	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:25:00	\N	0.5	-00:31:00	\N	0.9	-01:43:00	-00:17:00	Moore Harbor, W of	ME
108863	Moore Harbor, W of (depth 120 ft), Isle au Haut Bay, Maine Current	NOS	ACT0406_3	44.04217	-68.6925	:America/New_York	USA	knots	215	345	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:50:00	\N	0.3	-00:19:00	\N	1	-02:44:00	-01:02:00	Moore Harbor, W of	ME
108864	The Reach, NNE of, Green Island (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0411_1	44.04283	-68.85967	:America/New_York	USA	knots	111	284	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-02:26:00	\N	0.4	-00:46:00	\N	0.6	-03:33:00	-01:32:00	The Reach, NNE of, Green Island	ME
108865	White Islands, northeast of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0416_1	44.05	-68.90667	:America/New_York	USA	knots	165	322	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:39:00	\N	0.6	-01:54:00	\N	0.6	-01:58:00	-01:32:00	White Islands, northeast of	ME
108866	Fisherman Island Passage (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0421_1	44.052	-69.045	:America/New_York	USA	knots	240	53	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:59:00	\N	0.6	-02:13:00	\N	0.9	-02:54:00	-02:03:00	Fisherman Island Passage	ME
108867	Crotch Island, east of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0426_1	44.06033	-68.90717	:America/New_York	USA	knots	163	343	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:40:00	\N	1.8	-00:31:00	\N	2.8	-00:59:00	-00:58:00	Crotch Island, east of	ME
108868	Laireys Island, south of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0431_1	44.06033	-68.89633	:America/New_York	USA	knots	155	335	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:22:00	\N	0.8	00:06:00	\N	0.6	-00:58:00	-00:28:00	Laireys Island, south of	ME
108869	Sheep Island (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0436_1	44.06467	-69.05783	:America/New_York	USA	knots	220	23	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:47:00	\N	0.7	-00:55:00	\N	0.7	-02:54:00	-01:34:00	Sheep Island	ME
108870	Leadbetter I., SSW of southern tip (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0441_1	44.06783	-68.89833	:America/New_York	USA	knots	126	320	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:03:00	\N	1.2	-00:15:00	\N	2.1	-00:53:00	-00:05:00	Leadbetter I., SSW of southern tip	ME
108871	Leadbetter Island, E of southern tip (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0446_1	44.06917	-68.89367	:America/New_York	USA	knots	175	0	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	00:16:00	\N	0.6	-00:19:00	\N	0.6	-00:28:00	01:00:00	Leadbetter Island, E of southern tip	ME
108872	Leadbetter Island, northwest tip of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0451_1	44.08383	-68.91117	:America/New_York	USA	knots	214	16	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:43:00	\N	0.9	-00:17:00	\N	1.2	-00:58:00	-00:30:00	Leadbetter Island, northwest tip of	ME
108873	Dodge Point-Monroe Island, between (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0456_1	44.08533	-69.04367	:America/New_York	USA	knots	205	15	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-02:38:00	\N	0.5	-01:19:00	\N	0.6	-03:53:00	-02:32:00	Dodge Point-Monroe Island, between	ME
108874	Dogfish Island, NNE of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0461_1	44.092	-68.91333	:America/New_York	USA	knots	147	325	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:37:00	\N	0.4	-02:03:00	\N	0.7	-02:24:00	-02:32:00	Dogfish Island, NNE of	ME
108875	Rockland Harbor Breakwater (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0466_1	44.10217	-69.07783	:America/New_York	USA	knots	97	315	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:10:00	\N	0.4	-00:06:00	\N	0.4	-01:28:00	-00:41:00	Rockland Harbor Breakwater	ME
108876	Browns Head, Vinalhaven Island, NNW of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0471_1	44.112998962402344	-68.91217041015625	:America/New_York	USA	knots	221	16	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:27:00	\N	0.2	-00:58:00	\N	0.3	-01:58:00	-00:32:00	Browns Head, Vinalhaven Island, NNW of	ME
108877	Crabtree Pt., North Haven I., NNE of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0476_1	44.115	-68.92367	:America/New_York	USA	knots	228	3	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:32:00	\N	0.2	-00:54:00	\N	0.4	-00:53:00	-00:32:00	Crabtree Pt., North Haven I., NNE of	ME
108878	Fox Island Thorofare (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0481_1	44.127	-68.893	:America/New_York	USA	knots	278	70	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-02:56:00	\N	0.4	-02:17:00	\N	0.3	-03:23:00	-03:02:00	Fox Island Thorofare	ME
108879	Mark Island, 0.3 nmi SSE of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0486_1	44.16667	-68.9805	:America/New_York	USA	knots	246	44	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:57:00	\N	0.5	-01:07:00	\N	0.6	-01:51:00	-01:36:00	Mark Island, 0.3 nmi., SSE of	ME
108880	Saddle Island, northwest of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0491_1	44.18083	-68.955	:America/New_York	USA	knots	225	10	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:44:00	\N	0.4	-02:07:00	\N	0.4	-03:53:00	-03:33:00	Saddle Island, northwest of	ME
109340	Jones Inlet, Long Island, New York Current	NOS	ACT3546_1	40.59170150756836	-73.56670379638672	:America/New_York	USA	knots	217	35	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-01:04:00	\N	1.63	-00:49:00	\N	2.33	-00:52:00	-00:51:00	Jones Inlet	NY
108881	Lasell Island, SSW of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0501_1	44.18667	-68.947	:America/New_York	USA	knots	217	22	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:17:00	\N	0.4	-01:07:00	\N	0.6	-01:57:00	-02:31:00	Lasell Island, SSW of	ME
108882	East Goose Rock, NNE of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0506_1	44.1895	-68.968	:America/New_York	USA	knots	210	0	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-02:44:00	\N	0.4	-02:19:00	\N	0.6	-03:55:00	-03:34:00	East Goose Rock, NNE of	ME
108883	Camden Harbor entrance (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0511_1	44.20283	-69.04667	:America/New_York	USA	knots	190	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:27:00	\N	0.3	-03:42:00	\N	0.3	-02:54:00	-02:03:00	Camden Harbor Entrance	ME
108884	Ensign Island, SSE of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0516_1	44.22333	-68.95867	:America/New_York	USA	knots	220	22	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:56:00	\N	0.3	-00:36:00	\N	0.4	-01:40:00	00:55:00	Ensign Island, SSE of	ME
108885	Warren Island, northwest of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0521_1	44.27583	-68.95367	:America/New_York	USA	knots	248	36	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:44:00	\N	0.3	-00:28:00	\N	0.7	-02:27:00	-01:00:00	Warren Island, northwest of	ME
108886	Ducktrap Harbor, northeast of (depth 15 ft), West Penobscot Bay, Maine Current	NOS	ACT0526_1	44.3	-68.93967	:America/New_York	USA	knots	185	355	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:12:00	\N	0.4	-00:34:00	\N	0.7	-01:17:00	-01:00:00	Ducktrap Harbor, northeast of	ME
108887	Ducktrap Harbor, northeast of (depth 40 ft), West Penobscot Bay, Maine Current	NOS	ACT0526_2	44.3	-68.93967	:America/New_York	USA	knots	237	14	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:20:00	\N	0.3	-00:56:00	\N	0.6	-02:39:00	-01:24:00	Ducktrap Harbor, northeast of	ME
108888	Ducktrap Harbor, NNE of (depth 90 ft), West Penobscot Bay, Maine Current	NOS	ACT0531_1	44.3045	-68.95583	:America/New_York	USA	knots	203	14	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:04:00	\N	0.3	-00:04:00	\N	0.6	-01:09:00	00:04:00	Ducktrap Harbor, NNE of	ME
108889	Ducktrap Harbor, NNE of (depth 160 ft), West Penobscot Bay, Maine Current	NOS	ACT0531_2	44.3045	-68.95583	:America/New_York	USA	knots	233	38	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	00:02:00	\N	0.3	-00:05:00	\N	0.7	-01:12:00	00:13:00	Ducktrap Harbor, NNE of	ME
108890	Ducktrap Harbor, NNE of (depth 15 ft), West Penobscot Bay, Maine Current	NOS	ACT0536_1	44.305	-68.95917	:America/New_York	USA	knots	202	58	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:06:00	\N	0.5	00:11:00	\N	0.6	00:23:00	-00:33:00	Ducktrap Harbor, NNE of	ME
108891	Ducktrap Harbor, NNE of (depth 130 ft), West Penobscot Bay, Maine Current	NOS	ACT0536_2	44.305	-68.95917	:America/New_York	USA	knots	193	13	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:42:00	\N	0.5	-00:28:00	\N	0.9	-01:24:00	-00:25:00	Ducktrap Harbor, NNE of	ME
108892	Flat Island, SSW of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0541_1	44.31383	-68.92417	:America/New_York	USA	knots	230	45	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:38:00	\N	0.4	00:01:00	\N	0.6	-01:23:00	-00:32:00	Flat Island, SSW of	ME
108893	Head of the Cape, 0.8 nmi W, of Penobscot Bay (depth 15 ft), Maine Current	NOS	ACT0546_1	44.32083	-68.84667	:America/New_York	USA	knots	125	325	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	00:01:00	\N	0.4	00:10:00	\N	0.6	-00:34:00	-00:01:00	Head of the Cape, 0.8 nmi. W, of Penobscot Bay	ME
108894	Head of the Cape, 0.8 nmi W, of Penobscot Bay (depth 130 ft), Maine Current	NOS	ACT0546_2	44.32083	-68.84667	:America/New_York	USA	knots	166	15	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:22:00	\N	0.3	-00:35:00	\N	0.6	-01:24:00	-00:18:00	Head of the Cape, 0.8 nmi. W, of Penobscot Bay	ME
108895	Head of the Cape, NNW of, Penobscot Bay (depth 15 ft), Maine Current	NOS	ACT0551_1	44.31783	-68.83617	:America/New_York	USA	knots	163	332	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:24:00	\N	0.4	-00:15:00	\N	0.9	-00:56:00	00:05:00	Head of the Cape, NNW of, Penobscot Bay	ME
109358	New Hamburg, Hudson River (midchannel), New York Current	NOS	ACT3741_1	41.58333	-73.95	:America/New_York	USA	knots	\N	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106683	02:33:00	\N	0.4	02:40:00	\N	0.6	02:48:00	02:24:00	New Hamburg	NY
108896	Head of the Cape, NNW of, Penobscot Bay (depth 30 ft), Maine Current	NOS	ACT0551_2	44.31783	-68.83617	:America/New_York	USA	knots	176	356	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:30:00	\N	0.3	-00:23:00	\N	0.7	-01:32:00	-00:01:00	Head of the Cape, NNW of, Penobscot Bay	ME
108897	Head of the Cape, NNW of, Penobscot Bay (depth 130 ft), Maine Current	NOS	ACT0551_3	44.31783	-68.83617	:America/New_York	USA	knots	172	353	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:30:00	\N	0.4	-00:56:00	\N	0.4	-01:09:00	-00:48:00	Head of the Cape, NNW of, Penobscot Bay	ME
108898	Ram Island, west of, West Penobscot Bay (depth 14 ft), Maine Current	NOS	ACT0556_1	44.35467	-68.91583	:America/New_York	USA	knots	189	4	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:47:00	\N	0.3	-01:31:00	\N	0.6	-03:53:00	-02:30:00	Ram Island, west of, West Penobscot Bay	ME
108899	Temple Heights, NE of, W Penobscot Bay (depth 15 ft), Maine Current	NOS	ACT0561_1	44.35633	-68.92217	:America/New_York	USA	knots	189	0	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:49:00	\N	0.4	-00:59:00	\N	0.6	-01:12:00	-01:40:00	Temple Heights, NE of, W Penobscot Bay	ME
108900	Temple Heights, NE of, W Penobscot Bay (depth 65 ft), Maine Current	NOS	ACT0561_2	44.35633	-68.92217	:America/New_York	USA	knots	175	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-01:04:00	\N	0.3	-00:48:00	\N	0.6	-01:56:00	-01:13:00	Temple Heights, NE of, W Penobscot Bay	ME
108901	Temple Heights, NNE of, W Penobscot Bay (depth 15 ft), Maine Current	NOS	ACT0566_1	44.3575	-68.94367	:America/New_York	USA	knots	175	5	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:36:00	\N	0.6	00:03:00	\N	0.9	-00:44:00	-00:12:00	Temple Heights, NNE of, W Penobscot Bay	ME
108902	Temple Heights, NNE of, W Penobscot Bay (depth 30 ft), Maine Current	NOS	ACT0566_2	44.3575	-68.94367	:America/New_York	USA	knots	188	344	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:14:00	\N	0.4	-00:02:00	\N	0.9	-01:01:00	00:08:00	Temple Heights, NNE of, W Penobscot Bay	ME
108903	Temple Heights, NNE of, W Penobscot Bay (depth 50 ft), Maine Current	NOS	ACT0566_3	44.3575	-68.94367	:America/New_York	USA	knots	164	333	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	-00:10:00	\N	0.5	-00:06:00	\N	0.7	-00:38:00	-00:24:00	Temple Heights, NNE of, W Penobscot Bay	ME
108904	Damariscotta River, off Cavis Point, Maine Current	NOS	ACT0576_1	43.875	-69.58332824707031	:America/New_York	USA	knots	215	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106175	-01:58:00	\N	0.49	-01:45:00	\N	0.31	-01:27:00	-02:10:00	Damariscotta River, off Cavis Point	ME
108905	Sheepscot River, off Barter Island, Maine Current	NOS	ACT0581_1	43.900001525878906	-69.6916732788086	:America/New_York	USA	knots	200	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106175	-01:13:00	\N	0.54	-02:13:00	\N	0.42	-01:26:00	-02:01:00	Sheepscot River, off Barter Island	ME
108906	Lowe Point, NE of, Sasanoa River, Maine Current	NOS	ACT0586_1	43.85166931152344	-69.72167205810547	:America/New_York	USA	knots	152	327	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106175	-01:07:00	\N	0.87	-01:02:00	\N	0.88	-01:26:00	-01:32:00	Lowe Point, NE of, Sasanoa River	ME
108907	Lower Hell Gate, Knubble Bay, Maine Current	NOS	ACT0591_1	43.876670837402344	-69.7300033569336	:America/New_York	USA	knots	155	290	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106175	-00:34:00	\N	1.7	-00:34:00	\N	1.56	-01:01:00	-01:32:00	Lower Hell Gate, Knubble Bay	ME
108908	Upper Hell Gate, Sasanoa River, Maine Current	NOS	ACT0596_1	43.89500045776367	-69.77166748046875	:America/New_York	USA	knots	142	307	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106175	01:23:00	\N	0.4	01:37:00	\N	0.52	02:53:00	00:34:00	Upper Hell Gate, Sasanoa River	ME
108909	Hunniwell Point, northeast of, Kennebec River, Maine Current	NOS	ACT0601_1	43.75667190551758	-69.78166961669922	:America/New_York	USA	knots	151	332	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106175	-00:16:00	\N	1.41	-00:59:00	\N	1.25	-00:33:00	-00:41:00	Hunniwell Point, northeast of	ME
108910	Bald Head, 0.3 mi southwest of, Kennebec River, Maine Current	NOS	ACT0606_1	43.80167007446289	-69.79332733154297	:America/New_York	USA	knots	153	321	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106175	-00:17:00	\N	1.12	-00:43:00	\N	0.83	-00:15:00	-00:50:00	Bald Head, 0.3 mile southwest of	ME
108911	Bluff Head, west of, Kennebec River, Maine Current	NOS	ACT0611_1	43.85499954223633	-69.79666900634766	:America/New_York	USA	knots	184	14	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106175	-00:16:00	\N	1.65	-00:18:00	\N	1.2	-00:05:00	-00:20:00	Bluff Head, west of	ME
108914	Lincoln Ledge, east of, Kennebec River, Maine Current	NOS	ACT0626_1	43.89667	-69.81	:America/New_York	USA	knots	174	359	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106127	01:31:00	\N	2.6	01:49:00	\N	2.8	01:42:00	01:48:00	Lincoln Ledge, east of	ME
108915	Odiornes Point, NNE of (depth 15 ft), Portsmouth Harbor, New Hampshire Current	NOS	ACT0686_1	43.04333	-70.705	:America/New_York	USA	knots	183	339	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107084	02:13:00	\N	0.6	01:54:00	\N	0.4	01:23:00	00:41:00	Odiornes Point, NNE of	NH
108916	Odiornes Point, northeast of (depth 15 ft), Portsmouth Harbor, New Hampshire Current	NOS	ACT0691_1	43.05	-70.70167	:America/New_York	USA	knots	156	320	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107084	01:03:00	\N	0.7	00:14:00	\N	0.5	00:09:00	00:29:00	Odiornes Point, northeast of	NH
108917	Whaleback Reef, west of (depth 15 ft), Portsmouth Harbor, New Hampshire Current	NOS	ACT0706_1	43.05833	-70.7045	:America/New_York	USA	knots	144	340	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107084	00:10:00	\N	1	00:27:00	\N	0.6	00:09:00	00:03:00	Whaleback Reef, west of	NH
108918	Wood Island, northwest of (depth 15 ft), Portsmouth Harbor, New Hampshire Current	NOS	ACT0716_1	43.06583	-70.705	:America/New_York	USA	knots	199	358	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107084	-00:44:00	\N	0.8	00:09:00	\N	1	00:12:00	00:23:00	Wood Island, northwest of	NH
108919	Salamander Point, north of (depth 15 ft), Portsmouth Harbor, Maine Current	NOS	ACT0726_1	43.07633	-70.717	:America/New_York	USA	knots	91	257	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107084	00:45:00	\N	0.6	00:44:00	\N	1.2	00:24:00	00:26:00	Salamander Point, north of	ME
108920	Clark Island, south of (depth 15 ft), Portsmouth Harbor, New Hampshire Current	NOS	ACT0731_1	43.07383	-70.72467	:America/New_York	USA	knots	85	270	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107084	00:31:00	\N	1.5	00:31:00	\N	1.4	00:33:00	00:28:00	Clark Island, south of	NH
108921	Clark Island, southwest of (depth 15 ft), Portsmouth Harbor, Maine Current	NOS	ACT0736_1	43.075	-70.72783	:America/New_York	USA	knots	70	263	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107084	-00:06:00	\N	0.6	-00:05:00	\N	0.6	00:31:00	00:26:00	Clark Island, southwest of	ME
108922	Henderson Point, SSW of (depth 15 ft), Portsmouth Harbor, New Hampshire Current	NOS	ACT0741_1	43.07333	-70.73867	:America/New_York	USA	knots	133	306	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107084	00:36:00	\N	1.2	01:20:00	\N	1.4	00:14:00	00:07:00	Henderson Point, SSW of	NH
108923	Shapleigh Island Bridge, south of, Portsmouth Harbor, New Hampshire Current	NOS	ACT0751_1	43.06967	-70.73833	:America/New_York	USA	knots	348	178	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107084	-00:37:00	\N	0.4	-00:18:00	\N	0.7	-00:40:00	-01:01:00	Shapleigh Island Bridge, south of	NH
108924	Pierces Island, northeast of (depth 15 ft), Portsmouth Harbor, New Hampshire Current	NOS	ACT0756_1	43.07583	-70.74133	:America/New_York	USA	knots	144	325	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107084	-00:21:00	\N	0.8	00:34:00	\N	2.4	-00:08:00	00:31:00	Pierces Island, northeast of	NH
108925	Dover Point, west of (depth 15 ft), New Hampshire Current	NOS	ACT0791_1	43.11917	-70.83717	:America/New_York	USA	knots	119	283	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107084	-00:02:00	\N	0.4	00:18:00	\N	1.2	00:07:00	00:23:00	Dover Point, west of	NH
108926	Goat Island, north of (depth 15 ft), New Hampshire Current	NOS	ACT0796_1	43.127	-70.85617	:America/New_York	USA	knots	77	272	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107084	00:49:00	\N	0.8	01:05:00	\N	1	00:52:00	00:20:00	Goat Island, north of	NH
108927	Goat Island and Fox Point, between (depth 15 ft), New Hampshire Current	NOS	ACT0801_1	43.12283	-70.857	:America/New_York	USA	knots	142	303	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107084	02:30:00	\N	0.4	01:39:00	\N	1	00:34:00	00:51:00	Goat Island and Fox Point, between	NH
108928	Knight Hill Township, west of (depth 15 ft), New Hampshire Current	NOS	ACT0806_1	43.10783	-70.85833	:America/New_York	USA	knots	15	205	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107084	00:21:00	\N	0.5	00:41:00	\N	0.6	00:39:00	00:54:00	Knight Hill Township, west of	NH
108929	Merrimack River entrance, Massachusetts Current	NOS	ACT0816_1	42.81833	-70.81	:America/New_York	USA	knots	105	285	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:46:00	\N	1.1	01:20:00	\N	1.7	00:55:00	01:08:00	Merrimack River entrance	MA
108930	Newburyport, Merrimack River, Massachusetts Current	NOS	ACT0821_1	42.81333	-70.86833	:America/New_York	USA	knots	98	288	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:23:00	\N	1.1	01:53:00	\N	1.2	01:19:00	01:42:00	Newburyport, Merrimack River	MA
108931	Plum Island Sound entrance, Massachusetts Current	NOS	ACT0826_1	42.705	-70.78833	:America/New_York	USA	knots	184	316	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:19:00	\N	1.2	00:55:00	\N	1.2	00:27:00	00:43:00	Plum Island Sound entrance	MA
108932	Annisquam Harbor Light, Massachusetts Current	NOS	ACT0831_1	42.66833	-70.685	:America/New_York	USA	knots	13	200	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:09:00	\N	1.1	00:54:00	\N	0.8	00:33:00	00:53:00	Annisquam Harbor Light	MA
108933	Gloucester Harbor entrance, Massachusetts Current	NOS	ACT0836_1	42.58167	-70.675	:America/New_York	USA	knots	195	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:48:00	\N	0.2	00:06:00	\N	0.2	-00:37:00	-00:34:00	Gloucester Harbor entrance	MA
108934	Blynman Canal ent., Gloucester Harbor, Massachusetts Current	NOS	ACT0841_1	42.61	-70.67333	:America/New_York	USA	knots	130	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:51:00	\N	2.7	00:10:00	\N	2.3	-00:15:00	-00:20:00	Blynman Canal ent., Gloucester Harbor	MA
108935	Nahant, 1.8 nmi NE of East Point (depth 10 ft), Massachusetts Current	NOS	ACT0906_1	42.43333	-70.867	:America/New_York	USA	knots	144	252	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:48:00	\N	0.1	00:54:00	\N	0.5	00:23:00	00:10:00	Nahant, 1.8 n.mi. NE of East Point	MA
108936	Nahant, 1.8 nmi NE of East Point (depth 45 ft), Massachusetts Current	NOS	ACT0906_2	42.43333	-70.867	:America/New_York	USA	knots	70	250	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:43:00	\N	0.2	01:09:00	\N	0.2	-00:30:00	01:09:00	Nahant, 1.8 n.mi. NE of East Point	MA
108937	Nahant, 1.8 nmi NE of East Point (depth 80 ft), Massachusetts Current	NOS	ACT0906_3	42.43333	-70.867	:America/New_York	USA	knots	77	238	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:43:00	\N	0.2	01:09:00	\N	0.2	-00:34:00	01:10:00	Nahant, 1.8 n.mi. NE of East Point	MA
108938	Nahant, 0.4 nmi east of East Point (depth 15 ft), Massachusetts Current	NOS	ACT0911_1	42.4205	-70.89383	:America/New_York	USA	knots	45	205	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:10:00	\N	0.5	-00:36:00	\N	0.4	-00:05:00	00:10:00	Nahant, 0.4 n.mi. east of East Point	MA
108939	Nahant, 0.4 nmi east of East Point (depth 25 ft), Massachusetts Current	NOS	ACT0911_2	42.4205	-70.89383	:America/New_York	USA	knots	27	198	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:17:00	\N	0.4	-00:21:00	\N	0.3	-00:06:00	00:03:00	Nahant, 0.4 n.mi. east of East Point	MA
108940	Nahant, 1 nmi SE of East Point (depth 45 ft), Massachusetts Current	NOS	ACT0916_1	42.39717	-70.85283	:America/New_York	USA	knots	74	253	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:13:00	\N	0.2	00:01:00	\N	0.2	-00:31:00	00:14:00	Nahant, 1 n.mi. SE of East Point	MA
108941	Nahant, 1 nmi SE of East Point (depth 70 ft), Massachusetts Current	NOS	ACT0916_2	42.39717	-70.85283	:America/New_York	USA	knots	90	261	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:02:00	\N	0.2	01:09:00	\N	0.2	-00:05:00	01:08:00	Nahant, 1 n.mi. SE of East Point	MA
108942	Pea Island, 0.4 nmi southeast of (depth 15 ft), Massachusetts Current	NOS	ACT0921_1	42.4105	-70.90217	:America/New_York	USA	knots	63	239	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:13:00	\N	0.4	01:00:00	\N	0.4	00:44:00	00:37:00	Pea Island, 0.4 n.mi. southeast of	MA
108943	Pea Island, 0.4 nmi southeast of (depth 25 ft), Massachusetts Current	NOS	ACT0921_2	42.4105	-70.90217	:America/New_York	USA	knots	48	224	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:17:00	\N	0.3	00:39:00	\N	0.4	00:25:00	00:52:00	Pea Island, 0.4 n.mi. southeast of	MA
108944	Pea Island, 0.4 nmi southeast of (depth 65 ft), Massachusetts Current	NOS	ACT0921_3	42.4105	-70.90217	:America/New_York	USA	knots	35	271	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:43:00	\N	0.3	-00:54:00	\N	0.3	-00:46:00	00:09:00	Pea Island, 0.4 n.mi. southeast of	MA
108945	Bass Point, 1.2 nmi southeast of (depth 10 ft), Massachusetts Current	NOS	ACT0926_1	42.402	-70.91783	:America/New_York	USA	knots	66	259	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:26:00	\N	0.6	01:25:00	\N	0.6	-00:31:00	00:53:00	Bass Point, 1.2 n.mi. southeast of	MA
108946	Bass Point, 1.2 nmi southeast of (depth 45 ft), Massachusetts Current	NOS	ACT0926_2	42.402	-70.91783	:America/New_York	USA	knots	86	251	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:41:00	\N	0.2	-00:05:00	\N	0.3	-00:38:00	00:47:00	Bass Point, 1.2 n.mi. southeast of	MA
108947	Bass Point, 1.2 nmi southeast of (depth 60 ft), Massachusetts Current	NOS	ACT0926_3	42.402	-70.91783	:America/New_York	USA	knots	91	250	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:11:00	\N	0.2	-00:05:00	\N	0.2	-00:38:00	00:26:00	Bass Point, 1.2 n.mi. southeast of	MA
108948	Little Nahant Cupola, 0.6 nmi west of (depth 10 ft), Massachusetts Current	NOS	ACT0941_1	42.43117	-70.94717	:America/New_York	USA	knots	219	33	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:34:00	\N	0.4	-00:21:00	\N	0.3	-00:11:00	01:27:00	Little Nahant Cupola, 0.6 n.mi. west of	MA
108949	Sand Point, Black Marsh Channel (depth 10 ft), Massachusetts Current	NOS	ACT0946_1	42.443	-70.942	:America/New_York	USA	knots	203	13	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:15:00	\N	0.4	-00:12:00	\N	0.4	-00:05:00	01:15:00	Sand Point, Black Marsh Channel	MA
108950	Lynn Harbor (depth 10 ft), Massachusetts Current	NOS	ACT0951_1	42.4545	-70.94633	:America/New_York	USA	knots	90	274	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	01:12:00	\N	0.2	-00:21:00	\N	0.2	00:20:00	02:30:00	Lynn Harbor	MA
108951	Point of Pines, 0.5 nmi south of (depth 6 ft), Massachusetts Current	NOS	ACT0956_1	42.43283	-70.95883	:America/New_York	USA	knots	198	9	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:29:00	\N	0.5	00:24:00	\N	0.4	-00:04:00	01:03:00	Point of Pines, 0.5 n.mi. south of	MA
108952	Point of Pines, 0.1 nmi northeast of (depth 6 ft), Massachusetts Current	NOS	ACT0961_1	42.442	-70.96033	:America/New_York	USA	knots	131	296	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:22:00	\N	1	00:24:00	\N	0.7	00:34:00	00:45:00	Point of Pines, 0.1 n.mi. northeast of	MA
108953	Finn's Ledge Bell, 0.2 nmi west of (depth 10 ft), Massachusetts Current	NOS	ACT0966_1	42.3695	-70.92367	:America/New_York	USA	knots	35	226	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:14:00	\N	0.6	01:10:00	\N	0.4	-00:10:00	00:21:00	Finn's Ledge Bell, 0.2 n.mi. west of	MA
108954	Finn's Ledge Bell, 0.2 nmi west of (depth 25 ft), Massachusetts Current	NOS	ACT0966_2	42.3695	-70.92367	:America/New_York	USA	knots	33	229	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:16:00	\N	0.4	00:55:00	\N	0.3	-00:20:00	00:31:00	Finn's Ledge Bell, 0.2 n.mi. west of	MA
108955	Winthrop Head, 1.1 nmi east of (depth 10 ft), Massachusetts Current	NOS	ACT0971_1	42.3655	-70.942	:America/New_York	USA	knots	19	205	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:58:00	\N	0.3	00:24:00	\N	0.4	-01:21:00	00:26:00	Winthrop Head, 1.1 n.mi. east of	MA
108956	The Graves, 0.3 nmi SSE of (depth 10 ft), Massachusetts Current	NOS	ACT1026_1	42.36	-70.86667	:America/New_York	USA	knots	103	227	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:07:00	\N	0.5	01:13:00	\N	0.5	00:07:00	01:16:00	The Graves, 0.3 n.mi. SSE of	MA
108957	The Graves, 0.3 nmi SSE of (depth 45 ft), Massachusetts Current	NOS	ACT1026_2	42.36	-70.86667	:America/New_York	USA	knots	85	262	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:10:00	\N	0.4	-00:47:00	\N	0.3	-00:46:00	-00:15:00	The Graves, 0.3 n.mi. SSE of	MA
108958	The Graves, 0.3 nmi SSE of (depth 60 ft), Massachusetts Current	NOS	ACT1026_3	42.36	-70.86667	:America/New_York	USA	knots	70	252	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:35:00	\N	0.3	-00:47:00	\N	0.2	-00:58:00	-00:21:00	The Graves, 0.3 n.mi. SSE of	MA
108959	Thieves Ledge (depth 45 ft), Massachusetts Current	NOS	ACT1031_1	42.32133	-70.838	:America/New_York	USA	knots	128	304	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:49:00	\N	0.2	-00:01:00	\N	0.2	-00:24:00	-00:45:00	Thieves Ledge	MA
108960	Little Brewster Island, 1.5 nmi E of (depth 10 ft), Massachusetts Current	NOS	ACT1036_1	42.328	-70.85717	:America/New_York	USA	knots	80	285	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:43:00	\N	0.9	00:46:00	\N	0.5	02:10:00	-00:45:00	Little Brewster Island, 1.5 n.mi. E of	MA
108961	Little Brewster Island, 1.5 nmi E of (depth 35 ft), Massachusetts Current	NOS	ACT1036_2	42.328	-70.85717	:America/New_York	USA	knots	76	236	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	01:15:00	\N	0.4	-00:44:00	\N	0.3	00:44:00	-00:02:00	Little Brewster Island, 1.5 n.mi. E of	MA
108962	Little Brewster Island, 1.5 nmi E of (depth 60 ft), Massachusetts Current	NOS	ACT1036_3	42.328	-70.85717	:America/New_York	USA	knots	47	225	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:57:00	\N	0.2	-01:18:00	\N	0.2	-01:23:00	01:26:00	Little Brewster Island, 1.5 n.mi. E of	MA
108963	Hypocrite Channel (depth 10 ft), Massachusetts Current	NOS	ACT1041_1	42.34917	-70.89383	:America/New_York	USA	knots	70	262	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:43:00	\N	0.8	00:24:00	\N	0.7	00:04:00	00:44:00	Hypocrite Channel	MA
108964	Little Calf Island, 0.4 nmi NW of (depth 10 ft), Massachusetts Current	NOS	ACT1046_1	42.35083	-70.9	:America/New_York	USA	knots	48	220	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:30:00	\N	0.6	00:09:00	\N	0.4	00:14:00	-00:20:00	Little Calf Island, 0.4 n.mi. NW of	MA
108965	Boston Light, 0.2 nmi south of (depth 10 ft), Massachusetts Current	NOS	ACT1051_1	42.32533	-70.89	:America/New_York	USA	knots	100	267	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:28:00	\N	1.1	00:24:00	\N	0.8	00:05:00	00:36:00	Boston Light, 0.2 n.mi. south of	MA
108966	Point Allerton, 0.4 nmi northwest of (depth 10 ft), Massachusetts Current	NOS	ACT1061_1	42.31467	-70.88717	:America/New_York	USA	knots	80	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:23:00	\N	0.7	00:58:00	\N	0.5	-00:18:00	00:12:00	Point Allerton, 0.4 n.mi. northwest of	MA
108967	Calf Island, 0.4 nmi west of (depth 10 ft), Massachusetts Current	NOS	ACT1066_1	42.33883	-70.90633	:America/New_York	USA	knots	37	198	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:01:00	\N	0.5	00:28:00	\N	0.4	00:07:00	00:05:00	Calf Island, 0.4 n.mi. west of	MA
108968	Calf Island, 0.4 nmi west of (depth 25 ft), Massachusetts Current	NOS	ACT1066_2	42.33883	-70.90633	:America/New_York	USA	knots	52	203	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:48:00	\N	0.3	00:05:00	\N	0.4	-00:37:00	00:11:00	Calf Island, 0.4 n.mi. west of	MA
108969	Calf Island, 0.4 nmi west of (depth 45 ft), Massachusetts Current	NOS	ACT1066_3	42.33883	-70.90633	:America/New_York	USA	knots	20	209	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-02:27:00	\N	0.3	00:09:00	\N	0.3	-01:37:00	00:00:00	Calf Island, 0.4 n.mi. west of	MA
108970	Black Rock Channel (depth 10 ft), Massachusetts Current	NOS	ACT1081_1	42.32883	-70.9155	:America/New_York	USA	knots	46	247	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:13:00	\N	0.8	-00:06:00	\N	0.5	-00:17:00	00:19:00	Black Rock Channel	MA
108971	Deer Island Light, 0.4 nmi NW of (depth 35 ft), Massachusetts Current	NOS	ACT1086_1	42.343	-70.92833	:America/New_York	USA	knots	116	307	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:58:00	\N	0.5	-02:05:00	\N	0.2	-00:24:00	-04:16:00	Deer Island Light, 0.4 n.mi. NW of	MA
108972	Lovell Island, 0.4 nmi north of (depth 10 ft), Massachusetts Current	NOS	ACT1091_1	42.34083	-70.93	:America/New_York	USA	knots	64	259	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:41:00	\N	1	-00:06:00	\N	0.9	00:00:00	00:17:00	Lovell Island, 0.4 n.mi. north of	MA
108973	Lovell Island, 0.4 nmi north of (depth 25 ft), Massachusetts Current	NOS	ACT1091_2	42.34083	-70.93	:America/New_York	USA	knots	74	264	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:23:00	\N	0.8	-00:09:00	\N	0.9	-00:17:00	00:21:00	Lovell Island, 0.4 n.mi. north of	MA
108974	Deer Island Light, 0.8 nmi ESE of (depth 10 ft), Massachusetts Current	NOS	ACT1101_1	42.337	-70.938	:America/New_York	USA	knots	66	233	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:35:00	\N	0.8	-00:15:00	\N	0.7	-00:13:00	00:15:00	Deer Island Light, 0.8 n.mi. ESE of	MA
108975	Deer Island Light, 0.4 nmi east of (depth 10 ft), Massachusetts Current	NOS	ACT1106_1	42.34083	-70.94617	:America/New_York	USA	knots	57	240	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:28:00	\N	0.8	-01:08:00	\N	0.7	-00:01:00	00:12:00	Deer Island Light, 0.4 n.mi. east of	MA
108976	Deer Island Light, 0.4 nmi east of (depth 35 ft), Massachusetts Current	NOS	ACT1106_2	42.34083	-70.94617	:America/New_York	USA	knots	53	264	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:04:00	\N	0.6	00:57:00	\N	0.9	-00:41:00	00:39:00	Deer Island Light, 0.4 n.mi. east of	MA
108977	Deer Island Light, 0.7 nmi ESE of (depth 35 ft), Massachusetts Current	NOS	ACT1111_1	42.3375	-70.93967	:America/New_York	USA	knots	62	233	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:13:00	\N	0.5	-00:05:00	\N	0.7	-00:32:00	00:20:00	Deer Island Light, 0.7 n.mi. ESE of	MA
108978	Deer Island Light, 0.3 nmi SSE of (depth 10 ft), Massachusetts Current	NOS	ACT1121_1	42.33533	-70.957	:America/New_York	USA	knots	82	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:16:00	\N	0.9	00:49:00	\N	1.1	-00:07:00	00:10:00	Deer Island Light, 0.3 n.mi. SSE of	MA
108979	Deer Island Light, 0.3 nmi SSE of (depth 35 ft), Massachusetts Current	NOS	ACT1121_2	42.33533	-70.957	:America/New_York	USA	knots	90	261	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:16:00	\N	0.8	00:51:00	\N	1.1	-00:20:00	00:44:00	Deer Island Light, 0.3 n.mi. SSE of	MA
108980	Deer Island Light, 0.4 nmi SSE of (depth 10 ft), Massachusetts Current	NOS	ACT1126_1	42.33283	-70.957	:America/New_York	USA	knots	73	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:18:00	\N	0.9	00:58:00	\N	1.2	-00:03:00	00:38:00	Deer Island Light, 0.4 n.mi. SSE of	MA
108981	Deer Island Light, 0.4 nmi SSE of (depth 25 ft), Massachusetts Current	NOS	ACT1126_2	42.33283	-70.957	:America/New_York	USA	knots	81	269	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:21:00	\N	0.9	00:52:00	\N	1.1	-00:11:00	00:47:00	Deer Island Light, 0.4 n.mi. SSE of	MA
108982	Deer Island, southwest of (depth 10 ft), Massachusetts Current	NOS	ACT1131_1	42.34383	-70.963	:America/New_York	USA	knots	137	351	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:20:00	\N	0.5	-00:21:00	\N	0.3	-00:05:00	-02:03:00	Deer Island, southwest of	MA
108983	Long Island Head, 0.9 nmi NW of (depth 10 ft), Massachusetts Current	NOS	ACT1136_1	42.34	-70.97383	:America/New_York	USA	knots	103	302	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:56:00	\N	0.5	00:35:00	\N	0.5	-00:17:00	-00:04:00	Long Island Head, 0.9 n.mi. NW of	MA
108984	Long Island Head, 0.9 nmi NW of (depth 35 ft), Massachusetts Current	NOS	ACT1136_2	42.34	-70.97383	:America/New_York	USA	knots	79	304	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:21:00	\N	0.3	01:26:00	\N	0.4	-00:10:00	00:45:00	Long Island Head, 0.9 n.mi. NW of	MA
108985	Deer Island Flats (depth 10 ft), Massachusetts Current	NOS	ACT1141_1	42.34717	-70.9775	:America/New_York	USA	knots	107	327	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-03:16:00	\N	0.4	-01:06:00	\N	0.4	-00:36:00	-01:37:00	Deer Island Flats	MA
108986	Snake Island, southwest of (depth 10 ft), Massachusetts Current	NOS	ACT1151_1	42.36283	-70.987	:America/New_York	USA	knots	134	312	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:01:00	\N	0.4	00:24:00	\N	0.3	-00:14:00	00:26:00	Snake Island, southwest of	MA
108987	Deer Island Light, 1.0 nmi WSW of (depth 10 ft), Massachusetts Current	NOS	ACT1156_1	42.33283	-70.97383	:America/New_York	USA	knots	86	254	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:53:00	\N	0.7	01:13:00	\N	1	00:43:00	02:05:00	Deer Island Light, 1.0 n.mi. WSW of	MA
108988	Deer Island Light, 1.0 nmi WSW of (depth 35 ft), Massachusetts Current	NOS	ACT1156_2	42.33283	-70.97383	:America/New_York	USA	knots	82	273	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:11:00	\N	0.3	01:38:00	\N	1	-00:05:00	01:41:00	Deer Island Light, 1.0 n.mi. WSW of	MA
108989	Spectacle I. and Long I., between (depth 10 ft), Massachusetts Current	NOS	ACT1161_1	42.3225	-70.97417	:America/New_York	USA	knots	38	217	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:34:00	\N	0.5	00:09:00	\N	0.4	-00:13:00	-00:39:00	Spectacle I. and Long I., between	MA
108990	Spectacle Island, 0.2 nmi south of (depth 10 ft), Massachusetts Current	NOS	ACT1166_1	42.31633	-70.98583	:America/New_York	USA	knots	98	244	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:58:00	\N	0.4	-01:00:00	\N	0.4	-00:22:00	-00:57:00	Spectacle Island, 0.2 n.mi. south of	MA
108991	Spectacle I. and Thompson I., between (depth 10 ft), Massachusetts Current	NOS	ACT1176_1	42.32083	-70.99283	:America/New_York	USA	knots	127	306	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-03:08:00	\N	0.3	-03:49:00	\N	0.2	-01:49:00	-02:35:00	Spectacle I. and Thompson I., between	MA
108992	Thompson Island, 0.7 nmi NNE of (depth 10 ft), Massachusetts Current	NOS	ACT1181_1	42.33283	-70.99833	:America/New_York	USA	knots	86	281	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:32:00	\N	0.5	01:36:00	\N	0.6	-00:37:00	01:05:00	Thompson Island, 0.7 n.mi. NNE of	MA
108993	Thompson Island, 0.7 nmi NNE of (depth 35 ft), Massachusetts Current	NOS	ACT1181_2	42.33283	-70.99833	:America/New_York	USA	knots	91	277	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:52:00	\N	0.2	01:36:00	\N	0.4	-01:13:00	00:43:00	Thompson Island, 0.7 n.mi. NNE of	MA
108994	Fort Independence, 0.3 nmi east of (depth 10 ft), Massachusetts Current	NOS	ACT1191_1	42.33883	-71.00367	:America/New_York	USA	knots	125	303	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	01:00:00	\N	0.5	01:36:00	\N	0.5	00:27:00	01:25:00	Fort Independence, 0.3 n.mi. east of	MA
108995	South Boston, Pier 4, 0.2 nmi NNE of (depth 10 ft), Massachusetts Current	NOS	ACT1206_1	42.35217	-71.03083	:America/New_York	USA	knots	118	299	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	01:01:00	\N	0.3	01:01:00	\N	0.2	00:29:00	00:11:00	South Boston, Pier 4, 0.2 n.mi. NNE of	MA
108996	South Boston, Pier 4, 0.2 nmi NNE of (depth 25 ft), Massachusetts Current	NOS	ACT1206_2	42.35217	-71.03083	:America/New_York	USA	knots	120	30	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:03:00	\N	0.1	00:24:00	\N	0.3	-00:23:00	01:37:00	South Boston, Pier 4, 0.2 n.mi. NNE of	MA
108997	East Boston, Pier 10, southeast of (depth 10 ft), Massachusetts Current	NOS	ACT1216_1	42.37583	-71.04667	:America/New_York	USA	knots	194	17	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:04:00	\N	0.3	00:55:00	\N	0.2	01:26:00	00:23:00	East Boston, Pier 10, southeast of	MA
108998	East Boston, Pier 10, southeast of (depth 25 ft), Massachusetts Current	NOS	ACT1216_2	42.37583	-71.04667	:America/New_York	USA	knots	193	30	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:39:00	\N	0.2	01:10:00	\N	0.3	-00:08:00	01:18:00	East Boston, Pier 10, southeast of	MA
108999	Chelsea River, west of bascule bridge (depth 10 ft), Massachusetts Current	NOS	ACT1226_1	42.3845	-71.04217	:America/New_York	USA	knots	240	48	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:58:00	\N	0.2	-00:21:00	\N	0.2	-00:07:00	00:38:00	Chelsea River, west of bascule bridge	MA
109000	Chelsea River, below bascule bridge (depth 10 ft), Massachusetts Current	NOS	ACT1231_1	42.38383	-71.02833	:America/New_York	USA	knots	272	88	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:16:00	\N	0.2	-00:10:00	\N	0.2	00:20:00	00:32:00	Chelsea River, below bascule bridge	MA
109001	Mystic River Bridge, 0.1 nmi west of (depth 10 ft), Massachusetts Current	NOS	ACT1236_1	42.38583	-71.05033	:America/New_York	USA	knots	93	267	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:28:00	\N	0.1	-00:05:00	\N	0.1	00:22:00	-00:51:00	Mystic River Bridge, 0.1 n.mi. west of	MA
109002	Mystic River Bridge, northwest of (depth 10 ft), Massachusetts Current	NOS	ACT1241_1	42.38583	-71.04917	:America/New_York	USA	knots	98	300	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:56:00	\N	0.1	01:09:00	\N	0.1	-00:29:00	00:17:00	Mystic River Bridge, northwest of	MA
109003	City Point, 0.8 nmi SSE of (depth 10 ft), Massachusetts Current	NOS	ACT1246_1	42.32033	-71.01467	:America/New_York	USA	knots	69	248	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:51:00	\N	0.5	00:39:00	\N	0.5	00:04:00	01:14:00	City Point, 0.8 n.mi. SSE of	MA
109004	Squantum Point, 0.8 nmi northeast of (depth 10 ft), Massachusetts Current	NOS	ACT1251_1	42.3105	-71.02833	:America/New_York	USA	knots	36	216	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:39:00	\N	0.4	00:40:00	\N	0.3	00:09:00	01:11:00	Squantum Point, 0.8 n.mi. northeast of	MA
109005	Squantum Point, 0.4 nmi NNE of (depth 10 ft), Massachusetts Current	NOS	ACT1256_1	42.30633	-71.03717	:America/New_York	USA	knots	91	266	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:40:00	\N	0.4	-00:01:00	\N	0.3	00:05:00	00:36:00	Squantum Point, 0.4 n.mi. NNE of	MA
109006	Neponset River (depth 10 ft), Massachusetts Current	NOS	ACT1261_1	42.30417	-71.043	:America/New_York	USA	knots	25	218	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:23:00	\N	0.4	-00:27:00	\N	0.3	-00:34:00	00:40:00	Neponset River	MA
109007	Lovell Island, 0.1 nmi south of (depth 10 ft), Massachusetts Current	NOS	ACT1271_1	42.32333	-70.92467	:America/New_York	USA	knots	92	275	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:05:00	\N	0.9	-01:49:00	\N	0.6	-00:01:00	-00:35:00	Lovell Island, 0.1 n.mi. south of	MA
109008	Lovell Island, 0.1 nmi south of (depth 24 ft), Massachusetts Current	NOS	ACT1271_2	42.32333	-70.92467	:America/New_York	USA	knots	95	294	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:13:00	\N	0.7	-02:12:00	\N	0.6	-00:34:00	-00:25:00	Lovell Island, 0.1 n.mi. south of	MA
109359	Hyde Park, Hudson River (midchannel), New York Current	NOS	ACT3751_1	41.78333	-73.95	:America/New_York	USA	knots	\N	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106683	03:00:00	\N	0.5	03:08:00	\N	0.7	03:25:00	02:43:00	Hyde Park	NY
109009	Georges Island, northeast of (depth 10 ft), Massachusetts Current	NOS	ACT1276_1	42.32283	-70.9255	:America/New_York	USA	knots	100	279	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-02:22:00	\N	0.6	-01:42:00	\N	0.6	-00:22:00	-00:34:00	Georges Island, northeast of	MA
109010	Georges Island, north of (depth 25 ft), Massachusetts Current	NOS	ACT1281_1	42.32367	-70.92783	:America/New_York	USA	knots	112	298	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:58:00	\N	0.8	-01:36:00	\N	0.6	-01:34:00	-00:06:00	Georges Island, north of	MA
109011	Gallops Island, 0.2 nmi SSE of (depth 10 ft), Massachusetts Current	NOS	ACT1286_1	42.323	-70.93217	:America/New_York	USA	knots	62	243	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:09:00	\N	0.8	00:21:00	\N	0.9	-00:08:00	-00:04:00	Gallops Island, 0.2 n.mi. SSE of	MA
109012	Gallops Island, 0.1 nmi southeast of (depth 10 ft), Massachusetts Current	NOS	ACT1291_1	42.32417	-70.93167	:America/New_York	USA	knots	63	225	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:15:00	\N	0.9	-00:33:00	\N	0.7	-00:10:00	-00:01:00	Gallops Island, 0.1 n.mi. southeast of	MA
109013	Gallops Island, 0.1 nmi southeast of (depth 35 ft), Massachusetts Current	NOS	ACT1291_2	42.32417	-70.93167	:America/New_York	USA	knots	52	255	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:15:00	\N	0.7	-00:38:00	\N	0.8	-00:07:00	00:17:00	Gallops Island, 0.1 n.mi. southeast of	MA
109014	Gallops Island, The Narrows (depth 20 ft), Massachusetts Current	NOS	ACT1296_1	42.327	-70.93383	:America/New_York	USA	knots	262	135	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:58:00	\N	0.1	-00:06:00	\N	0.4	-01:34:00	01:08:00	Gallops Island, The Narrows	MA
109015	Lovell Island, west of (depth 10 ft), Massachusetts Current	NOS	ACT1306_1	42.32867	-70.93283	:America/New_York	USA	knots	299	134	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:17:00	\N	1	-00:21:00	\N	0.4	00:07:00	00:44:00	Lovell Island, west of	MA
109016	Lovell Island, west of (depth 24 ft), Massachusetts Current	NOS	ACT1306_2	42.32867	-70.93283	:America/New_York	USA	knots	313	136	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:10:00	\N	1	00:19:00	\N	0.3	-00:13:00	01:17:00	Lovell Island, west of	MA
109017	Georges Island, 0.5 nmi ESE of (depth 10 ft), Massachusetts Current	NOS	ACT1316_1	42.3195	-70.91617	:America/New_York	USA	knots	65	244	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:01:00	\N	1	00:51:00	\N	0.8	00:23:00	00:55:00	Georges Island, 0.5 n.mi. ESE of	MA
109018	Georges Island, 0.4 nmi east of (depth 10 ft), Massachusetts Current	NOS	ACT1321_1	42.31867	-70.91617	:America/New_York	USA	knots	57	248	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:23:00	\N	0.9	00:09:00	\N	0.8	-00:26:00	00:03:00	Georges Island, 0.4 n.mi. east of	MA
109019	Georges Island, 0.3 nmi SSE of (depth 10 ft), Massachusetts Current	NOS	ACT1331_1	42.313	-70.92583	:America/New_York	USA	knots	69	234	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:29:00	\N	1	00:29:00	\N	0.9	00:12:00	00:29:00	Georges Island, 0.3 n.mi. SSE of	MA
109020	Georges Island, 0.3 nmi SSE of (depth 35 ft), Massachusetts Current	NOS	ACT1331_2	42.313	-70.92583	:America/New_York	USA	knots	73	237	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:10:00	\N	0.7	00:40:00	\N	0.8	-00:01:00	00:53:00	Georges Island, 0.3 n.mi. SSE of	MA
109021	Georges Island, 0.4 nmi SSE of (depth 10 ft), Massachusetts Current	NOS	ACT1336_1	42.31117	-70.9255	:America/New_York	USA	knots	46	236	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-02:15:00	\N	0.8	00:58:00	\N	1	00:07:00	00:27:00	Georges Island, 0.4 n.mi. SSE of	MA
109022	Georges Island, 0.4 nmi SSE of (depth 35 ft), Massachusetts Current	NOS	ACT1336_2	42.31117	-70.9255	:America/New_York	USA	knots	65	240	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:12:00	\N	0.8	01:01:00	\N	1	00:05:00	00:51:00	Georges Island, 0.4 n.mi. SSE of	MA
109023	Nubble Channel (depth 10 ft), Massachusetts Current	NOS	ACT1341_1	42.32883	-70.94883	:America/New_York	USA	knots	6	187	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:31:00	\N	0.6	00:50:00	\N	0.6	-00:21:00	00:40:00	Nubble Channel	MA
109024	Peddocks Island, 0.2 nmi north of (depth 10 ft), Massachusetts Current	NOS	ACT1356_1	42.30533	-70.93333	:America/New_York	USA	knots	257	246	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:41:00	\N	0.6	01:27:00	\N	0.8	00:28:00	01:15:00	Peddocks Island, 0.2 n.mi. north of	MA
109025	Peddocks Island, 0.2 nmi north of (depth 25 ft), Massachusetts Current	NOS	ACT1356_2	42.30533	-70.93333	:America/New_York	USA	knots	60	255	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:05:00	\N	0.5	01:09:00	\N	0.8	-00:02:00	01:25:00	Peddocks Island, 0.2 n.mi. north of	MA
109026	Peddocks Island, 0.3 nmi northwest of (depth 10 ft), Massachusetts Current	NOS	ACT1361_1	42.30667	-70.9355	:America/New_York	USA	knots	60	245	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:44:00	\N	0.8	01:30:00	\N	0.9	00:42:00	01:20:00	Peddocks Island, 0.3 n.mi. northwest of	MA
109027	Peddocks Island, 0.3 nmi northwest of (depth 25 ft), Massachusetts Current	NOS	ACT1361_2	42.30667	-70.9355	:America/New_York	USA	knots	55	250	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:03:00	\N	0.5	01:14:00	\N	0.8	00:12:00	01:27:00	Peddocks Island, 0.3 n.mi. northwest of	MA
109028	Peddocks Island, 0.3 nmi northwest of (depth 40 ft), Massachusetts Current	NOS	ACT1361_3	42.30667	-70.9355	:America/New_York	USA	knots	60	261	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:59:00	\N	0.4	01:11:00	\N	0.8	-00:17:00	01:40:00	Peddocks Island, 0.3 n.mi. northwest of	MA
109029	Rainsford I. and Windmill Pt., between (depth 10 ft), Massachusetts Current	NOS	ACT1366_1	42.30867	-70.93867	:America/New_York	USA	knots	56	251	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:34:00	\N	0.8	00:59:00	\N	0.6	00:28:00	00:29:00	Rainsford I. and Windmill Pt., between	MA
109030	Rainsford I. and Windmill Pt., between (depth 25 ft), Massachusetts Current	NOS	ACT1366_2	42.30867	-70.93867	:America/New_York	USA	knots	53	256	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:07:00	\N	0.4	01:24:00	\N	0.6	00:13:00	01:31:00	Rainsford I. and Windmill Pt., between	MA
109031	Gallops Island, 0.5 nmi southwest of (depth 10 ft), Massachusetts Current	NOS	ACT1371_1	42.31883	-70.947	:America/New_York	USA	knots	74	238	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:35:00	\N	0.6	00:19:00	\N	0.5	00:41:00	-01:02:00	Gallops Island, 0.5 n.mi. southwest of	MA
109032	Gallops Island, 0.5 nmi southwest of (depth 25 ft), Massachusetts Current	NOS	ACT1371_2	42.31883	-70.947	:America/New_York	USA	knots	72	237	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:58:00	\N	0.3	00:22:00	\N	0.4	00:08:00	-00:33:00	Gallops Island, 0.5 n.mi. southwest of	MA
109033	Rainsford Island, 0.2 nmi NE of (depth 10 ft), Massachusetts Current	NOS	ACT1376_1	42.315	-70.94917	:America/New_York	USA	knots	84	239	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:13:00	\N	0.4	00:23:00	\N	0.4	-00:26:00	00:14:00	Rainsford Island, 0.2 n.mi. NE of	MA
109034	Rainsford Island, 0.2 nmi NE of (depth 20 ft), Massachusetts Current	NOS	ACT1376_2	42.315	-70.94917	:America/New_York	USA	knots	86	237	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:24:00	\N	0.2	00:46:00	\N	0.4	-02:01:00	00:12:00	Rainsford Island, 0.2 n.mi. NE of	MA
109035	Rainsford Island, 0.4 nmi SE of (depth 10 ft), Massachusetts Current	NOS	ACT1381_1	42.30833	-70.94367	:America/New_York	USA	knots	55	225	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:11:00	\N	0.6	-00:44:00	\N	0.5	-00:08:00	00:57:00	Rainsford Island, 0.4 n.mi. SE of	MA
109036	Long I. and Rainsford I., between (depth 10 ft), Massachusetts Current	NOS	ACT1386_1	42.31167	-70.963	:America/New_York	USA	knots	49	226	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:43:00	\N	0.7	00:18:00	\N	0.6	00:22:00	00:34:00	Long I. and Rainsford I., between	MA
109037	Long I. and Rainsford I., between (depth 25 ft), Massachusetts Current	NOS	ACT1386_2	42.31167	-70.963	:America/New_York	USA	knots	33	229	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:13:00	\N	0.6	00:43:00	\N	0.5	00:13:00	00:38:00	Long I. and Rainsford I., between	MA
109038	West Head, Peddocks I., 0.1 nmi W of (depth 10 ft), Massachusetts Current	NOS	ACT1391_1	42.29083	-70.95367	:America/New_York	USA	knots	18	208	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:16:00	\N	0.7	01:02:00	\N	0.8	-01:30:00	01:24:00	West Head, Peddocks I., 0.1 n.mi. W of	MA
109039	West Head, Peddocks I., 0.1 nmi W of (depth 30 ft), Massachusetts Current	NOS	ACT1391_2	42.29083	-70.95367	:America/New_York	USA	knots	38	198	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:00:00	\N	0.5	01:08:00	\N	0.7	-01:35:00	01:15:00	West Head, Peddocks I., 0.1 n.mi. W of	MA
109040	Sunken Ledge, 0.2 nmi northwest of (depth 10 ft), Massachusetts Current	NOS	ACT1396_1	42.29783	-70.9645	:America/New_York	USA	knots	16	223	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:44:00	\N	0.5	-00:31:00	\N	0.3	00:17:00	00:28:00	Sunken Ledge, 0.2 n.mi. northwest of	MA
109041	Sunken Ledge, 0.2 nmi northwest of (depth 20 ft), Massachusetts Current	NOS	ACT1396_2	42.29783	-70.9645	:America/New_York	USA	knots	30	236	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:14:00	\N	0.4	00:29:00	\N	0.3	00:19:00	00:33:00	Sunken Ledge, 0.2 n.mi. northwest of	MA
109042	West Head, Long I., 0.4 nmi south of (depth 10 ft), Massachusetts Current	NOS	ACT1401_1	42.30533	-70.97133	:America/New_York	USA	knots	60	231	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:17:00	\N	0.5	00:51:00	\N	0.5	00:24:00	01:00:00	West Head, Long I., 0.4 n.mi. south of	MA
109043	West Head, Long I., 0.4 nmi south of (depth 20 ft), Massachusetts Current	NOS	ACT1401_2	42.30533	-70.97133	:America/New_York	USA	knots	43	231	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:13:00	\N	0.4	01:05:00	\N	0.4	00:06:00	00:55:00	West Head, Long I., 0.4 n.mi. south of	MA
109044	Moon Head, 0.4 nmi east of (depth 10 ft), Massachusetts Current	NOS	ACT1406_1	42.30633	-70.97883	:America/New_York	USA	knots	80	259	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:43:00	\N	0.3	-01:49:00	\N	0.3	-00:18:00	-00:30:00	Moon Head, 0.4 n.mi. east of	MA
109045	West Head, 0.2 nmi southwest of (depth 10 ft), Massachusetts Current	NOS	ACT1411_1	42.28583	-70.953	:America/New_York	USA	knots	322	167	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:03:00	\N	1.2	00:26:00	\N	1.1	-00:13:00	01:00:00	West Head, 0.2 n.mi. southwest of	MA
109046	Nut Island, 0.4 nmi NNE of (depth 10 ft), Massachusetts Current	NOS	ACT1416_1	42.28467	-70.95367	:America/New_York	USA	knots	312	158	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:31:00	\N	1.2	00:30:00	\N	1	00:11:00	01:01:00	Nut Island, 0.4 n.mi. NNE of	MA
109047	Nut Island, 0.4 nmi NNE of (depth 20 ft), Massachusetts Current	NOS	ACT1416_2	42.28467	-70.95367	:America/New_York	USA	knots	321	155	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:29:00	\N	1.2	00:34:00	\N	0.9	00:11:00	01:08:00	Nut Island, 0.4 n.mi. NNE of	MA
109048	Nut Island, 0.2 nmi NNE of (depth 10 ft), Massachusetts Current	NOS	ACT1421_1	42.283	-70.95533	:America/New_York	USA	knots	309	146	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:31:00	\N	1	00:40:00	\N	0.9	00:31:00	01:15:00	Nut Island, 0.2 n.mi. NNE of	MA
109049	Nut Island, 0.2 nmi NNE of (depth 20 ft), Massachusetts Current	NOS	ACT1421_2	42.283	-70.95533	:America/New_York	USA	knots	303	131	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:16:00	\N	0.8	00:43:00	\N	0.8	00:30:00	01:25:00	Nut Island, 0.2 n.mi. NNE of	MA
109050	Peddocks Island, west of (depth 10 ft), Massachusetts Current	NOS	ACT1426_1	42.28717	-70.96533	:America/New_York	USA	knots	358	187	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:43:00	\N	0.3	00:20:00	\N	0.4	-00:42:00	-00:04:00	Peddocks Island, west of	MA
109051	Moon Head, 0.9 nmi southeast of (depth 10 ft), Massachusetts Current	NOS	ACT1431_1	42.29167	-70.98217	:America/New_York	USA	knots	33	227	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:32:00	\N	0.3	01:09:00	\N	0.3	00:30:00	01:27:00	Moon Head, 0.9 n.mi. southeast of	MA
109052	Weir River entrance (depth 10 ft), Massachusetts Current	NOS	ACT1441_1	42.2755	-70.8805	:America/New_York	USA	knots	272	76	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:30:00	\N	0.6	00:39:00	\N	0.6	00:09:00	00:42:00	Weir River entrance	MA
109053	Crow Point, 0.2 nmi north of (depth 10 ft), Massachusetts Current	NOS	ACT1451_1	42.26617	-70.895	:America/New_York	USA	knots	319	146	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	01:30:00	\N	0.2	-00:36:00	\N	0.2	00:05:00	00:04:00	Crow Point, 0.2 n.mi. north of	MA
109054	Bumkin Island, 0.1 nmi west of (depth 10 ft), Massachusetts Current	NOS	ACT1456_1	42.28083	-70.90617	:America/New_York	USA	knots	320	166	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:52:00	\N	0.6	01:18:00	\N	0.5	-00:02:00	00:37:00	Bumkin Island, 0.1 n.mi. west of	MA
109055	Bumkin Island, 0.1 nmi west of (depth 20 ft), Massachusetts Current	NOS	ACT1456_2	42.28083	-70.90617	:America/New_York	USA	knots	316	161	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:41:00	\N	0.5	01:16:00	\N	0.4	-00:23:00	00:57:00	Bumkin Island, 0.1 n.mi. west of	MA
109056	Windmill Point, 0.7 nmi SSE of (depth 10 ft), Massachusetts Current	NOS	ACT1461_1	42.2925	-70.91617	:America/New_York	USA	knots	350	128	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-01:41:00	\N	0.4	00:40:00	\N	0.8	-00:02:00	00:11:00	Windmill Point, 0.7 n.mi. SSE of	MA
109057	Windmill Point, 0.7 nmi SSE of (depth 25 ft), Massachusetts Current	NOS	ACT1461_2	42.2925	-70.91617	:America/New_York	USA	knots	315	136	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:49:00	\N	0.2	00:55:00	\N	0.8	-00:07:00	01:41:00	Windmill Point, 0.7 n.mi. SSE of	MA
109058	Bumkin Island, 0.4 nmi west of (depth 10 ft), Massachusetts Current	NOS	ACT1466_1	42.2805	-70.9125	:America/New_York	USA	knots	303	195	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-02:58:00	\N	0.2	00:51:00	\N	0.4	-00:23:00	00:23:00	Bumkin Island, 0.4 n.mi. west of	MA
109059	Sheep Island, 0.3 nmi west of (depth 10 ft), Massachusetts Current	NOS	ACT1476_1	42.28117	-70.933	:America/New_York	USA	knots	305	75	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:49:00	\N	0.4	01:14:00	\N	0.8	00:11:00	01:15:00	Sheep Island, 0.3 n.mi. west of	MA
109060	Sheep Island, 0.3 nmi west of (depth 25 ft), Massachusetts Current	NOS	ACT1476_2	42.28117	-70.933	:America/New_York	USA	knots	300	82	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:22:00	\N	0.3	01:14:00	\N	0.7	01:10:00	01:32:00	Sheep Island, 0.3 n.mi. west of	MA
109061	Pig Rock, north of (depth 10 ft), Massachusetts Current	NOS	ACT1486_1	42.28217	-70.94083	:America/New_York	USA	knots	290	78	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:47:00	\N	0.8	-00:36:00	\N	0.5	00:40:00	-00:15:00	Pig Rock, north of	MA
109062	Pig Rock, north of (depth 25 ft), Massachusetts Current	NOS	ACT1486_2	42.28217	-70.94083	:America/New_York	USA	knots	293	82	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:22:00	\N	0.6	00:24:00	\N	0.5	00:35:00	01:21:00	Pig Rock, north of	MA
109063	Pig Rock, northwest of (depth 20 ft), Massachusetts Current	NOS	ACT1491_1	42.28133	-70.9425	:America/New_York	USA	knots	283	85	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	01:00:00	\N	0.7	00:52:00	\N	0.8	01:04:00	01:53:00	Pig Rock, northwest of	MA
109064	Grape Island and Lower Neck, between (depth 10 ft), Massachusetts Current	NOS	ACT1496_1	42.2645	-70.925	:America/New_York	USA	knots	281	94	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:11:00	\N	0.7	-01:16:00	\N	0.6	-00:23:00	00:06:00	Grape Island and Lower Neck, between	MA
109065	Grape Island (depth 10 ft), Massachusetts Current	NOS	ACT1501_1	42.268	-70.93133	:America/New_York	USA	knots	345	203	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:18:00	\N	0.3	00:13:00	\N	0.4	-00:47:00	00:38:00	Grape Island	MA
109066	Stodders Neck, Weymouth Back River (depth 10 ft), Massachusetts Current	NOS	ACT1506_1	42.25333	-70.9275	:America/New_York	USA	knots	93	268	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:43:00	\N	0.2	00:54:00	\N	0.4	-00:32:00	00:34:00	Stodders Neck, Weymouth Back River	MA
109067	Gull Point, 0.4 nmi ESE of (depth 10 ft), Massachusetts Current	NOS	ACT1516_1	42.253	-70.947	:America/New_York	USA	knots	69	229	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	-00:05:00	\N	0.4	-00:32:00	\N	0.3	-00:19:00	00:08:00	Gull Point, 0.4 n.mi. ESE of	MA
109068	Gull Point, 0.4 nmi ESE of (depth 25 ft), Massachusetts Current	NOS	ACT1516_2	42.253	-70.947	:America/New_York	USA	knots	42	235	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:07:00	\N	0.2	-00:42:00	\N	0.3	-00:49:00	00:42:00	Gull Point, 0.4 n.mi. ESE of	MA
109069	Germantown Point (depth 20 ft), Massachusetts Current	NOS	ACT1526_1	42.24633	-70.96467	:America/New_York	USA	knots	70	269	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:01:00	\N	0.3	00:54:00	\N	0.3	00:05:00	00:49:00	Germantown Point	MA
109070	Philip Head, Town River Bay (depth 10 ft), Massachusetts Current	NOS	ACT1536_1	42.25	-70.97033	:America/New_York	USA	knots	95	289	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:17:00	\N	0.2	01:33:00	\N	0.3	00:11:00	01:11:00	Philip Head, Town River Bay	MA
109071	Barnstable Harbor (depth 7 ft), Cape Cod Bay, Massachusetts Current	NOS	ACT1546_1	41.72667	-70.27333	:America/New_York	USA	knots	4	192	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106067	00:17:00	\N	1.1	01:03:00	\N	0.9	00:10:00	00:17:00	Barnstable Harbor	MA
109072	Old Man Shoal, Nantucket Shoals, Massachusetts Current	NOS	ACT1591_1	41.22667	-69.98333	:America/New_York	USA	knots	225	80	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:14:00	\N	0.9	01:03:00	\N	0.9	01:23:00	01:17:00	Old Man Shoal, Nantucket Shoals	MA
109073	Miacomet Pond, 3.0 mi SSE of, Massachusetts Current	NOS	ACT1596_1	41.19	-70.09667	:America/New_York	USA	knots	280	80	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	02:16:00	\N	0.8	02:03:00	\N	0.6	02:19:00	02:22:00	Miacomet Pond, 3.0 miles SSE of	MA
109074	Tuckernuck Island, 4.2 mi SSW of, Massachusetts Current	NOS	ACT1601_1	41.22617	-70.28167	:America/New_York	USA	knots	280	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	03:56:00	\N	0.6	03:13:00	\N	0.3	04:08:00	02:17:00	Tuckernuck Island, 4.2 miles SSW of	MA
109075	Pollock Rip Channel, east end, Nantucket Sound entrance, Massachusetts Current	NOS	ACT1611_1	41.565	-69.92333	:America/New_York	USA	knots	212	53	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-00:38:00	\N	1.1	-00:39:00	\N	1	-00:14:00	-00:23:00	Pollock Rip Channel, east end	MA
109076	Monomoy Pt., channel 0.2 mi west of, Nantucket Sound, Massachusetts Current	NOS	ACT1626_1	41.55	-70.02167	:America/New_York	USA	knots	346	170	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-00:23:00	\N	1.2	00:39:00	\N	0.8	00:00:00	00:18:00	Monomoy Pt., channel 0.2 mile west of	MA
109077	Stage Harbor, west of Morris Island, Nantucket Sound, Massachusetts Current	NOS	ACT1636_1	41.65667	-69.975	:America/New_York	USA	knots	144	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	04:28:00	\N	0.6	01:29:00	\N	0.3	03:07:00	02:24:00	Stage Harbor, west of Morris Island	MA
109078	Dennis Port, 2.2 mi south of, Nantucket Sound, Massachusetts Current	NOS	ACT1641_1	41.61667	-70.115	:America/New_York	USA	knots	269	77	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:04:00	\N	0.2	00:52:00	\N	0.2	01:28:00	00:27:00	Dennis Port, 2.2 miles south of	MA
109079	Monomoy Point, 6 mi west of, Nantucket Sound, Massachusetts Current	NOS	ACT1646_1	41.55833	-70.15	:America/New_York	USA	knots	275	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:22:00	\N	0.3	01:52:00	\N	0.2	01:22:00	01:09:00	Monomoy Point, 6 miles west of	MA
109080	Handkerchief Lighted Whistle Buoy H, Nantucket Sound, Massachusetts Current	NOS	ACT1651_1	41.48833	-70.06667	:America/New_York	USA	knots	251	80	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	00:59:00	\N	0.8	01:10:00	\N	0.6	01:08:00	00:49:00	Handkerchief Lighted Whistle Buoy 'H'	MA
109081	Halfmoon Shoal, 1.9 mi northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1656_1	41.48417	-70.1925	:America/New_York	USA	knots	265	110	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:44:00	\N	0.3	01:49:00	\N	0.4	01:42:00	01:24:00	Halfmoon Shoal, 1.9 miles northeast of	MA
109082	Halfmoon Shoal, 3.5 mi east of, Nantucket Sound, Massachusetts Current	NOS	ACT1661_1	41.46833	-70.15333	:America/New_York	USA	knots	295	88	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:11:00	\N	0.6	01:23:00	\N	0.5	01:13:00	01:06:00	Halfmoon Shoal, 3.5 miles east of	MA
109083	Great Point, 0.5 mi west of, Nantucket Sound, Massachusetts Current	NOS	ACT1666_1	41.39333	-70.06167	:America/New_York	USA	knots	195	29	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	00:33:00	\N	0.7	01:37:00	\N	0.6	00:25:00	01:13:00	Great Point, 0.5 mile west of	MA
109084	Great Point, 3 mi west of, Nantucket Sound, Massachusetts Current	NOS	ACT1671_1	41.39	-70.11333	:America/New_York	USA	knots	248	66	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:08:00	\N	0.5	01:23:00	\N	0.4	01:15:00	00:51:00	Great Point, 3 miles west of	MA
109085	Tuckernuck Shoal, off east end, Nantucket Sound, Massachusetts Current	NOS	ACT1676_1	41.405	-70.17333	:America/New_York	USA	knots	287	113	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:10:00	\N	0.5	01:34:00	\N	0.5	01:22:00	01:09:00	Tuckernuck Shoal, off east end	MA
109086	Nantucket Harbor entrance channel, Nantucket Sound, Massachusetts Current	NOS	ACT1686_1	41.30667	-70.1	:America/New_York	USA	knots	350	171	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	03:58:00	\N	0.9	01:55:00	\N	0.6	03:22:00	02:44:00	Nantucket Harbor entrance channel	MA
109087	Eel Pt., Nantucket I. 2.5 mi NE of, Nantucket Sound, Massachusetts Current	NOS	ACT1691_1	41.32167	-70.17	:America/New_York	USA	knots	284	94	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:15:00	\N	0.2	01:12:00	\N	0.3	01:13:00	01:02:00	Eel Pt., Nantucket I. 2.5 miles NE of	MA
109088	Muskeget I., channel 1 mi northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1696_1	41.35	-70.285	:America/New_York	USA	knots	295	108	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	00:56:00	\N	0.9	00:45:00	\N	0.6	01:29:00	00:57:00	Muskeget I., channel 1 mile northeast of	MA
109089	Muskeget Rock, 1.3 mi southwest of, Nantucket Sound, Massachusetts Current	NOS	ACT1701_1	41.32	-70.39333	:America/New_York	USA	knots	192	24	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	00:18:00	\N	0.6	00:23:00	\N	0.6	01:10:00	00:57:00	Muskeget Rock, 1.3 miles southwest of	MA
109090	Muskeget Channel, Nantucket Sound, Massachusetts Current	NOS	ACT1706_1	41.34833	-70.42	:America/New_York	USA	knots	200	21	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:02:00	\N	1.9	00:38:00	\N	1.9	01:40:00	01:29:00	Muskeget Channel	MA
109091	Long Shoal-Norton Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1716_1	41.40833	-70.33333	:America/New_York	USA	knots	260	100	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:13:00	\N	0.6	01:12:00	\N	0.7	01:31:00	01:26:00	Long Shoal-Norton Shoal, between	MA
109092	Cape Poge Lt., 1.7 mi SSE of, Nantucket Sound, Massachusetts Current	NOS	ACT1721_1	41.4	-70.42667	:America/New_York	USA	knots	215	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	00:48:00	\N	0.7	-00:07:00	\N	0.8	00:58:00	00:49:00	Cape Poge Lt., 1.7 miles SSE of	MA
109093	Cross Rip Channel, Nantucket Sound, Massachusetts Current	NOS	ACT1726_1	41.44833	-70.29167	:America/New_York	USA	knots	272	91	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:59:00	\N	0.5	01:48:00	\N	0.6	01:48:00	01:55:00	Cross Rip Channel	MA
109094	Cape Poge Lt., 3.2 mi northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1731_1	41.45833	-70.4	:America/New_York	USA	knots	300	95	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	02:37:00	\N	0.7	02:03:00	\N	0.8	02:42:00	02:33:00	Cape Poge Lt., 3.2 miles northeast of	MA
109095	Broken Ground-Horseshoe Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1736_1	41.55	-70.285	:America/New_York	USA	knots	276	107	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:20:00	\N	0.5	01:55:00	\N	0.5	01:46:00	01:15:00	Broken Ground-Horseshoe Shoal, between	MA
109096	Point Gammon, 1.2 mi south of, Nantucket Sound, Massachusetts Current	NOS	ACT1741_1	41.58833	-70.25667	:America/New_York	USA	knots	260	105	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:02:00	\N	0.6	01:03:00	\N	0.5	01:15:00	01:06:00	Point Gammon, 1.2 miles south of	MA
109097	Lewis Bay entrance channel, Nantucket Sound, Massachusetts Current	NOS	ACT1751_1	41.63167	-70.27333	:America/New_York	USA	knots	184	4	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	04:22:00	\N	0.8	00:53:00	\N	0.5	02:46:00	02:44:00	Lewis Bay entrance channel	MA
109098	Cotuit Bay entrance (Bluff Point), Nantucket Sound, Massachusetts Current	NOS	ACT1756_1	41.61	-70.43	:America/New_York	USA	knots	218	35	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	03:35:00	\N	0.4	02:33:00	\N	0.3	02:44:00	02:51:00	Cotuit Bay entrance (Bluff Point)	MA
109099	Wreck Shoal-Eldridge Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1761_1	41.53333	-70.42833	:America/New_York	USA	knots	245	62	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:45:00	\N	0.8	01:32:00	\N	0.8	01:47:00	01:44:00	Wreck Shoal-Eldridge Shoal, between	MA
109100	Hedge Fence Lighted Gong Buoy 22, Nantucket Sound, Massachusetts Current	NOS	ACT1766_1	41.47167	-70.48333	:America/New_York	USA	knots	268	108	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	02:44:00	\N	0.7	02:34:00	\N	0.7	02:48:00	02:38:00	Hedge Fence Lighted Gong Buoy 22	MA
109101	Cape Poge Light, 1.4 mi west of, Nantucket Sound, Massachusetts Current	NOS	ACT1771_1	41.42417	-70.48333	:America/New_York	USA	knots	250	95	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:39:00	\N	0.1	01:54:00	\N	0.2	02:13:00	01:26:00	Cape Poge Light, 1.4 miles west of	MA
109102	East Chop-Squash Meadow, between, Nantucket Sound, Massachusetts Current	NOS	ACT1786_1	41.465	-70.53667	:America/New_York	USA	knots	329	131	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	02:04:00	\N	1.1	00:55:00	\N	0.7	02:07:00	01:43:00	East Chop-Squash Meadow, between	MA
109103	East Chop, 1 mi north of, Nantucket Sound, Massachusetts Current	NOS	ACT1791_1	41.485	-70.55833	:America/New_York	USA	knots	297	116	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	02:11:00	\N	1.3	01:52:00	\N	1.1	02:40:00	02:17:00	East Chop, 1 mile north of	MA
109104	West Chop, 0.8 mi north of, Nantucket Sound, Massachusetts Current	NOS	ACT1801_1	41.49333	-70.595	:America/New_York	USA	knots	282	96	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	02:35:00	\N	1.8	01:58:00	\N	1.6	02:49:00	02:20:00	West Chop, 0.8 mile north of	MA
109105	Hedge Fence-L'Hommedieu Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1806_1	41.505	-70.53667	:America/New_York	USA	knots	276	106	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:52:00	\N	1.3	01:38:00	\N	1	02:27:00	02:01:00	Hedge Fence-L'Hommedieu Shoal, between	MA
109106	Waquoit Bay entrance, Nantucket Sound, Massachusetts Current	NOS	ACT1811_1	41.54833	-70.53	:America/New_York	USA	knots	203	348	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	04:01:00	\N	0.8	02:14:00	\N	0.8	03:21:00	03:40:00	Waquoit Bay entrance	MA
109107	L'Hommedieu Shoal, north of west end, Nantucket Sound, Massachusetts Current	NOS	ACT1816_1	41.52667	-70.57667	:America/New_York	USA	knots	268	80	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	02:11:00	\N	1.4	02:03:00	\N	1.2	02:30:00	02:12:00	L'Hommedieu Shoal, north of west end	MA
109108	Nobska Point, 1.8 mi east of, Nantucket Sound, Massachusetts Current	NOS	ACT1821_1	41.51833	-70.61833	:America/New_York	USA	knots	240	63	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:49:00	\N	1	01:45:00	\N	1.2	02:13:00	01:55:00	Nobska Point, 1.8 miles east of	MA
109109	West Chop, 0.2 mi west of, Vineyard Sound, Massachusetts Current	NOS	ACT1826_1	41.48333	-70.61	:America/New_York	USA	knots	241	59	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:16:00	\N	0.8	01:34:00	\N	1.3	01:19:00	01:50:00	West Chop, 0.2 mile west of	MA
109110	Nobska Point, 1 mi southeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1831_1	41.50167	-70.64333	:America/New_York	USA	knots	259	71	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	02:19:00	\N	1.4	02:15:00	\N	1.3	02:33:00	02:25:00	Nobska Point, 1 mile southeast of	MA
109111	Norton Point, 0.5 mi north of, Vineyard Sound, Massachusetts Current	NOS	ACT1836_1	41.46833	-70.665	:America/New_York	USA	knots	240	50	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:12:00	\N	1.4	01:44:00	\N	1.7	01:55:00	02:01:00	Norton Point, 0.5 mile north of	MA
109112	Tarpaulin Cove, 1.5 mi east of, Vineyard Sound, Massachusetts Current	NOS	ACT1841_1	41.47167	-70.725	:America/New_York	USA	knots	232	55	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	02:33:00	\N	1.4	02:07:00	\N	1	02:49:00	02:12:00	Tarpaulin Cove, 1.5 miles east of	MA
109113	Robinsons Hole, 1.2 mi southeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1846_1	41.435	-70.78	:America/New_York	USA	knots	240	60	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	02:02:00	\N	1.2	01:51:00	\N	1	02:30:00	02:11:00	Robinsons Hole, 1.2 miles southeast of	MA
109114	Gay Head, 3 mi northeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1851_1	41.385	-70.78333	:America/New_York	USA	knots	238	81	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	02:11:00	\N	0.8	01:50:00	\N	0.5	02:25:00	01:42:00	Gay Head, 3 miles northeast of	MA
109115	Gay Head, 3 mi north of, Vineyard Sound, Massachusetts Current	NOS	ACT1861_1	41.40167	-70.85333	:America/New_York	USA	knots	255	74	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:17:00	\N	0.7	01:24:00	\N	0.6	02:13:00	01:55:00	Gay Head, 3 miles north of	MA
109116	Gay Head, 1.5 mi northwest of, Vineyard Sound, Massachusetts Current	NOS	ACT1866_1	41.36333	-70.86333	:America/New_York	USA	knots	249	12	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	01:16:00	\N	1.2	00:54:00	\N	1	01:30:00	01:42:00	Gay Head, 1.5 miles northwest of	MA
109117	South end, Quicks Hole, Massachusetts Current	NOS	ACT1901_1	41.43833	-70.84167	:America/New_York	USA	knots	300	140	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106304	00:09:00	\N	0.7	00:12:00	\N	0.9	01:17:00	00:29:00	South end	MA
109118	North end, Quicks Hole, Massachusetts Current	NOS	ACT1911_1	41.45167	-70.85	:America/New_York	USA	knots	2	165	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106304	-00:21:00	\N	0.9	00:36:00	\N	0.9	01:41:00	00:56:00	North end	MA
109119	Westport River entrance, Buzzards Bay, Massachusetts Current	NOS	ACT1921_1	41.50833	-71.08833	:America/New_York	USA	knots	108	290	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106304	-01:49:00	\N	0.9	-01:23:00	\N	1	-01:15:00	-01:26:00	Westport River entrance	MA
109120	Ribbon Reef-Sow & Pigs Reef, between, Buzzards Bay, Massachusetts Current	NOS	ACT1931_1	41.42167	-70.97	:America/New_York	USA	knots	237	62	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106304	-02:30:00	\N	0.4	-02:49:00	\N	0.4	-01:43:00	-03:44:00	Ribbon Reef-Sow & Pigs Reef, between	MA
109121	Penikese Island, 0.8 mi northwest of, Buzzards Bay, Massachusetts Current	NOS	ACT1936_1	41.465	-70.93667	:America/New_York	USA	knots	254	50	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106304	-01:33:00	\N	0.4	-01:43:00	\N	0.6	-03:01:00	-01:55:00	Penikese Island, 0.8 mile northwest of	MA
109122	Penikese Island, 0.2 mi south of, Buzzards Bay, Massachusetts Current	NOS	ACT1941_1	41.44333	-70.925	:America/New_York	USA	knots	287	93	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106304	-03:15:00	\N	0.3	-01:33:00	\N	0.3	-03:07:00	-02:30:00	Penikese Island, 0.2 mile south of	MA
109123	Gull I. and Nashawena I., between, Buzzards Bay, Massachusetts Current	NOS	ACT1946_1	41.43667	-70.90333	:America/New_York	USA	knots	247	91	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106304	-03:17:00	\N	0.4	-02:15:00	\N	0.4	-03:39:00	-03:01:00	Gull I. and Nashawena I., between	MA
109124	Weepecket Island, south of, Buzzards Bay, Massachusetts Current	NOS	ACT1951_1	41.50667	-70.73833	:America/New_York	USA	knots	255	69	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106304	-03:03:00	\N	0.2	-02:25:00	\N	0.4	-04:40:00	-02:28:00	Weepecket Island, south of	MA
109125	Dumpling Rocks, 0.2 mi southeast of, Buzzards Bay, Massachusetts Current	NOS	ACT1966_1	41.53333	-70.91833	:America/New_York	USA	knots	190	66	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106304	-02:45:00	\N	0.4	-02:21:00	\N	0.4	-03:07:00	-02:32:00	Dumpling Rocks, 0.2 mile southeast of	MA
109126	Wareham River, off Long Beach Point, Buzzards Bay, Massachusetts Current	NOS	ACT2026_1	41.73333	-70.71667	:America/New_York	USA	knots	202	22	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106284	-01:24:00	\N	0.1	-00:33:00	\N	0.1	-02:09:00	-01:38:00	Wareham River, off Long Beach Point	MA
109127	Wareham River, off Barneys Point, Buzzards Bay, Massachusetts Current	NOS	ACT2031_1	41.745	-70.70667	:America/New_York	USA	knots	185	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106284	-01:32:00	\N	0.1	-00:29:00	\N	0.2	-02:17:00	-01:38:00	Wareham River, off Barneys Point	MA
109128	Bourne Highway bridge, Cape Cod Canal, Massachusetts Current	NOS	ACT2046_1	41.75	-70.58333	:America/New_York	USA	knots	245	65	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106284	-00:13:00	\N	0.8	-00:15:00	\N	0.8	-00:08:00	-00:07:00	Bourne Highway bridge	MA
109129	Black Point, SW of, Sakonnet River (depth 15 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2071_1	41.50667	-71.22	:America/New_York	USA	knots	194	12	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-02:26:00	\N	0.2	-01:55:00	\N	0.2	-02:54:00	-02:13:00	Black Point, SW of, Sakonnet River	RI
109130	Almy Point Bridge, south of, Sakonnet River (depth 15 ft), Rhode Island Current	NOS	ACT2076_1	41.62167	-71.22	:America/New_York	USA	knots	180	34	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-03:13:00	\N	0.8	-02:10:00	\N	0.2	-03:00:00	-02:30:00	Almy Point Bridge, south of, Sakonnet River	RI
109131	Brenton Point, 1.4 nmi southwest of (depth 7 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2096_1	41.43167	-71.37667	:America/New_York	USA	knots	170	347	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-01:04:00	\N	0.4	-00:38:00	\N	0.2	-01:03:00	-01:20:00	Brenton Point, 1.4 n.mi. southwest of	RI
109132	Castle Hill, west of, east passage (depth 15 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2101_1	41.45667	-71.37833	:America/New_York	USA	knots	237	13	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-00:29:00	\N	0.7	-00:42:00	\N	0.4	-00:06:00	-01:07:00	Castle Hill, west of, East Passage	RI
109133	Bull Point, east of (depth 10 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2106_1	41.48	-71.35	:America/New_York	USA	knots	206	1	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-01:33:00	\N	0.8	-00:47:00	\N	0.6	-01:10:00	-01:10:00	Bull Point, east of	RI
109134	Rose Island, northeast of (depth 15 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2121_1	41.50333	-71.33167	:America/New_York	USA	knots	124	310	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-02:08:00	\N	0.5	-00:07:00	\N	0.4	-01:57:00	-01:17:00	Rose Island, northeast of	RI
109135	Rose Island, northwest of (depth 15 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2126_1	41.50667	-71.35167	:America/New_York	USA	knots	190	7	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-01:39:00	\N	0.5	-00:26:00	\N	0.4	-01:38:00	-01:38:00	Rose Island, northwest of	RI
109136	Rose Island, west of, Narragansett Bay, Rhode Island Current	NOS	ACT2131_1	41.49667	-71.35	:America/New_York	USA	knots	172	1	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-01:28:00	\N	0.6	-00:34:00	\N	0.4	-00:42:00	-01:20:00	Rose Island, west of	RI
109137	Gould Island, southeast of (depth 7 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2136_1	41.525	-71.33667	:America/New_York	USA	knots	217	33	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-01:16:00	\N	0.4	-01:28:00	\N	0.3	-01:40:00	-01:14:00	Gould Island, southeast of	RI
109138	Gould Island, west of (depth 15 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2141_1	41.53167	-71.35833	:America/New_York	USA	knots	193	351	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-01:07:00	\N	0.4	-00:32:00	\N	0.3	-00:16:00	-01:13:00	Gould Island, west of	RI
109139	Dyer Island-Carrs Point (between), Narragansett Bay, Rhode Island Current	NOS	ACT2146_1	41.575	-71.29667	:America/New_York	USA	knots	236	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-01:37:00	\N	0.4	-01:13:00	\N	0.4	-01:56:00	-00:50:00	Dyer Island-Carrs Point (between)	RI
109140	Conanicut Point, ENE of (depth 15 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2151_1	41.575	-71.34167	:America/New_York	USA	knots	183	18	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-01:13:00	\N	0.2	-00:24:00	\N	0.2	-02:05:00	-01:18:00	Conanicut Point, ENE of	RI
109141	Dyer Island, west of (depth 7 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2156_1	41.58667	-71.30833	:America/New_York	USA	knots	216	23	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-01:34:00	\N	0.6	-00:46:00	\N	0.4	-01:04:00	-00:53:00	Dyer Island, west of	RI
109142	Mount Hope Bridge (depth 7 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2166_1	41.64	-71.25833	:America/New_York	USA	knots	230	47	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-00:58:00	\N	0.8	-01:34:00	\N	0.6	-01:22:00	-01:08:00	Mount Hope Bridge	RI
109143	Hog Island, northwest of (depth 10 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2171_1	41.64667	-71.295	:America/New_York	USA	knots	199	11	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-01:04:00	\N	0.2	-00:04:00	\N	0.2	-02:16:00	-00:30:00	Hog Island, northwest of	RI
109144	Common Fence Point, west of (depth 10 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2176_1	41.65	-71.245	:America/New_York	USA	knots	224	50	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-00:37:00	\N	0.4	00:08:00	\N	0.2	-01:13:00	-01:00:00	Common Fence Point, west of	RI
109145	Mount Hope Point, northeast of (depth 10 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2181_1	41.68	-71.21167	:America/New_York	USA	knots	217	38	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-00:57:00	\N	0.2	-00:20:00	\N	0.2	-02:01:00	-01:03:00	Mount Hope Point, northeast of	RI
109146	Warren, Warren River, Narragansett Bay, Rhode Island Current	NOS	ACT2196_1	41.72833	-71.28833	:America/New_York	USA	knots	171	358	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-01:05:00	\N	0.5	00:11:00	\N	0.5	-00:14:00	-00:22:00	Warren, Warren River	RI
109147	Beavertail Point, 0.8 mi northwest of, Narragansett Bay, Rhode Island Current	NOS	ACT2201_1	41.45833	-71.41167	:America/New_York	USA	knots	188	3	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-00:19:00	\N	0.6	-00:54:00	\N	0.3	-00:11:00	-01:31:00	Beavertail Point, 0.8 mile northwest of	RI
109148	Dutch Island and Beaver Head, between, Narragansett Bay, Rhode Island Current	NOS	ACT2211_1	41.49667	-71.40333	:America/New_York	USA	knots	233	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-01:47:00	\N	0.6	-01:32:00	\N	0.5	-01:56:00	-01:58:00	Dutch Island and Beaver Head, between	RI
109149	Dutch Island, west of (depth 7 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2216_1	41.505	-71.41	:America/New_York	USA	knots	206	14	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-01:16:00	\N	0.7	-01:49:00	\N	0.7	-01:33:00	-01:21:00	Dutch Island, west of	RI
109150	Patience Island, narrows east of, Narragansett Bay, Rhode Island Current	NOS	ACT2236_1	41.65833	-71.35333	:America/New_York	USA	knots	157	354	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-02:37:00	\N	0.5	-02:29:00	\N	0.4	-02:41:00	-02:44:00	Patience Island, narrows east of	RI
109151	Patience I. and Warwick Neck, between, Narragansett Bay, Rhode Island Current	NOS	ACT2241_1	41.66333	-71.37333	:America/New_York	USA	knots	224	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-01:13:00	\N	0.5	-01:21:00	\N	0.3	-01:40:00	-01:18:00	Patience I. and Warwick Neck, between	RI
109152	Nayatt Point, WNW of (depth 10 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2246_1	41.72833	-71.36	:America/New_York	USA	knots	128	325	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106032	-01:11:00	\N	0.1	00:47:00	\N	0.1	-02:24:00	-01:00:00	Nayatt Point, WNW of	RI
109153	Harbor of Refuge, south entrance, Point Judith, Block Island Sound, Rhode Island Current	NOS	ACT2266_1	41.358	-71.49583	:America/New_York	USA	knots	181	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-03:02:00	\N	0.2	-02:53:00	\N	0.2	-02:25:00	-02:47:00	Harbor of Refuge, south entrance	RI
109154	Pond entrance - Point Judith, Block Island Sound, Rhode Island Current	NOS	ACT2276_1	41.38333	-71.51667	:America/New_York	USA	knots	186	351	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-04:04:00	\N	0.4	-03:06:00	\N	0.6	-03:15:00	-03:06:00	Pond entrance - Point Judith	RI
109155	2.4 mi southwest of, Point Judith, Block Island Sound, Rhode Island Current	NOS	ACT2281_1	41.33117	-71.51083	:America/New_York	USA	knots	90	258	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:36:00	\N	0.1	00:06:00	\N	0.2	-00:40:00	00:28:00	2.4 miles southwest of	RI
109156	4 mi north of, Block Island, Block Island Sound, Rhode Island Current	NOS	ACT2291_1	41.3	-71.53333	:America/New_York	USA	knots	76	285	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:06:00	\N	0.2	-00:05:00	\N	0.2	-00:32:00	00:31:00	4 miles north of	RI
109157	Sandy Point, 2.1 mi NNE of (depth 15 ft), Block Island Sound, Rhode Island Current	NOS	ACT2296_1	41.26417	-71.56667	:America/New_York	USA	knots	66	296	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:55:00	\N	0.4	-00:58:00	\N	0.3	00:17:00	-00:20:00	Sandy Point, 2.1 miles NNE of	RI
109158	Sandy Pt., 1.5 mi north of (depth 7 ft), Block Island Sound, Rhode Island Current	NOS	ACT2301_1	41.25	-71.56667	:America/New_York	USA	knots	63	315	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:05:00	\N	0.5	-00:38:00	\N	0.6	-00:24:00	-01:07:00	Sandy Pt., 1.5 miles north of	RI
109159	Clay Head, 1.2 mi ENE of (depth 15 ft), Block Island Sound, Rhode Island Current	NOS	ACT2306_1	41.2225	-71.53083	:America/New_York	USA	knots	164	298	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:07:00	\N	0.1	-01:37:00	\N	0.2	-02:20:00	00:49:00	Clay Head, 1.2 miles ENE of	RI
109160	Old Harbor Pt., 0.5 mi southeast of, Block Island Sound, Rhode Island Current	NOS	ACT2311_1	41.15	-71.53333	:America/New_York	USA	knots	175	336	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:06:00	\N	0.1	-00:37:00	\N	0.1	-00:12:00	-00:38:00	Old Harbor Pt., 0.5 mile southeast of	RI
109161	Lewis Pt., 1.0 mi southwest of, Block Island, Block Island Sound, Rhode Island Current	NOS	ACT2316_1	41.13667	-71.62167	:America/New_York	USA	knots	136	298	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:25:00	\N	0.4	-01:13:00	\N	0.6	-01:29:00	-00:24:00	Lewis Pt., 1.0 mile southwest of	RI
109162	Lewis Pt., 1.5 mi west of, Block Island, Block Island Sound, Rhode Island Current	NOS	ACT2321_1	41.15	-71.63333	:America/New_York	USA	knots	170	318	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:12:00	\N	0.4	-01:23:00	\N	0.4	-01:33:00	-00:48:00	Lewis Pt., 1.5 miles west of	RI
109163	Great Salt Pond entrance, Block Island, Block Island Sound, Rhode Island Current	NOS	ACT2326_1	41.1995	-71.59167	:America/New_York	USA	knots	326	165	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-04:34:00	\N	0.1	-03:40:00	\N	0.1	-04:10:00	-03:24:00	Great Salt Pond entrance	RI
109164	Great Salt Pond ent., 1 mi NW of (depth 7 ft), Block Island Sound, Rhode Island Current	NOS	ACT2331_1	41.2	-71.6	:America/New_York	USA	knots	35	158	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:47:00	\N	0.1	-01:06:00	\N	0.1	-00:54:00	-01:54:00	Great Salt Pond ent., 1 mile NW of	RI
109165	Green Hill Point, 1.1 mi south of, Block Island Sound, Rhode Island Current	NOS	ACT2341_1	41.34833	-71.59617	:America/New_York	USA	knots	70	258	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:07:00	\N	0.1	-00:52:00	\N	0.2	-00:58:00	-00:24:00	Green Hill Point, 1.1 miles south of	RI
109166	Sandy Point, 4.1 mi northwest of (depth 15 ft), Block Island Sound, Rhode Island Current	NOS	ACT2346_1	41.29333	-71.63333	:America/New_York	USA	knots	84	270	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:08:00	\N	0.2	00:06:00	\N	0.2	00:04:00	00:32:00	Sandy Point, 4.1 miles northwest of	RI
109167	Quonochontaug Beach, 1.1 mi S of, Block Island Sound, Rhode Island Current	NOS	ACT2356_1	41.31333	-71.71367	:America/New_York	USA	knots	78	248	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:32:00	\N	0.1	00:01:00	\N	0.3	-00:43:00	00:47:00	Quonochontaug Beach, 1.1 miles S of	RI
109168	Quonochontaug Beach, 3.8 mi S of (depth 15 ft), Block Island Sound, Rhode Island Current	NOS	ACT2361_1	41.2725	-71.71667	:America/New_York	USA	knots	58	243	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:04:00	\N	0.2	-00:11:00	\N	0.2	00:03:00	00:39:00	Quonochontaug Beach, 3.8 miles S of	RI
109169	Lewis Point, 6.0 mi WNW of (depth 15 ft), Block Island Sound, Rhode Island Current	NOS	ACT2366_1	41.19333	-71.73667	:America/New_York	USA	knots	97	286	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:23:00	\N	0.3	00:35:00	\N	0.2	00:59:00	00:16:00	Lewis Point, 6.0 miles WNW of	RI
109170	Southwest Ledge, Block Island Sound, Rhode Island Current	NOS	ACT2371_1	41.11667	-71.7	:America/New_York	USA	knots	141	321	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:23:00	\N	0.5	-00:41:00	\N	0.5	-00:35:00	-00:14:00	Southwest Ledge	RI
109171	Southwest Ledge, 2.0 mi west of (depth 15 ft), Block Island Sound, Rhode Island Current	NOS	ACT2376_1	41.11333	-71.71667	:America/New_York	USA	knots	168	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:53:00	\N	0.5	00:05:00	\N	0.4	00:10:00	00:11:00	Southwest Ledge, 2.0 miles west of	RI
109172	Watch Hill Point, 2.2 mi east of, Block Island Sound, Rhode Island Current	NOS	ACT2381_1	41.30267	-71.81	:America/New_York	USA	knots	86	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:33:00	\N	0.2	-00:13:00	\N	0.4	-00:29:00	00:45:00	Watch Hill Point, 2.2 miles east of	RI
109173	Watch Hill Point, 5.2 mi SSE of (depth 15 ft), Block Island Sound, Rhode Island Current	NOS	ACT2386_1	41.22	-71.81667	:America/New_York	USA	knots	64	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:00:00	\N	0.3	00:13:00	\N	0.4	00:35:00	00:39:00	Watch Hill Point, 5.2 miles SSE of	RI
109174	Watch Hill Point, 5.3 nmi SE of (depth 15 ft), Block Island Sound, Rhode Island Current	NOS	ACT2391_1	41.24417	-71.77383	:America/New_York	USA	knots	92	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:03:00	\N	0.2	-00:11:00	\N	0.2	-00:08:00	-00:17:00	Watch Hill Point, 5.3 n.mi. SE of	RI
109175	Montauk Point, 5.4 mi NNE of (depth 15 ft), Block Island Sound, New York Current	NOS	ACT2396_1	41.15917	-71.82467	:America/New_York	USA	knots	79	279	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:04:00	\N	0.4	-00:08:00	\N	0.3	00:33:00	-00:38:00	Montauk Point, 5.4 miles NNE of	NY
109176	Montauk Point, 1.2 mi east of, Block Island Sound, New York Current	NOS	ACT2401_1	41.075	-71.83	:America/New_York	USA	knots	162	346	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-02:05:00	\N	0.7	-01:14:00	\N	0.8	-01:22:00	-00:38:00	Montauk Point, 1.2 miles east of	NY
109177	Montauk Point, 1 mi northeast of, Block Island Sound, New York Current	NOS	ACT2406_1	41.08333	-71.85	:America/New_York	USA	knots	145	356	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:56:00	\N	0.5	-01:37:00	\N	0.7	-02:04:00	-01:14:00	Montauk Point, 1 mile northeast of	NY
109178	East Pt., 4.1 mi S of Fishers Island (depth 15 ft), New York Current	NOS	ACT2416_1	41.22333	-71.925	:America/New_York	USA	knots	73	236	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:00:00	\N	0.4	00:27:00	\N	0.3	00:50:00	00:19:00	East Pt., 4.1 miles S of Fishers Island	NY
109179	Cerberus Shoal, 1.5 mi east of (depth 15 ft), Block Island Sound, New York Current	NOS	ACT2421_1	41.17417	-71.9195	:America/New_York	USA	knots	92	256	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:04:00	\N	0.4	00:20:00	\N	0.3	-00:15:00	-00:23:00	Cerberus Shoal, 1.5 miles east of	NY
109180	Shagwong Reef & Cerberus Shoal, between, Block Island Sound, New York Current	NOS	ACT2426_1	41.13167	-71.925	:America/New_York	USA	knots	56	241	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:10:00	\N	0.4	-00:52:00	\N	0.6	-00:30:00	-00:25:00	Shagwong Reef & Cerberus Shoal, between	NY
109181	Mt. Prospect, 0.6 mi SSE of (depth 15 ft), Block Island Sound, New York Current	NOS	ACT2436_1	41.24583	-71.99667	:America/New_York	USA	knots	54	275	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:11:00	\N	0.4	-00:11:00	\N	0.5	-00:34:00	00:10:00	Mt. Prospect, 0.6 mile SSE of	NY
109182	Cerberus Shoal and Fishers I., between (depth 7 ft), Block Island Sound, New York Current	NOS	ACT2441_1	41.21667	-71.96667	:America/New_York	USA	knots	96	264	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:21:00	\N	0.3	-00:13:00	\N	0.4	-00:59:00	00:07:00	Cerberus Shoal and Fishers I., between	NY
109183	Gardiners Island, 3 mi northeast of (depth 10 ft), Block Island Sound, New York Current	NOS	ACT2451_1	41.13167	-72.03333	:America/New_York	USA	knots	138	305	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:41:00	\N	0.2	-01:04:00	\N	0.3	-00:47:00	-00:25:00	Gardiners Island, 3 miles northeast of	NY
109360	Barrytown, Hudson River (midchannel), New York Current	NOS	ACT3766_1	42	-73.93333	:America/New_York	USA	knots	\N	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106685	-00:04:00	\N	1.3	00:24:00	\N	1.3	00:21:00	-00:05:00	Barrytown	NY
109184	Eastern Plain Pt., 3.9 mi ENE of, Block Island Sound, New York Current	NOS	ACT2456_1	41.1175	-71.99667	:America/New_York	USA	knots	96	246	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:13:00	\N	0.2	-01:30:00	\N	0.3	-01:01:00	-00:22:00	Eastern Plain Pt., 3.9 miles ENE of	NY
109185	Rocky Point, 2 mi WNW of (depth 15 ft), Block Island Sound, New York Current	NOS	ACT2466_1	41.05917	-72.03	:America/New_York	USA	knots	65	255	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:11:00	\N	0.1	-01:06:00	\N	0.1	-01:22:00	-00:49:00	Rocky Point, 2 miles WNW of	NY
109186	Goff Point, 0.4 mi northwest of, New York Current	NOS	ACT2471_1	41.02483	-72.0625	:America/New_York	USA	knots	10	225	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-02:43:00	\N	0.4	-02:30:00	\N	0.4	-01:46:00	-01:25:00	Goff Point, 0.4 mile northwest of	NY
109187	Acabonack Hbr. ent., 0.6 mi ESE of, New York Current	NOS	ACT2476_1	41.02167	-72.12333	:America/New_York	USA	knots	140	345	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-02:42:00	\N	0.3	-02:15:00	\N	0.4	-01:34:00	-01:05:00	Acabonack Hbr. ent., 0.6 mile ESE of	NY
109188	Hog Creek Point, north of, New York Current	NOS	ACT2481_1	41.06833	-72.16167	:America/New_York	USA	knots	67	281	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-02:04:00	\N	0.1	-00:54:00	\N	0.1	-00:56:00	-01:21:00	Hog Creek Point, north of	NY
109189	Ram Island, 2.2 mi east of, New York Current	NOS	ACT2486_1	41.07833	-72.23	:America/New_York	USA	knots	90	250	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:24:00	\N	0.1	-00:29:00	\N	0.1	-00:19:00	-00:14:00	Ram Island, 2.2 miles east of	NY
109190	Orient Point, 2.4 mi SSE of, New York Current	NOS	ACT2491_1	41.125	-72.205	:America/New_York	USA	knots	25	250	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:43:00	\N	0.1	-00:39:00	\N	0.1	00:19:00	01:11:00	Orient Point, 2.4 miles SSE of	NY
109191	Gardiners Pt. Ruins, 1.1 mi N of, New York Current	NOS	ACT2496_1	41.15833	-72.14717	:America/New_York	USA	knots	66	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:09:00	\N	0.4	-00:22:00	\N	0.4	-00:12:00	-00:09:00	Gardiners Pt. Ruins, 1.1 miles N of	NY
109192	Gardiners Point & Plum Island, between (depth 15 ft), New York Current	NOS	ACT2501_1	41.1555	-72.15867	:America/New_York	USA	knots	100	288	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:42:00	\N	0.4	-00:36:00	\N	0.4	-00:18:00	-00:32:00	Gardiners Point & Plum Island, between	NY
109193	Ram Island, 1.4 mi NNE of, New York Current	NOS	ACT2506_1	41.09667	-72.26333	:America/New_York	USA	knots	75	240	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:05:00	\N	0.1	-00:07:00	\N	0.1	00:01:00	00:07:00	Ram Island, 1.4 miles NNE of	NY
109194	Long Beach Pt., 0.7 mi southwest of (depth 15 ft), New York Current	NOS	ACT2511_1	41.10417	-72.30667	:America/New_York	USA	knots	101	307	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:12:00	\N	0.4	-00:16:00	\N	0.4	00:33:00	00:44:00	Long Beach Pt., 0.7 mile southwest of	NY
109195	Jennings Point, 0.2 mi NNW of (depth 13 ft), New York Current	NOS	ACT2521_1	41.07467	-72.3825	:America/New_York	USA	knots	55	290	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:09:00	\N	0.4	00:04:00	\N	0.5	00:32:00	00:37:00	Jennings Point, 0.2 mile NNW of	NY
109196	Cedar Point, 0.2 mi west of, New York Current	NOS	ACT2526_1	41.03967	-72.26783	:America/New_York	USA	knots	5	195	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:53:00	\N	0.5	-00:21:00	\N	0.7	-00:11:00	00:29:00	Cedar Point, 0.2 mile west of	NY
109197	North Haven Peninsula, north of, New York Current	NOS	ACT2531_1	41.04117	-72.32083	:America/New_York	USA	knots	35	230	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:46:00	\N	0.5	-00:35:00	\N	0.7	00:12:00	00:39:00	North Haven Peninsula, north of	NY
109198	Paradise Point, 0.4 mi east of (depth 13 ft), New York Current	NOS	ACT2536_1	41.048	-72.37617	:America/New_York	USA	knots	345	145	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:06:00	\N	0.4	-00:02:00	\N	0.5	00:26:00	00:45:00	Paradise Point, 0.4 mile east of	NY
109199	Little Peconic Bay entrance (depth 19 ft), New York Current	NOS	ACT2541_1	41.02633	-72.38467	:America/New_York	USA	knots	15	240	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:09:00	\N	0.4	-00:04:00	\N	0.5	00:35:00	00:53:00	Little Peconic Bay entrance	NY
109200	Robins Island, 0.5 mi south of, New York Current	NOS	ACT2546_1	40.94967	-72.453	:America/New_York	USA	knots	65	245	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:23:00	\N	0.1	-00:17:00	\N	0.3	00:32:00	00:56:00	Robins Island, 0.5 mile south of	NY
109201	Napatree Point, 0.7 mi southwest of, Fishers Island Sound, Rhode Island Current	NOS	ACT2556_1	41.29867	-71.9	:America/New_York	USA	knots	113	284	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:30:00	\N	0.5	-01:12:00	\N	0.5	-00:48:00	-00:47:00	Napatree Point, 0.7 mile southwest of	RI
109202	Little Narragansett Bay entrance, Fishers Island Sound, Connecticut Current	NOS	ACT2561_1	41.33333	-71.88333	:America/New_York	USA	knots	268	92	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-02:50:00	\N	0.3	-02:07:00	\N	0.4	-01:58:00	-02:13:00	Little Narragansett Bay entrance	CT
109203	Ram Island Reef, south of (depth 7 ft), Fishers Island Sound, Connecticut Current	NOS	ACT2571_1	41.30167	-71.975	:America/New_York	USA	knots	88	255	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:05:00	\N	0.4	-00:55:00	\N	0.4	-00:54:00	-00:45:00	Ram Island Reef, south of	CT
109204	Clay Point, 1.3 mi NNE of (depth 15 ft), Fishers Island Sound, New York Current	NOS	ACT2586_1	41.298	-71.9755	:America/New_York	USA	knots	35	264	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:27:00	\N	0.4	-00:54:00	\N	0.4	-00:34:00	-00:30:00	Clay Point, 1.3 miles NNE of	NY
109205	North Hill Point, 1.1 mi NNW of, Fishers Island Sound, Connecticut Current	NOS	ACT2591_1	41.29283	-72.028	:America/New_York	USA	knots	82	258	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:49:00	\N	0.3	-00:31:00	\N	0.5	-00:57:00	-00:08:00	North Hill Point, 1.1 miles NNW of	CT
109206	Race Point, 0.4 mi southwest of, The Race, Long Island Sound, New York Current	NOS	ACT2596_1	41.245	-72.04333	:America/New_York	USA	knots	135	288	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:57:00	\N	0.8	-00:40:00	\N	0.8	-00:16:00	-00:33:00	Race Point, 0.4 mile southwest of	NY
109207	Little Gull Island, 1.4 nmi NNE of (depth 45 ft), Long Island Sound, New York Current	NOS	ACT2606_1	41.2255	-72.092	:America/New_York	USA	knots	100	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:34:00	\N	0.4	00:12:00	\N	0.4	00:02:00	00:08:00	Little Gull Island, 1.4 n.mi. NNE of	NY
109208	Little Gull Island, 1.1 mi ENE of, The Race, Long Island Sound, New York Current	NOS	ACT2611_1	41.21833	-72.085	:America/New_York	USA	knots	130	301	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:57:00	\N	1.1	-00:16:00	\N	1.2	00:01:00	00:11:00	Little Gull Island, 1.1 miles ENE of	NY
109209	Little Gull Island, 0.8 mi NNW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2616_1	41.21833	-72.1155	:America/New_York	USA	knots	43	258	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:58:00	\N	0.7	-01:24:00	\N	0.6	00:25:00	-02:19:00	Little Gull Island, 0.8 mile NNW of	NY
109210	Goshen Point, 1.9 mi SSE of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2666_1	41.26667	-72.105	:America/New_York	USA	knots	62	285	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-02:01:00	\N	0.4	-01:05:00	\N	0.4	-00:57:00	-00:53:00	Goshen Point, 1.9 miles SSE of	CT
109211	Bartlett Reef, 0.2 mi south of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2671_1	41.26667	-72.13333	:America/New_York	USA	knots	90	255	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:46:00	\N	0.3	-00:58:00	\N	0.4	-02:03:00	-01:04:00	Bartlett Reef, 0.2 mile south of	CT
109212	Twotree Island Channel (depth 11 ft), Long Island Sound, Connecticut Current	NOS	ACT2676_1	41.29833	-72.14167	:America/New_York	USA	knots	99	267	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:54:00	\N	0.4	-01:32:00	\N	0.4	-00:58:00	-00:33:00	Twotree Island Channel	CT
109213	Niantic (Railroad Bridge) (depth 5 ft), Long Island Sound, Connecticut Current	NOS	ACT2681_1	41.32667	-72.17667	:America/New_York	USA	knots	178	352	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:52:00	\N	0.2	-01:08:00	\N	0.5	-00:45:00	-00:43:00	Niantic (Railroad Bridge)	CT
109214	Black Point, 0.8 mi south of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2686_1	41.27333	-72.20833	:America/New_York	USA	knots	73	260	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:22:00	\N	0.3	-01:16:00	\N	0.4	-00:42:00	-00:15:00	Black Point, 0.8 mile south of	CT
109215	Black Point and Plum Island, between (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2691_1	41.23333	-72.205	:America/New_York	USA	knots	76	236	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:14:00	\N	0.6	-00:01:00	\N	0.7	00:33:00	00:39:00	Black Point and Plum Island, between	NY
109361	Saugerties, Hudson River (midchannel), New York Current	NOS	ACT3771_1	42.06667	-73.93333	:America/New_York	USA	knots	\N	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106685	00:06:00	\N	1.5	00:45:00	\N	1.4	00:38:00	00:14:00	Saugerties	NY
109216	Plum Island, 0.8 mi NNW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2701_1	41.19833	-72.19833	:America/New_York	USA	knots	65	247	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:53:00	\N	0.6	-00:21:00	\N	0.5	00:12:00	-01:03:00	Plum Island, 0.8 mile NNW of	NY
109217	Hatchett Point, 1.6 nmi S of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2711_1	41.25667	-72.25617	:America/New_York	USA	knots	75	255	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:04:00	\N	0.4	-01:07:00	\N	0.5	-00:59:00	-00:27:00	Hatchett Point, 1.6 n.mi. S of	CT
109218	Hatchett Point, 1.1 mi WSW of, Long Island Sound, Connecticut Current	NOS	ACT2716_1	41.2725	-72.282	:America/New_York	USA	knots	45	240	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-02:49:00	\N	0.3	-01:16:00	\N	0.4	-02:29:00	-00:42:00	Hatchett Point, 1.1 miles WSW of	CT
109219	Orient Point, 1 mi WNW of, Long Island Sound, New York Current	NOS	ACT2721_1	41.16667	-72.25167	:America/New_York	USA	knots	55	245	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:27:00	\N	0.7	-02:07:00	\N	0.4	-01:01:00	-00:23:00	Orient Point, 1 mile WNW of	NY
109220	Saybrook Breakwater, 1.5 mi SE of, Long Island Sound, Connecticut Current	NOS	ACT2726_1	41.24633	-72.3175	:America/New_York	USA	knots	70	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-02:09:00	\N	0.5	-01:16:00	\N	0.6	-01:22:00	-00:45:00	Saybrook Breakwater, 1.5 miles SE of	CT
109221	Eustasia Island, 0.6 mi ESE of, Connecticut River, Long Island Sound, Connecticut Current	NOS	ACT2746_1	41.38833	-72.40383	:America/New_York	USA	knots	70	290	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	01:14:00	\N	0.3	01:33:00	\N	0.3	02:01:00	01:33:00	Eustasia Island, 0.6 mile ESE of	CT
109222	Eddy Rock Shoal, west of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2751_1	41.44283	-72.463	:America/New_York	USA	knots	155	350	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	01:08:00	\N	0.1	02:11:00	\N	0.2	01:49:00	02:11:00	Eddy Rock Shoal, west of	CT
109223	Higganum Creek, 0.5 mi ESE of, Connecticut River, Long Island Sound, Connecticut Current	NOS	ACT2756_1	41.50033	-72.54367	:America/New_York	USA	knots	80	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	02:49:00	\N	0.2	02:47:00	\N	0.2	03:14:00	02:45:00	Higganum Creek, 0.5 mile ESE of	CT
109224	Wilcox Island Park, east of, Connecticut River, Long Island Sound, Connecticut Current	NOS	ACT2761_1	41.57217	-72.648	:America/New_York	USA	knots	160	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	03:23:00	\N	0.2	03:31:00	\N	0.3	04:14:00	03:17:00	Wilcox Island Park, east of	CT
109225	Rocky Hill (depth 9 ft), Connecticut River, Long Island Sound, Connecticut Current	NOS	ACT2766_1	41.66367	-72.62883	:America/New_York	USA	knots	135	335	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	03:18:00	\N	0.2	03:32:00	\N	0.2	04:51:00	03:31:00	Rocky Hill	CT
109226	Hartford Jetty (depth 9 ft), Connecticut River, Long Island Sound, Connecticut Current	NOS	ACT2771_1	41.75117	-72.65033	:America/New_York	USA	knots	95	290	IGNORE VELOCITIES	Velocities for this station should be disregarded--use times only.	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	04:17:00	\N	0.2	04:34:00	\N	0.001	05:53:00	03:32:00	Hartford Jetty	CT
109227	Mulford Point, 3.1 mi northwest of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2776_1	41.2	-72.31833	:America/New_York	USA	knots	66	269	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:36:00	\N	0.5	-01:10:00	\N	0.6	00:02:00	00:05:00	Mulford Point, 3.1 miles northwest of	NY
109228	Rocky Point, 0.3 mi north of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2781_1	41.14383	-72.357	:America/New_York	USA	knots	41	279	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:40:00	\N	0.5	-01:07:00	\N	0.5	-00:19:00	-00:51:00	Rocky Point, 0.3 mile north of	NY
109229	Cornfield Point, 2.8 nmi SE of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2786_1	41.2325	-72.33883	:America/New_York	USA	knots	85	249	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:44:00	\N	0.3	-01:02:00	\N	0.6	-01:27:00	-00:32:00	Cornfield Point, 2.8 n.mi. SE of	CT
109230	Cornfield Point, 1.1 mi south of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2796_1	41.24417	-72.39	:America/New_York	USA	knots	108	293	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-02:15:00	\N	0.4	-01:39:00	\N	0.4	-00:53:00	-00:52:00	Cornfield Point, 1.1 miles south of	CT
109231	Cornfield Point, 1.9 nmi SW of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2801_1	41.24133	-72.42167	:America/New_York	USA	knots	91	272	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:23:00	\N	0.4	-01:40:00	\N	0.4	-01:09:00	-01:24:00	Cornfield Point, 1.9 n.mi. SW of	CT
109232	Kelsey Point, 2.1 mi southeast of, Long Island Sound, Connecticut Current	NOS	ACT2806_1	41.235	-72.4655	:America/New_York	USA	knots	70	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:12:00	\N	0.4	-01:07:00	\N	0.5	-00:27:00	-00:44:00	Kelsey Point, 2.1 miles southeast of	CT
109233	Kelsey Point, 1 mi south of, Long Island Sound, Connecticut Current	NOS	ACT2811_1	41.23333	-72.5	:America/New_York	USA	knots	118	249	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-02:06:00	\N	0.4	-01:08:00	\N	0.6	-01:34:00	-01:07:00	Kelsey Point, 1 mile south of	CT
109234	Six Mile Reef, 1.5 mi north of, Long Island Sound, Connecticut Current	NOS	ACT2816_1	41.21117	-72.48117	:America/New_York	USA	knots	95	290	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:53:00	\N	0.3	-00:17:00	\N	0.3	-00:09:00	-00:13:00	Six Mile Reef, 1.5 miles north of	CT
109235	Six Mile Reef, 2 mi east of, Long Island Sound, New York Current	NOS	ACT2821_1	41.1805	-72.44833	:America/New_York	USA	knots	40	235	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:47:00	\N	0.5	-00:17:00	\N	0.5	-00:28:00	00:03:00	Six Mile Reef, 2 miles east of	NY
109236	Horton Point, 1.4 mi NNW of, Long Island Sound, New York Current	NOS	ACT2841_1	41.105	-72.45667	:America/New_York	USA	knots	40	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:30:00	\N	0.5	00:03:00	\N	0.4	00:12:00	00:07:00	Horton Point, 1.4 miles NNW of	NY
109237	Hammonasset Point, 1.2 mi SW of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2846_1	41.237	-72.56667	:America/New_York	USA	knots	106	287	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:43:00	\N	0.2	-01:20:00	\N	0.3	-00:51:00	-00:34:00	Hammonasset Point, 1.2 miles SW of	CT
109238	Hammonasset Point, 5 mi south of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2851_1	41.16333	-72.5695	:America/New_York	USA	knots	90	284	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:18:00	\N	0.4	-00:08:00	\N	0.4	00:05:00	-00:14:00	Hammonasset Point, 5 miles south of	NY
109239	Duck Pond Point, 3.2 nmi NW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2856_1	41.07883	-72.56517	:America/New_York	USA	knots	71	253	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:15:00	\N	0.3	-00:14:00	\N	0.4	-00:25:00	-00:06:00	Duck Pond Point, 3.2 n.mi. NW of	NY
109240	Mattituck Inlet, 1 mi northwest of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2861_1	41.028	-72.57033	:America/New_York	USA	knots	53	241	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:38:00	\N	0.2	-00:20:00	\N	0.3	-00:13:00	00:02:00	Mattituck Inlet, 1 mile northwest of	NY
109241	Sachem Head, 1 mi SSE of, Long Island Sound, Connecticut Current	NOS	ACT2866_1	41.2275	-72.705	:America/New_York	USA	knots	65	255	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:14:00	\N	0.2	-00:41:00	\N	0.3	-00:30:00	-00:25:00	Sachem Head, 1 mile SSE of	CT
109242	Sachem Head 6.2 mi south of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2871_1	41.1455	-72.705	:America/New_York	USA	knots	65	260	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:16:00	\N	0.2	00:19:00	\N	0.2	00:37:00	-00:02:00	Sachem Head  6.2 miles south of	CT
109243	Roanoke Point, 5.6 mi north of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2876_1	41.07283	-72.70883	:America/New_York	USA	knots	50	255	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:36:00	\N	0.2	-00:07:00	\N	0.2	00:06:00	-00:05:00	Roanoke Point, 5.6 miles north of	NY
109244	Roanoke Point, 2.3 mi NNW of, Long Island Sound, New York Current	NOS	ACT2886_1	41.01533	-72.71617	:America/New_York	USA	knots	70	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:41:00	\N	0.2	-00:27:00	\N	0.3	-01:11:00	00:00:00	Roanoke Point, 2.3 miles NNW of	NY
109245	Branford Reef, 1.5 mi southwest of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2891_1	41.2095	-72.8305	:America/New_York	USA	knots	68	272	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:30:00	\N	0.2	-00:19:00	\N	0.2	-00:05:00	00:01:00	Branford Reef, 1.5 miles southwest of	CT
109246	Herod Point, 6.5 mi north of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2901_1	41.0775	-72.83	:America/New_York	USA	knots	70	254	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:19:00	\N	0.2	00:01:00	\N	0.3	-00:19:00	00:22:00	Herod Point, 6.5 miles north of	NY
109247	Herod Point, 2.8 mi north of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2906_1	41.01617	-72.83217	:America/New_York	USA	knots	90	290	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:18:00	\N	0.1	-00:22:00	\N	0.1	-00:21:00	-00:17:00	Herod Point, 2.8 miles north of	NY
109248	Herod Point, 5.0 nmi NW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2911_1	41.02733	-72.91217	:America/New_York	USA	knots	89	271	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:01:00	\N	0.2	-00:22:00	\N	0.2	-00:09:00	-00:27:00	Herod Point, 5.0 n.mi. NW of	NY
109249	Pond Point, 4.2 mi SSE of, Long Island Sound, Connecticut Current	NOS	ACT2936_1	41.14333	-72.968	:America/New_York	USA	knots	65	265	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:26:00	\N	0.1	-00:01:00	\N	0.2	-00:12:00	00:06:00	Pond Point, 4.2 miles SSE of	CT
109250	Sound Beach, 2.2 mi north of, Long Island Sound, New York Current	NOS	ACT2941_1	41.0055	-72.97417	:America/New_York	USA	knots	75	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:37:00	\N	0.2	-00:11:00	\N	0.3	00:05:00	-00:05:00	Sound Beach, 2.2 miles north of	NY
109251	Charles Island, 0.8 mi SSE of, Long Island Sound, Connecticut Current	NOS	ACT2946_1	41.1795	-73.04383	:America/New_York	USA	knots	70	250	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:06:00	\N	0.1	-00:41:00	\N	0.1	-00:43:00	-00:20:00	Charles Island, 0.8 mile SSE of	CT
109252	Milford Point, 0.2 mi west of (depth 10 ft), Long Island Sound, Connecticut Current	NOS	ACT2951_1	41.1725	-73.11367	:America/New_York	USA	knots	135	330	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:07:00	\N	0.3	-00:04:00	\N	0.4	00:02:00	00:25:00	Milford Point, 0.2 mile west of	CT
109253	Railroad drawbridge, above (depth 5 ft), Long Island Sound, Connecticut Current	NOS	ACT2956_1	41.20883	-73.11117	:America/New_York	USA	knots	185	350	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:07:00	\N	0.3	00:08:00	\N	0.3	00:42:00	00:39:00	Railroad drawbridge, above	CT
109254	Fowler Island, 0.1 mi NNW of (depth 5 ft), Long Island Sound, Connecticut Current	NOS	ACT2961_1	41.24	-73.10383	:America/New_York	USA	knots	270	40	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:36:00	\N	0.3	00:05:00	\N	0.3	00:56:00	00:40:00	Fowler Island, 0.1 mile NNW of	CT
109255	Wooster Island, 0.1 mi southwest of (depth 5 ft), Long Island Sound, Connecticut Current	NOS	ACT2966_1	41.27783	-73.08667	:America/New_York	USA	knots	220	20	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:10:00	\N	0.2	00:28:00	\N	0.2	01:27:00	00:30:00	Wooster Island, 0.1 mile southwest of	CT
109256	Point No Point, 2.1 mi south of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2976_1	41.1125	-73.11883	:America/New_York	USA	knots	74	251	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:13:00	\N	0.3	-00:11:00	\N	0.4	-00:22:00	00:02:00	Point No Point, 2.1 miles south of	CT
109257	Stratford Point, 4.3 mi south of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2986_1	41.0795	-73.11117	:America/New_York	USA	knots	75	254	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:02:00	\N	0.2	00:14:00	\N	0.3	00:20:00	00:15:00	Stratford Point, 4.3 miles south of	CT
109258	Stratford Point, 4.3 mi south of (depth 60 ft), Long Island Sound, Connecticut Current	NOS	ACT2986_2	41.0795	-73.11117	:America/New_York	USA	knots	78	291	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:03:00	\N	0.2	-00:14:00	\N	0.2	-00:28:00	-00:13:00	Stratford Point, 4.3 miles south of	CT
109259	Stratford Point, 6.1 mi south of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2991_1	41.0495	-73.09667	:America/New_York	USA	knots	80	267	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:18:00	\N	0.2	-00:02:00	\N	0.3	-00:10:00	00:26:00	Stratford Point, 6.1 miles south of	NY
109260	Stratford Point, 6.1 mi south of (depth 51 ft), Long Island Sound, New York Current	NOS	ACT2991_2	41.0495	-73.09667	:America/New_York	USA	knots	87	279	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:24:00	\N	0.2	-00:36:00	\N	0.3	-00:35:00	-00:24:00	Stratford Point, 6.1 miles south of	NY
109261	Stratford Shoal, 6 mi east of, Long Island Sound, New York Current	NOS	ACT2996_1	41.07533	-72.97383	:America/New_York	USA	knots	60	265	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:21:00	\N	0.1	-00:07:00	\N	0.2	00:09:00	00:03:00	Stratford Shoal, 6 miles east of	NY
109362	Catskill, Hudson River (midchannel), New York Current	NOS	ACT3781_1	42.21667	-73.85	:America/New_York	USA	knots	\N	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106685	00:36:00	\N	1.5	01:30:00	\N	1.5	01:11:00	00:54:00	Catskill	NY
109262	Old Field Point, 2.9 nmi NNW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3006_1	41.022	-73.1395	:America/New_York	USA	knots	76	254	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:15:00	\N	0.2	-00:16:00	\N	0.2	00:27:00	-00:35:00	Old Field Point, 2.9 n.mi. NNW of	NY
109263	Old Field Point, 2 mi northeast of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3011_1	41.00383	-73.095	:America/New_York	USA	knots	92	266	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:46:00	\N	0.3	00:08:00	\N	0.3	00:41:00	-00:01:00	Old Field Point, 2 miles northeast of	NY
109264	Old Field Point, 2 mi northeast of (depth 40 ft), Long Island Sound, New York Current	NOS	ACT3011_2	41.00383	-73.095	:America/New_York	USA	knots	81	236	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:29:00	\N	0.2	00:03:00	\N	0.2	00:30:00	-00:02:00	Old Field Point, 2 miles northeast of	NY
109265	Old Field Point, 1 mi east of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3016_1	40.9745	-73.09667	:America/New_York	USA	knots	308	105	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	01:44:00	\N	0.2	02:26:00	\N	0.1	03:34:00	02:35:00	Old Field Point, 1 mile east of	NY
109266	Old Field Point, 1 mi east of (depth 22 ft), Long Island Sound, New York Current	NOS	ACT3016_2	40.9745	-73.09667	:America/New_York	USA	knots	297	110	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	01:32:00	\N	0.1	01:49:00	\N	0.1	02:38:00	02:27:00	Old Field Point, 1 mile east of	NY
109267	Crane Neck Point, 0.5 mi northwest of, Long Island Sound, New York Current	NOS	ACT3026_1	40.96667	-73.16667	:America/New_York	USA	knots	16	256	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-01:49:00	\N	0.4	-01:32:00	\N	0.4	-00:47:00	-01:42:00	Crane Neck Point, 0.5 mile northwest of	NY
109268	Pine Creek Point, 2.3 mi SSE of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT3041_1	41.08417	-73.24	:America/New_York	USA	knots	84	272	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:11:00	\N	0.1	00:01:00	\N	0.2	-00:12:00	00:31:00	Pine Creek Point, 2.3 miles SSE of	CT
109269	Shoal Point, 6 mi south of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3046_1	41.02833	-73.23383	:America/New_York	USA	knots	47	232	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:43:00	\N	0.1	00:23:00	\N	0.1	00:30:00	00:52:00	Shoal Point, 6 miles south of	NY
109270	Crane Neck Point, 3.4 mi WNW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3051_1	40.98333	-73.23117	:America/New_York	USA	knots	79	261	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:03:00	\N	0.1	-00:03:00	\N	0.2	-00:04:00	-00:15:00	Crane Neck Point, 3.4 miles WNW of	NY
109271	Crane Neck Point, 3.7 mi WSW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3056_1	40.93833	-73.23117	:America/New_York	USA	knots	232	66	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:30:00	\N	0.1	-00:36:00	\N	0.1	-01:24:00	-00:14:00	Crane Neck Point, 3.7 miles WSW of	NY
109272	Saugatuck River, 0.3 mi NW of Bluff Pt (depth 15 ft), Connecticut Current	NOS	ACT3061_1	41.1045	-73.36533	:America/New_York	USA	knots	80	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:02:00	\N	0.1	-00:46:00	\N	0.2	-00:04:00	00:30:00	Saugatuck River, 0.3 mi. NW of Bluff Pt	CT
109273	Sheffield I. Hbr., 0.5 mi southeast of (depth 12 ft), Connecticut Current	NOS	ACT3076_1	41.05533	-73.42083	:America/New_York	USA	knots	42	229	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-02:24:00	\N	0.1	-03:59:00	\N	0.1	-02:33:00	-03:26:00	Sheffield I. Hbr., 0.5 mile southeast of	CT
109274	Sheffield I. Tower, 1.1 mi SE of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT3081_1	41.03283	-73.4055	:America/New_York	USA	knots	81	283	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:21:00	\N	0.2	00:34:00	\N	0.3	00:41:00	01:09:00	Sheffield I. Tower, 1.1 miles SE of	CT
109275	Sheffield I. Tower, 1.1 mi SE of (depth 60 ft), Long Island Sound, Connecticut Current	NOS	ACT3081_2	41.03283	-73.4055	:America/New_York	USA	knots	76	269	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:24:00	\N	0.1	00:19:00	\N	0.2	-00:19:00	01:10:00	Sheffield I. Tower, 1.1 miles SE of	CT
109276	Eatons Neck Pt., 2.5 nmi NNW of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT3091_1	40.9955	-73.41	:America/New_York	USA	knots	73	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-02:21:00	\N	0.2	-02:02:00	\N	0.2	-01:51:00	-02:06:00	Eatons Neck Pt., 2.5 n.mi. NNW of	CT
109277	Eatons Neck Pt., 1.3 mi north of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3096_1	40.97667	-73.39617	:America/New_York	USA	knots	75	283	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:09:00	\N	0.3	00:16:00	\N	0.4	00:29:00	00:13:00	Eatons Neck Pt., 1.3 miles north of	NY
109278	Eatons Neck Pt., 1.8 mi west of, Long Island Sound, New York Current	NOS	ACT3106_1	40.95	-73.43333	:America/New_York	USA	knots	68	199	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:44:00	\N	0.1	-01:09:00	\N	0.2	-01:11:00	-00:32:00	Eatons Neck Pt., 1.8 miles west of	NY
109279	Huntington Bay, off East Fort Point (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3111_1	40.92667	-73.4175	:America/New_York	USA	knots	14	190	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:39:00	\N	0.1	00:09:00	\N	0.2	00:02:00	00:24:00	Huntington Bay, off East Fort Point	NY
109280	Huntington Bay, off East Fort Point (depth 30 ft), Long Island Sound, New York Current	NOS	ACT3111_2	40.92667	-73.4175	:America/New_York	USA	knots	7	179	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:28:00	\N	0.1	00:05:00	\N	0.1	-00:46:00	00:15:00	Huntington Bay, off East Fort Point	NY
109281	Northport Bay entrance (in channel) (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3116_1	40.90883	-73.4075	:America/New_York	USA	knots	267	100	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:18:00	\N	0.1	00:09:00	\N	0.1	-00:03:00	00:22:00	Northport Bay entrance (in channel)	NY
109282	Northport Bay, south of Duck I. Bluff, Long Island Sound, New York Current	NOS	ACT3121_1	40.91667	-73.38333	:America/New_York	USA	knots	286	7	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:20:00	\N	0.1	00:46:00	\N	0.1	00:29:00	00:08:00	Northport Bay, south of Duck I. Bluff	NY
109283	Long Neck Point, 0.6 mi south of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT3126_1	41.02633	-73.478	:America/New_York	USA	knots	73	252	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:01:00	\N	0.1	-00:10:00	\N	0.3	-01:12:00	01:24:00	Long Neck Point, 0.6 mile south of	CT
109284	Long Neck Point, 0.6 mi south of (depth 27 ft), Long Island Sound, Connecticut Current	NOS	ACT3126_2	41.02633	-73.478	:America/New_York	USA	knots	80	257	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:03:00	\N	0.1	-00:13:00	\N	0.2	-00:57:00	01:22:00	Long Neck Point, 0.6 mile south of	CT
109285	Lloyd Point, 1.3 mi NNW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3131_1	40.96583	-73.495	:America/New_York	USA	knots	55	255	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:53:00	\N	0.2	00:49:00	\N	0.3	01:24:00	01:30:00	Lloyd Point, 1.3 miles NNW of	NY
109286	Lloyd Point, 1.3 mi NNW of (depth 40 ft), Long Island Sound, New York Current	NOS	ACT3131_2	40.96583	-73.495	:America/New_York	USA	knots	53	269	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:25:00	\N	0.2	00:08:00	\N	0.3	00:00:00	01:17:00	Lloyd Point, 1.3 miles NNW of	NY
109287	Shippan Point, 1.3 mi SSE of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT3136_1	40.99967	-73.51717	:America/New_York	USA	knots	55	239	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:04:00	\N	0.1	00:02:00	\N	0.3	00:36:00	00:23:00	Shippan Point, 1.3 miles SSE of	CT
109288	Shippan Point, 1.3 mi SSE of (depth 40 ft), Long Island Sound, Connecticut Current	NOS	ACT3136_2	40.99967	-73.51717	:America/New_York	USA	knots	71	247	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:22:00	\N	0.2	00:06:00	\N	0.2	00:18:00	00:56:00	Shippan Point, 1.3 miles SSE of	CT
109289	Rocky Point, 1 mi east of (depth 15 ft), Oyster Bay, Long Island Sound, New York Current	NOS	ACT3151_1	40.91917	-73.5005	:America/New_York	USA	knots	306	117	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:30:00	\N	0.1	00:15:00	\N	0.2	00:19:00	00:24:00	Rocky Point, 1 mile east of	NY
109290	Harbor ent., south of Plum Point (depth 7 ft), Long Island Sound, New York Current	NOS	ACT3156_1	40.9	-73.51667	:America/New_York	USA	knots	54	244	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:11:00	\N	0.2	-00:01:00	\N	0.2	-00:06:00	00:00:00	Harbor ent., south of Plum Point	NY
109291	Harbor, west of Soper Point (depth 7 ft), Oyster Bay, Long Island Sound, New York Current	NOS	ACT3161_1	40.88333	-73.53333	:America/New_York	USA	knots	140	333	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:11:00	\N	0.1	00:20:00	\N	0.2	00:24:00	-00:03:00	Harbor, west of Soper Point	NY
109292	Greenwich Point, 1.1 mi south of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT3171_1	40.98367	-73.567	:America/New_York	USA	knots	73	258	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	01:01:00	\N	0.2	00:58:00	\N	0.2	01:21:00	01:49:00	Greenwich Point, 1.1 miles south of	CT
109293	Greenwich Point, 1.1 mi south of (depth 55 ft), Long Island Sound, Connecticut Current	NOS	ACT3171_2	40.98367	-73.567	:America/New_York	USA	knots	69	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	01:03:00	\N	0.1	00:51:00	\N	0.2	01:24:00	00:51:00	Greenwich Point, 1.1 miles south of	CT
109294	Greenwich Point, 2.5 mi south of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3176_1	40.96	-73.56133	:America/New_York	USA	knots	52	242	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:29:00	\N	0.2	00:10:00	\N	0.2	00:47:00	00:57:00	Greenwich Point, 2.5 miles south of	NY
109295	Greenwich Point, 2.5 mi south of (depth 55 ft), Long Island Sound, New York Current	NOS	ACT3176_2	40.96	-73.56133	:America/New_York	USA	knots	79	256	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:17:00	\N	0.1	-00:04:00	\N	0.2	-01:07:00	-00:27:00	Greenwich Point, 2.5 miles south of	NY
109296	Oak Neck Point, 0.6 mi north of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3181_1	40.925	-73.567	:America/New_York	USA	knots	72	260	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	02:11:00	\N	0.2	01:58:00	\N	0.2	02:51:00	02:25:00	Oak Neck Point, 0.6 mile north of	NY
109297	Oak Neck Point, 0.6 mi north of (depth 30 ft), Long Island Sound, New York Current	NOS	ACT3181_2	40.925	-73.567	:America/New_York	USA	knots	90	300	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	01:51:00	\N	0.1	01:35:00	\N	0.2	00:54:00	01:41:00	Oak Neck Point, 0.6 mile north of	NY
109298	Cos Cob Harbor, off Goose Island, Long Island Sound, Connecticut Current	NOS	ACT3186_1	41.01667022705078	-73.5999984741211	:America/New_York	USA	knots	188	13	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:55:00	\N	0.1	-00:15:00	\N	0.2	00:11:00	00:00:00	Cos Cob Harbor, off Goose Island	CT
109299	Captain Hbr. ent., 0.6 mi southwest of (depth 15 ft), Connecticut Current	NOS	ACT3191_1	40.99417	-73.5945	:America/New_York	USA	knots	118	312	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	02:00:00	\N	0.2	01:44:00	\N	0.2	01:32:00	01:49:00	Captain Hbr. Ent., 0.6 mile southwest of	CT
109300	Captain Hbr. ent., 0.6 mi southwest of (depth 30 ft), Connecticut Current	NOS	ACT3191_2	40.99417	-73.5945	:America/New_York	USA	knots	142	319	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	01:58:00	\N	0.2	01:14:00	\N	0.2	01:22:00	00:58:00	Captain Hbr. Ent., 0.6 mile southwest of	CT
109301	Parsonage Point, 1.3 nmi ESE of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3196_1	40.9375	-73.65817	:America/New_York	USA	knots	51	230	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	01:00:00	\N	0.1	00:24:00	\N	0.2	00:47:00	01:10:00	Parsonage Point, 1.3 n.mi. ESE of	NY
109302	Peningo Neck, 0.6 mi off Parsonage Pt (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3201_1	40.93867	-73.675	:America/New_York	USA	knots	35	226	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:27:00	\N	0.2	00:23:00	\N	0.2	01:09:00	01:16:00	Peningo Neck, 0.6 mi. off Parsonage Pt	NY
109303	Matinecock Point, 0.7 mi NNW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3211_1	40.91333	-73.64	:America/New_York	USA	knots	46	233	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:36:00	\N	0.1	00:27:00	\N	0.2	01:14:00	01:34:00	Matinecock Point, 0.7 mile NNW of	NY
109304	Matinecock Point, 0.7 mi NNW of (depth 40 ft), Long Island Sound, New York Current	NOS	ACT3211_2	40.91333	-73.64	:America/New_York	USA	knots	53	262	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	00:20:00	\N	0.1	00:07:00	\N	0.2	00:35:00	01:33:00	Matinecock Point, 0.7 mile NNW of	NY
109305	Hempstead Harbor, off Glenwood Landing (depth 10 ft), Long Island Sound, New York Current	NOS	ACT3226_1	40.828	-73.65	:America/New_York	USA	knots	320	138	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:59:00	\N	0.2	-00:19:00	\N	0.3	-00:38:00	00:03:00	Hempstead Harbor, off Glenwood Landing	NY
109306	Delancey Point, 1 mi southeast of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3236_1	40.91667	-73.71217	:America/New_York	USA	knots	59	244	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106815	-00:05:00	\N	0.1	00:09:00	\N	0.2	00:45:00	01:14:00	Delancey Point, 1 mile southeast of	NY
109307	Huckleberry Island, 0.2 mi NW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3256_1	40.8905	-73.75717	:America/New_York	USA	knots	234	69	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106923	-03:40:00	\N	0.2	-04:16:00	\N	0.1	-03:25:00	-03:21:00	Huckleberry Island, 0.2 mile NW of	NY
109308	Huckleberry Island, 0.6 mi SE of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3261_1	40.88	-73.74583	:America/New_York	USA	knots	226	25	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106923	-02:24:00	\N	0.3	-00:33:00	\N	0.2	-02:35:00	-01:53:00	Huckleberry Island, 0.6 mile SE of	NY
109309	Manhasset Bay entrance (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3271_1	40.82917	-73.72967	:America/New_York	USA	knots	307	115	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106923	03:04:00	\N	0.3	02:18:00	\N	0.2	02:48:00	02:48:00	Manhasset Bay entrance	NY
109310	Hart Island, 0.3 nmi SSE of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3286_1	40.8405	-73.76567	:America/New_York	USA	knots	201	40	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106923	-01:10:00	\N	0.5	-01:28:00	\N	0.3	-01:37:00	-01:46:00	Hart Island, 0.3 n.mi. SSE of	NY
109311	City Island Bridge (depth 10 ft), Long Island Sound, New York Current	NOS	ACT3296_1	40.85783	-73.79333	:America/New_York	USA	knots	198	352	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106923	-04:13:00	\N	0.4	-05:01:00	\N	0.1	-03:09:00	-04:06:00	City Island Bridge	NY
109312	Eastchester Bay, near Big Tom (depth 5 ft), Long Island Sound, New York Current	NOS	ACT3301_1	40.83667	-73.79533	:America/New_York	USA	knots	294	97	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106923	-03:14:00	\N	0.4	-04:00:00	\N	0.2	-03:15:00	-03:46:00	Eastchester Bay, near Big Tom	NY
109313	Hutchinson R., Pelham Highway Bridge (depth 5 ft), Long Island Sound, New York Current	NOS	ACT3306_1	40.86167	-73.81667	:America/New_York	USA	knots	78	305	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106923	02:13:00	\N	0.4	02:28:00	\N	0.5	02:31:00	02:12:00	Hutchinson R., Pelham Highway Bridge	NY
109314	Throgs Neck, 0.3 nmi NE of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3321_1	40.81067	-73.7855	:America/New_York	USA	knots	193	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106923	00:08:00	\N	0.6	-00:40:00	\N	0.6	-00:31:00	-00:52:00	Throgs Neck, 0.3 n.mi. NE of	NY
109315	Throgs Neck, 0.4 mi south of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3326_1	40.79833	-73.79083	:America/New_York	USA	knots	278	90	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106923	00:19:00	\N	0.6	00:09:00	\N	0.5	00:26:00	00:41:00	Throgs Neck, 0.4 mile south of	NY
109316	Throgs Neck, 0.2 mi S of (Willets Point) (depth 15 ft), New York Current	NOS	ACT3331_1	40.802	-73.79133	:America/New_York	USA	knots	289	90	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106923	00:13:00	\N	0.7	-00:09:00	\N	0.4	-00:10:00	00:21:00	Throgs Neck, 0.2 mile S of (Willets Point)	NY
109317	Cryders Point, 0.4 mi NNW of, East River, New York Current	NOS	ACT3341_1	40.80030059814453	-73.79869842529297	:America/New_York	USA	knots	285	110	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	-00:59:00	\N	0.26	-00:45:00	\N	0.39	-00:26:00	-00:20:00	Cryders Point, 0.4 mile NNW of	NY
109318	Bronx-Whitestone Bridge, east of (depth 14 ft), East River, New York Current	NOS	ACT3346_1	40.801700592041016	-73.82669830322266	:America/New_York	USA	knots	247	76	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	-01:26:00	\N	0.23	-00:48:00	\N	0.5	-00:31:00	00:00:00	Bronx-Whitestone Bridge, East of	NY
109319	College Point Reef, 0.25 nmi NW of (depth 15 ft), East River, New York Current	NOS	ACT3356_1	40.80099868774414	-73.85469818115234	:America/New_York	USA	knots	261	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	-00:56:00	\N	0.3	-00:51:00	\N	0.45	-00:30:00	00:09:00	College Point Reef, 0.25 n.mi. NW of	NY
109320	Rikers I. chan., off La Guardia Field, East River, New York Current	NOS	ACT3366_1	40.78329849243164	-73.88330078125	:America/New_York	USA	knots	261	88	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	-00:07:00	\N	0.31	-00:06:00	\N	0.33	00:07:00	00:14:00	Rikers I. chan., off La Guardia Field	NY
109321	Hunts Point, southwest of, East River, New York Current	NOS	ACT3376_1	40.79999923706055	-73.88330078125	:America/New_York	USA	knots	280	108	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	-00:04:00	\N	0.31	-00:12:00	\N	0.51	00:04:00	00:11:00	Hunts Point, southwest of	NY
109322	South Brother Island, NW of (depth 15 ft), East River, New York Current	NOS	ACT3381_1	40.79669952392578	-73.90170288085938	:America/New_York	USA	knots	252	54	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	-00:11:00	\N	0.29	00:02:00	\N	0.45	-00:14:00	00:04:00	South Brother Island, NW of	NY
109323	Off Winthrop Ave., Astoria, East River, New York Current	NOS	ACT3386_1	40.78670120239258	-73.91670227050781	:America/New_York	USA	knots	220	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	-00:10:00	\N	0.6	00:00:00	\N	1.02	00:07:00	00:09:00	Off Winthrop Ave., Astoria	NY
109324	Roosevelt Is., west of, off 75th Street, East River, New York Current	NOS	ACT3406_1	40.766700744628906	-73.94999694824219	:America/New_York	USA	knots	215	37	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	00:08:00	\N	1.12	-00:06:00	\N	0.6	00:01:00	-00:02:00	Roosevelt Is., west of, off 75th Street	NY
109325	Roosevelt Is., east of, off 36th Avenue, East River, New York Current	NOS	ACT3411_1	40.76359939575195	-73.94550323486328	:America/New_York	USA	knots	210	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	-00:10:00	\N	0.81	-00:06:00	\N	1.05	-00:05:00	00:02:00	Roosevelt Island, east of, off 36th Avenue	NY
109326	Roosevelt Is., west of, off 67th Street, East River, New York Current	NOS	ACT3416_1	40.762298583984375	-73.9540023803711	:America/New_York	USA	knots	230	11	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	00:12:00	\N	0.95	-00:10:00	\N	1.08	00:16:00	00:16:00	Roosevelt Is., west of, off 67th Street	NY
109327	Roosevelt Is., west of, off 63rd Street, East River, New York Current	NOS	ACT3421_1	40.759700775146484	-73.95449829101562	:America/New_York	USA	knots	223	36	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	00:04:00	\N	0.69	-00:10:00	\N	0.84	-00:07:00	00:10:00	Roosevelt Is., west of, off 63rd Street	NY
109328	Roosevelt Island, east of, East River, New York Current	NOS	ACT3426_1	40.758201599121094	-73.95130157470703	:America/New_York	USA	knots	200	28	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	00:08:00	\N	0.62	-00:08:00	\N	0.84	00:03:00	00:12:00	Roosevelt Island, east of	NY
109329	Manhattan, off 31st Street, East River, New York Current	NOS	ACT3431_1	40.73970031738281	-73.96949768066406	:America/New_York	USA	knots	175	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	00:37:00	\N	0.5	-00:13:00	\N	0.45	00:12:00	00:08:00	Manhattan, off 31st Street	NY
109330	Willis Ave. Bridge, 0.1 mi NW of, Harlem River, New York Current	NOS	ACT3481_1	40.805	-73.93	:America/New_York	USA	knots	330	140	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	-00:12:00	\N	0.31	-00:02:00	\N	0.36	-00:27:00	-00:02:00	Willis Ave. Bridge, 0.1 mile NW of	NY
109331	Madison Ave. Bridge, Harlem River, New York Current	NOS	ACT3486_1	40.81330108642578	-73.93499755859375	:America/New_York	USA	knots	0	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	-00:13:00	\N	0.41	00:16:00	\N	0.54	-00:17:00	-00:11:00	Madison Ave. Bridge	NY
109332	Macombs Dam Bridge, Harlem River, New York Current	NOS	ACT3491_1	40.82830047607422	-73.93499755859375	:America/New_York	USA	knots	0	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	-00:10:00	\N	0.33	00:12:00	\N	0.51	-00:17:00	-00:12:00	Macombs Dam Bridge	NY
109333	High Bridge, Harlem River, New York Current	NOS	ACT3496_1	40.84170150756836	-73.93170166015625	:America/New_York	USA	knots	15	189	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	-00:07:00	\N	0.48	00:06:00	\N	0.6	-00:17:00	-00:13:00	High Bridge	NY
109334	West 207th Street Bridge, Harlem River, New York Current	NOS	ACT3501_1	40.86330032348633	-73.91500091552734	:America/New_York	USA	knots	35	215	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	-00:01:00	\N	0.48	00:03:00	\N	0.6	-00:19:00	-00:12:00	West 207th Street Bridge	NY
109335	Broadway Bridge, Harlem River, New York Current	NOS	ACT3506_1	40.87329864501953	-73.91169738769531	:America/New_York	USA	knots	299	116	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	00:05:00	\N	0.55	00:06:00	\N	0.63	-00:20:00	-00:10:00	Broadway Bridge	NY
109336	Henry Hudson Bridge, 0.7 nmi SE of (depth 16 ft), Harlem River, New York Current	NOS	ACT3511_1	40.87670135498047	-73.92169952392578	:America/New_York	USA	knots	326	137	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107021	00:42:00	\N	0.3	00:29:00	\N	0.23	00:15:00	-00:21:00	Henry Hudson Bridge, 0.7 nmi. SE of	NY
109337	Ponquogue bridge, Shinnecock Bay, Long Island, New York Current	NOS	ACT3531_1	40.845001220703125	-72.50170135498047	:America/New_York	USA	knots	90	250	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	00:38:00	\N	0.4	00:35:00	\N	0.6	01:17:00	00:24:00	Ponquogue bridge, Shinnecock Bay	NY
109338	Shinnecock Inlet, Long Island, New York Current	NOS	ACT3536_1	40.843299865722656	-72.47830200195312	:America/New_York	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-01:02:00	\N	1.44	-00:21:00	\N	1.88	00:17:00	-00:33:00	Shinnecock Inlet	NY
109339	Fire I. Inlet, 0.5 mi S of Oak Beach, Long Island, New York Current	NOS	ACT3541_1	40.62969970703125	-73.30670166015625	:America/New_York	USA	knots	244	82	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	00:00:00	\N	1.5	-00:01:00	\N	1.81	00:20:00	00:26:00	Fire I. Inlet, 0.5 mi. S of Oak Beach	NY
109341	Long Beach, inside, between bridges, Long Island, New York Current	NOS	ACT3551_1	40.595001220703125	-73.66000366210938	:America/New_York	USA	knots	277	76	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	00:01:00	\N	0.38	00:23:00	\N	0.38	00:31:00	00:29:00	Long Beach, inside, between bridges	NY
109342	East Rockaway Inlet, Long Island, New York Current	NOS	ACT3556_1	40.59000015258789	-73.75499725341797	:America/New_York	USA	knots	227	42	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-01:37:00	\N	1.44	-01:35:00	\N	1.66	-01:23:00	-01:06:00	East Rockaway Inlet	NY
109343	Rockaway Point (depth 15 ft), Jamaica Bay, New York Current	NOS	ACT3571_1	40.53630065917969	-73.94129943847656	:America/New_York	USA	knots	140	301	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-03:01:00	\N	0.68	-02:34:00	\N	1.43	-02:13:00	-01:41:00	Rockaway Point	NY
109344	Beach Channel (bridge), Jamaica Bay, New York Current	NOS	ACT3596_1	40.58330154418945	-73.81670379638672	:America/New_York	USA	knots	225	62	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-01:19:00	\N	1.23	-01:13:00	\N	1.43	-01:25:00	-01:00:00	Beach Channel (bridge)	NY
109345	Grass Hassock Channel, Jamaica Bay, New York Current	NOS	ACT3601_1	40.61000061035156	-73.78500366210938	:America/New_York	USA	knots	228	52	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-00:53:00	\N	0.63	-01:02:00	\N	0.75	-00:58:00	-01:00:00	Grass Hassock Channel	NY
109346	Norton Point, WSW of (depth 16 ft), New York Harbor entrance, New York Current	NOS	ACT3611_1	40.55500030517578	-74.02169799804688	:America/New_York	USA	knots	166	341	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	00:28:00	\N	0.77	-01:01:00	\N	0.75	00:10:00	00:23:00	Norton Point, WSW of	NY
109347	Bay Ridge, west of (depth 22 ft), Upper Bay, New York Harbor, New York Current	NOS	ACT3621_1	40.625701904296875	-74.05400085449219	:America/New_York	USA	knots	185	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	01:00:00	\N	0.93	00:20:00	\N	1.04	00:12:00	00:39:00	Bay Ridge, west of	NY
109348	Statue of Liberty, east of, Upper Bay, New York Harbor, New York Current	NOS	ACT3646_1	40.689998626708984	-74.02999877929688	:America/New_York	USA	knots	205	31	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	01:00:00	\N	1.19	00:58:00	\N	1.05	01:20:00	00:53:00	Statue of Liberty, east of	NY
109349	Grants Tomb (depth 18 ft), Hudson River (midchannel), New York Current	NOS	ACT3656_1	40.808	-73.96767	:America/New_York	USA	knots	208	25	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106683	-00:33:00	\N	0.7	-00:22:00	\N	1	-00:13:00	00:11:00	Grants Tomb	NY
109350	Riverdale, Hudson River (midchannel), New York Current	NOS	ACT3671_1	40.9	-73.91667	:America/New_York	USA	knots	200	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106683	00:32:00	\N	0.8	00:27:00	\N	0.8	00:54:00	00:15:00	Riverdale	NY
109351	Mount St. Vincent College, SW of (depth 15 ft), New York Current	NOS	ACT3676_1	40.907	-73.908	:America/New_York	USA	knots	190	7	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106683	00:29:00	\N	0.5	00:20:00	\N	0.8	00:09:00	00:27:00	Mount St. Vincent College, SW of	NY
109352	Dobbs Ferry, Hudson River (midchannel), New York Current	NOS	ACT3681_1	41.01667	-73.88333	:America/New_York	USA	knots	\N	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106683	00:49:00	\N	0.7	00:53:00	\N	0.7	01:13:00	00:37:00	Dobbs Ferry	NY
109353	Tarrytown, Hudson River (midchannel), New York Current	NOS	ACT3691_1	41.08333	-73.88333	:America/New_York	USA	knots	\N	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106683	01:02:00	\N	0.6	01:06:00	\N	0.6	01:20:00	00:53:00	Tarrytown	NY
109354	Ossining, Hudson River (midchannel), New York Current	NOS	ACT3696_1	41.16667	-73.9	:America/New_York	USA	knots	\N	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106683	01:19:00	\N	0.5	01:22:00	\N	0.5	01:33:00	01:16:00	Ossining	NY
109355	Peekskill, Hudson River (midchannel), New York Current	NOS	ACT3711_1	41.28333	-73.95	:America/New_York	USA	knots	\N	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106683	01:42:00	\N	0.5	01:44:00	\N	0.5	01:53:00	01:46:00	Peekskill	NY
109356	Highland Falls, Hudson River (midchannel), New York Current	NOS	ACT3721_1	41.36667	-73.96667	:America/New_York	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106683	02:02:00	\N	0.5	01:57:00	\N	0.6	02:07:00	01:57:00	Highland Falls	NY
109357	West Point, off Duck Island, Hudson River (midchannel), New York Current	NOS	ACT3726_1	41.4	-73.95	:America/New_York	USA	knots	\N	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106683	02:04:00	\N	0.4	02:07:00	\N	0.6	02:15:00	02:04:00	West Point, off Duck Island	NY
109363	New Baltimore, Hudson River (midchannel), New York Current	NOS	ACT3801_1	42.45	-73.78333	:America/New_York	USA	knots	\N	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106685	01:58:00	\N	1.1	02:07:00	\N	1.2	02:07:00	01:58:00	New Baltimore	NY
109364	Sandy Hook Chan., 0.4 mi W of N. Tip, Lower Bay, New York Harbor, New Jersey Current	NOS	ACT3826_1	40.479801177978516	-74.02169799804688	:America/New_York	USA	knots	50	235	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-01:49:00	\N	1	-01:55:00	\N	1.51	-01:28:00	-01:33:00	Sandy Hook Chan., 0.4 mi. W of N. Tip	NJ
109365	New Dorp Beach, 1.2 mi south of, Lower Bay, New York Harbor, New York Current	NOS	ACT3841_1	40.540000915527344	-74.0967025756836	:America/New_York	USA	knots	30	225	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-04:15:00	\N	0.31	-03:36:00	\N	0.3	-03:56:00	-04:38:00	New Dorp Beach, 1.2 miles south of	NY
109366	Old Orchard Shoal Lt., 1.2 mi ENE of, Lower Bay, New York Harbor, New York Current	NOS	ACT3846_1	40.5182991027832	-74.07330322265625	:America/New_York	USA	knots	85	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-02:01:00	\N	0.25	-02:07:00	\N	0.53	-01:56:00	-01:26:00	Old Orchard Shoal Lt., 1.2 mi. ENE of	NY
109367	Coney Island Lt., 1.5 mi SSE of, Lower Bay, New York Harbor, New York Current	NOS	ACT3861_1	40.551700592041016	-74.00499725341797	:America/New_York	USA	knots	125	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-00:52:00	\N	0.81	-01:56:00	\N	0.83	-01:04:00	-01:01:00	Coney Island Lt., 1.5 miles SSE of	NY
109368	Hoffman Island, 0.2 mi west of, Lower Bay, New York Harbor, New York Current	NOS	ACT3866_1	40.58330154418945	-74.06670379638672	:America/New_York	USA	knots	210	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-00:49:00	\N	0.5	-01:48:00	\N	0.68	-01:20:00	-00:20:00	Hoffman Island, 0.2 mile west of	NY
109369	Coney Island Channel, west end, Lower Bay, New York Harbor, New York Current	NOS	ACT3876_1	40.56999969482422	-74.00830078125	:America/New_York	USA	knots	102	293	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-00:47:00	\N	0.75	-00:44:00	\N	0.83	-00:58:00	-00:27:00	Coney Island Channel, west end	NY
109370	Seabright Bridge, Shrewsbury River, New Jersey Current	NOS	ACT3886_1	40.3650016784668	-73.9749984741211	:America/New_York	USA	knots	0	185	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	00:52:00	\N	1.06	01:06:00	\N	1.05	01:18:00	00:49:00	Seabright Bridge, Shrewsbury River	NJ
109371	Raritan Bay Reach Channel (depth 15 ft), New Jersey Current	NOS	ACT3891_1	40.48929977416992	-74.1176986694336	:America/New_York	USA	knots	94	285	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-00:50:00	\N	0.22	-02:40:00	\N	0.44	-01:42:00	-00:41:00	Raritan Bay Reach Channel	NJ
109372	Red Bank, 1.4 mi south of, Raritan Bay, New York Current	NOS	ACT3901_1	40.4817008972168	-74.20999908447266	:America/New_York	USA	knots	79	278	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-01:43:00	\N	0.31	-02:12:00	\N	0.45	-01:22:00	-01:25:00	Red Bank, 1.4 miles south of	NY
109373	Seguine Point (depth 14 ft), Raritan Bay, New York Current	NOS	ACT3906_1	40.50400161743164	-74.185302734375	:America/New_York	USA	knots	79	281	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-02:07:00	\N	0.19	-02:50:00	\N	0.53	-01:39:00	-00:51:00	Seguine Point	NY
109374	Seguine Point (depth 34 ft), Raritan Bay, New York Current	NOS	ACT3906_2	40.50400161743164	-74.185302734375	:America/New_York	USA	knots	105	285	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-02:07:00	\N	0.19	-02:50:00	\N	0.53	-01:39:00	-00:51:00	Seguine Point	NY
109375	Ward Point, ESE (depth 14 ft), Raritan Bay, New York Current	NOS	ACT3911_1	40.48830032348633	-74.22470092773438	:America/New_York	USA	knots	48	244	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-00:53:00	\N	0.34	-01:58:00	\N	0.56	-01:32:00	-00:14:00	Ward Point, ESE	NY
109376	Washington Canal, north entrance, Raritan River, New Jersey Current	NOS	ACT3921_1	40.47169876098633	-74.36830139160156	:America/New_York	USA	knots	60	240	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-02:50:00	\N	0.94	-01:25:00	\N	1.13	-00:49:00	-01:33:00	Washington Canal, north entrance	NJ
109377	South River entrance, Raritan River, New Jersey Current	NOS	ACT3926_1	40.47829818725586	-74.37830352783203	:America/New_York	USA	knots	0	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-01:43:00	\N	0.63	-02:14:00	\N	0.83	-01:32:00	-00:30:00	South River entrance	NJ
109378	Tottenville, Arthur Kill River (depth 15 ft), New York Current	NOS	ACT3931_1	40.513301849365234	-74.25499725341797	:America/New_York	USA	knots	211	23	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-01:22:00	\N	0.68	-01:25:00	\N	0.79	-00:51:00	-00:36:00	Tottenville, Arthur Kill River	NY
109379	Tottenville, Arthur Kill River (depth 32 ft), New York Current	NOS	ACT3931_2	40.513301849365234	-74.25499725341797	:America/New_York	USA	knots	207	26	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-01:02:00	\N	0.29	-01:05:00	\N	0.46	-01:10:00	-00:51:00	Tottenville, Arthur Kill River	NY
109380	Tufts Point-Smoking Point, Arthur Kill, New York Current	NOS	ACT3936_1	40.55670166015625	-74.22329711914062	:America/New_York	USA	knots	267	109	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-01:07:00	\N	0.75	-00:44:00	\N	0.9	-00:25:00	-00:27:00	Tufts Point-Smoking Point	NY
109381	Elizabethport, Arthur Kill, New Jersey Current	NOS	ACT3946_1	40.64670181274414	-74.18170166015625	:America/New_York	USA	knots	262	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	00:05:00	\N	0.69	-00:09:00	\N	1.05	00:28:00	00:29:00	Elizabethport	NJ
109382	Bergen Point, East Reach (depth 15 ft), Kill Van Kull, New York Current	NOS	ACT3956_1	40.64030075073242	-74.12470245361328	:America/New_York	USA	knots	94	274	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-01:43:00	\N	0.73	-02:13:00	\N	0.81	-01:11:00	-01:37:00	Bergen Point, East Reach	NY
109383	South Reach, Newark Bay (depth 15 ft), New Jersey Current	NOS	ACT3966_1	40.65599822998047	-74.13729858398438	:America/New_York	USA	knots	218	31	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-01:05:00	\N	0.46	-01:45:00	\N	0.51	-00:33:00	-00:54:00	South Reach, Newark Bay	NJ
109384	Lincoln Highway Bridge, Hackensack River, Newark Bay, New Jersey Current	NOS	ACT3971_1	40.733299255371094	-74.0999984741211	:America/New_York	USA	knots	181	17	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-00:13:00	\N	0.5	00:12:00	\N	0.68	00:17:00	00:44:00	Lincoln Highway Bridge, Hackensack River	NJ
109385	Lincoln Highway Bridge, Passaic River, Newark Bay, New Jersey Current	NOS	ACT3976_1	40.733299255371094	-74.11669921875	:America/New_York	USA	knots	180	9	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108759	-00:26:00	\N	0.31	-00:19:00	\N	0.45	-00:08:00	-00:15:00	Lincoln Highway Bridge, Passaic River	NJ
109386	Manasquan Inlet, New Jersey Current	NOS	ACT3986_1	40.1	-74.03333	:America/New_York	USA	knots	120	300	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-01:53:00	\N	1.1	-01:09:00	\N	1	-01:03:00	-01:39:00	Manasquan Inlet	NJ
109387	Manasquan R., hwy. bridge, main chan, New Jersey Current	NOS	ACT3991_1	40.1	-74.05	:America/New_York	USA	knots	50	230	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-00:46:00	\N	1.2	-01:29:00	\N	1.3	-01:01:00	-01:42:00	Manasquan R., hwy. bridge, main chan	NJ
109388	Point Pleasant Canal, north bridge, New Jersey Current	NOS	ACT3996_1	40.08333	-74.06667	:America/New_York	USA	knots	350	170	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	01:14:00	\N	1.2	00:49:00	\N	1	01:26:00	00:21:00	Point Pleasant Canal, north bridge	NJ
109389	Barnegat Inlet, New Jersey Current	NOS	ACT4001_1	39.76667	-74.11667	:America/New_York	USA	knots	90	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-00:08:00	\N	1.5	-00:27:00	\N	1.3	00:41:00	-00:12:00	Barnegat Inlet	NJ
109390	Manahawkin Drawbridge, New Jersey Current	NOS	ACT4006_1	39.65	-74.18333	:America/New_York	USA	knots	210	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	03:25:00	\N	0.5	02:04:00	\N	0.6	02:13:00	01:58:00	Manahawkin Drawbridge	NJ
109391	Absecon Inlet (depth 9 ft), New Jersey Current	NOS	ACT4011_1	39.3765	-74.4145	:America/New_York	USA	knots	147	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-02:14:00	\N	1.2	-01:30:00	\N	1.3	-01:27:00	-01:21:00	Absecon Inlet	NJ
109392	Absecon Inlet (depth 42 ft), New Jersey Current	NOS	ACT4011_2	39.3765	-74.4145	:America/New_York	USA	knots	144	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-02:04:00	\N	1.1	-01:45:00	\N	1.1	-01:22:00	-01:23:00	Absecon Inlet	NJ
109393	Five Fathom Bank Traffic Lane (depth 35 ft), New Jersey Current	NOS	ACT4031_1	38.78833	-74.71133	:America/New_York	USA	knots	121	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-01:36:00	\N	0.2	-02:21:00	\N	0.3	-02:10:00	-01:29:00	Five Fathom Bank Traffic Lane	NJ
109394	Five Fathom Bank Traffic Lane (depth 50 ft), New Jersey Current	NOS	ACT4031_2	38.78833	-74.71133	:America/New_York	USA	knots	128	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-02:16:00	\N	0.2	-01:57:00	\N	0.2	-02:44:00	-01:48:00	Five Fathom Bank Traffic Lane	NJ
109395	McCrie Shoal, New Jersey Current	NOS	ACT4036_1	38.85	-74.85	:America/New_York	USA	knots	100	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-01:00:00	\N	0.8	-01:05:00	\N	0.7	-00:54:00	-01:10:00	McCrie Shoal	NJ
109396	Cape May Canal, east end, New Jersey Current	NOS	ACT4046_1	38.95	-74.9	:America/New_York	USA	knots	130	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-02:01:00	\N	1.1	-02:27:00	\N	1.1	-02:07:00	-02:20:00	Cape May Canal, east end	NJ
109397	Cape May Channel, New Jersey Current	NOS	ACT4056_1	38.9	-74.96667	:America/New_York	USA	knots	150	306	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-01:41:00	\N	1.4	-02:09:00	\N	0.9	-01:34:00	-01:38:00	Cape May Channel	NJ
109398	Cape May Point, 1.4 nmi SSW of (depth 15 ft), New Jersey Current	NOS	ACT4061_1	38.90617	-74.978	:America/New_York	USA	knots	130	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-01:43:00	\N	1.1	-01:57:00	\N	0.9	-01:23:00	-01:29:00	Cape May Point, 1.4 n.mi. SSW of	NJ
109399	Cape May Point, 1.4 nmi SSW of (depth 25 ft), New Jersey Current	NOS	ACT4061_2	38.90617	-74.978	:America/New_York	USA	knots	139	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-01:37:00	\N	0.7	-01:44:00	\N	0.6	-01:16:00	-01:27:00	Cape May Point, 1.4 n.mi. SSW of	NJ
109400	Cape May Point, 2.7 nmi SSW of (depth 15 ft), New Jersey Current	NOS	ACT4066_1	38.89	-74.9855	:America/New_York	USA	knots	146	299	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-01:32:00	\N	0.5	-01:47:00	\N	0.7	-01:50:00	-01:14:00	Cape May Point, 2.7 n.mi. SSW of	NJ
109401	Cape Henlopen, 0.7 nmi ESE of (depth 12 ft), Delaware Current	NOS	ACT4076_1	38.7995	-75.08167	:America/New_York	USA	knots	139	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-00:59:00	\N	1.4	-00:32:00	\N	1	-00:25:00	-01:07:00	Cape Henlopen, 0.7 n.mi. ESE of	DE
109402	Cape Henlopen, 0.7 nmi ESE of (depth 70 ft), Delaware Current	NOS	ACT4076_2	38.7995	-75.08167	:America/New_York	USA	knots	150	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-00:40:00	\N	0.4	-00:35:00	\N	0.7	-01:46:00	-00:51:00	Cape Henlopen, 0.7 n.mi. ESE of	DE
109403	Cape Henlopen, 4.8 nmi northeast of (depth 18 ft), New Jersey Current	NOS	ACT4091_1	38.85917	-75.0245	:America/New_York	USA	knots	150	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-00:59:00	\N	1.1	-01:50:00	\N	0.9	-00:43:00	-01:09:00	Cape Henlopen, 4.8 n.mi. northeast of	NJ
109404	Cape Henlopen, 4.8 nmi northeast of (depth 28 ft), New Jersey Current	NOS	ACT4091_2	38.85917	-75.0245	:America/New_York	USA	knots	154	301	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-00:51:00	\N	0.7	-01:39:00	\N	0.6	-01:04:00	-01:11:00	Cape Henlopen, 4.8 n.mi. northeast of	NJ
109405	Breakwater Harbor, Delaware Current	NOS	ACT4101_1	38.79333	-75.10833	:America/New_York	USA	knots	78	266	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-01:10:00	\N	0.5	-01:29:00	\N	0.5	-01:15:00	-01:41:00	Breakwater Harbor	DE
109406	Broadkill Slough (depth 14 ft), Delaware Current	NOS	ACT4111_1	38.89633	-75.2105	:America/New_York	USA	knots	132	314	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-00:55:00	\N	0.4	-00:31:00	\N	0.5	-00:56:00	-00:30:00	Broadkill Slough	DE
109407	Mispillion River mouth, Delaware Current	NOS	ACT4116_1	38.94667	-75.315	:America/New_York	USA	knots	190	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	01:18:00	\N	0.6	01:50:00	\N	0.9	02:14:00	01:22:00	Mispillion River mouth	DE
109408	Bay Shore Channel (north) (depth 13 ft), New Jersey Current	NOS	ACT4121_1	39.078	-74.98133	:America/New_York	USA	knots	183	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-00:04:00	\N	0.4	-00:34:00	\N	0.5	-00:49:00	-00:24:00	Bay Shore Channel (north)	NJ
109409	Big Stone Beach, 2.8 mi southeast of, Delaware Current	NOS	ACT4141_1	38.97833	-75.27667	:America/New_York	USA	knots	145	326	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-01:07:00	\N	0.5	-01:30:00	\N	0.4	-01:04:00	-01:08:00	Big Stone Beach, 2.8 miles southeast of	DE
109410	Big Stone Beach, 2.2 nmi ENE of (depth 15 ft), Delaware Current	NOS	ACT4146_1	39.008	-75.28417	:America/New_York	USA	knots	135	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	00:04:00	\N	0.4	-00:26:00	\N	0.3	-00:13:00	-00:23:00	Big Stone Beach, 2.2 n.mi. ENE of	DE
109411	Fourteen Ft. Bank Lt., 1.4 nmi SSE of (depth 12 ft), New Jersey Current	NOS	ACT4151_1	39.03867	-75.158	:America/New_York	USA	knots	160	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	00:10:00	\N	0.7	-00:36:00	\N	0.7	-00:10:00	-00:14:00	Fourteen Ft. Bank Lt., 1.4 n.mi. SSE of	NJ
109412	Fourteen Ft. Bank Lt., 1.4 nmi SSE of (depth 30 ft), New Jersey Current	NOS	ACT4151_2	39.03867	-75.158	:America/New_York	USA	knots	155	343	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-00:05:00	\N	0.4	-00:32:00	\N	0.5	-00:40:00	-00:17:00	Fourteen Ft. Bank Lt., 1.4 n.mi. SSE of	NJ
109413	Fourteen Ft. Bank Lt., 1.2 mi east of, New Jersey Current	NOS	ACT4156_1	39.055	-75.15833	:America/New_York	USA	knots	174	339	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	00:05:00	\N	0.9	-00:26:00	\N	0.7	-00:10:00	00:02:00	Fourteen Ft. Bank Lt., 1.2 mi. east of	NJ
109414	Deadman Shoal, 3.1 nmi SW of (depth 13 ft), New Jersey Current	NOS	ACT4161_1	39.06667	-75.07033	:America/New_York	USA	knots	173	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-00:19:00	\N	0.4	-00:35:00	\N	0.5	-00:43:00	-00:35:00	Deadman Shoal, 3.1 n.mi. SW of	NJ
109415	Egg Island Flats, New Jersey Current	NOS	ACT4166_1	39.10667	-75.11833	:America/New_York	USA	knots	150	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-01:26:00	\N	0.4	-01:05:00	\N	0.4	-01:13:00	-00:58:00	Egg Island Flats	NJ
109416	Maurice River entrance, New Jersey Current	NOS	ACT4176_1	39.21667	-75.045	:America/New_York	USA	knots	192	12	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	00:39:00	\N	0.6	00:06:00	\N	0.6	00:31:00	00:37:00	Maurice River entrance	NJ
109417	Mauricetown Bridge, Maurice River, New Jersey Current	NOS	ACT4181_1	39.28667	-74.99333	:America/New_York	USA	knots	180	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	00:33:00	\N	1.3	00:48:00	\N	1.4	00:41:00	00:57:00	Mauricetown Bridge, Maurice River	NJ
109418	St. Jones River ent., 1 mi east of, Delaware Current	NOS	ACT4191_1	39.06667	-75.38333	:America/New_York	USA	knots	122	334	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-00:09:00	\N	0.4	-00:40:00	\N	0.3	-00:21:00	-00:16:00	St. Jones River ent., 1 mile east of	DE
109419	Kelly Island, 1.5 mi east of, Delaware Current	NOS	ACT4196_1	39.21333	-75.36167	:America/New_York	USA	knots	164	348	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	00:16:00	\N	0.7	00:11:00	\N	0.5	00:31:00	00:17:00	Kelly Island, 1.5 miles east of	DE
109420	False Egg Island Point, 2 mi off, New Jersey Current	NOS	ACT4206_1	39.19	-75.2	:America/New_York	USA	knots	158	342	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	00:06:00	\N	0.8	-00:35:00	\N	0.6	00:07:00	-00:14:00	False Egg Island Point, 2 miles off	NJ
109421	Ben Davis Pt. Shoal, southwest of (depth 15 ft), New Jersey Current	NOS	ACT4211_1	39.24783	-75.3155	:America/New_York	USA	knots	147	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	01:41:00	\N	1.1	00:51:00	\N	1	01:28:00	01:03:00	Ben Davis Pt. Shoal, southwest of	NJ
109422	Ben Davis Point, 0.8 mi southwest of, New Jersey Current	NOS	ACT4221_1	39.28167	-75.30333	:America/New_York	USA	knots	122	308	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	00:25:00	\N	0.5	00:19:00	\N	0.7	00:37:00	00:46:00	Ben Davis Point, 0.8 mile southwest of	NJ
109423	Cohansey River, 0.5 mi above entrance, New Jersey Current	NOS	ACT4226_1	39.34833	-75.36	:America/New_York	USA	knots	254	74	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	00:53:00	\N	0.8	00:41:00	\N	0.7	01:10:00	01:04:00	Cohansey River, 0.5 mile above entrance	NJ
109424	Smyrna River entrance, Delaware Current	NOS	ACT4241_1	39.365	-75.51333	:America/New_York	USA	knots	70	250	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	01:32:00	\N	0.9	01:02:00	\N	0.7	01:29:00	01:30:00	Smyrna River entrance	DE
109425	Stony Point, channel west of, Delaware Current	NOS	ACT4246_1	39.451698303222656	-75.56330108642578	:America/New_York	USA	knots	151	324	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108666	-01:09:00	\N	0.9	00:00:00	\N	0.8	00:03:00	-00:25:00	Stony Point, channel west of	DE
109426	Appoquinimink River entrance, Delaware Current	NOS	ACT4251_1	39.44670104980469	-75.58170318603516	:America/New_York	USA	knots	48	231	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108666	-01:41:00	\N	0.5	00:05:00	\N	0.6	-00:47:00	-00:41:00	Appoquinimink River entrance	DE
109427	Reedy Island (off end of pier), Delaware Current	NOS	ACT4261_1	39.51169967651367	-75.55670166015625	:America/New_York	USA	knots	194	27	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108666	-00:52:00	\N	1.2	00:11:00	\N	1.3	-00:19:00	-00:09:00	Reedy Island (off end of pier)	DE
109428	Alloway Creek ent., 0.2 mi above, New Jersey Current	NOS	ACT4266_1	39.49829864501953	-75.5250015258789	:America/New_York	USA	knots	325	129	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108666	-02:19:00	\N	0.9	-00:08:00	\N	1.2	-00:59:00	-00:44:00	Alloway Creek ent., 0.2 mile above	NJ
109429	New Bridge, Alloway Creek, New Jersey Current	NOS	ACT4271_1	39.52669906616211	-75.45169830322266	:America/New_York	USA	knots	270	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108666	-00:39:00	\N	0.6	01:07:00	\N	0.7	-00:17:00	00:33:00	New Bridge, Alloway Creek	NJ
109430	Salem River entrance, New Jersey Current	NOS	ACT4296_1	39.56999969482422	-75.50170135498047	:America/New_York	USA	knots	245	62	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108666	-00:06:00	\N	0.7	00:43:00	\N	0.8	00:26:00	00:34:00	Salem River entrance	NJ
109431	Bulkhead Shoal Channel, SE, Del. City (depth 14 ft), Delaware Current	NOS	ACT4301_1	39.57630157470703	-75.57530212402344	:America/New_York	USA	knots	118	299	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108666	-00:33:00	\N	0.9	-00:05:00	\N	1	00:04:00	00:06:00	Bulkhead Shoal Channel, SE, Del. City	DE
109432	Bulkhead Shoal Channel, off Del. City, Delaware Current	NOS	ACT4306_1	39.58330154418945	-75.58670043945312	:America/New_York	USA	knots	138	308	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108666	-00:31:00	\N	0.9	00:08:00	\N	1.2	-00:04:00	00:00:00	Bulkhead Shoal Channel, off Del. City	DE
109433	Finns Point, 0.60 nmi northwest of (depth 16 ft), Delaware Current	NOS	ACT4316_1	39.606201171875	-75.57450103759766	:America/New_York	USA	knots	152	332	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108666	-00:22:00	\N	1	00:18:00	\N	1.2	00:14:00	00:22:00	Finns Point, 0.60 n.mi. Northwest of	DE
109434	Penns Neck, 0.6 mi west of, Delaware Current	NOS	ACT4321_1	39.61750030517578	-75.58200073242188	:America/New_York	USA	knots	167	2	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108666	-00:44:00	\N	0.8	00:48:00	\N	0.9	00:18:00	00:11:00	Penns Neck, 0.6 mile west of	DE
109435	Penns Neck, 0.3 mi west of, Delaware Current	NOS	ACT4326_1	39.617801666259766	-75.57630157470703	:America/New_York	USA	knots	152	339	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108666	-00:38:00	\N	0.8	00:17:00	\N	1	00:02:00	00:05:00	Penns Neck, 0.3 mile west of	DE
109436	Christina River, 0.9 nmi above ent. (depth 15 ft), Delaware Current	NOS	ACT4351_1	39.72169876098633	-75.52950286865234	:America/New_York	USA	knots	137	303	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108666	-00:46:00	\N	0.4	00:26:00	\N	0.1	00:32:00	-00:22:00	Christina River, 0.9 n.mi. above ent	DE
109437	Hog Island, channel southeast of, Pennsylvania Current	NOS	ACT4391_1	39.86669921875	-75.21499633789062	:America/New_York	USA	knots	231	54	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108668	-00:13:00	\N	1.09	-00:03:00	\N	1.27	-00:49:00	00:15:00	Hog Island, channel southeast of	PA
109438	Eagle Point, 0.2 nmi northwest of (depth 17 ft), New Jersey Current	NOS	ACT4406_1	39.88029861450195	-75.1729965209961	:America/New_York	USA	knots	271	91	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108668	-00:29:00	\N	0.87	-00:56:00	\N	1.05	-00:27:00	00:08:00	Eagle Point, 0.2 n.mi. northwest of	NJ
109439	Eagle Point, 0.2 nmi northwest of (depth 40 ft), New Jersey Current	NOS	ACT4406_2	39.88029861450195	-75.1729965209961	:America/New_York	USA	knots	274	90	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108668	-00:29:00	\N	0.64	-01:11:00	\N	0.71	-00:33:00	00:03:00	Eagle Point, 0.2 n.mi. northwest of	NJ
109440	Smith Island Shoal, southeast of (depth 7 ft), Virginia Current	NOS	ACT4496_1	37.08833	-75.725	:America/New_York	USA	knots	68	298	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:41:00	\N	0.4	-01:56:00	\N	0.3	-01:41:00	-02:15:00	Smith Island Shoal, southeast of	VA
109441	Cape Henry Light, 2.2 mi southeast of, Virginia Current	NOS	ACT4501_1	36.89833	-75.97833	:America/New_York	USA	knots	165	346	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:17:00	\N	0.8	-01:02:00	\N	0.9	-01:21:00	-00:50:00	Cape Henry Light, 2.2 miles southeast of	VA
109442	Cape Henry Light, 3.4 nmi NNE of (depth 7 ft), Chesapeake Bay, Virginia Current	NOS	ACT4506_1	36.97983	-75.98083	:America/New_York	USA	knots	116	287	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:08:00	\N	1.5	-00:39:00	\N	0.9	-00:08:00	-00:31:00	Cape Henry Light, 3.4nm NNE of	VA
109443	Cape Henry Light, 3.4 nmi NNE of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4506_2	36.97983	-75.98083	:America/New_York	USA	knots	112	284	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:12:00	\N	1.1	-00:43:00	\N	0.9	-00:19:00	-00:29:00	Cape Henry Light, 3.4nm NNE of	VA
109444	Cape Henry Light, 3.4 nmi NNE of (depth 30 ft), Chesapeake Bay, Virginia Current	NOS	ACT4506_3	36.97983	-75.98083	:America/New_York	USA	knots	104	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:45:00	\N	0.6	-00:38:00	\N	0.5	-00:54:00	-00:43:00	Cape Henry Light, 3.4nm NNE of	VA
109445	Cape Henry Light, 2.35 nmi NNE of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4511_1	36.96233	-75.98567	:America/New_York	USA	knots	116	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:00:00	\N	1.1	-00:06:00	\N	0.9	00:12:00	-00:22:00	Cape Henry Light, 2.35nm NNE of	VA
109446	Cape Henry Light, 2.35 nmi NNE of (depth 30 ft), Chesapeake Bay, Virginia Current	NOS	ACT4511_2	36.96233	-75.98567	:America/New_York	USA	knots	123	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:32:00	\N	0.9	-00:39:00	\N	1.1	-00:41:00	-00:33:00	Cape Henry Light, 2.35nm NNE of	VA
109447	Cape Henry Light, 2.35 nmi NNE of (depth 45 ft), Chesapeake Bay, Virginia Current	NOS	ACT4511_3	36.96233	-75.98567	:America/New_York	USA	knots	125	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:48:00	\N	0.8	-00:47:00	\N	1.3	-01:10:00	-00:30:00	Cape Henry Light, 2.35nm NNE of	VA
109448	Cape Henry Light, 2.35 nmi NNE of (depth 60 ft), Chesapeake Bay, Virginia Current	NOS	ACT4511_4	36.96233	-75.98567	:America/New_York	USA	knots	124	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:03:00	\N	0.7	-00:57:00	\N	1.1	-01:27:00	-00:36:00	Cape Henry Light, 2.35nm NNE of	VA
109449	Cape Henry Light, 1.4 nmi NE of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4516_1	36.9455	-75.98967	:America/New_York	USA	knots	117	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:14:00	\N	1.4	00:05:00	\N	0.8	00:38:00	-00:23:00	Cape Henry Light, 1.4nm NE of	VA
109450	Cape Henry Light, 1.4 nmi NE of (depth 30 ft), Chesapeake Bay, Virginia Current	NOS	ACT4516_2	36.9455	-75.98967	:America/New_York	USA	knots	118	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:03:00	\N	1.1	-00:20:00	\N	1.1	-00:05:00	-00:15:00	Cape Henry Light, 1.4nm NE of	VA
109451	Cape Henry Light, 1.4 nmi NE of (depth 45 ft), Chesapeake Bay, Virginia Current	NOS	ACT4516_3	36.9455	-75.98967	:America/New_York	USA	knots	114	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:08:00	\N	1	-00:30:00	\N	1.1	-00:23:00	-00:10:00	Cape Henry Light, 1.4nm NE of	VA
109452	Cape Henry Light, 1.4 nmi NE of (depth 60 ft), Chesapeake Bay, Virginia Current	NOS	ACT4516_4	36.9455	-75.98967	:America/New_York	USA	knots	107	282	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:18:00	\N	0.9	-00:32:00	\N	0.9	-00:37:00	-00:10:00	Cape Henry Light, 1.4nm NE of	VA
109453	Cape Henry Light, 0.8 nmi NNE of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4521_1	36.93883	-75.99967	:America/New_York	USA	knots	113	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:03:00	\N	1.6	-00:36:00	\N	0.9	00:21:00	-00:44:00	Cape Henry Light, 0.8 n.mi. NNE of	VA
109454	Cape Henry Light, 0.8 nmi NNE of (depth 38 ft), Chesapeake Bay, Virginia Current	NOS	ACT4521_2	36.93883	-75.99967	:America/New_York	USA	knots	106	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:59:00	\N	1.1	-02:20:00	\N	1	-01:47:00	-02:16:00	Cape Henry Light, 0.8 n.mi. NNE of	VA
109455	Cape Henry Light, 3.2 mi north of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4531_1	36.98	-75.998	:America/New_York	USA	knots	129	300	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:07:00	\N	1.1	-00:39:00	\N	0.7	-00:05:00	-00:40:00	Cape Henry Light, 3.2 miles north of	VA
109456	Cape Henry Light, 4.6 mi north of, Chesapeake Bay, Virginia Current	NOS	ACT4536_1	37.00167	-75.98833	:America/New_York	USA	knots	104	294	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:16:00	\N	1.2	-00:30:00	\N	1.2	-00:32:00	-00:21:00	Cape Henry Light, 4.6 miles north of	VA
109457	Cape Henry Light, 5.9 nmi north of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4541_1	37.02333	-75.9925	:America/New_York	USA	knots	140	307	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:43:00	\N	0.7	-00:48:00	\N	0.5	-01:04:00	-01:06:00	Cape Henry Light, 5.9 n.mi. north of	VA
109458	Cape Henry Light, 8.3 mi NW of (depth 12 ft), Chesapeake Bay, Virginia Current	NOS	ACT4546_1	37.03667	-76.11	:America/New_York	USA	knots	133	329	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:19:00	\N	1	00:04:00	\N	0.9	00:11:00	00:05:00	Cape Henry Light, 8.3 mi. NW of	VA
109459	Lynnhaven Roads, Chesapeake Bay, Virginia Current	NOS	ACT4551_1	36.91833	-76.08167	:America/New_York	USA	knots	70	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:17:00	\N	0.8	-00:21:00	\N	0.7	-00:25:00	-00:25:00	Lynnhaven Roads	VA
109460	Lynnhaven Inlet bridge, Chesapeake Bay, Virginia Current	NOS	ACT4556_1	36.90667	-76.09333	:America/New_York	USA	knots	0	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-02:37:00	\N	1.3	-01:49:00	\N	0.5	-01:23:00	-02:23:00	Lynnhaven Inlet bridge	VA
109461	Chesapeake Beach, 1.5 mi north of, Chesapeake Bay Bridge Tunnel, Virginia Current	NOS	ACT4561_1	36.94483	-76.12217	:America/New_York	USA	knots	100	305	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:07:00	\N	0.8	00:09:00	\N	0.7	00:24:00	-00:34:00	Chesapeake Beach, 1.5 miles north of	VA
109462	Tail of the Horseshoe, Chesapeake Bay Bridge Tunnel, Virginia Current	NOS	ACT4571_1	36.99283	-76.10333	:America/New_York	USA	knots	110	300	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:21:00	\N	0.9	-00:09:00	\N	0.8	00:00:00	-00:24:00	Tail of the Horseshoe	VA
109463	Chesapeake Channel (bridge tunnel), Chesapeake Bay Bridge Tunnel, Virginia Current	NOS	ACT4576_1	37.04167	-76.07217	:America/New_York	USA	knots	145	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:12:00	\N	1.4	-00:01:00	\N	1.6	00:00:00	-00:08:00	Chesapeake Channel (bridge tunnel)	VA
109464	Chesapeake Channel (Buoy 15) (depth 13 ft), Chesapeake Bay, Virginia Current	NOS	ACT4581_1	37.05667	-76.093	:America/New_York	USA	knots	125	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:31:00	\N	0.4	-00:06:00	\N	0.5	-00:35:00	00:10:00	Chesapeake Channel (Buoy '15')	VA
109465	Chesapeake Channel (Buoy 15) (depth 34 ft), Chesapeake Bay, Virginia Current	NOS	ACT4581_2	37.05667	-76.093	:America/New_York	USA	knots	139	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:14:00	\N	0.4	-00:12:00	\N	0.5	-00:26:00	00:17:00	Chesapeake Channel (Buoy '15')	VA
109466	Fishermans Island, 3.2 mi WSW of, Chesapeake Bay Bridge Tunnel, Virginia Current	NOS	ACT4586_1	37.06667	-76.0375	:America/New_York	USA	knots	135	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:43:00	\N	1.5	-00:51:00	\N	1.1	-00:27:00	-00:57:00	Fishermans Island, 3.2 miles WSW of	VA
109467	Fishermans Island, 1.4 mi WSW of, Chesapeake Bay Bridge Tunnel, Virginia Current	NOS	ACT4591_1	37.07967	-76.00417	:America/New_York	USA	knots	140	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:09:00	\N	1	-00:41:00	\N	1.6	-01:14:00	-00:52:00	Fishermans Island, 1.4 miles WSW of	VA
109468	Fishermans Island, 2.45 nmi south of (depth 6 ft), Chesapeake Bay, Virginia Current	NOS	ACT4596_1	37.044	-75.96283	:America/New_York	USA	knots	126	301	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:38:00	\N	1.7	-00:59:00	\N	1.1	-00:22:00	-00:57:00	Fishermans Island, 2.45nm south of	VA
109469	Fishermans Island, 2.45 nmi south of (depth 16 ft), Chesapeake Bay, Virginia Current	NOS	ACT4596_2	37.044	-75.96283	:America/New_York	USA	knots	127	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:40:00	\N	1.5	-01:07:00	\N	1.1	-00:39:00	-00:54:00	Fishermans Island, 2.45nm south of	VA
109470	Fishermans Island, 2.45 nmi south of (depth 31 ft), Chesapeake Bay, Virginia Current	NOS	ACT4596_3	37.044	-75.96283	:America/New_York	USA	knots	123	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:53:00	\N	1	-01:11:00	\N	0.9	-01:06:00	-00:53:00	Fishermans Island, 2.45nm south of	VA
109471	Fishermans Island, 1.7 nmi south of (depth 16 ft), Chesapeake Bay, Virginia Current	NOS	ACT4601_1	37.05617	-75.97217	:America/New_York	USA	knots	126	297	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:33:00	\N	1.3	-01:08:00	\N	0.9	-00:24:00	-00:55:00	Fishermans Island, 1.7 n.mi. south of	VA
109472	Fishermans Island, 1.7 nmi south of (depth 26 ft), Chesapeake Bay, Virginia Current	NOS	ACT4601_2	37.05617	-75.97217	:America/New_York	USA	knots	120	290	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:41:00	\N	0.9	-00:58:00	\N	0.7	-00:42:00	-00:56:00	Fishermans Island, 1.7 n.mi. south of	VA
109473	Fishermans Island, 0.5 nmi SW of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4606_1	37.08083	-75.9805	:America/New_York	USA	knots	140	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:42:00	\N	1.8	-00:54:00	\N	1.3	-01:02:00	-01:04:00	Fishermans Island, 0.5 n.mi. SW of	VA
109474	Fishermans I., 0.4 mi west of, Chesapeake Bay Bridge Tunnel, Virginia Current	NOS	ACT4611_1	37.09283	-75.98883	:America/New_York	USA	knots	175	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:49:00	\N	1.9	-00:47:00	\N	1.8	-00:26:00	-00:46:00	Fishermans I., 0.4 mile west of	VA
109475	Fishermans I., 1.4 nmi WNW of (depth 16 ft), Chesapeake Bay, Virginia Current	NOS	ACT4616_1	37.10167	-76.0055	:America/New_York	USA	knots	155	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:34:00	\N	1.1	-00:53:00	\N	1.1	-00:33:00	-00:28:00	Fishermans I., 1.4 n.mi. WNW of	VA
109476	Fishermans I., 1.1 mi northwest of, Chesapeake Bay Bridge Tunnel, Virginia Current	NOS	ACT4621_1	37.10833	-76	:America/New_York	USA	knots	165	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:26:00	\N	1.5	-00:19:00	\N	1.6	-00:44:00	-00:17:00	Fishermans I., 1.1 miles northwest of	VA
109477	Cape Charles, off Wise Point (depth 5 ft), Chesapeake Bay Bridge Tunnel, Virginia Current	NOS	ACT4626_1	37.11467	-75.97167	:America/New_York	USA	knots	75	305	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:13:00	\N	0.2	-00:02:00	\N	0.6	00:04:00	00:16:00	Cape Charles, off Wise Point	VA
109478	Little Creek, 0.2 nmi N of east jetty (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4631_1	36.93417	-76.17667	:America/New_York	USA	knots	92	278	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:08:00	\N	0.3	-01:57:00	\N	0.3	-01:06:00	-01:19:00	Little Creek, 0.2 n.mi. N of east jetty	VA
109479	Butler Bluff, 2.1 nmi WSW of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4636_1	37.15617	-76.02667	:America/New_York	USA	knots	164	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:05:00	\N	0.8	-00:25:00	\N	0.7	-00:03:00	00:17:00	Butler Bluff, 2.1 n.mi. WSW of	VA
109480	York Spit Channel, N of Buoy 26 (depth 7 ft), Chesapeake Bay, Virginia Current	NOS	ACT4641_1	37.215	-76.14167	:America/New_York	USA	knots	195	10	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:19:00	\N	1	01:11:00	\N	0.7	01:28:00	00:44:00	York Spit Channel, N of Buoy '26'	VA
109481	Old Plantation Flats Lt., 0.5 mi W of, Chesapeake Bay, Virginia Current	NOS	ACT4646_1	37.23333	-76.06833	:America/New_York	USA	knots	175	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:59:00	\N	1.2	01:22:00	\N	1.1	01:26:00	01:15:00	Old Plantation Flats Lt., 0.5 mi. W of	VA
109482	Cape Charles City, 3.3 nmi west of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4651_1	37.2645	-76.09367	:America/New_York	USA	knots	187	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:54:00	\N	0.9	00:39:00	\N	0.9	00:33:00	00:23:00	Cape Charles City, 3.3 n.mi. west of	VA
109483	Cape Charles City, 3.3 nmi west of (depth 40 ft), Chesapeake Bay, Virginia Current	NOS	ACT4651_2	37.2645	-76.09367	:America/New_York	USA	knots	182	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:23:00	\N	0.8	00:04:00	\N	0.8	00:11:00	00:30:00	Cape Charles City, 3.3 n.mi. west of	VA
109484	Cape Charles City, 3.3 nmi west of (depth 95 ft), Chesapeake Bay, Virginia Current	NOS	ACT4651_3	37.2645	-76.09367	:America/New_York	USA	knots	138	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:17:00	\N	0.8	00:21:00	\N	0.9	00:24:00	00:57:00	Cape Charles City, 3.3 n.mi. west of	VA
109485	New Point Comfort, 4.1 nmi ESE of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4656_1	37.29	-76.19083	:America/New_York	USA	knots	202	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:39:00	\N	0.9	00:43:00	\N	0.7	01:02:00	00:06:00	New Point Comfort, 4.1 n.mi. ESE of	VA
109486	Wolf Trap Light, 0.5 mi west of, Chesapeake Bay, Virginia Current	NOS	ACT4661_1	37.39	-76.19833	:America/New_York	USA	knots	190	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:29:00	\N	1.1	01:21:00	\N	0.9	01:38:00	00:54:00	Wolf Trap Light, 0.5 mile west of	VA
109487	Wolf Trap Light, 5.8 mi east of, Chesapeake Bay, Virginia Current	NOS	ACT4666_1	37.385	-76.07167	:America/New_York	USA	knots	175	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:09:00	\N	1.2	02:01:00	\N	0.8	02:18:00	01:34:00	Wolf Trap Light, 5.8 miles east of	VA
109488	Church Neck Point, 1.9 nmi W of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4671_1	37.40333	-76.013	:America/New_York	USA	knots	177	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:43:00	\N	0.4	00:58:00	\N	0.4	00:41:00	00:56:00	Church Neck Point, 1.9 n.mi. W of	VA
109489	Wolf Trap Light, 6.1 nmi ENE of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4676_1	37.40833	-76.06383	:America/New_York	USA	knots	191	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:04:00	\N	1	01:19:00	\N	1.2	01:35:00	01:48:00	Wolf Trap Light, 6.1 n.mi. ENE of	VA
109490	Wolf Trap Light, 6.1 nmi ENE of (depth 29 ft), Chesapeake Bay, Virginia Current	NOS	ACT4676_2	37.40833	-76.06383	:America/New_York	USA	knots	173	12	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:00:00	\N	0.7	00:16:00	\N	0.6	00:21:00	00:47:00	Wolf Trap Light, 6.1 n.mi. ENE of	VA
109491	Wolf Trap Light, 5.2 nmi ENE of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4681_1	37.40833	-76.08333	:America/New_York	USA	knots	187	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:02:00	\N	1	01:55:00	\N	1.2	01:38:00	02:01:00	Wolf Trap Light, 5.2 n.mi. ENE of	VA
109492	Wolf Trap Light, 5.2 nmi ENE of (depth 40 ft), Chesapeake Bay, Virginia Current	NOS	ACT4681_2	37.40833	-76.08333	:America/New_York	USA	knots	183	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:12:00	\N	0.7	01:45:00	\N	0.9	01:02:00	02:03:00	Wolf Trap Light, 5.2 n.mi. ENE of	VA
109493	Wolf Trap Light, 5.2 nmi ENE of (depth 63 ft), Chesapeake Bay, Virginia Current	NOS	ACT4681_3	37.40833	-76.08333	:America/New_York	USA	knots	158	343	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:04:00	\N	0.6	00:43:00	\N	0.7	00:19:00	01:25:00	Wolf Trap Light, 5.2 n.mi. ENE of	VA
109494	Wolf Trap Light, 1.4 nmi NNE of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4686_1	37.41117	-76.17617	:America/New_York	USA	knots	175	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:12:00	\N	1.1	01:37:00	\N	1	01:33:00	01:12:00	Wolf Trap Light, 1.4 n.mi. NNE of	VA
109495	Wolf Trap Light, 2.0 nmi NW of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4691_1	37.41667	-76.215	:America/New_York	USA	knots	166	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:01:00	\N	0.6	-00:06:00	\N	0.5	-00:02:00	00:25:00	Wolf Trap Light, 2.0 n.mi. NW of	VA
109496	Nassawadox Point, 1.9 nmi NW of (depth 13 ft), Chesapeake Bay, Virginia Current	NOS	ACT4696_1	37.4995	-75.9895	:America/New_York	USA	knots	178	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:29:00	\N	0.6	01:04:00	\N	0.5	01:11:00	01:16:00	Nassawadox Point, 1.9 n.mi. NW of	VA
109497	Gwynn Island, 8.0 nmi east of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4701_1	37.495	-76.10833	:America/New_York	USA	knots	175	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:26:00	\N	1	02:24:00	\N	0.9	01:58:00	02:08:00	Gwynn Island, 8.0 n.mi. east of	VA
109498	Gwynn Island, 8.0 nmi east of (depth 28 ft), Chesapeake Bay, Virginia Current	NOS	ACT4701_2	37.495	-76.10833	:America/New_York	USA	knots	209	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:16:00	\N	0.5	00:28:00	\N	0.5	00:28:00	01:06:00	Gwynn Island, 8.0 n.mi. east of	VA
109499	Gwynn Island, 1.5 nmi east of (depth 16 ft), Chesapeake Bay, Virginia Current	NOS	ACT4706_1	37.5005	-76.245	:America/New_York	USA	knots	159	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:15:00	\N	0.5	00:15:00	\N	0.4	00:54:00	00:14:00	Gwynn Island, 1.5 n.mi. east of	VA
109500	Stingray Point, 5.5 mi east of, Chesapeake Bay, Virginia Current	NOS	ACT4711_1	37.58333	-76.17333	:America/New_York	USA	knots	179	343	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:25:00	\N	0.8	02:57:00	\N	0.9	02:23:00	02:41:00	Stingray Point, 5.5 miles east of	VA
109501	Stingray Point, 12.5 mi east of, Chesapeake Bay, Virginia Current	NOS	ACT4716_1	37.56333	-76.03833	:America/New_York	USA	knots	175	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:29:00	\N	0.8	02:21:00	\N	0.9	02:13:00	01:29:00	Stingray Point, 12.5 miles east of	VA
109502	Powells Bluff, 2.2 nmi NW of (depth 17 ft), Chesapeake Bay, Virginia Current	NOS	ACT4721_1	37.59083	-76.96833	:America/New_York	USA	knots	201	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:16:00	\N	0.6	00:50:00	\N	0.5	01:16:00	01:14:00	Powells Bluff, 2.2 n.mi. NW of	VA
109503	Windmill Point Light, 8.3 nmi ESE of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4726_1	37.57667	-76.06333	:America/New_York	USA	knots	182	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:39:00	\N	0.8	02:18:00	\N	0.8	02:13:00	02:24:00	Windmill Point Light, 8.3 n.mi. ESE of	VA
109504	Windmill Point Light, 8.3 nmi ESE of (depth 33 ft), Chesapeake Bay, Virginia Current	NOS	ACT4726_2	37.57667	-76.06333	:America/New_York	USA	knots	172	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:07:00	\N	0.4	00:43:00	\N	0.4	01:01:00	02:27:00	Windmill Point Light, 8.3 n.mi. ESE of	VA
109505	Windmill Point Light, 2.2 nmi ESE of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4731_1	37.58833	-76.19167	:America/New_York	USA	knots	169	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:22:00	\N	0.8	01:59:00	\N	0.5	02:44:00	01:41:00	Windmill Point Light, 2.2 n.mi. ESE of	VA
109506	Windmill Point Light, 2.2 nmi ESE of (depth 35 ft), Chesapeake Bay, Virginia Current	NOS	ACT4731_2	37.58833	-76.19167	:America/New_York	USA	knots	175	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:37:00	\N	0.4	00:56:00	\N	0.5	01:03:00	01:21:00	Windmill Point Light, 2.2 n.mi. ESE of	VA
109507	Milby Point, 5.3 nmi WNW of (depth 13 ft), Chesapeake Bay, Virginia Current	NOS	ACT4736_1	37.66417	-76.00867	:America/New_York	USA	knots	210	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:25:00	\N	0.7	01:51:00	\N	0.5	02:08:00	01:48:00	Milby Point, 5.3 n.mi. WNW of	VA
109508	Milby Point, 5.3 nmi WNW of (depth 38 ft), Chesapeake Bay, Virginia Current	NOS	ACT4736_2	37.66417	-76.00867	:America/New_York	USA	knots	197	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:33:00	\N	0.4	-00:27:00	\N	0.4	00:28:00	00:32:00	Milby Point, 5.3 n.mi. WNW of	VA
109509	Bluff Point, 4.6 nmi east of (depth 13 ft), Chesapeake Bay, Virginia Current	NOS	ACT4741_1	37.67833	-76.20417	:America/New_York	USA	knots	178	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:39:00	\N	0.7	02:46:00	\N	0.4	03:05:00	01:45:00	Bluff Point, 4.6 n.mi. east of	VA
109510	Bluff Point, 4.6 nmi east of (depth 33 ft), Chesapeake Bay, Virginia Current	NOS	ACT4741_2	37.67833	-76.20417	:America/New_York	USA	knots	185	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:54:00	\N	0.2	01:22:00	\N	0.4	01:25:00	01:52:00	Bluff Point, 4.6 n.mi. east of	VA
109511	Tangier Sound Light, 5.8 nmi west of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4746_1	37.78383	-76.09467	:America/New_York	USA	knots	185	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:19:00	\N	0.7	03:30:00	\N	0.4	03:29:00	03:16:00	Tangier Sound Light, 5.8 n.mi. west of	VA
109512	Great Wicomico R. Lt., 3.8 nmi ESE of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4751_1	37.78333	-76.19167	:America/New_York	USA	knots	196	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:45:00	\N	0.5	03:38:00	\N	0.4	03:15:00	03:14:00	Great Wicomico R. Lt., 3.8 n.mi. ESE of	VA
109513	Great Wicomico R. Lt., 3.8 nmi ESE of (depth 39 ft), Chesapeake Bay, Virginia Current	NOS	ACT4751_2	37.78333	-76.19167	:America/New_York	USA	knots	196	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:15:00	\N	0.3	02:48:00	\N	0.5	02:06:00	04:10:00	Great Wicomico R. Lt., 3.8 n.mi. ESE of	VA
109514	Smith Point Light, 6.7 nmi east of (depth 9 ft), Chesapeake Bay, Virginia Current	NOS	ACT4756_1	37.8805	-76.04417	:America/New_York	USA	knots	178	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:52:00	\N	0.4	02:18:00	\N	0.4	02:24:00	02:05:00	Smith Point Light, 6.7 n.mi. east of	VA
109515	Smith Point Light, 4.5 nmi east of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4761_1	37.87783	-76.08833	:America/New_York	USA	knots	171	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:28:00	\N	0.7	03:25:00	\N	0.4	03:22:00	03:09:00	Smith Point Light, 4.5 n.mi. east of	VA
109516	Smith Point Light, 4.5 nmi east of (depth 24 ft), Chesapeake Bay, Virginia Current	NOS	ACT4761_2	37.87783	-76.08833	:America/New_York	USA	knots	168	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:59:00	\N	0.5	02:48:00	\N	0.4	03:13:00	02:29:00	Smith Point Light, 4.5 n.mi. east of	VA
109517	Smith Point Light, 3.0 nmi east of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4766_1	37.8775	-76.118	:America/New_York	USA	knots	167	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:25:00	\N	0.7	04:16:00	\N	0.4	04:25:00	03:02:00	Smith Point Light, 3.0 n.mi. east of	VA
109518	Smith Point Light, 3.0 nmi east of (depth 34 ft), Chesapeake Bay, Virginia Current	NOS	ACT4766_2	37.8775	-76.118	:America/New_York	USA	knots	149	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:27:00	\N	0.3	01:43:00	\N	0.4	02:10:00	02:36:00	Smith Point Light, 3.0 n.mi. east of	VA
109519	Smith Point Light, 1.5 nmi east of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4771_1	37.87917	-76.152	:America/New_York	USA	knots	159	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:16:00	\N	0.7	03:54:00	\N	0.4	04:22:00	03:04:00	Smith Point Light, 1.5 n.mi. east of	VA
109520	Smith Point Light, 1.5 nmi east of (depth 39 ft), Chesapeake Bay, Virginia Current	NOS	ACT4771_2	37.87917	-76.152	:America/New_York	USA	knots	176	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:27:00	\N	0.5	03:42:00	\N	0.7	02:44:00	03:49:00	Smith Point Light, 1.5 n.mi. east of	VA
109521	Smith Point Light, 1.5 nmi east of (depth 68 ft), Chesapeake Bay, Virginia Current	NOS	ACT4771_3	37.87917	-76.152	:America/New_York	USA	knots	160	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:30:00	\N	0.3	02:03:00	\N	0.4	02:05:00	03:29:00	Smith Point Light, 1.5 n.mi. east of	VA
109522	Smith Point Light, 0.8 nmi NW of (depth 8 ft), Chesapeake Bay, Virginia Current	NOS	ACT4776_1	37.88717	-76.19833	:America/New_York	USA	knots	150	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:20:00	\N	0.8	02:06:00	\N	0.8	02:23:00	02:33:00	Smith Point Light, 0.8 n.mi. NW of	VA
109523	Smith Point Light, 6 mi north of, Chesapeake Bay, Maryland Current	NOS	ACT4786_1	37.98167	-76.19	:America/New_York	USA	knots	135	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:59:00	\N	0.9	03:51:00	\N	0.4	04:23:00	03:39:00	Smith Point Light, 6 miles north of	MD
109524	Smith Island, 3.6 nmi northwest of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4791_1	38.0075	-76.12133	:America/New_York	USA	knots	187	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:11:00	\N	0.4	02:33:00	\N	0.4	02:43:00	02:59:00	Smith Island, 3.6 n.mi. northwest of	MD
109525	Point Lookout, 5.9 nmi ESE of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4796_1	38.01467	-76.202	:America/New_York	USA	knots	161	340	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:08:00	\N	0.4	04:14:00	\N	0.4	03:40:00	04:17:00	Point Lookout, 5.9 n.mi. ESE of	MD
109526	Point Lookout, 5.9 nmi ESE of (depth 51 ft), Chesapeake Bay, Maryland Current	NOS	ACT4796_2	38.01467	-76.202	:America/New_York	USA	knots	167	330	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:25:00	\N	0.2	03:51:00	\N	0.4	02:40:00	03:56:00	Point Lookout, 5.9 n.mi. ESE of	MD
109527	Point Lookin, Chesapeake Bay, Maryland Current	NOS	ACT4806_1	38.11	-76.21833	:America/New_York	USA	knots	160	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:39:00	\N	0.5	05:31:00	\N	0.4	05:08:00	04:24:00	Point Lookin	MD
109528	Adams Island, 1.1 nmi west of (depth 12 ft), Chesapeake Bay, Maryland Current	NOS	ACT4811_1	38.1445	-76.1145	:America/New_York	USA	knots	191	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:19:00	\N	0.3	03:09:00	\N	0.1	04:30:00	02:17:00	Adams Island, 1.1 n.mi. west of	MD
109529	Adams Island, 3.4 nmi west of (depth 16 ft), Chesapeake Bay, Maryland Current	NOS	ACT4816_1	38.13967	-76.16333	:America/New_York	USA	knots	167	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:31:00	\N	0.4	04:31:00	\N	0.2	04:53:00	03:23:00	Adams Island, 3.4 n.mi west of	MD
109530	Point No Point, 4.3 nmi east of (depth 17 ft), Chesapeake Bay, Maryland Current	NOS	ACT4821_1	38.1355	-76.22917	:America/New_York	USA	knots	170	340	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	05:38:00	\N	0.2	04:54:00	\N	0.3	04:44:00	05:24:00	Point No Point, 4.3 n.mi. east of	MD
109531	Point No Point, 2.8 nmi east of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4826_1	38.13967	-76.26117	:America/New_York	USA	knots	172	340	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:59:00	\N	0.5	04:53:00	\N	0.2	05:16:00	04:04:00	Point No Point, 2.8 n.mi. east of	MD
109532	Point No Point, 2.8 nmi east of (depth 39 ft), Chesapeake Bay, Maryland Current	NOS	ACT4826_2	38.13967	-76.26117	:America/New_York	USA	knots	162	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:47:00	\N	0.2	04:21:00	\N	0.4	03:32:00	05:02:00	Point No Point, 2.8 n.mi. east of	MD
109533	Point No Point, 1.0 nmi east of (depth 17 ft), Chesapeake Bay, Maryland Current	NOS	ACT4831_1	38.1405	-76.30217	:America/New_York	USA	knots	172	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:27:00	\N	0.5	04:27:00	\N	0.3	04:37:00	03:51:00	Point No Point, 1.0 n.mi. east of	MD
109534	Hooper Strait (west), at Buoy 2 (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4836_1	38.22083	-76.10333	:America/New_York	USA	knots	233	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:33:00	\N	0.6	01:49:00	\N	0.5	02:00:00	01:53:00	Hooper Strait (west), at buoy '2'	MD
109535	Cedar Point, 2.9 nmi ENE of (depth 16 ft), Chesapeake Bay, Maryland Current	NOS	ACT4846_1	38.31083	-76.31333	:America/New_York	USA	knots	164	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:55:00	\N	0.8	-02:34:00	\N	0.5	-02:35:00	-03:16:00	Cedar Point, 2.9 n.mi. ENE of	MD
109663	Allmondsville, York River, Virginia Current	NOS	ACT5466_1	37.4	-76.66667	:America/New_York	USA	knots	105	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:13:00	\N	1	00:05:00	\N	1.1	00:43:00	-00:01:00	Allmondsville	VA
109536	Cedar Point, 2.9 nmi ENE of (depth 50 ft), Chesapeake Bay, Maryland Current	NOS	ACT4846_2	38.31083	-76.31333	:America/New_York	USA	knots	141	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-03:15:00	\N	0.3	-03:30:00	\N	0.5	-04:08:00	-03:05:00	Cedar Point, 2.9 n.mi. ENE of	MD
109537	Cedar Point, 1.1 mi ENE of, Chesapeake Bay, Maryland Current	NOS	ACT4851_1	38.3045	-76.35167	:America/New_York	USA	knots	185	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-03:42:00	\N	0.8	-02:50:00	\N	0.5	-03:23:00	-02:36:00	Cedar Point, 1.1 miles ENE of	MD
109538	Cove Point, 1.1 nmi east of (depth 17 ft), Chesapeake Bay, Maryland Current	NOS	ACT4861_1	38.38133	-76.36033	:America/New_York	USA	knots	165	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:14:00	\N	0.9	-02:42:00	\N	0.9	-02:57:00	-02:40:00	Cove Point, 1.1 n.mi. east of	MD
109539	Cove Point, 1.1 nmi east of (depth 40 ft), Chesapeake Bay, Maryland Current	NOS	ACT4861_2	38.38133	-76.36033	:America/New_York	USA	knots	165	343	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-03:26:00	\N	0.7	-03:19:00	\N	0.8	-03:22:00	-02:38:00	Cove Point, 1.1 n.mi. east of	MD
109540	Cove Point, 2.7 nmi east of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_1	38.38	-76.32533	:America/New_York	USA	knots	169	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:40:00	\N	0.9	-02:41:00	\N	0.5	-02:23:00	-02:59:00	Cove Point, 2.7 n.mi. east of	MD
109541	Cove Point, 2.7 nmi east of (depth 40 ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_2	38.38	-76.32533	:America/New_York	USA	knots	170	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:40:00	\N	0.6	-02:39:00	\N	0.9	-03:15:00	-01:53:00	Cove Point, 2.7 n.mi. east of	MD
109542	Cove Point, 2.7 nmi east of (depth 98 ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_3	38.38	-76.32533	:America/New_York	USA	knots	165	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-03:36:00	\N	0.5	-04:02:00	\N	0.7	-03:49:00	-03:13:00	Cove Point, 2.7 n.mi. east of	MD
109543	Cove Point, 3.9 nmi east of (depth 11 ft), Chesapeake Bay, Maryland Current	NOS	ACT4871_1	38.37533	-76.29867	:America/New_York	USA	knots	171	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-03:44:00	\N	0.6	-03:36:00	\N	0.4	-03:29:00	-04:08:00	Cove Point, 3.9 n.mi. east of	MD
109544	Cove Point, 4.9 nmi NNE of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_1	38.46717	-76.37667	:America/New_York	USA	knots	159	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:26:00	\N	0.7	-02:29:00	\N	0.7	-02:57:00	-02:24:00	Cove Point, 4.9 n.mi. NNE of	MD
109545	Cove Point, 4.9 nmi NNE of (depth 40 ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_2	38.46717	-76.37667	:America/New_York	USA	knots	149	332	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:17:00	\N	0.4	-02:47:00	\N	1	-03:23:00	-01:58:00	Cove Point, 4.9 n.mi. NNE of	MD
109546	Cove Point, 4.9 nmi NNE of (depth 67 ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_3	38.46717	-76.37667	:America/New_York	USA	knots	135	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:58:00	\N	0.4	-03:38:00	\N	0.6	-03:55:00	-02:14:00	Cove Point, 4.9 n.mi. NNE of	MD
109547	Kenwood Beach, 1.5 mi northeast of, Chesapeake Bay, Maryland Current	NOS	ACT4881_1	38.51833	-76.48167	:America/New_York	USA	knots	160	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:37:00	\N	0.4	-02:41:00	\N	0.2	-01:56:00	-02:46:00	Kenwood Beach, 1.5 miles northeast of	MD
109548	James Island, 3.4 mi west of, Chesapeake Bay, Maryland Current	NOS	ACT4891_1	38.525	-76.42	:America/New_York	USA	knots	175	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:02:00	\N	0.4	-02:39:00	\N	0.5	-02:16:00	-03:01:00	James Island, 3.4 miles west of	MD
109549	James Island, 2.5 mi WNW of, Chesapeake Bay, Maryland Current	NOS	ACT4896_1	38.53333	-76.39333	:America/New_York	USA	knots	175	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:36:00	\N	0.6	-02:42:00	\N	0.5	-02:31:00	-02:18:00	James Island, 2.5 miles WNW of	MD
109550	Plum Point, 1.4 mi ESE of, Chesapeake Bay, Maryland Current	NOS	ACT4901_1	38.6125	-76.4775	:America/New_York	USA	knots	155	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:04:00	\N	0.7	-01:37:00	\N	0.2	-01:31:00	-02:20:00	Plum Point, 1.4 miles ESE of	MD
109551	Sharp Island Lt., 2.3 nmi SE of (depth 20 ft), Chesapeake Bay, Maryland Current	NOS	ACT4906_1	38.60717	-76.348	:America/New_York	USA	knots	203	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:54:00	\N	0.7	-03:34:00	\N	0.8	-03:15:00	-03:07:00	Sharp Island Lt., 2.3 n.mi. SE of	MD
109552	Sharp Island Lt., 2.1 nmi west of (depth 18 ft), Chesapeake Bay, Maryland Current	NOS	ACT4911_1	38.64333	-76.42033	:America/New_York	USA	knots	183	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-01:33:00	\N	0.5	-01:36:00	\N	0.4	-01:49:00	-01:33:00	Sharp Island Lt., 2.1 n.mi. west of	MD
109553	Sharp Island Lt., 3.4 nmi west of (depth 18 ft), Chesapeake Bay, Maryland Current	NOS	ACT4916_1	38.64383	-76.448	:America/New_York	USA	knots	186	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-01:43:00	\N	0.5	-01:41:00	\N	0.4	-01:39:00	-01:57:00	Sharp Island Lt., 3.4 n.mi. west of	MD
109554	Sharp Island Lt., 3.4 nmi west of (depth 35 ft), Chesapeake Bay, Maryland Current	NOS	ACT4916_2	38.64383	-76.448	:America/New_York	USA	knots	183	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:24:00	\N	0.4	-02:23:00	\N	0.4	-02:34:00	-02:23:00	Sharp Island Lt., 3.4 n.mi. west of	MD
109555	Plum Point, 2.1 nmi NNE of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4921_1	38.645	-76.48717	:America/New_York	USA	knots	174	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:01:00	\N	0.5	-01:51:00	\N	0.4	-01:50:00	-01:51:00	Plum Point, 2.1 n.mi. NNE of	MD
109556	Poplar Island, 2.2 nmi WSW of (depth 14 ft), Chesapeake Bay, Maryland Current	NOS	ACT4926_1	38.75617	-76.4295	:America/New_York	USA	knots	185	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:49:00	\N	0.8	-01:26:00	\N	0.6	-00:44:00	-00:57:00	Poplar Island, 2.2 n.mi. WSW of	MD
109557	Poplar Island, 3.0 nmi WSW of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4931_1	38.74967	-76.4455	:America/New_York	USA	knots	189	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-01:08:00	\N	0.5	-01:22:00	\N	0.6	-01:08:00	-00:59:00	Poplar Island, 3.0 n.mi. WSW of	MD
109558	Poplar Island, 3.0 nmi WSW of (depth 48 ft), Chesapeake Bay, Maryland Current	NOS	ACT4931_2	38.74967	-76.4455	:America/New_York	USA	knots	172	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:13:00	\N	0.4	01:21:00	\N	0.5	00:58:00	02:01:00	Poplar Island, 3.0 n.mi. WSW of	MD
109559	Holland Point, 2.0 nmi east of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4936_1	38.75167	-76.49883	:America/New_York	USA	knots	180	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-01:39:00	\N	0.4	-01:24:00	\N	0.2	-01:20:00	-01:45:00	Holland Point, 2.0 n.mi east of	MD
109560	Kent Point, 4 mi southwest of, Chesapeake Bay, Maryland Current	NOS	ACT4941_1	38.79167	-76.43333	:America/New_York	USA	knots	210	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-01:05:00	\N	0.6	-01:04:00	\N	0.6	-01:03:00	-01:11:00	Kent Point, 4 miles southwest of	MD
109561	Kent Point, 1.3 mi south of, Chesapeake Bay, Maryland Current	NOS	ACT4946_1	38.81667	-76.36417	:America/New_York	USA	knots	235	55	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-03:47:00	\N	0.5	-03:38:00	\N	0.6	-03:27:00	-03:53:00	Kent Point, 1.3 miles south of	MD
109562	Horseshoe Point, 1.7 mi east of, Chesapeake Bay, Maryland Current	NOS	ACT4951_1	38.83833	-76.45333	:America/New_York	USA	knots	200	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-01:10:00	\N	0.6	-00:39:00	\N	0.6	-00:52:00	-00:49:00	Horseshoe Point, 1.7 miles east of	MD
109563	Bloody Point Bar Light, 0.6 mi NW of (depth 19 ft), Chesapeake Bay, Maryland Current	NOS	ACT4956_1	38.8395	-76.40283	:America/New_York	USA	knots	190	35	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:05:00	\N	0.6	-00:23:00	\N	0.9	-00:08:00	00:02:00	Bloody Point Bar Light, 0.6 mi. NW of	MD
109564	Thomas Pt. Shoal Lt., 1.8 mi SW of, Chesapeake Bay, Maryland Current	NOS	ACT4961_1	38.875	-76.46167	:America/New_York	USA	knots	190	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:17:00	\N	0.4	-02:27:00	\N	0.5	-02:24:00	-01:43:00	Thomas Pt. Shoal Lt., 1.8 mi. SW of	MD
109565	Thomas Pt. Shoal Lt., 2.0 nmi east of (depth 22 ft), Chesapeake Bay, Maryland Current	NOS	ACT4966_1	38.89583	-76.38683	:America/New_York	USA	knots	186	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:20:00	\N	0.6	-00:14:00	\N	0.6	-01:05:00	-00:22:00	Thomas Pt. Shoal Lt., 2.0 n.mi. east of	MD
109566	Thomas Pt. Shoal Lt., 0.5 nmi SE of (depth 16 ft), Chesapeake Bay, Maryland Current	NOS	ACT4971_1	38.891	-76.427	:America/New_York	USA	knots	191	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:41:00	\N	1.3	-00:09:00	\N	1	-00:25:00	-00:43:00	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of	MD
109664	Purtan Island, 0.2 mi southwest of, York River, Virginia Current	NOS	ACT5471_1	37.41467	-76.687	:America/New_York	USA	knots	104	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:46:00	\N	1	00:26:00	\N	1.2	00:44:00	00:18:00	Purtan Island, 0.2 mile southwest of	VA
109567	Thomas Pt. Shoal Lt., 0.5 nmi SE of (depth 33 ft), Chesapeake Bay, Maryland Current	NOS	ACT4971_2	38.891	-76.427	:America/New_York	USA	knots	196	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-01:20:00	\N	0.7	-01:18:00	\N	0.7	-00:54:00	-01:25:00	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of	MD
109568	Tolly Point, 1.6 mi east of, Chesapeake Bay, Maryland Current	NOS	ACT4976_1	38.9345	-76.417	:America/New_York	USA	knots	190	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:24:00	\N	0.9	-00:19:00	\N	0.6	-00:03:00	-00:32:00	Tolly Point, 1.6 miles east of	MD
109569	Chesapeake Bay Bridge, main channel, Maryland Current	NOS	ACT4981_1	38.99167	-76.385	:America/New_York	USA	knots	230	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:13:00	\N	1.1	00:08:00	\N	0.9	00:16:00	-00:17:00	Chesapeake Bay Bridge, main channel	MD
109570	Sandy Point, 2.3 nmi east of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4986_1	39.00267	-76.34883	:America/New_York	USA	knots	199	20	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:29:00	\N	0.9	00:15:00	\N	1.1	00:19:00	00:13:00	Sandy Point, 2.3 n.mi. east of	MD
109571	Sandy Point, 2.3 nmi east of (depth 41 ft), Chesapeake Bay, Maryland Current	NOS	ACT4986_2	39.00267	-76.34883	:America/New_York	USA	knots	210	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:39:00	\N	0.6	-01:14:00	\N	0.8	-01:33:00	-00:48:00	Sandy Point, 2.3 n.mi. east of	MD
109572	Sandy Point, 0.8 nmi ESE of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4991_1	39.004	-76.38	:America/New_York	USA	knots	199	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:05:00	\N	1.5	00:24:00	\N	1.2	-00:11:00	-00:15:00	Sandy Point, 0.8 n.mi. ESE of	MD
109573	Sandy Point, 0.8 nmi ESE of (depth 43 ft), Chesapeake Bay, Maryland Current	NOS	ACT4991_2	39.004	-76.38	:America/New_York	USA	knots	197	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-01:02:00	\N	1	-01:10:00	\N	1	-00:59:00	-00:59:00	Sandy Point, 0.8 n.mi. ESE of	MD
109574	Craighill Channel entrance, Buoy 2C (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT5001_1	39.04033	-76.37783	:America/New_York	USA	knots	182	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:09:00	\N	0.9	00:26:00	\N	1	-00:04:00	00:01:00	Craighill Channel entrance, Buoy '2C'	MD
109575	Craighill Channel entrance, Buoy 2C (depth 38 ft), Chesapeake Bay, Maryland Current	NOS	ACT5001_2	39.04033	-76.37783	:America/New_York	USA	knots	147	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:18:00	\N	0.6	00:01:00	\N	0.5	00:00:00	-00:06:00	Craighill Channel entrance, Buoy '2C'	MD
109576	Love Point, 2.5 mi north of, Chesapeake Bay, Maryland Current	NOS	ACT5011_1	39.07967	-76.31217	:America/New_York	USA	knots	240	55	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:07:00	\N	0.5	00:19:00	\N	0.8	-00:48:00	00:27:00	Love Point, 2.5 miles north of	MD
109577	Craighill Channel, NE of Mountain Pt, Chesapeake Bay, Maryland Current	NOS	ACT5021_1	39.08133	-76.3945	:America/New_York	USA	knots	175	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:34:00	\N	0.9	00:40:00	\N	0.8	00:28:00	00:25:00	Craighill Channel, NE of Mountain Pt	MD
109578	Craighill Channel, Belvidere Shoal (depth 18 ft), Chesapeake Bay, Maryland Current	NOS	ACT5026_1	39.09467	-76.393	:America/New_York	USA	knots	186	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:19:00	\N	0.6	00:46:00	\N	0.7	00:10:00	00:33:00	Craighill Channel, Belvidere Shoal	MD
109579	Craighill Angle, right outside quarter, Chesapeake Bay, Maryland Current	NOS	ACT5031_1	39.12833	-76.38783	:America/New_York	USA	knots	170	345	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:23:00	\N	0.6	00:27:00	\N	0.6	00:12:00	00:34:00	Craighill Angle, right outside quarter	MD
109580	Swan Point, 2.7 nmi SW of (depth 14 ft), Chesapeake Bay, Maryland Current	NOS	ACT5036_1	39.108	-76.30533	:America/New_York	USA	knots	170	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:25:00	\N	0.5	00:42:00	\N	0.6	00:18:00	00:38:00	Swan Point, 2.7 n.mi. SW of	MD
109581	Swan Point, 2.7 nmi SW of (depth 27 ft), Chesapeake Bay, Maryland Current	NOS	ACT5036_2	39.108	-76.30533	:America/New_York	USA	knots	142	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:25:00	\N	0.4	00:30:00	\N	0.6	-00:27:00	01:17:00	Swan Point, 2.7 n.mi. SW of	MD
109582	Swan Point, 1.6 mi northwest of, Chesapeake Bay, Maryland Current	NOS	ACT5046_1	39.1625	-76.30467	:America/New_York	USA	knots	215	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:57:00	\N	0.9	00:44:00	\N	0.8	00:53:00	00:38:00	Swan Point, 1.6 miles northwest of	MD
109583	Brewerton Channel Eastern Ext., Buoy 7 (depth 14 ft), Chesapeake Bay, Maryland Current	NOS	ACT5051_1	39.163	-76.38967	:America/New_York	USA	knots	175	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:05:00	\N	0.4	-00:02:00	\N	0.5	00:16:00	-00:14:00	Brewerton Channel Eastern Ext., Buoy '7'	MD
109584	Tolchester Channel, SW of Buoy 58B (depth 17 ft), Chesapeake Bay, Maryland Current	NOS	ACT5056_1	39.1825	-76.28117	:America/New_York	USA	knots	229	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:54:00	\N	1.1	00:20:00	\N	1.1	00:44:00	00:48:00	Tolchester Channel, SW of Bouy '58B'	MD
109585	Tolchester Channel, SW of Buoy 58B (depth 25 ft), Chesapeake Bay, Maryland Current	NOS	ACT5056_2	39.1825	-76.28117	:America/New_York	USA	knots	217	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:48:00	\N	0.7	00:02:00	\N	0.9	-00:09:00	00:38:00	Tolchester Channel, SW of Bouy '58B'	MD
109586	Tolchester Channel, Buoy 22 (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT5061_1	39.19117	-76.26583	:America/New_York	USA	knots	231	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:23:00	\N	0.8	01:10:00	\N	0.9	01:43:00	00:59:00	Tolchester Channel, Buoy '22'	MD
109587	Tolchester Channel, south of Buoy 38B (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT5066_1	39.19283	-76.28783	:America/New_York	USA	knots	208	28	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:50:00	\N	0.8	01:08:00	\N	0.7	00:51:00	00:59:00	Tolchester Channel, south of Buoy '38B'	MD
109588	North Point, 2.5 mi northeast of (depth 7 ft), Chesapeake Bay, Maryland Current	NOS	ACT5071_1	39.2145	-76.39533	:America/New_York	USA	knots	225	35	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:06:00	\N	0.5	01:00:00	\N	0.4	01:25:00	00:53:00	North Point, 2.5 miles northeast of	MD
109589	Tolchester Beach, 0.33 nmi west of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT5076_1	39.21717	-76.24833	:America/New_York	USA	knots	201	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:24:00	\N	1.1	01:20:00	\N	1.2	00:49:00	01:22:00	Tolchester Beach, 0.33 n.mi. west of	MD
109590	Pooles Island, 4 mi southwest of, Chesapeake Bay, Maryland Current	NOS	ACT5081_1	39.22667	-76.33133	:America/New_York	USA	knots	210	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:12:00	\N	0.8	00:48:00	\N	0.6	00:59:00	00:56:00	Pooles Island, 4 miles southwest of	MD
109591	Pooles Island 2.0 nmi SSW of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT5086_1	39.24633	-76.29667	:America/New_York	USA	knots	238	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:29:00	\N	0.7	00:58:00	\N	0.7	01:01:00	01:03:00	Pooles Island 2.0 n.mi. SSW of	MD
109592	Pooles Island, 0.8 mi south of, Chesapeake Bay, Maryland Current	NOS	ACT5091_1	39.26167	-76.27333	:America/New_York	USA	knots	255	60	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:20:00	\N	1.2	01:24:00	\N	0.9	01:29:00	01:12:00	Pooles Island, 0.8 mile south of	MD
109593	Miller Island, 1.5 mi ENE of (depth 7 ft), Chesapeake Bay, Maryland Current	NOS	ACT5096_1	39.275	-76.33167	:America/New_York	USA	knots	185	0	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:25:00	\N	0.3	00:15:00	\N	0.6	00:11:00	00:37:00	Miller Island, 1.5 miles ENE of	MD
109594	Pooles Island, 1.6 nmi east of (depth 16 ft), Chesapeake Bay, Maryland Current	NOS	ACT5101_1	39.2745	-76.22617	:America/New_York	USA	knots	208	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:03:00	\N	1.1	01:34:00	\N	1.1	01:28:00	01:45:00	Pooles Island, 1.6 n.mi. east of	MD
109595	Robins Point, 0.7 mi ESE of (depth 5 ft), Chesapeake Bay, Maryland Current	NOS	ACT5106_1	39.29583	-76.26833	:America/New_York	USA	knots	210	25	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:13:00	\N	1	-00:14:00	\N	1.4	-00:03:00	00:37:00	Robins Point, 0.7 mile ESE of	MD
109596	Worton Point, 1.5 nmi WSW of (depth 17 ft), Chesapeake Bay, Maryland Current	NOS	ACT5111_1	39.31167	-76.21717	:America/New_York	USA	knots	211	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:36:00	\N	1.1	01:45:00	\N	1	02:04:00	01:27:00	Worton Point, 1.5 n.mi. WSW of	MD
109597	Worton Point, 1.1 mi northwest of, Chesapeake Bay, Maryland Current	NOS	ACT5116_1	39.33167	-76.2	:America/New_York	USA	knots	245	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:32:00	\N	1.5	01:43:00	\N	1.4	01:43:00	01:38:00	Worton Point, 1.1 miles northwest of	MD
109598	Howell Point, 0.8 nmi west of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT5121_1	39.3705	-76.13	:America/New_York	USA	knots	235	51	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:33:00	\N	1.3	01:48:00	\N	1	02:30:00	01:19:00	Howell Point, 0.8 n.mi. west of	MD
109599	Howell Point, 0.4 mi NNW of, Chesapeake Bay, Maryland Current	NOS	ACT5126_1	39.37667	-76.115	:America/New_York	USA	knots	245	80	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:18:00	\N	1.1	01:24:00	\N	1.1	01:28:00	01:20:00	Howell Point, 0.4 mile NNW of	MD
109600	Grove Point, 0.7 nmiNW of (depth 14 ft), Chesapeake Bay, Maryland Current	NOS	ACT5131_1	39.39633	-76.05033	:America/New_York	USA	knots	211	34	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	02:03:00	\N	1	02:01:00	\N	0.6	02:40:00	01:31:00	Grove Point, 0.7 n.mi.NW of	MD
109601	Turkey Point, 1.2 nmi SW of (depth 9 ft), Chesapeake Bay, Maryland Current	NOS	ACT5136_1	39.44333	-76.03383	:America/New_York	USA	knots	193	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:00:00	\N	0.8	01:30:00	\N	0.6	02:39:00	00:58:00	Turkey Point, 1.2 n.mi. SW of	MD
109602	Spesutie Island, channel north of (depth 7 ft), Chesapeake Bay, Maryland Current	NOS	ACT5141_1	39.4805	-76.08167	:America/New_York	USA	knots	100	285	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:40:00	\N	0.6	01:20:00	\N	0.8	01:42:00	01:49:00	Spesutie Island, channel north of	MD
109603	Rocky Pt. (Elk Neck), 0.25 nmi SW of (depth 9 ft), Chesapeake Bay, Maryland Current	NOS	ACT5146_1	39.48833	-75.9975	:America/New_York	USA	knots	196	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:49:00	\N	0.7	01:28:00	\N	0.6	02:42:00	01:14:00	Rocky Pt. (Elk Neck), 0.25 n.mi. SW of	MD
109604	Red Point, 0.2 mi W of, Northeast River (depth 7 ft), Chesapeake Bay, Maryland Current	NOS	ACT5151_1	39.52917	-75.98467	:America/New_York	USA	knots	\N	\N	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:47:00	\N	0.6	01:28:00	\N	0.9	01:42:00	01:57:00	Red Point, 0.2 mile W of, Northeast River	MD
109605	Thimble Shoal Channel (west end) (depth 15 ft), Hampton Roads, Virginia Current	NOS	ACT5161_1	37.00533	-76.22667	:America/New_York	USA	knots	116	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:24:00	\N	1.1	-00:27:00	\N	0.8	-00:20:00	-00:42:00	Thimble Shoal Channel (west end)	VA
109606	0.55 nmi east of (depth 48 ft), Old Point Comfort, Hampton Roads, Virginia Current	NOS	ACT5171_1	37.002	-76.29533	:America/New_York	USA	knots	60	251	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-02:18:00	\N	0.6	-01:11:00	\N	1.3	-03:07:00	-00:23:00	0.55 n.mi. east of	VA
109607	0.2 mi south of, Old Point Comfort, Hampton Roads, Virginia Current	NOS	ACT5176_1	36.99617	-76.31467	:America/New_York	USA	knots	75	240	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:32:00	\N	1.3	-01:04:00	\N	1.5	-00:42:00	-01:33:00	0.2 mile south of	VA
109608	0.9 mi southwest of, Old Point Comfort, Hampton Roads, Virginia Current	NOS	ACT5181_1	36.98883	-76.32617	:America/New_York	USA	knots	50	240	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:18:00	\N	1.4	-00:53:00	\N	1.5	-00:58:00	-00:41:00	0.9 mile southwest of	VA
109609	Willoughby Spit, 0.8 mi northwest of, Hampton Roads, Virginia Current	NOS	ACT5186_1	36.97667	-76.30667	:America/New_York	USA	knots	40	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-02:01:00	\N	0.9	-02:09:00	\N	0.6	-01:37:00	-02:21:00	Willoughby Spit, 0.8 mile northwest of	VA
109610	Willoughby Bay entrance, Hampton Roads, Virginia Current	NOS	ACT5191_1	36.96167	-76.29833	:America/New_York	USA	knots	330	135	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-02:26:00	\N	0.4	-02:34:00	\N	0.3	-02:17:00	-03:01:00	Willoughby Bay entrance	VA
109611	Norfolk Harbor Reach (Buoy R8) (depth 13 ft), Hampton Roads, Virginia Current	NOS	ACT5201_1	36.95	-76.3395	:America/New_York	USA	knots	11	183	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:23:00	\N	0.8	-01:21:00	\N	0.5	-00:23:00	-02:16:00	Norfolk Harbor Reach (Buoy R '8')	VA
109612	Norfolk Harbor Reach (Buoy R8) (depth 42 ft), Hampton Roads, Virginia Current	NOS	ACT5201_2	36.95	-76.3395	:America/New_York	USA	knots	0	152	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:57:00	\N	0.3	-01:39:00	\N	0.4	-00:38:00	-01:02:00	Norfolk Harbor Reach (Buoy R '8')	VA
109613	Sewells Point, pierhead (depth 7 ft), Hampton Roads, Virginia Current	NOS	ACT5206_1	36.94667	-76.335	:America/New_York	USA	knots	10	195	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:11:00	\N	0.8	-01:19:00	\N	0.5	-00:57:00	-01:41:00	Sewells Point, pierhead	VA
109614	Channel, middle (depth 15 ft), Newport News, Hampton Roads, Virginia Current	NOS	ACT5211_1	36.95633	-76.38167	:America/New_York	USA	knots	76	244	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:08:00	\N	1	-01:02:00	\N	1	-00:48:00	-00:52:00	Channel, middle	VA
109615	Middle Ground, 1 mi south of (depth 7 ft), Newport News, Hampton Roads, Virginia Current	NOS	ACT5221_1	36.93333	-76.38667	:America/New_York	USA	knots	100	270	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:19:00	\N	1.1	00:11:00	\N	1	00:28:00	-00:16:00	Middle Ground, 1 mile south of	VA
109616	Craney Island (depth 15 ft), Elizabeth River, Virginia Current	NOS	ACT5226_1	36.89467	-76.33583	:America/New_York	USA	knots	1	177	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:55:00	\N	0.8	-01:54:00	\N	0.6	-01:22:00	-02:33:00	Craney Island	VA
109617	Lamberts Point (depth 15 ft), Elizabeth River, Virginia Current	NOS	ACT5236_1	36.875	-76.3325	:America/New_York	USA	knots	328	143	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:57:00	\N	0.7	-02:00:00	\N	0.4	-02:08:00	-02:34:00	Lamberts Point	VA
109618	West Norfolk Bridge, Western Branch, Elizabeth River, Virginia Current	NOS	ACT5241_1	36.85833	-76.34333	:America/New_York	USA	knots	80	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-02:11:00	\N	0.7	-02:19:00	\N	0.5	-02:06:00	-02:46:00	West Norfolk Bridge, Western Branch	VA
109619	Seaboard Coast Line RR, Pinner Point, Elizabeth River, Virginia Current	NOS	ACT5246_1	36.86	-76.31667	:America/New_York	USA	knots	290	140	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-02:16:00	\N	0.4	-02:14:00	\N	0.4	-02:13:00	-02:11:00	Seaboard Coast Line RR, Pinner Point	VA
109620	Berkley Bridge, Eastern Branch, Elizabeth River, Virginia Current	NOS	ACT5251_1	36.84167	-76.28333	:America/New_York	USA	knots	295	120	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-02:56:00	\N	0.4	-02:10:00	\N	0.3	-02:30:00	-02:16:00	Berkley Bridge, Eastern Branch	VA
109621	Norfolk and Western RR. Bridge, E Branch, Elizabeth River, Virginia Current	NOS	ACT5256_1	36.83667	-76.245	:America/New_York	USA	knots	280	100	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:46:00	\N	0.6	-01:54:00	\N	0.4	-01:37:00	-02:21:00	Norfolk and Western RR. Bridge, E Branch	VA
109622	Berkley, Southern Branch, Elizabeth River, Virginia Current	NOS	ACT5261_1	36.83333	-76.29667	:America/New_York	USA	knots	330	215	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-02:34:00	\N	0.3	-01:56:00	\N	0.3	-02:28:00	-02:08:00	Berkley, Southern Branch	VA
109623	Chesapeake, Southern Branch, Elizabeth River, Virginia Current	NOS	ACT5266_1	36.80833	-76.29	:America/New_York	USA	knots	0	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-02:00:00	\N	0.6	-01:55:00	\N	0.6	-02:03:00	-02:10:00	Chesapeake, Southern Branch	VA
109624	Gilmerton Hwy. bridge, Southern Branch, Elizabeth River, Virginia Current	NOS	ACT5271_1	36.775	-76.295	:America/New_York	USA	knots	0	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-02:10:00	\N	0.7	-01:58:00	\N	0.5	-02:13:00	-02:23:00	Gilmerton Hwy. bridge, Southern Branch	VA
109625	Money Point, Southern Branch (depth 15 ft), Elizabeth River, Virginia Current	NOS	ACT5276_1	36.777000427246094	-76.30216979980469	:America/New_York	USA	knots	276	88	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:48:00	\N	0.9	-00:46:00	\N	0.7	-00:53:00	-00:35:00	Money Point, Southern Branch	VA
109626	Pig Point, 1.8 mi northeast of, Nansemond River, Virginia Current	NOS	ACT5281_1	36.92333	-76.41833	:America/New_York	USA	knots	70	285	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:48:00	\N	0.9	-00:46:00	\N	0.7	-00:53:00	-00:35:00	Pig Point, 1.8 miles northeast of	VA
109627	Town Point Bridge, 0.5 mi east of, Nansemond River, Virginia Current	NOS	ACT5286_1	36.88833	-76.48333	:America/New_York	USA	knots	70	265	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:14:00	\N	0.8	-01:38:00	\N	0.8	-01:30:00	-01:31:00	Town Point Bridge, 0.5 mile east of	VA
109628	Dumpling Island, Nansemond River, Virginia Current	NOS	ACT5291_1	36.80833	-76.55833	:America/New_York	USA	knots	345	175	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:31:00	\N	0.9	-01:39:00	\N	0.9	-01:22:00	-02:06:00	Dumpling Island	VA
109629	0.8 mi SW of shipbuilding plant, Newport News, Hampton Roads, Virginia Current	NOS	ACT5301_1	36.975	-76.455	:America/New_York	USA	knots	140	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:03:00	\N	1.1	-00:21:00	\N	0.9	-00:02:00	-00:27:00	0.8 mile SW of shipbuilding plant	VA
109630	1.5 mi SW of shipbuilding plant (depth 6 ft), Hampton Roads, Virginia Current	NOS	ACT5306_1	36.96833	-76.47	:America/New_York	USA	knots	140	350	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:50:00	\N	1	-00:39:00	\N	0.9	-00:41:00	-00:43:00	1.5 miles SW of shipbuilding plant	VA
109631	South end, Rocklanding Shoal Channel, James River, Virginia Current	NOS	ACT5311_1	37.05833	-76.59383	:America/New_York	USA	knots	165	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:07:00	\N	1	00:22:00	\N	0.7	00:34:00	00:20:00	South end	VA
109632	Middle, Rocklanding Shoal Channel, James River, Virginia Current	NOS	ACT5316_1	37.08667	-76.61383	:America/New_York	USA	knots	155	345	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:02:00	\N	0.9	00:57:00	\N	1	00:44:00	01:03:00	Middle	VA
109633	North end, Rocklanding Shoal Channel, James River, Virginia Current	NOS	ACT5321_1	37.11	-76.6325	:America/New_York	USA	knots	145	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:15:00	\N	0.9	01:01:00	\N	1.2	00:55:00	01:07:00	North end	VA
109634	Point of Shoals, west of, James River, Virginia Current	NOS	ACT5326_1	37.065	-76.66	:America/New_York	USA	knots	195	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:14:00	\N	0.8	02:06:00	\N	0.3	02:23:00	01:39:00	Point of Shoals, west of	VA
109635	Deepwater Shoals, James River, Virginia Current	NOS	ACT5331_1	37.14333	-76.63667	:America/New_York	USA	knots	166	353	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:50:00	\N	0.8	01:33:00	\N	1.1	01:37:00	00:59:00	Deepwater Shoals	VA
109636	Hog Point, James River, Virginia Current	NOS	ACT5336_1	37.2	-76.69167	:America/New_York	USA	knots	70	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:04:00	\N	1.2	01:56:00	\N	0.9	02:23:00	01:39:00	Hog Point	VA
109637	Jamestown Island, Church Point, James River, Virginia Current	NOS	ACT5341_1	37.20333	-76.78333	:America/New_York	USA	knots	145	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:08:00	\N	1.2	01:55:00	\N	1	02:19:00	02:03:00	Jamestown Island, Church Point	VA
109638	Chickahominy River Bridge, James River, Virginia Current	NOS	ACT5346_1	37.26167	-76.875	:America/New_York	USA	knots	154	332	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:52:00	\N	1.1	01:50:00	\N	1.2	02:00:00	02:02:00	Chickahominy River Bridge	VA
109639	Caremont Landing, James River, Virginia Current	NOS	ACT5351_1	37.23333	-76.95333	:America/New_York	USA	knots	125	290	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:19:00	\N	1.4	03:11:00	\N	1.3	03:38:00	02:54:00	Caremont Landing	VA
109640	Brandon Point, 0.3 mi northeast of, James River, Virginia Current	NOS	ACT5356_1	37.275	-76.98667	:America/New_York	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:20:00	\N	1.2	03:17:00	\N	1.1	03:51:00	02:57:00	Brandon Point, 0.3 mile northeast of	VA
109641	Windmill Point, James River, Virginia Current	NOS	ACT5361_1	37.31167	-77.095	:America/New_York	USA	knots	65	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:29:00	\N	0.9	03:21:00	\N	1.2	04:25:00	03:24:00	Windmill Point	VA
109642	Coggins Point, 0.5 mi north of, James River, Virginia Current	NOS	ACT5366_1	37.30667	-77.16667	:America/New_York	USA	knots	88	273	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:00:00	\N	0.8	03:39:00	\N	0.5	04:40:00	03:27:00	Coggins Point, 0.5 mile north of	VA
109643	City Point, James River, Virginia Current	NOS	ACT5371_1	37.31667	-77.27167	:America/New_York	USA	knots	135	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:04:00	\N	1.1	03:56:00	\N	1.2	04:43:00	03:59:00	City Point	VA
109644	Appomattox River entrance, James River, Virginia Current	NOS	ACT5376_1	37.31167	-77.295	:America/New_York	USA	knots	80	271	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:51:00	\N	0.8	04:20:00	\N	0.9	05:19:00	03:57:00	Appomattox River entrance	VA
109645	Bermuda Hundred, James River, Virginia Current	NOS	ACT5381_1	37.33667	-77.27	:America/New_York	USA	knots	199	19	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:19:00	\N	1.2	04:13:00	\N	0.8	05:40:00	03:21:00	Bermuda Hundred	VA
109646	Dutch Gap Canal, 0.5 mi east of, James River, Virginia Current	NOS	ACT5386_1	37.38	-77.34667	:America/New_York	USA	knots	90	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:49:00	\N	0.8	04:41:00	\N	0.7	05:23:00	04:39:00	Dutch Gap Canal, 0.5 mile east of	VA
109647	York Spit Light, 0.8 mi southwest of, York River, Virginia Current	NOS	ACT5401_1	37.2	-76.26667	:America/New_York	USA	knots	145	323	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:20:00	\N	0.8	-00:33:00	\N	0.7	-00:42:00	-00:16:00	York Spit Light, 0.8 mile southwest of	VA
109648	York River ent. Channel (NW end) (depth 15 ft), Virginia Current	NOS	ACT5406_1	37.22583	-76.30783	:America/New_York	USA	knots	128	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:26:00	\N	0.5	-00:45:00	\N	0.6	-01:52:00	00:03:00	York River Ent. Channel (NW end)	VA
109649	Tue Marshes Light, 0.7 nmi north of (depth 14 ft), York River, Virginia Current	NOS	ACT5411_1	37.24667	-76.388	:America/New_York	USA	knots	78	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:18:00	\N	0.8	01:26:00	\N	0.9	01:27:00	01:18:00	Tue Marshes Light, 0.7 n.mi. north of	VA
109650	Tue Marshes Light, 0.7 nmi north of (depth 39 ft), York River, Virginia Current	NOS	ACT5411_2	37.24667	-76.388	:America/New_York	USA	knots	70	247	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:55:00	\N	0.6	00:24:00	\N	0.8	00:27:00	01:15:00	Tue Marshes Light, 0.7 n.mi. north of	VA
109651	Tue Marshes Light, 0.7 nmi north of (depth 49 ft), York River, Virginia Current	NOS	ACT5411_3	37.24667	-76.388	:America/New_York	USA	knots	68	249	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:48:00	\N	0.3	-02:11:00	\N	0.4	-02:56:00	-01:11:00	Tue Marshes Light, 0.7 n.mi. north of	VA
109652	Tue Marshes Light, 0.9 nmi WNW of (depth 14 ft), York River, Virginia Current	NOS	ACT5416_1	37.238	-76.40217	:America/New_York	USA	knots	69	249	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:32:00	\N	0.7	-00:30:00	\N	0.7	-00:21:00	-00:30:00	Tue Marshes Light, 0.9 n.mi. WNW of	VA
109653	Tue Marshes Light, 0.9 nmi WNW of (depth 28 ft), York River, Virginia Current	NOS	ACT5416_2	37.238	-76.40217	:America/New_York	USA	knots	64	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:41:00	\N	0.6	-01:15:00	\N	0.5	-01:20:00	-00:46:00	Tue Marshes Light, 0.9 n.mi. WNW of	VA
109654	Midchannel, Tue Marshes Light, 2.7 mi west of, York River, Virginia Current	NOS	ACT5421_1	37.23333	-76.44333	:America/New_York	USA	knots	72	258	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:30:00	\N	0.6	-00:17:00	\N	0.5	-00:18:00	-00:22:00	Midchannel	VA
109655	North edge of channel, Tue Marshes Light, 2.7 mi west of, York River, Virginia Current	NOS	ACT5426_1	37.23667	-76.44333	:America/New_York	USA	knots	74	251	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:08:00	\N	0.7	-00:56:00	\N	0.4	-00:53:00	-01:16:00	North edge of channel	VA
109656	South edge of channel, Tue Marshes Light, 2.7 mi west of, York River, Virginia Current	NOS	ACT5431_1	37.22667	-76.44167	:America/New_York	USA	knots	95	257	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:31:00	\N	0.5	-00:49:00	\N	0.4	-00:31:00	-01:02:00	South edge of channel	VA
109657	Yorktown, York River, Virginia Current	NOS	ACT5436_1	37.24167	-76.50833	:America/New_York	USA	knots	124	302	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:24:00	\N	1.5	-01:07:00	\N	1.1	-00:35:00	-00:59:00	Yorktown	VA
109658	Gloucester Point, 150 yd southeast of, York River, Virginia Current	NOS	ACT5441_1	37.2425	-76.50167	:America/New_York	USA	knots	90	267	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-01:28:00	\N	1	-00:40:00	\N	0.8	-00:40:00	-01:07:00	Gloucester Point, 150 yds. southeast of	VA
109659	Gloucester Point, 0.4 mi southwest of, York River, Virginia Current	NOS	ACT5446_1	37.24033	-76.51083	:America/New_York	USA	knots	108	294	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:51:00	\N	0.9	-00:39:00	\N	1	-00:30:00	-00:24:00	Gloucester Point, 0.4 mile southwest of	VA
109660	Pages Rock, 1 mi SSE of, York River, Virginia Current	NOS	ACT5451_1	37.29333	-76.58	:America/New_York	USA	knots	125	303	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:29:00	\N	0.9	-00:15:00	\N	0.9	-00:15:00	-00:27:00	Pages Rock, 1 mile SSE of	VA
109661	Blundering Point, 0.9 mi SSW of, York River, Virginia Current	NOS	ACT5456_1	37.30217	-76.58467	:America/New_York	USA	knots	138	293	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:23:00	\N	1	-00:26:00	\N	1	-00:27:00	-00:03:00	Blundering Point, 0.9 mile SSW of	VA
109662	Clay Bank Pier, 100 yd southwest of, York River, Virginia Current	NOS	ACT5461_1	37.34633	-76.61333	:America/New_York	USA	knots	123	311	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:12:00	\N	1	-00:25:00	\N	1	-00:07:00	00:37:00	Clay Bank Pier, 100 yds. southwest of	VA
109665	Goff Point, 0.8 mi SSW of, York River, Virginia Current	NOS	ACT5476_1	37.4995	-76.78383	:America/New_York	USA	knots	123	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:47:00	\N	0.9	00:57:00	\N	0.8	01:32:00	01:14:00	Goff Point, 0.8 mile SSW of	VA
109666	West Point, 0.8 mi below, York River, Virginia Current	NOS	ACT5481_1	37.515	-76.79167	:America/New_York	USA	knots	150	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:59:00	\N	1.4	00:41:00	\N	1	01:18:00	00:34:00	West Point, 0.8 mile below	VA
109667	Lord Delaware Bridge, 100 yd S of, York River, Virginia Current	NOS	ACT5486_1	37.537	-76.79083	:America/New_York	USA	knots	210	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:39:00	\N	0.5	00:51:00	\N	0.7	01:32:00	01:08:00	Lord Delaware Bridge, 100 yds. S of	VA
109668	Wakema, Mattaponi River, York River, Virginia Current	NOS	ACT5491_1	37.65333	-76.9	:America/New_York	USA	knots	280	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:34:00	\N	1.6	01:26:00	\N	1.3	02:03:00	01:19:00	Wakema, Mattaponi River	VA
109669	Walkerton, Mattaponi River, York River, Virginia Current	NOS	ACT5496_1	37.72333	-77.025	:America/New_York	USA	knots	95	275	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:18:00	\N	0.8	02:25:00	\N	0.8	03:24:00	02:10:00	Walkerton, Mattaponi River	VA
109670	Eltham Bridge, 100 yd north of, York River, Virginia Current	NOS	ACT5501_1	37.535	-76.807	:America/New_York	USA	knots	124	327	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:07:00	\N	0.8	01:54:00	\N	0.5	02:01:00	01:37:00	Eltham Bridge, 100 yds. north of	VA
109671	Lester Manor, Pamunkey River, York River, Virginia Current	NOS	ACT5506_1	37.58167	-76.99	:America/New_York	USA	knots	55	235	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:59:00	\N	0.9	02:51:00	\N	1.1	03:13:00	02:39:00	Lester Manor, Pamunkey River	VA
109672	Northbury, Pamunkey River, York River, Virginia Current	NOS	ACT5511_1	37.625	-77.12167	:America/New_York	USA	knots	100	290	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:19:00	\N	1.2	04:11:00	\N	0.4	04:28:00	03:44:00	Northbury, Pamunkey River	VA
109673	New Point Comfort, 2.0 nmi WSW of (depth 16 ft), Virginia Current	NOS	ACT5516_1	37.295	-76.32083	:America/New_York	USA	knots	129	315	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:56:00	\N	0.4	01:39:00	\N	0.5	00:58:00	01:12:00	New Point Comfort, 2.0 n.mi. WSW of	VA
109674	Bland Point, Piankatank River, Virginia Current	NOS	ACT5521_1	37.53	-76.365	:America/New_York	USA	knots	125	300	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:06:00	\N	0.2	-00:14:00	\N	0.4	00:03:00	-00:41:00	Bland Point, Piankatank River	VA
109675	Doctor Point, 0.4 mi west of, Virginia Current	NOS	ACT5526_1	37.51833	-76.45	:America/New_York	USA	knots	142	311	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:13:00	\N	0.4	-00:42:00	\N	0.4	00:05:00	-01:28:00	Doctor Point, 0.4 mile west of	VA
109676	Stingray Point, 1.2 nmi NE of (depth 28 ft), Rappahannock River, Virginia Current	NOS	ACT5531_1	37.5755	-76.28467	:America/New_York	USA	knots	121	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:54:00	\N	0.5	-00:04:00	\N	0.4	01:01:00	-00:51:00	Stingray Point, 1.2 n.mi. NE of	VA
109677	Windmill Point, 1.0 nmi SSW of (depth 15 ft), Rappahannock River, Virginia Current	NOS	ACT5536_1	37.6	-76.29167	:America/New_York	USA	knots	103	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:24:00	\N	0.5	01:14:00	\N	0.6	01:08:00	01:49:00	Windmill Point, 1.0 n.mi SSW of	VA
109678	Windmill Point, 1.0 nmi SSW of (depth 38 ft), Rappahannock River, Virginia Current	NOS	ACT5536_2	37.6	-76.29167	:America/New_York	USA	knots	90	269	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:46:00	\N	0.3	01:18:00	\N	0.5	00:33:00	01:50:00	Windmill Point, 1.0 n.mi SSW of	VA
109679	Mosquito Point, 0.9 mi SSE of, Rappahannock River, Virginia Current	NOS	ACT5541_1	37.59533	-76.35133	:America/New_York	USA	knots	90	265	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:05:00	\N	0.8	01:47:00	\N	0.6	01:29:00	01:27:00	Mosquito Point, 0.9 mile SSE of	VA
109680	Orchard Point, 1.0 mi south of, Rappahannock River, Virginia Current	NOS	ACT5551_1	37.63283	-76.4575	:America/New_York	USA	knots	85	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:16:00	\N	0.6	01:51:00	\N	0.4	01:22:00	01:39:00	Orchard Point, 1.0 mile south of	VA
109681	Towles Point, Rappahannock River, Virginia Current	NOS	ACT5556_1	37.63	-76.50667	:America/New_York	USA	knots	103	274	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:49:00	\N	0.5	01:23:00	\N	0.5	01:39:00	01:59:00	Towles Point	VA
109682	Waterview, 1.3 mi NNE of, Rappahannock River, Virginia Current	NOS	ACT5566_1	37.74917	-76.59867	:America/New_York	USA	knots	155	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:34:00	\N	0.6	02:15:00	\N	0.6	02:14:00	02:35:00	Waterview, 1.3 miles NNE of	VA
109683	Tarpley Point, 1.5 mi south of, Rappahannock River, Virginia Current	NOS	ACT5571_1	37.76917	-76.652	:America/New_York	USA	knots	105	300	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:03:00	\N	0.7	02:53:00	\N	0.6	02:49:00	03:09:00	Tarpley Point, 1.5 miles south of	VA
109684	Jones Point, 1.4 mi NNW of, Rappahannock River, Virginia Current	NOS	ACT5576_1	37.8005	-76.693	:America/New_York	USA	knots	105	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:51:00	\N	0.8	02:39:00	\N	1	02:37:00	03:08:00	Jones Point, 1.4 miles NNW of	VA
109685	Sharps, 1.2 mi south of, Rappahannock River, Virginia Current	NOS	ACT5581_1	37.803	-76.69867	:America/New_York	USA	knots	95	290	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:25:00	\N	0.8	03:02:00	\N	0.8	02:52:00	03:41:00	Sharps, 1.2 miles south of	VA
109686	Bowlers Rock, 0.2 mi north of, Rappahannock River, Virginia Current	NOS	ACT5586_1	37.82633	-76.73333	:America/New_York	USA	knots	135	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:14:00	\N	1	02:57:00	\N	0.9	03:00:00	03:26:00	Bowlers Rock, 0.2 mile north of	VA
109687	Accaceek Point, 0.3 mi southwest of, Rappahannock River, Virginia Current	NOS	ACT5591_1	37.87533	-76.77333	:America/New_York	USA	knots	150	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:37:00	\N	0.9	03:04:00	\N	1.1	03:13:00	03:16:00	Accaceek Point, 0.3 mile southwest of	VA
109688	Tappahannock Bridge, 1.8 mi SE of, Rappahannock River, Virginia Current	NOS	ACT5596_1	37.91833	-76.82117	:America/New_York	USA	knots	105	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:52:00	\N	1.2	03:23:00	\N	1.3	03:51:00	03:45:00	Tappahannock Bridge, 1.8 miles SE of	VA
109689	Port Royal, Rappahannock River, Virginia Current	NOS	ACT5606_1	38.175	-77.19	:America/New_York	USA	knots	130	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	06:34:00	\N	0.7	06:26:00	\N	0.6	06:43:00	05:59:00	Port Royal	VA
109690	Pocomoke Sound approach, Virginia Current	NOS	ACT5611_1	37.63333	-75.965	:America/New_York	USA	knots	196	9	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:55:00	\N	0.7	01:28:00	\N	0.6	01:09:00	02:00:00	Pocomoke Sound Approach	VA
109691	Watts Island, 4 mi south of (depth 7 ft), Pocomoke Sound, Virginia Current	NOS	ACT5621_1	37.72	-75.9	:America/New_York	USA	knots	247	27	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:20:00	\N	0.6	00:17:00	\N	0.5	00:50:00	00:16:00	Watts Island, 4 miles south of	VA
109692	Watts Island, 2.3 nmi east of (depth 13 ft), Pocomoke Sound, Virginia Current	NOS	ACT5626_1	37.79367	-75.84717	:America/New_York	USA	knots	208	32	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:50:00	\N	1	01:24:00	\N	0.9	01:53:00	01:20:00	Watts Island, 2.3 n.mi. east of	VA
109693	Watts Island, 2.3 nmi east of (depth 48 ft), Pocomoke Sound, Virginia Current	NOS	ACT5626_2	37.79367	-75.84717	:America/New_York	USA	knots	209	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:10:00	\N	0.8	01:13:00	\N	0.9	01:26:00	01:30:00	Watts Island, 2.3 n.mi. east of	VA
109694	Long Point, 2.0 nmi northeast of (depth 9 ft), Pocomoke Sound, Maryland Current	NOS	ACT5631_1	37.915	-75.79833	:America/New_York	USA	knots	211	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:23:00	\N	0.3	00:57:00	\N	0.4	01:24:00	01:03:00	Long Point, 2.0 n.mi. northeast of	MD
109695	Pocomoke R., 0.5 mi below Shelltown, Pocomoke Sound, Maryland Current	NOS	ACT5636_1	37.97167	-75.645	:America/New_York	USA	knots	170	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:24:00	\N	0.8	03:16:00	\N	1	04:03:00	03:19:00	Pocomoke R., 0.5 mile below Shelltown	MD
109696	Tangier Sound Light, 0.5 nmi east of (depth 16 ft), Virginia Current	NOS	ACT5641_1	37.7875	-75.96383	:America/New_York	USA	knots	195	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:28:00	\N	0.8	01:59:00	\N	0.8	02:21:00	02:07:00	Tangier Sound Light, 0.5 n.mi. east of	VA
109697	Tangier Sound Light, 0.5 nmi east of (depth 41 ft), Virginia Current	NOS	ACT5641_2	37.7875	-75.96383	:America/New_York	USA	knots	189	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:17:00	\N	0.8	01:57:00	\N	0.9	02:20:00	02:14:00	Tangier Sound Light, 0.5 n.mi. east of	VA
109698	Tangier Sound Light, 1.5 mi NE of, Virginia Current	NOS	ACT5646_1	37.80833	-75.95667	:America/New_York	USA	knots	220	14	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:03:00	\N	1	02:18:00	\N	1.1	02:03:00	02:04:00	Tangier Sound Light, 1.5 miles NE of	VA
109699	Clump Island, 2.5 nmi west of (depth 15 ft), Tangier Sound, Virginia Current	NOS	ACT5651_1	37.90833	-75.957	:America/New_York	USA	knots	168	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:16:00	\N	0.6	03:04:00	\N	0.7	03:05:00	03:06:00	Clump Island, 2.5 n.mi. west of	VA
109700	Clump Island, 2.5 nmi west of (depth 40 ft), Tangier Sound, Virginia Current	NOS	ACT5651_2	37.90833	-75.957	:America/New_York	USA	knots	166	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:09:00	\N	0.6	02:45:00	\N	0.7	02:56:00	02:53:00	Clump Island, 2.5 n.mi. west of	VA
109701	Janes Island Light, 2.3 nmi NNE of (depth 14 ft), Tangier Sound, Maryland Current	NOS	ACT5656_1	38.00083	-75.90867	:America/New_York	USA	knots	188	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:09:00	\N	0.7	03:14:00	\N	0.6	03:17:00	03:23:00	Janes Island Light, 2.3 n.mi. NNE OF	MD
109702	Janes Island Light, 2.3 nmi NNE of (depth 39 ft), Tangier Sound, Maryland Current	NOS	ACT5656_2	38.00083	-75.90867	:America/New_York	USA	knots	174	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:02:00	\N	0.7	03:33:00	\N	0.6	03:28:00	03:40:00	Janes Island Light, 2.3 n.mi. NNE OF	MD
109703	Janes Island Light, 2.3 nmi NNE of (depth 92 ft), Tangier Sound, Maryland Current	NOS	ACT5656_3	38.00083	-75.90867	:America/New_York	USA	knots	181	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:28:00	\N	0.4	03:39:00	\N	0.5	02:58:00	03:33:00	Janes Island Light, 2.3 n.mi. NNE OF	MD
109704	Big Annemessex River entrance (depth 12 ft), Tangier Sound, Maryland Current	NOS	ACT5661_1	38.04883	-75.8575	:America/New_York	USA	knots	258	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:36:00	\N	0.2	01:35:00	\N	0.3	02:07:00	01:36:00	Big Annemessex River Entrance	MD
109705	Kedges Strait Buoy 4 (depth 12 ft), Tangier Sound, Maryland Current	NOS	ACT5666_1	38.0575	-76.03217	:America/New_York	USA	knots	276	91	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:57:00	\N	0.7	00:49:00	\N	0.7	00:46:00	00:47:00	Kedges Strait Buoy '4'	MD
109706	Manokin R. ent., 1.1 nmi E of Drum Pt (depth 20 ft), Tangier Sound, Maryland Current	NOS	ACT5671_1	38.097	-75.89133	:America/New_York	USA	knots	197	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:32:00	\N	0.3	02:16:00	\N	0.4	02:18:00	02:32:00	Manokin R. Ent., 1.1 n.mi. E of Drum Pt	MD
109707	Deal Is., 0.6 nmi W. of, at Buoy 14 (depth 14 ft), Tangier Sound, Maryland Current	NOS	ACT5676_1	38.14083	-75.97217	:America/New_York	USA	knots	181	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:03:00	\N	0.6	03:13:00	\N	0.6	03:18:00	03:14:00	Deal Is., 0.6 n.mi. W. of, at Bouy '14'	MD
109708	Deal Is., 0.6 nmi W. of, at Buoy 14 (depth 41 ft), Tangier Sound, Maryland Current	NOS	ACT5676_2	38.14083	-75.97217	:America/New_York	USA	knots	175	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:29:00	\N	0.4	02:21:00	\N	0.5	02:51:00	03:24:00	Deal Is., 0.6 n.mi. W. of, at Bouy '14'	MD
109709	Frog Point, 1.6 mi south of, Tangier Sound, Maryland Current	NOS	ACT5681_1	38.21	-75.955	:America/New_York	USA	knots	240	48	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:55:00	\N	1	03:16:00	\N	0.9	03:52:00	03:30:00	Frog Point, 1.6 miles south of	MD
109710	Long Point and Nanticoke Point, between (depth 9 ft), Tangier Sound, Maryland Current	NOS	ACT5686_1	38.21333	-75.9	:America/New_York	USA	knots	263	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:36:00	\N	0.7	02:53:00	\N	0.4	03:24:00	02:56:00	Long Point and Nanticoke Point, between	MD
109711	Victor Point, 0.8 mi southwest of, Wicomico River, Tangier Sound, Maryland Current	NOS	ACT5691_1	38.23833	-75.86333	:America/New_York	USA	knots	242	34	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:58:00	\N	0.8	03:10:00	\N	0.5	03:43:00	03:38:00	Victor Point, 0.8 mile southwest of	MD
109712	Whitehaven, Wicomico River, Tangier Sound, Maryland Current	NOS	ACT5696_1	38.265	-75.79167	:America/New_York	USA	knots	284	89	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:25:00	\N	1	04:01:00	\N	1	03:29:00	03:51:00	Whitehaven	MD
109713	Whitehaven, 2.5 mi above (depth 4 ft), Wicomico River, Tangier Sound, Maryland Current	NOS	ACT5701_1	38.29667	-75.75833	:America/New_York	USA	knots	188	6	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:19:00	\N	1	03:29:00	\N	0.9	03:33:00	03:34:00	Whitehaven, 2.5 miles above	MD
109714	Salisbury, 2 mi below (depth 4 ft), Wicomico River, Tangier Sound, Maryland Current	NOS	ACT5706_1	38.34	-75.63833	:America/New_York	USA	knots	258	85	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:52:00	\N	0.8	03:47:00	\N	0.5	03:56:00	03:52:00	Salisbury, 2 miles below	MD
109715	Sandy Point, Nanticoke River, Tangier Sound, Maryland Current	NOS	ACT5711_1	38.24667	-75.92833	:America/New_York	USA	knots	182	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:03:00	\N	1	03:52:00	\N	1.1	03:47:00	04:10:00	Sandy Point, Nanticoke River	MD
109716	Roaring Point, WSW of Nanticoke River (depth 18 ft), Tangier Sound, Maryland Current	NOS	ACT5716_1	38.26333	-75.92333	:America/New_York	USA	knots	181	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:34:00	\N	0.8	03:17:00	\N	0.8	03:50:00	04:06:00	Roaring Point, WSW of Nanticoke River	MD
109717	Roaring Point, WSW of Nanticoke River (depth 37 ft), Tangier Sound, Maryland Current	NOS	ACT5716_2	38.26333	-75.92333	:America/New_York	USA	knots	150	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:36:00	\N	0.5	03:15:00	\N	0.5	03:38:00	04:34:00	Roaring Point, WSW of Nanticoke River	MD
109718	Chapter Point, Nanticoke River, Tangier Sound, Maryland Current	NOS	ACT5721_1	38.37667	-75.86667	:America/New_York	USA	knots	204	14	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	05:42:00	\N	1.1	03:59:00	\N	1.3	05:10:00	04:41:00	Chapter Point, Nanticoke River	MD
109719	Fishing Bay entrance, at Buoy 2 (depth 15 ft), Tangier Sound, Maryland Current	NOS	ACT5726_1	38.22467	-75.9895	:America/New_York	USA	knots	139	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:45:00	\N	0.3	04:16:00	\N	0.4	03:47:00	04:02:00	Fishing Bay Entrance, at Buoy '2'	MD
109720	Hooper Strait, at Buoy 4 (depth 14 ft), Tangier Sound, Maryland Current	NOS	ACT5731_1	38.2175	-76.06383	:America/New_York	USA	knots	287	97	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:07:00	\N	0.7	00:48:00	\N	0.7	00:51:00	01:16:00	Hooper Strait, at Buoy '4'	MD
109721	Honga River entrance, at Buoy 1A (depth 26 ft), Tangier Sound, Maryland Current	NOS	ACT5741_1	38.24667	-76.11667	:America/New_York	USA	knots	152	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:03:00	\N	0.4	02:22:00	\N	0.4	02:52:00	03:17:00	Honga River Entrance, at Buoy '1A'	MD
109722	Sandy Point, east of, Great Wicomico River, Virginia Current	NOS	ACT5746_1	37.82167	-76.3	:America/New_York	USA	knots	140	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	00:49:00	\N	0.3	00:41:00	\N	0.3	00:58:00	00:14:00	Sandy Point, east of	VA
109723	Point Lookout, 5.2 nmi SW of (depth 13 ft), Potomac River, Maryland Current	NOS	ACT5751_1	37.96867	-76.39167	:America/New_York	USA	knots	113	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	01:16:00	\N	0.1	01:37:00	\N	0.1	02:34:00	01:38:00	Point Lookout, 5.2 n.mi. SW of	MD
109724	Point Lookout, 3.1 nmi SW of (depth 15 ft), Potomac River, Maryland Current	NOS	ACT5756_1	37.99783	-76.3625	:America/New_York	USA	knots	116	295	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:19:00	\N	0.4	03:23:00	\N	0.3	03:34:00	03:20:00	Point Lookout, 3.1 n.mi. SW of	MD
109725	Point Lookout, 3.1 nmi SW of (depth 34 ft), Potomac River, Maryland Current	NOS	ACT5756_2	37.99783	-76.3625	:America/New_York	USA	knots	126	303	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:40:00	\N	0.2	02:20:00	\N	0.2	02:44:00	02:50:00	Point Lookout, 3.1 n.mi. SW of	MD
109726	Point Lookout, 1.8 nmi SW of (depth 14 ft), Potomac River, Maryland Current	NOS	ACT5761_1	38.01333	-76.34367	:America/New_York	USA	knots	122	297	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:31:00	\N	0.4	03:01:00	\N	0.4	03:01:00	03:48:00	Point Lookout, 1.8 n.mi. SW of	MD
109727	Point Lookout, 1.8 nmi SW of (depth 47 ft), Potomac River, Maryland Current	NOS	ACT5761_2	38.01333	-76.34367	:America/New_York	USA	knots	102	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:13:00	\N	0.1	02:31:00	\N	0.3	02:08:00	03:16:00	Point Lookout, 1.8 n.mi. SW of	MD
109745	Freestone Point, 2.3 mi east of, Potomac River, Maryland Current	NOS	ACT5891_1	38.59633	-77.198	:America/New_York	USA	knots	229	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:06:00	\N	0.9	-00:01:00	\N	0.9	-00:03:00	-00:28:00	Freestone Point, 2.3 miles east of	MD
109728	Point Lookout, 1.0 nmi south of (depth 15 ft), Potomac River, Maryland Current	NOS	ACT5766_1	38.02083	-76.32417	:America/New_York	USA	knots	117	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:48:00	\N	0.5	02:48:00	\N	0.6	02:25:00	03:14:00	Point Lookout, 1.0 n.mi. south of	MD
109729	Point Lookout, 1.0 nmi south of (depth 43 ft), Potomac River, Maryland Current	NOS	ACT5766_2	38.02083	-76.32417	:America/New_York	USA	knots	86	271	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:04:00	\N	0.3	02:31:00	\N	0.5	02:00:00	03:58:00	Point Lookout, 1.0 n.mi. south of	MD
109730	Cornfield Point, midchannel, Potomac River, Maryland Current	NOS	ACT5776_1	38.01832962036133	-76.3550033569336	:America/New_York	USA	knots	110	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:24:00	\N	0.6	04:16:00	\N	0.4	04:33:00	03:49:00	Cornfield Point, midchannel	MD
109731	Cornfield Point, 3.8 mi south of, Potomac River, Maryland Current	NOS	ACT5781_1	37.9900016784668	-76.35832977294922	:America/New_York	USA	knots	100	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:09:00	\N	0.6	04:01:00	\N	0.6	04:18:00	03:34:00	Cornfield Point, 3.8 miles south of	MD
109732	Piney Point, 0.2 mi south of, Potomac River, Maryland Current	NOS	ACT5796_1	38.130001068115234	-76.53333282470703	:America/New_York	USA	knots	145	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:24:00	\N	0.6	03:16:00	\N	1.2	03:33:00	02:49:00	Piney Point, 0.2 mile south of	MD
109733	Piney Point, 2.2 mi south of, Potomac River, Maryland Current	NOS	ACT5806_1	38.098331451416016	-76.55166625976562	:America/New_York	USA	knots	130	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:24:00	\N	0.5	03:16:00	\N	0.4	03:33:00	02:49:00	Piney Point, 2.2 miles south of	MD
109734	White Point, Nomini Creek entrance, Potomac River, Virginia Current	NOS	ACT5816_1	38.135	-76.72167	:America/New_York	USA	knots	335	155	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:59:00	\N	1.1	03:51:00	\N	1.1	04:08:00	03:24:00	White Point, Nomini Creek entrance	VA
109735	Breton Bay entrance, Potomac River, Maryland Current	NOS	ACT5821_1	38.24167	-76.695	:America/New_York	USA	knots	200	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	02:44:00	\N	0.4	02:36:00	\N	0.5	02:53:00	02:09:00	Breton Bay entrance	MD
109736	St. Clements I., 1.8 mi southeast of, Potomac River, Maryland Current	NOS	ACT5831_1	38.195	-76.70833	:America/New_York	USA	knots	85	250	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	05:09:00	\N	0.8	05:01:00	\N	0.4	05:18:00	04:34:00	St. Clements I., 1.8 miles southeast of	MD
109737	St. Clements I., 1.1 mi southwest of, Potomac River, Maryland Current	NOS	ACT5836_1	38.19283	-76.76117	:America/New_York	USA	knots	99	281	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	04:58:00	\N	0.8	05:10:00	\N	0.5	05:04:00	04:33:00	St. Clements I., 1.1 miles southwest of	MD
109738	Rock Point, Wicomico River entrance, Potomac River, Maryland Current	NOS	ACT5841_1	38.27333	-76.82167	:America/New_York	USA	knots	174	19	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	03:46:00	\N	0.6	03:57:00	\N	0.4	03:42:00	03:42:00	Rock Point, Wicomico River entrance	MD
109739	Swan Point, Potomac River, Maryland Current	NOS	ACT5846_1	38.27333	-76.945	:America/New_York	USA	knots	140	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:09:00	\N	1	-02:04:00	\N	0.4	-01:54:00	-02:32:00	Swan Point	MD
109740	Persimmon Point, Potomac River, Maryland Current	NOS	ACT5861_1	38.36833	-76.99	:America/New_York	USA	knots	175	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-01:24:00	\N	1.8	-01:19:00	\N	1.5	-01:09:00	-01:47:00	Persimmon Point	MD
109741	Potomac River Bridge, 0.4 mi south of, Maryland Current	NOS	ACT5866_1	38.35633	-76.98667	:America/New_York	USA	knots	165	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-01:17:00	\N	1.8	-01:28:00	\N	1.1	-01:25:00	-01:38:00	Potomac River Bridge, 0.4 mile south of	MD
109742	Maryland Point, Potomac River, Maryland Current	NOS	ACT5876_1	38.34667	-77.19667	:America/New_York	USA	knots	80	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-01:19:00	\N	1.8	-01:14:00	\N	1.4	-01:04:00	-01:42:00	Maryland Point	MD
109743	Quantico, Potomac River, Maryland Current	NOS	ACT5881_1	38.52167	-77.27667	:America/New_York	USA	knots	200	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-01:09:00	\N	1.1	-01:04:00	\N	0.9	-00:54:00	-01:32:00	Quantico	MD
109744	Quantico Creek entrance, Potomac River, Virginia Current	NOS	ACT5886_1	38.52833	-77.28833	:America/New_York	USA	knots	115	305	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-01:34:00	\N	0.6	-01:29:00	\N	0.6	-01:19:00	-01:57:00	Quantico Creek entrance	VA
109746	Hallowing Point, Potomac River, Maryland Current	NOS	ACT5896_1	38.645	-77.1275	:America/New_York	USA	knots	149	345	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:15:00	\N	1.4	-00:05:00	\N	1.4	00:12:00	-00:24:00	Hallowing Point	MD
109747	Jones Point, Alexandria, Potomac River, DC Current	NOS	ACT5901_1	38.79367	-77.03717	:America/New_York	USA	knots	171	352	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:07:00	\N	1.1	00:01:00	\N	1.2	00:36:00	00:09:00	Jones Point, Alexandria	DC
109748	Hains Point, Potomac River, DC Current	NOS	ACT5906_1	38.85133	-77.022	:America/New_York	USA	knots	176	359	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:18:00	\N	0.4	00:31:00	\N	0.8	00:20:00	00:04:00	Hains Point	DC
109749	Hog Point, 0.6 nmi north of (depth 13 ft), Patuxent River, Maryland Current	NOS	ACT5931_1	38.318	-76.40117	:America/New_York	USA	knots	70	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-06:00:00	\N	0.6	-05:29:00	\N	0.5	-04:45:00	-05:59:00	Hog Point, 0.6 n.mi. north of	MD
109750	Hog Point, 0.6 nmi north of (depth 41 ft), Patuxent River, Maryland Current	NOS	ACT5931_2	38.318	-76.40117	:America/New_York	USA	knots	61	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-06:38:00	\N	0.3	-05:38:00	\N	0.5	-06:24:00	-05:36:00	Hog Point, 0.6 n.mi. north of	MD
109751	Drum Point, 0.3 mi SSE of, Patuxent River, Maryland Current	NOS	ACT5936_1	38.3155	-76.41917	:America/New_York	USA	knots	65	245	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-05:16:00	\N	0.5	-05:20:00	\N	0.5	-05:19:00	-05:25:00	Drum Point, 0.3 mile SSE of	MD
109752	Sandy Point, 0.5 mi south of, Patuxent River, Maryland Current	NOS	ACT5941_1	38.30833	-76.455	:America/New_York	USA	knots	125	300	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-04:55:00	\N	0.6	-05:49:00	\N	0.5	-05:08:00	-05:53:00	Sandy Point, 0.5 mile south of	MD
109753	Point Patience, 0.1 mi southwest of (depth 15 ft), Patuxent River, Maryland Current	NOS	ACT5946_1	38.32833	-76.48667	:America/New_York	USA	knots	145	315	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-06:01:00	\N	1	-06:12:00	\N	0.6	-05:07:00	-06:46:00	Point Patience, 0.1 mile southwest of	MD
109754	Broomes Island, 0.4 mi south of, Patuxent River, Maryland Current	NOS	ACT5951_1	38.395	-76.55417	:America/New_York	USA	knots	110	290	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-05:02:00	\N	0.6	-05:16:00	\N	0.5	-05:01:00	-05:02:00	Broomes Island, 0.4 mile south of	MD
109755	Sheridan Point, 0.1 mi southwest of, Patuxent River, Maryland Current	NOS	ACT5956_1	38.46617	-76.648	:America/New_York	USA	knots	135	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-04:16:00	\N	0.8	-04:54:00	\N	0.8	-04:33:00	-04:38:00	Sheridan Point, 0.1 mile southwest of	MD
109756	Benedict, highway bridge, Patuxent River, Maryland Current	NOS	ACT5961_1	38.51167	-76.67217	:America/New_York	USA	knots	190	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-04:35:00	\N	0.6	-04:38:00	\N	1	-04:45:00	-04:09:00	Benedict, highway bridge	MD
109757	Lyons Creek Wharf, Patuxent River, Maryland Current	NOS	ACT5966_1	38.74667	-76.685	:America/New_York	USA	knots	140	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-03:29:00	\N	1.1	-03:24:00	\N	1.4	-03:14:00	-03:52:00	Lyons Creek Wharf	MD
109758	Ragged Point, 1.5 mi east of, Little Choptank River, Maryland Current	NOS	ACT5976_1	38.53	-76.24417	:America/New_York	USA	knots	235	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-04:57:00	\N	0.2	-05:15:00	\N	0.5	-04:53:00	-04:29:00	Ragged Point, 1.5 miles east of	MD
109759	Cook Point, 1.4 nmi NNW of (depth 15 ft), Choptank River, Maryland Current	NOS	ACT5981_1	38.64717	-76.30667	:America/New_York	USA	knots	241	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-04:24:00	\N	0.7	-04:06:00	\N	0.8	-03:52:00	-04:06:00	Cook Point, 1.4 n.mi. NNW of	MD
109760	Cook Point, 1.4 nmi NNW of (depth 45 ft), Choptank River, Maryland Current	NOS	ACT5981_2	38.64717	-76.30667	:America/New_York	USA	knots	232	68	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-04:12:00	\N	0.6	-04:05:00	\N	0.6	-04:09:00	-04:03:00	Cook Point, 1.4 n.mi. NNW of	MD
109761	Holland Point, 2.0 nmi SSW of (depth 14 ft), Choptank River, Maryland Current	NOS	ACT5986_1	38.67383	-76.2575	:America/New_York	USA	knots	262	89	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-04:00:00	\N	0.2	-04:21:00	\N	0.3	-03:54:00	-03:26:00	Holland Point, 2.0 n.mi. SSW of	MD
109762	Chlora Point, 0.5 nmi SSW of (depth 17 ft), Choptank River, Maryland Current	NOS	ACT5991_1	38.62833	-76.15167	:America/New_York	USA	knots	332	139	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-03:58:00	\N	0.5	-03:32:00	\N	0.6	-03:45:00	-03:22:00	Chlora Point, 0.5 n.mi. SSW of	MD
109763	Chlora Point, 0.5 nmi SSW of (depth 24 ft), Choptank River, Maryland Current	NOS	ACT5991_2	38.62833	-76.15167	:America/New_York	USA	knots	323	143	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-03:42:00	\N	0.4	-03:33:00	\N	0.4	-03:48:00	-03:13:00	Chlora Point, 0.5 n.mi. SSW of	MD
109764	Martin Point, 0.6 nmi west of (depth 18 ft), Choptank River, Maryland Current	NOS	ACT5996_1	38.62717	-76.13583	:America/New_York	USA	knots	341	155	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-03:34:00	\N	0.2	-03:42:00	\N	0.3	-03:18:00	-03:22:00	Martin Point, 0.6 n.mi. west of	MD
109765	Howell Point, 0.5 nmi south of (depth 7 ft), Choptank River, Maryland Current	NOS	ACT6001_1	38.60383	-76.1145	:America/New_York	USA	knots	274	122	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-03:42:00	\N	0.5	-04:04:00	\N	0.4	-03:17:00	-03:52:00	Howell Point, 0.5 n.mi. south of	MD
109766	Cambridge hwy. bridge, W. of Swing Span (depth 18 ft), Choptank River, Maryland Current	NOS	ACT6006_1	38.57967	-76.06117	:America/New_York	USA	knots	316	132	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:13:00	\N	0.3	-03:05:00	\N	0.6	-02:48:00	-01:07:00	Cambridge hwy. bridge, W. of Swing Span	MD
109767	Off Jamaica Point, Choptank River, Maryland Current	NOS	ACT6011_1	38.60967	-75.98283	:America/New_York	USA	knots	205	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:26:00	\N	0.8	-02:32:00	\N	0.6	-02:13:00	-02:44:00	Off Jamaica Point	MD
109768	Poplar Point, south of, Choptank River, Maryland Current	NOS	ACT6016_1	38.67533	-75.96633	:America/New_York	USA	knots	100	305	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:15:00	\N	1	-02:05:00	\N	1	-01:52:00	-01:56:00	Poplar Point, south of	MD
109769	Dover Bridge, Choptank River, Maryland Current	NOS	ACT6021_1	38.75667	-75.99867	:America/New_York	USA	knots	235	50	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-01:47:00	\N	1	-01:50:00	\N	1.1	-01:19:00	-01:25:00	Dover Bridge	MD
109770	Bald Eagle Pt., east of, Harris Creek, Choptank River, Maryland Current	NOS	ACT6041_1	38.72917	-76.305	:America/New_York	USA	knots	175	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-04:14:00	\N	0.5	-04:27:00	\N	0.5	-04:07:00	-04:07:00	Bald Eagle Pt., east of, Harris Creek	MD
109771	Poplar Island, east of south end, Eastern Bay, Maryland Current	NOS	ACT6046_1	38.74833	-76.35333	:America/New_York	USA	knots	170	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:20:00	\N	0.8	-02:20:00	\N	1.2	-02:20:00	-02:20:00	Poplar Island, east of south end	MD
109772	Kent Point, 1.4 nmi east of (depth 15 ft), Eastern Bay, Maryland Current	NOS	ACT6051_1	38.83883	-76.3375	:America/New_York	USA	knots	233	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-03:12:00	\N	0.4	-03:18:00	\N	0.5	-03:04:00	-03:49:00	Kent Point, 1.4 n.mi. east of	MD
109773	Long Point, 1 mi southeast of, Eastern Bay, Maryland Current	NOS	ACT6056_1	38.84333	-76.32667	:America/New_York	USA	knots	235	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-03:40:00	\N	0.5	-03:40:00	\N	0.6	-03:40:00	-03:40:00	Long Point, 1 mile southeast of	MD
109774	Wye River, west of Bruffs Island (depth 9 ft), Eastern Bay, Maryland Current	NOS	ACT6081_1	38.85467	-76.198	:America/New_York	USA	knots	190	30	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-03:00:00	\N	0.9	-03:18:00	\N	0.8	-02:33:00	-03:17:00	Wye River, west of Bruffs Island	MD
109775	Deepwater Point, Miles River, Eastern Bay, Maryland Current	NOS	ACT6086_1	38.8055	-76.20917	:America/New_York	USA	knots	25	215	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-04:14:00	\N	0.6	-03:52:00	\N	0.6	-03:48:00	-03:43:00	Deepwater Point, Miles River	MD
109776	Greenbury Point, 1.8 mi east of (depth 8 ft), Maryland Current	NOS	ACT6106_1	38.97333	-76.41667	:America/New_York	USA	knots	245	70	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:47:00	\N	0.8	-01:05:00	\N	0.8	-00:57:00	-00:51:00	Greenbury Point, 1.8 miles east of	MD
109777	Mountain Point, Magothy River entrance, Maryland Current	NOS	ACT6121_1	39.05783	-76.43717	:America/New_York	USA	knots	125	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:04:00	\N	0.4	-02:00:00	\N	0.8	-02:20:00	-01:29:00	Mountain Point, Magothy River entrance	MD
109778	Love Point, 1.6 nmi east of (depth 16 ft), Chester River, Maryland Current	NOS	ACT6126_1	39.03417	-76.26783	:America/New_York	USA	knots	341	202	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-01:15:00	\N	0.4	-01:15:00	\N	0.6	-01:42:00	-00:47:00	Love Point, 1.6 n.mi. east of	MD
109779	Kent Island Narrows (highway bridge) (depth 4 ft), Chester River, Maryland Current	NOS	ACT6131_1	38.9705	-76.24717	:America/New_York	USA	knots	190	5	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-02:56:00	\N	1.1	-02:25:00	\N	1.2	-02:07:00	-02:11:00	Kent Island Narrows (highway bridge)	MD
109780	Hail Point, 0.7 nmieast of (depth 16 ft), Chester River, Maryland Current	NOS	ACT6136_1	39.0105	-76.1825	:America/New_York	USA	knots	168	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:37:00	\N	0.6	-01:08:00	\N	0.5	-00:51:00	-01:12:00	Hail Point, 0.7 n.mi.east of	MD
109781	Deep Point, Chester River, Maryland Current	NOS	ACT6141_1	39.10633	-76.1205	:America/New_York	USA	knots	260	65	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:18:00	\N	0.9	-00:33:00	\N	0.6	-00:31:00	-00:32:00	Deep Point	MD
109782	Chestertown, Chester River, Maryland Current	NOS	ACT6146_1	39.20717	-76.06117	:America/New_York	USA	knots	220	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:17:00	\N	0.6	00:05:00	\N	0.8	-00:21:00	-00:02:00	Chestertown	MD
109783	Lynch Point, Back River, Maryland Current	NOS	ACT6186_1	39.25	-76.43833	:America/New_York	USA	knots	130	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	-00:10:00	\N	0.5	-00:10:00	\N	0.7	00:00:00	00:00:00	Lynch Point, Back River	MD
109784	Gunpowder River entrance, Maryland Current	NOS	ACT6191_1	39.31167	-76.30833	:America/New_York	USA	knots	205	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:05:00	\N	0.4	-00:41:00	\N	0.5	-00:24:00	00:25:00	Gunpowder River entrance	MD
109785	Bush River, 0.4 mi SW of Bush Point, Maryland Current	NOS	ACT6196_1	39.35667	-76.25667	:America/New_York	USA	knots	165	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:20:00	\N	0.6	-00:24:00	\N	0.8	00:07:00	00:21:00	Bush River, 0.4 mi. SW of Bush Point	MD
109786	Grove Point, Sassafrass River, Maryland Current	NOS	ACT6201_1	39.37833	-76.04333	:America/New_York	USA	knots	288	95	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:44:00	\N	0.4	00:46:00	\N	0.5	00:46:00	00:51:00	Grove Point	MD
109787	Ordinary Point, 0.4 mi west of, Sassafrass River, Maryland Current	NOS	ACT6206_1	39.37417	-75.9875	:America/New_York	USA	knots	345	165	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	00:58:00	\N	0.5	00:37:00	\N	0.6	00:50:00	01:17:00	Ordinary Point, 0.4 mile west of	MD
109788	Georgetown, Sassafrass River, Maryland Current	NOS	ACT6211_1	39.36117	-75.88617	:America/New_York	USA	knots	200	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:25:00	\N	0.5	00:25:00	\N	0.4	01:00:00	00:56:00	Georgetown	MD
109789	Arnold Point, 0.4 mi west of, Elk River, Maryland Current	NOS	ACT6216_1	39.46383	-75.97417	:America/New_York	USA	knots	215	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:32:00	\N	1	01:45:00	\N	1	01:39:00	01:24:00	Arnold Point, 0.4 mile west of	MD
109790	Old Town Point Wharf, northwest of (depth 17 ft), Elk River, Maryland Current	NOS	ACT6221_1	39.50383	-75.91867	:America/New_York	USA	knots	242	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:45:00	\N	1.6	01:53:00	\N	1.3	02:00:00	01:49:00	Old Town Point Wharf, northwest of	MD
109791	Old Town Point Wharf, northwest of (depth 29 ft), Elk River, Maryland Current	NOS	ACT6221_2	39.50383	-75.91867	:America/New_York	USA	knots	237	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	01:45:00	\N	1.4	02:04:00	\N	1.2	02:07:00	01:47:00	Old Town Point Wharf, northwest of	MD
109792	Hendersons Point, Elk River, Maryland Current	NOS	ACT6226_1	39.55333	-75.86	:America/New_York	USA	knots	210	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106033	02:05:00	\N	0.9	02:05:00	\N	0.6	02:05:00	02:05:00	Hendersons Point	MD
109793	Back Creek, 0.3 nmi W of Sandy Pt (depth 14 ft), Maryland Current	NOS	ACT6231_1	39.52783	-75.86617	:America/New_York	USA	knots	244	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108657	00:06:00	\N	0.7	00:00:00	\N	0.6	-00:01:00	-00:15:00	Back Creek, 0.3 n.mi. W of Sandy Pt	MD
109794	Back Creek, 0.3 nmi W of Sandy Pt (depth 31 ft), Maryland Current	NOS	ACT6231_2	39.52783	-75.86617	:America/New_York	USA	knots	240	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108657	00:08:00	\N	0.6	-00:13:00	\N	0.6	00:01:00	-00:05:00	Back Creek, 0.3 n.mi. W of Sandy Pt	MD
109795	Chesapeake City Bridge, 0.45 nmi E of (depth 26 ft), Maryland Current	NOS	ACT6241_1	39.52783	-75.80717	:America/New_York	USA	knots	273	92	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108657	00:00:00	\N	0.7	00:01:00	\N	1	-00:22:00	00:03:00	Chesapeake City Bridge, 0.45 n.mi. E of	MD
109796	Chesapeake City Bridge, 0.45 nmi E of (depth 37 ft), Maryland Current	NOS	ACT6241_2	39.52783	-75.80717	:America/New_York	USA	knots	275	83	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108657	-00:07:00	\N	0.5	-00:04:00	\N	0.8	-00:26:00	00:06:00	Chesapeake City Bridge, 0.45 n.mi. E of	MD
109797	Conrail Bridge, east of (depth 17 ft), Chesapeake and Delaware Canal, Delaware Current	NOS	ACT6246_1	39.5425	-75.7025	:America/New_York	USA	knots	278	99	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108657	-00:01:00	\N	0.7	-00:13:00	\N	1	-00:30:00	-00:03:00	Conrail Bridge, east of	DE
109798	Conrail Bridge, east of (depth 34 ft), Chesapeake and Delaware Canal, Delaware Current	NOS	ACT6246_2	39.5425	-75.7025	:America/New_York	USA	knots	281	96	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108657	-00:24:00	\N	0.5	-00:11:00	\N	0.7	-00:35:00	-00:06:00	Conrail Bridge, east of	DE
109799	St. George Bridge, 0.1 nmi ENE of (depth 18 ft), Delaware Current	NOS	ACT6251_1	39.55283	-75.65	:America/New_York	USA	knots	247	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108657	-01:01:00	\N	0.7	-00:56:00	\N	0.9	-00:52:00	-00:53:00	St. George Bridge, 0.1 n.mi. ENE of	DE
109800	Reedy Point Radio Tower, south of (depth 19 ft), Delaware Current	NOS	ACT6256_1	39.56033	-75.57	:America/New_York	USA	knots	263	78	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108657	-00:09:00	\N	0.7	-00:43:00	\N	1	-01:00:00	-00:15:00	Reedy Point Radio Tower, south of	DE
109801	Cape Henry Light, 0.7 mi east of, Virginia Current	NOS	ACT6261_1	36.92833	-75.99333	:America/New_York	USA	knots	105	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:06:00	\N	1.8	-00:23:00	\N	0.9	-00:06:00	-01:07:00	Cape Henry Light, 0.7 mile east of	VA
109802	Carova Beach, north end, North Carolina Current	NOS	ACT6266_1	36.55	-75.86833	:America/New_York	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108625	-00:09:00	\N	0.4	-00:20:00	\N	0.4	-00:53:00	-00:21:00	Virginia Beach, south end	NC
109803	Bodie Island-Pea Island, between (depth 6 ft), Pamlico Sound, North Carolina Current	NOS	ACT6271_1	35.77667	-75.535	:America/New_York	USA	knots	28	202	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:52:00	\N	0.6	02:20:00	\N	1.2	02:38:00	02:03:00	Bodie Island-Pea Island, between	NC
109804	Bodie Island-Pea Island, between (depth 12 ft), Pamlico Sound, North Carolina Current	NOS	ACT6271_2	35.77667	-75.535	:America/New_York	USA	knots	36	204	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:48:00	\N	0.6	02:36:00	\N	1.2	02:49:00	02:02:00	Bodie Island-Pea Island, between	NC
109805	Coast Guard Tower, southwest of (depth 6 ft), Pamlico Sound, North Carolina Current	NOS	ACT6276_1	35.76167	-75.53167	:America/New_York	USA	knots	28	205	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	02:18:00	\N	0.8	02:30:00	\N	0.8	03:04:00	01:53:00	Coast Guard Tower, southwest of	NC
109806	Coast Guard Tower, southwest of (depth 12 ft), Pamlico Sound, North Carolina Current	NOS	ACT6276_2	35.76167	-75.53167	:America/New_York	USA	knots	33	212	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:33:00	\N	0.7	02:33:00	\N	0.8	03:01:00	01:57:00	Coast Guard Tower, southwest of	NC
109807	Herbert C. Bonner Bridge, WSW of (depth 6 ft), Pamlico Sound, North Carolina Current	NOS	ACT6281_1	35.77	-75.54667	:America/New_York	USA	knots	87	280	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:46:00	\N	0.9	02:55:00	\N	0.6	03:32:00	01:30:00	Herbert C. Bonner Bridge, WSW of	NC
109808	Hatteras Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6286_1	35.2	-75.75	:America/New_York	USA	knots	148	307	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:38:00	\N	1	02:42:00	\N	1.2	02:42:00	02:18:00	Hatteras Inlet	NC
109809	Ocracoke Inlet, channel entrance, Pamlico Sound, North Carolina Current	NOS	ACT6296_1	35.06529998779297	-76.018798828125	:America/New_York	USA	knots	145	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:40:00	\N	1.2	02:24:00	\N	1	02:48:00	01:43:00	Ocracoke Inlet, channel entrance	NC
109810	Teaches Hole Channel (depth 10 ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6301_1	35.07917	-76.00467	:America/New_York	USA	knots	195	50	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:47:00	\N	0.8	02:27:00	\N	0.6	02:49:00	01:42:00	Teaches Hole Channel	NC
109811	Blair Channel (depth 10 ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6306_1	35.08133	-76.03383	:America/New_York	USA	knots	140	355	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	02:03:00	\N	0.9	02:33:00	\N	0.6	02:52:00	01:48:00	Blair Channel	NC
109812	Wallace Channel (depth 9 ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6311_1	35.07967	-76.052	:America/New_York	USA	knots	140	305	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	02:13:00	\N	0.9	02:57:00	\N	0.9	02:51:00	02:03:00	Wallace Channel	NC
109813	Sheep Island Slue, Pamlico Sound, North Carolina Current	NOS	ACT6316_1	35.06667	-76.1	:America/New_York	USA	knots	95	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:56:00	\N	0.2	03:18:00	\N	0.1	02:33:00	01:35:00	Sheep Island Slue	NC
109814	Shackleford Banks, 0.8 mi S of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6326_1	34.66633	-76.6555	:America/New_York	USA	knots	145	314	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:31:00	\N	0.7	01:16:00	\N	0.8	01:19:00	00:30:00	Shackleford Banks, 0.8 mile S of	NC
109815	Beaufort Inlet approach, North Carolina Current	NOS	ACT6331_1	34.67169952392578	-76.66999816894531	:America/New_York	USA	knots	161	358	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:57:00	\N	0.7	01:19:00	\N	0.2	02:03:00	00:37:00	Beaufort Inlet Approach	NC
109816	Fort Macon, 0.6 mi SE of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6336_1	34.68579864501953	-76.66829681396484	:America/New_York	USA	knots	154	332	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:38:00	\N	0.9	01:47:00	\N	0.7	01:42:00	00:51:00	Fort Macon, 0.6 mile SE of	NC
109817	Fort Macon, 0.2 mi NE of (depth 10 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6341_1	34.69967	-76.67533	:America/New_York	USA	knots	151	307	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:21:00	\N	0.9	01:20:00	\N	1.1	01:12:00	00:36:00	Fort Macon, 0.2 mile NE of	NC
109818	Fort Macon, 0.2 mi NE of (depth 20 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6341_2	34.69967	-76.67533	:America/New_York	USA	knots	153	320	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:39:00	\N	0.9	01:18:00	\N	1.1	01:12:00	00:36:00	Fort Macon, 0.2 mile NE of	NC
109819	Tombstone Point, 0.1 mi E of (depth 15 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6346_1	34.70383	-76.68617	:America/New_York	USA	knots	128	305	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:27:00	\N	0.8	01:25:00	\N	0.9	01:13:00	00:34:00	Tombstone Point, 0.1 mile E of	NC
109820	Turning Basin (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6351_1	34.713	-76.69417	:America/New_York	USA	knots	144	327	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:32:00	\N	0.5	01:34:00	\N	0.8	01:11:00	00:50:00	Turning Basin	NC
109821	Turning Basin (depth 15 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6351_2	34.713	-76.69417	:America/New_York	USA	knots	138	334	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:32:00	\N	0.5	01:34:00	\N	0.7	01:09:00	00:59:00	Turning Basin	NC
109822	Sugarloaf Island, 0.2 mi S of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6356_1	34.7125	-76.71383	:America/New_York	USA	knots	94	266	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:14:00	\N	0.8	01:39:00	\N	0.7	01:58:00	01:22:00	Sugarloaf Island, 0.2 mile S of	NC
109823	Morehead City, S of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6361_1	34.71667	-76.73283	:America/New_York	USA	knots	110	293	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:42:00	\N	0.7	01:47:00	\N	0.8	02:12:00	01:29:00	Morehead City, S of	NC
109824	Morehead City, RR. bridge, N of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6366_1	34.72283	-76.69383	:America/New_York	USA	knots	185	54	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-01:03:00	\N	0.5	01:01:00	\N	0.6	00:44:00	00:09:00	Morehead City, RR. bridge, N of	NC
109825	Newport Marshes, SE of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6371_1	34.73133	-76.68333	:America/New_York	USA	knots	215	44	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:08:00	\N	0.6	01:02:00	\N	0.8	00:57:00	00:18:00	Newport Marshes, SE of	NC
109826	Newport Marshes, SE of (depth 15 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6371_2	34.73133	-76.68333	:America/New_York	USA	knots	226	44	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:08:00	\N	0.6	01:15:00	\N	0.8	00:53:00	00:21:00	Newport Marshes, SE of	NC
109827	Newport Marshes, E of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6376_1	34.73783	-76.6805	:America/New_York	USA	knots	224	40	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:09:00	\N	0.5	00:11:00	\N	0.6	00:07:00	-00:37:00	Newport Marshes, E of	NC
109828	Radio Island, E of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6381_1	34.71167	-76.67967	:America/New_York	USA	knots	202	22	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:16:00	\N	0.6	00:55:00	\N	0.7	00:55:00	00:20:00	Radio Island, E of	NC
109829	Bird Shoal, SE of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6391_1	34.7005	-76.65383	:America/New_York	USA	knots	304	126	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:16:00	\N	0.4	01:34:00	\N	0.5	01:40:00	01:10:00	Bird Shoal, SE of	NC
109830	Shackleford Point, NE of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6396_1	34.69217	-76.65217	:America/New_York	USA	knots	305	135	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:46:00	\N	0.6	01:28:00	\N	0.8	01:32:00	01:10:00	Shackleford Point, NE of	NC
109831	Carrot Island (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6401_1	34.70217	-76.6175	:America/New_York	USA	knots	262	80	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:49:00	\N	0.7	01:34:00	\N	0.5	01:49:00	01:15:00	Carrot Island	NC
109832	Middle Marshes, S of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6406_1	34.67833	-76.61383	:America/New_York	USA	knots	275	123	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:18:00	\N	0.5	01:04:00	\N	0.8	00:59:00	01:03:00	Middle Marshes, S of	NC
109833	Reaves Point, 0.3 mi east of (depth 6 ft), Cape Fear River, North Carolina Current	NOS	ACT6446_1	33.9986686706543	-77.94950103759766	:America/New_York	USA	knots	181	351	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106243	-01:58:00	\N	0.1	-01:01:00	\N	0.2	-00:29:00	00:23:00	Reaves Point, 0.3 mile east of	NC
109834	Reaves Point, 0.3 mi east of (depth 16 ft), Cape Fear River, North Carolina Current	NOS	ACT6446_2	33.9986686706543	-77.94950103759766	:America/New_York	USA	knots	159	332	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106243	-00:56:00	\N	0.1	00:37:00	\N	0.4	-00:06:00	01:00:00	Reaves Point, 0.3 mile east of	NC
109835	Reaves Point, 0.3 mi east of (depth 26 ft), Cape Fear River, North Carolina Current	NOS	ACT6446_3	33.9986686706543	-77.94950103759766	:America/New_York	USA	knots	160	331	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106243	00:28:00	\N	0.1	00:40:00	\N	0.6	-00:39:00	02:05:00	Reaves Point, 0.3 mile east of	NC
109836	Reaves Point Channel (depth 6 ft), Cape Fear River, North Carolina Current	NOS	ACT6451_1	33.98466873168945	-77.93083190917969	:America/New_York	USA	knots	195	9	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106243	01:08:00	\N	0.5	00:27:00	\N	0.8	00:57:00	01:02:00	Reaves Point Channel	NC
109837	Reaves Point Channel (depth 16 ft), Cape Fear River, North Carolina Current	NOS	ACT6451_2	33.98466873168945	-77.93083190917969	:America/New_York	USA	knots	192	13	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106243	01:10:00	\N	0.5	00:04:00	\N	0.9	00:34:00	00:56:00	Reaves Point Channel	NC
109838	Reaves Point Channel (depth 26 ft), Cape Fear River, North Carolina Current	NOS	ACT6451_3	33.98466873168945	-77.93083190917969	:America/New_York	USA	knots	194	17	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106243	00:43:00	\N	0.3	01:42:00	\N	0.6	00:20:00	01:42:00	Reaves Point Channel	NC
109839	Reaves Point, 0.4 mi north of (depth 6 ft), Cape Fear River, North Carolina Current	NOS	ACT6461_1	34.006168365478516	-77.95249938964844	:America/New_York	USA	knots	198	27	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106243	01:10:00	\N	0.3	00:42:00	\N	0.5	01:11:00	01:05:00	Reaves Point, 0.4 mile north of	NC
109840	Reaves Point, 0.4 mi north of (depth 16 ft), Cape Fear River, North Carolina Current	NOS	ACT6461_2	34.006168365478516	-77.95249938964844	:America/New_York	USA	knots	191	11	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106243	00:58:00	\N	0.2	01:34:00	\N	0.5	00:51:00	01:18:00	Reaves Point, 0.4 mile north of	NC
109841	Reaves Point, 0.4 mi north of (depth 26 ft), Cape Fear River, North Carolina Current	NOS	ACT6461_3	34.006168365478516	-77.95249938964844	:America/New_York	USA	knots	183	50	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106243	00:17:00	\N	0.2	01:00:00	\N	0.5	-00:05:00	01:37:00	Reaves Point, 0.4 mile north of	NC
109842	0.4 mi north of (depth 6 ft), Brunswick River, Cape Fear River, North Carolina Current	NOS	ACT6496_1	34.18117141723633	-77.96582794189453	:America/New_York	USA	knots	118	290	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106243	00:13:00	\N	0.4	00:26:00	\N	0.5	01:42:00	01:12:00	0.4 mile north of	NC
109843	0.4 mi north of (depth 16 ft), Brunswick River, Cape Fear River, North Carolina Current	NOS	ACT6496_2	34.18117141723633	-77.96582794189453	:America/New_York	USA	knots	127	301	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106243	00:13:00	\N	0.3	00:48:00	\N	0.5	01:34:00	01:14:00	0.4 mile north of	NC
109844	1.8 mi north of mouth (depth 6 ft), Cape Fear River, North Carolina Current	NOS	ACT6501_1	34.205501556396484	-77.97450256347656	:America/New_York	USA	knots	170	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106243	01:43:00	\N	0.3	01:30:00	\N	0.3	01:48:00	01:20:00	1.8 miles north of mouth	NC
109845	Winyah Bay entrance, South Carolina Current	NOS	ACT6531_1	33.20717	-79.1845	:America/New_York	USA	knots	140	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:20:00	\N	1	01:35:00	\N	1.1	01:47:00	01:05:00	Winyah Bay entrance	SC
109846	Range D, off Mosquito Creek, Winyah Bay, South Carolina Current	NOS	ACT6536_1	33.24417	-79.20583	:America/New_York	USA	knots	130	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:42:00	\N	1.1	01:57:00	\N	1.2	02:00:00	01:13:00	Range D, off Mosquito Creek	SC
109847	Frazier Point, south of, Winyah Bay, South Carolina Current	NOS	ACT6541_1	33.295	-79.27283	:America/New_York	USA	knots	115	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:59:00	\N	0.5	01:52:00	\N	1.1	01:52:00	02:20:00	Frazier Point, south of	SC
109848	Frazier Point, west of, Winyah Bay, South Carolina Current	NOS	ACT6546_1	33.30967	-79.28667	:America/New_York	USA	knots	170	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:41:00	\N	1	02:19:00	\N	0.9	02:23:00	02:01:00	Frazier Point, west of	SC
109849	Rabbit Island, northwest of, Winyah Bay, South Carolina Current	NOS	ACT6551_1	33.3395	-79.28133	:America/New_York	USA	knots	215	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	02:25:00	\N	0.9	02:46:00	\N	1.2	02:39:00	02:14:00	Rabbit Island, northwest of	SC
109850	Sampit River entrance, Winyah Bay, South Carolina Current	NOS	ACT6556_1	33.35133	-79.28033	:America/New_York	USA	knots	135	345	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:53:00	\N	0.7	01:20:00	\N	0.6	01:33:00	01:39:00	Sampit River entrance	SC
109851	Georgetown, Sampit River, Winyah Bay, South Carolina Current	NOS	ACT6561_1	33.35917	-79.2875	:America/New_York	USA	knots	80	275	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:52:00	\N	0.6	01:18:00	\N	0.5	02:00:00	00:56:00	Georgetown, Sampit River	SC
109852	Pee Dee River, swing bridge, Winyah Bay, South Carolina Current	NOS	ACT6566_1	33.3705	-79.26383	:America/New_York	USA	knots	210	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	02:43:00	\N	0.5	03:13:00	\N	0.4	03:03:00	01:57:00	Pee Dee River, swing bridge	SC
109853	Lafayette swing bridge, Waccamaw River, Winyah Bay, South Carolina Current	NOS	ACT6571_1	33.36867	-79.252	:America/New_York	USA	knots	200	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	02:31:00	\N	0.6	03:04:00	\N	0.4	03:23:00	01:56:00	Lafayette swing bridge, Waccamaw River	SC
109854	Butler Island, 0.3 mi south of, Winyah Bay, South Carolina Current	NOS	ACT6576_1	33.41667	-79.212	:America/New_York	USA	knots	205	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	02:55:00	\N	0.5	03:34:00	\N	0.4	03:36:00	02:11:00	Butler Island, 0.3 mile south of	SC
109855	North Santee River entrance (depth 6 ft), Santee Rivers, South Carolina Current	NOS	ACT6581_1	33.13583	-79.24083	:America/New_York	USA	knots	165	10	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:01:00	\N	0.9	00:33:00	\N	0.9	01:00:00	00:03:00	North Santee River entrance	SC
109856	South Santee River entrance (depth 5 ft), Santee Rivers, South Carolina Current	NOS	ACT6586_1	33.12	-79.275	:America/New_York	USA	knots	240	45	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:15:00	\N	0.8	00:38:00	\N	0.9	00:20:00	00:27:00	South Santee River entrance	SC
109857	Fort Sumter Range, Buoy 10, Charleston Harbor, South Carolina Current	NOS	ACT6611_1	32.68299865722656	-79.72599792480469	:America/New_York	USA	knots	104	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-01:03:00	\N	0.2	-00:51:00	\N	0.2	-01:05:00	-01:11:00	Fort Sumter Range, Buoy 10	SC
109858	Fort Sumter Range, Buoy 14, Charleston Harbor, South Carolina Current	NOS	ACT6616_1	32.69770050048828	-79.75569915771484	:America/New_York	USA	knots	117	289	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:38:00	\N	0.2	-00:59:00	\N	0.3	-00:49:00	-01:10:00	Fort Sumter Range, Buoy 14	SC
109859	Fort Sumter Range, Buoy 16, Charleston Harbor, South Carolina Current	NOS	ACT6621_1	32.71500015258789	-79.79229736328125	:America/New_York	USA	knots	128	299	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:24:00	\N	0.5	-00:16:00	\N	0.4	-00:15:00	00:17:00	Fort Sumter Range, Buoy 16	SC
109860	Fort Sumter Range, Buoy 18, Charleston Harbor, South Carolina Current	NOS	ACT6626_1	32.724300384521484	-79.80999755859375	:America/New_York	USA	knots	116	287	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:01:00	\N	0.8	-00:04:00	\N	0.6	-00:10:00	00:16:00	Fort Sumter Range, Buoy 18	SC
109861	North Jetty, 0.8 mi southeast of, Charleston Harbor, South Carolina Current	NOS	ACT6631_1	32.7175	-79.8	:America/New_York	USA	knots	110	295	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:16:00	\N	0.6	-00:48:00	\N	0.2	-00:06:00	-01:09:00	North Jetty, 0.8 mile southeast of	SC
109862	Charleston Hbr. ent. (between jetties), Charleston Harbor, South Carolina Current	NOS	ACT6636_1	32.73333	-79.83333	:America/New_York	USA	knots	121	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:09:00	\N	0.9	00:04:00	\N	1.1	-00:01:00	00:05:00	Charleston Hbr. ent. (between jetties)	SC
109863	Fort Sumter Range, Buoy 22, Charleston Harbor, South Carolina Current	NOS	ACT6641_1	32.740501403808594	-79.84449768066406	:America/New_York	USA	knots	128	305	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:51:00	\N	0.9	-00:15:00	\N	0.9	-00:33:00	-00:33:00	Fort Sumter Range, Buoy 22	SC
109864	South Jetty, break in, Charleston Harbor, South Carolina Current	NOS	ACT6646_1	32.73117	-79.85033	:America/New_York	USA	knots	204	2	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:22:00	\N	1.4	00:31:00	\N	0.7	00:38:00	00:06:00	South Jetty, break in	SC
109865	Ft. Sumter, 0.6 nmi NW of, Charleston Harbor, South Carolina Current	NOS	ACT6656_1	32.76117	-79.86717	:America/New_York	USA	knots	138	322	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:24:00	\N	0.9	-00:03:00	\N	0.9	-00:05:00	00:01:00	Ft. Sumter, 0.6 n.mi. NW of	SC
109866	South Chan., 0.8 mi ENE of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6661_1	32.75867	-79.88467	:America/New_York	USA	knots	115	275	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:13:00	\N	1.3	00:11:00	\N	0.5	00:43:00	-00:12:00	South Chan., 0.8 mi. ENE of Ft. Johnson	SC
109867	South Chan., 0.4 mi NW of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6666_1	32.758	-79.90633	:America/New_York	USA	knots	104	282	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:43:00	\N	1	00:58:00	\N	0.4	01:10:00	00:16:00	South Chan., 0.4 mi. NW of Ft. Johnson	SC
109868	Castle Pinckney, 0.4 mi south of, Charleston Harbor, South Carolina Current	NOS	ACT6676_1	32.767	-79.91167	:America/New_York	USA	knots	98	304	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:58:00	\N	0.9	01:00:00	\N	0.5	00:40:00	00:14:00	Castle Pinckney, 0.4 mile south of	SC
109869	South Channel, Buoy 4, Charleston Harbor, South Carolina Current	NOS	ACT6681_1	32.76219940185547	-79.91100311279297	:America/New_York	USA	knots	125	305	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:02:00	\N	0.5	-00:04:00	\N	0.5	-00:01:00	00:18:00	South Channel, Buoy 4	SC
109870	Castle Pinckney, 0.6 mi southwest of, Charleston Harbor, South Carolina Current	NOS	ACT6686_1	32.76633	-79.9195	:America/New_York	USA	knots	156	318	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:40:00	\N	0.7	01:20:00	\N	0.4	01:21:00	00:24:00	Castle Pinckney, 0.6 mile southwest of	SC
109871	Shutes Folly Island, 0.4 mi west of, Charleston Harbor, South Carolina Current	NOS	ACT6691_1	32.77633	-79.92083	:America/New_York	USA	knots	164	28	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:08:00	\N	1.1	00:59:00	\N	0.5	00:53:00	00:20:00	Shutes Folly Island, 0.4 mile west of	SC
109872	Customhouse Reach, off Customhouse, Charleston Harbor, South Carolina Current	NOS	ACT6696_1	32.77949905395508	-79.92250061035156	:America/New_York	USA	knots	190	9	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:23:00	\N	0.7	01:03:00	\N	0.6	00:49:00	00:59:00	Customhouse Reach, off Customhouse	SC
109873	Customhouse Reach, Charleston Harbor, South Carolina Current	NOS	ACT6701_1	32.7825	-79.92	:America/New_York	USA	knots	153	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:15:00	\N	0.9	00:37:00	\N	0.6	00:46:00	00:37:00	Customhouse Reach	SC
109874	Lower Town Creek Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6706_1	32.7925	-79.9245	:America/New_York	USA	knots	172	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:07:00	\N	1.1	00:24:00	\N	0.6	00:34:00	00:02:00	Lower Town Creek Reach	SC
109875	Town Creek, 0.2 mi above bridge, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6711_1	32.80533	-79.93167	:America/New_York	USA	knots	166	2	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:03:00	\N	1.3	00:54:00	\N	0.5	01:06:00	00:03:00	Town Creek, 0.2 mile above bridge	SC
109876	Rebellion Reach, 0.8 nmi N. of Ft. Sumter, Charleston Harbor, South Carolina Current	NOS	ACT6716_1	32.76633	-79.87333	:America/New_York	USA	knots	143	329	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:48:00	\N	0.4	00:27:00	\N	0.4	-00:06:00	-00:25:00	Rebellion Reach, 0.8 n.mi. N. of Ft. Sumter	SC
109877	The Cove, entrance on the Cove Range, Charleston Harbor, South Carolina Current	NOS	ACT6721_1	32.7675	-79.872	:America/New_York	USA	knots	151	346	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:10:00	\N	0.5	01:14:00	\N	0.7	00:28:00	00:06:00	The Cove, entrance on the Cove Range	SC
109878	Hog Island Channel, Charleston Harbor, South Carolina Current	NOS	ACT6726_1	32.78117	-79.87633	:America/New_York	USA	knots	125	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:20:00	\N	0.4	00:03:00	\N	0.5	-00:39:00	-00:29:00	Hog Island Channel	SC
109879	Folly I. Channel, N of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6731_1	32.76967	-79.90117	:America/New_York	USA	knots	104	301	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:59:00	\N	0.6	-00:03:00	\N	0.7	-01:09:00	-00:04:00	Folly I. Channel, N of Ft. Johnson	SC
109880	Bennis Range, Buoy 31, Charleston Harbor, South Carolina Current	NOS	ACT6736_1	32.77629852294922	-79.89920043945312	:America/New_York	USA	knots	110	292	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:13:00	\N	0.8	00:35:00	\N	0.7	00:02:00	00:18:00	Bennis Range, Buoy 31	SC
109881	Bennis Range, Buoy 34, Charleston Harbor, South Carolina Current	NOS	ACT6741_1	32.78219985961914	-79.91079711914062	:America/New_York	USA	knots	136	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:25:00	\N	0.8	00:22:00	\N	0.7	00:18:00	00:15:00	Bennis Range, Buoy 34	SC
109882	Horse Reach, Charleston Harbor, South Carolina Current	NOS	ACT6746_1	32.78617	-79.915	:America/New_York	USA	knots	146	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:09:00	\N	1	00:23:00	\N	0.8	00:36:00	-00:12:00	Horse Reach	SC
109883	Hog Island Reach, Buoy 38, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6751_1	32.794498443603516	-79.91500091552734	:America/New_York	USA	knots	193	12	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:12:00	\N	0.7	00:28:00	\N	0.7	00:13:00	00:14:00	Hog Island Reach, Buoy 38	SC
109884	Drum Island, 0.4 mi SSE of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6756_1	32.7945	-79.92083	:America/New_York	USA	knots	155	11	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:02:00	\N	0.9	00:53:00	\N	0.8	00:34:00	00:11:00	Drum Island, 0.4 mile SSE of	SC
109885	Drum Island, east of (bridge), Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6761_1	32.8045	-79.91533	:America/New_York	USA	knots	183	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:06:00	\N	1	00:42:00	\N	0.7	00:30:00	00:15:00	Drum Island, east of (bridge)	SC
109886	Hog Island Reach, SW of Remley Point, Charleston Harbor, South Carolina Current	NOS	ACT6766_1	32.81183	-79.912	:America/New_York	USA	knots	210	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:51:00	\N	0.7	00:44:00	\N	0.7	00:30:00	00:43:00	Hog Island Reach, SW of Remley Point	SC
109887	Drum Island Reach, marker 45, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6771_1	32.816200256347656	-79.92279815673828	:America/New_York	USA	knots	133	312	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:00:00	\N	0.5	01:00:00	\N	0.4	00:26:00	01:06:00	Drum Island Reach, marker 45	SC
109888	Drum Island, 0.2 mi above, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6776_1	32.81967	-79.92917	:America/New_York	USA	knots	152	332	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:37:00	\N	1.2	01:09:00	\N	0.6	01:12:00	00:01:00	Drum Island, 0.2 mile above	SC
109889	Daniel Island Reach, Buoy 48, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6781_1	32.82720184326172	-79.92880249023438	:America/New_York	USA	knots	182	6	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:55:00	\N	0.7	01:29:00	\N	0.7	01:01:00	00:53:00	Daniel Island Reach, Buoy 48	SC
109890	Shipyard Creek entrance, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6786_1	32.83000183105469	-79.93499755859375	:America/New_York	USA	knots	197	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:09:00	\N	0.8	01:06:00	\N	0.3	00:41:00	-00:29:00	Shipyard Creek entrance	SC
109891	Daniel Island Reach, Buoy 47A, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6791_1	32.832801818847656	-79.93000030517578	:America/New_York	USA	knots	190	352	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:51:00	\N	1.2	01:49:00	\N	0.8	01:29:00	00:42:00	Daniel Island Reach, Buoy 47A	SC
109892	Daniel Island Bend, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6796_1	32.84833	-79.92917	:America/New_York	USA	knots	153	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:39:00	\N	1.1	01:29:00	\N	0.7	00:55:00	00:55:00	Daniel Island Bend	SC
109893	North Charleston, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6806_1	32.86367	-79.95883	:America/New_York	USA	knots	142	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:17:00	\N	0.9	02:28:00	\N	0.6	01:26:00	01:04:00	North Charleston	SC
109894	Filbin Creek Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6811_1	32.88867	-79.96533	:America/New_York	USA	knots	180	6	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:27:00	\N	0.9	02:06:00	\N	0.7	01:31:00	01:08:00	Filbin Creek Reach	SC
109895	Filbin Creek Reach, 0.2 mi east of, Charleston Harbor, South Carolina Current	NOS	ACT6816_1	32.888	-79.9605	:America/New_York	USA	knots	197	2	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:29:00	\N	0.7	01:47:00	\N	0.4	01:16:00	00:32:00	Filbin Creek Reach, 0.2 mile east of	SC
109896	Filbin Creek Reach, Buoy 58, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6821_1	32.89630126953125	-79.96119689941406	:America/New_York	USA	knots	214	31	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:09:00	\N	0.7	02:04:00	\N	0.6	01:18:00	01:24:00	Filbin Creek Reach, Buoy 58	SC
109897	Ordnance Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6826_1	32.90633	-79.95283	:America/New_York	USA	knots	242	62	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:07:00	\N	0.6	02:34:00	\N	0.6	01:35:00	01:05:00	Ordnance Reach	SC
109898	Yellow House Creek, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6831_1	32.90883	-79.93633	:America/New_York	USA	knots	270	88	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:12:00	\N	0.7	02:41:00	\N	0.4	02:06:00	00:57:00	Yellow House Creek	SC
109899	Yellow House Landing, 1 mi NW of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6836_1	32.91967	-79.9305	:America/New_York	USA	knots	170	334	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:06:00	\N	0.9	02:43:00	\N	0.4	02:26:00	00:58:00	Yellow House Landing, 1 mile NW of	SC
109900	Woods Point, SE of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6841_1	32.92583084106445	-79.93283081054688	:America/New_York	USA	knots	157	334	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	02:09:00	\N	0.5	01:55:00	\N	0.5	01:48:00	01:55:00	Woods Point, SE of	SC
109901	Woods Point, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6846_1	32.93167	-79.93833	:America/New_York	USA	knots	201	2	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:43:00	\N	0.7	03:02:00	\N	0.5	02:41:00	01:11:00	Woods Point	SC
109902	Snow Point, 0.5 mi north of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6851_1	32.95167	-79.93	:America/New_York	USA	knots	210	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:33:00	\N	0.7	02:36:00	\N	0.6	02:15:00	01:48:00	Snow Point, 0.5 mile north of	SC
109903	Back River entrance, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6856_1	32.96833	-79.93333	:America/New_York	USA	knots	67	252	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:34:00	\N	0.6	00:45:00	\N	0.6	00:46:00	00:48:00	Back River entrance	SC
109904	Off Amoco Pier, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6861_1	32.95920181274414	-79.91799926757812	:America/New_York	USA	knots	191	24	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:48:00	\N	0.5	02:49:00	\N	0.4	02:09:00	02:10:00	off Amoco Pier	SC
109905	Moreland, 0.5 nmi below, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6866_1	33.0005	-79.90467	:America/New_York	USA	knots	216	36	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	02:19:00	\N	1	02:58:00	\N	1.1	02:39:00	02:28:00	Moreland, 0.5 n.mi. below	SC
109906	Hagan Island, 1 nmi below, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6871_1	33.03333	-79.91333	:America/New_York	USA	knots	134	308	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:37:00	\N	0.7	03:52:00	\N	0.8	02:39:00	02:27:00	Hagan Island, 1 n.mi. below	SC
109907	The Tee, 0.4 mi southwest of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6876_1	33.06333	-79.92967	:America/New_York	USA	knots	98	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	03:20:00	\N	0.9	04:20:00	\N	0.6	04:22:00	02:29:00	The Tee, 0.4 mile southwest of	SC
109908	The Tee, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6881_1	33.06583	-79.923	:America/New_York	USA	knots	161	339	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:43:00	\N	0.5	03:09:00	\N	0.6	03:00:00	02:36:00	The Tee	SC
109909	Childsbury, S.A.L. RR. bridge, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6886_1	33.09383	-79.9425	:America/New_York	USA	knots	141	309	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	03:34:00	\N	0.9	04:27:00	\N	0.4	04:43:00	02:15:00	Childsbury, S.A.L. RR. bridge	SC
109910	East Branch, 0.2 mi above entrance, Charleston Harbor, South Carolina Current	NOS	ACT6891_1	33.06833	-79.92	:America/New_York	USA	knots	262	84	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	03:06:00	\N	0.9	03:07:00	\N	1.1	03:01:00	02:59:00	East Branch, 0.2 mile above entrance	SC
109911	Bonneau Ferry, east of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6896_1	33.07167	-79.88333	:America/New_York	USA	knots	197	22	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	03:36:00	\N	0.4	03:10:00	\N	0.4	03:27:00	02:44:00	Bonneau Ferry, east of	SC
109912	Remley Point, 0.2 mi northwest of, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6901_1	32.81617	-79.9095	:America/New_York	USA	knots	191	28	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:04:00	\N	0.9	00:36:00	\N	0.8	-00:14:00	00:20:00	Remley Point, 0.2 mile northwest of	SC
109913	Wando River Upper Reach, Turning Basin, Charleston Harbor, South Carolina Current	NOS	ACT6906_1	32.83333	-79.89667	:America/New_York	USA	knots	192	12	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:09:00	\N	0.6	-00:12:00	\N	0.6	-00:14:00	-00:09:00	Wando River Upper Reach, Turning Basin	SC
109914	Rathall Creek entrance, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6911_1	32.8595	-79.89617	:America/New_York	USA	knots	216	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:18:00	\N	0.9	00:35:00	\N	0.8	00:25:00	00:18:00	Rathall Creek entrance	SC
109915	Horlbeck Creek, 0.2 mi above entrance, Charleston Harbor, South Carolina Current	NOS	ACT6916_1	32.885	-79.845	:America/New_York	USA	knots	218	26	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:24:00	\N	0.5	00:29:00	\N	0.6	00:28:00	00:31:00	Horlbeck Creek, 0.2 mile above entrance	SC
109916	Nowell Creek entrance, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6921_1	32.87833	-79.875	:America/New_York	USA	knots	171	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:39:00	\N	0.6	00:42:00	\N	0.4	-00:02:00	-00:12:00	Nowell Creek entrance	SC
109917	Nowell Creek, southeast of, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6926_1	32.87200164794922	-79.8655014038086	:America/New_York	USA	knots	261	80	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:19:00	\N	0.5	-00:06:00	\N	0.5	-00:08:00	00:04:00	Nowell Creek, Southeast of	SC
109918	Anneville, marker 36, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6931_1	32.91830062866211	-79.83830261230469	:America/New_York	USA	knots	207	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:28:00	\N	0.7	00:41:00	\N	0.5	00:30:00	00:26:00	Anneville, marker 36	SC
109919	Battery, southwest of, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6936_1	32.76717	-79.93383	:America/New_York	USA	knots	114	303	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:03:00	\N	0.9	00:09:00	\N	0.7	00:16:00	-00:24:00	Battery, southwest of	SC
109920	Wappoo Creek entrance, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6941_1	32.77299880981445	-79.94999694824219	:America/New_York	USA	knots	136	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:41:00	\N	0.6	-00:05:00	\N	0.7	00:07:00	-00:06:00	Wappoo Creek entrance	SC
109921	Ashley River Memorial Bridge, Highway 17, Charleston Harbor, South Carolina Current	NOS	ACT6946_1	32.78200149536133	-79.95999908447266	:America/New_York	USA	knots	138	321	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:18:00	\N	0.6	00:30:00	\N	0.7	-00:09:00	-00:03:00	Ashley River Memorial Bridge, Highway 17	SC
109922	Trestle Ruins, marker 6A, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6951_1	32.795501708984375	-79.97329711914062	:America/New_York	USA	knots	150	353	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:28:00	\N	0.6	00:44:00	\N	0.6	-00:06:00	-00:12:00	Trestle Ruins, marker 6A	SC
109923	Duck Island, Marker 15, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6956_1	32.81999969482422	-79.96499633789062	:America/New_York	USA	knots	178	351	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:09:00	\N	0.8	00:19:00	\N	0.7	00:22:00	00:17:00	Duck Island, Marker 15	SC
109924	State Hwy. 7 bridge, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6961_1	32.83717	-79.982	:America/New_York	USA	knots	114	293	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:05:00	\N	0.5	-00:04:00	\N	0.6	00:06:00	00:05:00	State Hwy. 7 bridge	SC
109925	West Marsh Island, 0.1 mi east of, Charleston Harbor, South Carolina Current	NOS	ACT6966_1	32.82833	-80.00833	:America/New_York	USA	knots	86	250	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:25:00	\N	0.5	00:30:00	\N	0.4	00:23:00	00:14:00	West Marsh Island, 0.1 mile east of	SC
109926	Drayton, Railroad Bridge, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6971_1	32.84669876098633	-80.05000305175781	:America/New_York	USA	knots	130	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:21:00	\N	1.2	00:30:00	\N	1.1	00:22:00	00:44:00	Drayton, Railroad Bridge	SC
109927	Stono Inlet, Stono River, South Carolina Current	NOS	ACT6976_1	32.62667	-79.99333	:America/New_York	USA	knots	136	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:45:00	\N	1.4	00:44:00	\N	1.1	-00:14:00	-00:09:00	Stono Inlet	SC
109928	Snake Island (depth 12 ft), Stono River, South Carolina Current	NOS	ACT6981_1	32.64	-80.02	:America/New_York	USA	knots	179	347	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:38:00	\N	0.5	-00:42:00	\N	0.7	-00:44:00	-00:30:00	Snake Island	SC
109929	Johns Island Airport, south of (depth 12 ft), Stono River, South Carolina Current	NOS	ACT6986_1	32.68333	-80.00333	:America/New_York	USA	knots	192	7	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:34:00	\N	0.8	-00:46:00	\N	0.9	-00:15:00	-00:13:00	Johns Island Airport, south of	SC
109930	Johns Island Bridge (depth 14 ft), Stono River, South Carolina Current	NOS	ACT6991_1	32.75333	-80.01	:America/New_York	USA	knots	182	358	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:10:00	\N	0.5	00:21:00	\N	0.5	00:40:00	00:33:00	Johns Island Bridge	SC
109931	Elliott Cut, west end, Stono River, South Carolina Current	NOS	ACT6996_1	32.76667	-80	:America/New_York	USA	knots	80	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:18:00	\N	1	-01:00:00	\N	0.9	00:10:00	-00:46:00	Elliott Cut, west end	SC
109932	Johns Island, main road bridge (depth 12 ft), Stono River, South Carolina Current	NOS	ACT7001_1	32.78670120239258	-80.10669708251953	:America/New_York	USA	knots	68	249	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:32:00	\N	0.4	01:48:00	\N	0.4	-00:24:00	00:29:00	Johns Island. Main Road Bridge	SC
109933	Pleasant Point (depth 12 ft), Stono River, South Carolina Current	NOS	ACT7006_1	32.75	-80.13333	:America/New_York	USA	knots	196	8	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	03:37:00	\N	0.4	00:34:00	\N	0.3	02:04:00	03:54:00	Pleasant Point	SC
109934	Deveaux Banks, off North Edisto River entrance (depth 12 ft), South Carolina Current	NOS	ACT7021_1	32.545	-80.15667	:America/New_York	USA	knots	126	306	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:26:00	\N	1	-00:01:00	\N	0.8	-00:16:00	-00:04:00	Deveaux Banks, off North Edisto River entrance	SC
109935	North Edisto River entrance, South Carolina Current	NOS	ACT7026_1	32.56167	-80.18667	:America/New_York	USA	knots	142	332	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:43:00	\N	1.9	01:10:00	\N	1.7	00:56:00	01:11:00	North Edisto River entrance	SC
109936	Wadmalaw Island, Wadmalaw River entrance (depth 12 ft), South Carolina Current	NOS	ACT7031_1	32.665	-80.235	:America/New_York	USA	knots	165	355	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-01:29:00	\N	0.4	00:11:00	\N	0.7	-01:02:00	00:06:00	Wadmalaw Island, Wadmalaw River entrance	SC
109937	Goshen Point, SE of, Wadmalaw River (depth 12 ft), South Carolina Current	NOS	ACT7036_1	32.71	-80.17167	:America/New_York	USA	knots	249	59	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:48:00	\N	0.4	02:18:00	\N	0.5	00:51:00	01:47:00	Goshen Point, SE of, Wadmalaw River	SC
109938	Goshen Point, south of, Wadmalaw River (depth 12 ft), South Carolina Current	NOS	ACT7041_1	32.71333	-80.18667	:America/New_York	USA	knots	235	48	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:53:00	\N	0.5	02:03:00	\N	0.4	01:24:00	01:35:00	Goshen Point, south of, Wadmalaw River	SC
109939	White Point, south of, Dawho River (depth 12 ft), South Carolina Current	NOS	ACT7046_1	32.625	-80.28167	:America/New_York	USA	knots	44	234	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:15:00	\N	0.4	00:02:00	\N	0.4	00:31:00	00:29:00	White Point, south of, Dawho River	SC
109940	Whooping Island, Dawho River (depth 12 ft), North Edisto River, South Carolina Current	NOS	ACT7051_1	32.63667	-80.34	:America/New_York	USA	knots	70	246	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:37:00	\N	0.3	00:36:00	\N	0.5	01:36:00	01:35:00	Whooping Island, Dawho River	SC
109941	South Edisto River entrance, South Carolina Current	NOS	ACT7056_1	32.48833	-80.34833	:America/New_York	USA	knots	146	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:24:00	\N	1.1	-00:14:00	\N	1.1	00:19:00	-00:09:00	South Edisto River entrance	SC
109942	Pine Island, South Edisto River (depth 15 ft), South Carolina Current	NOS	ACT7061_1	32.50667	-80.36167	:America/New_York	USA	knots	163	345	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:37:00	\N	0.5	-00:09:00	\N	0.7	00:00:00	00:12:00	Pine Island, South Edisto River	SC
109943	Fenwick Island Cut, South Edisto River (depth 15 ft), South Carolina Current	NOS	ACT7066_1	32.535	-80.41333	:America/New_York	USA	knots	23	220	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-01:26:00	\N	0.4	-00:55:00	\N	0.4	-02:43:00	-03:20:00	Fenwick Island Cut, South Edisto River	SC
109944	Sampson Island, S end, South Edisto Riv. (depth 15 ft), South Carolina Current	NOS	ACT7071_1	32.56330108642578	-80.3917007446289	:America/New_York	USA	knots	244	37	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:52:00	\N	0.8	00:34:00	\N	0.8	00:59:00	00:59:00	Sampson Island, S end, South Edisto Riv.	SC
109945	Sampson Island, NE end, South Edisto Riv. (depth 15 ft), South Carolina Current	NOS	ACT7076_1	32.61669921875	-80.38670349121094	:America/New_York	USA	knots	156	334	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:52:00	\N	0.8	01:15:00	\N	0.8	01:35:00	01:02:00	Sampson Island, NE end, South Edisto Riv.	SC
109946	Jehossee Island, S tip, South Edisto River (depth 15 ft), South Carolina Current	NOS	ACT7081_1	32.60333	-80.42	:America/New_York	USA	knots	69	275	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:05:00	\N	0.7	00:48:00	\N	0.7	01:44:00	00:53:00	Jehossee Island, S tip, South Edisto River	SC
109947	Smuggedy Swamp, South Edisto River (depth 6 ft), South Carolina Current	NOS	ACT7086_1	32.66	-80.41167	:America/New_York	USA	knots	166	349	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	02:25:00	\N	0.7	01:14:00	\N	0.5	02:26:00	01:01:00	Smuggedy Swamp, South Edisto River	SC
109948	Hutchinson Island, N. of, Ashepoo River (depth 10 ft), South Carolina Current	NOS	ACT7091_1	32.531700134277344	-80.43499755859375	:America/New_York	USA	knots	68	278	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:56:00	\N	0.7	01:14:00	\N	0.6	01:21:00	00:54:00	Hutchinson Island, N. of, Ashepoo River	SC
109949	Ashepoo Coosaw Cutoff, ICW marker 169 (depth 6 ft), South Carolina Current	NOS	ACT7096_1	32.525001525878906	-80.45330047607422	:America/New_York	USA	knots	265	65	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:12:00	\N	0.6	00:36:00	\N	0.5	01:22:00	00:56:00	Ashepoo Coosaw Cutoff, ICW marker 169	SC
109950	Pelican Bank, St. Helena Sound (depth 15 ft), South Carolina Current	NOS	ACT7101_1	32.455	-80.42833	:America/New_York	USA	knots	118	300	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:35:00	\N	0.8	-00:33:00	\N	0.9	00:05:00	00:17:00	Pelican Bank, St. Helena Sound	SC
109951	Ashepoo River, off Jefford Creek, St. Helena Sound, South Carolina Current	NOS	ACT7106_1	32.50669860839844	-80.41000366210938	:America/New_York	USA	knots	197	16	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:43:00	\N	0.8	00:46:00	\N	0.9	01:04:00	01:00:00	Ashepoo River, off Jefford Creek	SC
109952	Egg Bank, St. Helena Sound (depth 10 ft), South Carolina Current	NOS	ACT7111_1	32.435	-80.44333	:America/New_York	USA	knots	128	329	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:20:00	\N	0.8	-01:24:00	\N	0.8	-00:12:00	-00:06:00	Egg Bank, St. Helena Sound	SC
109953	Morgan Island, NE of, Coosaw River (depth 15 ft), South Carolina Current	NOS	ACT7116_1	32.48833	-80.47333	:America/New_York	USA	knots	125	303	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:19:00	\N	1	00:27:00	\N	0.8	00:28:00	00:36:00	Morgan Island, NE of, Coosaw River	SC
109969	Hilton Head, Port Royal Sound, South Carolina Current	NOS	ACT7201_1	32.25	-80.66667	:America/New_York	USA	knots	146	324	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:01:00	\N	0.9	00:49:00	\N	1.1	00:16:00	00:32:00	Hilton Head	SC
109954	Ashepoo Coosaw Cutoff, south end (depth 15 ft), St. Helena Sound, South Carolina Current	NOS	ACT7121_1	32.5099983215332	-80.50499725341797	:America/New_York	USA	knots	134	325	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:31:00	\N	0.6	-00:09:00	\N	0.6	00:32:00	00:43:00	Ashepoo Coosaw Cutoff, south end	SC
109955	Ashepoo Coosaw Cutoff, ICW marker 181 (depth 6 ft), South Carolina Current	NOS	ACT7126_1	32.52000045776367	-80.48829650878906	:America/New_York	USA	knots	34	232	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:13:00	\N	0.4	01:41:00	\N	0.5	00:31:00	01:01:00	Ashepoo Coosaw Cutoff, ICW marker 181	SC
109956	Combahee River entrance (depth 8 ft), St. Helena Sound, South Carolina Current	NOS	ACT7131_1	32.52669906616211	-80.53669738769531	:America/New_York	USA	knots	147	335	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:53:00	\N	0.8	00:59:00	\N	0.6	00:55:00	01:04:00	Combahee River entrance	SC
109957	Combahee River, S. of Fields Point (depth 15 ft), South Carolina Current	NOS	ACT7136_1	32.54999923706055	-80.56330108642578	:America/New_York	USA	knots	73	280	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:03:00	\N	1	01:35:00	\N	0.8	01:36:00	01:33:00	Combahee River, S. of Fields Point	SC
109958	Parrot Creek, Coosaw Island (depth 15 ft), St. Helena Sound, South Carolina Current	NOS	ACT7141_1	32.47333	-80.545	:America/New_York	USA	knots	175	355	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:54:00	\N	0.6	-00:48:00	\N	0.7	00:12:00	00:24:00	Parrot Creek, Coosaw Island	SC
109959	Morgan Island, north end, Coosaw River (depth 15 ft), South Carolina Current	NOS	ACT7146_1	32.50333	-80.53667	:America/New_York	USA	knots	85	271	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:30:00	\N	0.9	00:41:00	\N	0.8	00:34:00	00:27:00	Morgan Island, North end, Coosaw River	SC
109960	Williman Creek (depth 10 ft), St. Helena Sound, South Carolina Current	NOS	ACT7151_1	32.56167	-80.59167	:America/New_York	USA	knots	160	343	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:04:00	\N	0.8	01:27:00	\N	0.6	00:40:00	01:02:00	Williman Creek	SC
109961	Coosaw Island, south of, Morgan River (depth 10 ft), South Carolina Current	NOS	ACT7156_1	32.45167	-80.58333	:America/New_York	USA	knots	58	252	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:03:00	\N	0.7	00:55:00	\N	0.7	00:09:00	00:15:00	Coosaw Island, South of, Morgan River	SC
109962	Sams Point, northeast of, Coosaw River (depth 10 ft), South Carolina Current	NOS	ACT7161_1	32.49330139160156	-80.59329986572266	:America/New_York	USA	knots	117	292	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:24:00	\N	0.6	00:36:00	\N	0.5	00:34:00	00:31:00	Sams Point, Northeast of, Coosaw River	SC
109963	Whale Branch River (depth 10 ft), St. Helena Sound, South Carolina Current	NOS	ACT7166_1	32.52667	-80.69167	:America/New_York	USA	knots	111	295	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:09:00	\N	0.7	-00:09:00	\N	0.5	01:12:00	00:51:00	Whale Branch River	SC
109964	Fripps Inlet, Fripps Island (depth 15 ft), St. Helena Sound, South Carolina Current	NOS	ACT7171_1	32.34	-80.465	:America/New_York	USA	knots	104	299	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-01:29:00	\N	0.6	01:12:00	\N	0.7	-00:29:00	-00:22:00	Fripps Inlet, Fripps Island	SC
109965	Southeast Channel, Buoy 8, Port Royal Sound, South Carolina Current	NOS	ACT7181_1	32.13330078125	-80.58329772949219	:America/New_York	USA	knots	150	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:12:00	\N	0.8	-00:38:00	\N	0.8	-00:30:00	-00:09:00	Southeast Channel, Buoy 8	SC
109966	Port Royal Plantation Tower, east of (depth 15 ft), South Carolina Current	NOS	ACT7186_1	32.22333	-80.65667	:America/New_York	USA	knots	147	347	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:16:00	\N	1	-00:16:00	\N	0.9	00:33:00	00:19:00	Port Royal Plantation Tower, east of	SC
109967	Bay Point Island, S of, Broad River entrance (depth 15 ft), South Carolina Current	NOS	ACT7191_1	32.23333	-80.63	:America/New_York	USA	knots	128	320	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:46:00	\N	0.9	-01:09:00	\N	0.7	00:39:00	00:06:00	Bay Point Island, S of, Broad River entrance	SC
109968	Broad River entrance, Point Royal Sound (depth 15 ft), South Carolina Current	NOS	ACT7196_1	32.23167	-80.64	:America/New_York	USA	knots	138	324	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:25:00	\N	0.9	00:21:00	\N	1	00:36:00	00:32:00	Broad River Entrance, Point Royal Sound	SC
109970	Beaufort River entrance (depth 15 ft), Port Royal Sound, South Carolina Current	NOS	ACT7206_1	32.28833	-80.65167	:America/New_York	USA	knots	195	10	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:03:00	\N	0.7	01:11:00	\N	0.7	00:19:00	00:20:00	Beaufort River Entrance	SC
109971	Parris Island, east of, Beaufort River (depth 10 ft), South Carolina Current	NOS	ACT7211_1	32.326698303222656	-80.65670013427734	:America/New_York	USA	knots	175	356	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:12:00	\N	0.8	01:12:00	\N	0.7	00:29:00	00:11:00	Parris Island, east of, Beaufort River	SC
109972	Chowan Creek (depth 15 ft), Port Royal Sound, South Carolina Current	NOS	ACT7216_1	32.37	-80.63833	:America/New_York	USA	knots	246	39	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:34:00	\N	0.6	01:53:00	\N	0.6	00:24:00	00:23:00	Chowan Creek	SC
109973	Parris Island, north of, Beaufort River (depth 15 ft), South Carolina Current	NOS	ACT7221_1	32.36000061035156	-80.67500305175781	:America/New_York	USA	knots	149	341	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:22:00	\N	0.7	01:19:00	\N	0.7	00:56:00	00:51:00	Parris Island, north of, Beaufort River	SC
109974	Burkmeyer Bech, Beaufort River (depth 15 ft), Port Royal Sound, South Carolina Current	NOS	ACT7226_1	32.40330123901367	-80.67169952392578	:America/New_York	USA	knots	200	12	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:33:00	\N	0.5	01:19:00	\N	0.5	01:04:00	01:01:00	Burkmeyer Bech, Beaufort River	SC
109975	Beaufort, Beaufort River (depth 12 ft), Port Royal Sound, South Carolina Current	NOS	ACT7231_1	32.43	-80.67667	:America/New_York	USA	knots	257	73	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:17:00	\N	0.6	01:18:00	\N	0.7	00:55:00	01:08:00	Beaufort, Beaufort River	SC
109976	Beaufort Airport, Beaufort River (depth 15 ft), Port Royal Sound, South Carolina Current	NOS	ACT7236_1	32.45	-80.66333	:America/New_York	USA	knots	152	333	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	01:08:00	\N	0.5	01:39:00	\N	0.5	01:25:00	01:21:00	Beaufort Airport, Beaufort River	SC
109977	Brickyard Creek (depth 10 ft), Port Royal Sound, South Carolina Current	NOS	ACT7241_1	32.47333	-80.69167	:America/New_York	USA	knots	171	351	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	02:58:00	\N	0.4	00:30:00	\N	0.5	01:48:00	02:50:00	Brickyard Creek	SC
109978	Skull Creek, north entrance, Port Royal Sound, South Carolina Current	NOS	ACT7246_1	32.26333	-80.74167	:America/New_York	USA	knots	35	222	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-02:14:00	\N	0.6	-01:20:00	\N	0.4	-01:50:00	-01:58:00	Skull Creek, north entrance	SC
109979	Daws Island, SE of, Broad River (depth 15 ft), Port Royal Sound, South Carolina Current	NOS	ACT7251_1	32.30167	-80.725	:America/New_York	USA	knots	150	330	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:31:00	\N	0.8	00:05:00	\N	0.8	00:46:00	00:39:00	Daws Island, SE of, Broad River	SC
109980	Parris Island Lookout Tower, Broad River (depth 15 ft), South Carolina Current	NOS	ACT7256_1	32.31167	-80.70667	:America/New_York	USA	knots	152	339	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:16:00	\N	0.7	-00:07:00	\N	0.7	00:39:00	00:29:00	Parris Island Lookout Tower, Broad River	SC
109981	Daws Island, south of, Chechessee River (depth 15 ft), South Carolina Current	NOS	ACT7261_1	32.28667	-80.74333	:America/New_York	USA	knots	142	317	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:31:00	\N	0.7	-00:22:00	\N	0.6	00:31:00	00:34:00	Daws Island, south of, Chechessee River	SC
109982	Lemon Island South, Chechessee River (depth 10 ft), South Carolina Current	NOS	ACT7266_1	32.35	-80.80667	:America/New_York	USA	knots	175	359	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	-00:02:00	\N	0.7	01:19:00	\N	0.6	00:33:00	00:39:00	Lemon Island South, Chechessee River	SC
109983	Broad River Bridge, S of, Broad River (depth 15 ft), South Carolina Current	NOS	ACT7271_1	32.38167	-80.77667	:America/New_York	USA	knots	156	341	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:07:00	\N	0.8	-00:15:00	\N	0.6	00:52:00	00:49:00	Broad River Bridge, S of, Broad River	SC
109984	Boyd Creek entrance, SE of, Broad River (depth 12 ft), South Carolina Current	NOS	ACT7276_1	32.45669937133789	-80.81829833984375	:America/New_York	USA	knots	174	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:52:00	\N	0.5	00:51:00	\N	0.6	01:27:00	01:32:00	Boyd Creek Entrance, SE of, Broad River	SC
109985	Little Barnwell I., E of, Whale Branch River (depth 6 ft), South Carolina Current	NOS	ACT7281_1	32.50167	-80.78667	:America/New_York	USA	knots	175	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106034	00:40:00	\N	0.4	03:03:00	\N	0.6	01:41:00	01:54:00	Little Barnwell I., E of, Whale Branch River	SC
109986	Braddock Point, SW of, Calibogue Sound (depth 10 ft), South Carolina Current	NOS	ACT7286_1	32.105	-80.83667	:America/New_York	USA	knots	183	6	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:04:00	\N	1	00:16:00	\N	0.8	-00:15:00	-00:04:00	Braddock Point, SW of, Calibogue Sound	SC
109987	Haig Point Light, NW of, Cooper River (depth 10 ft), South Carolina Current	NOS	ACT7291_1	32.14833	-80.84167	:America/New_York	USA	knots	94	278	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:12:00	\N	0.7	-00:05:00	\N	0.4	-00:51:00	-00:40:00	Haig Point Light, NW of, Cooper River	SC
109988	Ramshorn Creek Light, E of, Cooper River (depth 6 ft), South Carolina Current	NOS	ACT7296_1	32.13	-80.88167	:America/New_York	USA	knots	98	280	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:17:00	\N	0.7	-00:53:00	\N	0.5	00:06:00	00:15:00	Ramshorn Creek Light, E of, Cooper River	SC
109989	Spanish Wells, Calibogue Sound (depth 30 ft), South Carolina Current	NOS	ACT7301_1	32.18667	-80.785	:America/New_York	USA	knots	204	28	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:10:00	\N	0.7	00:51:00	\N	0.7	-00:14:00	00:12:00	Spanish Wells, Calibogue Sound	SC
109990	Skull Creek, south entrance (depth 10 ft), Calibogue Sound, South Carolina Current	NOS	ACT7306_1	32.22333	-80.785	:America/New_York	USA	knots	231	53	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	00:55:00	\N	0.4	02:57:00	\N	0.4	00:38:00	01:23:00	Skull Creek, south entrance	SC
109991	MacKay Creek, south entrance (depth 10 ft), Calibogue Sound, South Carolina Current	NOS	ACT7311_1	32.22	-80.79	:America/New_York	USA	knots	212	33	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:26:00	\N	0.6	00:03:00	\N	0.3	00:06:00	00:12:00	MacKay Creek, south entrance	SC
109992	Bloody Pt., 0.5 mi north of, New River, South Carolina Current	NOS	ACT7316_1	32.08833	-80.88	:America/New_York	USA	knots	147	332	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-02:13:00	\N	0.6	00:00:00	\N	0.6	-01:03:00	-00:53:00	Bloody Pt., 0.5 mile north of, New River	SC
109993	Bloody Pt., 0.5 mi west of, New River, South Carolina Current	NOS	ACT7321_1	32.08167	-80.88333	:America/New_York	USA	knots	92	267	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:26:00	\N	0.9	-00:21:00	\N	0.9	-00:47:00	-00:36:00	Bloody Pt., 0.5 mile west of, New River	SC
109994	Wright R., 0.2 mi above Walls Cut, South Carolina Current	NOS	ACT7326_1	32.085	-80.92167	:America/New_York	USA	knots	142	332	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:16:00	\N	0.8	-00:16:00	\N	0.6	-00:38:00	-00:38:00	Wright R., 0.2 mile above Walls Cut	SC
109995	Walls Cut, Turtle Island (depth 6 ft), South Carolina Current	NOS	ACT7336_1	32.08167	-80.91667	:America/New_York	USA	knots	100	294	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-03:05:00	\N	0.5	-00:57:00	\N	0.5	-02:29:00	-01:12:00	Walls Cut, Turtle Island	SC
109996	Daufuskie Landing Light, south of (depth 10 ft), South Carolina Current	NOS	ACT7341_1	32.10167	-80.89833	:America/New_York	USA	knots	226	43	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:45:00	\N	0.8	01:04:00	\N	0.7	00:07:00	00:02:00	Daufuskie Landing Light, south of	SC
109997	Fort Pulaski, N of, Savannah River, South Carolina Current	NOS	ACT7356_1	32.03667	-80.90167	:America/New_York	USA	knots	98	283	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	00:09:00	\N	1.5	00:51:00	\N	0.9	00:42:00	00:15:00	Fort Pulaski	SC
109998	Fort Pulaski, 1.8 mi above, Savannah River, Georgia Current	NOS	ACT7361_1	32.045	-80.93167	:America/New_York	USA	knots	140	316	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	00:12:00	\N	1.4	00:18:00	\N	1.1	00:25:00	-00:01:00	Fort Pulaski, 1.8 miles above	GA
109999	Fort Pulaski, 4.8 mi above, Savannah River, Georgia Current	NOS	ACT7366_1	32.075	-80.97667	:America/New_York	USA	knots	116	296	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:16:00	\N	1.5	00:31:00	\N	1.1	00:36:00	00:06:00	Fort Pulaski, 4.8 miles above	GA
110000	McQueen Island Cut (depth 10 ft), Savannah River, Georgia Current	NOS	ACT7371_1	32.065	-80.98667	:America/New_York	USA	knots	69	251	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-02:44:00	\N	0.6	-02:45:00	\N	0.3	-02:39:00	-01:04:00	McQueen Island Cut	GA
110001	Elba Island Cut, NE of, Savannah River (depth 10 ft), South Carolina Current	NOS	ACT7376_1	32.07333	-80.965	:America/New_York	USA	knots	104	288	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:14:00	\N	1.3	00:15:00	\N	0.7	00:26:00	-00:37:00	Elba Island Cut, NE of, Savannah River	SC
110002	Elba Island, NE of, Savannah River (depth 10 ft), Georgia Current	NOS	ACT7381_1	32.09	-80.99333	:America/New_York	USA	knots	149	329	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:27:00	\N	1.2	00:40:00	\N	0.6	01:01:00	-00:35:00	Elba Island, NE of, Savannah River	GA
110003	Elba Island, west of, Savannah River (depth 10 ft), South Carolina Current	NOS	ACT7386_1	32.095	-81.02	:America/New_York	USA	knots	40	219	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:53:00	\N	0.8	00:52:00	\N	0.5	00:37:00	-00:30:00	Elba Island, west of, Savannah River	SC
110004	Fig Island, north of, Back River, Savannah River, Georgia Current	NOS	ACT7391_1	32.085	-81.05	:America/New_York	USA	knots	94	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:00:00	\N	0.7	01:06:00	\N	0.5	00:14:00	-00:25:00	Fig Island, north of, Back River	GA
110005	South Channel, western end, Savannah River, Georgia Current	NOS	ACT7396_1	32.08833	-81.01667	:America/New_York	USA	knots	122	300	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:35:00	\N	0.7	00:18:00	\N	0.5	00:42:00	-00:33:00	South Channel, western end	GA
110006	Wilmington R. ent., south channel, Savannah River, Georgia Current	NOS	ACT7401_1	32.07667	-81.00167	:America/New_York	USA	knots	206	32	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	01:25:00	\N	0.8	-00:36:00	\N	0.5	00:42:00	01:28:00	Wilmington R. ent., south channel	GA
110007	Savannah, southeast of highway bridge (depth 10 ft), Savannah River, Georgia Current	NOS	ACT7406_1	32.08667	-81.09667	:America/New_York	USA	knots	146	319	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	00:05:00	\N	1.3	00:41:00	\N	0.6	01:36:00	-00:24:00	Savannah, southeast of highway bridge	GA
110008	Savannah, Savannah River, Georgia Current	NOS	ACT7411_1	32.08333	-81.08333	:America/New_York	USA	knots	106	279	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	00:18:00	\N	1.1	00:45:00	\N	0.8	01:12:00	00:01:00	Savannah	GA
110009	Kings Island Channel, Savannah River (depth 10 ft), Georgia Current	NOS	ACT7416_1	32.12667	-81.13667	:America/New_York	USA	knots	152	339	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:21:00	\N	1	00:45:00	\N	0.8	01:21:00	00:06:00	Kings Island Channel, Savannah River	GA
110010	Seaboard Coast Line Railroad, Savannah River, Georgia Current	NOS	ACT7421_1	32.10333	-81.11833	:America/New_York	USA	knots	150	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	00:59:00	\N	1.7	00:45:00	\N	1.2	01:06:00	00:29:00	Seaboard Coast Line Railroad	GA
110011	King Island, west of, Savannah River, Georgia Current	NOS	ACT7426_1	32.12333	-81.135	:America/New_York	USA	knots	160	337	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	00:48:00	\N	1	00:54:00	\N	0.7	01:21:00	00:33:00	King Island, west of	GA
110012	Port Wentworth, 0.2 mi above, Savannah River, Georgia Current	NOS	ACT7431_1	32.14667	-81.14	:America/New_York	USA	knots	210	22	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	01:19:00	\N	0.7	01:36:00	\N	0.5	02:00:00	00:24:00	Port Wentworth, 0.2 mile above	GA
110013	Wassaw Island, N of E end, Wassaw Sound (depth 10 ft), Savannah River, Georgia Current	NOS	ACT7441_1	31.915	-80.93833	:America/New_York	USA	knots	108	292	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:33:00	\N	1	-00:50:00	\N	0.7	-00:48:00	-00:45:00	Wassaw Island, N of E end, Wassaw Sound	GA
110014	Entrance, off Beach Hammock, Wassaw Sound, Georgia Current	NOS	ACT7446_1	31.94167	-80.93167	:America/New_York	USA	knots	156	352	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:44:00	\N	1.1	-01:00:00	\N	0.9	-00:41:00	-00:54:00	Entrance, off Beach Hammock	GA
110015	Wilmington Island, SSE of, Bull River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7451_1	31.96667	-80.93	:America/New_York	USA	knots	218	35	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-02:00:00	\N	0.7	00:38:00	\N	0.4	-00:35:00	-00:40:00	Wilmington Island, SSE of, Bull River	GA
110016	Lazaretto Creek entrance, N of, Bull River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7456_1	32	-80.92833	:America/New_York	USA	knots	207	15	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-02:04:00	\N	0.7	00:00:00	\N	0.5	-00:37:00	-00:33:00	Lazaretto Creek Entrance, N of, Bull River	GA
110017	Bull River, 2 mi below hwy. bridge, Wassaw Sound, Georgia Current	NOS	ACT7461_1	32.01833	-80.94	:America/New_York	USA	knots	151	327	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:57:00	\N	0.8	-00:18:00	\N	0.6	-00:18:00	-00:25:00	Bull River, 2 miles below hwy. bridge	GA
110018	Entrance, off Wassaw Island, Wassaw Sound, Georgia Current	NOS	ACT7466_1	31.91667	-80.94667	:America/New_York	USA	knots	105	277	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:27:00	\N	0.9	-01:11:00	\N	0.7	-00:46:00	-00:42:00	Entrance, off Wassaw Island	GA
110019	Wilmington River ent. off Cabbage Island, Wassaw Sound, Georgia Current	NOS	ACT7471_1	31.93833	-80.97667	:America/New_York	USA	knots	138	323	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:51:00	\N	0.8	-00:36:00	\N	0.6	-00:44:00	-00:45:00	Wilmington River ent. off Cabbage Island	GA
110020	Joe's Cut, Wilmington River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7476_1	31.94333	-80.985	:America/New_York	USA	knots	123	315	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:44:00	\N	1	-00:48:00	\N	0.6	-00:54:00	-00:34:00	Joe's Cut, Wilmington River	GA
110021	Wilmington R., 0.5 mi S of Turners Creek, Wassaw Sound, Georgia Current	NOS	ACT7481_1	32.005	-81.00333	:America/New_York	USA	knots	154	344	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:51:00	\N	0.7	-00:10:00	\N	0.5	-00:31:00	-00:37:00	Wilmington R., 0.5 mi. S of Turners Creek	GA
110022	Thunderbolt, SE of, Wilmington River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7486_1	32.02333	-81.045	:America/New_York	USA	knots	121	298	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	00:25:00	\N	0.5	-01:04:00	\N	0.4	-00:20:00	00:12:00	Thunderbolt, SE of, Wilmington River	GA
110023	Oatland Island, north tip (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7491_1	32.07333	-81.01	:America/New_York	USA	knots	138	317	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-02:32:00	\N	0.5	-02:14:00	\N	0.3	-03:20:00	-00:43:00	Oatland Island, north tip	GA
110024	Skidaway River, north entrance, Wassaw Sound, Georgia Current	NOS	ACT7496_1	32.00833	-81.01667	:America/New_York	USA	knots	16	204	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-02:11:00	\N	0.7	-00:02:00	\N	0.6	-00:46:00	-00:49:00	Skidaway River, north entrance	GA
110025	Skidaway Island, N End, Wilmington River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7501_1	32.01	-81.00833	:America/New_York	USA	knots	119	307	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:49:00	\N	0.9	00:16:00	\N	0.6	-00:33:00	-00:23:00	Skidaway Island, N End, Wilmington River	GA
110026	Dutch Island, SE of, Skidaway River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7506_1	31.99167	-81.02	:America/New_York	USA	knots	61	245	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-02:02:00	\N	0.6	00:16:00	\N	0.5	-00:40:00	-00:33:00	Dutch Island, SE of, Skidaway River	GA
110027	Isle of Hope City, SE of, Skidaway River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7511_1	31.97667	-81.04667	:America/New_York	USA	knots	72	268	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:40:00	\N	0.3	-00:30:00	\N	0.2	-00:17:00	-00:32:00	Isle of Hope City, SE of, Skidaway River	GA
110028	Isle of Hope City, Skidaway River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7516_1	31.98	-81.055	:America/New_York	USA	knots	28	212	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:25:00	\N	0.3	00:00:00	\N	0.4	-00:34:00	-00:19:00	Isle of Hope City, Skidaway River	GA
110029	Burntpot Island, west of, Skidaway River (depth 6 ft), Wassaw Sound, Georgia Current	NOS	ACT7521_1	31.96833	-81.05333	:America/New_York	USA	knots	18	194	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:03:00	\N	0.5	-00:41:00	\N	0.5	-00:27:00	-00:13:00	Burntpot Island, west of, Skidaway River	GA
110030	Skidaway Narrows, Wassaw Sound, Georgia Current	NOS	ACT7526_1	31.95333	-81.065	:America/New_York	USA	knots	42	218	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:24:00	\N	0.5	-00:24:00	\N	0.5	00:03:00	00:26:00	Skidaway Narrows	GA
110031	Long Island, NNE of, Skidaway River (depth 6 ft), Wassaw Sound, Georgia Current	NOS	ACT7531_1	31.95667	-81.06	:America/New_York	USA	knots	47	226	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	00:17:00	\N	0.4	-01:09:00	\N	0.4	-00:13:00	01:02:00	Long Island, NNE of, Skidaway River	GA
110032	Long Island, south of, Skidaway River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7536_1	31.94333	-81.07333	:America/New_York	USA	knots	258	75	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-08:05:00	\N	0.3	-04:43:00	\N	0.2	-04:25:00	-06:07:00	Long Island, south of, Skidaway River	GA
110033	Pigeon Island, SSE of, Skidaway River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7541_1	31.93667	-81.07667	:America/New_York	USA	knots	150	331	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-02:16:00	\N	0.5	-02:43:00	\N	0.2	-02:37:00	-00:56:00	Pigeon Island, SSE of, Skidaway River	GA
110034	Burnside Island, SE of, Burnside River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7546_1	31.92167	-81.08	:America/New_York	USA	knots	295	114	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-02:05:00	\N	0.6	00:53:00	\N	0.4	-00:40:00	-00:20:00	Burnside Island, SE of, Burnside River	GA
110035	Little Don Island, east of, Vernon River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7551_1	31.87	-81.07333	:America/New_York	USA	knots	153	316	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:38:00	\N	0.7	-01:16:00	\N	0.7	-00:17:00	-00:03:00	Little Don Island, east of, Vernon River	GA
110036	Little Ogeechee River entrance (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7556_1	31.88833	-81.09833	:America/New_York	USA	knots	71	259	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:06:00	\N	1	-00:59:00	\N	0.7	-00:15:00	-00:03:00	Little Ogeechee River Entrance	GA
110037	Little Ogeechee River entrance (depth 20 ft), Wassaw Sound, Georgia Current	NOS	ACT7556_2	31.88833	-81.09833	:America/New_York	USA	knots	73	244	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:57:00	\N	0.9	-00:50:00	\N	0.6	-00:30:00	00:05:00	Little Ogeechee River Entrance	GA
110038	Montgomery, Vernon River (depth 6 ft), Wassaw Sound, Georgia Current	NOS	ACT7561_1	31.935	-81.12833	:America/New_York	USA	knots	89	267	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:30:00	\N	0.6	00:00:00	\N	0.3	-00:32:00	-00:24:00	Montgomery, Vernon River	GA
110039	Odingsell River entrance (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7566_1	31.86833	-81	:America/New_York	USA	knots	212	32	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-02:14:00	\N	0.9	00:44:00	\N	0.7	-00:54:00	-00:48:00	Odingsell River Entrance	GA
110040	Odingsell River entrance (depth 20 ft), Wassaw Sound, Georgia Current	NOS	ACT7566_2	31.86833	-81	:America/New_York	USA	knots	210	30	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-02:12:00	\N	0.8	00:42:00	\N	0.6	-01:19:00	-00:42:00	Odingsell River Entrance	GA
110041	Wassaw Island, SSW of (depth 10 ft), Ossabaw Sound, Georgia Current	NOS	ACT7571_1	31.85667	-81.00833	:America/New_York	USA	knots	123	316	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:01:00	\N	1.1	-01:04:00	\N	0.8	-00:26:00	-00:27:00	Wassaw Island, SSW of	GA
110042	Wassaw Island, SSW of (depth 20 ft), Ossabaw Sound, Georgia Current	NOS	ACT7571_2	31.85667	-81.00833	:America/New_York	USA	knots	132	312	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:01:00	\N	0.9	-00:58:00	\N	0.7	-00:46:00	-00:33:00	Wassaw Island, SSW of	GA
110043	Bradley Point, NNE of (depth 10 ft), Ossabaw Sound, Georgia Current	NOS	ACT7576_1	31.83167	-81.03833	:America/New_York	USA	knots	125	302	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:12:00	\N	0.8	-00:58:00	\N	0.6	-00:48:00	-00:48:00	Bradley Point, NNE of	GA
110044	Raccoon Key (depth 10 ft), Ossabaw Sound, Georgia Current	NOS	ACT7581_1	31.86167	-81.055	:America/New_York	USA	knots	117	285	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:35:00	\N	0.9	-01:23:00	\N	0.8	-00:45:00	-00:36:00	Raccoon Key	GA
110045	Little Wassaw Island, SW of (depth 10 ft), Ossabaw Sound, Georgia Current	NOS	ACT7586_1	31.87	-81.05	:America/New_York	USA	knots	116	282	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:51:00	\N	0.7	-00:17:00	\N	0.9	-01:05:00	-00:21:00	Little Wassaw Island, SW of	GA
110046	Vernon R., 1.2 mi S of Possum Point, Ossabaw Sound, Georgia Current	NOS	ACT7591_1	31.89833	-81.09833	:America/New_York	USA	knots	166	324	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:33:00	\N	0.8	00:02:00	\N	0.6	-00:24:00	-00:12:00	Vernon R., 1.2 miles S of Possum Point	GA
110047	Little Ogeechee River entrance, north of (depth 6 ft), Ossabaw Sound, Georgia Current	NOS	ACT7596_1	31.89667	-81.095	:America/New_York	USA	knots	156	324	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-02:03:00	\N	0.8	00:29:00	\N	0.6	-00:41:00	-00:30:00	Little Ogeechee River Entrance, north of	GA
110048	Raccoon Key & Egg Island Shoal, between (depth 10 ft), Ossabaw Sound, Georgia Current	NOS	ACT7601_1	31.84283	-81.0675	:America/New_York	USA	knots	129	254	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:57:00	\N	1	00:17:00	\N	0.8	00:20:00	-00:23:00	Raccoon Key & Egg Island Shoal, between	GA
110049	Florida Passage, N of, Ogeechee River (depth 10 ft), Ossabaw Sound, Georgia Current	NOS	ACT7606_1	31.85667	-81.14333	:America/New_York	USA	knots	127	302	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:05:00	\N	1	00:01:00	\N	0.7	00:10:00	-00:01:00	Florida Passage, N of, Ogeechee River	GA
110050	Florida Passage (south) (depth 6 ft), Ossabaw Sound, Georgia Current	NOS	ACT7611_1	31.82967	-81.15783	:America/New_York	USA	knots	18	187	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:10:00	\N	0.7	-01:13:00	\N	0.5	-01:48:00	-00:23:00	Florida Passage (south)	GA
110051	610 Statute Mile Mark (depth 6 ft), Bear River, St. Catherines Sound, Georgia Current	NOS	ACT7616_1	31.8105	-81.17667	:America/New_York	USA	knots	175	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:39:00	\N	0.7	00:48:00	\N	0.5	00:20:00	-00:05:00	610 Statute Mile Mark	GA
110052	North of Big Tom Creek entrance (depth 10 ft), St. Catherines Sound, Georgia Current	NOS	ACT7621_1	31.78333	-81.16033	:America/New_York	USA	knots	179	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:25:00	\N	0.7	-00:13:00	\N	0.6	-00:24:00	-00:19:00	North of Big Tom Creek Entrance	GA
110053	South of Kilkenny Creek entrance, Bear River, St. Catherines Sound, Georgia Current	NOS	ACT7626_1	31.75833	-81.17333	:America/New_York	USA	knots	190	348	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:12:00	\N	1	01:25:00	\N	0.6	00:26:00	-00:02:00	South of Kilkenny Creek Entrance	GA
110054	Northwest of Newell Creek entrance (depth 10 ft), St. Catherines Sound, Georgia Current	NOS	ACT7631_1	31.74883	-81.1655	:America/New_York	USA	knots	149	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:12:00	\N	0.9	00:12:00	\N	0.6	-00:11:00	-00:16:00	Northwest of Newell Creek Entrance	GA
110055	Medway River at Marsh Island (depth 10 ft), St. Catherines Sound, Georgia Current	NOS	ACT7636_1	31.74333	-81.22	:America/New_York	USA	knots	117	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:56:00	\N	0.8	-00:18:00	\N	0.3	00:20:00	-00:15:00	Medway River at Marsh Island	GA
110056	St. Catherines Sound entrance (depth 10 ft), Georgia Current	NOS	ACT7641_1	31.715	-81.1405	:America/New_York	USA	knots	126	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:27:00	\N	0.8	-00:31:00	\N	0.9	-00:39:00	00:13:00	St. Catherines Sound Entrance	GA
110057	Medway River, northwest of Cedar Point (depth 10 ft), Georgia Current	NOS	ACT7646_1	31.7145	-81.19083	:America/New_York	USA	knots	146	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:21:00	\N	0.8	-00:43:00	\N	0.7	-00:40:00	-00:23:00	Medway River, northwest of Cedar Point	GA
110058	N. Newport River, NE of Vandyke Creek (depth 10 ft), Georgia Current	NOS	ACT7651_1	31.69117	-81.187	:America/New_York	USA	knots	45	233	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:21:00	\N	0.8	00:12:00	\N	0.7	-00:27:00	00:00:00	N. Newport River, NE of Vandyke Creek	GA
110059	N. Newport River, above Walburg Creek (depth 6 ft), St. Catherines Sound, Georgia Current	NOS	ACT7656_1	31.67383	-81.19533	:America/New_York	USA	knots	11	195	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:40:00	\N	0.8	00:30:00	\N	0.6	-00:34:00	-00:39:00	N. Newport River, above Walburg Creek	GA
110060	N. Newport River, NW of Johnson Creek (depth 10 ft), Georgia Current	NOS	ACT7661_1	31.663	-81.2105	:America/New_York	USA	knots	138	312	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:27:00	\N	0.9	-01:01:00	\N	0.5	00:20:00	-00:37:00	N. Newport River, NW of Johnson Creek	GA
110061	N. Newport River, ESE of S. Newport Cut (depth 6 ft), Georgia Current	NOS	ACT7666_1	31.66533	-81.2645	:America/New_York	USA	knots	147	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	00:15:00	\N	0.7	-00:13:00	\N	0.5	00:32:00	00:27:00	N. Newport River, ESE of S. Newport Cut	GA
110062	S. Newport River, below S. Newport Cut (depth 10 ft), Georgia Current	NOS	ACT7671_1	31.65033	-81.302	:America/New_York	USA	knots	134	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	02:15:00	\N	0.5	01:30:00	\N	0.5	01:20:00	02:41:00	S. Newport River, below S. Newport Cut	GA
110063	S. Newport River, above Swain River ent. (depth 10 ft), Georgia Current	NOS	ACT7676_1	31.6245	-81.21667	:America/New_York	USA	knots	156	335	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:43:00	\N	0.6	-01:13:00	\N	0.6	-00:22:00	00:00:00	S. Newport River, above Swain River Ent	GA
110064	Entrance (depth 19 ft), Sapelo Sound, Georgia Current	NOS	ACT7681_1	31.54	-81.18	:America/New_York	USA	knots	118	290	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:59:00	\N	1.1	00:28:00	\N	0.9	-00:30:00	-00:06:00	Entrance	GA
110065	Entrance (depth 29 ft), Sapelo Sound, Georgia Current	NOS	ACT7681_2	31.54	-81.18	:America/New_York	USA	knots	116	289	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:02:00	\N	0.9	-00:36:00	\N	0.7	-00:48:00	-00:17:00	Entrance	GA
110066	Johnson Creek, midway between ends, Sapelo Sound, Georgia Current	NOS	ACT7686_1	31.62667	-81.18833	:America/New_York	USA	knots	195	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:59:00	\N	0.4	-01:08:00	\N	0.4	-01:50:00	-00:35:00	Johnson Creek, midway between ends	GA
110067	Cedar Hammock, south of (depth 12 ft), Sapelo Sound, Georgia Current	NOS	ACT7691_1	31.545	-81.24667	:America/New_York	USA	knots	96	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:38:00	\N	0.6	-01:00:00	\N	0.7	-00:26:00	-00:12:00	Cedar Hammock, south of	GA
110068	Sapelo River entrance (depth 11 ft), Sapelo Sound, Georgia Current	NOS	ACT7696_1	31.535	-81.27167	:America/New_York	USA	knots	58	234	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:43:00	\N	0.6	-01:05:00	\N	0.6	-00:23:00	-00:13:00	Sapelo River Entrance	GA
110069	Sutherland Bluff, Sapelo River, Sapelo Sound, Georgia Current	NOS	ACT7701_1	31.54833	-81.33333	:America/New_York	USA	knots	104	281	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:16:00	\N	0.6	00:10:00	\N	0.5	-00:30:00	-00:12:00	Sutherland Bluff, Sapelo River	GA
110070	Front River (depth 13 ft), Sapelo Sound, Georgia Current	NOS	ACT7706_1	31.51333	-81.29833	:America/New_York	USA	knots	56	227	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-02:05:00	\N	0.5	01:16:00	\N	0.4	-00:33:00	-00:25:00	Front River	GA
110071	New Teakettle Cr., 0.8 mi N of, Mud River, Sapelo Sound, Georgia Current	NOS	ACT7711_1	31.49667	-81.29	:America/New_York	USA	knots	53	236	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-02:11:00	\N	0.5	-00:29:00	\N	0.4	-00:54:00	-01:08:00	New Teakettle Cr., 0.8 mi. N of	GA
110072	Crescent River (depth 11 ft), Sapelo Sound, Georgia Current	NOS	ACT7716_1	31.48667	-81.30667	:America/New_York	USA	knots	133	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:21:00	\N	0.5	01:07:00	\N	0.2	-01:27:00	-00:34:00	Crescent River	GA
110073	Old Teakettle Creek (north) (depth 13 ft), Sapelo Sound, Georgia Current	NOS	ACT7721_1	31.47833	-81.32833	:America/New_York	USA	knots	256	78	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:37:00	\N	0.6	00:01:00	\N	0.5	-00:35:00	00:14:00	Old Teakettle Creek (north)	GA
110074	Bar, Doboy Sound, Georgia Current	NOS	ACT7726_1	31.345	-81.235	:America/New_York	USA	knots	114	312	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:53:00	\N	0.7	-00:29:00	\N	0.7	-00:29:00	-00:09:00	Bar	GA
110075	Entrance (depth 14 ft), Doboy Sound, Georgia Current	NOS	ACT7731_1	31.34167	-81.26333	:America/New_York	USA	knots	106	289	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:49:00	\N	0.9	-00:10:00	\N	0.8	-00:32:00	-00:24:00	Entrance	GA
110076	Entrance (depth 22 ft), Doboy Sound, Georgia Current	NOS	ACT7731_2	31.34167	-81.26333	:America/New_York	USA	knots	99	276	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:26:00	\N	0.8	-00:05:00	\N	0.8	-00:56:00	-00:20:00	Entrance	GA
110077	Old Teakettle Creek entrance, south of (depth 15 ft), Doboy Sound, Georgia Current	NOS	ACT7736_1	31.42	-81.315	:America/New_York	USA	knots	159	335	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:27:00	\N	0.5	-00:59:00	\N	0.5	-00:45:00	00:00:00	Old Teakettle Creek Entrance, south of	GA
110078	Old Teakettle Creek (south) (depth 13 ft), Doboy Sound, Georgia Current	NOS	ACT7741_1	31.43667	-81.30833	:America/New_York	USA	knots	207	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-02:44:00	\N	0.4	-01:45:00	\N	0.5	-03:12:00	-02:16:00	Old Teakettle Creek (south)	GA
110079	Folly River and Cardigan River, between (depth 10 ft), Doboy Sound, Georgia Current	NOS	ACT7746_1	31.44167	-81.33667	:America/New_York	USA	knots	150	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:00:00	\N	0.3	-00:56:00	\N	0.3	-00:55:00	-00:16:00	Folly River and Cardigan River, between	GA
110080	South River (depth 13 ft), Doboy Sound, Georgia Current	NOS	ACT7751_1	31.36667	-81.31167	:America/New_York	USA	knots	95	282	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:24:00	\N	0.7	-00:25:00	\N	0.6	-00:22:00	-00:32:00	South River	GA
110081	South River (depth 21 ft), Doboy Sound, Georgia Current	NOS	ACT7751_2	31.36667	-81.31167	:America/New_York	USA	knots	95	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:24:00	\N	0.4	-00:33:00	\N	0.5	-00:41:00	-00:29:00	South River	GA
110082	North River at Darien River (depth 9 ft), Doboy Sound, Georgia Current	NOS	ACT7756_1	31.38333	-81.335	:America/New_York	USA	knots	29	247	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	00:22:00	\N	0.2	-00:33:00	\N	0.2	-00:10:00	00:08:00	North River at Darien River	GA
110083	Doboy Island (North River) (depth 12 ft), Doboy Sound, Georgia Current	NOS	ACT7761_1	31.40333	-81.32833	:America/New_York	USA	knots	37	224	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	00:13:00	\N	0.5	-00:06:00	\N	0.6	-00:14:00	00:47:00	Doboy Island (North River)	GA
110084	Doboy Island (North River) (depth 20 ft), Doboy Sound, Georgia Current	NOS	ACT7761_2	31.40333	-81.32833	:America/New_York	USA	knots	43	225	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	00:22:00	\N	0.3	00:36:00	\N	0.5	-00:20:00	00:46:00	Doboy Island (North River)	GA
110085	Buzzard Roost Creek (depth 13 ft), Doboy Sound, Georgia Current	NOS	ACT7766_1	31.415	-81.375	:America/New_York	USA	knots	2	177	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	00:28:00	\N	0.2	00:12:00	\N	0.3	00:22:00	00:56:00	Buzzard Roost Creek	GA
110086	Little Egg Island, northwest of (depth 12 ft), Altamaha Sound, Georgia Current	NOS	ACT7771_1	31.31833	-81.305	:America/New_York	USA	knots	110	296	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:10:00	\N	0.6	-00:53:00	\N	0.6	-00:33:00	-00:25:00	Little Egg Island, northwest of	GA
110087	Little Mud River Range (depth 9 ft), Altamaha Sound, Georgia Current	NOS	ACT7776_1	31.32667	-81.31833	:America/New_York	USA	knots	116	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:06:00	\N	0.5	-01:05:00	\N	0.3	-00:38:00	-00:23:00	Little Mud River Range	GA
110088	Little St. Simon Island (north) (depth 11 ft), Altamaha Sound, Georgia Current	NOS	ACT7781_1	31.31167	-81.35333	:America/New_York	USA	knots	89	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:29:00	\N	0.8	00:06:00	\N	0.6	00:10:00	-00:15:00	Little St. Simon Island (north)	GA
110089	Onemile Cut, 1 mi southeast of, Altamaha Sound, Georgia Current	NOS	ACT7786_1	31.31333	-81.35167	:America/New_York	USA	knots	92	272	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:32:00	\N	0.9	00:03:00	\N	0.5	00:46:00	-01:09:00	Onemile Cut, 1 mile southeast of	GA
110090	Broughton Island (south) (depth 9 ft), Buttermilk Sound, Altamaha Sound, Georgia Current	NOS	ACT7791_1	31.31	-81.41333	:America/New_York	USA	knots	30	222	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:51:00	\N	0.4	00:12:00	\N	0.4	-02:06:00	-00:01:00	Broughton Island (south)	GA
110091	Bar Channel (depth 12 ft), St. Simons Sound, Georgia Current	NOS	ACT7796_1	31.105	-81.33833	:America/New_York	USA	knots	119	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:02:00	\N	0.8	-00:44:00	\N	0.4	-00:13:00	00:09:00	Bar Channel	GA
110092	Entrance, north of channel (depth 13 ft), St. Simons Sound, Georgia Current	NOS	ACT7801_1	31.1335	-81.404	:America/New_York	USA	knots	107	290	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:11:00	\N	0.6	00:18:00	\N	0.9	-00:32:00	00:07:00	Entrance, north of channel	GA
110093	Entrance, south of channel (depth 11 ft), St. Simons Sound, Georgia Current	NOS	ACT7806_1	31.12667	-81.40333	:America/New_York	USA	knots	80	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:59:00	\N	1.1	-00:32:00	\N	0.8	-00:27:00	-00:21:00	Entrance, south of channel	GA
110094	Entrance, south of channel (depth 29 ft), St. Simons Sound, Georgia Current	NOS	ACT7806_2	31.12667	-81.40333	:America/New_York	USA	knots	92	257	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:21:00	\N	0.8	-00:03:00	\N	0.6	-00:18:00	00:06:00	Entrance, south of channel	GA
110095	Back River entrance (depth 10 ft), St. Simons Sound, Georgia Current	NOS	ACT7811_1	31.14833	-81.44167	:America/New_York	USA	knots	111	288	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:16:00	\N	0.5	01:34:00	\N	0.5	-00:37:00	00:06:00	Back River entrance	GA
110096	Back River entrance (depth 18 ft), St. Simons Sound, Georgia Current	NOS	ACT7811_2	31.14833	-81.44167	:America/New_York	USA	knots	109	280	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:15:00	\N	0.4	01:36:00	\N	0.5	-01:29:00	00:08:00	Back River entrance	GA
110097	Mackay R., 0.5 mi N of Troup Creek entrance, St. Simons Sound, Georgia Current	NOS	ACT7816_1	31.225	-81.43333	:America/New_York	USA	knots	166	348	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	00:24:00	\N	0.7	00:09:00	\N	0.5	00:56:00	00:35:00	Mackay R., 0.5 mi. N of Troup Creek entrance	GA
110098	Brunswick River, off Quarantine Dock, St. Simons Sound, Georgia Current	NOS	ACT7821_1	31.11167	-81.47333	:America/New_York	USA	knots	125	300	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:39:00	\N	1	-00:03:00	\N	0.7	00:10:00	00:11:00	Brunswick River, off Quarantine Dock	GA
110099	Brunswick River Bridge, southeast of (depth 13 ft), St. Simons Sound, Georgia Current	NOS	ACT7826_1	31.115	-81.47667	:America/New_York	USA	knots	132	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:09:00	\N	0.7	00:13:00	\N	0.5	-00:15:00	00:26:00	Brunswick River Bridge, southeast of	GA
110100	Brunswick River Bridge, southeast of (depth 21 ft), St. Simons Sound, Georgia Current	NOS	ACT7826_2	31.115	-81.47667	:America/New_York	USA	knots	129	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:02:00	\N	0.7	00:42:00	\N	0.5	00:19:00	00:56:00	Brunswick River Bridge, southeast of	GA
110101	Brunswick, off Prince Street Dock, St. Simons Sound, Georgia Current	NOS	ACT7831_1	31.13833	-81.49667	:America/New_York	USA	knots	166	342	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:08:00	\N	0.6	00:55:00	\N	0.5	-00:01:00	00:06:00	Brunswick, off Prince Street Dock	GA
110102	Turtle River, off Allied Chemical Corp, St. Simons Sound, Georgia Current	NOS	ACT7836_1	31.17667	-81.525	:America/New_York	USA	knots	165	348	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:33:00	\N	0.8	00:18:00	\N	0.7	00:16:00	00:36:00	Turtle River, off Allied Chemical Corp	GA
110103	Turtle River, off Andrews Island (depth 20 ft), St. Simons Sound, Georgia Current	NOS	ACT7841_1	31.14333	-81.52667	:America/New_York	USA	knots	153	339	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:23:00	\N	0.7	00:40:00	\N	0.5	-00:21:00	00:31:00	Turtle River, off Andrews Island	GA
110104	Entrance, St. Andrews Sound, Georgia Current	NOS	ACT7846_1	30.98667	-81.405	:America/New_York	USA	knots	103	268	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:00:00	\N	1.1	00:13:00	\N	1.1	-00:18:00	00:02:00	Entrance	GA
110105	Jekyll Creek, south entrance, St. Andrews Sound, Georgia Current	NOS	ACT7851_1	31.035	-81.43333	:America/New_York	USA	knots	232	60	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:20:00	\N	0.7	-00:21:00	\N	0.5	-00:21:00	-00:25:00	Jekyll Creek, south entrance	GA
110106	Cumberland River, north entrance, St. Andrews Sound, Georgia Current	NOS	ACT7856_1	30.95833	-81.43167	:America/New_York	USA	knots	18	191	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-01:18:00	\N	0.7	00:32:00	\N	0.7	-00:29:00	-00:17:00	Cumberland River, north entrance	GA
110107	Cabin Bluff, Cumberland River, St. Andrews Sound, Georgia Current	NOS	ACT7861_1	30.88167	-81.51333	:America/New_York	USA	knots	355	171	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106035	-00:45:00	\N	0.6	01:29:00	\N	0.7	00:21:00	00:51:00	Cabin Bluff, Cumberland River	GA
110108	Fort Clinch, 1.1 nmi NW of (depth 14 ft), Cumberland Sound, Florida Current	NOS	ACT7886_1	30.709	-81.47267	:America/New_York	USA	knots	133	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106554	00:18:00	\N	0.7	-00:01:00	\N	0.6	00:01:00	00:10:00	Fort Clinch, 1.1 n.mi. NW of	FL
110109	Fort Clinch, 1.1 nmi NW of (depth 29 ft), Cumberland Sound, Florida Current	NOS	ACT7886_2	30.709	-81.47267	:America/New_York	USA	knots	122	315	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106554	00:08:00	\N	0.5	00:02:00	\N	0.5	-00:13:00	00:02:00	Fort Clinch, 1.1 n.mi. NW of	FL
110110	Drum Point Island, Range D Channel (depth 12 ft), Cumberland Sound, Georgia Current	NOS	ACT7896_1	30.759	-81.48533	:America/New_York	USA	knots	170	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106554	-00:03:00	\N	0.6	-00:11:00	\N	0.5	-00:05:00	00:02:00	Drum Point Island, Range D Channel	GA
110111	Drum Point Island, Range D Channel (depth 22 ft), Cumberland Sound, Georgia Current	NOS	ACT7896_2	30.759	-81.48533	:America/New_York	USA	knots	170	351	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106554	-00:09:00	\N	0.5	-00:34:00	\N	0.4	-00:10:00	-00:08:00	Drum Point Island, Range D Channel	GA
110112	Stafford Island, west of, Cumberland Sound, Georgia Current	NOS	ACT7906_1	30.81	-81.49167	:America/New_York	USA	knots	180	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106554	-01:01:00	\N	0.5	-00:28:00	\N	0.6	-00:25:00	-00:27:00	Stafford Island, west of	GA
110113	Kingsley Creek, highway bridge, Cumberland Sound, Florida Current	NOS	ACT7921_1	30.62833	-81.485	:America/New_York	USA	knots	330	150	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106554	01:25:00	\N	0.6	01:17:00	\N	0.5	01:45:00	00:53:00	Kingsley Creek, highway bridge	FL
110114	Midsound, 1 mi N of Sawpit Creek entrance, Nassau Sound, Florida Current	NOS	ACT7926_1	30.52333	-81.45167	:America/New_York	USA	knots	135	312	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106965	-00:21:00	\N	0.7	-00:12:00	\N	0.8	00:02:00	-00:15:00	Midsound, 1 mi. N of Sawpit Creek entrance	FL
110115	South Amelia River, off Walker Creek, Nassau Sound, Florida Current	NOS	ACT7931_1	30.53667	-81.465	:America/New_York	USA	knots	162	341	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106965	-01:57:00	\N	0.6	-00:09:00	\N	0.6	-01:08:00	-00:40:00	South Amelia River, off Walker Creek	FL
110116	Nassau River, SW of Mesa Marsh, Nassau Sound, Florida Current	NOS	ACT7936_1	30.53333	-81.48	:America/New_York	USA	knots	129	294	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106965	-00:13:00	\N	0.7	-00:09:00	\N	0.7	00:09:00	-00:01:00	Nassau River, SW of Mesa Marsh	FL
110117	Ft. George River, Nassau Sound, Florida Current	NOS	ACT7941_1	30.45667	-81.45167	:America/New_York	USA	knots	162	334	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106965	-02:20:00	\N	0.4	-01:08:00	\N	0.1	-01:35:00	-01:26:00	Ft. George River	FL
110118	Mayport (depth 7 ft), St. Johns River, Florida Current	NOS	ACT7971_1	30.39333	-81.43333	:America/New_York	USA	knots	26	211	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	-00:04:00	\N	1.6	01:02:00	\N	1.1	00:06:00	00:15:00	Mayport	FL
110119	Mayport (depth 17 ft), St. Johns River, Florida Current	NOS	ACT7971_2	30.39333	-81.43333	:America/New_York	USA	knots	26	211	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	00:05:00	\N	1.3	00:38:00	\N	1.1	-00:03:00	00:12:00	Mayport	FL
110120	Mayport (depth 27 ft), St. Johns River, Florida Current	NOS	ACT7971_3	30.39333	-81.43333	:America/New_York	USA	knots	26	211	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	00:14:00	\N	0.9	00:26:00	\N	0.9	-00:27:00	00:15:00	Mayport	FL
110121	Pablo Creek bascule bridge (depth 3 ft), St. Johns River, Florida Current	NOS	ACT7986_1	30.32333	-81.43833	:America/New_York	USA	knots	0	180	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	00:59:00	\N	2.5	-00:18:00	\N	1.7	-00:14:00	00:49:00	Pablo Creek bascule bridge	FL
110122	Sisters Creek entrance (bridge) (depth 4 ft), St. Johns River, Florida Current	NOS	ACT7991_1	30.39	-81.46167	:America/New_York	USA	knots	180	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	-02:34:00	\N	0.8	-03:14:00	\N	0.8	-03:30:00	-02:13:00	Sisters Creek entrance (bridge)	FL
110123	Sisters Creek entrance (bridge) (depth 10 ft), St. Johns River, Florida Current	NOS	ACT7991_2	30.39	-81.46167	:America/New_York	USA	knots	180	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	-02:34:00	\N	0.6	-03:04:00	\N	0.6	-03:36:00	-02:07:00	Sisters Creek entrance (bridge)	FL
110124	Drummond Point, channel south of (depth 7 ft), St. Johns River, Florida Current	NOS	ACT8016_1	30.40917	-81.60283	:America/New_York	USA	knots	60	241	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	03:00:00	\N	0.8	02:32:00	\N	0.7	01:51:00	02:44:00	Drummond Point, channel south of	FL
110125	Drummond Point, channel south of (depth 17 ft), St. Johns River, Florida Current	NOS	ACT8016_2	30.40917	-81.60283	:America/New_York	USA	knots	61	222	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	03:01:00	\N	0.7	02:35:00	\N	0.7	01:34:00	02:51:00	Drummond Point, channel south of	FL
110126	Drummond Point, channel south of (depth 27 ft), St. Johns River, Florida Current	NOS	ACT8016_3	30.40917	-81.60283	:America/New_York	USA	knots	57	243	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	02:51:00	\N	0.5	02:20:00	\N	0.6	01:21:00	02:46:00	Drummond Point, channel south of	FL
110127	Terminal Channel (north end) (depth 7 ft), St. Johns River, Florida Current	NOS	ACT8031_1	30.357	-81.618	:America/New_York	USA	knots	1	225	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	03:38:00	\N	0.6	03:16:00	\N	0.5	02:39:00	03:02:00	Terminal Channel (north end)	FL
110128	Terminal Channel (north end) (depth 17 ft), St. Johns River, Florida Current	NOS	ACT8031_2	30.357	-81.618	:America/New_York	USA	knots	1	183	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	03:33:00	\N	0.5	03:06:00	\N	0.6	02:16:00	03:20:00	Terminal Channel (north end)	FL
110129	Terminal Channel (north end) (depth 27 ft), St. Johns River, Florida Current	NOS	ACT8031_3	30.357	-81.618	:America/New_York	USA	knots	1	185	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	03:23:00	\N	0.3	03:28:00	\N	0.5	01:51:00	03:16:00	Terminal Channel (north end)	FL
110130	Commodore Point, terminal channel (depth 7 ft), St. Johns River, Florida Current	NOS	ACT8036_1	30.3175	-81.62633	:America/New_York	USA	knots	72	197	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	03:37:00	\N	0.5	03:28:00	\N	0.5	02:39:00	03:10:00	Commodore Point, terminal channel	FL
110131	Commodore Point, terminal channel (depth 17 ft), St. Johns River, Florida Current	NOS	ACT8036_2	30.3175	-81.62633	:America/New_York	USA	knots	51	221	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	03:25:00	\N	0.4	03:13:00	\N	0.5	02:12:00	03:23:00	Commodore Point, terminal channel	FL
110132	Commodore Point, terminal channel (depth 27 ft), St. Johns River, Florida Current	NOS	ACT8036_3	30.3175	-81.62633	:America/New_York	USA	knots	35	221	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	03:08:00	\N	0.4	02:30:00	\N	0.6	01:43:00	03:38:00	Commodore Point, terminal channel	FL
110133	Jacksonville, off Washington St, St. Johns River, Florida Current	NOS	ACT8041_1	30.32167	-81.65333	:America/New_York	USA	knots	118	281	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	03:23:00	\N	0.9	03:10:00	\N	0.9	02:59:00	02:54:00	Jacksonville, off Washington St	FL
110134	Winter Point, St. Johns River, Florida Current	NOS	ACT8051_1	30.30833	-81.675	:America/New_York	USA	knots	15	200	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	03:59:00	\N	0.5	03:22:00	\N	0.6	02:59:00	04:04:00	Winter Point	FL
110135	Mandarin Point (depth 6 ft), St. Johns River, Florida Current	NOS	ACT8056_1	30.155	-81.685	:America/New_York	USA	knots	13	179	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	03:38:00	\N	0.4	03:39:00	\N	0.3	03:07:00	03:24:00	Mandarin Point	FL
110136	Mandarin Point (depth 15 ft), St. Johns River, Florida Current	NOS	ACT8056_2	30.155	-81.685	:America/New_York	USA	knots	13	179	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	03:38:00	\N	0.3	03:33:00	\N	0.3	03:13:00	03:24:00	Mandarin Point	FL
110137	Mandarin Point (depth 24 ft), St. Johns River, Florida Current	NOS	ACT8056_3	30.155	-81.685	:America/New_York	USA	knots	13	179	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	03:32:00	\N	0.3	03:33:00	\N	0.3	02:48:00	03:24:00	Mandarin Point	FL
110138	Red Bay Point, draw bridge (depth 4 ft), St. Johns River, Florida Current	NOS	ACT8061_1	29.985	-81.63	:America/New_York	USA	knots	300	115	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	04:02:00	\N	0.3	03:57:00	\N	0.5	02:48:00	05:24:00	Red Bay Point, draw bridge	FL
110139	Red Bay Point, draw bridge (depth 6 ft), St. Johns River, Florida Current	NOS	ACT8061_2	29.985	-81.63	:America/New_York	USA	knots	300	115	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	04:08:00	\N	0.3	03:57:00	\N	0.5	02:42:00	05:18:00	Red Bay Point, draw bridge	FL
110140	Red Bay Point, draw bridge (depth 14 ft), St. Johns River, Florida Current	NOS	ACT8061_3	29.985	-81.63	:America/New_York	USA	knots	300	115	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108532	04:08:00	\N	0.2	03:57:00	\N	0.4	02:48:00	05:30:00	Red Bay Point, draw bridge	FL
110141	Fort Lauderdale, New River, Port Everglades, Florida Current	NOS	ACT8126_1	26.11217	-80.11967	:America/New_York	USA	knots	130	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106965	00:52:00	\N	0.8	-00:01:00	\N	1.4	-00:14:00	00:28:00	Fort Lauderdale, New River	FL
110142	Bakers Haulover Cut, Miami Harbor, Florida Current	NOS	ACT8141_1	25.9	-80.12333	:America/New_York	USA	knots	90	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106965	-00:08:00	\N	1	00:19:00	\N	1.3	00:00:00	00:13:00	Bakers Haulover Cut	FL
110143	Caesar Creek, Biscayne Bay, Florida Current	NOS	ACT8216_1	25.38667	-80.22667	:America/New_York	USA	knots	123	316	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106568	-00:23:00	\N	1	00:03:00	\N	0.9	00:09:00	-00:21:00	Caesar Creek, Biscayne Bay	FL
110144	Long Key, drawbridge east of, Florida Current	NOS	ACT8221_1	24.84	-80.77	:America/New_York	USA	knots	202	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106568	01:15:00	\N	0.7	01:38:00	\N	0.8	01:00:00	02:14:00	Long Key, drawbridge east of	FL
110145	Long Key Viaduct, Florida Current	NOS	ACT8226_1	24.80167	-80.865	:America/New_York	USA	knots	170	349	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106568	01:39:00	\N	0.7	01:39:00	\N	0.7	01:36:00	01:55:00	Long Key Viaduct	FL
110146	No Name Key, northeast of, Florida Current	NOS	ACT8241_1	24.705	-81.31333	:America/New_York	USA	knots	142	312	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106568	00:35:00	\N	0.5	01:35:00	\N	0.5	00:57:00	01:13:00	No Name Key, northeast of	FL
110147	Ft. Taylor, 0.6 mi N of, Key West, Florida Current	NOS	ACT8261_1	24.55833	-81.81	:America/New_York	USA	knots	202	42	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106568	-00:05:00	\N	0.7	00:24:00	\N	0.4	00:22:00	-00:18:00	Ft. Taylor, 0.6 mile N of	FL
110148	Isaac Shoal, Florida Current	NOS	ACT8291_1	24.55833	-82.53667	:America/New_York	USA	knots	181	2	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106568	01:37:00	\N	0.5	01:05:00	\N	0.8	01:02:00	01:45:00	Isaac Shoal	FL
110149	Southeast Channel, Florida Current	NOS	ACT8296_1	24.627	-82.85117	:America/New_York	USA	knots	172	4	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106568	00:18:00	\N	0.4	00:05:00	\N	0.5	-00:25:00	00:30:00	Southeast Channel	FL
110150	Southwest Channel, Florida Current	NOS	ACT8301_1	24.61533	-82.91167	:America/New_York	USA	knots	209	1	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106568	01:46:00	\N	0.3	01:10:00	\N	0.3	00:47:00	01:18:00	Southwest Channel	FL
110151	Point Ybel, 0.4 mi northwest of, Florida Current	NOS	ACT8306_1	26.45667	-82.01867	:America/New_York	USA	knots	80	255	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	00:35:00	\N	0.7	-00:52:00	\N	0.8	-00:25:00	00:17:00	Point Ybel, 0.4 mile northwest of	FL
110152	Captiva Pass, Florida Current	NOS	ACT8311_1	26.60933	-82.22233	:America/New_York	USA	knots	251	67	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:23:00	\N	0.9	-01:29:00	\N	1.4	-00:53:00	-01:14:00	Captiva Pass	FL
110153	Boca Grande Pass, Charlotte Harbor, Florida Current	NOS	ACT8316_1	26.71433	-82.25667	:America/New_York	USA	knots	251	57	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	00:05:00	\N	1.3	-00:37:00	\N	1.7	-00:15:00	-00:15:00	Boca Grande Pass, Charlotte Harbor	FL
110154	Cape Haze, 2.3 mi S of, Charlotte Hbr, Florida Current	NOS	ACT8331_1	26.745	-82.15167	:America/New_York	USA	knots	268	80	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	01:18:00	\N	0.4	00:41:00	\N	0.4	00:30:00	-00:20:00	Cape Haze, 2.3 mi. S of, Charlotte Hbr	FL
110155	Gasparilla Pass, Florida Current	NOS	ACT8346_1	26.81233	-82.281	:America/New_York	USA	knots	236	66	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:41:00	\N	0.8	-01:13:00	\N	0.8	-01:15:00	-00:35:00	Gasparilla Pass	FL
110156	Venice Inlet, Florida Current	NOS	ACT8351_1	27.11333	-82.46667	:America/New_York	USA	knots	262	87	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-01:59:00	\N	0.7	-02:08:00	\N	0.8	-02:05:00	-01:57:00	Venice Inlet	FL
110157	Blackburn Bay, south end, bridge, Florida Current	NOS	ACT8356_1	27.12333	-82.47	:America/New_York	USA	knots	180	357	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:10:00	\N	0.5	-01:20:00	\N	0.7	-00:55:00	-01:28:00	Blackburn Bay, south end, bridge	FL
110158	Little Sarasota Bay, south end, bridge, Florida Current	NOS	ACT8361_1	27.18	-82.495	:America/New_York	USA	knots	357	167	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:06:00	\N	0.5	-00:56:00	\N	1.1	-01:19:00	-00:57:00	Little Sarasota Bay, south end, bridge	FL
110159	Big Sarasota Pass, Sarasota Bay, Florida Current	NOS	ACT8371_1	27.3	-82.56333	:America/New_York	USA	knots	183	6	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-02:03:00	\N	0.8	-01:49:00	\N	1.2	-01:54:00	-01:34:00	Big Sarasota Pass	FL
110160	Sarasota Bay, south end, bridge, Florida Current	NOS	ACT8376_1	27.30167	-82.54667	:America/New_York	USA	knots	13	196	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:32:00	\N	0.2	-01:39:00	\N	0.2	-01:25:00	-01:13:00	Sarasota Bay, south end, bridge	FL
110161	New Pass, Sarasota Bay, Florida Current	NOS	ACT8381_1	27.33167	-82.58167	:America/New_York	USA	knots	231	46	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-01:25:00	\N	0.8	-02:48:00	\N	1.2	-02:06:00	-01:18:00	New Pass	FL
110162	Golden Gate Point, off, Sarasota Bay, Florida Current	NOS	ACT8386_1	27.32833	-82.55667	:America/New_York	USA	knots	159	344	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-01:19:00	\N	0.2	-01:57:00	\N	0.3	-01:38:00	-01:25:00	Golden Gate Point, off	FL
110163	Longboat Pass, Sarasota Bay, Florida Current	NOS	ACT8391_1	27.44167	-82.69	:America/New_York	USA	knots	267	88	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-01:56:00	\N	1.2	-02:42:00	\N	1.4	-02:32:00	-01:51:00	Longboat Pass	FL
110164	Cortez, north of bridge, Sarasota Bay, Florida Current	NOS	ACT8396_1	27.47	-82.69333	:America/New_York	USA	knots	162	346	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-01:11:00	\N	0.1	-01:10:00	\N	0.5	-01:47:00	-00:25:00	Cortez, north of bridge	FL
110165	Egmont Channel, Marker 10 (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8401_1	27.6005	-82.86767	:America/New_York	USA	knots	259	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-01:31:00	\N	0.2	-03:17:00	\N	0.2	-02:04:00	-02:22:00	Egmont Channel, marker '10'	FL
110166	Egmont Channel (3 mi W of Egmont Key Lt.), Tampa Bay, Florida Current	NOS	ACT8406_1	27.60833	-82.81833	:America/New_York	USA	knots	260	65	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:29:00	\N	0.5	-00:28:00	\N	0.4	-00:30:00	-00:30:00	Egmont Channel (3 mi. W of Egmont Key Lt.)	FL
110167	Southwest Channel (S of Egmont Key) (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8416_1	27.56167	-82.76733	:America/New_York	USA	knots	269	87	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:30:00	\N	0.9	-00:53:00	\N	0.6	-00:46:00	-00:40:00	Southwest Channel (S of Egmont Key)	FL
110168	Mullet Key Channel entrance, Tampa Bay, Florida Current	NOS	ACT8421_1	27.6045	-82.72383	:America/New_York	USA	knots	255	55	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	00:08:00	\N	0.8	-00:01:00	\N	0.8	-00:03:00	-00:23:00	Mullet Key Channel entrance	FL
110169	Passage Key Inlet (off Bean Pt.) (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8426_1	27.53933	-82.74767	:America/New_York	USA	knots	247	81	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-01:08:00	\N	0.7	-01:50:00	\N	0.6	-01:29:00	-01:13:00	Passage Key Inlet (off Bean Pt.)	FL
110170	Rattlesnake Key, 3.1 mi west of, Tampa Bay, Florida Current	NOS	ACT8431_1	27.55333	-82.68833	:America/New_York	USA	knots	250	65	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	00:04:00	\N	0.4	-00:05:00	\N	0.3	00:20:00	-00:51:00	Rattlesnake Key, 3.1 miles west of	FL
110171	Rattlesnake Key, 1.1 mi northwest of, Tampa Bay, Florida Current	NOS	ACT8436_1	27.57083	-82.64383	:America/New_York	USA	knots	210	35	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:09:00	\N	0.1	-00:34:00	\N	0.2	-00:28:00	-00:34:00	Rattlesnake Key, 1.1 miles northwest of	FL
110172	Mullet Key Channel, Marker 24 (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8441_1	27.60833	-82.694	:America/New_York	USA	knots	255	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:06:00	\N	0.7	-00:07:00	\N	0.7	-00:14:00	-00:06:00	Mullet Key Channel, marker '24'	FL
110173	Bunces Pass (west of Bayway bridge), Tampa Bay, Florida Current	NOS	ACT8446_1	27.647	-82.7395	:America/New_York	USA	knots	315	125	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-01:02:00	\N	0.7	-00:46:00	\N	0.8	-00:47:00	-01:07:00	Bunces Pass (West of Bayway bridge)	FL
110174	Pine Key (Pinellas Bayway bridge), Tampa Bay, Florida Current	NOS	ACT8451_1	27.6925	-82.71717	:America/New_York	USA	knots	280	100	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-01:00:00	\N	0.6	-00:29:00	\N	0.3	-00:32:00	-01:07:00	Pine Key (Pinellas Bayway bridge)	FL
110175	Cats Point (bridge west of), Tampa Bay, Florida Current	NOS	ACT8456_1	27.70833	-82.72467	:America/New_York	USA	knots	150	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-01:23:00	\N	0.5	-02:41:00	\N	0.5	-01:27:00	-02:12:00	Cats Point (bridge west of)	FL
110176	Cut A & B, Channel Junction, Tampa Bay, Florida Current	NOS	ACT8466_1	27.63883	-82.6255	:America/New_York	USA	knots	225	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	00:46:00	\N	0.7	00:07:00	\N	0.8	00:25:00	00:23:00	Cut A & B, Channel Junction	FL
110177	Joe Island, 1.8 mi northwest of, Tampa Bay, Florida Current	NOS	ACT8471_1	27.6125	-82.625	:America/New_York	USA	knots	245	70	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:02:00	\N	0.7	-00:07:00	\N	0.5	00:03:00	-00:24:00	Joe Island, 1.8 miles northwest of	FL
110178	Harbor Key, 1.3 mi west of, Tampa Bay, Florida Current	NOS	ACT8476_1	27.61117	-82.5945	:America/New_York	USA	knots	160	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:38:00	\N	0.3	-00:56:00	\N	0.2	-00:50:00	-01:06:00	Harbor Key, 1.3 miles west of	FL
110179	Pinellas Point, 2.6 mi south of, Tampa Bay, Florida Current	NOS	ACT8486_1	27.660499572753906	-82.6417007446289	:America/New_York	USA	knots	210	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:34:00	\N	0.7	-00:23:00	\N	0.6	-00:46:00	-00:16:00	Pinellas Point, 2.6 miles south of	FL
110180	Pinellas Point, 0.5 mi southeast of, Tampa Bay, Florida Current	NOS	ACT8491_1	27.69700050354004	-82.63249969482422	:America/New_York	USA	knots	220	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:57:00	\N	0.2	-01:19:00	\N	0.2	-01:28:00	-01:53:00	Pinellas Point, 0.5 mile southeast of	FL
110181	Pinellas Point, 1.9 mi SE of, Tampa Bay, Florida Current	NOS	ACT8496_1	27.68470001220703	-82.60970306396484	:America/New_York	USA	knots	180	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	00:20:00	\N	0.6	-00:32:00	\N	0.5	00:29:00	-00:06:00	Pinellas Point, 1.9 miles SE of	FL
110182	Port Manatee Channel, Marker 4 (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8511_1	27.6535	-82.58983	:America/New_York	USA	knots	242	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	00:01:00	\N	0.3	-00:11:00	\N	0.2	-00:34:00	-00:22:00	Port Manatee Channel, marker '4'	FL
110183	Piney Point, 0.6 mi NNW of, Tampa Bay, Florida Current	NOS	ACT8516_1	27.65367	-82.56217	:America/New_York	USA	knots	215	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	00:01:00	\N	0.4	-00:29:00	\N	0.3	00:12:00	-00:45:00	Piney Point, 0.6 mile NNW of	FL
110184	Lewis Island, 0.9 mi east of, Tampa Bay, Florida Current	NOS	ACT8521_1	27.7245	-82.60967	:America/New_York	USA	knots	160	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108809	-00:06:00	\N	0.8	-00:09:00	\N	0.8	00:15:00	-00:52:00	Lewis Island, 0.9 mile east of	FL
110185	Camp Key, 1.9 mi northwest of, Tampa Bay, Florida Current	NOS	ACT8526_1	27.70783	-82.55	:America/New_York	USA	knots	220	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108809	-00:08:00	\N	0.7	00:09:00	\N	0.7	00:22:00	-00:30:00	Camp Key, 1.9 miles northwest of	FL
110186	Cut E Channel, Marker 2E (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8536_1	27.72533	-82.53567	:America/New_York	USA	knots	226	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108809	-00:09:00	\N	0.7	00:17:00	\N	0.7	-00:33:00	-00:13:00	Cut E Channel, marker '2E'	FL
110187	Snell Isle, 1.8 mi east of, Tampa Bay, Florida Current	NOS	ACT8546_1	27.79367	-82.57217	:America/New_York	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108809	00:13:00	\N	0.4	00:32:00	\N	0.3	00:49:00	-00:36:00	Snell Isle, 1.8 miles east of	FL
110188	Ross Island, 1 mi east of, Marker 4 (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8551_1	27.837	-82.57317	:America/New_York	USA	knots	175	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108809	-00:09:00	\N	0.5	00:29:00	\N	0.6	00:12:00	00:17:00	Ross Island, 1 mile east of, marker '4'	FL
110189	Weedon I. powerplant channel, Marker 10 (depth 23 ft), Tampa Bay, Florida Current	NOS	ACT8561_1	27.862	-82.58533	:America/New_York	USA	knots	204	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108809	-00:10:00	\N	0.4	00:47:00	\N	0.7	00:28:00	00:16:00	Weedon I. powerplant channel, marker '10'	FL
110190	Gandy Bridge, west channel, Tampa Bay, Florida Current	NOS	ACT8566_1	27.87917	-82.5805	:America/New_York	USA	knots	155	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108809	-00:20:00	\N	0.8	-00:16:00	\N	0.9	00:20:00	-00:42:00	Gandy Bridge, west channel	FL
110191	Gandy Bridge, east channel (depth 6 ft), Tampa Bay, Florida Current	NOS	ACT8571_1	27.88317	-82.55233	:America/New_York	USA	knots	179	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108809	00:20:00	\N	0.5	00:30:00	\N	0.6	00:21:00	00:22:00	Gandy Bridge, east channel	FL
110192	W Howard Frankland Bridge, Tampa Bay, Florida Current	NOS	ACT8576_1	27.92583	-82.58617	:America/New_York	USA	knots	140	285	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108809	00:29:00	\N	0.2	01:00:00	\N	0.3	00:30:00	00:01:00	W Howard Frankland Bridge	FL
110193	Courtney Campbell Parkway, Tampa Bay, Florida Current	NOS	ACT8581_1	27.968	-82.62417	:America/New_York	USA	knots	140	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108809	00:29:00	\N	0.6	00:36:00	\N	0.5	00:48:00	-00:22:00	Courtney Campbell Parkway	FL
110194	Cut A Channel, Marker 10, Hillsborough Bay (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8591_1	27.81183	-82.44733	:America/New_York	USA	knots	213	40	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108809	-00:40:00	\N	0.2	00:16:00	\N	0.3	-01:22:00	-00:41:00	Cut A Channel, marker '10', Hillsborough Bay	FL
110195	Cut C Channel, Marker 21, Hillsborough Bay (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8596_1	27.846	-82.44367	:America/New_York	USA	knots	183	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108809	-00:10:00	\N	0.2	00:41:00	\N	0.4	-01:03:00	-00:07:00	Cut C Channel, marker '21', Hillsborough Bay	FL
110196	Pass-a-Grille Channel, Florida Current	NOS	ACT8606_1	27.685	-82.735	:America/New_York	USA	knots	186	357	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:17:00	\N	1	-00:43:00	\N	0.9	-00:30:00	-00:30:00	Pass-a-Grille Channel	FL
110197	Bridge, 0.8 mi south of Maximo Pt., Florida Current	NOS	ACT8611_1	27.69333	-82.68	:America/New_York	USA	knots	255	78	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:50:00	\N	1	-01:22:00	\N	0.9	-01:05:00	-01:05:00	Bridge, 0.8 mi. south of Maximo Pt.	FL
110198	Blind Pass (north end), Florida Current	NOS	ACT8621_1	27.75667	-82.76167	:America/New_York	USA	knots	180	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-01:12:00	\N	0.3	-01:25:00	\N	0.5	-01:20:00	-01:20:00	Blind Pass (north end)	FL
110199	The Narrows (Indian Rocks Beach Bridge), Florida Current	NOS	ACT8651_1	27.876670837402344	-82.8499984741211	:America/New_York	USA	knots	0	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:54:00	\N	0.1	-00:25:00	\N	0.5	-00:23:00	-01:17:00	The Narrows (Indian Rocks Beach Bridge)	FL
110200	Clearwater Pass, 0.2 mi NE of Sand Key, Florida Current	NOS	ACT8656_1	27.95667	-82.82333	:America/New_York	USA	knots	348	179	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-01:50:00	\N	0.8	-02:49:00	\N	1	-02:24:00	-02:18:00	Clearwater Pass, 0.2 mi. NE of Sand Key	FL
110201	St. Marks River approach, Apalachee Bay, Florida Current	NOS	ACT8666_1	30.04667	-84.18	:America/New_York	USA	knots	170	339	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:08:00	\N	0.4	-00:46:00	\N	0.5	-00:57:00	-00:10:00	St. Marks River approach	FL
110202	Four Mile Point, St. Marks River, Apalachee Bay, Florida Current	NOS	ACT8671_1	30.11167	-84.20333	:America/New_York	USA	knots	187	358	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	-00:26:00	\N	0.3	-00:14:00	\N	0.3	-00:13:00	00:24:00	Four Mile Point, St. Marks River	FL
110203	St. Marks, St. Marks River, Apalachee Bay, Florida Current	NOS	ACT8676_1	30.155	-84.20167	:America/New_York	USA	knots	247	67	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106036	00:23:00	\N	0.3	01:10:00	\N	0.2	01:38:00	-00:23:00	St. Marks, St. Marks River	FL
110204	Pensacola Bay entrance, midchannel, Florida Current	NOS	ACT8716_1	30.335	-87.3	:America/Chicago	USA	knots	256	74	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106967	-00:49:00	\N	1.3	-01:01:00	\N	1.1	-01:13:00	00:06:00	Pensacola Bay entrance, midchannel	FL
110205	Channel, 6 mi N of Mobile Point, Mobile Bay, Alabama Current	NOS	ACT8731_1	30.33	-88.02833	:America/Chicago	USA	knots	208	32	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106967	01:09:00	\N	0.4	00:46:00	\N	0.4	-00:10:00	01:14:00	Channel, 6 miles N of Mobile Point	AL
110206	Mobile River entrance, Mobile Bay, Alabama Current	NOS	ACT8741_1	30.67	-88.03333	:America/Chicago	USA	knots	151	333	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106967	03:11:00	\N	0.5	04:24:00	\N	0.2	05:11:00	02:32:00	Mobile River entrance	AL
110207	Tensaw River entrance (bridge), Mobile Bay, Alabama Current	NOS	ACT8746_1	30.68167	-88.01167	:America/Chicago	USA	knots	222	29	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106967	00:05:00	\N	0.7	01:05:00	\N	0.3	01:39:00	-01:12:00	Tensaw River entrance (bridge)	AL
110208	Quatre Bayoux Pass, Barataria Bay, Louisiana Current	NOS	ACT8771_1	29.31	-89.85167	:America/Chicago	USA	knots	103	288	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106967	00:32:00	\N	0.9	00:34:00	\N	0.9	01:12:00	00:31:00	Quatre Bayoux Pass, Barataria Bay	LA
110209	Pass Abel, Barataria Bay, Louisiana Current	NOS	ACT8776_1	29.295	-89.90333	:America/Chicago	USA	knots	143	317	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106967	00:23:00	\N	1.1	00:30:00	\N	0.6	00:28:00	00:01:00	Pass Abel, Barataria Bay	LA
110210	Barataria Pass, Barataria Bay, Louisiana Current	NOS	ACT8781_1	29.27167	-89.94833	:America/Chicago	USA	knots	120	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106967	00:45:00	\N	0.9	00:53:00	\N	1.1	02:04:00	00:49:00	Barataria Pass, Barataria Bay	LA
110211	Barataria Bay, 1.1 mi NE of Manilla, Louisiana Current	NOS	ACT8786_1	29.43667	-89.96	:America/Chicago	USA	knots	160	356	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106967	04:38:00	\N	0.3	03:05:00	\N	0.3	04:16:00	02:58:00	Barataria Bay, 1.1 mi. NE of Manilla	LA
110212	Caminada Pass, Barataria Bay, Louisiana Current	NOS	ACT8791_1	29.19833	-90.04667	:America/Chicago	USA	knots	118	297	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106967	01:04:00	\N	1.1	01:57:00	\N	1.1	01:19:00	00:44:00	Caminada Pass, Barataria Bay	LA
110213	Cat Island Pass, Terrebonne Bay (depth 6 ft), Louisiana Current	NOS	ACT8801_1	29.08	-90.57333	:America/Chicago	USA	knots	195	13	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106037	-02:59:00	\N	1.2	-01:57:00	\N	0.8	-02:32:00	-01:05:00	Cat Island Pass, Terrebonne Bay	LA
110214	Wine Island Pass, Louisiana Current	NOS	ACT8806_1	29.07	-90.63333	:America/Chicago	USA	knots	160	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106037	-04:17:00	\N	1.5	-05:03:00	\N	1.2	-04:33:00	-03:38:00	Wine Island Pass	LA
110215	Caillou Boca, Caillou Bay (depth 4 ft), Louisiana Current	NOS	ACT8811_1	29.05833	-90.80833	:America/Chicago	USA	knots	264	95	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106037	-00:05:00	\N	0.6	-00:41:00	\N	0.9	-00:33:00	02:59:00	Caillou Boca, Caillou Bay	LA
110216	Galveston Bay ent. (between jetties) (depth 5 ft), Texas Current	NOS	ACT8851_1	29.34869956970215	-94.71420288085938	:America/Chicago	USA	knots	91	272	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106037	00:05:00	\N	1.1	00:15:00	\N	1	00:17:00	00:02:00	Galveston Bay Ent. (between jetties)	TX
110217	Galveston Bay ent. (between jetties) (depth 34 ft), Texas Current	NOS	ACT8851_3	29.34869956970215	-94.71420288085938	:America/Chicago	USA	knots	94	274	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106037	-00:13:00	\N	0.9	-00:01:00	\N	0.8	-00:18:00	-00:03:00	Galveston Bay Ent. (between jetties)	TX
110218	Bolivar Roads (depth 8 ft), Galveston Bay, Texas Current	NOS	ACT8856_1	29.343299865722656	-94.78130340576172	:America/Chicago	USA	knots	125	295	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106038	-00:01:00	\N	1.1	00:07:00	\N	1	00:09:00	-00:16:00	Bolivar Roads	TX
110219	Bolivar Roads (depth 31 ft), Galveston Bay, Texas Current	NOS	ACT8856_3	29.343299865722656	-94.78130340576172	:America/Chicago	USA	knots	115	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106038	-00:08:00	\N	0.6	-00:11:00	\N	0.8	-00:32:00	00:17:00	Bolivar Roads	TX
110220	Houston Channel, W of Port Bolivar (depth 3 ft), Galveston Bay, Texas Current	NOS	ACT8876_1	29.36467	-94.79667	:America/Chicago	USA	knots	135	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106038	-01:41:00	\N	1	-00:18:00	\N	1.1	-00:05:00	-02:14:00	Houston Channel, W of Port Bolivar	TX
110221	Houston Channel, W of Port Bolivar (depth 14 ft), Galveston Bay, Texas Current	NOS	ACT8876_2	29.36467	-94.79667	:America/Chicago	USA	knots	133	312	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106038	-01:55:00	\N	0.9	-00:11:00	\N	1	-00:03:00	-02:15:00	Houston Channel, W of Port Bolivar	TX
110222	Houston Channel, W of Port Bolivar (depth 26 ft), Galveston Bay, Texas Current	NOS	ACT8876_3	29.36467	-94.79667	:America/Chicago	USA	knots	133	312	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106038	-01:41:00	\N	0.8	-00:14:00	\N	0.9	-00:06:00	-02:12:00	Houston Channel, W of Port Bolivar	TX
110223	Houston Ship Channel (Red Fish Bar) (depth 7 ft), Galveston Bay, Texas Current	NOS	ACT8881_1	29.50733	-94.87467	:America/Chicago	USA	knots	154	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106038	00:50:00	\N	0.5	01:13:00	\N	0.5	00:41:00	01:13:00	Houston Ship Channel (Red Fish Bar)	TX
110224	Houston Ship Channel (Red Fish Bar) (depth 14 ft), Galveston Bay, Texas Current	NOS	ACT8881_2	29.50733	-94.87467	:America/Chicago	USA	knots	148	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106038	01:10:00	\N	0.7	01:28:00	\N	0.7	00:45:00	01:17:00	Houston Ship Channel (Red Fish Bar)	TX
110225	Houston Ship Channel (Red Fish Bar) (depth 24 ft), Galveston Bay, Texas Current	NOS	ACT8881_3	29.50733	-94.87467	:America/Chicago	USA	knots	144	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106038	01:42:00	\N	0.5	01:15:00	\N	0.5	00:48:00	01:20:00	Houston Ship Channel (Red Fish Bar)	TX
110226	Punta Ostiones, 1.5 mi west of, Puerto Rico Current	NOS	ACT8921_1	18.08667	-67.22667	:America/Puerto_Rico	USA	knots	1	187	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106039	-00:35:00	\N	1.3	-00:52:00	\N	1.7	-00:26:00	-00:04:00	Punta Ostiones, 1.5 miles west of	PR
110227	Vieques Sound, Puerto Rico Current	NOS	ACT8931_1	18.2645	-65.57	:America/Puerto_Rico	USA	knots	355	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106039	-01:05:00	\N	0.9	-01:16:00	\N	0.7	-00:44:00	-01:28:00	Vieques Sound	PR
110228	Largo Shoals, west of, Puerto Rico Current	NOS	ACT8936_1	18.31667	-65.58333	:America/Puerto_Rico	USA	knots	330	186	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106039	-01:08:00	\N	1	-01:28:00	\N	0.7	-00:52:00	-01:33:00	Largo Shoals, west of	PR
110229	Fajardo Harbor (channel), Puerto Rico Current	NOS	ACT8951_1	18.33333	-65.61667	:America/Puerto_Rico	USA	knots	339	162	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106039	-01:45:00	\N	1.6	-01:52:00	\N	0.5	-01:13:00	-02:27:00	Fajardo Harbor (channel)	PR
110230	Port Mackenzie (depth 13 ft), Cook Inlet, Alaska Current	NOS	COI0211_7	61.26765	-149.91688	:America/Anchorage	USA	knots	193	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106327	-00:37:00	\N	0.3	-01:08:00	\N	0.2	-01:50:00	-00:44:00	Port Mackenzie	AK
110231	Corson's Inlet entrance (depth 15 ft), New Jersey Current	NOS	COR0301_5	39.20863	-74.6519	:America/New_York	USA	knots	129	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106455	-02:55:00	\N	1.1	-01:57:00	\N	0.9	-01:53:00	-02:04:00	Corson's Inlet Entrance	NJ
110232	Magdalena Bay entrance, California Current	NOS	PCT0016_1	24.53333	-112.03333	:America/Los_Angeles	USA	knots	\N	35	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108376	-04:27:00	\N	0.3	-04:46:00	\N	0.6	-05:45:00	-03:56:00	Magdalena Bay entrance	CA
110233	Point Loma Light, 0.8 nmi east of (depth 15 ft), San Diego Bay, California Current	NOS	PCT0026_1	32.66583	-117.22617	:America/Los_Angeles	USA	knots	174	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	00:45:00	\N	0.4	-00:43:00	\N	0.5	-00:18:00	-00:05:00	Point Loma Light, 0.8 nmi. east of	CA
110234	Point Loma Light, 0.8 nmi east of (depth 33 ft), San Diego Bay, California Current	NOS	PCT0026_2	32.66583	-117.22617	:America/Los_Angeles	USA	knots	166	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	-00:23:00	\N	0.2	-00:46:00	\N	0.4	-01:08:00	-00:08:00	Point Loma Light, 0.8 nmi. east of	CA
110235	Ballast Point, south of (depth 5 ft), San Diego Bay, California Current	NOS	PCT0036_1	32.6845	-117.23217	:America/Los_Angeles	USA	knots	238	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	-02:03:00	\N	0.2	-01:02:00	\N	0.4	-01:04:00	-01:01:00	Ballast Point, south of	CA
110236	Ballast Point, 100 yards north of, San Diego Bay, California Current	NOS	PCT0041_1	32.68333	-117.23333	:America/Los_Angeles	USA	knots	133	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	-00:02:00	\N	0.9	-00:24:00	\N	1	-00:27:00	-00:23:00	Ballast Point, 100 yards north of	CA
110237	Ballast Point, 0.55 nmi north of (depth 14 ft), San Diego Bay, California Current	NOS	PCT0046_1	32.69583	-117.2325	:America/Los_Angeles	USA	knots	193	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	00:24:00	\N	0.4	-00:39:00	\N	0.5	-00:05:00	-00:34:00	Ballast Point, 0.55 nmi. north of	CA
110238	Ballast Point, 0.55 nmi north of (depth 34 ft), San Diego Bay, California Current	NOS	PCT0046_2	32.69583	-117.2325	:America/Los_Angeles	USA	knots	147	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	-00:03:00	\N	0.2	00:10:00	\N	0.5	-00:44:00	00:03:00	Ballast Point, 0.55 nmi. north of	CA
110239	Quarantine Station, La Playa, San Diego Bay, California Current	NOS	PCT0051_1	32.7	-117.23333	:America/Los_Angeles	USA	knots	200	21	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	00:20:00	\N	0.8	00:15:00	\N	0.8	-00:03:00	00:10:00	Quarantine Station, La Playa	CA
110240	North Island (depth 14 ft), San Diego Bay, California Current	NOS	PCT0056_1	32.713	-117.21283	:America/Los_Angeles	USA	knots	245	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	-00:03:00	\N	0.4	-00:56:00	\N	0.5	-00:26:00	-00:54:00	North Island	CA
110241	North Island (depth 34 ft), San Diego Bay, California Current	NOS	PCT0056_2	32.713	-117.21283	:America/Los_Angeles	USA	knots	241	77	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	-00:33:00	\N	0.2	-01:05:00	\N	0.3	-00:43:00	-00:44:00	North Island	CA
110242	Harbor Island (east end), SSW of (depth 15 ft), San Diego Bay, California Current	NOS	PCT0061_1	32.71917	-117.19167	:America/Los_Angeles	USA	knots	293	97	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	00:23:00	\N	0.3	00:09:00	\N	0.3	00:29:00	-00:24:00	Harbor Island (east end), SSW of	CA
110243	San Diego, 0.5 mi west of, San Diego Bay, California Current	NOS	PCT0066_1	32.71667	-117.18333	:America/Los_Angeles	USA	knots	304	121	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	-00:12:00	\N	0.5	-00:08:00	\N	0.6	-00:16:00	-00:12:00	San Diego, 0.5 mile west of	CA
110244	G St. Pier (San Diego), 0.22 nmi SW of (depth 14 ft), San Diego Bay, California Current	NOS	PCT0081_1	32.70833	-117.1775	:America/Los_Angeles	USA	knots	304	139	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	00:41:00	\N	0.3	00:20:00	\N	0.3	00:10:00	-00:03:00	G St. Pier (San Diego), 0.22 nmi. SW of	CA
110245	G St. Pier (San Diego), 0.22 nmi SW of (depth 37 ft), San Diego Bay, California Current	NOS	PCT0081_2	32.70833	-117.1775	:America/Los_Angeles	USA	knots	301	125	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	00:58:00	\N	0.2	00:21:00	\N	0.3	-00:23:00	-00:18:00	G St. Pier (San Diego), 0.22 nmi. SW of	CA
110246	Coronado, off northeast end (depth 14 ft), San Diego Bay, California Current	NOS	PCT0091_1	32.698	-117.16383	:America/Los_Angeles	USA	knots	317	128	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	00:09:00	\N	0.5	-00:58:00	\N	0.7	-00:24:00	-00:51:00	Coronado, off northeast end	CA
110247	Coronado, off northeast end (depth 38 ft), San Diego Bay, California Current	NOS	PCT0091_2	32.698	-117.16383	:America/Los_Angeles	USA	knots	319	130	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	00:03:00	\N	0.4	-00:59:00	\N	0.5	-00:41:00	-01:01:00	Coronado, off northeast end	CA
110248	28th St. Pier (San Diego), 0.92 nmi SW (depth 7 ft), San Diego Bay, California Current	NOS	PCT0096_1	32.67467	-117.1495	:America/Los_Angeles	USA	knots	351	182	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	-00:05:00	\N	0.1	-01:17:00	\N	0.2	-00:44:00	-01:10:00	28th St. Pier (San Diego), 0.92 nmi. SW	CA
110249	28th St. Pier (San Diego), 0.35 nmi SW (depth 14 ft), San Diego Bay, California Current	NOS	PCT0101_1	32.68283	-117.14283	:America/Los_Angeles	USA	knots	317	133	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	00:13:00	\N	0.2	00:15:00	\N	0.3	-00:14:00	00:15:00	28th St. Pier (San Diego), 0.35 nmi. SW	CA
110250	28th St. Pier (San Diego), 0.35 nmi SW (depth 28 ft), San Diego Bay, California Current	NOS	PCT0101_2	32.68283	-117.14283	:America/Los_Angeles	USA	knots	328	148	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	00:35:00	\N	0.2	00:24:00	\N	0.2	00:01:00	00:15:00	28th St. Pier (San Diego), 0.35 nmi. SW	CA
110251	National City, San Diego Bay, California Current	NOS	PCT0106_1	32.65	-117.11667	:America/Los_Angeles	USA	knots	2	166	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	00:50:00	\N	0.4	00:00:00	\N	0.4	00:23:00	-00:02:00	National City	CA
110252	National City, WSW of Pier 12 (depth 32 ft), San Diego Bay, California Current	NOS	PCT0111_1	32.66217	-117.1255	:America/Los_Angeles	USA	knots	351	178	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	00:58:00	\N	0.2	00:34:00	\N	0.2	00:22:00	00:34:00	National City, WSW of Pier 12	CA
110253	Sweetwater Channel, southwest of (depth 14 ft), San Diego Bay, California Current	NOS	PCT0116_1	32.645	-117.12283	:America/Los_Angeles	USA	knots	348	203	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107041	00:46:00	\N	0.2	-00:33:00	\N	0.1	00:29:00	-00:05:00	Sweetwater Channel, southwest of	CA
110254	Point Bonita Lt., 5.27 nmi WSW of (depth 39 ft), California Current	NOS	PCT0181_1	37.8045	-122.63883	:America/Los_Angeles	USA	knots	266	95	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108376	-01:01:00	\N	0.2	-01:35:00	\N	0.2	-01:54:00	-00:51:00	Point Bonita Lt., 5.27 nmi. WSW of	CA
110255	Point Lobos, 3.73 nmi W of (depth 46 ft), California Current	NOS	PCT0191_1	37.7875	-122.58867	:America/Los_Angeles	USA	knots	241	92	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108376	-00:31:00	\N	0.2	-01:03:00	\N	0.3	-02:16:00	-00:20:00	Point Lobos, 3.73 nmi. W of	CA
110256	Point Lobos, 1.3 nmi SW of (depth 46 ft), California Current	NOS	PCT0201_1	37.77167	-122.5355	:America/Los_Angeles	USA	knots	182	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108376	-00:06:00	\N	0.4	-00:51:00	\N	0.5	-01:26:00	00:27:00	Point Lobos, 1.3 nmi. SW of	CA
110257	South Channel, California Current	NOS	PCT0206_1	37.75	-122.53333	:America/Los_Angeles	USA	knots	180	23	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108376	-00:52:00	\N	0.5	-01:21:00	\N	0.5	-01:31:00	-00:14:00	South Channel	CA
110258	Point Lobos, 5.47 nmi SW of (depth 39 ft), California Current	NOS	PCT0211_1	37.7205	-122.59783	:America/Los_Angeles	USA	knots	211	48	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108376	-01:10:00	\N	0.3	-02:02:00	\N	0.3	-02:01:00	-00:51:00	Point Lobos, 5.47 nmi. SW of	CA
110259	Point Bonita, 0.8 nmi NE of (depth 22 ft), California Current	NOS	PCT0231_1	37.82083	-122.51617	:America/Los_Angeles	USA	knots	267	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108376	-04:01:00	\N	0.3	-03:38:00	\N	0.4	-04:51:00	-04:21:00	Point Bonita, 0.8 nmi. NE of	CA
110260	Point Bonita, 0.8 nmi NE of (depth 41 ft), California Current	NOS	PCT0231_2	37.82083	-122.51617	:America/Los_Angeles	USA	knots	247	111	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108376	-04:01:00	\N	0.2	-04:23:00	\N	0.3	-05:12:00	-04:45:00	Point Bonita, 0.8 nmi. NE of	CA
110261	Point Bonita Lt., 0.4 nmi SSE of (depth 43 ft), California Current	NOS	PCT0236_1	37.812	-122.52117	:America/Los_Angeles	USA	knots	229	104	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108376	-01:25:00	\N	0.5	-01:04:00	\N	0.3	-01:08:00	-01:28:00	Point Bonita Lt., 0.4 nmi. SSE of	CA
110262	Mile Rock Lt., 0.2 nmi NW of (depth 15 ft), California Current	NOS	PCT0246_1	37.79533	-122.51133	:America/Los_Angeles	USA	knots	230	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108376	-00:33:00	\N	0.9	-00:25:00	\N	1.1	-00:35:00	00:18:00	Mile Rock Lt., 0.2 nmi. NW of	CA
110263	Mile Rock Lt., 0.2 nmi NW of (depth 35 ft), California Current	NOS	PCT0246_2	37.79533	-122.51133	:America/Los_Angeles	USA	knots	231	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108376	-00:34:00	\N	0.8	-00:28:00	\N	1.1	-00:48:00	00:23:00	Mile Rock Lt., 0.2 nmi. NW of	CA
110264	Point Diablo, 0.2 mi SE of, California Current	NOS	PCT0251_1	37.81783	-122.49667	:America/Los_Angeles	USA	knots	263	82	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108376	00:08:00	\N	1	-00:53:00	\N	0.8	-00:09:00	-00:47:00	Point Diablo, 0.2 mile SE of	CA
110265	Baker Beach (South Bay), 0.3 nmi NW of (depth 31 ft), California Current	NOS	PCT0256_1	37.79783	-122.4885	:America/Los_Angeles	USA	knots	208	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108376	-02:52:00	\N	0.3	-04:15:00	\N	0.6	-05:06:00	-01:59:00	Baker Beach (South Bay), 0.3 nmi. NW of	CA
110266	Baker Beach (South Bay), 0.3 nmi NW of (depth 50 ft), California Current	NOS	PCT0256_2	37.79783	-122.4885	:America/Los_Angeles	USA	knots	215	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108376	-02:54:00	\N	0.3	-04:14:00	\N	0.4	-05:11:00	-01:33:00	Baker Beach (South Bay), 0.3 nmi. NW of	CA
110267	Fort Point, 0.3 nmi west of (depth 75 ft), California Current	NOS	PCT0261_1	37.80917	-122.48283	:America/Los_Angeles	USA	knots	335	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108376	00:20:00	\N	0.2	-00:41:00	\N	0.6	-02:10:00	01:02:00	Fort Point, 0.3 nmi. west of	CA
110268	Golden Gate Bridge, 0.8 mi east of, California Current	NOS	PCT0281_1	37.82167	-122.46167	:America/Los_Angeles	USA	knots	256	70	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	00:43:00	\N	1.4	00:15:00	\N	0.9	00:42:00	00:27:00	Golden Gate Bridge, 0.8 mile east of	CA
110269	Fort Point, 0.5 nmi east of (depth 55 ft), California Current	NOS	PCT0286_1	37.81167	-122.46633	:America/Los_Angeles	USA	knots	287	99	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	-01:12:00	\N	0.8	-02:47:00	\N	0.2	-00:43:00	-00:30:00	Fort Point, 0.5 nmi. east of	CA
110270	Alcatraz Island, 0.2 mi west of, San Francisco Bay, California Current	NOS	PCT0291_1	37.82783	-122.43033	:America/Los_Angeles	USA	knots	266	70	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	00:20:00	\N	1.1	00:00:00	\N	0.8	00:15:00	00:24:00	Alcatraz Island, 0.2 mile west of	CA
110271	Alcatraz Island, south of, San Francisco Bay, California Current	NOS	PCT0301_1	37.81833	-122.422	:America/Los_Angeles	USA	knots	286	93	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	00:02:00	\N	1.2	-00:03:00	\N	0.5	00:15:00	00:07:00	Alcatraz Island, south of	CA
110272	Treasure Island, 0.8 mi west of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0321_1	37.82167	-122.39167	:America/Los_Angeles	USA	knots	334	148	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	-00:01:00	\N	1.5	-00:37:00	\N	0.4	-00:01:00	-00:39:00	Treasure Island, 0.8 mile west of	CA
110273	Treasure Island, 0.2 mi west of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0326_1	37.82167	-122.37833	:America/Los_Angeles	USA	knots	343	172	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	-00:30:00	\N	1.2	-00:50:00	\N	0.5	-00:54:00	-00:32:00	Treasure Island, 0.2 mile west of	CA
110274	Oakland, Yerba Buena Island (depth 29 ft), San Francisco Bay, California Current	NOS	PCT0336_2	37.80979919433594	-122.35070037841797	:America/Los_Angeles	USA	knots	355	163	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107042	-00:07:00	\N	0.6	-00:04:00	\N	0.7	-00:38:00	-00:01:00	Oakland, Yerba Buena Island	CA
110275	Treasure Island, 0.5 mi north of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0346_1	37.8405	-122.36833	:America/Los_Angeles	USA	knots	304	118	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107042	00:42:00	\N	0.9	00:02:00	\N	0.8	00:31:00	00:22:00	Treasure Island, 0.5 mile north of	CA
110276	Treasure Island, 0.85 nmi east of (depth 11 ft), San Francisco Bay, California Current	NOS	PCT0351_1	37.825	-122.34633	:America/Los_Angeles	USA	knots	340	161	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107042	-00:26:00	\N	0.5	00:16:00	\N	0.6	-00:13:00	00:24:00	Treasure Island, 0.85 nmi. east of	CA
110277	Treasure Island, 0.3 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0356_1	37.82667	-122.355	:America/Los_Angeles	USA	knots	327	140	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107042	01:02:00	\N	1.2	00:13:00	\N	1	01:12:00	00:00:00	Treasure Island, 0.3 mile east of	CA
110278	Yerba Buena Island, 0.3 nmi SE of (depth 23 ft), San Francisco Bay, California Current	NOS	PCT0361_1	37.80417	-122.35717	:America/Los_Angeles	USA	knots	316	159	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107042	00:21:00	\N	0.8	00:05:00	\N	0.5	00:31:00	00:07:00	Yerba Buena Island, 0.3 nmi. SE of	CA
110279	Oakland Inner Harbor entrance (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0371_1	37.80167	-122.34	:America/Los_Angeles	USA	knots	338	178	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107042	-00:09:00	\N	1.2	-00:12:00	\N	0.7	-00:11:00	-00:01:00	Oakland Inner Harbor entrance	CA
110280	Oakland Harbor, Webster Street, San Francisco Bay, California Current	NOS	PCT0386_1	37.79167	-122.2745	:America/Los_Angeles	USA	knots	300	120	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107042	-00:03:00	\N	0.8	-00:32:00	\N	0.6	00:08:00	-00:18:00	Oakland Harbor, Webster Street	CA
110281	Oakland 7th St. Marine, 0.6 nmi SSW of (depth 21 ft), California Current	NOS	PCT0396_1	37.7945	-122.34417	:America/Los_Angeles	USA	knots	342	154	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107042	00:03:00	\N	0.6	00:27:00	\N	0.8	-00:01:00	-00:02:00	Oakland 7th St. Marine, 0.6 nmi. SSW of	CA
110282	Rincon Point, midbay (depth 11 ft), San Francisco Bay, California Current	NOS	PCT0406_1	37.78333	-122.35383	:America/Los_Angeles	USA	knots	322	166	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	-00:24:00	\N	1.3	-00:33:00	\N	0.8	-00:22:00	-00:38:00	Rincon Point, midbay	CA
110283	Mission Rock, 0.6 mi east of, San Francisco Bay, California Current	NOS	PCT0411_1	37.77333	-122.36833	:America/Los_Angeles	USA	knots	320	160	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	00:06:00	\N	1.4	-00:21:00	\N	0.9	-00:09:00	-00:08:00	Mission Rock, 0.6 mile east of	CA
110284	Mission Rock, 1.3 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0416_1	37.775	-122.35333	:America/Los_Angeles	USA	knots	344	182	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	00:14:00	\N	1.2	-00:31:00	\N	0.8	00:01:00	-00:02:00	Mission Rock, 1.3 mile east of	CA
110285	Mission Rock, 2.0 mi east of, San Francisco Bay, California Current	NOS	PCT0421_1	37.77667	-122.33833	:America/Los_Angeles	USA	knots	330	142	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	-00:20:00	\N	1.4	-00:51:00	\N	0.6	-00:49:00	-00:18:00	Mission Rock, 2.0 miles east of	CA
110286	Potrero Point, 1.08 nmi east of (depth 20 ft), San Francisco Bay, California Current	NOS	PCT0426_1	37.7575	-122.35783	:America/Los_Angeles	USA	knots	342	169	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	-00:04:00	\N	1.1	-00:25:00	\N	0.6	-00:08:00	-00:06:00	Potrero Point, 1.08 nmi. east of	CA
110287	Potrero Point, 1.08 nmi east of (depth 49 ft), San Francisco Bay, California Current	NOS	PCT0426_2	37.7575	-122.35783	:America/Los_Angeles	USA	knots	327	139	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	00:13:00	\N	0.7	-00:32:00	\N	0.4	-00:15:00	-00:05:00	Potrero Point, 1.08 nmi. east of	CA
110288	Potrero Point, 2 mi east of, San Francisco Bay, California Current	NOS	PCT0431_1	37.75	-122.33333	:America/Los_Angeles	USA	knots	328	159	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	-00:02:00	\N	1	-00:44:00	\N	0.6	-00:08:00	00:03:00	Potrero Point, 2 miles  east of	CA
110289	Alameda Radar Tower, 0.9 nmi SSW of (depth 4 ft), San Francisco Bay, California Current	NOS	PCT0436_1	37.7455	-122.283	:America/Los_Angeles	USA	knots	309	132	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	-01:12:00	\N	0.4	-01:14:00	\N	0.2	-00:55:00	-01:18:00	Alameda Radar Tower, 0.9 nmi. SSW of	CA
110478	Ketchikan, Tongass Narrows, Alaska Current	NOS	PCT2786_1	55.33617	-131.64417	:America/Juneau	USA	knots	120	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:41:00	\N	0.1	00:08:00	\N	0.3	-00:50:00	00:04:00	Ketchikan	AK
110290	Point Avisadero, 0.3 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0441_1	37.73	-122.34833	:America/Los_Angeles	USA	knots	337	156	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:20:00	\N	1.3	-00:21:00	\N	1.2	-00:30:00	-00:13:00	Point Avisadero, 0.3 mile east of	CA
110291	Point Avisadero, 1 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0446_1	37.73	-122.33667	:America/Los_Angeles	USA	knots	352	154	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:07:00	\N	1	00:02:00	\N	1.2	-00:32:00	00:25:00	Point Avisadero, 1 mile east of	CA
110292	Point Avisadero, 2 mi east of (depth 6 ft), San Francisco Bay, California Current	NOS	PCT0451_1	37.73167	-122.31333	:America/Los_Angeles	USA	knots	335	148	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:24:00	\N	1.1	-00:06:00	\N	1.1	-00:32:00	-00:10:00	Point Avisadero, 2 miles east of	CA
110293	Point Avisadero, 0.6 nmi ESE of (depth 21 ft), San Francisco Bay, California Current	NOS	PCT0456_1	37.723	-122.32383	:America/Los_Angeles	USA	knots	335	140	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:39:00	\N	1	-00:25:00	\N	1	-00:32:00	-00:14:00	Point Avisadero, 0.6 nmi. ESE of	CA
110294	Point Avisadero, 0.6 nmi ESE of (depth 37 ft), San Francisco Bay, California Current	NOS	PCT0456_2	37.723	-122.32383	:America/Los_Angeles	USA	knots	327	132	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:43:00	\N	0.7	-00:23:00	\N	0.8	-00:37:00	-00:10:00	Point Avisadero, 0.6 nmi. ESE of	CA
110295	Point Avisadero, 1.25 nmi SSE of (depth 20 ft), San Francisco Bay, California Current	NOS	PCT0461_1	37.70783	-122.3495	:America/Los_Angeles	USA	knots	4	175	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:52:00	\N	0.8	-00:15:00	\N	0.9	-00:45:00	-00:29:00	Point Avisadero, 1.25 nmi. SSE of	CA
110296	Point Avisadero, 1.25 nmi SSE of (depth 32 ft), San Francisco Bay, California Current	NOS	PCT0461_2	37.70783	-122.3495	:America/Los_Angeles	USA	knots	8	186	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:48:00	\N	0.6	-00:06:00	\N	0.7	-00:43:00	-00:33:00	Point Avisadero, 1.25 nmi. SSE of	CA
110297	Oakland Airport, southwest of (depth 3 ft), San Francisco Bay, California Current	NOS	PCT0466_1	37.68217	-122.23083	:America/Los_Angeles	USA	knots	304	125	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-01:18:00	\N	0.5	-00:46:00	\N	0.5	-01:05:00	-00:39:00	Oakland Airport, southwest of	CA
110298	Sierra Point, 1.3 mi ENE of, San Francisco Bay, California Current	NOS	PCT0471_1	37.68467	-122.35667	:America/Los_Angeles	USA	knots	3	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:40:00	\N	0.7	-00:34:00	\N	0.8	-00:47:00	-00:25:00	Sierra Point, 1.3 miles ENE of	CA
110299	Sierra Point, 1.2 nmi east of (depth 18 ft), San Francisco Bay, California Current	NOS	PCT0476_1	37.678	-122.3175	:America/Los_Angeles	USA	knots	358	210	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:22:00	\N	0.5	-00:30:00	\N	0.6	-00:42:00	-00:26:00	Sierra Point, 1.2 nmi. east of	CA
110300	Oyster Point, 2.8 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0481_1	37.665	-122.32333	:America/Los_Angeles	USA	knots	345	172	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:16:00	\N	0.8	-00:20:00	\N	0.7	-00:29:00	-00:13:00	Oyster Point, 2.8 miles east of	CA
110301	Sierra Point, 4.4 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0486_1	37.67333	-122.295	:America/Los_Angeles	USA	knots	329	152	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:33:00	\N	0.6	-00:34:00	\N	0.7	-00:48:00	-00:09:00	Sierra Point, 4.4 miles east of	CA
110302	Point San Bruno, 0.51 nmi east of (depth 10 ft), San Francisco Bay, California Current	NOS	PCT0491_1	37.65417	-122.36383	:America/Los_Angeles	USA	knots	359	174	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-01:07:00	\N	0.3	-00:27:00	\N	0.5	-01:16:00	-00:21:00	Point San Bruno, 0.51 nmi. east  of	CA
110303	Little Coyote Pt., 3.4 nmi NNE of (depth 4 ft), San Francisco Bay, California Current	NOS	PCT0501_1	37.62383	-122.23133	:America/Los_Angeles	USA	knots	310	128	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-01:01:00	\N	0.4	-00:54:00	\N	0.4	-01:06:00	-00:50:00	Little Coyote Pt., 3.4 nmi. NNE of	CA
110304	Little Coyote Pt., 3.1 nmi ENE of (depth 4 ft), San Francisco Bay, California Current	NOS	PCT0506_1	37.598	-122.2055	:America/Los_Angeles	USA	knots	317	135	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-01:49:00	\N	0.4	-01:34:00	\N	0.4	-01:52:00	-00:58:00	Little Coyote Pt., 3.1 nmi. ENE of	CA
110305	Little Coyote Pt., 1.2 nmi NE of (depth 10 ft), San Francisco Bay, California Current	NOS	PCT0511_1	37.59033	-122.24867	:America/Los_Angeles	USA	knots	303	121	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:11:00	\N	1.1	-00:26:00	\N	1.1	-00:09:00	-00:11:00	Little Coyote Pt., 1.2 nmi. NE of	CA
110306	Little Coyote Pt., 1.2 nmi NE of (depth 20 ft), San Francisco Bay, California Current	NOS	PCT0511_2	37.59033	-122.24867	:America/Los_Angeles	USA	knots	307	122	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:13:00	\N	1	-00:27:00	\N	0.9	-00:17:00	-00:07:00	Little Coyote Pt., 1.2 nmi. NE of	CA
110307	Little Coyote Pt., 1.2 nmi NE of (depth 39 ft), San Francisco Bay, California Current	NOS	PCT0511_3	37.59033	-122.24867	:America/Los_Angeles	USA	knots	310	138	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:09:00	\N	0.8	-00:21:00	\N	0.7	-00:24:00	-00:12:00	Little Coyote Pt., 1.2 nmi. NE of	CA
110308	Redwood Pt., Blair I., 1.15 nmi NNE of (depth 19 ft), California Current	NOS	PCT0521_1	37.558	-122.19883	:America/Los_Angeles	USA	knots	310	120	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:06:00	\N	1.1	-00:21:00	\N	1	-00:02:00	-00:02:00	Redwood Pt., Blair I., 1.15 nmi. NNE of	CA
110309	Redwood Pt., Blair I., 1.15 nmi NNE of (depth 42 ft), California Current	NOS	PCT0521_2	37.558	-122.19883	:America/Los_Angeles	USA	knots	300	107	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:06:00	\N	0.7	-00:27:00	\N	0.8	-00:17:00	-00:10:00	Redwood Pt., Blair I., 1.15 nmi. NNE of	CA
110310	Dumbarton Hwy. Bridge, 0.28 nmi SE of (depth 25 ft), California Current	NOS	PCT0531_1	37.50133	-122.1155	:America/Los_Angeles	USA	knots	319	141	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:37:00	\N	1.2	00:06:00	\N	1	-00:21:00	00:02:00	Dumbarton Hwy. Bridge, 0.28 nmi. SE of	CA
110311	Dumbarton Hwy. Bridge, 0.28 nmi SE of (depth 42 ft), California Current	NOS	PCT0531_2	37.50133	-122.1155	:America/Los_Angeles	USA	knots	322	137	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:45:00	\N	0.7	00:10:00	\N	0.9	-00:36:00	00:01:00	Dumbarton Hwy. Bridge, 0.28 nmi. SE of	CA
110312	Dumbarton Point, 1.15 nmi SE of (depth 17 ft), San Francisco Bay, California Current	NOS	PCT0536_1	37.4875	-122.08133	:America/Los_Angeles	USA	knots	320	131	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	00:54:00	\N	0.6	-00:20:00	\N	0.8	-00:12:00	00:12:00	Dumbarton Point, 1.15 nmi. SE  of	CA
110313	Dumbarton Point, 2.25 mi SE of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0541_1	37.475	-122.07	:America/Los_Angeles	USA	knots	302	127	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	00:56:00	\N	0.8	-00:06:00	\N	0.9	00:08:00	00:00:00	Dumbarton Point, 2.25 miles SE of	CA
110314	Yellow Bluff, 0.8 nmi NE of (depth 19 ft), San Francisco Bay, California Current	NOS	PCT0546_1	37.8455	-122.45717	:America/Los_Angeles	USA	knots	211	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:59:00	\N	1.1	-00:28:00	\N	1.2	-00:27:00	-00:37:00	Yellow Bluff, 0.8 nmi. NE of	CA
110315	Yellow Bluff, 0.8 nmi NE of (depth 51 ft), San Francisco Bay, California Current	NOS	PCT0546_2	37.8455	-122.45717	:America/Los_Angeles	USA	knots	226	12	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108447	-00:33:00	\N	0.6	-00:31:00	\N	0.8	-00:42:00	-00:06:00	Yellow Bluff, 0.8 nmi. NE of	CA
110316	Yellow Bluff, 0.8 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0551_1	37.835	-122.455	:America/Los_Angeles	USA	knots	257	22	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	00:44:00	\N	1.4	00:16:00	\N	1	00:24:00	00:22:00	Yellow Bluff, 0.8 mile east of	CA
110317	Point Cavallo, 1.3 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0556_1	37.83167	-122.44333	:America/Los_Angeles	USA	knots	256	87	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	00:44:00	\N	1.6	00:26:00	\N	0.9	00:31:00	00:42:00	Point Cavallo, 1.3 miles east of	CA
110318	Point Blunt, Angel I., 0.5 nmi SW of (depth 21 ft), San Francisco Bay, California Current	NOS	PCT0561_1	37.8455	-122.423	:America/Los_Angeles	USA	knots	258	77	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	00:33:00	\N	1	00:09:00	\N	0.4	00:56:00	00:03:00	Point Blunt, Angel I., 0.5 nmi. SW of	CA
110319	Point Blunt, Angel I., 0.5 nmi SW of (depth 40 ft), San Francisco Bay, California Current	NOS	PCT0561_2	37.8455	-122.423	:America/Los_Angeles	USA	knots	258	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	00:33:00	\N	0.9	-00:12:00	\N	0.4	00:02:00	00:27:00	Point Blunt, Angel I., 0.5 nmi. SW of	CA
110320	Point Blunt, Angel I., 0.25 mi S of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0566_1	37.84667	-122.41667	:America/Los_Angeles	USA	knots	258	103	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	01:08:00	\N	1.3	00:11:00	\N	0.6	00:12:00	00:24:00	Point Blunt, Angel I., 0.25 mile S of	CA
110321	Pt. Blunt, Angel I., 0.8 mi SE of, San Francisco Bay, California Current	NOS	PCT0571_1	37.845	-122.405	:America/Los_Angeles	USA	knots	297	86	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	-00:12:00	\N	0.8	00:02:00	\N	0.4	-01:06:00	00:21:00	Pt. Blunt, Angel I., 0.8 mi. SE of	CA
110322	Pt. Blunt, Angel I., 0.25 nmi east of (depth 21 ft), California Current	NOS	PCT0576_1	37.85283	-122.41217	:America/Los_Angeles	USA	knots	185	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	02:23:00	\N	1	-00:06:00	\N	0.4	01:45:00	00:17:00	Pt. Blunt, Angel I., 0.25 nmi. east of	CA
110323	Pt. Blunt, Angel I., 0.25 nmi east of (depth 41 ft), California Current	NOS	PCT0576_2	37.85283	-122.41217	:America/Los_Angeles	USA	knots	194	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	02:02:00	\N	0.8	-00:32:00	\N	0.3	00:55:00	00:34:00	Pt. Blunt, Angel I., 0.25 nmi. east of	CA
110324	Angel Island, off Quarry Point, San Francisco Bay, California Current	NOS	PCT0581_1	37.86333	-122.41333	:America/Los_Angeles	USA	knots	130	27	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	01:47:00	\N	1.2	00:22:00	\N	0.2	02:11:00	01:10:00	Angel Island, off Quarry Point	CA
110325	Angel Island, 0.75 mi east of, San Francisco Bay, California Current	NOS	PCT0586_1	37.86333	-122.40167	:America/Los_Angeles	USA	knots	192	351	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	01:59:00	\N	0.6	01:10:00	\N	0.4	01:30:00	01:35:00	Angel Island, 0.75 mile east of	CA
110326	Point Simpson, Angel I., 1.05 nmi E of (depth 21 ft), California Current	NOS	PCT0591_1	37.87383	-122.40283	:America/Los_Angeles	USA	knots	177	332	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	00:33:00	\N	0.5	01:08:00	\N	0.5	00:53:00	01:03:00	Point Simpson, Angel I., 1.05 nmi. E of	CA
110327	Point Simpson, Angel I., 1.05 nmi E of (depth 42 ft), California Current	NOS	PCT0591_2	37.87383	-122.40283	:America/Los_Angeles	USA	knots	169	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	00:33:00	\N	0.3	01:19:00	\N	0.3	00:29:00	01:01:00	Point Simpson, Angel I., 1.05 nmi. E of	CA
110328	Fleming Point, 1.72 nmi SW of (depth 3 ft), San Francisco Bay, California Current	NOS	PCT0596_1	37.877	-122.35883	:America/Los_Angeles	USA	knots	259	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	-00:47:00	\N	0.3	-01:02:00	\N	0.2	-01:04:00	-00:24:00	Fleming Point, 1.72 nmi. SW of	CA
110329	Raccoon Strait, off Point Stuart (depth 15 ft), San Francisco Bay, California Current	NOS	PCT0606_1	37.86117	-122.452	:America/Los_Angeles	USA	knots	226	14	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	00:04:00	\N	1.2	00:08:00	\N	0.5	00:11:00	-00:02:00	Raccoon Strait, off Point Stuart	CA
110330	Bluff Point, 0.1 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0621_1	37.88333	-122.435	:America/Los_Angeles	USA	knots	147	9	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	00:50:00	\N	1.2	-00:26:00	\N	0.6	01:04:00	00:18:00	Bluff Point, 0.1 mile east of	CA
110331	Bluff Point, 1.15 nmi east of (depth 21 ft), San Francisco Bay, California Current	NOS	PCT0626_1	37.88717	-122.413	:America/Los_Angeles	USA	knots	167	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	00:33:00	\N	0.6	00:46:00	\N	0.4	00:55:00	00:58:00	Bluff Point, 1.15 nmi. east of	CA
110332	Southampton Shoal Light, 0.2 mi E of (depth 10 ft), San Francisco Bay, California Current	NOS	PCT0631_1	37.8825	-122.39583	:America/Los_Angeles	USA	knots	188	19	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108379	00:25:00	\N	0.7	00:55:00	\N	0.3	01:04:00	00:53:00	Southampton Shoal Light, 0.2 mile E of	CA
110333	Point Chauncey, 0.75 nmi NW of (depth 19 ft), San Francisco Bay, California Current	NOS	PCT0641_1	37.903	-122.45883	:America/Los_Angeles	USA	knots	131	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	-00:09:00	\N	0.6	-00:46:00	\N	0.7	00:08:00	00:10:00	Point Chauncey, 0.75 nmi. NW of	CA
110334	Point Richmond, 0.5 mi west of (depth 6 ft), San Francisco Bay, California Current	NOS	PCT0656_1	37.905	-122.4	:America/Los_Angeles	USA	knots	142	332	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	-00:12:00	\N	0.5	00:01:00	\N	0.5	-00:16:00	00:10:00	Point Richmond, 0.5 mile west of	CA
110335	Point Richmond, 0.8 nmi NNW of (depth 4 ft), San Francisco Bay, California Current	NOS	PCT0661_1	37.92083	-122.39667	:America/Los_Angeles	USA	knots	147	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	-02:02:00	\N	0.2	-01:55:00	\N	0.2	-00:48:00	-01:14:00	Point Richmond, 0.8 nmi. NNW of	CA
110336	Richmond (depth 7 ft), San Francisco Bay, California Current	NOS	PCT0666_1	37.929298400878906	-122.42500305175781	:America/Los_Angeles	USA	knots	150	324	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	00:04:00	\N	1.1	00:10:00	\N	1	00:16:00	-00:03:00	Richmond	CA
110337	Richmond (depth 31 ft), San Francisco Bay, California Current	NOS	PCT0666_3	37.929298400878906	-122.42500305175781	:America/Los_Angeles	USA	knots	145	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	-00:06:00	\N	0.8	-00:13:00	\N	1	-00:33:00	00:07:00	Richmond	CA
110338	Richmond (depth 43 ft), San Francisco Bay, California Current	NOS	PCT0666_4	37.929298400878906	-122.42500305175781	:America/Los_Angeles	USA	knots	149	330	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	-00:07:00	\N	0.7	-00:30:00	\N	0.8	-00:51:00	00:10:00	Richmond	CA
110339	Red Rock, east of (depth 11 ft), San Francisco Bay, California Current	NOS	PCT0671_1	37.9295	-122.42833	:America/Los_Angeles	USA	knots	175	318	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	00:07:00	\N	0.8	00:03:00	\N	0.8	00:06:00	00:28:00	Red Rock, east of	CA
110340	Red Rock, 0.60 nmi NNE of (depth 17 ft), San Francisco Bay, California Current	NOS	PCT0676_1	37.94	-122.42667	:America/Los_Angeles	USA	knots	155	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	-00:33:00	\N	0.9	-00:37:00	\N	1.1	-00:18:00	00:10:00	Red Rock, 0.60 nmi. NNE of	CA
110341	Red Rock, 0.60 nmi NNE of (depth 23 ft), San Francisco Bay, California Current	NOS	PCT0676_2	37.94	-122.42667	:America/Los_Angeles	USA	knots	145	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	-00:38:00	\N	0.8	-00:22:00	\N	1	-00:33:00	00:04:00	Red Rock, 0.60 nmi. NNE of	CA
110342	Red Rock, 0.60 nmi NNE of (depth 38 ft), San Francisco Bay, California Current	NOS	PCT0676_3	37.94	-122.42667	:America/Los_Angeles	USA	knots	145	335	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	-00:34:00	\N	0.6	-00:21:00	\N	0.9	-00:46:00	00:16:00	Red Rock, 0.60 nmi. NNE of	CA
110343	Point San Quentin, 0.82 nmi east of (depth 15 ft), San Francisco Bay, California Current	NOS	PCT0681_1	37.94117	-122.46167	:America/Los_Angeles	USA	knots	182	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	-00:46:00	\N	0.5	00:02:00	\N	0.4	-00:09:00	00:02:00	Point San Quentin, 0.82 nmi. east  of	CA
110344	Point San Quentin, 1.3 nmi east of (depth 23 ft), San Francisco Bay, California Current	NOS	PCT0686_1	37.94217	-122.45267	:America/Los_Angeles	USA	knots	181	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	00:23:00	\N	0.9	00:19:00	\N	0.8	00:20:00	00:35:00	Point San Quentin, 1.3 nmi. east of	CA
110345	Point San Quentin, 1.3 nmi east of (depth 38 ft), San Francisco Bay, California Current	NOS	PCT0686_2	37.94217	-122.45267	:America/Los_Angeles	USA	knots	186	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	00:11:00	\N	0.5	00:19:00	\N	0.6	-00:05:00	00:26:00	Point San Quentin, 1.3 nmi. east of	CA
110346	Point San Quentin, 1.9 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0691_1	37.95	-122.44	:America/Los_Angeles	USA	knots	168	14	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	00:37:00	\N	1.3	00:26:00	\N	0.9	00:52:00	00:28:00	Point San Quentin, 1.9 miles east of	CA
110347	Point San Pedro, 0.55 nmi SE of (depth 20 ft), San Pablo Bay, California Current	NOS	PCT0701_1	37.97967	-122.43667	:America/Los_Angeles	USA	knots	192	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	00:30:00	\N	1.5	00:23:00	\N	1.3	00:28:00	00:39:00	Point San Pedro, 0.55 nmi. SE of	CA
110348	Point San Pedro, 0.55 nmi SE of (depth 40 ft), San Pablo Bay, California Current	NOS	PCT0701_2	37.97967	-122.43667	:America/Los_Angeles	USA	knots	205	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	02:25:00	\N	1.2	-00:11:00	\N	1.1	00:12:00	00:37:00	Point San Pedro, 0.55 nmi. SE of	CA
110349	Point San Pedro, 0.55 nmi SE of (depth 63 ft), San Pablo Bay, California Current	NOS	PCT0701_3	37.97967	-122.43667	:America/Los_Angeles	USA	knots	236	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	00:20:00	\N	0.8	00:19:00	\N	0.7	-00:14:00	00:35:00	Point San Pedro, 0.55 nmi. SE of	CA
110513	The Narrows, Alaska Current	NOS	PCT3081_1	56.36783	-132.10267	:America/Juneau	USA	knots	45	225	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:44:00	\N	1.4	00:23:00	\N	0.9	00:31:00	00:13:00	The Narrows	AK
110350	Pinole Point, 1.18 nmi west of (depth 19 ft), San Pablo Bay, California Current	NOS	PCT0706_1	38.008	-122.38967	:America/Los_Angeles	USA	knots	218	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	00:06:00	\N	0.6	-00:25:00	\N	0.5	00:07:00	00:07:00	Pinole Point, 1.18 nmi. west of	CA
110351	Pinole Point, 3.0 nmi WNW of (depth 8 ft), San Pablo Bay, California Current	NOS	PCT0711_1	38.02667	-122.42467	:America/Los_Angeles	USA	knots	185	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	00:03:00	\N	0.5	-00:19:00	\N	0.5	00:01:00	00:05:00	Pinole Point, 3.0 nmi. WNW of	CA
110352	Pinole Point, 1.42 nmi NNW of (depth 21 ft), San Pablo Bay, California Current	NOS	PCT0721_1	38.03383	-122.37917	:America/Los_Angeles	USA	knots	233	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	01:11:00	\N	0.8	00:51:00	\N	0.7	01:09:00	00:52:00	Pinole Point, 1.42 nmi. NNW of	CA
110353	Petaluma River approach (depth 4 ft), San Pablo Bay, California Current	NOS	PCT0731_1	38.07	-122.42	:America/Los_Angeles	USA	knots	186	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	-00:06:00	\N	0.4	-00:24:00	\N	0.4	-00:01:00	-00:15:00	Petaluma River approach	CA
110354	Petaluma River entrance (depth 7 ft), San Pablo Bay, California Current	NOS	PCT0736_1	38.1105	-122.493	:America/Los_Angeles	USA	knots	95	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	-01:00:00	\N	0.6	00:05:00	\N	0.5	00:10:00	-00:19:00	Petaluma River entrance	CA
110355	Wilson Point, 1.55 nmi north of (depth 10 ft), San Pablo Bay, California Current	NOS	PCT0741_1	38.0375	-122.1505	:America/Los_Angeles	USA	knots	253	71	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	01:08:00	\N	0.5	00:57:00	\N	0.5	00:54:00	01:10:00	Wilson Point, 1.55 nmi. north of	CA
110356	Wilson Point, 3.90 nmi NNW of (depth 4 ft), San Pablo Bay, California Current	NOS	PCT0746_1	38.0745	-122.3425	:America/Los_Angeles	USA	knots	237	46	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107043	00:22:00	\N	0.3	-00:44:00	\N	0.3	-00:08:00	00:08:00	Wilson Point, 3.90 nmi. NNW of	CA
110357	Davis Point, midchannel (depth 8 ft), San Pablo Bay, California Current	NOS	PCT0756_1	38.06333	-122.25833	:America/Los_Angeles	USA	knots	249	91	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108485	-00:38:00	\N	0.9	-00:28:00	\N	0.7	-00:13:00	-00:17:00	Davis Point, (midchannel)	CA
110358	Mare Island Strait (Buoy 4) (depth 20 ft), Carquinez Strait, California Current	NOS	PCT0766_1	38.07417	-122.24283	:America/Los_Angeles	USA	knots	177	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108485	-03:07:00	\N	0.2	-01:05:00	\N	0.3	-02:25:00	-01:23:00	Mare Island Strait (Buoy "4")	CA
110359	Martinez Marina, 0.65 nmi NW of (depth 20 ft), Carquinez Strait, California Current	NOS	PCT0781_1	38.033	-122.14967	:America/Los_Angeles	USA	knots	272	91	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108485	-00:02:00	\N	0.6	-00:03:00	\N	0.7	-00:12:00	00:10:00	Martinez Marina, 0.65 nmi. NW of	CA
110360	Martinez Marina, 0.50 nmi west of (depth 30 ft), Carquinez Strait, California Current	NOS	PCT0786_1	38.02867	-122.14867	:America/Los_Angeles	USA	knots	271	89	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108485	00:11:00	\N	0.7	-00:43:00	\N	0.7	-00:37:00	00:27:00	Martinez Marina, 0.50 nmi. west of	CA
110361	Martinez Marina, 0.61 nmi NNW of (depth 23 ft), Carquinez Strait, California Current	NOS	PCT0791_1	38.03633	-122.14467	:America/Los_Angeles	USA	knots	266	85	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108485	-01:00:00	\N	0.6	-00:35:00	\N	0.5	-00:56:00	-00:13:00	Martinez Marina, 0.61 nmi. NNW of	CA
110362	Army Pt. Pier Lt. 0.2 nmi SE of (depth 21 ft), Carquinez Strait, California Current	NOS	PCT0796_1	38.03883	-122.13367	:America/Los_Angeles	USA	knots	238	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108485	00:08:00	\N	1	-00:13:00	\N	0.7	-00:07:00	-00:16:00	Army Pt. Pier Lt. 0.2 nmi. SE of	CA
110363	Army Pt. Pier Lt. 0.2 nmi SE of (depth 41 ft), Carquinez Strait, California Current	NOS	PCT0796_2	38.03883	-122.13367	:America/Los_Angeles	USA	knots	245	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108485	00:03:00	\N	0.5	00:02:00	\N	0.5	-00:37:00	-00:06:00	Army Pt. Pier Lt. 0.2 nmi. SE of	CA
110364	1 mi inside west entrance (depth 22 ft), Montezuma Slough, Suisun Bay, California Current	NOS	PCT0801_1	38.14717	-122.05633	:America/Los_Angeles	USA	knots	191	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	-01:41:00	\N	0.5	-00:50:00	\N	0.4	-00:25:00	-00:32:00	1 mile inside west entrance	CA
110365	West entrance (depth 6 ft), Montezuma Slough, Suisun Bay, California Current	NOS	PCT0806_1	38.132	-122.058	:America/Los_Angeles	USA	knots	315	135	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	-01:01:00	\N	1	-01:06:00	\N	0.7	-00:11:00	-00:09:00	West entrance	CA
110366	1 mi inside entrance (depth 15 ft), Suisun Slough, Suisun Bay, California Current	NOS	PCT0811_1	38.13783	-122.08133	:America/Los_Angeles	USA	knots	202	34	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	-01:41:00	\N	0.3	-01:03:00	\N	0.3	-00:55:00	-00:46:00	1 mile inside entrance	CA
110367	Entrance (depth 3 ft), Suisun Slough, Suisun Bay, California Current	NOS	PCT0816_1	38.12117	-122.0675	:America/Los_Angeles	USA	knots	110	290	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	-00:57:00	\N	0.9	-01:10:00	\N	0.6	-00:30:00	-00:39:00	Entrance	CA
110368	0.5 nmi east of entrance (depth 4 ft), Suisun Slough, Suisun Bay, California Current	NOS	PCT0821_1	38.11883	-122.05333	:America/Los_Angeles	USA	knots	156	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	00:08:00	\N	0.3	-01:18:00	\N	0.4	-00:22:00	-00:21:00	0.5 nmi. east of entrance	CA
110369	Avon Pier, 0.15 nmi north of (depth 30 ft), Suisun Bay, California Current	NOS	PCT0831_1	38.05167	-122.09033	:America/Los_Angeles	USA	knots	237	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	00:11:00	\N	0.7	00:21:00	\N	0.7	00:05:00	00:22:00	Avon Pier, 0.15 nmi. north of	CA
110370	Pt. Edith, 1.7 nmi NNW of (depth 24 ft), Suisun Bay, California Current	NOS	PCT0836_1	38.07867	-122.08383	:America/Los_Angeles	USA	knots	219	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	00:07:00	\N	0.5	00:03:00	\N	0.6	00:04:00	00:23:00	Pt. Edith, 1.7 nmi. NNW of	CA
110371	Seal Island, south of (depth 24 ft), Suisun Bay, California Current	NOS	PCT0841_1	38.05333	-122.0495	:America/Los_Angeles	USA	knots	271	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	00:38:00	\N	0.6	-00:03:00	\N	0.5	00:14:00	00:54:00	Seal Island, south of	CA
110372	Roe Island, Gilbert Pt., 0.15 nmi NW of (depth 16 ft), Suisun Bay, California Current	NOS	PCT0851_1	38.07367	-122.02167	:America/Los_Angeles	USA	knots	283	105	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	01:02:00	\N	0.8	00:43:00	\N	0.5	01:07:00	00:50:00	Roe Island, Gilbert Pt., 0.15 nmi. NW of	CA
110373	Suisun Cutoff (depth 24 ft), Suisun Bay, California Current	NOS	PCT0856_1	38.08883	-122.00717	:America/Los_Angeles	USA	knots	298	126	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	01:05:00	\N	0.5	01:42:00	\N	0.5	01:40:00	01:27:00	Suisun Cutoff	CA
110374	Middle Point Lt., 0.18 nmi NNW of (depth 20 ft), Suisun Bay, California Current	NOS	PCT0861_1	38.0575	-121.99283	:America/Los_Angeles	USA	knots	271	97	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	00:56:00	\N	0.8	00:11:00	\N	0.8	00:39:00	00:57:00	Middle Point Lt., 0.18 nmi. NNW of	CA
110375	Middle Point Lt., 0.18 nmi NNW of (depth 38 ft), Suisun Bay, California Current	NOS	PCT0861_2	38.0575	-121.99283	:America/Los_Angeles	USA	knots	307	130	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	01:00:00	\N	0.5	00:21:00	\N	0.7	00:29:00	00:57:00	Middle Point Lt., 0.18 nmi. NNW of	CA
110376	Stake Point, 0.9 nmi NNW of (depth 4 ft), Suisun Bay, California Current	NOS	PCT0866_1	38.06467	-121.9555	:America/Los_Angeles	USA	knots	283	77	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	00:29:00	\N	0.4	00:45:00	\N	0.4	00:13:00	00:33:00	Stake Point, 0.9 nmi. NNW of	CA
110377	Simmons Pt., Chipps Is., 0.6 nmi ESE of (depth 12 ft), Suisun Bay, California Current	NOS	PCT0871_1	38.0645	-121.92167	:America/Los_Angeles	USA	knots	279	101	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	01:02:00	\N	1.2	01:05:00	\N	0.9	01:16:00	00:56:00	Simmons Pt., Chipps Is., 0.6 nmi. ESE of	CA
110378	Simmons Pt., Chipps Is., 0.6 nmi ESE of (depth 34 ft), Suisun Bay, California Current	NOS	PCT0871_2	38.0645	-121.92167	:America/Los_Angeles	USA	knots	284	84	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	01:13:00	\N	1	01:05:00	\N	0.7	01:12:00	00:54:00	Simmons Pt., Chipps Is., 0.6 nmi. ESE of	CA
110379	Spoonbill Creek, near bridge (depth 3 ft), Suisun Bay, California Current	NOS	PCT0876_1	38.05883	-121.90467	:America/Los_Angeles	USA	knots	285	105	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	00:37:00	\N	0.9	00:16:00	\N	0.8	00:11:00	01:02:00	Spoonbill Creek, near bridge	CA
110428	Entrance, 0.6 mi WNW of Westport, Grays Harbor, Washington Current	NOS	PCT1286_1	46.91467	-124.125	:America/Los_Angeles	USA	knots	238	44	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	00:00:00	\N	0.7	00:00:00	\N	1.2	00:00:00	00:06:00	Entrance, 0.6 mile WNW of Westport	WA
110380	Montezuma Slough, east end, near bridge (depth 6 ft), Suisun Bay, California Current	NOS	PCT0881_1	38.07783	-121.88383	:America/Los_Angeles	USA	knots	315	135	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	02:23:00	\N	0.8	02:14:00	\N	0.5	02:29:00	02:08:00	Montezuma Slough, east end, near bridge	CA
110381	New York Slough, 0.6 mi E of Pt. Emmet (depth 7 ft), Suisun Bay, California Current	NOS	PCT0886_1	38.0325	-121.8695	:America/Los_Angeles	USA	knots	295	110	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	01:44:00	\N	0.9	01:15:00	\N	0.6	01:38:00	01:36:00	New York Slough, 0.6miles E of Pt. Emmet	CA
110382	New York Slough, Winter Island (depth 15 ft), Suisun Bay, California Current	NOS	PCT0891_1	38.02833	-121.84633	:America/Los_Angeles	USA	knots	302	122	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	01:11:00	\N	0.8	00:34:00	\N	0.6	01:01:00	00:45:00	New York Slough, Winter Island	CA
110383	Entrance, 0.7 mi SW of Chain Island (depth 7 ft), Suisun Bay, California Current	NOS	PCT0896_1	38.05833	-121.8705	:America/Los_Angeles	USA	knots	212	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	01:31:00	\N	0.9	01:22:00	\N	0.6	01:26:00	01:33:00	Entrance, 0.7 mile SW of Chain Island	CA
110384	Point Sacramento, 0.3 mi NE of (depth 7 ft), Sacramento River, California Current	NOS	PCT0901_1	38.06667	-121.83333	:America/Los_Angeles	USA	knots	286	98	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	01:07:00	\N	0.5	00:54:00	\N	0.6	01:14:00	01:22:00	Point Sacramento, 0.3 mile NE OF	CA
110385	Sherman Island East, 0.2 mi north of (depth 14 ft), Sacramento River, California Current	NOS	PCT0906_1	38.05867	-121.80417	:America/Los_Angeles	USA	knots	270	94	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	00:30:00	\N	0.8	01:01:00	\N	0.5	01:21:00	01:08:00	Sherman Island East, 0.2 mile north of	CA
110386	Sherman Island East, 0.2 mi north of (depth 25 ft), Sacramento River, California Current	NOS	PCT0906_2	38.05867	-121.80417	:America/Los_Angeles	USA	knots	274	79	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	00:56:00	\N	0.6	01:01:00	\N	0.4	02:10:00	01:08:00	Sherman Island East, 0.2 mile north of	CA
110387	Pt. San Joaquin, 0.45 nmi ENE of (depth 18 ft), San Joaquin River, California Current	NOS	PCT0911_1	38.06167	-121.85	:America/Los_Angeles	USA	knots	282	108	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	01:14:00	\N	0.8	01:26:00	\N	0.8	01:23:00	01:29:00	Pt. San Joaquin, 0.45 nmi. ENE of	CA
110388	Pt. San Joaquin, 0.45 nmi ENE of (depth 33 ft), San Joaquin River, California Current	NOS	PCT0911_2	38.06167	-121.85	:America/Los_Angeles	USA	knots	275	112	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	00:55:00	\N	0.5	01:36:00	\N	0.6	01:22:00	01:24:00	Pt. San Joaquin, 0.45 nmi. ENE of	CA
110389	Point Beenar, 0.7 nmi north of (depth 5 ft), San Joaquin River, California Current	NOS	PCT0916_1	38.04217	-121.838	:America/Los_Angeles	USA	knots	349	163	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	01:22:00	\N	0.4	01:58:00	\N	0.3	02:34:00	01:39:00	Point Beenar, 0.7 nmi. north of	CA
110390	Point Beenar, 100 yd NE of (depth 14 ft), San Joaquin River, California Current	NOS	PCT0921_1	38.0325	-121.8355	:America/Los_Angeles	USA	knots	314	137	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	02:25:00	\N	0.9	01:58:00	\N	0.5	02:34:00	02:27:00	Point Beenar, 100 yds., NE of	CA
110391	Point Beenar, 100 yd NE of (depth 22 ft), San Joaquin River, California Current	NOS	PCT0921_2	38.0325	-121.8355	:America/Los_Angeles	USA	knots	324	142	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	02:26:00	\N	0.8	01:58:00	\N	0.4	02:28:00	02:30:00	Point Beenar, 100 yds., NE of	CA
110392	Antioch Point, 0.3 mi east of, San Joaquin River, California Current	NOS	PCT0926_1	38.03333	-121.81667	:America/Los_Angeles	USA	knots	304	128	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	02:01:00	\N	1	02:22:00	\N	0.8	02:21:00	01:58:00	Antioch Point, 0.3 mile east of	CA
110393	West Island Lt., 0.5 mi SE of (depth 5 ft), San Joaquin River, California Current	NOS	PCT0931_1	38.02117	-121.762	:America/Los_Angeles	USA	knots	270	90	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	02:09:00	\N	0.5	02:13:00	\N	0.2	02:18:00	01:56:00	West Island Lt., 0.5 mile SE of	CA
110394	Vulcan Island, 0.5 mi east of (depth 17 ft), San Joaquin River, California Current	NOS	PCT0936_1	37.98533	-121.39083	:America/Los_Angeles	USA	knots	315	135	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108782	03:30:00	\N	0.3	03:23:00	\N	0.4	03:37:00	03:24:00	Vulcan Island, 0.5 mile east of	CA
110395	North Bay Channel at Fairhaven (depth 13 ft), Humboldt Bay, California Current	NOS	PCT1021_1	40.78733	-124.19433	:America/Los_Angeles	USA	knots	216	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106659	00:07:00	\N	1.2	00:05:00	\N	0.8	00:18:00	-00:11:00	North Bay Channel at Fairhaven	CA
110396	North Bay Channel at Samoa Channel (depth 15 ft), Humboldt Bay, California Current	NOS	PCT1026_1	40.79617	-124.18733	:America/Los_Angeles	USA	knots	196	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106659	00:05:00	\N	0.9	00:08:00	\N	0.8	00:14:00	00:00:00	North Bay Channel at Samoa Channel	CA
110397	Coquille River entrance, Oregon Current	NOS	PCT1056_1	43.121700286865234	-124.4197006225586	:America/Los_Angeles	USA	knots	290	91	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	-00:36:00	\N	0.43	-00:26:00	\N	0.74	-00:24:00	-00:23:00	Coquille River entrance	OR
110398	Coos Bay entrance, Oregon Current	NOS	PCT1061_1	43.35499954223633	-124.34120178222656	:America/Los_Angeles	USA	knots	280	100	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	00:20:00	\N	0.79	00:17:00	\N	0.95	00:12:00	00:22:00	Coos Bay entrance	OR
110399	Umpqua River entrance, Oregon Current	NOS	PCT1066_1	43.67829895019531	-124.19329833984375	:America/Los_Angeles	USA	knots	190	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	00:30:00	\N	0.36	00:27:00	\N	0.42	00:22:00	00:32:00	Umpqua River entrance	OR
110400	Heceta Head, Oregon Current	NOS	PCT1071_1	44.13330078125	-124.13330078125	:America/Los_Angeles	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	00:50:00	\N	0.5	00:47:00	\N	0.67	00:42:00	00:52:00	Heceta Head	OR
110401	Yaquina Bay entrance, Oregon Current	NOS	PCT1076_1	44.61669921875	-124.06670379638672	:America/Los_Angeles	USA	knots	235	50	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	-01:54:00	\N	0.8	-00:05:00	\N	1.3	-00:44:00	-00:13:00	Yaquina Bay entrance	OR
110402	Yaquina Bay, Highway Bridge, Oregon Current	NOS	PCT1081_1	44.62329864501953	-124.05699920654297	:America/Los_Angeles	USA	knots	222	44	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	-00:59:00	\N	0.8	-00:50:00	\N	1	-01:49:00	-00:40:00	Yaquina Bay, Highway Bridge	OR
110403	Yaquina, Yaquina River, Yaquina Bay, Oregon Current	NOS	PCT1086_1	44.60200119018555	-124.01129913330078	:America/Los_Angeles	USA	knots	2	184	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	-00:39:00	\N	0.4	-00:50:00	\N	0.5	-00:47:00	-00:33:00	Yaquina, Yaquina River	OR
110404	Yaquina River, 1 mi below Toledo, Yaquina Bay, Oregon Current	NOS	PCT1091_1	44.60049819946289	-123.94170379638672	:America/Los_Angeles	USA	knots	132	332	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	-00:08:00	\N	0.5	-00:13:00	\N	0.7	00:05:00	00:14:00	Yaquina River, 1 mile below Toledo	OR
110405	Tillamook Bay entrance, Oregon Current	NOS	PCT1096_1	45.562198638916016	-123.93830108642578	:America/Los_Angeles	USA	knots	305	141	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	-00:35:00	\N	0.9	00:12:00	\N	1.6	00:16:00	-00:01:00	Tillamook Bay entrance	OR
110406	Sand Island Tower, 1 nmi SE of (midchannel) (depth 15 ft), Oregon Current	NOS	PCT1106_1	46.25283	-123.99083	:America/Los_Angeles	USA	knots	275	107	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	00:07:00	\N	1.6	01:03:00	\N	1.6	01:12:00	00:38:00	Sand Island Tower, 1nm SE of (midchannel)	OR
110407	Sand Island Tower, 0.9 nmi SE of (north channel) (depth 15 ft), Oregon Current	NOS	PCT1111_1	46.25783	-123.9945	:America/Los_Angeles	USA	knots	262	92	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	-00:44:00	\N	0.7	00:33:00	\N	1.1	00:39:00	00:27:00	Sand Island Tower, 0.9nm SE of (north channel)	OR
110408	Baker Bay entrance, E of Sand Island Tower (depth 23 ft), Oregon Current	NOS	PCT1116_1	46.262	-123.998	:America/Los_Angeles	USA	knots	202	8	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	00:14:00	\N	0.3	00:08:00	\N	0.6	00:28:00	00:20:00	Baker Bay entrance, E of Sand Island Tower	OR
110409	Clatsop Spit, NNE of (depth 15 ft), Oregon Current	NOS	PCT1121_1	46.24617	-123.99417	:America/Los_Angeles	USA	knots	289	114	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	00:20:00	\N	1.1	00:56:00	\N	1.4	00:45:00	00:56:00	Clatsop Spit, NNE of	OR
110410	Sand Island, SSE of (depth 12 ft), Oregon Current	NOS	PCT1126_1	46.2555	-123.968	:America/Los_Angeles	USA	knots	265	97	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	-00:32:00	\N	0.4	-00:25:00	\N	0.3	00:18:00	-00:16:00	Sand Island, SSE of	OR
110411	Youngs Bay Bridge (depth 9 ft), Oregon Current	NOS	PCT1146_1	46.17783	-123.86833	:America/Los_Angeles	USA	knots	320	135	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	00:28:00	\N	0.3	-00:14:00	\N	0.4	00:10:00	00:50:00	Youngs Bay Bridge	OR
110412	Hammond, northeast of ship channel (depth 15 ft), Oregon Current	NOS	PCT1151_1	46.21117	-123.9345	:America/Los_Angeles	USA	knots	307	134	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	00:01:00	\N	0.6	00:24:00	\N	0.4	00:57:00	00:26:00	Hammond, northeast of ship channel	OR
110413	McGowan, SSW of (depth 14 ft), Washington Current	NOS	PCT1156_1	46.2395	-123.91533	:America/Los_Angeles	USA	knots	282	107	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	00:23:00	\N	1.6	01:14:00	\N	0.9	01:28:00	00:21:00	McGowan, SSW of	WA
110414	Point Ellice, east of (depth 17 ft), Washington Current	NOS	PCT1161_1	46.24167	-123.84833	:America/Los_Angeles	USA	knots	254	65	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	00:11:00	\N	0.9	00:25:00	\N	0.8	00:55:00	00:51:00	Point Ellice, east of	WA
110415	Point Adams, NNE of (depth 14 ft), Oregon Current	NOS	PCT1166_1	46.22783	-123.9675	:America/Los_Angeles	USA	knots	297	139	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	01:11:00	\N	0.9	00:13:00	\N	0.8	01:16:00	00:26:00	Point Adams, NNE OF	OR
110416	Chinook Point, WSW of (depth 14 ft), Oregon Current	NOS	PCT1171_1	46.24217	-123.96417	:America/Los_Angeles	USA	knots	287	117	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	-00:21:00	\N	0.9	00:25:00	\N	1.2	00:29:00	00:45:00	Chinook Point, WSW of	OR
110417	Tongue Point, northwest of (depth 15 ft), Oregon Current	NOS	PCT1176_1	46.21917	-123.76667	:America/Los_Angeles	USA	knots	249	77	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	00:46:00	\N	0.9	01:09:00	\N	0.4	02:31:00	00:24:00	Tongue Point, northwest of	OR
110418	Woody Island Channel (depth 15 ft), Washington Current	NOS	PCT1186_1	46.2395	-123.67333	:America/Los_Angeles	USA	knots	298	118	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	01:15:00	\N	0.3	01:09:00	\N	0.5	01:12:00	01:36:00	Woody Island Channel	WA
110419	Woody Island Channel (off Seal Island) (depth 12 ft), Oregon Current	NOS	PCT1191_1	46.2175	-123.62917	:America/Los_Angeles	USA	knots	247	81	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	02:53:00	\N	0.4	01:53:00	\N	0.3	02:38:00	01:25:00	Woody Island Channel (off Seal Island)	OR
110420	Quinn Island, Prairie Channel (depth 8 ft), Washington Current	NOS	PCT1201_1	46.23717	-123.50333	:America/Los_Angeles	USA	knots	281	97	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	01:53:00	\N	0.5	01:52:00	\N	0.3	03:19:00	00:55:00	Quinn Island, Prairie Channel	WA
110421	Clifton Channel (depth 10 ft), Washington Current	NOS	PCT1206_1	46.21783	-123.46533	:America/Los_Angeles	USA	knots	301	118	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	02:17:00	\N	0.4	02:27:00	\N	0.3	03:41:00	01:21:00	Clifton Channel	WA
110422	Hunting Island, south of (depth 20 ft), Washington Current	NOS	PCT1216_1	46.20717	-123.40417	:America/Los_Angeles	USA	knots	295	125	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	03:20:00	\N	0.4	02:56:00	\N	0.2	04:20:00	01:38:00	Hunting Island, south of	WA
110423	Cathlamet Channel, SE of Nassa Point (depth 19 ft), Washington Current	NOS	PCT1231_1	46.15617	-123.315	:America/Los_Angeles	USA	knots	278	103	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	05:38:00	\N	0.6	03:23:00	\N	0.1	05:16:00	01:39:00	Cathlamet Channel, SE of Nassa Point	WA
110424	Walker Island, south of (depth 12 ft), Washington Current	NOS	PCT1251_1	46.14117	-123.04583	:America/Los_Angeles	USA	knots	330	148	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	05:09:00	\N	0.4	04:15:00	\N	0.2	05:46:00	02:41:00	Walker Island, south of	WA
110425	South Bend, Willapa River, Washington Current	NOS	PCT1271_1	46.66467	-123.80133	:America/Los_Angeles	USA	knots	270	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	-00:06:00	\N	0.5	00:20:00	\N	0.6	00:19:00	00:24:00	South Bend, Willapa River	WA
110426	Entrance, 0.2 mi south of north jetty, Grays Harbor, Washington Current	NOS	PCT1276_1	46.92633	-124.16133	:America/Los_Angeles	USA	knots	243	70	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	-00:47:00	\N	0.6	00:16:00	\N	1.3	-00:28:00	00:10:00	Entrance, 0.2 mile south of north jetty	WA
110427	Entrance, Point Chehalis Range, Grays Harbor, Washington Current	NOS	PCT1281_1	46.90833	-124.1555	:America/Los_Angeles	USA	knots	268	92	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	-00:21:00	\N	1.1	-00:11:00	\N	0.9	00:08:00	-00:22:00	Entrance, Point Chehalis Range	WA
110429	Entrance, 1.1 mi NW of Westport, Grays Harbor, Washington Current	NOS	PCT1296_1	46.91667	-124.13333	:America/Los_Angeles	USA	knots	233	78	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	-00:23:00	\N	0.9	-00:06:00	\N	0.9	00:04:00	-00:05:00	Entrance, 1.1 miles NW of Westport	WA
110430	Channel, 1.5 mi north of Westport, Grays Harbor, Washington Current	NOS	PCT1301_1	46.93333	-124.1	:America/Los_Angeles	USA	knots	226	36	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	-00:25:00	\N	0.6	-00:04:00	\N	0.7	-00:22:00	-00:04:00	Channel, 1.5 miles north of Westport	WA
110431	Channel, 2.1 mi NNE of Westport, Grays Harbor, Washington Current	NOS	PCT1306_1	46.93333	-124.08333	:America/Los_Angeles	USA	knots	249	21	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	00:02:00	\N	0.5	00:00:00	\N	0.6	-00:02:00	-00:02:00	Channel, 2.1 miles NNE of Westport	WA
110432	Westport, channel 0.4 mi NE of, Grays Harbor, Washington Current	NOS	PCT1316_1	46.91417	-124.10833	:America/Los_Angeles	USA	knots	310	113	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107044	-00:36:00	\N	0.7	-00:04:00	\N	1	-00:41:00	-00:19:00	Westport, channel 0.4 mile NE of	WA
110433	Quillayute River entrance, Washington Current	NOS	PCT1321_1	47.91667	-124.63333	:America/Los_Angeles	USA	knots	345	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108376	00:00:00	\N	0.5	-00:12:00	\N	0.1	-00:12:00	00:24:00	Quillayute River entrance	WA
110434	New Dungeness Light, 6 mi NNE of (depth 15 ft), Washington Current	NOS	PCT1401_1	48.26667022705078	-123.05000305175781	:America/Los_Angeles	USA	knots	255	50	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107639	00:39:00	\N	0.57	00:46:00	\N	0.48	00:59:00	00:13:00	New Dungeness Light, 6 miles NNE of	WA
110435	Cattle Point, 2.8 mi SSW of, San Juan Channel, Washington Current	NOS	PCT1416_1	48.400001525878906	-123	:America/Los_Angeles	USA	knots	187	46	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107697	-00:08:00	\N	0.12	01:07:00	\N	0.21	-00:36:00	01:10:00	Cattle Point, 2.8 miles SSW of	WA
110436	Smith Island, 1.4 mi SSW of, Strait of Juan de Fuca, Washington Current	NOS	PCT1451_1	48.29999923706055	-122.8499984741211	:America/Los_Angeles	USA	knots	280	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107594	00:30:00	\N	0.28	00:14:00	\N	0.25	00:33:00	00:03:00	Smith Island, 1.4 miles SSW of	WA
110437	Point Partridge, 3.7 mi west of, Strait of Juan de Fuca, Washington Current	NOS	PCT1466_1	48.23332977294922	-122.86666870117188	:America/Los_Angeles	USA	knots	250	140	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107594	00:47:00	\N	0.59	00:28:00	\N	0.14	01:46:00	-00:50:00	Point Partridge, 3.7 miles west of	WA
110438	Point Wilson, 0.8 mi east of, Admiralty Inlet, Washington Current	NOS	PCT1496_1	48.150001525878906	-122.73332977294922	:America/Los_Angeles	USA	knots	280	165	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107594	-00:49:00	\N	0.74	-00:09:00	\N	0.87	-00:14:00	00:01:00	Point Wilson, 0.8 mile east of	WA
110439	Marrowstone Point, 1.1 mi northwest of, Admiralty Inlet, Washington Current	NOS	PCT1511_1	48.116668701171875	-122.69999694824219	:America/Los_Angeles	USA	knots	275	100	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107594	-01:37:00	\N	0.37	-02:09:00	\N	0.46	-02:52:00	-01:28:00	Marrowstone Point, 1.1 miles northwest of	WA
110440	Agate Passage, north end, Puget Sound, Washington Current	NOS	PCT1636_1	47.722	-122.555	:America/Los_Angeles	USA	knots	32	230	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107594	-00:54:00	\N	0.51	-00:49:00	\N	0.42	-00:49:00	-00:44:00	Agate Passage, north end	WA
110441	Off Pleasant Beach, Rich Passage, Puget Sound, Washington Current	NOS	PCT1701_1	47.58332824707031	-122.53333282470703	:America/Los_Angeles	USA	knots	132	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107594	00:48:00	\N	0.79	-00:04:00	\N	0.46	00:25:00	00:10:00	Off Pleasant Beach	WA
110442	Eld Inlet entrance (depth 15 ft), Puget Sound, Washington Current	NOS	PCT1861_1	47.146331787109375	-122.9333267211914	:America/Los_Angeles	USA	knots	28	224	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107464	-00:10:00	\N	0.31	00:10:00	\N	0.54	-00:13:00	-00:12:00	Eld Inlet entrance	WA
110443	Hammersley Inlet, west of Skookum Point (depth 15 ft), Puget Sound, Washington Current	NOS	PCT1896_1	47.207000732421875	-123.03949737548828	:America/Los_Angeles	USA	knots	101	287	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107464	01:04:00	\N	0.82	01:30:00	\N	1.01	01:05:00	01:21:00	Hammersley Inlet, west of Skookum Point	WA
110444	Iceberg Point, 2.1 mi SSW of, Rosario Strait, Washington Current	NOS	PCT1966_1	48.383331298828125	-122.91667175292969	:America/Los_Angeles	USA	knots	260	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107694	-00:37:00	\N	0.4	-00:41:00	\N	0.7	-00:44:00	00:52:00	Iceberg Point, 2.1 miles SSW of	WA
110445	Colville Island, 1 mi SSE of, Rosario Strait, Washington Current	NOS	PCT1971_1	48.400001525878906	-122.8166732788086	:America/Los_Angeles	USA	knots	235	55	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107694	-00:20:00	\N	1	-00:05:00	\N	0.7	00:09:00	00:17:00	Colville Island, 1 mile SSE of	WA
110446	Burrows Bay, 0.5 mi east of Allan I, Rosario Strait, Washington Current	NOS	PCT2006_1	48.46282958984375	-122.68283081054688	:America/Los_Angeles	USA	knots	209	22	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107694	-01:10:00	\N	0.2	-01:04:00	\N	0.6	-03:11:00	-00:07:00	Burrows Bay, 0.5 mile east of Allan I	WA
110447	Green Point, 0.8 mi northwest of, Rosario Strait, Washington Current	NOS	PCT2026_1	48.504669189453125	-122.70616912841797	:America/Los_Angeles	USA	knots	190	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107871	-01:30:00	\N	0.75	-01:11:00	\N	1.09	-00:43:00	-00:34:00	Green Point, 0.8 mile northwest of	WA
110448	Frost-Willow Island, between, Rosario Strait, Washington Current	NOS	PCT2046_1	48.53916931152344	-122.8308334350586	:America/Los_Angeles	USA	knots	126	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107694	00:02:00	\N	0.4	00:38:00	\N	0.4	00:36:00	-00:10:00	Frost-Willow Island, between	WA
110449	Barnes Island, 0.8 mi southwest of, Rosario Strait, Washington Current	NOS	PCT2071_1	48.685829162597656	-122.78883361816406	:America/Los_Angeles	USA	knots	140	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107694	-00:19:00	\N	0.4	00:44:00	\N	0.4	00:27:00	-00:36:00	Barnes Island, 0.8 mile southwest of	WA
110450	Raccoon Point, 0.6 mi NNE of, Rosario Strait, Washington Current	NOS	PCT2076_1	48.706329345703125	-122.82917022705078	:America/Los_Angeles	USA	knots	101	286	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107694	-00:47:00	\N	0.4	-01:21:00	\N	0.4	-00:46:00	-02:10:00	Raccoon Point, 0.6 mile NNE of	WA
110451	Matia Island, 0.8 mi west of, Rosario Strait, Washington Current	NOS	PCT2086_1	48.74882888793945	-122.86582946777344	:America/Los_Angeles	USA	knots	206	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107694	-00:13:00	\N	0.7	-00:10:00	\N	0.7	00:12:00	-00:55:00	Matia Island, 0.8 mile west of	WA
110452	Huckleberry Island, 0.5 mi north of, Rosario Strait, Washington Current	NOS	PCT2106_1	48.54583	-122.56633	:America/Los_Angeles	USA	knots	253	6	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107734	-01:57:00	\N	0.5	-00:47:00	\N	0.5	-03:28:00	-00:25:00	Huckleberry Island, 0.5 mile north of	WA
110453	Towhead Island, 0.4 mi east of, Rosario Strait, Washington Current	NOS	PCT2126_1	48.6121711730957	-122.7021713256836	:America/Los_Angeles	USA	knots	125	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107734	-00:46:00	\N	0.32	00:08:00	\N	0.5	-02:06:00	01:42:00	Towhead Island, 0.4 mile east of	WA
110454	Puffin Island Light, 4.8 mi north of, Rosario Strait, Washington Current	NOS	PCT2166_1	48.82217025756836	-122.8083267211914	:America/Los_Angeles	USA	knots	210	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107734	-00:36:00	\N	0.63	00:25:00	\N	0.31	00:07:00	-00:06:00	Puffin Island Light, 4.8 miles north of	WA
110455	Kings Point, Lopez Island, 1 mi NNW of (depth 15 ft), Washington Current	NOS	PCT2191_1	48.48332977294922	-122.9558334350586	:America/Los_Angeles	USA	knots	185	20	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107697	00:38:00	\N	0.37	-00:28:00	\N	0.53	00:50:00	00:47:00	Kings Point, Lopez Island, 1 mile NNW of	WA
110456	Johns Island, 0.8 mi north of, Washington Current	NOS	PCT2266_1	48.68333053588867	-123.1500015258789	:America/Los_Angeles	USA	knots	350	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107697	00:51:00	\N	0.17	-00:52:00	\N	0.21	-00:16:00	00:26:00	Johns Island, 0.8 mile north of	WA
110457	Skipjack Island, 1.5 mi northwest of (depth 15 ft), Washington Current	NOS	PCT2276_1	48.7495002746582	-123.06082916259766	:America/Los_Angeles	USA	knots	290	35	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107697	01:14:00	\N	0.39	00:58:00	\N	0.29	01:16:00	01:28:00	Skipjack Island, 1.5 miles northwest of	WA
110458	Point Hammond, 1.1 mi northwest of (depth 15 ft), Washington Current	NOS	PCT2281_1	48.731998443603516	-123.02532958984375	:America/Los_Angeles	USA	knots	255	55	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107697	01:15:00	\N	0.65	00:44:00	\N	0.22	01:10:00	00:47:00	Point Hammond, 1.1 miles northwest of	WA
110459	Alden Point, Patos Island, 2 mi S of, Rosario Strait, Washington Current	NOS	PCT2286_1	48.75783157348633	-122.98033142089844	:America/Los_Angeles	USA	knots	185	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107734	-01:40:00	\N	1.66	-01:31:00	\N	0.6	-00:02:00	-00:46:00	Alden Point, Patos Island, 2 miles S of	WA
110460	Drayton Harbor entrance, Georgia Strait, Washington Current	NOS	PCT2301_1	48.99082946777344	-122.76782989501953	:America/Los_Angeles	USA	knots	313	133	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107734	-01:08:00	\N	0.79	-01:29:00	\N	0.63	-01:01:00	-01:11:00	Drayton Harbor Entrance	WA
110461	Cape Muzon, 4 mi south from, Dixon Entrance, Alaska Current	NOS	PCT2621_1	54.6	-132.68333	:America/Juneau	USA	knots	225	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:26:00	\N	1.2	-00:47:00	\N	0.8	-00:39:00	-00:57:00	Cape Muzon, 4 miles south from	AK
110462	Point Marsh, 5 mi south from, Dixon Entrance, Alaska Current	NOS	PCT2626_1	54.63333	-132.3	:America/Juneau	USA	knots	215	35	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:26:00	\N	1.1	-00:47:00	\N	0.7	-00:39:00	-00:57:00	Point Marsh, 5 miles south from	AK
110463	West Devil Rock, 2 mi north of, Dixon Entrance, Alaska Current	NOS	PCT2636_1	54.7	-131.6	:America/Juneau	USA	knots	215	35	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:21:00	\N	1.2	-00:42:00	\N	0.8	-00:34:00	-00:52:00	West Devil Rock, 2 miles north of	AK
110464	Barren Island Light, 2 mi south from, Dixon Entrance, Alaska Current	NOS	PCT2641_1	54.7	-131.35	:America/Juneau	USA	knots	220	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:16:00	\N	1.1	-00:37:00	\N	0.7	-00:29:00	-00:47:00	Barren Island Light, 2 miles south from	AK
110465	East Devil Rock, 1 mi north of, Dixon Entrance, Alaska Current	NOS	PCT2646_1	54.7	-131.08333	:America/Juneau	USA	knots	265	85	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:44:00	\N	1.1	00:23:00	\N	0.7	00:31:00	00:13:00	East Devil Rock, 1 mile north of	AK
110466	Between Dundas Island and Cape Fox, Dixon Entrance, Alaska Current	NOS	PCT2651_1	54.7	-130.83333	:America/Juneau	USA	knots	270	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:39:00	\N	1.4	00:18:00	\N	0.6	00:14:00	00:20:00	Between Dundas Island and Cape Fox	AK
110467	Tongass Islands, east of, Nakat Bay, Dixon Entrance, Alaska Current	NOS	PCT2656_1	54.78233	-130.73717	:America/Juneau	USA	knots	157	326	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-01:31:00	\N	0.6	-02:40:00	\N	0.3	-01:31:00	-01:38:00	Tongass Islands, east of, Nakat Bay	AK
110468	Point Phipp, Pearse Canal, Alaska Current	NOS	PCT2676_1	54.78333	-130.63333	:America/Juneau	USA	knots	245	65	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:44:00	\N	1.3	00:23:00	\N	0.9	00:31:00	00:13:00	Point Phipp	AK
110469	Narrows, Pearse Canal, Alaska Current	NOS	PCT2681_1	54.83467	-130.4855	:America/Juneau	USA	knots	225	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:47:00	\N	1.3	00:26:00	\N	0.9	00:34:00	00:31:00	Narrows	AK
110470	Blaine Point, Pearse Canal, Alaska Current	NOS	PCT2686_1	55.03333	-130.21667	:America/Juneau	USA	knots	205	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	1	-00:27:00	\N	0.6	-00:19:00	-00:37:00	Blaine Point	AK
110471	Dickens Point, Portland Canal, Alaska Current	NOS	PCT2711_1	55.15	-130.15	:America/Juneau	USA	knots	200	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:54:00	\N	0.7	00:33:00	\N	0.5	00:41:00	00:23:00	Dickens Point	AK
110472	White Point, Portland Canal, Alaska Current	NOS	PCT2716_1	55.56667	-130.11667	:America/Juneau	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:59:00	\N	0.5	00:38:00	\N	0.3	00:46:00	00:28:00	White Point	AK
110473	Camp Point, Portland Canal, Alaska Current	NOS	PCT2721_1	55.28333	-129.98333	:America/Juneau	USA	knots	180	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:01:00	\N	0.6	-00:22:00	\N	0.4	-00:14:00	-00:32:00	Camp Point	AK
110474	Miners Point, Portland Canal, Alaska Current	NOS	PCT2726_1	55.71667	-130.15	:America/Juneau	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:04:00	\N	0.4	-00:17:00	\N	0.3	-00:09:00	-00:27:00	Miners Point	AK
110475	Lion Point, Portland Canal, Alaska Current	NOS	PCT2731_1	55.88333	-130.03333	:America/Juneau	USA	knots	205	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:04:00	\N	0.2	-00:17:00	\N	0.2	-00:09:00	-00:27:00	Lion Point	AK
110476	Race Point, 0.7 mi ENE of, Revillagigedo Channel, Alaska Current	NOS	PCT2761_1	55.28583	-131.546	:America/Juneau	USA	knots	300	145	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:18:00	\N	0.2	00:22:00	\N	0.2	00:49:00	00:10:00	Race Point, 0.7 mile ENE of	AK
110477	Saxman Spire, 0.2 mi south of, Tongass Narrows, Alaska Current	NOS	PCT2781_1	55.3155	-131.60267	:America/Juneau	USA	knots	110	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:12:00	\N	0.3	-02:00:00	\N	0.2	-00:32:00	-02:02:00	Saxman Spire, 0.2 mile south of	AK
110479	Hotspur Island, 0.5 mi southeast of, Felice Strait, Alaska Current	NOS	PCT2806_1	54.96667	-131.48333	:America/Juneau	USA	knots	220	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:56:00	\N	0.4	-01:29:00	\N	0.3	-00:53:00	-01:06:00	Hotspur Island, 0.5 mile southeast of	AK
110480	Point Davidson, 1 mi south of, Felice Strait, Alaska Current	NOS	PCT2811_1	54.98333	-131.6	:America/Juneau	USA	knots	240	60	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:16:00	\N	1	-00:37:00	\N	0.6	-00:29:00	-00:47:00	Point Davidson, 1 mile south of	AK
110481	Harris Island, Felice Strait, Alaska Current	NOS	PCT2816_1	55	-131.53333	:America/Juneau	USA	knots	235	55	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:16:00	\N	1.8	-00:37:00	\N	1.3	-00:29:00	-00:47:00	Harris Island	AK
110482	Ajax Reef, Felice Strait, Alaska Current	NOS	PCT2821_1	55	-131.46667	:America/Juneau	USA	knots	275	95	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:11:00	\N	1.4	-00:32:00	\N	0.9	-00:24:00	-00:42:00	Ajax Reef	AK
110483	Snipe Island, Felice Strait, Alaska Current	NOS	PCT2831_1	55	-131.38333	:America/Juneau	USA	knots	250	70	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	1.8	-00:27:00	\N	1.3	-00:19:00	-00:37:00	Snipe Island	AK
110484	Grass Rock, Tamgas Harbor entrance, Felice Strait, Alaska Current	NOS	PCT2836_1	55.02167	-131.52233	:America/Juneau	USA	knots	195	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:11:00	\N	1.2	-00:32:00	\N	0.8	-00:24:00	-00:42:00	Grass Rock, Tamgas Harbor entrance	AK
110485	Indian Reef, Felice Strait, Alaska Current	NOS	PCT2841_1	55.03333	-131.35	:America/Juneau	USA	knots	210	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	1.6	-00:27:00	\N	1.1	-00:19:00	-00:37:00	Indian Reef	AK
110486	Customhouse Cove, 1 mi west of, Felice Strait, Alaska Current	NOS	PCT2866_1	55.1	-131.26667	:America/Juneau	USA	knots	200	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	1	-00:27:00	\N	0.6	-00:19:00	-00:37:00	Customhouse Cove, 1 mile west of	AK
110487	Hid Reef, 2.7 mi south of, Nichols Passage, Alaska Current	NOS	PCT2871_1	55.03333	-131.66667	:America/Juneau	USA	knots	190	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:12:00	\N	0.2	-00:54:00	\N	0.2	-00:18:00	-00:40:00	Hid Reef, 2.7 miles south of	AK
110488	Point McCartey Light, Nichols Passage, Alaska Current	NOS	PCT2876_1	55.11667	-131.7	:America/Juneau	USA	knots	220	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:11:00	\N	1	-00:32:00	\N	0.6	-00:24:00	-00:42:00	Point McCartey Light	AK
110489	Wharburton Island, Nichols Passage, Alaska Current	NOS	PCT2891_1	55.1335	-131.62867	:America/Juneau	USA	knots	205	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:11:00	\N	1.1	-00:32:00	\N	0.7	-00:24:00	-00:42:00	Wharburton Island	AK
110490	Driest Point, Nichols Passage, Alaska Current	NOS	PCT2896_1	55.18333	-131.6	:America/Juneau	USA	knots	175	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	0.9	-00:27:00	\N	0.6	-00:19:00	-00:37:00	Driest Point	AK
110491	Blank Point, Nichols Passage, Alaska Current	NOS	PCT2911_1	55.24867	-131.66933	:America/Juneau	USA	knots	190	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:01:00	\N	1.1	-00:22:00	\N	0.7	-00:14:00	-00:32:00	Blank Point	AK
110492	Point Sykes, Behm Canal, Alaska Current	NOS	PCT2921_1	55.2	-131.11667	:America/Juneau	USA	knots	220	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Point Sykes	AK
110493	Behm Narrows, Behm Canal, Alaska Current	NOS	PCT2936_1	55.91367	-131.532	:America/Juneau	USA	knots	264	62	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-02:58:00	\N	0.6	-03:07:00	\N	0.1	-01:41:00	-03:41:00	Behm Narrows	AK
110494	Helm Point, Behm Canal, Alaska Current	NOS	PCT2941_1	55.6	-131.83333	:America/Juneau	USA	knots	210	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	0.6	-00:27:00	\N	0.4	-00:19:00	-00:37:00	Helm Point	AK
110495	Guard Islands, 2 mi northwest of, Behm Canal, Alaska Current	NOS	PCT2946_1	55.46667	-131.9	:America/Juneau	USA	knots	200	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	0.7	-00:27:00	\N	0.4	-00:19:00	-00:37:00	Guard Islands, 2 miles northwest of	AK
110514	Channel Island, north of, Alaska Current	NOS	PCT3086_1	56.37517	-132.16967	:America/Juneau	USA	knots	320	140	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:44:00	\N	1	00:23:00	\N	0.6	00:31:00	00:13:00	Channel Island, north of	AK
110496	Grass Rock, 1 mi south of, Clarence Strait, Alaska Current	NOS	PCT2961_1	55	-131.55	:America/Juneau	USA	knots	235	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:22:00	\N	0.6	-00:29:00	\N	0.2	-00:24:00	-00:02:00	Grass Rock, 1 mile south of	AK
110497	Moira Rock, 2 mi east of, Clarence Strait, Alaska Current	NOS	PCT2966_1	55.08333	-131.93333	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:11:00	\N	0.7	-00:32:00	\N	0.5	-00:24:00	-00:42:00	Moira Rock, 2 miles east of	AK
110498	Skin Island, 3 mi east from, Clarence Strait, Alaska Current	NOS	PCT2991_1	55.3	-131.98333	:America/Juneau	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	0.7	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Skin Island, 3 miles east from	AK
110499	Guard Island Lighthouse, 5.1 mi SW of, Clarence Strait, Alaska Current	NOS	PCT3011_1	55.4	-132	:America/Juneau	USA	knots	164	6	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:20:00	\N	0.3	-00:03:00	\N	0.2	00:06:00	-00:12:00	Guard Island Lighthouse, 5.1 miles SW of	AK
110500	Guard Islands, 2 mi west of, Clarence Strait, Alaska Current	NOS	PCT3016_1	55.45	-131.95	:America/Juneau	USA	knots	190	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	0.7	-00:27:00	\N	0.4	-00:19:00	-00:37:00	Guard Islands, 2 miles west of	AK
110501	Ship Island, Clarence Strait, Alaska Current	NOS	PCT3021_1	55.6	-132.25	:America/Juneau	USA	knots	155	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:01:00	\N	0.7	-00:22:00	\N	0.5	-00:14:00	-00:32:00	Ship Island	AK
110502	Narrow Point, Clarence Strait, Alaska Current	NOS	PCT3026_1	55.78333	-132.41667	:America/Juneau	USA	knots	150	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:04:00	\N	0.7	-00:17:00	\N	0.5	-00:09:00	-00:27:00	Narrow Point	AK
110503	Mabel Island, 3 mi west from, Clarence Strait, Alaska Current	NOS	PCT3031_1	55.91667	-132.5	:America/Juneau	USA	knots	150	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:14:00	\N	0.7	-00:07:00	\N	0.5	00:01:00	-00:17:00	Mabel Island, 3 miles west from	AK
110504	Lincoln Rock Light, 1 mi west from, Clarence Strait, Alaska Current	NOS	PCT3036_1	56.05	-132.71667	:America/Juneau	USA	knots	155	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:24:00	\N	0.7	00:03:00	\N	0.5	00:11:00	-00:07:00	Lincoln Rock Light, 1 mile west from	AK
110505	McHenry Ledge, 1 mi north of, Ernest Sound, Alaska Current	NOS	PCT3041_1	55.8	-132.3	:America/Juneau	USA	knots	225	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:04:00	\N	1	-00:17:00	\N	0.6	-00:09:00	-00:27:00	McHenry Ledge, 1 mile north of	AK
110506	Vixen Point, 3 mi west of, Ernest Sound, Alaska Current	NOS	PCT3046_1	55.85	-132.18333	:America/Juneau	USA	knots	245	65	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:09:00	\N	0.8	-00:12:00	\N	0.5	-00:04:00	-00:22:00	Vixen Point, 3 miles west of	AK
110507	Eaton Point, Ernest Sound, Alaska Current	NOS	PCT3051_1	55.95283	-132.09	:America/Juneau	USA	knots	195	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:14:00	\N	1	-00:07:00	\N	0.7	00:01:00	-00:17:00	Eaton Point	AK
110508	Niblack Islands, Ernest Sound, Alaska Current	NOS	PCT3056_1	56.03333	-132.08333	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	1	-00:02:00	\N	0.7	00:06:00	-00:12:00	Niblack Islands	AK
110509	Blanche Rock, Ernest Sound, Alaska Current	NOS	PCT3061_1	56.08333	-132.08333	:America/Juneau	USA	knots	215	35	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:24:00	\N	1	00:03:00	\N	0.6	00:11:00	-00:07:00	Blanche Rock	AK
110510	Point Warde, Ernest Sound, Alaska Current	NOS	PCT3066_1	56.18333	-131.96667	:America/Juneau	USA	knots	225	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:29:00	\N	1	00:08:00	\N	0.6	00:16:00	-00:02:00	Point Warde	AK
110511	Blake Island, Alaska Current	NOS	PCT3071_1	56.223	-131.90883	:America/Juneau	USA	knots	150	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:34:00	\N	1.2	00:13:00	\N	0.8	00:21:00	00:03:00	Blake Island	AK
110512	Berg Bay, Alaska Current	NOS	PCT3076_1	56.34367	-132.00767	:America/Juneau	USA	knots	155	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:39:00	\N	1.1	00:18:00	\N	0.7	00:26:00	00:08:00	Berg Bay	AK
110516	Point Highfield, Alaska Current	NOS	PCT3096_1	56.5	-132.38333	:America/Juneau	USA	knots	275	95	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	0.7	-00:02:00	\N	0.5	00:06:00	-00:12:00	Point Highfield	AK
110517	Found Island, 1 mi northwest of, Zimovia Strait, Alaska Current	NOS	PCT3101_1	56.11667	-132.1	:America/Juneau	USA	knots	140	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:24:00	\N	0.8	00:03:00	\N	0.5	00:11:00	-00:07:00	Found Island, 1 mile northwest of	AK
110518	No Name Island, near Thoms Place, Zimovia Strait, Alaska Current	NOS	PCT3106_1	56.15	-132.15	:America/Juneau	USA	knots	150	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:29:00	\N	0.8	00:08:00	\N	0.5	00:16:00	-00:02:00	No Name Island, near Thoms Place	AK
110519	Village Islands, Zimovia Strait, Alaska Current	NOS	PCT3111_1	56.21667	-132.31667	:America/Juneau	USA	knots	135	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:29:00	\N	0.7	00:08:00	\N	0.5	00:16:00	-00:02:00	Village Islands	AK
110520	Young Rock, 2 mi south of, Zimovia Strait, Alaska Current	NOS	PCT3116_1	56.33333	-132.38333	:America/Juneau	USA	knots	345	165	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:34:00	\N	0.8	00:13:00	\N	0.5	00:21:00	00:03:00	Young Rock, 2 miles south of	AK
110521	East Point, east of, Zimovia Strait, Alaska Current	NOS	PCT3121_1	56.38333	-132.4	:America/Juneau	USA	knots	190	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	0.8	-00:02:00	\N	0.5	00:06:00	-00:12:00	East Point, east of	AK
110522	Wrangell Harbor, 1.6 mi west of, Zimovia Strait, Alaska Current	NOS	PCT3131_1	56.46667	-132.45	:America/Juneau	USA	knots	235	50	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:33:00	\N	0.4	03:36:00	\N	0.3	02:28:00	02:16:00	Wrangell Harbor, 1.6 miles west of	AK
110523	Key Reef, Clarence Strait, Alaska Current	NOS	PCT3141_1	56.16667	-132.83333	:America/Juneau	USA	knots	190	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108099	02:33:00	\N	0.5	02:19:00	\N	0.6	01:58:00	02:08:00	Key Reef	AK
110524	Snow Passage, north entrance, Clarence Strait, Alaska Current	NOS	PCT3151_1	56.3	-133.03333	:America/Juneau	USA	knots	282	122	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108099	00:40:00	\N	1.1	-00:50:00	\N	0.6	00:08:00	00:08:00	Snow Passage, north entrance	AK
110525	Kashevarof Passage, north entrance, Clarence Strait, Alaska Current	NOS	PCT3161_1	56.25	-133.05	:America/Juneau	USA	knots	335	155	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108099	00:23:00	\N	0.7	-00:03:00	\N	0.6	00:10:00	00:35:00	Kashevarof Passage, north entrance	AK
110526	Steamer Point, 1 mi west of, Stikine Strait, Alaska Current	NOS	PCT3176_1	56.21667	-132.73333	:America/Juneau	USA	knots	220	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108099	02:33:00	\N	0.7	02:19:00	\N	0.8	01:58:00	02:08:00	Steamer Point, 1 mile west of	AK
110527	Round Point, Stikine Strait, Alaska Current	NOS	PCT3181_1	56.28333	-132.61667	:America/Juneau	USA	knots	195	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108099	02:33:00	\N	0.5	02:19:00	\N	0.6	01:58:00	02:08:00	Round Point	AK
110528	South Craig Point, Stikine Strait, Alaska Current	NOS	PCT3186_1	56.38333	-132.6	:America/Juneau	USA	knots	190	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108099	02:38:00	\N	0.7	02:24:00	\N	0.8	02:03:00	02:13:00	South Craig Point	AK
110529	Vank Island, off Neal Point, Stikine Strait, Alaska Current	NOS	PCT3191_1	56.4425	-132.59183	:America/Juneau	USA	knots	215	35	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108099	02:38:00	\N	0.7	02:24:00	\N	0.8	02:03:00	02:13:00	Vank Island, off Neal Point	AK
110530	Cape Muzon, 5 mi east of, Cordova Bay, Alaska Current	NOS	PCT3196_1	54.66667	-132.53333	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:26:00	\N	0.6	-00:47:00	\N	0.4	-00:39:00	-00:57:00	Cape Muzon, 5 miles east of	AK
110531	Dewey Rocks, 2 mi west of, Cordova Bay, Alaska Current	NOS	PCT3201_1	54.75	-132.53333	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:21:00	\N	0.5	-00:42:00	\N	0.3	-00:34:00	-00:52:00	Dewey Rocks, 2 miles west of	AK
110532	Boat Rocks, 2 mi west of, Cordova Bay, Alaska Current	NOS	PCT3211_1	54.81667	-132.56667	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:21:00	\N	0.5	-00:42:00	\N	0.3	-00:34:00	-00:52:00	Boat Rocks, 2 miles west of	AK
110533	Webster Point, 1 mi west of, Cordova Bay, Alaska Current	NOS	PCT3221_1	54.96667	-132.63333	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:16:00	\N	0.8	-00:37:00	\N	0.5	-00:29:00	-00:47:00	Webster Point, 1 mile west of	AK
110534	Mellen Rock, 1 mi east of, Cordova Bay, Alaska Current	NOS	PCT3226_1	55.03333	-132.65	:America/Juneau	USA	knots	190	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:11:00	\N	1	-00:32:00	\N	0.6	-00:24:00	-00:42:00	Mellen Rock, 1 mile east of	AK
110535	Shoe Rock, 1 mi north of, Tlevak Strait, Alaska Current	NOS	PCT3231_1	54.96667	-132.73333	:America/Juneau	USA	knots	105	285	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:16:00	\N	0.8	-00:37:00	\N	0.5	-00:29:00	-00:47:00	Shoe Rock, 1 mile north of	AK
110536	Grand Island, 2 mi north of, Tlevak Strait, Alaska Current	NOS	PCT3236_1	55	-132.86667	:America/Juneau	USA	knots	115	295	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:11:00	\N	0.7	-00:32:00	\N	0.5	-00:24:00	-00:42:00	Grand Island, 2 miles north of	AK
110537	High Point, 1 mi east of, Tlevak Strait, Alaska Current	NOS	PCT3241_1	55.01667	-132.93333	:America/Juneau	USA	knots	160	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:11:00	\N	0.9	-00:32:00	\N	0.6	-00:24:00	-00:42:00	High Point, 1 mile east of	AK
110538	McFarland Islands, Tlevak Strait, Alaska Current	NOS	PCT3246_1	55.06667	-132.95	:America/Juneau	USA	knots	160	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	0.8	-00:27:00	\N	0.5	-00:19:00	-00:37:00	McFarland Islands	AK
110539	Corlies Islands, Tlevak Strait, Alaska Current	NOS	PCT3251_1	55.13333	-132.96667	:America/Juneau	USA	knots	165	345	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	0.7	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Corlies Islands	AK
110540	Sukkwan Narrows, Tlevak Strait, Alaska Current	NOS	PCT3256_1	55.19833	-132.824	:America/Juneau	USA	knots	130	323	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:09:00	\N	0.6	-00:45:00	\N	0.4	-00:29:00	-00:20:00	Sukkwan Narrows	AK
110541	The Sentinels, 1 mi west of, Tlevak Strait, Alaska Current	NOS	PCT3261_1	55.18333	-133.01667	:America/Juneau	USA	knots	155	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	0.8	-00:27:00	\N	0.5	-00:19:00	-00:37:00	The Sentinels, 1 mile west of	AK
110542	Halibut Nose, Tlevak Strait, Alaska Current	NOS	PCT3266_1	55.21667	-133.06667	:America/Juneau	USA	knots	350	170	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108072	-00:05:00	\N	0.3	-00:06:00	\N	0.2	00:08:00	00:01:00	Halibut Nose	AK
110543	Lively Islands, west of, Tlevak Strait, Alaska Current	NOS	PCT3271_1	55.23317	-133.09233	:America/Juneau	USA	knots	355	175	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108072	-00:20:00	\N	0.7	-00:21:00	\N	0.5	-00:07:00	-00:14:00	Lively Islands, west of	AK
110544	Meares Island, south of, Meares Passage, Alaska Current	NOS	PCT3281_1	55.25783	-133.18283	:America/Juneau	USA	knots	270	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	1	-00:27:00	\N	0.7	-00:19:00	-00:37:00	Meares Island, south of	AK
110545	Millar Rocks, Meares Passage, Alaska Current	NOS	PCT3291_1	55.2	-133.25	:America/Juneau	USA	knots	210	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:16:00	\N	0.6	-00:37:00	\N	0.4	-00:29:00	-00:47:00	Millar Rocks	AK
110546	Diver Islands, Meares Passage, Alaska Current	NOS	PCT3296_1	55.18333	-133.28333	:America/Juneau	USA	knots	205	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:16:00	\N	0.5	-00:37:00	\N	0.3	-00:29:00	-00:47:00	Diver Islands	AK
110547	Cape Flores, Ulloa Channel, Alaska Current	NOS	PCT3301_1	55.35	-133.31667	:America/Juneau	USA	knots	330	150	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	1.1	-00:27:00	\N	0.7	-00:19:00	-00:37:00	Cape Flores	AK
110548	Waterfall Cannery, Ulloa Channel, Alaska Current	NOS	PCT3311_1	55.3	-133.25	:America/Juneau	USA	knots	335	155	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	1	-00:27:00	\N	0.6	-00:19:00	-00:37:00	Waterfall Cannery	AK
110549	Cape Bartolome, 2 mi east of, Alaska Current	NOS	PCT3316_1	55.23333	-133.55	:America/Juneau	USA	knots	200	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:16:00	\N	0.6	-00:37:00	\N	0.4	-00:29:00	-00:47:00	Cape Bartolome, 2 miles east of	AK
110550	Point Arboleda, 1 mi west of, Alaska Current	NOS	PCT3326_1	55.31667	-133.48333	:America/Juneau	USA	knots	200	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:11:00	\N	0.7	-00:32:00	\N	0.4	-00:24:00	-00:42:00	Point Arboleda, 1 mile west of	AK
110551	Cabras Islands, 1 mi west of, Alaska Current	NOS	PCT3331_1	55.35	-133.41667	:America/Juneau	USA	knots	225	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:11:00	\N	0.6	-00:32:00	\N	0.4	-00:24:00	-00:42:00	Cabras Islands, 1 mile west of	AK
110552	Cape Flores, 1 mi north of, Alaska Current	NOS	PCT3336_1	55.36667	-133.3	:America/Juneau	USA	knots	235	55	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	0.7	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Cape Flores, 1 mile north of	AK
110553	Toti Island, 1.1 mi west of, Alaska Current	NOS	PCT3346_1	55.41667	-133.15	:America/Juneau	USA	knots	250	70	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Toti Island, 1.1 miles west of	AK
110554	Coronados Islands, 2 mi west of, Alaska Current	NOS	PCT3351_1	55.43333	-133.16667	:America/Juneau	USA	knots	205	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:01:00	\N	0.5	-00:22:00	\N	0.3	-00:14:00	-00:32:00	Coronados Islands, 2 miles west of	AK
110555	Craig Cannery, Alaska Current	NOS	PCT3356_1	55.48333	-133.15	:America/Juneau	USA	knots	190	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:01:00	\N	0.5	-00:22:00	\N	0.3	-00:14:00	-00:32:00	Craig Cannery	AK
110556	Tuxekan Passage, 0.2 mi S of Tuxekan, Alaska Current	NOS	PCT3456_1	55.88267	-133.24233	:America/Juneau	USA	knots	137	323	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-03:05:00	\N	0.2	-03:32:00	\N	0.3	-03:34:00	-01:42:00	Tuxekan Passage, 0.2 mile S of Tuxekan	AK
110557	Skookumchuck Pass, El Capitan Passage, Alaska Current	NOS	PCT3476_1	55.91467	-133.31233	:America/Juneau	USA	knots	207	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:03:00	\N	1	-00:19:00	\N	0.7	-00:06:00	-00:11:00	Skookumchuck Pass	AK
110558	Brockman Island, east of, El Capitan Passage, Alaska Current	NOS	PCT3481_1	55.96683	-133.30483	:America/Juneau	USA	knots	182	351	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:31:00	\N	0.2	00:43:00	\N	0.1	00:28:00	-00:13:00	Brockman Island, east of	AK
110559	Tenass Island, 0.3 mi SSW of, El Capitan Passage, Alaska Current	NOS	PCT3491_1	55.98667	-133.30483	:America/Juneau	USA	knots	220	39	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:05:00	\N	0.3	-00:48:00	\N	0.2	00:06:00	-01:18:00	Tenass Island, 0.3 mile  SSW of	AK
110560	The Narrows, west of, Aneskett Point, El Capitan Passage, Alaska Current	NOS	PCT3506_1	56.16017	-133.338	:America/Juneau	USA	knots	248	65	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	05:37:00	\N	0.1	05:37:00	\N	0.2	04:57:00	05:54:00	The Narrows, west of	AK
110561	Cora Point, 2 mi east of, Sumner Strait, Alaska Current	NOS	PCT3521_1	55.91667	-134.05	:America/Juneau	USA	knots	200	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:21:00	\N	1	-00:42:00	\N	0.1	-00:34:00	-00:52:00	Cora Point, 2 miles east of	AK
110562	Point St. Albans, 3 mi SSE of, Sumner Strait, Alaska Current	NOS	PCT3551_1	56.03333	-133.95	:America/Juneau	USA	knots	232	78	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:28:00	\N	0.4	-01:14:00	\N	0.2	-00:05:00	-01:05:00	Point St. Albans, 3 miles SSE of	AK
110563	Point St. Albans, 4 mi east of, Sumner Strait, Alaska Current	NOS	PCT3556_1	56.08333	-133.85	:America/Juneau	USA	knots	205	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:16:00	\N	1	-00:37:00	\N	0.1	-00:29:00	-00:46:00	Point St. Albans, 4 miles east of	AK
110564	Ruins Point, 2 mi west of, Sumner Strait, Alaska Current	NOS	PCT3561_1	56.06667	-133.75	:America/Juneau	USA	knots	175	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:49:00	\N	0.3	00:38:00	\N	0.2	00:15:00	-00:48:00	Ruins Point, 2 miles west of	AK
110565	Shakan Light, 2.8 mi WNW of, Sumner Strait, Alaska Current	NOS	PCT3576_1	56.16667	-133.7	:America/Juneau	USA	knots	182	19	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:36:00	\N	0.3	-01:48:00	\N	0.2	-01:21:00	-01:34:00	Shakan Light, 2.8 miles WNW of	AK
110566	Beauclerc Island Light, 1 mi east of, Sumner Strait, Alaska Current	NOS	PCT3616_1	56.25	-133.81667	:America/Juneau	USA	knots	205	70	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-01:28:00	\N	0.4	-00:41:00	\N	0.1	00:09:00	-01:30:00	Beauclerc Island Light, 1 mile east of	AK
110567	Sumner Island, 1.8 mi south of, Sumner Strait, Alaska Current	NOS	PCT3636_1	56.36667	-133.81667	:America/Juneau	USA	knots	240	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-01:16:00	\N	0.3	-03:33:00	\N	0.3	-02:39:00	-00:54:00	Sumner Island, 1.8 miles south of	AK
110568	Blaquiere Point, 1 mi SSW of, Sumner Strait, Alaska Current	NOS	PCT3681_1	56.55	-132.56667	:America/Juneau	USA	knots	240	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:23:00	\N	0.5	00:23:00	\N	0.3	-00:08:00	-00:20:00	Blaquiere Point, 1 mile SSW of	AK
110569	Southern entrance to Keku Strait, Alaska Current	NOS	PCT3701_1	56.56667	-133.71667	:America/Juneau	USA	knots	184	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:32:00	\N	0.6	00:13:00	\N	0.3	00:57:00	-00:25:00	Southern entrance to Keku Strait	AK
110570	Eagle Island, 0.5 mi southeast of, Keku Strait, Alaska Current	NOS	PCT3706_1	56.60733	-133.68217	:America/Juneau	USA	knots	130	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:43:00	\N	1	-00:24:00	\N	0.5	-00:04:00	-00:49:00	Eagle Island, 0.5 mile southeast of	AK
110571	Devils Elbow, Keku Strait, Alaska Current	NOS	PCT3711_1	56.63617	-133.6895	:America/Juneau	USA	knots	90	285	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:13:00	\N	0.8	-00:09:00	\N	0.8	-00:18:00	-00:41:00	Devils Elbow	AK
110572	Summit Island, west of, Keku Strait, Alaska Current	NOS	PCT3716_1	56.6765	-133.7325	:America/Juneau	USA	knots	10	185	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	01:46:00	\N	1.2	01:43:00	\N	0.7	01:48:00	02:10:00	Summit Island, west of	AK
110573	High Island, 1.1 mi south of, Keku Strait, Alaska Current	NOS	PCT3721_1	56.70233	-133.733	:America/Juneau	USA	knots	10	150	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:30:00	\N	0.5	00:40:00	\N	0.3	00:40:00	00:28:00	High Island, 1.1 miles south of	AK
110574	High Island, northwest of, Keku Strait, Alaska Current	NOS	PCT3726_1	56.75	-133.73333	:America/Juneau	USA	knots	325	210	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:18:00	\N	0.4	00:49:00	\N	0.3	00:07:00	00:34:00	High Island, northwest of	AK
110575	Cucumber Reef, 0.2 mi northwest of, Keku Strait, Alaska Current	NOS	PCT3731_1	56.79	-133.767	:America/Juneau	USA	knots	325	110	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:11:00	\N	0.8	00:16:00	\N	0.4	00:11:00	00:04:00	Cucumber Reef, 0.2 mile northwest of	AK
110576	Point Alexander, Wrangell Narrows, Alaska Current	NOS	PCT3741_1	56.51033	-132.95833	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	0.5	-00:02:00	\N	0.3	00:06:00	-00:12:00	Point Alexander	AK
110577	Point Deception, Wrangell Narrows, Alaska Current	NOS	PCT3746_1	56.53333	-132.96667	:America/Juneau	USA	knots	180	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	0.5	-00:02:00	\N	0.3	00:06:00	-00:12:00	Point Deception	AK
110578	Point Lockwood, Wrangell Narrows, Alaska Current	NOS	PCT3751_1	56.55583	-132.96183	:America/Juneau	USA	knots	180	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	1.4	-00:02:00	\N	0.9	00:06:00	-00:12:00	Point Lockwood	AK
110579	Spike Rock, Wrangell Narrows, Alaska Current	NOS	PCT3756_1	56.601	-132.976	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	2.1	-00:02:00	\N	1.5	00:06:00	-00:12:00	Spike Rock	AK
110580	Anchor Point, Wrangell Narrows, Alaska Current	NOS	PCT3766_1	56.6395	-132.93117	:America/Juneau	USA	knots	225	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	1.6	-00:02:00	\N	1.1	00:06:00	-00:12:00	Anchor Point	AK
110581	Vexation Point, Woody Island, Wrangell Narrows, Alaska Current	NOS	PCT3771_1	56.65783	-132.927	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	1.2	-00:02:00	\N	0.8	00:06:00	-00:12:00	Vexation Point, Woody Island	AK
110582	Green Point, Wrangell Narrows, Alaska Current	NOS	PCT3781_1	56.7	-132.95	:America/Juneau	USA	knots	5	185	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:24:00	\N	0.5	00:03:00	\N	0.3	00:11:00	-00:07:00	Green Point	AK
110583	Mountain Point, Wrangell Narrows, Alaska Current	NOS	PCT3786_1	56.73333	-132.95	:America/Juneau	USA	knots	345	165	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:34:00	\N	1	00:13:00	\N	0.6	00:21:00	00:03:00	Mountain Point	AK
110584	Blunt Point, Wrangell Narrows, Alaska Current	NOS	PCT3791_1	56.77833	-132.97933	:America/Juneau	USA	knots	340	160	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:44:00	\N	1.6	00:23:00	\N	1.1	00:31:00	00:13:00	Blunt Point	AK
110585	Turn Point, Wrangell Narrows, Alaska Current	NOS	PCT3796_1	56.80783	-132.9835	:America/Juneau	USA	knots	40	220	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:44:00	\N	1.8	00:23:00	\N	1.4	00:31:00	00:13:00	Turn Point	AK
110586	Prolewy Rocks, Wrangell Narrows, Alaska Current	NOS	PCT3806_1	56.82233	-132.94833	:America/Juneau	USA	knots	60	240	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:44:00	\N	1.6	00:23:00	\N	1.1	00:31:00	00:13:00	Prolewy Rocks	AK
110587	Cosmos Point, 0.5 mi east of, Frederick Sound, Alaska Current	NOS	PCT3811_1	56.66667	-132.6	:America/Juneau	USA	knots	305	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:42:00	\N	0.2	01:15:00	\N	0.1	01:55:00	00:25:00	Cosmos Point, 0.5 mile east of	AK
110588	The Brothers, 2 mi east of, Stephens Passage, Alaska Current	NOS	PCT3826_1	57.3	-133.71667	:America/Juneau	USA	knots	205	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:24:00	\N	0.5	00:03:00	\N	0.3	00:11:00	-00:07:00	The Brothers, 2 miles east of	AK
110589	Point Gambier, 2 mi east of, Stephens Passage, Alaska Current	NOS	PCT3841_1	57.43333	-133.76667	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:29:00	\N	0.2	00:08:00	\N	0.2	00:16:00	-00:02:00	Point Gambier, 2 miles east of	AK
110590	Point Hugh, Stephens Passage, Alaska Current	NOS	PCT3846_1	57.61667	-133.76667	:America/Juneau	USA	knots	175	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:34:00	\N	0.5	00:13:00	\N	0.3	00:21:00	00:03:00	Point Hugh	AK
110591	Midway Island, Stephens Passage, Alaska Current	NOS	PCT3866_1	57.83333	-133.83333	:America/Juneau	USA	knots	155	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:34:00	\N	0.5	00:13:00	\N	0.3	00:21:00	00:03:00	Midway Island	AK
110592	Point Arden, Stephens Passage, Alaska Current	NOS	PCT3876_1	58.15	-134.13333	:America/Juneau	USA	knots	175	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:39:00	\N	0.5	00:18:00	\N	0.3	00:26:00	00:08:00	Point Arden	AK
110593	0.2 mi off Flat Point, Taku Inlet, Stephens Passage, Alaska Current	NOS	PCT3896_1	58.33333	-134.05	:America/Juneau	USA	knots	200	39	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:07:00	\N	0.5	00:11:00	\N	0.2	00:48:00	-00:12:00	0.2 mile off Flat Point	AK
110594	0.2 mi off Taku Point, Taku Inlet, Stephens Passage, Alaska Current	NOS	PCT3901_1	58.4	-134.01667	:America/Juneau	USA	knots	203	357	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:08:00	\N	0.4	00:34:00	\N	0.4	00:53:00	00:10:00	0.2 mile off Taku Point	AK
110595	Douglas, north of (depth 15 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3916_1	58.283	-134.39367	:America/Juneau	USA	knots	144	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	01:32:00	\N	0.2	00:44:00	\N	0.1	02:12:00	00:11:00	Douglas, north of	AK
110596	Douglas, north of (depth 25 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3916_2	58.283	-134.39367	:America/Juneau	USA	knots	136	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	01:08:00	\N	0.3	00:41:00	\N	0.1	01:33:00	00:27:00	Douglas, north of	AK
110597	Juneau Harbor, S of (depth 25 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3921_1	58.29117	-134.407	:America/Juneau	USA	knots	102	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	01:05:00	\N	0.3	02:03:00	\N	0.1	03:19:00	00:34:00	Juneau Harbor, S of	AK
110598	West Juneau, NE of (depth 25 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3936_1	58.29633	-134.4245	:America/Juneau	USA	knots	137	314	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	01:21:00	\N	0.2	00:49:00	\N	0.1	00:24:00	00:32:00	West Juneau, NE of	AK
110599	Aurora Basin, SW of (depth 15 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3946_1	58.305	-134.44083	:America/Juneau	USA	knots	163	289	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:51:00	\N	0.4	00:34:00	\N	0.2	01:01:00	00:10:00	Aurora Basin, SW of	AK
110600	Point Sherman, WSW of, Lynn Canal, Alaska Current	NOS	PCT4011_1	58.84667	-135.197	:America/Juneau	USA	knots	175	341	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108362	-00:26:00	\N	0.1	-00:07:00	\N	0.3	-01:20:00	00:35:00	Point Sherman, WSW of	AK
110601	Hazy Islands, Chatham Strait, Alaska Current	NOS	PCT4056_1	55.88333	-134.6	:America/Juneau	USA	knots	205	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Hazy Islands	AK
110602	Cape Ommaney Light, 5 mi east of, Chatham Strait, Alaska Current	NOS	PCT4061_1	56.16667	-134.51667	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:01:00	\N	0.5	-00:22:00	\N	0.3	-00:14:00	-00:32:00	Cape Ommaney Light, 5 miles east of	AK
110603	Port Walter Light, 3 mi east of, Chatham Strait, Alaska Current	NOS	PCT4066_1	56.38333	-134.53333	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:04:00	\N	0.7	-00:17:00	\N	0.5	-00:09:00	-00:27:00	Port Walter Light, 3 miles east of	AK
110604	Point Ellis, 4 mi west of, Chatham Strait, Alaska Current	NOS	PCT4071_1	56.56667	-134.45	:America/Juneau	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:09:00	\N	0.7	-00:12:00	\N	0.5	-00:04:00	-00:22:00	Point Ellis, 4 miles west of	AK
110605	Kingsmill Point Light, 3 mi west of, Chatham Strait, Alaska Current	NOS	PCT4076_1	56.83333	-134.51667	:America/Juneau	USA	knots	175	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:14:00	\N	1	-00:07:00	\N	0.6	00:01:00	-00:17:00	Kingsmill Point Light, 3 miles west of	AK
110606	Point Gardner Light, 2 mi west of, Chatham Strait, Alaska Current	NOS	PCT4081_1	57.01667	-134.66667	:America/Juneau	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Point Gardner Light, 2 miles west of	AK
110607	Point Caution, 3 mi west of, Chatham Strait, Alaska Current	NOS	PCT4086_1	57.25	-134.73333	:America/Juneau	USA	knots	175	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:24:00	\N	1	00:03:00	\N	0.6	00:11:00	-00:07:00	Point Caution, 3 miles west of	AK
110608	Point Thatcher, 3 mi east of, Chatham Strait, Alaska Current	NOS	PCT4091_1	57.41667	-134.73333	:America/Juneau	USA	knots	160	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:24:00	\N	0.7	00:03:00	\N	0.5	00:11:00	-00:07:00	Point Thatcher, 3 miles east of	AK
110609	Danger Point Light, 3 mi west of, Chatham Strait, Alaska Current	NOS	PCT4101_1	57.51667	-134.7	:America/Juneau	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:29:00	\N	0.7	00:08:00	\N	0.5	00:16:00	-00:02:00	Danger Point Light, 3 miles west of	AK
110610	Turn Point, Kootznahoo Inlet, Chatham Strait, Alaska Current	NOS	PCT4106_1	57.5	-134.58333	:America/Juneau	USA	knots	285	105	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	01:09:00	\N	2.9	00:48:00	\N	2.2	00:56:00	00:38:00	Turn Point, Kootznahoo Inlet	AK
110611	South Passage Point, 3 mi east of, Chatham Strait, Alaska Current	NOS	PCT4111_1	57.76667	-134.83333	:America/Juneau	USA	knots	355	175	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:29:00	\N	0.7	00:08:00	\N	0.5	00:16:00	-00:02:00	South Passage Point, 3 miles east of	AK
110612	Point Augusta, ESE of (depth 70 ft), Chatham Strait, Alaska Current	NOS	PCT4116_1	58.025	-134.87333	:America/Juneau	USA	knots	164	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:54:00	\N	0.3	-00:04:00	\N	0.2	-00:02:00	00:01:00	Point Augusta, ESE of	AK
110613	Biorka Channel, Sitka Sound, Alaska Current	NOS	PCT4131_1	56.83333	-135.5	:America/Juneau	USA	knots	232	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:13:00	\N	0.2	00:20:00	\N	0.1	00:47:00	00:15:00	Biorka Channel	AK
110614	Sitka Harbor, channel off Harbor Island, Sitka Sound, Alaska Current	NOS	PCT4166_1	57.05	-135.33333	:America/Juneau	USA	knots	156	333	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-01:16:00	\N	0.2	-01:17:00	\N	0.1	-00:58:00	-02:02:00	Sitka Harbor, channel off Harbor Island	AK
110615	West Channel (narrows), Krestof Sound, Alaska Current	NOS	PCT4171_1	57.15	-135.58333	:America/Juneau	USA	knots	64	242	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:30:00	\N	0.5	-00:51:00	\N	0.4	-00:43:00	-01:01:00	West Channel (narrows)	AK
110616	East Channel (narrows), Krestof Sound, Alaska Current	NOS	PCT4176_1	57.16667	-135.55	:America/Juneau	USA	knots	229	51	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:23:00	\N	0.7	-00:32:00	\N	0.4	-00:30:00	-00:48:00	East Channel (narrows)	AK
110617	Allan Pt., 1.5 mi W of, Nakwasina Passage, Alaska Current	NOS	PCT4191_1	57.25	-135.43333	:America/Juneau	USA	knots	82	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:40:00	\N	0.8	-01:06:00	\N	0.6	-01:06:00	-00:59:00	Allan Pt., 1.5mile W of, Nakwasina Passage	AK
110618	Wyvill Reef, Neva Strait, Alaska Current	NOS	PCT4211_1	57.26667	-135.58333	:America/Juneau	USA	knots	323	150	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:13:00	\N	0.7	-00:30:00	\N	0.5	-00:27:00	-00:04:00	Wyvill Reef	AK
110619	Highwater Island, west of, Neva Strait, Alaska Current	NOS	PCT4216_1	57.28333	-135.6	:America/Juneau	USA	knots	330	144	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:34:00	\N	0.7	-00:29:00	\N	0.3	-00:15:00	-00:11:00	Highwater Island, west of	AK
110620	Sea Rock, 1 mi north of, Salisbury Sound, Alaska Current	NOS	PCT4236_1	57.35	-135.88333	:America/Juneau	USA	knots	245	65	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Sea Rock, 1 mile north of	AK
110621	Kalinin Point, 1 mi north of, Salisbury Sound, Alaska Current	NOS	PCT4241_1	57.35	-135.8	:America/Juneau	USA	knots	260	80	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Kalinin Point, 1 mile north of	AK
110622	Sinitsin Island, Salisbury Sound, Alaska Current	NOS	PCT4246_1	57.35	-135.76667	:America/Juneau	USA	knots	275	95	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	-00:06:00	\N	0.7	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Sinitsin Island	AK
110623	Point Siroi, Peril Strait, Alaska Current	NOS	PCT4266_1	57.41667	-135.58333	:America/Juneau	USA	knots	283	59	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108072	00:15:00	\N	0.4	00:11:00	\N	0.3	00:31:00	00:23:00	Point Siroi	AK
110624	Middle Point, Peril Strait, Alaska Current	NOS	PCT4271_1	57.43333	-135.58333	:America/Juneau	USA	knots	187	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108072	-00:06:00	\N	0.4	-00:37:00	\N	0.2	-00:09:00	-00:35:00	Middle Point	AK
110625	Otstoia Island Light, 1 mi north of, Peril Strait, Alaska Current	NOS	PCT4286_1	57.58333	-135.45	:America/Juneau	USA	knots	100	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Otstoia Island Light, 1 mile north of	AK
110626	Nismeni Point, 1 mi north of, Peril Strait, Alaska Current	NOS	PCT4291_1	57.58333	-135.41667	:America/Juneau	USA	knots	105	285	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Nismeni Point, 1 mile north of	AK
110627	Peschani Point, 1 mi east of, Peril Strait, Alaska Current	NOS	PCT4296_1	57.53333	-135.3	:America/Juneau	USA	knots	145	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Peschani Point, 1 mile east of	AK
110628	Point Elizabeth, 1 mi northeast of, Peril Strait, Alaska Current	NOS	PCT4301_1	57.51667	-135.26667	:America/Juneau	USA	knots	135	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Point Elizabeth, 1 mile northeast of	AK
110629	Point Benham, 1 mi east of, Peril Strait, Alaska Current	NOS	PCT4306_1	57.48333	-135.18333	:America/Juneau	USA	knots	130	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Point Benham, 1 mile east of	AK
110630	False Linderberg Head, 1 mi south of, Peril Strait, Alaska Current	NOS	PCT4311_1	57.45	-135.08333	:America/Juneau	USA	knots	125	305	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	False Linderberg Head, 1 mile south of	AK
110631	Lindenberg Head, Peril Strait, Alaska Current	NOS	PCT4316_1	57.45	-135.03333	:America/Juneau	USA	knots	100	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Lindenberg Head	AK
110632	Eva Islands, Peril Strait, Alaska Current	NOS	PCT4321_1	57.45	-134.93333	:America/Juneau	USA	knots	95	275	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:24:00	\N	0.6	00:03:00	\N	0.4	00:11:00	-00:07:00	Eva Islands	AK
110633	Fairway Island, Peril Strait, Alaska Current	NOS	PCT4326_1	57.45	-134.88333	:America/Juneau	USA	knots	85	265	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:24:00	\N	1	00:03:00	\N	0.6	00:11:00	-00:07:00	Fairway Island	AK
110634	Morris Reef, south of, Peril Strait, Alaska Current	NOS	PCT4331_1	57.45	-134.81667	:America/Juneau	USA	knots	95	275	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:24:00	\N	0.7	00:03:00	\N	0.5	00:11:00	-00:07:00	Morris Reef, south of	AK
110635	North Inian Pass, middle, Cross Sound, Alaska Current	NOS	PCT4361_1	58.28329849243164	-136.38330078125	:America/Juneau	USA	knots	260	75	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108362	-00:51:00	\N	2.3	00:15:00	\N	2.9	-00:22:00	-00:37:00	North Inian Pass, middle	AK
110636	Claybluff Point Light, 3.5 nmi south of (depth 75 ft), Icy Bay, Alaska Current	NOS	PCT4406_1	59.91	-141.595	:America/Anchorage	USA	knots	209	104	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-03:20:00	\N	0.2	-02:09:00	\N	0.2	-03:02:00	-03:14:00	Claybluff Point Light, 3.5 nmi. south of	AK
110637	Claybluff Point Light, 2.3 nmi SE of (depth 206 ft), Icy Bay, Alaska Current	NOS	PCT4411_1	59.94667	-141.52	:America/Anchorage	USA	knots	215	30	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-03:14:00	\N	0.1	-02:44:00	\N	0.1	-03:10:00	-03:17:00	Claybluff Point Light, 2.3 nmi. SE of	AK
110638	Carson Creek entrance, 1.4 nmi ESE of (depth 15 ft), Icy Bay, Alaska Current	NOS	PCT4416_1	59.98333	-141.47	:America/Anchorage	USA	knots	164	71	IGNORE VELOCITIES	Velocities for this station should be disregarded--use times only.	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-02:09:00	\N	0.001	-00:36:00	\N	0.2	-04:48:00	-00:20:00	Carson Creek Entrance, 1.4 nmi. ESE of	AK
110639	Carson Creek entrance, 3.3 nmi SE of (depth 78 ft), Icy Bay, Alaska Current	NOS	PCT4421_1	59.97	-141.41333	:America/Anchorage	USA	knots	232	67	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-02:03:00	\N	0.2	-01:45:00	\N	0.3	-02:49:00	-01:03:00	Carson Creek Entrance, 3.3 nmi. SE of	AK
110640	Carson Creek entrance, 2.4 nmi ESE of (depth 50 ft), Icy Bay, Alaska Current	NOS	PCT4426_1	59.98667	-141.43667	:America/Anchorage	USA	knots	244	54	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-02:06:00	\N	0.3	-01:38:00	\N	0.2	-03:00:00	-02:24:00	Carson Creek Entrance, 2.4 nmi. ESE of	AK
110641	Wingham Island, off northeast corner, Controller Bay, Alaska Current	NOS	PCT4436_1	60.05	-144.38333	:America/Anchorage	USA	knots	288	68	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	01:06:00	\N	0.6	01:11:00	\N	0.5	00:42:00	00:46:00	Wingham Island, off northeast corner	AK
110642	Kanak Island, southeast of, Controller Bay, Alaska Current	NOS	PCT4441_1	60.08333	-144.3	:America/Anchorage	USA	knots	255	67	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108066	00:53:00	\N	1	00:37:00	\N	0.5	00:58:00	00:38:00	Kanak Island, southeast of	AK
110643	Cape Hinchinbrook, SW of, Hinchinbrook I (depth 20 ft), Alaska Current	NOS	PCT4466_1	60.18667	-146.74833	:America/Anchorage	USA	knots	180	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107985	00:33:00	\N	1.4	-01:12:00	\N	0.6	00:10:00	-00:58:00	Cape Hinchinbrook, SW of, Hinchinbrook I	AK
110644	Bear Cape and Zaikof Point, between (depth 70 ft), Prince William Sound, Alaska Current	NOS	PCT4471_1	60.31167	-146.81333	:America/Anchorage	USA	knots	162	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107985	-00:30:00	\N	1.8	00:39:00	\N	0.6	01:30:00	-01:01:00	Bear Cape and Zaikof Point, between	AK
110645	Montague Strait, NW of Pt. Woodcock (depth 70 ft), Prince William Sound, Alaska Current	NOS	PCT4506_1	59.94783	-147.86117	:America/Anchorage	USA	knots	223	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107985	00:35:00	\N	0.9	-00:17:00	\N	0.5	00:53:00	-00:40:00	Montague Strait, NW of Pt. Woodcock	AK
110646	Bainbridge Passage (mid-passage) (depth 21 ft), Prince William Sound, Alaska Current	NOS	PCT4546_1	60.12667	-148.20383	:America/Anchorage	USA	knots	208	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107985	-01:19:00	\N	2.7	-01:48:00	\N	2.4	-00:40:00	-02:10:00	Bainbridge Passage (mid-passage)	AK
110647	Johnston Point, 7 nmi northwest of (depth 71 ft), Prince William Sound, Alaska Current	NOS	PCT4596_1	60.55167	-146.78333	:America/Anchorage	USA	knots	204	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107985	-00:18:00	\N	0.7	-01:29:00	\N	0.2	00:54:00	-03:35:00	Johnston Point, 7 nmi. northwest of	AK
110648	Salmo Point, Hawkins I., 1.2 mi SE of, Orca Bay, Alaska Current	NOS	PCT4811_1	60.6	-145.75	:America/Anchorage	USA	knots	20	160	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107985	00:30:00	\N	0.5	00:55:00	\N	0.3	00:34:00	00:58:00	Salmo Point, Hawkins I., 1.2 miles SE of	AK
110649	Cape Douglas, northeast of (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4831_1	58.94083	-152.89	:America/Anchorage	USA	knots	167	312	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106343	00:21:00	\N	0.2	00:08:00	\N	0.2	00:36:00	00:09:00	Cape Douglas, northeast of	AK
110650	Ushagat Island, northwest of (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4841_1	59.00617	-152.56333	:America/Anchorage	USA	knots	117	283	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106343	00:20:00	\N	0.3	-00:02:00	\N	0.2	00:17:00	00:32:00	Ushagat Island, northwest of	AK
110651	Ushagat Island, north of (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4846_1	59.08333	-152.255	:America/Anchorage	USA	knots	121	292	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106343	00:26:00	\N	0.5	00:44:00	\N	0.9	-00:18:00	01:26:00	Ushagat Island, north of	AK
110652	Augustine Island, northwest of (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4886_1	59.40833	-153.62033	:America/Anchorage	USA	knots	229	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106343	03:42:00	\N	0.6	03:08:00	\N	0.3	03:13:00	02:40:00	Augustine Island, northwest of	AK
110653	Chinitna Point, southeast of (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4896_1	59.57167	-152.825	:America/Anchorage	USA	knots	209	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106343	01:54:00	\N	0.8	01:55:00	\N	0.7	01:51:00	02:11:00	Chinitna Point, southeast of	AK
110654	Iniskin Bay, Cook Inlet, Alaska Current	NOS	PCT4916_1	59.66667	-153.45	:America/Anchorage	USA	knots	179	358	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106343	-00:29:00	\N	0.7	-00:32:00	\N	0.5	-00:32:00	-00:21:00	Iniskin Bay	AK
110655	Kachemak Bay entrance (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4926_1	59.555	-151.79667	:America/Anchorage	USA	knots	210	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106343	00:00:00	\N	0.4	-00:11:00	\N	0.3	00:37:00	-00:22:00	Kachemak Bay Entrance	AK
110656	Kachemak Bay, west of (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4931_1	59.56667	-152.27167	:America/Anchorage	USA	knots	188	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106343	01:01:00	\N	1	00:46:00	\N	0.9	01:01:00	01:08:00	Kachemak Bay, west of	AK
110657	Anchor Point, 5 mi northwest of (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4941_1	59.85167	-152.00833	:America/Anchorage	USA	knots	198	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106358	-00:35:00	\N	0.5	-01:04:00	\N	0.6	-01:09:00	-00:50:00	Anchor Point, 5 miles northwest of	AK
110658	Anchor Point, WNW of (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4946_1	59.85917	-152.205	:America/Anchorage	USA	knots	197	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106358	-00:04:00	\N	0.6	-00:49:00	\N	0.6	-00:39:00	-00:40:00	Anchor Point, WNW of	AK
110659	Cape Starichkof, northwest of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT4956_1	59.9675	-151.95083	:America/Anchorage	USA	knots	199	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106358	-00:36:00	\N	0.6	-01:22:00	\N	0.5	-00:47:00	-01:02:00	Cape Starichkof, northwest of	AK
110660	Chisik Island, 5 nmi east of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT4966_1	60.12667	-152.40167	:America/Anchorage	USA	knots	197	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106358	-00:11:00	\N	0.5	-01:01:00	\N	0.5	-00:50:00	-00:44:00	Chisik Island, 5 nmi. east of	AK
110661	Tuxedni Channel (south entrance) (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT4971_1	60.09667	-152.57417	:America/Anchorage	USA	knots	150	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106358	-01:41:00	\N	0.3	-01:30:00	\N	0.5	-01:35:00	-01:35:00	Tuxedni Channel (South Entrance)	AK
110662	Ninilchik Harbor, northwest of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT4976_1	60.13333	-151.93417	:America/Anchorage	USA	knots	212	29	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106358	-00:18:00	\N	0.8	-00:10:00	\N	0.6	-00:05:00	-00:19:00	Ninilchik Harbor, northwest of	AK
110663	Redoubt Point, southeast of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT4981_1	60.23167	-152.26417	:America/Anchorage	USA	knots	198	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106358	00:07:00	\N	0.6	-00:06:00	\N	0.5	-00:11:00	-00:10:00	Redoubt Point, southeast of	AK
110664	Cape Kasilof, 3 mi west of, Cook Inlet, Alaska Current	NOS	PCT5006_1	60.36667	-151.46667	:America/Anchorage	USA	knots	206	22	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106358	-00:41:00	\N	0.5	-01:47:00	\N	0.7	-01:27:00	-00:10:00	Cape Kasilof, 3 miles west of	AK
110665	Kenai, 6 mi southwest of, Cook Inlet, Alaska Current	NOS	PCT5011_1	60.48333	-151.43333	:America/Anchorage	USA	knots	193	21	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106358	-00:39:00	\N	0.6	-01:03:00	\N	0.6	-00:25:00	-00:23:00	Kenai, 6 miles southwest of	AK
110666	Kenai City Wharf, Cook Inlet, Alaska Current	NOS	PCT5016_1	60.55	-151.23333	:America/Anchorage	USA	knots	300	130	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106358	-00:56:00	\N	0.3	-01:45:00	\N	0.1	-01:18:00	-02:24:00	Kenai City Wharf	AK
110667	West Foreland, 1 nmi east of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5046_1	60.73917	-151.64167	:America/Anchorage	USA	knots	171	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106358	01:17:00	\N	1	-00:15:00	\N	0.9	00:54:00	00:07:00	West Foreland, 1 nmi. east of	AK
110668	East Foreland, 1.5 nmi west of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5056_1	60.72333	-151.46667	:America/Anchorage	USA	knots	195	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106358	00:20:00	\N	0.8	00:09:00	\N	0.7	00:24:00	00:19:00	East Foreland, 1.5 nmi. west of	AK
110669	Middle Ground Shoal, southeast of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5066_1	60.84583	-151.33667	:America/Anchorage	USA	knots	231	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106358	00:37:00	\N	1	-00:08:00	\N	0.8	00:45:00	00:05:00	Middle Ground Shoal, southeast of	AK
110670	North Foreland, southeast of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5071_1	61.00333	-151.07833	:America/Anchorage	USA	knots	221	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106327	-00:10:00	\N	0.7	-00:24:00	\N	0.7	-00:49:00	-00:41:00	North Foreland, southeast of	AK
110671	Moose Point, NNW of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5076_1	61.01583	-150.7	:America/Anchorage	USA	knots	237	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106327	-00:54:00	\N	0.5	-01:17:00	\N	0.6	-00:46:00	-00:46:00	Moose Point, NNW of	AK
110672	Moose Point, northwest of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5081_1	61.0775	-150.75	:America/Anchorage	USA	knots	255	86	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106327	-00:10:00	\N	0.5	-01:06:00	\N	0.6	-00:33:00	-00:35:00	Moose Point, northwest of	AK
110673	Point Possession, WNW of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5091_1	61.05	-150.46167	:America/Anchorage	USA	knots	246	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106327	-00:43:00	\N	0.6	-01:01:00	\N	0.7	-00:34:00	-00:27:00	Point Possession, WNW of	AK
110674	Point Possession, northwest of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5096_1	61.0875	-150.47167	:America/Anchorage	USA	knots	255	87	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106327	-00:57:00	\N	0.5	-00:31:00	\N	0.7	-00:22:00	-00:05:00	Point Possession, northwest of	AK
110675	Fire Island, west of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5111_1	61.1625	-150.5125	:America/Anchorage	USA	knots	258	93	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106327	00:14:00	\N	0.7	00:12:00	\N	0.8	00:05:00	00:21:00	Fire Island, west of	AK
110676	Point Woronzof, southwest of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5126_1	61.18717	-150.0625	:America/Anchorage	USA	knots	225	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106327	02:20:00	\N	0.3	-00:23:00	\N	0.6	00:15:00	00:31:00	Point Woronzof, southwest of	AK
110677	Point Woronzof, west of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5131_1	61.207	-150.06117	:America/Anchorage	USA	knots	225	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106327	-00:24:00	\N	0.6	-00:32:00	\N	0.6	00:11:00	00:26:00	Point Woronzof, west of	AK
110678	Anchorage, west of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5141_1	61.22783	-149.94833	:America/Anchorage	USA	knots	234	81	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106327	-00:20:00	\N	0.6	-00:09:00	\N	0.8	00:25:00	00:42:00	Anchorage, west of	AK
110679	Anchorage, 0.2 mi offshore (depth 15 ft), Cook Inlet, Alaska Current	NOS	PCT5146_1	61.225	-149.90633	:America/Anchorage	USA	knots	207	28	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106327	-01:22:00	\N	0.5	-00:55:00	\N	0.3	-02:59:00	-01:05:00	Anchorage, 0.2 mile offshore	AK
110680	Anchorage Shipdock, northwest of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5151_1	61.24583	-149.90833	:America/Anchorage	USA	knots	195	28	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106327	-00:28:00	\N	0.8	00:16:00	\N	0.9	00:41:00	00:43:00	Anchorage Shipdock, northwest of	AK
110681	Cairn Point, northwest of (east side) (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5161_1	61.26717	-149.90083	:America/Anchorage	USA	knots	192	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106327	00:07:00	\N	0.8	00:35:00	\N	0.7	00:38:00	00:38:00	Cairn Point, northwest of (east side)	AK
110682	Cairn Point, northwest of (west side) (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5166_1	61.26717	-149.89333	:America/Anchorage	USA	knots	198	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106327	-00:35:00	\N	0.7	00:24:00	\N	0.8	00:36:00	00:39:00	Cairn Point, northwest of (west side)	AK
110683	Knik Arm Mud Flats, south of (depth 10 ft), Cook Inlet, Alaska Current	NOS	PCT5186_1	61.33167	-149.79367	:America/Anchorage	USA	knots	241	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	106327	-00:26:00	\N	0.6	-00:18:00	\N	0.6	00:48:00	-00:02:00	Knik Arm Mud Flats, south of	AK
110684	Popof Strait, Shumagin Islands, Alaska Current	NOS	PCT5406_1	55.33333	-160.51667	:America/Anchorage	USA	knots	199	357	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-02:11:00	\N	0.2	-02:05:00	\N	0.1	-02:32:00	-01:28:00	Popof Strait	AK
110685	Unga Strait (1.4 mi N of Unga Spit), Shumagin Islands, Alaska Current	NOS	PCT5411_1	55.43333	-160.73333	:America/Anchorage	USA	knots	114	282	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	05:06:00	\N	0.1	05:42:00	\N	0.5	05:24:00	05:24:00	Unga Strait (1.4 miles N of Unga Spit)	AK
110686	Amak Island, 5 mi north of, Alaska Current	NOS	PCT5426_1	55.5	-163.1667022705078	:America/Nome	USA	knots	139	337	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108621	05:09:00	\N	0.23	05:30:00	\N	0.21	05:04:00	05:02:00	Amak Island, 5 miles north of	AK
110687	Amak Island, 5 mi southeast of, Alaska Current	NOS	PCT5431_1	55.349998474121094	-163.01669311523438	:America/Nome	USA	knots	200	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108621	04:35:00	\N	0.23	04:45:00	\N	0.21	04:36:00	04:22:00	Amak Island, 5 miles southeast of	AK
110688	Otter Point, off of, north side (depth 15 ft), Unimak Island, Alaska Current	NOS	PCT5441_1	55.06669998168945	-163.78329467773438	:America/Nome	USA	knots	258	89	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108621	03:53:00	\N	0.27	03:36:00	\N	0.24	03:48:00	03:25:00	Otter Point, off of, north side	AK
110689	Bechevin Bay, off Rocky Point, Isanotski Strait, Alaska Current	NOS	PCT5451_1	54.983299255371094	-163.4333038330078	:America/Nome	USA	knots	139	331	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108621	00:02:00	\N	0.46	-00:26:00	\N	0.47	-00:53:00	00:04:00	Bechevin Bay, off Rocky Point	AK
110690	Unimak Pass, 2.4 mi N of Tanginak I, Aleutian Islands, Alaska Current	NOS	PCT5481_1	54.23333	-165.3	:America/Nome	USA	knots	144	298	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108560	-00:38:00	\N	0.6	-00:10:00	\N	0.5	00:27:00	-01:13:00	Unimak Pass, 2.4 miles N of Tanginak I	AK
110691	Ugamak Strait (north end), Aleutian Islands, Alaska Current	NOS	PCT5511_1	54.2	-164.91667	:America/Nome	USA	knots	122	322	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108560	00:22:00	\N	0.8	00:12:00	\N	1.3	00:39:00	00:45:00	Ugamak Strait (North end)	AK
110692	Umnak Pass, south approach, Aleutian Islands, Alaska Current	NOS	PCT5546_1	53.25	-167.91667	:America/Nome	USA	knots	181	341	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	00:54:00	\N	1.2	-00:15:00	\N	0.4	00:25:00	00:04:00	Umnak Pass, south approach	AK
110693	Umnak Pass, northwest of Ship Rock, Aleutian Islands, Alaska Current	NOS	PCT5561_1	53.38333	-167.85	:America/Nome	USA	knots	218	52	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	00:00:00	\N	1.3	-00:14:00	\N	0.7	01:04:00	-00:01:00	Umnak Pass, northwest of Ship Rock	AK
110694	Fenimore Rock, 1.2 mi southwest of, Aleutian Islands, Alaska Current	NOS	PCT5611_1	51.96667	-175.56667	:America/Adak	USA	knots	140	10	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	00:10:00	\N	1.2	-00:06:00	\N	0.6	00:47:00	-00:50:00	Fenimore Rock, 1.2 miles southwest of	AK
110695	Igitkin Pass, 0.8 mi N of Tanager Pt, Aleutian Islands, Alaska Current	NOS	PCT5616_1	51.95	-175.86667	:America/Adak	USA	knots	245	40	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	00:19:00	\N	0.8	00:35:00	\N	0.6	01:40:00	00:02:00	Igitkin Pass, 0.8 mile N of Tanager Pt	AK
110696	Chugul Pass, 0.8 mi SW of Tanager Pt, Aleutian Islands, Alaska Current	NOS	PCT5621_1	51.93333	-175.88333	:America/Adak	USA	knots	160	325	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	-00:09:00	\N	0.6	-00:08:00	\N	0.3	-00:42:00	00:39:00	Chugul Pass, 0.8 mile SW of Tanager Pt	AK
110697	Chugul Pass, 2 mi NE of Cape Ruin, Aleutian Islands, Alaska Current	NOS	PCT5626_1	51.93333	-175.93333	:America/Adak	USA	knots	150	335	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	00:59:00	\N	0.6	01:37:00	\N	0.3	02:33:00	00:33:00	Chugul Pass, 2 miles NE of Cape Ruin	AK
110698	Chugul Pass, 0.5 mi NE of Cape Ruin, Aleutian Islands, Alaska Current	NOS	PCT5631_1	51.91667	-175.96667	:America/Adak	USA	knots	120	305	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	01:12:00	\N	0.7	00:34:00	\N	0.2	00:51:00	01:09:00	Chugul Pass, 0.5 mile NE of Cape Ruin	AK
110699	Umak Pass, off Narrows Point, Aleutian Islands, Alaska Current	NOS	PCT5636_1	51.85	-176.06667	:America/Adak	USA	knots	130	305	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	00:17:00	\N	0.9	00:19:00	\N	0.6	00:44:00	00:29:00	Umak Pass, off Narrows Point	AK
110700	Little Tanaga Strait, off Tana Pt, Aleutian Islands, Alaska Current	NOS	PCT5641_1	51.81667	-176.23333	:America/Adak	USA	knots	130	320	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	00:20:00	\N	1.2	00:04:00	\N	0.5	00:21:00	00:15:00	Little Tanaga Strait, off Tana Pt	AK
110701	Kagalaska Strait, off Galas Point, Aleutian Islands, Alaska Current	NOS	PCT5646_1	51.8	-176.41667	:America/Adak	USA	knots	175	310	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	00:56:00	\N	1.1	-00:01:00	\N	0.8	-00:11:00	00:41:00	Kagalaska Strait, off Galas Point	AK
110702	Adak Strait, 4 mi ENE of Naga Point, Aleutian Islands, Alaska Current	NOS	PCT5656_1	51.78333	-177	:America/Adak	USA	knots	195	10	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	02:01:00	\N	0.7	01:16:00	\N	0.4	01:09:00	00:43:00	Adak Strait, 4 miles ENE of Naga Point	AK
110703	Adak Strait, off Argonne Point, Aleutian Islands, Alaska Current	NOS	PCT5661_1	51.8	-176.95	:America/Adak	USA	knots	200	10	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	-00:40:00	\N	0.6	01:02:00	\N	0.5	-01:49:00	-00:05:00	Adak Strait, off Argonne Point	AK
110704	Kanaga Pass, 0.3 mi NW of Annoy Rock, Aleutian Islands, Alaska Current	NOS	PCT5666_1	51.71667	-177.8	:America/Adak	USA	knots	195	0	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	01:11:00	\N	0.9	02:38:00	\N	0.5	02:30:00	00:42:00	Kanaga Pass, 0.3 mile NW of Annoy Rock	AK
110705	Kanaga Pass, 2.2 mi NE of Annoy Rock, Aleutian Islands, Alaska Current	NOS	PCT5671_1	51.75	-177.75	:America/Adak	USA	knots	225	20	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	00:32:00	\N	0.9	02:16:00	\N	0.5	02:07:00	00:19:00	Kanaga Pass, 2.2 miles NE of Annoy Rock	AK
110706	Ogliuga Island, pass east of, Delarof Is, Aleutian Islands, Alaska Current	NOS	PCT5681_1	51.61667	-178.6	:America/Adak	USA	knots	220	36	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	-00:10:00	\N	0.2	-00:26:00	\N	0.1	-00:16:00	-00:56:00	Ogliuga Island, pass East of, Delarof Is	AK
110707	Ulak Pass, Delarof Islands, Aleutian Islands, Alaska Current	NOS	PCT5691_1	51.31667	-179.03333	:America/Adak	USA	knots	125	326	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	01:30:00	\N	0.9	01:40:00	\N	0.5	02:03:00	01:25:00	Ulak Pass, Delarof Islands	AK
110708	Krysi Pass, Rat Islands, Aleutian Islands, Alaska Current	NOS	PCT5721_1	51.85	178.11667	:America/Adak	USA	knots	210	40	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	01:28:00	\N	0.9	01:38:00	\N	0.5	02:06:00	00:57:00	Krysi Pass, Rat Islands	AK
110709	Sea Lion Pass, Rat Islands, Aleutian Islands, Alaska Current	NOS	PCT5726_1	51.9	177.9	:America/Adak	USA	knots	195	12	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	108584	01:45:00	\N	0.9	01:45:00	\N	0.5	02:09:00	00:53:00	Sea Lion Pass, Rat Islands	AK
110710	Cape Lieskof, 3 mi west of, Aleutian Islands, Alaska Current	NOS	PCT5741_1	55.75	-162.2	:America/Nome	USA	knots	248	56	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-04:53:00	\N	0.3	-04:39:00	\N	0.3	-05:39:00	-04:38:00	Cape Lieskof, 3 miles west of	AK
110711	Entrance Point, 3 mi west of, Port Moller, Alaska Current	NOS	PCT5746_1	56	-160.65	:America/Anchorage	USA	knots	2	174	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-04:34:00	\N	0.8	-04:28:00	\N	0.7	-05:04:00	-04:06:00	Entrance Point, 3 miles west of	AK
110712	Entrance Point, Port Moller, Alaska Current	NOS	PCT5751_1	55.98333	-160.58333	:America/Anchorage	USA	knots	0	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-05:27:00	\N	0.6	-04:53:00	\N	0.5	-04:57:00	-05:06:00	Entrance Point	AK
110713	Harbor Point, Port Moller, Alaska Current	NOS	PCT5756_1	55.91667	-160.6	:America/Anchorage	USA	knots	335	158	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-04:26:00	\N	0.8	-04:03:00	\N	0.4	-04:28:00	-04:59:00	Harbor Point	AK
110714	Hague Channel, east of Doe Point, Alaska Current	NOS	PCT5761_1	55.9	-160.76667	:America/Anchorage	USA	knots	33	220	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-05:21:00	\N	0.6	-04:39:00	\N	0.9	-05:59:00	-04:23:00	Hague Channel, east of Doe Point	AK
110715	Johnston Channel, off Halftide Rock, Alaska Current	NOS	PCT5766_1	55.83333	-160.78333	:America/Anchorage	USA	knots	337	179	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-04:24:00	\N	0.5	-04:45:00	\N	0.5	-04:27:00	-05:15:00	Johnston Channel, off Halftide Rock	AK
110716	Port Heiden, Alaska Current	NOS	PCT5771_1	56.98333	-158.88333	:America/Anchorage	USA	knots	233	67	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-01:15:00	\N	0.4	-01:05:00	\N	0.4	-02:23:00	-01:14:00	Port Heiden	AK
110717	Morakas Point, Naknek River, Kvichak Bay, Alaska Current	NOS	PCT5781_1	58.73333	-156.93333	:America/Anchorage	USA	knots	294	111	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	01:15:00	\N	0.9	01:05:00	\N	0.5	02:01:00	00:04:00	Morakas Point, Naknek River	AK
110718	Cape Constantine, 4 mi southeast of, Alaska Current	NOS	PCT5791_1	58.33333	-158.76667	:America/Anchorage	USA	knots	238	59	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-01:52:00	\N	0.7	-01:38:00	\N	0.6	-02:08:00	-01:05:00	Cape Constantine, 4 miles Southeast of	AK
110719	Protection Point, 2.5 mi east of, Alaska Current	NOS	PCT5796_1	58.5	-158.61667	:America/Anchorage	USA	knots	180	13	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-01:04:00	\N	1	-01:25:00	\N	1	-00:44:00	-00:40:00	Protection Point, 2.5 miles east of	AK
110720	Nushagak Bay entrance, Alaska Current	NOS	PCT5801_1	58.56667	-158.41667	:America/Anchorage	USA	knots	180	343	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-00:23:00	\N	1	00:03:00	\N	1	-00:59:00	00:19:00	Nushagak Bay entrance	AK
110721	Etolin Point, 8.5 mi west of, Alaska Current	NOS	PCT5806_1	58.63333	-158.58333	:America/Anchorage	USA	knots	173	352	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	00:05:00	\N	1.2	00:13:00	\N	0.9	-00:19:00	00:08:00	Etolin Point, 8.5 miles west of	AK
110722	Clarks Point, 1 mi west of, Alaska Current	NOS	PCT5811_1	58.83333	-158.58333	:America/Anchorage	USA	knots	213	18	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-00:02:00	\N	1.4	00:34:00	\N	1.3	-00:07:00	00:41:00	Clarks Point, 1 mile west of	AK
110723	Goodnews Bay entrance, Kuskokwim Bay, Alaska Current	NOS	PCT5821_1	59.06667	-161.78333	:America/Anchorage	USA	knots	213	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-06:02:00	\N	0.9	-06:05:00	\N	0.9	-06:23:00	-05:26:00	Goodnews Bay entrance	AK
110724	Carter Bay, west of, Kuskokwim Bay, Alaska Current	NOS	PCT5826_1	59.28333	-162.36667	:America/Nome	USA	knots	212	21	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-04:21:00	\N	0.6	-04:29:00	\N	0.6	-05:10:00	-03:44:00	Carter Bay, west of	AK
110725	Warehouse Bluff, southwest of, Kuskokwim Bay, Alaska Current	NOS	PCT5831_1	59.78333	-162.23333	:America/Nome	USA	knots	188	7	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-03:45:00	\N	0.8	-03:21:00	\N	0.6	-03:43:00	-03:21:00	Warehouse Bluff, southwest of	AK
110726	Apokak Creek entrance, Kuskokwim Bay, Alaska Current	NOS	PCT5836_1	60.13333	-162.16667	:America/Nome	USA	knots	205	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-02:51:00	\N	1.1	-03:42:00	\N	1.1	-05:04:00	-02:04:00	Apokak Creek entrance	AK
110727	Walrus Island, 0.5 mi west of, Pribilof Islands, Alaska Current	NOS	PCT5841_1	57.18333	-169.95	:America/Nome	USA	knots	210	18	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-06:38:00	\N	0.5	-06:47:00	\N	0.4	-06:40:00	-06:40:00	Walrus Island, 0.5 mile west of	AK
110728	SW Point, St. Paul Island, 1 mi off, Pribilof Islands, Alaska Current	NOS	PCT5861_1	57.15	-170.45	:America/Nome	USA	knots	170	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-08:10:00	\N	0.3	-08:10:00	\N	0.8	-08:55:00	-08:55:00	SW Point, St. Paul Island, 1 mile off	AK
110729	Hooper Bay entrance (depth 15 ft), Yukon Delta, Alaska Current	NOS	PCT5866_1	61.5	-166.0500030517578	:America/Nome	USA	knots	223	46	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-01:22:00	\N	0.8	-01:09:00	\N	0.7	-02:17:00	-01:11:00	Hooper Bay entrance	AK
110730	St. Matthew Island, southwest coast, Bering Sea, Alaska Current	NOS	PCT5871_1	60.35	-172.71667	:America/Nome	USA	knots	119	292	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	03:07:00	\N	0.4	03:20:00	\N	0.5	02:24:00	03:29:00	St. Mathew I., southwest coast	AK
110731	Apavawook Cape, 1 mi south of, St. Lawrence Island, Alaska Current	NOS	PCT5881_1	63.11667	-168.93333	:America/Adak	USA	knots	272	75	\N	Reference is in time zone :America/Anchorage; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	-02:23:00	\N	0.4	-02:14:00	\N	0.2	-02:58:00	-02:39:00	Apavawook Cape, 1 mile south of	AK
110732	Off Northeast Cape, St. Lawrence Island, Alaska Current	NOS	PCT5886_1	63.33330154418945	-168.8332977294922	:America/Adak	USA	knots	258	95	\N	Reference is in time zone :America/Anchorage; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107045	00:10:00	\N	0.3	00:57:00	\N	0.3	-00:41:00	01:16:00	Off Northeast Cape	AK
110733	Waldron Island, 1.7 nmi west of (depth 27 ft), Washington Current	NOS	PUG1716_23	48.704219818115234	-123.10476684570312	:America/Los_Angeles	USA	knots	252	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107697	00:33:00	\N	0.25	-00:27:00	\N	0.48	-01:00:00	00:21:00	Waldron Island, 1.7 nm west of	WA
110734	Waldron Island, 1.7 nmi west of (depth 93 ft), Washington Current	NOS	PUG1716_13	48.704219818115234	-123.10476684570312	:America/Los_Angeles	USA	knots	227	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107697	-00:30:00	\N	0.2	-00:35:00	\N	0.55	-02:10:00	00:11:00	Waldron Island, 1.7 nm west of	WA
110735	Waldron Island, 1.7 nmi west of (depth 159 ft), Washington Current	NOS	PUG1716_3	48.704219818115234	-123.10476684570312	:America/Los_Angeles	USA	knots	232	28	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2024-12-28	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	107697	-00:40:00	\N	0.22	-00:36:00	\N	0.53	-01:50:00	00:12:00	Waldron Island, 1.7 nm west of	WA
\.



COPY public.data_sets_old (index, name, station_id_context, station_id, lat, lng, timezone, country, units, min_dir, max_dir, legalese, notes, comments, source, restriction, date_imported, xfields, meridian, datumkind, datum, months_on_station, last_date_on_station, ref_index, min_time_add, min_level_add, min_level_multiply, max_time_add, max_level_add, max_level_multiply, flood_begins, ebb_begins, original_name, state) FROM stdin;
94649	Port Allen, Hanapepe Bay, Kauai Island, Hawaii	NOS	1611347	21.9033	-159.592	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT ALLEN, HANAPEPE BAY, KAUAI ISLAND	HI
94650	Nawiliwili, Nawiliwili Harbor, Kauai Island, Hawaii	NOS	1611400	21.9544	-159.3561	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nawiliwili	HI
94651	Honolulu, Honolulu Harbor, Oahu Island, Hawaii	NOS	1612340	21.30333333333334	-157.8645277777778	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Honolulu	HI
94652	Fort Kamehameha, Bishop Point, Pearl Harbor, Oahu Island, Hawaii	NOS	1612366	21.33	-157.967	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORT KAMEHAMEHA, BISHOP POINT, PEARL HBR	HI
94653	Ford Island, Pearl Harbor, Oahu Island, Hawaii	NOS	1612401	21.36750030517578	-157.96389770507812	:Pacific/Honolulu	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pearl Harbor	HI
94654	Pearl Harbor, Ford Island Ferry Dock, Oahu Island, Hawaii	NOS	1612404	21.3683	-157.94	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORD ISLAND, FERRY DOCK, PEARL HARBOR	HI
94655	Moku o Loe, Kaneohe Bay, Oahu Island, Hawaii	NOS	1612480	21.43305555555556	-157.79	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0500000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mokuoloe	HI
94656	Kaunakakai Harbor, Molokai Island, Hawaii	NOS	1613198	21.085	-157.032	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kaunakakai Harbor	HI
94657	Kahului, Kahului Harbor, Hawaii	NOS	1615680	20.89494444444445	-156.469	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1199999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kahului, Kahului Harbor	HI
94658	Kawaihae, Hawaii Island, Hawaii	NOS	1617433	20.0366	-155.8294	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9100000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kawaihae	HI
94659	Hilo, Hilo Bay, Kuhio Bay, Hawaii Island, Hawaii	NOS	1617760	19.73027777777778	-155.0555555555555	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1500000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hilo, Hilo Bay, Kuhio Bay	HI
94660	Johnston Atoll, Pacific Ocean	NOS	1619000	16.7383	-169.53	:Pacific/Johnston	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johnston Atoll	\N
94661	Sand Island, Midway Islands	NOS	1619910	28.2116667	-177.36	:Pacific/Midway	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6499999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sand Island, Midway Islands	\N
94662	Apra Harbor, Guam	NOS	1630000	13.44338888888889	144.6563611111111	:Pacific/Guam	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Apra Harbor, Guam	GU
94663	Pago Bay, Guam	NOS	1631428	13.4283333	144.7988888888889	:Pacific/Guam	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0100000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pago Bay, Guam	GU
94664	Tanapag Harbor, Saipan Island, Marianas	NOS	1633227	15.2267	145.737	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saipan	MP
94665	Pago Pago, American Samoa	NOS	1770000	-14.279999732971191	-170.69000244140625	:Pacific/Pago_Pago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3599999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pago Pago, American Samoa	AS
94666	Kwajalein, Marshall Islands	NOS	1820000	8.731666564941406	167.7361145019531	:Pacific/Kwajalein	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kwajalein, Marshall Islands	MH
94667	Chuuk, Moen Island, E. Caroline Islands, FSM	NOS	1840000	7.44667	151.847	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHUUK, MOEN ISLAND, E. CAROLINE ISLANDS	FM
94669	Wake Island, Pacific Ocean	NOS	1890000	19.2905556	166.6175	:Pacific/Wake	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1400000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wake Island, Pacific Ocean	MH
94670	Eastport, Passamaquoddy Bay, Maine	NOS	8410140	44.904598236083984	-66.98290252685547	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.7	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eastport	ME
94671	Coffin Point, Coffin Neck, Maine	NOS	8410714	44.87	-67.1083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COFFIN POINT, COFFIN NECK	ME
94672	Garnet Point, Hersey Neck, Pennamquan River, Cobscook Bay, Maine	NOS	8410715	44.9233	-67.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARNET POINT, HERSEY NECK	ME
94673	Pettegrove Point, Dochet Island, Maine	NOS	8410834	45.12844444444445	-67.14466666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pettegrove Point, Dochet Island	ME
94674	Gravelly Point, Whiting Bay, Maine	NOS	8410864	44.823299407958984	-67.15170288085938	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gravelly Point, Whiting Bay	ME
94675	Cutler (Farris Wharf), Little River, Maine	NOS	8411060	44.65702819824219	-67.20466613769531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cutler Farris Wharf	ME
94676	Cutler Naval Base, Machias Bay, Maine	NOS	8411250	44.6417	-67.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cutler Naval Base	ME
94677	Milbridge, Narraguagus River, Maine	NOS	8412581	44.54	-67.875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Milbridge	ME
94678	Bar Harbor, Frenchman Bay, Maine	NOS	8413320	44.39219444444444	-68.20427777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bar Harbor	ME
94679	Ellsworth, Union River, Blue Hill Bay, Maine	NOS	8413801	44.535	-68.4217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ellsworth	ME
94680	Mackerel Cove, Swans Island, Blue Hill Bay, Maine	NOS	8413825	44.16999816894531	-68.43499755859375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.46	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MACKEREL COVE, SWANS ISLAND	ME
94681	Oceanville, Deer Isle, Penobscot Bay, Maine	NOS	8414249	44.19230555555556	-68.62093055555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.289999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oceanville, Deer Isle	ME
94682	Bangor, Penobscot River, Maine	NOS	8414612	44.785	-68.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor	ME
94683	Fort Point, Penobscot River, Maine	NOS	8414721	44.4717	-68.8133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.609999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	ME
94684	Winterport, Penobscot River, Maine	NOS	8414781	44.63669967651367	-68.8416976928711	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.200000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WINTERPORT, PENOBSCOT RIVER	ME
94685	Pulpit Harbor, North Haven Island, Penobscot Bay, Maine	NOS	8414888	44.1567	-68.8867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.36	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PULPIT HARBOR, PENOBSCOT BAY	ME
94686	Rockland, Penobscot River, Maine	NOS	8415490	44.105	-69.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.329999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockland	ME
94687	Thomaston, St. George River, Maine	NOS	8415709	44.0717	-69.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.949999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thomaston	ME
94688	Walpole, Damariscotta River, Maine	NOS	8416731	43.9333	-69.58	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.050000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WALPOLE, DAMARISCOTTA RIVER	ME
94689	Wiscasset, Sheepscot River, Maine	NOS	8416921	44	-69.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.059999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wiscasset	ME
94690	Phipps Point, Back River, Maine	NOS	8417087	43.8983	-69.7433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.949999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Phipps Pt.	ME
94691	Gardiner, Kennebec River, Maine	NOS	8417134	44.2333	-69.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gardiner	ME
94693	Fort Popham, Hunniwell Point, Kennebec River, Maine	NOS	8417177	43.755	-69.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.59	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hunniwell Point	ME
94694	Richmond, Kennebec River, Maine	NOS	8417208	44.0883	-69.7983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9700000000000024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond	ME
94695	Bath, Kennebec River, Maine	NOS	8417227	43.925	-69.815	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bath	ME
94696	Portland, Casco Bay, Maine	NOS	8418150	43.65805555555556	-70.24416666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland	ME
94697	Pine Point, Maine	NOS	8418445	43.545	-70.3333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.759999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pine Point	ME
94698	Camp Ellis, Saco River entrance, Maine	NOS	8418606	43.4617	-70.3817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.820000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAMP ELLIS, SACO RIVER	ME
94699	Biddeford, Saco River, Maine	NOS	8418828	43.4917	-70.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.98	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIDDEFORD, SACO RIVER	ME
94700	Kennebunkport, Kennebunk River, Maine	NOS	8418911	43.3583	-70.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KENNEBUNKPORT, KENNEBUNK RIVER	ME
94701	Wells, Webhannet River, Maine	NOS	8419317	43.31999969482422	-70.56330108642578	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.77	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wells	ME
94702	Seavey Island, Portsmouth Harbor, Maine	NOS	8419870	43.0797222	-70.74111111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.460000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seavey Island	ME
94703	Dover, Cocheco River, Piscataqua River, New Hampshire	NOS	8420411	43.1983	-70.8683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9099999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOVER, COCHECO RIVER	NH
94704	Atlantic Terminals T14A, New Hampshire	NOS	8423005	43.1167	-70.8117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ATLANTIC TERMINALS  T14A	NH
94705	Fort Point, Portsmouth Harbor, New Hampshire	NOS	8423898	43.071388244628906	-70.71055603027344	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	NH
94706	Salisbury Point, Merrimack River, Massachusetts	NOS	8440273	42.8383	-70.9083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALISBURY POINT, MERRIMACK RIVER	MA
94707	Merrimacport, Merrimack River, Massachusetts	NOS	8440369	42.825	-70.9883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MERRIMACPORT, MERRIMACK RIVER	MA
94708	Plum Island, Merrimack River entrance, Merrimack River, Massachusetts	NOS	8440452	42.8167	-70.82	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLUM ISLAND, MERRIMACK  RIVER ENTRANCE	MA
94709	Newburyport, Merrimack River, Massachusetts	NOS	8440466	42.815	-70.8733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWBURYPORT, MERRIMACK RIVER	MA
94710	Riverside, Merrimack River, Massachusetts	NOS	8440889	42.7633	-71.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7800000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIVERSIDE, MERRIMACK RIVER	MA
94711	Plum Island Sound (south end), Massachusetts	NOS	8441241	42.71013888888889	-70.78861111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Island South	MA
94712	Rockport Harbor, Massachusetts	NOS	8441551	42.6583	-70.615	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.709999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ROCKPORT HARBOR	MA
94713	Annisquam, Lobster Cove, Massachusetts	NOS	8441571	42.654998779296875	-70.67669677734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.760000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LOBSTER COVE,  ANNISQUAM RIVER	MA
94714	Essex, Essex River, Massachusetts	NOS	8441771	42.6317	-70.7767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.080000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESSEX, ESSEX RIVER	MA
94715	Gloucester Harbor, Massachusetts	NOS	8441841	42.61000061035156	-70.66000366210938	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.7700000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GLOUCESTER HARBOR	MA
94717	Salem, Salem Harbor, Massachusetts	NOS	8442645	42.5233	-70.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.85	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALEM, SALEM HARBOR	MA
94718	Lynn, Lynn Harbor, Massachusetts	NOS	8443187	42.4583	-70.9433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LYNN, LYNN HARBOR	MA
94719	Amelia Earhart Dam, Mystic River, Boston Harbor, Massachusetts	NOS	8443662	42.395	-71.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.239999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AMELIA EARHART DAM, MYSTIC RIVER	MA
94720	Chelsea St. Bridge, Chelsea River, Boston Harbor, Massachusetts	NOS	8443725	42.3867	-71.0233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chelsea	MA
94721	Boston, Boston Harbor, Massachusetts	NOS	8443970	42.35388888888889	-71.05027777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.210000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston	MA
94722	Boston Light, Boston Harbor, Massachusetts	NOS	8444162	42.3283	-70.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.910000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Light	MA
94723	Nut Island, Quincy Bay, Massachusetts	NOS	8444525	42.28	-70.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.170000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nut Island	MA
94724	Shipyard Point, Weymouth Fore River, Massachusetts	NOS	8444788	42.2483	-70.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weymouth Fore River	MA
94725	Scituate, Scituate Harbor, Massachusetts	NOS	8445138	42.2017	-70.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.89	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SCITUATE, SCITUATE HARBOR	MA
94726	Brant Rock, Green Harbor River, Massachusetts	NOS	8446009	42.0833	-70.6467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.949999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BRANT ROCK, GREEN HARBOR RIVER	MA
94727	Provincetown, Cape Cod, Massachusetts	NOS	8446121	42.04959166666666	-70.18215833333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.030000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Provincetown	MA
94728	Duxbury, Duxbury Harbor, Cape Cod Bay, Massachusetts	NOS	8446166	42.0383	-70.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.489999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DUXBURY, DUXBURY HARBOR	MA
94729	Plymouth Harbor, Plymouth, Cape Cod Bay, Massachusetts	NOS	8446493	41.96	-70.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLYMOUTH, PLYMOUTH HARBOR	MA
94730	Cape Cod Canal (Sta. 115), Sagamore, Cape Cod Bay, Massachusetts	NOS	8447173	41.775	-70.535	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.41	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sagamore, Cape Cod Canal (Sta. 115)	MA
94731	Cape Cod Canal, Sandwich, Cape Cod Bay, Massachusetts	NOS	8447180	41.7717	-70.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.7	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandwich	MA
94732	Cape Cod Canal (Sta. 200), Bournedale, Cape Cod Bay, Massachusetts	NOS	8447191	41.77	-70.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bournedale, Cape Cod Canal (Sta. 200)	MA
94733	Sesuit Harbor, East Dennis, Cape Cod Bay, Massachusetts	NOS	8447241	41.7517	-70.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.220000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SESUIT HARBOR, EAST DENNIS	MA
94734	Cape Cod Canal (Sta. 320), Bourne Bridge, Cape Cod Bay, Massachusetts	NOS	8447259	41.745	-70.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bourne Bridge, Cape Cod Canal (Sta. 320)	MA
94735	Cape Cod Canal, RR. bridge, Buzzards Bay, Massachusetts	NOS	8447270	41.7417	-70.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buzzards Bay	MA
94736	Gray Gables, Buzzards Bay, Massachusetts	NOS	8447295	41.735	-70.6233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7700000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gray Gables	MA
94737	Great Hill, Buzzards Bay, Massachusetts	NOS	8447368	41.7117	-70.715	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Hill	MA
94738	Fall River, Narragansett Bay, Massachusetts	NOS	8447386	41.70429992675781	-71.16410064697266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fall River	MA
94739	Piney Point, Buzzards Bay, Massachusetts	NOS	8447416	41.695	-70.72	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piney Point	MA
94740	Chatham, Cape Cod, Massachusetts	NOS	8447435	41.688499450683594	-69.95110321044922	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.55	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chatham	MA
94741	Saquatucket Harbor, Nantucket Sound, Massachusetts	NOS	8447495	41.6683	-70.0567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAQUATUCKET HARBOR	MA
94742	Chatham, Stage Harbor, Cape Cod, Massachusetts	NOS	8447505	41.6667	-69.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHATHAM, STAGE HARBOR	MA
94743	Hyannis Port, Nantucket Sound, Massachusetts	NOS	8447605	41.6317	-70.3	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.92	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HYANNISPORT	MA
94745	Chapoquoit Point, West Falmouth Harbor, Buzzards Bay, Massachusetts	NOS	8447685	41.605	-70.6517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.85	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chappaquoit Point	MA
94746	Clarks Point, New Bedford, Buzzards Bay, Massachusetts	NOS	8447712	41.5933	-70.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW BEDFORD, CLARKS POINT	MA
94747	Round Hill Point, Buzzards Bay, Massachusetts	NOS	8447842	41.5383	-70.9283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6700000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ROUND HILL POINT	MA
94748	Woods Hole, Buzzards Bay, Massachusetts	NOS	8447930	41.52361297607422	-70.67111206054688	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.98	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woods Hole	MA
94749	Vineyard Haven Harbor, Vineyard Haven, Massachusetts	NOS	8448157	41.4583	-70.6	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VINEYARD HAVEN, VINEYARD HVN HBR	MA
94750	Penikese Island, Buzzards Bay, Massachusetts	NOS	8448248	41.45	-70.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6899999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PENIKESE ISLAND	MA
94751	Edgartown, Martha's Vineyard, Massachusetts	NOS	8448558	41.3883	-70.5117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgartown	MA
94752	Menemsha Harbor, Massachusetts	NOS	8448725	41.35444444444445	-70.76783333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Menemsha Harbor, MA	MA
94753	Martha's Vineyard GPS buoy, Martha's Vineyard, Massachusetts	NOS	8448875	41.32622222222222	-70.59033333333333	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4399999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Martha's Vineyard GPS Buoy	MA
94754	Nantucket, Nantucket Island, Massachusetts	NOS	8449130	41.28499984741211	-70.0967025756836	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nantucket Island	MA
94755	Sakonnet, Sakonnet River, Rhode Island	NOS	8450768	41.465	-71.1933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6100000000000012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAKONNET	RI
94756	Bristol Ferry, Narragansett Bay, Rhode Island	NOS	8451552	41.6367	-71.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BRISTOL FERRY	RI
94757	Bristol Highlands, Narragansett Bay, Rhode Island	NOS	8452154	41.69670104980469	-71.29329681396484	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bristol Highlands	RI
94758	Newport, Narragansett Bay, Rhode Island	NOS	8452660	41.5043333	-71.3261389	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newport	RI
94759	Conimicut Light, Narragansett Bay, Rhode Island	NOS	8452944	41.71670150756836	-71.34329986572266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Conimicut Light	RI
94760	West Jamestown, Dutch Island Harbor, Conanicut Island, Rhode Island	NOS	8453742	41.4967	-71.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEST JAMESTOWN	RI
94761	Providence, State Pier No. 1, Narragansett Bay, Rhode Island	NOS	8454000	41.80716666666667	-71.40066666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Providence	RI
94762	Quonset Point, Rhode Island	NOS	8454049	41.58679962158203	-71.41100311279297	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8699999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quonset Point	RI
94763	Wickford, Narragansett Bay, Rhode Island	NOS	8454538	41.5717	-71.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8499999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WICKFORD, NARRAGANSETT BAY	RI
94764	East Greenwich, Narragansett Bay, Rhode Island	NOS	8454578	41.665000915527344	-71.44499969482422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0600000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Greenwich	RI
94765	Point Judith, Harbor of Refuge, Rhode Island	NOS	8455083	41.3633	-71.49	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POINT JUDITH, HARBOR OF REFUGE	RI
94766	Kickamuit River, Narragansett Bay, Rhode Island	NOS	8455137	41.707801818847656	-71.24169921875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1900000000000013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kickamuit River	RI
94767	Westerly, Pawcatuck River, Rhode Island	NOS	8455189	41.3817	-71.8317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Westerly Pawcatuck	RI
94768	Weekapaug Point, Block Island Sound, Rhode Island	NOS	8458022	41.3283	-71.7617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEEKAPAUG POINT, BLOCK ISLAND SOUND	RI
94769	Block Island (Old Harbor), Rhode Island	NOS	8459338	41.1733	-71.5567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.46	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Block Island	RI
94772	Block Island (SW end), Block Island Sound, Rhode Island	NOS	8459681	41.1633	-71.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Block Island	RI
94773	West Mystic, Mystic River, Long Island Sound, Connecticut	NOS	8460751	41.343299865722656	-71.9749984741211	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Mystic River	CT
94774	New London, Thames River, Connecticut	NOS	8461490	41.36140060424805	-72.08999633789062	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5399999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London	CT
94775	Clinton Harbor, Connecticut	NOS	8463701	41.2683	-72.5317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.469999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Harbor	CT
94776	New Haven Harbor, New Haven Reach, Connecticut	NOS	8465705	41.28329849243164	-72.9083023071289	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3299999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven	CT
94777	Bridgeport Harbor, Bridgeport, Connecticut	NOS	8467150	41.17581944444444	-73.18396944444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6199999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport	CT
94778	Black Rock Harbor, Cedar Creek, Connecticut	NOS	8467373	41.1567	-73.2133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.630000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Black Rock Harbor	CT
94779	Southport, Southport Harbor, Connecticut	NOS	8467726	41.1333	-73.2833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.669999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport, Southport Harbor	CT
94780	Saugatuck, Saugatuck River, Long Island Sound, Connecticut	NOS	8468191	41.119998931884766	-73.36830139160156	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7600000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saugatuck River	CT
94781	South Norwalk, Norwalk River, Connecticut	NOS	8468448	41.0967	-73.415	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8099999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Norwalk	CT
94782	Long Neck Point, Long Island Sound, Connecticut	NOS	8468799	41.0383	-73.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.82	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG NECK POINT, LONG ISLAND SOUND	CT
94783	Mianus, Connecticut	NOS	8469057	41.039194	-73.592028	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mianus	CT
94784	Stamford Harbor, Stamford, Connecticut	NOS	8469198	41.0383	-73.5467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8499999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stamford Harbor	CT
94771	Sandy Point, Block Island Sound, Rhode Island	NOS	8459479	41.2283	-71.58	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY POINT, BLOCK IS, SOUND	RI
94786	Lake Montauk, Long Island, New York	NOS	8510448	41.0733	-71.935	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1800000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Montauk	NY
94787	Montauk, Fort Pond Bay, Long Island Sound, New York	NOS	8510560	41.0483333	-71.9594444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2399999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montauk	NY
94788	Silver Eel Pond, Fishers Island, New York	NOS	8510719	41.2567	-72.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4200000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Silver Eel Pond	NY
94790	Plum Gut Harbor, Plum Island, Long Island, New York	NOS	8511236	41.1717	-72.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5200000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PLUM ISLAND  PLUM GUT HARBOR	NY
94791	Sag Harbor, Shelter Island Sound, New York	NOS	8511629	41.0033	-72.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sag Harbor	NY
94792	Orient Harbor, Orient, Shelter Island Sound, New York	NOS	8511671	41.1367	-72.3067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orient Harbor	NY
94793	Greenport, Shelter Island Sound, New York	NOS	8511907	41.101	-72.36116666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4499999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Greenport	NY
94794	Shinnecock Inlet (ocean), Long Island, New York	NOS	8512354	40.8367	-72.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.610000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHINNECOCK INLET OPEN COAST	NY
94795	Ponquoque Point, Shinnecock Bay, New York	NOS	8512451	40.85	-72.5033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5200000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PONQUOGUE POINT	NY
94796	Mattituck Inlet, Long Island Sound, New York	NOS	8512668	41.01499938964844	-72.56169891357422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.710000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mattituck Inlet, Long Island	NY
94797	South Jamesport, Great Peconic Bay, New York	NOS	8512735	40.935	-72.5817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6400000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Jamesport	NY
94798	Shinnecock Yacht Club, Penniman Creek, Shinnecock Bay, New York	NOS	8512769	40.81855555555556	-72.58661111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHINNECOCK YACHT CLUB, PENNIMAN CREEK	NY
94799	Northville, Long Island, New York	NOS	8512987	40.9817	-72.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northville	NY
94800	Moriches USCG station, Long Island, New York	NOS	8513388	40.7867	-72.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moriches CGS, Moriches Bay	NY
94801	Moriches Inlet, Long Island, New York	NOS	8513398	40.76441666666667	-72.75597222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.620000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moriches Inlet	NY
94802	Smith Point Bridge, Narrow Bay, Long Island, New York	NOS	8513825	40.7383	-72.8683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SMITH POINT BRIDGE, NARROW BAY	NY
94803	Patchogue, Patchogue River, Great South Bay, New York	NOS	8514322	40.75	-73	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PATCHOGUE, PATCHOGUE RIVER	NY
94804	Cedar Beach, Long Island, New York	NOS	8514422	40.965	-73.0433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CEDAR BEACH	NY
94805	Port Jefferson, Long Island, New York	NOS	8514560	40.95000076293945	-73.07669830322266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT JEFFERSON	NY
94806	Seaview Ferry Dock, Great South Bay, New York	NOS	8514779	40.64925	-73.15061111111112	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seaview Ferry Dock	NY
94807	Fire Island USCG station, Great South Bay, New York	NOS	8515186	40.6267	-73.26	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island	NY
94789	Threemile Harbor entrance, Gardiners Bay, Long Island, New York	NOS	8511171	41.035	-72.19	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.34	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THREEMILE HARBOR ENTRANCE	NY
94808	Northport, Northport Bay, Long Island, New York	NOS	8515586	40.9	-73.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8699999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTHPORT, NORTHPORT BAY	NY
94809	Eatons Neck Point, Long Island, New York	NOS	8515786	40.9533	-73.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck	NY
94810	Huntington Harbor Lighthouse, Huntington Bay, Long Island, New York	NOS	8515921	40.91	-73.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LLOYD HARBOR LIGHTHOUSE	NY
94811	Cold Spring Harbor, Oyster Bay, New York	NOS	8516061	40.87329864501953	-73.47000122070312	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COLD SPRING HARBOR	NY
94812	Green Island, Hempstead Bay, New York	NOS	8516155	40.6233	-73.5017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.759999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GREEN ISLAND	NY
94813	Bayville Bridge, Oyster Bay, New York	NOS	8516299	40.9033	-73.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYVILLE BRIDGE, OYSTER BAY	NY
94814	Point Lookout, Long Island, New York	NOS	8516402	40.59388888888889	-73.58397222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.240000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Lookout	NY
94815	Parsonnage Cove, Long Island, New York	NOS	8516501	40.6333	-73.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.419999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parsonnage Cove	NY
94816	Harry Tappen Marina, Hempstead Harbor, Long Island, New York	NOS	8516607	40.83461111111111	-73.65241666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harry Tappen Marina	NY
94817	Glen Cove Yacht Club, Hempstead Harbor, Long Island, New York	NOS	8516614	40.8633	-73.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GLEN COVE YACHT CLUB, LONG ISLAND	NY
94818	Bay Park, East Rockaway, Hewlett Bay, New York	NOS	8516661	40.63	-73.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5600000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Park, NY	NY
94819	Long Beach (Bridgeview Yacht Club), New York	NOS	8516663	40.59633333333333	-73.65508333333334	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4400000000000013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG BEACH, NEW YORK	NY
94820	Port Washington, Manhasset Bay, Long Island, New York	NOS	8516761	40.8317	-73.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT WASHINGTON, MANHASSSET BAY	NY
94821	Atlantic Beach, East Rockaway Inlet, Long Island, New York	NOS	8516881	40.595	-73.7433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic Beach	NY
94822	Norton Point, Head of Bay, Jamaica Bay, New York	NOS	8516891	40.635	-73.7467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTON POINT, HOOK CREEK, NEW YORK	NY
94823	Kings Point, Long Island Sound, New York	NOS	8516945	40.810298919677734	-73.76490020751953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.889999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kings Point	NY
94824	Willets Point, Little Bay, East River, New York	NOS	8516990	40.7933	-73.7817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Willets Point	NY
94825	Beach Channel (bridge), Jamaica Bay, New York	NOS	8517137	40.5883	-73.82	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beach Channel	NY
94826	North Channel Bridge, Grassy Bay, Jamaica Bay, New York	NOS	8517201	40.645	-73.8367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0299999999999976	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Channel	NY
94830	Brooklyn Bridge, East River, New York	NOS	8517847	40.7033	-73.995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Bridge	NY
94829	Kingsborough Community College, Sheepshead Bay, Long Island, New York	NOS	8517756	40.581199645996094	-73.93379974365234	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.55	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingsborough CC	NY
94831	Rye Beach (Amusement Park), New York	NOS	8518091	40.9617	-73.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RYE BEACH, AMUSEMENT PARK	NY
94832	Throgs Neck, New York	NOS	8518526	40.805	-73.795	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Throgs Neck	NY
94833	Port Morris (Stony Point), East River, New York	NOS	8518639	40.8017	-73.9067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Morris	NY
94834	Harlem River, Randalls Island, East River, New York	NOS	8518643	40.8	-73.9283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Randalls Island	NY
94835	Horns Hook, East 90th Street, East River, New York, New York	NOS	8518668	40.7767	-73.9417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5299999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horns Hook	NY
94836	Queensboro Bridge, East River, New York	NOS	8518687	40.7583	-73.9583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Queensboro Bridge	NY
94837	Williamsburg Bridge, East River, New York	NOS	8518699	40.7117	-73.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Williamsburg Bridge	NY
94838	The Battery, New York Harbor, New York	NOS	8518750	40.7005556	-74.0141667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Battery	NY
94839	Ferry Slip, Dyckman Street, Hudson River, New York	NOS	8518902	40.8683	-73.9333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dyckman Street	NY
94842	Haverstraw Bay, Hudson River, New York	NOS	8518924	41.2183	-73.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HAVERSTRAW BAY	NY
94843	Beacon, Flushkill, Hudson River, New York	NOS	8518934	41.5	-73.9833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beacon, Hudson River	NY
94844	Hyde Park, Hudson River, New York	NOS	8518951	41.7833	-73.95	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.009999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hyde Park	NY
94845	Turkey Point Hudson River NERRS, Hudson River, New York	NOS	8518962	42.01390075683594	-73.93920135498047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turkey Point Hudson River NERRS	NY
94846	Albany, Hudson River, New York	NOS	8518995	42.65	-73.7467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ALBANY, HUDSON RIVER	NY
94847	USCG station, The Narrows, New York	NOS	8519050	40.612	-74.0598611111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG Station NY	NY
94848	Great Kills Harbor, New York	NOS	8519436	40.5433	-74.14	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.729999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Kills Harbor	NY
94849	Bayonne Bridge, Bergen Point West Reach, New York	NOS	8519483	40.63911111111111	-74.14630555555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bergen Point West Reach	NY
94850	Port Reading, Arthur Kill, New Jersey	NOS	8531142	40.55500030517578	-74.24500274658203	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Reading	NJ
94851	Cheesequake Creek, Garden State Parkway, New Jersey	NOS	8531223	40.4533	-74.2733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHEESEQUAKE CREEK	NJ
94853	Keasbey, Raritan River, New Jersey	NOS	8531262	40.50830078125	-74.31169891357422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.86	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEASBEY, RARITAN RIVER	NJ
94841	Riverdale, Hudson River, New York	NOS	8518905	40.9033	-73.9167	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIVERDALE, HUDSON RIVER	NY
94854	Old Bridge, South River, Raritan River, New Jersey	NOS	8531369	40.41669845581055	-74.36329650878906	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH OLD BRIDGE, SOUTH RIVER	NJ
94855	Sayreville, Raritan River, New Jersey	NOS	8531390	40.47829818725586	-74.35669708251953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAYREVILLE, RARITAN RIVER	NJ
94856	New Brunswick, Raritan River, New Jersey	NOS	8531463	40.48830032348633	-74.43499755859375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW BRUNSWICK  RARITAN RIVER	NJ
94857	Sandy Hook, Fort Hancock, New Jersey	NOS	8531680	40.46689987182617	-74.0093994140625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandy Hook	NJ
94858	Sea Bright, Shrewsbury River, New Jersey	NOS	8531804	40.365	-73.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Bright	NJ
94859	Toms River (town), Toms River, Barnegat Bay, New Jersey	NOS	8533051	39.95000076293945	-74.19830322265625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Toms River	NJ
94860	Stouts Creek, Barnegat Bay, New Jersey	NOS	8533365	39.845	-74.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.44000000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stouts Creek	NJ
94861	Barnegat Inlet, USCG station, Barnegat Bay, New Jersey	NOS	8533615	39.7617	-74.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BARNEGAT INLET (INSIDE)	NJ
94862	Shooting Thorofare, Little Egg Inlet, Great Bay, New Jersey	NOS	8534319	39.50830078125	-74.32499694824219	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01409335.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.55	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GREAT BAY, SHOOTING THOROFARE	NJ
94863	Mays Landing, Great Egg Harbor River, New Jersey	NOS	8534468	39.4483	-74.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MAYS LANDING, GREAT EGG HARBOR RIVER	NJ
94864	Atlantic City, New Jersey	NOS	8534720	39.356666564941406	-74.41805267333984	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic City	NJ
94865	Ventnor City, ocean pier, New Jersey	NOS	8534770	39.335	-74.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENTNOR CITY, FISHING PIER	NJ
94866	Longport, Risely Channel, New Jersey	NOS	8534836	39.3083	-74.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0300000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONGPORT, RISELY CHANNEL	NJ
94867	Tuckahoe, Tuckahoe River, Great Egg Harbor Bay, New Jersey	NOS	8534883	39.295	-74.7483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TUCKAHOE,TUCKAHOE RIVER	NJ
94868	Bivalve, Maurice River, Delaware Bay, New Jersey	NOS	8535055	39.23249816894531	-75.03279876708984	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01412150.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1300000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bivalve, Maurice River	NJ
94869	Ocean Drive bridge, Townsends Inlet, New Jersey	NOS	8535375	39.1217	-74.7167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1999999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Townsend Inlet	NJ
94870	Ingram Thorofare, Townsends Inlet, New Jersey	NOS	8535419	39.11	-74.7383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ingram Thorofare	NJ
94871	Stone Harbor, Great Channel, Hereford Inlet, New Jersey	NOS	8535581	39.05670166015625	-74.76499938964844	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01411360.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	STONE HARBOR, GREAT CHANNEL	NJ
94872	Wildwood Crest, ocean pier, New Jersey	NOS	8535835	38.975	-74.8233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WILDWOOD CREST	NJ
94873	Cape May Canal, Cape May, Delaware Bay, New Jersey	NOS	8536110	38.968299865722656	-74.95999908447266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May	NJ
94874	Bidwell Creek entrance, Delaware Bay, New Jersey	NOS	8536581	39.1283	-74.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIDWELL CREEK ENTRANCE, DELAWARE BAY	NJ
94875	Fortescue Creek, New Jersey	NOS	8536931	39.2383	-75.175	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORTESCUE CREEK	NJ
94876	Ship John Shoal, Delaware River, New Jersey	NOS	8537121	39.30538888888889	-75.37667777777777	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0400000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship John Shoal	NJ
94877	Paulsboro, Mantua Creek, New Jersey	NOS	8538512	39.835	-75.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.2600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAULSBORO, MANTUA CREEK	NJ
94878	Tacony-Palmyra Bridge, New Jersey	NOS	8538886	40.01194	-75.04299999978807	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6400000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tacony-Palmyra Bridge	NJ
94879	Burlington, Delaware River, New Jersey	NOS	8539094	40.08169937133789	-74.86969757080078	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9899999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burlington, Delaware River	NJ
94880	Fieldsboro, Delaware River, New Jersey	NOS	8539487	40.1367	-74.7367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FIELDSBORO, DELAWARE RIVER	NJ
94881	Trenton Marine Terminal, Trenton, New Jersey	NOS	8539993	40.1883	-74.755	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.470000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TRENTON MARINE TERMINAL	NJ
94882	Marcus Hook, Pennsylvania	NOS	8540433	39.81180555555556	-75.4095	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1400000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marcus Hook	PA
94883	Philadelphia (USCG station), Delaware River, Pennsylvania	NOS	8545240	39.93305555555556	-75.14198055555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4899999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Philadelphia	PA
94884	Philadelphia, Municipal Pier 11, Pennsylvania	NOS	8545530	39.9533	-75.1383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PHILADELPHIA (PIER 11 NORTH), DEL. RIVER	PA
94885	Bridesburg, Philadelphia, Pennsylvania	NOS	8546252	39.97968333333333	-75.07931666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.59	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridesburg	PA
94886	Newbold, Delaware River, Pennsylvania	NOS	8548989	40.13733333333333	-74.75183333333334	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newbold	PA
94887	Delaware City, Delaware River, Delaware	NOS	8551762	39.58219444444445	-75.58897222222222	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.950000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware City	DE
94888	Reedy Point, C&D Canal, Delaware	NOS	8551910	39.5583333	-75.5719444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9199999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Point	DE
94889	Mahon River entrance, Delaware Bay, Delaware	NOS	8554399	39.185	-75.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mahon River Entrance	DE
94890	Brandywine Shoal Light, Delaware Bay, New Jersey	NOS	8555889	38.98666666666667	-75.11333333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.610000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Shoal Light	NJ
94891	Lewes, Fort Miles, Delaware	NOS	8557380	38.78283333333334	-75.11927777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lewes	DE
94892	Inlet (USCG station), Indian River, Delaware	NOS	8558690	38.61	-75.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	INDIAN RIVER INLET	DE
94893	Rosedale Beach, Indian River, Delaware	NOS	8558814	38.59149932861328	-75.21160125732422	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01484540.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.64	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosedale Beach, Indian River	DE
94894	Little Assawoman Bay, Delaware	NOS	8559957	38.45500183105469	-75.05829620361328	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01484701.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Little Assawoman Bay	DE
94895	Ocean City (fishing pier), Maryland	NOS	8570280	38.3267	-75.0833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN CITY, FISHING PIER	MD
94896	Ocean City Inlet, Maryland	NOS	8570283	38.32833	-75.09166666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocean City Inlet	MD
94897	South Point, Sinepuxent Neck, Chincoteague Bay, Maryland	NOS	8570536	38.215	-75.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH POINT, SINEPUXENT NECK, CHINC. BAY	MD
94898	Public Landing, Chincoteague Bay, Maryland	NOS	8570649	38.1483	-75.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUBLIC LANDING, CHINCOTEAGUE BAY	MD
94899	Buntings Bridge, Chincoteague Bay, Maryland	NOS	8570691	38.13894444444445	-75.18352777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buntings Bridge	MD
94900	Crisfield, Little Annemessex River, Chesapeake Bay, Maryland	NOS	8571091	37.9767	-75.8633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRISFIELD	MD
94901	Ewell, Smith Island, Chesapeake Bay, Maryland	NOS	8571117	37.995	-76.0317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9400000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ewell, Smith Island	MD
94902	Snow Hill, city park, Pocomoke River, Maryland	NOS	8571359	38.17833	-75.39666666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Hill	MD
94903	Bishops Head, Hooper Strait, Maryland	NOS	8571421	38.22	-76.0383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bishops Head	MD
94904	McCready's Creek, Fishing Bay, Chesapeake Bay, Maryland	NOS	8571559	38.3	-76.005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	McCready's Creek	MD
94905	Barren Island, Chesapeake Bay, Maryland	NOS	8571579	38.3417	-76.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barren Island	MD
94906	Salisbury, Wicomico River, Maryland	NOS	8571616	38.3650016784668	-75.60669708251953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SALISBURY, WICOMICO RIVER	MD
94907	Smithville Road Bridge, Beaverdam Creek, Little Choptank River, Maryland	NOS	8571702	38.42833	-76.23666666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beaverdam Creek	MD
94908	Vienna, Nanticoke River, Maryland	NOS	8571773	38.48333	-75.81833333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vienna	MD
94909	Sharptown, Nanticoke River, Maryland	NOS	8571858	38.54499816894531	-75.72329711914062	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01488110.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHARPSTOWN, NANTICOKE RIVER	MD
94910	Cambridge, Choptank River, Maryland	NOS	8571892	38.5725	-76.0616667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cambridge	MD
94911	Poplar Island, Chesapeake Bay, Maryland	NOS	8572271	38.75833333333333	-76.375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.78	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Poplar Island	MD
94913	Kent Point Marina, Chesapeake Bay, Maryland	NOS	8572467	38.8367	-76.3733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kent Point	MD
94914	Hillsboro, Tuckahoe Creek, Maryland	NOS	8572669	38.9167	-75.945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4600000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hillsboro	MD
94915	Matapeake, Kent Island, Chesapeake Bay, Maryland	NOS	8572770	38.9567	-76.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matapeake	MD
94916	Love Point, Chester River, Maryland	NOS	8572955	39.0317	-76.3017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Love Point Pier	MD
94917	Crumpton, Chester River, Maryland	NOS	8573349	39.245	-75.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crumpton	MD
94918	Tolchester Beach, Chesapeake Bay, Maryland	NOS	8573364	39.21344444444444	-76.24455555555555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tolchester Beach	MD
94919	Sassafras River, Betterton, Chesapeake Bay, Maryland	NOS	8573704	39.3717	-76.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Betterton	MD
94920	Town Point Wharf, Elk River, Maryland	NOS	8573903	39.5033	-75.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TOWN POINT WHARF	MD
94921	Chesapeake City, Chesapeake and Delaware Canal, Maryland	NOS	8573927	39.5266667	-75.81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake City	MD
94922	Havre de Grace, Susquehanna River, Maryland	NOS	8574070	39.5367	-76.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Havre De Grace	MD
94923	Pond Point (Aberdeen P.G.), Bush River, Chesapeake Bay, Maryland	NOS	8574459	39.3883	-76.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POND POINT (ABERDEEN P.G.), BUSH RIVER	MD
94924	Baltimore (Fort McHenry), Maryland	NOS	8574680	39.266700744628906	-76.57830047607422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baltimore	MD
94925	Fort McHenry Marsh, Patapsco River, Maryland	NOS	8574683	39.2617	-76.585	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort McHenry Marsh	MD
94926	Annapolis (US Naval Academy), Severn River, Maryland	NOS	8575512	38.98327777777778	-76.48155555555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Annapolis	MD
94927	Long Beach, Chesapeake Bay, Maryland	NOS	8577004	38.465	-76.4733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Long Beach	MD
94928	Cove Point, Chesapeake Bay, Maryland	NOS	8577188	38.3917	-76.3983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COVE POINT	MD
94929	Solomons Island, Patuxent River, Maryland	NOS	8577330	38.3172222	-76.4508333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Solomons Island	MD
94930	Lower Marlboro, Patuxent River, Maryland	NOS	8579542	38.655	-76.68333333333334	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1099999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Marlboro	MD
94931	Bladensburg, Anacostia River, Maryland	NOS	8579997	38.9333	-76.9383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.63	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLADENSBURG, ANACOSTIA RIVER	MD
94932	Washington, Potomac River, DC	NOS	8594900	38.87333333333334	-77.02166666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Washington	DC
94933	Jesters Island, Virginia	NOS	8630111	37.9817008972168	-75.30169677734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	JESTERS ISLAND, CHINCOTEAGUE BAY	VA
94934	Chincoteague Island, USCG station, Virginia	NOS	8630249	37.93170166015625	-75.38330078125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINCOTEAGUE, USCG STATION	VA
94935	Chincoteague Channel (south end), Chincoteague Bay, Virginia	NOS	8630308	37.9067	-75.405	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1700000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINCOTEAGUE CHANNEL, SOUTH END	VA
94936	Southern Chincoteague Island, Chincoteague Bay, Virginia	NOS	8630315	37.902400970458984	-75.40789794921875	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=01484746.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.63	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southern Chincoteague Island	VA
94937	Wachapreague, Wachapreague Channel, Virginia	NOS	8631044	37.60777777777778	-75.68583333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wachapreague	VA
94938	Kiptopeke Beach, Chesapeake Bay, Virginia	NOS	8632200	37.16519546508789	-75.98844146728516	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kiptopeke	VA
94940	Rappahannock Light, Virginia	NOS	8632837	37.5383	-76.015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9399999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rappahannock Light	VA
94941	Gaskins Point, Occohannock Creek, Chesapeake Bay, Virginia	NOS	8632869	37.5567	-75.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GASKINS PT., OCCOHANNOCK CREEK	VA
94942	Tangier Island, Chesapeake Bay, Virginia	NOS	8633532	37.8283	-75.9933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8499999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tangier Island	VA
94943	Saxis, Starling Creek, Pocomoke Sound, Chesapeake Bay, Virginia	NOS	8633777	37.92169952392578	-75.72830200195312	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAXIS, STARLING CREEK	VA
94944	Dahlgren, Upper Machodoc Creek, Potomac River, Virginia	NOS	8635027	38.31975277777778	-77.03659722222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9399999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dahlgren	VA
94945	Colonial Beach, Potomac River, Virginia	NOS	8635150	38.2517	-76.96	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Colonial Beach, Potomac River	VA
94946	Rappahannock Bend, Virginia	NOS	8635257	38.2133	-77.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rappahannock Bend	VA
94947	Lewisetta, Potomac River, Virginia	NOS	8635750	37.99538888888889	-76.46461111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lewisetta	VA
94948	Wares Wharf, Rappahannock River, Virginia	NOS	8635985	37.8733	-76.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wares Wharf	VA
94949	Windmill Point, Rappahannock River, Virginia	NOS	8636580	37.6155	-76.28977777777777	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Windmill Point	VA
94950	Lester Manor, Pamunkey River, Virginia	NOS	8636653	37.5833	-76.99	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lester Manor	VA
94951	Richmond Deepwater Terminal, James River, Virginia	NOS	8636941	37.45955555555555	-77.42077777777777	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond Deepwater Terminal, James River	VA
94954	Gloucester Point, York River, Virginia	NOS	8637624	37.2467	-76.5	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2900000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gloucester Point	VA
94955	Yorktown USCG Training Center, York River, Virginia	NOS	8637689	37.2265	-76.47880555555555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yorktown USCG Training Center	VA
94956	Jamestown Wharf, Jamestown, Virginia	NOS	8637712	37.22011111111111	-76.79141666666666	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data collected from 2017 and beyond are from United States Geological Survey\n(USGS) water level stations that are subject to NOAA's National Ocean Service\n(NOS) routine quality assurance procedures on a monthly basis with data\navailable for the previous month. For access to the real-time data at this\nlocation visit USGS at:\nhttps://nwis.waterdata.usgs.gov/nwis/uv?site_no=02042770.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jamestown Wharf	VA
94957	Fort Eustis (MARAD), James River, Virginia	NOS	8638017	37.13822222222223	-76.62275	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2799999999999976	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FORT EUSTIS (MARAD), JAMES RIVER	VA
94958	Western Branch, Elizabeth River, Virginia	NOS	8638339	36.82322222222222	-76.39911111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5400000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Western Branch	VA
94952	New Point, Virginia	NOS	8637289	37.3467	-76.2733	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.85	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW POINT	VA
94960	Kingsmill, James River, Virginia	NOS	8638424	37.22	-76.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2799999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingsmill	VA
94961	Scotland, James River, Virginia	NOS	8638433	37.185	-76.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1500000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scotland	VA
94962	Lanexa, Chickahominy River, Virginia	NOS	8638445	37.4033	-76.9117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lanexa, Chickahominy River	VA
94963	Tettington, James River, Virginia	NOS	8638450	37.24	-76.9433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.129999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tettington, James River	VA
94964	Willcox Wharf, Charles City, James River, Virginia	NOS	8638464	37.315	-77.0983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3099999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilcox Wharf	VA
94965	Hopewell, City Point, James River, Virginia	NOS	8638481	37.3133	-77.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hopewell	VA
94966	Puddledock Sand & Gravel, Appomattox River, Virginia	NOS	8638489	37.2667	-77.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puddledock	VA
94967	Richmond River Locks, James River, Virginia	NOS	8638495	37.525	-77.42	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond River Locks, James River	VA
94968	Sewells Point, Hampton Roads, Virginia	NOS	8638610	36.9427778	-76.3286111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sewells Point	VA
94969	Portsmouth, Naval Shipyard, Elizabeth River, Virginia	NOS	8638660	36.8217	-76.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5299999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORTSMOUTH, NORFOLK NAVAL SHIPYARD	VA
94970	Lafayette River, Virginia	NOS	8638671	36.88422222222222	-76.27585833333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lafayette River	VA
94971	Chesapeake Bay Bridge-Tunnel, Virginia	NOS	8638863	36.9667	-76.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4200000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Bridge Tunnel	VA
94972	Chesapeake Bay Bridge-Tunnel, Chesapeake Bay, Virginia	NOS	8638901	37.032901763916016	-76.08329772949219	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CBBT, Chesapeake Channel	VA
94973	Inside channel, Rudee Inlet, Virginia	NOS	8639207	36.8317	-75.9733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8000000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rudee Inlet	VA
94974	Money Point, South Bridge, Elizabeth River, Virginia	NOS	8639348	36.77819444444445	-76.30186111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Money Point	VA
94975	FRF Pier, Duck, North Carolina	NOS	8651370	36.18330001831055	-75.74669647216797	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7700000000000031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Duck	NC
94976	Manns Harbor, Croatan Sound, North Carolina	NOS	8652247	35.9033	-75.77	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.21999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Manns Harbor	NC
94977	Oyster Creek, Croatan Sound, North Carolina	NOS	8652437	35.845	-75.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.31000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oyster Creek	NC
94978	Roanoke Marshes Light, Pamlico Sound, North Carolina	NOS	8652547	35.8117	-75.7	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roanoke Marshes Light	NC
94979	Oregon Inlet Marina, Pamlico Sound, North Carolina	NOS	8652587	35.79569444444444	-75.54819444444445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5800000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oregon Inlet Marina	NC
94980	Old House Channel, Pamlico Sound, North Carolina	NOS	8652648	35.77669906616211	-75.58499908447266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.45999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old House Channel	NC
94981	Oregon Inlet (USCG station), North Carolina	NOS	8652678	35.7683	-75.5267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG LIFEBOAT STATION, OREGON INLET	NC
94982	Rodanthe, Pamlico Sound, North Carolina	NOS	8653215	35.595	-75.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.42000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RODANTHE, PAMLICO SOUND	NC
94983	Engelhard, Pamlico Sound, North Carolina	NOS	8653471	35.5093994140625	-75.98889923095703	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Engelhard	NC
94984	Avon Seafood dock, Peter's Ditch, Avon, North Carolina	NOS	8653951	35.35013888888889	-75.51202777777777	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.28999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peter's Ditch	NC
94985	Cape Hatteras (fishing pier), North Carolina	NOS	8654400	35.2233	-75.635	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6199999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Hatteras Fishing Pier	NC
94986	Hatteras (USCG station), North Carolina	NOS	8654467	35.20861111111111	-75.70419444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USCG Station Hatteras	NC
94987	Ocracoke, Pamlico Sound, North Carolina	NOS	8654769	35.115501403808594	-75.98690032958984	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.45999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocracoke, Pamlico Sound	NC
94988	Ocracoke, Ocracoke Island, North Carolina	NOS	8654792	35.115	-75.9883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCRACOKE ISLAND	NC
94991	Sea Level, Core Sound, North Carolina	NOS	8655875	34.875	-76.3433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Level	NC
94992	Core Creek Bridge, North Carolina	NOS	8656084	34.82500076293945	-76.69000244140625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1199999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CORE CREEK BRIDGE	NC
94993	Davis, Core Sound, North Carolina	NOS	8656201	34.79679870605469	-76.45549774169922	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6300000000000026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Davis, Core Sound	NC
94994	Spooner Creek, Bogue Sound, North Carolina	NOS	8656467	34.725	-76.8033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spooners Creek	NC
94995	Duke Marine Lab, Beaufort, North Carolina	NOS	8656483	34.71733055555556	-76.67065833333334	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beaufort, Duke Marine Lab	NC
94996	Triple S Pier, Atlantic Beach, North Carolina	NOS	8656590	34.6933	-76.7117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atlantic Beach Triple S Pier	NC
94997	Swansboro, East Corbett Ave. Bridge, North Carolina	NOS	8656613	34.68659973144531	-77.11810302734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Swansboro, East Corbett Ave Bridge	NC
94998	Cape Lookout Bight, North Carolina	NOS	8656841	34.6133	-76.5383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE LOOKOUT, LOOKOUT BIGHT	NC
94999	Sneads Ferry, New River, North Carolina	NOS	8657002	34.57630157470703	-77.39540100097656	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sneads Ferry, New River	NC
95000	Hampstead, ICWW, North Carolina	NOS	8657813	34.33940124511719	-77.70600128173828	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.860000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hampstead	NC
95001	Wilmington, North Carolina	NOS	8658120	34.2275	-77.9536111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilmington	NC
95002	Shinn Point, ICWW, North Carolina	NOS	8658145	34.217899322509766	-77.81230163574219	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1400000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shinn Point	NC
95003	Wrightsville Beach, North Carolina	NOS	8658163	34.21330555555556	-77.78669444444445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.150000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrightsville Beach	NC
95004	Wharf 3, MOTSU, Cape Fear River, North Carolina	NOS	8658579	34.0233	-77.9467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SUNNY POINT, MOTSU NORTH WHARF	NC
95005	Zekes Island, Cape Fear River, North Carolina	NOS	8658741	33.95	-77.9517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZEKES ISLAND, CAPE FEAR RIVER	NC
95006	Southport, Cape Fear River, North Carolina	NOS	8659084	33.915	-78.0183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport	NC
95007	Oak Island, Yaupon Beach, North Carolina	NOS	8659182	33.9017	-78.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5400000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oak Island, Atlantic Ocean	NC
95008	Varnamtown, Lockwoods Folly River, North Carolina	NOS	8659414	33.933101654052734	-78.21890258789062	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.150000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Varnamtown, Lockwoods Folly River	NC
95009	Shallotte Inlet (Bowen Point), North Carolina	NOS	8659665	33.915000915527344	-78.37329864501953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2600000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOWEN POINT, SHALLOTTE INLET	NC
95010	Sunset Beach Pier, North Carolina	NOS	8659897	33.865	-78.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunset Beach	NC
95011	Carolina Forest, ICWW, South Carolina	NOS	8660754	33.734901428222656	-78.88269805908203	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carolina Forest	SC
95013	Bucksport, Waccamaw River, South Carolina	NOS	8661139	33.6467	-79.095	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUCKSPORT, WACCAMAW RIVER	SC
95014	Garden City Bridge, Main Creek, Murrells Inlet, South Carolina	NOS	8661419	33.5783	-79.0033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARDEN CITY BRIDGE, MURRELLS INLET	SC
95015	Garden City Pier (ocean), South Carolina	NOS	8661437	33.575	-78.9967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7100000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GARDEN CITY PIER, MURRELLS INLET	SC
95016	Wachesaw Landing, Waccamaw River, South Carolina	NOS	8661493	33.560001373291016	-79.08499908447266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WACHESAW LANDING, WACCAMAW R.	SC
95017	Oaks Creek, upper end, Murrells Inlet, South Carolina	NOS	8661684	33.5117	-79.0683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OAKS CREEK, UPPER END, MURRELLS INLET	SC
95018	Thoroughfare Creek entrance, Waccamaw River, South Carolina	NOS	8661703	33.5067	-79.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY ISLAND, THOROUGHFARE CREEK	SC
95019	Bennet's Dock, Pawleys Island Creek, South Carolina	NOS	8661989	33.435	-79.1267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BENNETT'S DOCK	SC
95020	Pawleys Island Pier (ocean), South Carolina	NOS	8662006	33.4317	-79.1167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAWLEYS ISLAND PIER, ATLANTIC OCEAN	SC
95021	Ward's Dock, Pawleys Inlet, South Carolina	NOS	8662071	33.4117	-79.135	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.92	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PAWLEYS INLET, WARDS DOCK	SC
95022	Crab Haul Creek north inlet estuary, Oyster Landing, South Carolina	NOS	8662245	33.35169982910156	-79.18669891357422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oyster Landing (N Inlet Estuary)	SC
95023	Clambank Creek Dock, Goat Island, North Inlet, South Carolina	NOS	8662299	33.3333	-79.1933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7100000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLAMBANK CREEK DOCK, GOAT ISLAND	SC
95024	South Island Plantation (USCG station), Winyah Bay, South Carolina	NOS	8662746	33.235	-79.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0500000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WINYAH BAY, SOUTH ISLAND PLANTATION	SC
95025	Georgetown, Sampit River, South Carolina	NOS	8662926	33.361698150634766	-79.27999877929688	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1900000000000013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GEORGETOWN, SAMPIT RIVER ENT.	SC
95026	Waccamaw River entrance, Winyah Bay, South Carolina	NOS	8662931	33.36669921875	-79.25499725341797	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.990000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WACCAMAW RIVER ENTRANCE	SC
95027	Windsor Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8662953	33.415	-79.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9599999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WINDSOR PLANTATION, BLACK RIVER	SC
95028	South Santee River, ICWW (Fourmile Creek Canal), South Carolina	NOS	8663219	33.15420150756836	-79.35440063476562	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1499999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	S. SANTEE R.,IWW(4 MI. CANAL CR)	SC
95029	Buck Hall, Awendaw Creek, Bulls Bay, South Carolina	NOS	8663858	33.040000915527344	-79.55999755859375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6399999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUCK HALL, AWENDAW CREEK	SC
95030	General Dynamics Pier, Cooper River, South Carolina	NOS	8664022	33.0083	-79.9233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GEN. DYNAMICS PIER, COOPER R.	SC
95031	Cainhoy, Wando River, South Carolina	NOS	8664545	32.9267	-79.83	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5400000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cainhoy, Wando River	SC
95032	Army Depot, Cooper River, South Carolina	NOS	8664662	32.91	-79.9517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Army Depot	SC
95033	North Charleston, Ashley River, South Carolina	NOS	8664699	32.900299072265625	-80.11750030517578	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.669999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Charleston, Ashley River	SC
95034	Capers Creek, South Capers Island, South Carolina	NOS	8664941	32.8567	-79.7067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5799999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Capers Island	SC
95035	I-526 bridge, Ashley River, South Carolina	NOS	8665099	32.8367	-80.0217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.289999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-526 BRIDGE, ASHLEY RIVER	SC
95036	Charleston, Cooper River entrance, South Carolina	NOS	8665530	32.7808333	-79.9236111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9200000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston	SC
95037	Church Flats, Stono River, South Carolina	NOS	8665763	32.746700286865234	-80.16500091552734	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5100000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hollywood, Wadmalaw River	SC
95038	White House Woods, Mosquito Creek, Ashepoo River, St. Helena Sound, South Carolina	NOS	8667295	32.55870056152344	-80.45439910888672	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.450000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	White House Woods, Mosquito Creek	SC
95039	Air Station Beaufort, McCalleys Creek, South Carolina	NOS	8667612	32.50189971923828	-80.68489837646484	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Air Station Beaufort, McCalleys Creek	SC
95040	Clarendon Plantation, South Carolina	NOS	8667633	32.5025	-80.7841	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.800000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clarendon Plantation	SC
95041	Beaufort, Beaufort River, South Carolina	NOS	8667999	32.43	-80.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BEAUFORT	SC
95042	Fripp Inlet, Hunting Island Bridge, St. Helena Sound, South Carolina	NOS	8668498	32.34	-80.465	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fripps Inlet	SC
95043	Skull Creek, Ribaut Island, South Carolina	NOS	8668918	32.2667	-80.7367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.89	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RIBAUT ISLAND, SKULL CREEK	SC
95044	Brighton Beach, May River, South Carolina	NOS	8669246	32.2140998840332	-80.84649658203125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.260000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brighton Beach	SC
95045	Port Wentworth, Savannah River, Georgia	NOS	8670424	32.14330555555556	-81.14169444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Wentworth	GA
95047	Fort Pulaski, Savannah River, Georgia	NOS	8670870	32.03469444444445	-80.90302777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pulaski	GA
95049	Skidaway Institute, Skidaway River, Georgia	NOS	8671086	31.99	-81.0233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.2700000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SKIDAWAY INSTITUTE, SKIDAWAY RIVER	GA
95050	Halfmoon Reef, Halfmoon River, Georgia	NOS	8671314	31.963300704956055	-80.94329833984375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HALFMOON REEF, HALFMOON RIVER	GA
95051	Priest Landing, Wilmington River, Georgia	NOS	8671315	31.963300704956055	-81.01170349121094	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PRIEST LANDING, WILMINGTON RIVER	GA
95052	Richmond Hill, Ogeechee River, Georgia	NOS	8671489	31.94300079345703	-81.28980255126953	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond Hill, Ogeechee River	GA
95054	Bear River, Range A Light, Georgia	NOS	8672667	31.7933	-81.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A Light, Bear River	GA
95055	Sunbury, Sunbury Channel, Georgia	NOS	8672875	31.7667	-81.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunbury, Sunbury Channel	GA
95056	South Ossabaw Island, Bear River, Georgia	NOS	8673171	31.72302777777778	-81.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Ossabaw Island, Bear River	GA
95057	South Newport River (Daymark 135), Georgia	NOS	8674301	31.575	-81.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7900000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #135, South Newport River	GA
95058	Mud River, head of (Daymark 156), Georgia	NOS	8674975	31.4867	-81.32	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.199999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #156, Head of Mud River	GA
95059	Rockdedundy River (Daymark 185), Georgia	NOS	8675761	31.37386111111111	-81.33394444444444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Daymark #185, Rockdedundy River Entrance	GA
95060	Crispen Island, Turtle River, Georgia	NOS	8676808	31.213300704956055	-81.55000305175781	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRISPEN ISLAND,TURTLE RIVER	GA
95061	St. Simons Lighthouse, St. Simons Island, Georgia	NOS	8677344	31.1317	-81.3967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5699999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St.Simons Island	GA
95062	Howe Street Pier, Brunswick, Georgia	NOS	8677406	31.14455555555556	-81.49680555555555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.009999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Howe Street Pier, Brunswick	GA
95063	Raccoon Key Spit, St. Andrew Sound, Georgia	NOS	8678124	31.01480555555555	-81.45597222222223	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5599999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raccoon Key Spit	GA
95064	Bailey Cut, 0.8 mi west of, Satilla River, Georgia	NOS	8678322	30.985	-81.5917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bailey Cut, Satilla River	GA
95065	Kings Bay, Navy Base, Georgia	NOS	8679511	30.7967	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5599999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KINGS BAY	GA
95066	Kings Bay, MSF Pier, Cumberland Sound, Georgia	NOS	8679598	30.7780556	-81.4913889	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4799999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kings Bay MSF Pier	GA
95067	Dungeness, Seacamp Dock, Georgia	NOS	8679758	30.7633	-81.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.4299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DUNGENESS, SEACAMP DOCK	GA
95068	St. Marys, St. Marys River, Georgia	NOS	8679964	30.72	-81.5483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MARYS, ST. MARYS RIVER	GA
95069	Crandall, St. Marys River, Florida	NOS	8720004	30.7217	-81.6217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8199999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRANDALL, ST. MARYS RIVER	FL
95070	Cut 1N front range, St. Marys River, Florida	NOS	8720011	30.7083	-81.465	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1999999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUT 1N FRONT RANGE, ST MARYS RIVER ENTR	FL
95072	Chester, Bells River, Florida	NOS	8720023	30.6833	-81.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHESTER, BELLS RIVER	FL
95071	Cut 2N front range, St. Marys River, Georgia	NOS	8720012	30.7167	-81.3017	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.99	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUT 2N FRONT RANGE, ST MARYS RIVER ENTR	GA
95073	Fernandina Beach, Amelia River, Florida	NOS	8720030	30.67135555555556	-81.46584166666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fernandina Beach	FL
95074	Lofton, Lanceford Creek, Florida	NOS	8720051	30.6433	-81.5233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LANCEFORD CREEK, LOFTON	FL
95075	Vaughns Landing, Florida	NOS	8720059	30.63	-81.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8299999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vaughns Landing	FL
95076	Nassauville, Nassau River East, Florida	NOS	8720098	30.5683	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NASSAUVILLE, NASSAU RIVER EAST	FL
95077	Edwards Creek, Nassau River, Florida	NOS	8720145	30.5017	-81.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edwards Creek	FL
95078	Cedar Heights, Broward River, Florida	NOS	8720189	30.4367	-81.6417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6200000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CEDAR HEIGHTS	FL
95079	Sisters Creek, Florida	NOS	8720196	30.4167	-81.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3800000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SISTERS CREEK	FL
95080	Clapboard Creek, Pelotes Island, Florida	NOS	8720198	30.4067	-81.51	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLAPBOARD CREEK	FL
95081	Water Treatment Dock, Mayport Naval Station, St. Johns River, Florida	NOS	8720211	30.4	-81.4133	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport Naval Sta., St Johns River	FL
95082	Sherwood Forest, Trout River, Florida	NOS	8720213	30.42	-81.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3800000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TROUT R., SHERWOOD FOREST	FL
95083	Degaussing structure, Mayport Naval Station, Florida	NOS	8720214	30.3967	-81.395	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5599999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Degaussing Structure	FL
95084	Bar Pilot Dock, St. Johns River, Florida	NOS	8720218	30.39816666666667	-81.42788888888889	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4700000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport (Bar Pilots Dock)	FL
95085	Dame Point, St. Johns River, Florida	NOS	8720219	30.386699676513672	-81.55829620361328	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8599999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point	FL
95086	Mayport (Ferry Depot), Florida	NOS	8720220	30.3933	-81.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport (Ferry Depot)	FL
95087	Mayport, St. Johns River, Florida	NOS	8720224	30.395	-81.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MAYPORT, ST JOHNS RIVER	FL
95088	Phoenix Park, Florida	NOS	8720225	30.3833	-81.6367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3199999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PHOENIX PARK	FL
95089	Main Street Bridge, St. Johns River, Florida	NOS	8720226	30.32	-81.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southbank Riverwalk, St Johns River	FL
95090	Jacksonville, Long Branch, Florida	NOS	8720242	30.360000610351562	-81.62000274658203	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3699999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Long Branch	FL
95091	Jacksonville Beach, Florida	NOS	8720291	30.2833	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.55	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jacksonville Beach	FL
95092	I-295 Bridge (west end), St. Johns River, Florida	NOS	8720357	30.19241666666667	-81.68888888888888	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-295 Buckman Bridge	FL
95093	Peoria Point, Doctors Lake, Florida	NOS	8720406	30.12	-81.7583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOCTORS LAKE, PEORIA POINT	FL
95094	Black Creek, S.C.L. RR. bridge, Florida	NOS	8720434	30.08	-81.7617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACK CREEK	FL
95096	Red Bay Point, St. Johns River, Florida	NOS	8720503	29.98166666666667	-81.63416666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bay Point, St Johns River	FL
95097	Vilano Beach ICWW, Tolomato River, Florida	NOS	8720554	29.9167	-81.3	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vilano Beach ICWW	FL
95098	State Road 312, Matanzas River, ICWW, Florida	NOS	8720582	29.8667	-81.3067	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Road 312, Matanzas River	FL
95099	St. Augustine Beach, Florida	NOS	8720587	29.8567	-81.2633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4300000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Augustine Beach	FL
95100	Racy Point, St. Johns River, Florida	NOS	8720625	29.8017	-81.5483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.64	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Racy Point, St Johns River	FL
95101	Crescent Beach, Matanzas River, ICWW, Florida	NOS	8720651	29.7683	-81.2583	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crescent Beach, Matanzas River	FL
95102	State Road A1A Bridge, Florida	NOS	8720692	29.70453055555556	-81.22785555555555	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9399999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Road A1A Bridge	FL
95904	Nonopapa, Niihau Island, Hawaii	NOS	1610367	21.87	-160.235	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94651	-00:11:00	\N	0.77	-00:16:00	\N	0.77	\N	\N	Nonopapa, Niihau Island	HI
95905	Waimea Bay, Kauai Island, Hawaii	NOS	1611401	21.9567	-159.673	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94650	00:18:00	\N	0.91	00:07:00	\N	0.86	\N	\N	Waimea Bay	HI
95103	Bings Landing, Matanzas River, ICWW, Florida	NOS	8720757	29.615	-81.205	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9400000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bings Landing, Matanzas River	FL
95104	Buffalo Bluff, St. Johns River, Florida	NOS	8720767	29.595	-81.6817	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5800000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buffalo Bluff, St Johns River	FL
95125	PGA Boulevard Bridge, Palm Beach, Florida	NOS	8722548	26.8433	-80.0667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PGA Boulevard Bridge, Palm Beach	FL
95105	Palatka, St. Johns River, Florida	NOS	8720774	29.6433	-81.6317	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.72	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Palatka, St Johns River	FL
95106	Welaka, St. Johns River, Florida	NOS	8720832	29.4767	-81.675	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These raw data are derived from the water level network operated by the\nFlorida Department of Environmental Protection (FDEP), Bureau of Surveying and\nMapping (BSM), a coastal observing system that uses National Ocean Service\n(NOS) data collection procedures. These stations transmit data via GOES once\nevery three hours. Tidal datums and predictions are produced by CO-OPS,\nderived from the raw data collected by BSM. NOTE: most of these stations have\na station zero of NAVD88, resulting in a negative value for MLLW. For\ninformation on the BSM, go to BSM.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Welaka	FL
95108	Daytona Beach Shores, Sunglow Pier, Florida	NOS	8721120	29.1467	-80.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DAYTONA BEACH SHORES	FL
95109	Ponce De Leon Inlet South, Florida	NOS	8721147	29.06329917907715	-80.91500091552734	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ponce De Leon Inlet South	FL
95110	Mosquito Lagoon, New Smyrna Beach, Florida	NOS	8721164	29.0233	-80.9183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Smyrna Beach	FL
95111	Packwood Place, Florida	NOS	8721222	28.94	-80.87	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PACKWOOD PLACE	FL
95112	Turtle Mound, Florida	NOS	8721223	28.9267	-80.825	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.18000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURTLE MOUND	FL
95113	Trident Pier, Port Canaveral, Florida	NOS	8721604	28.415800094604492	-80.59310150146484	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trident Pier, Port Canaveral	FL
95115	Cocoa Beach, Florida	NOS	8721649	28.3683	-80.6	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COCOA BEACH, ATLANTIC OCEAN	FL
95117	Vero Beach, Indian River, Florida	NOS	8722125	27.6317	-80.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.43000000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vero Beach	FL
95118	North Beach Causeway, Indian River, Florida	NOS	8722208	27.4717	-80.325	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9500000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Beach Causeway	FL
95119	Fort Pierce Inlet, Binney Dock, Florida	NOS	8722213	27.46830555555556	-80.3	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2300000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Binney Dock	FL
95120	South Beach Causeway, Indian River, Florida	NOS	8722219	27.4567	-80.3233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Beach Causeway	FL
95121	Ankona, Indian River, Florida	NOS	8722274	27.355	-80.2733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7799999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ANKONA, INDIAN RIVER	FL
95123	Sewall Point, St. Lucie River, Florida	NOS	8722371	27.175	-80.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SEWALL POINT. ST. LUCIE RIVER	FL
95124	South Point, St. Lucie Inlet, St. Lucie River, Florida	NOS	8722375	27.165278	-80.163056	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH POINT, ST LUCIE INLET	FL
95122	Jensen Beach Causeway Park, ICWW, Florida	NOS	8722329	27.2517	-80.2183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jensen Beach Causeway Park	FL
95107	Daytona Beach (ocean), Florida	NOS	8721020	29.2283	-81.005	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DAYTONA BEACH (OCEAN)	FL
95126	Port of West Palm Beach, Florida	NOS	8722588	26.77	-80.0517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of West Palm Beach	FL
95127	Lake Worth ICW, Florida	NOS	8722669	26.6133	-80.0467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4499999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth ICW	FL
95128	Lake Worth Pier, Florida	NOS	8722670	26.6127778	-80.0341667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5400000000000027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth Pier, Atlantic Ocean	FL
95130	Ocean Ridge, ICWW, Florida	NOS	8722718	26.52669906616211	-80.05329895019531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN RIDGE	FL
95131	South Delray Beach, ICWW, Florida	NOS	8722761	26.4467	-80.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH DELRAY BEACH	FL
95132	Lake Wyman, ICWW, Florida	NOS	8722802	26.37	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAKE WYMAN	FL
95133	Boca Raton, Lake Boca Raton, Florida	NOS	8722816	26.343299865722656	-80.07669830322266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOCA RATON	FL
95134	Hillsboro Inlet Marina, Florida	NOS	8722859	26.260000228881836	-80.08499908447266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HILLSBORO	FL
95135	Lauderdale-by-the-Sea, Anglin Fishing Pier, Florida	NOS	8722899	26.18829917907715	-80.09329986572266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4599999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAUDERDALE-BY-THE-SEA	FL
95136	South Port Everglades, ICWW, Florida	NOS	8722956	26.0816667	-80.1166667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4100000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Port Everglades	FL
95137	Haulover Pier, N. Miami Beach, Florida	NOS	8723080	25.9033	-80.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HAULOVER PIER, N. MIAMI BEACH	FL
95138	Miami, Miamarina, Biscayne Bay, Florida	NOS	8723165	25.7783	-80.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MIAMI, BISCAYNE BAY	FL
95139	Miami Beach (city pier), Florida	NOS	8723170	25.7683	-80.1317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami Beach	FL
95140	Government Cut, Miami Harbor entrance, Florida	NOS	8723178	25.7633	-80.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MIAMI BEACH, GOVERNMENT CUT	FL
95141	Virginia Key, Bear Cut, Biscayne Bay, Florida	NOS	8723214	25.7314	-80.1618	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.129999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Virginia Key, Biscayne Bay	FL
95142	Cutler, Biscayne Bay, Florida	NOS	8723289	25.615	-80.305	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUTLER, BISCAYNE BAY	FL
95143	Ragged Key No. 5, Biscayne Bay, Florida	NOS	8723355	25.5233	-80.175	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RAGGED KEY NO. 5, BISCAYNE BAY	FL
95144	Elliott Key Harbor, Elliott Key, Biscayne Bay, Florida	NOS	8723409	25.4533	-80.1967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ELLIOTT KEY HARBOR, ELLIOTT KEY	FL
95145	Turkey Point, Biscayne Bay, Florida	NOS	8723423	25.4367	-80.33	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURKEY POINT, BISCAYNE BAY	FL
95146	East Arsenicker, Card Sound, Florida	NOS	8723465	25.3733	-80.29	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST ARSENICKER, CARD SOUND	FL
95147	Pumpkin Key, south end, Card Sound, Florida	NOS	8723506	25.325	-80.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUMPKIN KEY, CARD SOUND	FL
95148	Little Card Sound bridge, Florida	NOS	8723534	25.2883	-80.37	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CARD SOUND BRIDGE	FL
95149	Key Colony Beach, Florida	NOS	8723962	24.7183	-81.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key Colony Beach	FL
95150	Vaca Key, Florida Bay, Florida	NOS	8723970	24.711	-81.1065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5099999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vaca Key, Florida Bay	FL
95151	Boca Chica Marina, Florida	NOS	8724493	24.575	-81.7083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6499999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOCA CHICA MARINA	FL
95152	Fleming Key, north end, Florida	NOS	8724571	24.5917	-81.795	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7100000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fleming Key	FL
95153	Key West, Florida	NOS	8724580	24.555700302124023	-81.80789947509766	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West	FL
95154	Sand Key Lighthouse, Sand Key Channel, Florida	NOS	8724635	24.4533	-81.8783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAND KEY LIGHTHOUSE	FL
95155	Smith Shoal Light, Florida	NOS	8724671	24.71827777777778	-81.92152777777778	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Shoal Light	FL
95156	Loggerhead Key, Dry Tortugas, Florida	NOS	8724698	24.6317	-82.92	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Loggerhead Key	FL
95157	Dismal Key, Pumpkin Bay, Florida	NOS	8724963	25.895	-81.5583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DISMAL KEY, PUMPKIN BAY	FL
95158	Coon Key Pass, Gullivan Bay, Florida	NOS	8724964	25.8967	-81.6367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COON KEY PASS, GULLIVAN BAY	FL
95159	Marco Island, Caxambas Pass, Florida	NOS	8724967	25.9083	-81.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.68	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARCO ISLAND, CAXAMBAS PASS	FL
95160	Marco, Big Marco River, Florida	NOS	8724991	25.9717	-81.7283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARCO, BIG MARCO RIVER	FL
95161	McIlvaine Bay, Florida	NOS	8724996	25.985	-81.7017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.44	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MCILVAINE BAY	FL
95162	Keewaydin Island (inside), Florida	NOS	8725019	26.025	-81.7683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4500000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEEWAYDIN ISLAND, INSIDE	FL
95163	Naples, Florida	NOS	8725110	26.1316667	-81.8075	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naples, Gulf of Mexico	FL
95164	Little Hickory Island, Estero Bay, Florida	NOS	8725283	26.3533	-81.855	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LITTLE HICKORY IS., ESTERO B.	FL
95165	Coconut Point, Estero Bay, Florida	NOS	8725319	26.4	-81.8433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COCONUT POINT, ESTERO BAY	FL
95166	Carlos Point, Estero Bay, Florida	NOS	8725325	26.405000686645508	-81.88500213623047	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CARLOS POINT, ESTERO BAY	FL
95167	Estero Island, Estero Bay, Florida	NOS	8725351	26.4383	-81.9183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESTERO ISLAND, ESTERO BAY	FL
95168	Tarpon Bay, Sanibel Island, Florida	NOS	8725362	26.4433	-82.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TARPON BAY	FL
95169	Hendry Creek, Estero Bay, Florida	NOS	8725377	26.47	-81.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HENDRY CREEK, ESTERO BAY	FL
95170	Punta Rassa, San Carlos Bay, Florida	NOS	8725391	26.48811111111111	-82.01333333333334	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUNTA RASSA, SAN CARLOS BAY	FL
95171	St. James City, Pine Island, Florida	NOS	8725393	26.4917	-82.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. JAMES CITY,PINE ISLAND	FL
95172	Cape Coral Bridge, Caloosahatchee River, Florida	NOS	8725451	26.56329917907715	-81.93329620361328	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE CORAL BR.,CALOOSAHATCHEE R.	FL
95173	North Captiva Island, Florida	NOS	8725488	26.605	-82.2183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH CAPTIVA ISLAND	FL
95174	Matlacha Pass (bascule bridge), Florida	NOS	8725506	26.63222222222222	-82.06916666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.98	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MATLACHA PASS (SWING BR.)	FL
95175	Fort Myers, Caloosahatchee River, Florida	NOS	8725520	26.64777777777778	-81.8711111111111	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Myers	FL
95176	Bokellia, Charlotte Harbor, Florida	NOS	8725541	26.70669937133789	-82.16329956054688	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9200000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOKEELIA, CHARLOTTE HARBOR	FL
95177	Port Boca Grande, Charlotte Harbor, Florida	NOS	8725577	26.719999313354492	-82.25830078125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT BOCA GRANDE, CHARLOTTE HBR.	FL
95178	Turtle Bay, Charlotte Harbor, Florida	NOS	8725649	26.7967	-82.1833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8600000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURTLE BAY	FL
95179	Don Pedro Island State Park, cutoff (south), Florida	NOS	8725685	26.855	-82.3033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CUTOFF SOUTH	FL
95180	Locust Point, Hog Island, Charlotte Harbor, Florida	NOS	8725745	26.93	-82.1367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LOCUST POINT, HOG ISLAND	FL
95181	Harbour Heights, Peace River, Charlotte Harbor, Florida	NOS	8725791	26.9883	-81.9933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HARBOUR HEIGHTS, PEACE RIVER	FL
95182	Manasota, Lemon Bay, Florida	NOS	8725809	27.0117	-82.41	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MANASOTA	FL
95183	Myakka River, US 41 bridge, Charlotte Harbor, Florida	NOS	8725837	27.045	-82.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MYAKKA RIVER, US 41	FL
95184	Venice Fishing Pier, Venice, Florida	NOS	8725858	27.0717	-82.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENICE, GULF OF MEXICO	FL
95185	Siesta Key, Big Sarasota Pass, Florida	NOS	8726034	27.283899307250977	-82.56500244140625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Siesta Key, Big Sarasota Pass	FL
95186	Ellenton, Manatee River, Tampa Bay, Florida	NOS	8726265	27.51490020751953	-82.53379821777344	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ellenton, Manatee River	FL
95187	Egmont Key, Egmont Channel, Tampa Bay, Florida	NOS	8726347	27.6017	-82.76	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EGMONT KEY, TAMPA BAY	FL
95188	Mullet Key Channel (Skyway), Tampa Bay, Florida	NOS	8726364	27.615	-82.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1099999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MULLET KEY, TAMPA BAY	FL
95189	Port Manatee, Tampa Bay, Florida	NOS	8726384	27.638700485229492	-82.56210327148438	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Manatee	FL
95190	Little Manatee River, Florida	NOS	8726436	27.705	-82.4483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LITTLE MANATEE RIVER	FL
95191	St. Petersburg, Tampa Bay, Florida	NOS	8726520	27.7611111	-82.6269444	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Petersburg, Tampa Bay	FL
95192	Newman Branch, Tampa Bay, Florida	NOS	8726539	27.7833	-82.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWMAN BRANCH	FL
95193	Port Tampa, Old Tampa Bay, Florida	NOS	8726607	27.857799530029297	-82.55280303955078	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Port Tampa	FL
95194	Ballast Point, Tampa, Florida	NOS	8726639	27.89	-82.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TAMPA, BALLAST POINT	FL
95195	CSX Rockport, Mckay Bay entrance, Florida	NOS	8726667	27.913299560546875	-82.42500305175781	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.46	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mckay Bay Entrance	FL
95196	East Bay, Tampa Bay, Florida	NOS	8726674	27.923099517822266	-82.42140197753906	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Bay	FL
95197	Clearwater Beach, Florida	NOS	8726724	27.9783333	-82.8316667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clearwater Beach	FL
95198	Safety Harbor, Old Tampa Bay, Florida	NOS	8726738	27.9883	-82.685	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAFETY HARBOR, OLD TAMPA BAY	FL
95199	Anclote Lighthouse, Anclote Key, Florida	NOS	8726917	28.165	-82.8433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6999999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ANCLOTE LIGHTHOUSE, ANCLOTE KEY	FL
95200	Bayport, Florida	NOS	8727151	28.5333	-82.65	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYPORT	FL
95201	Johns Island, Chassahowitzka Bay, Florida	NOS	8727235	28.6917	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	JOHNS ISLAND, CHASSAHOWITZKA BAY	FL
95202	Chassahowitzka, Chassahowitzka River, Florida	NOS	8727246	28.715	-82.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHASSAHOWITZKA RIVER	FL
95203	Mason Creek, Homosassa Bay, Florida	NOS	8727274	28.7617	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MASON CREEK, HOMOSASSA BAY	FL
95204	Tuckers Island, Homosassa River, Florida	NOS	8727277	28.7717	-82.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TUCKERS ISLAND, HOMOSASSA RIVER	FL
95205	Halls River bridge, Homosassa River, Florida	NOS	8727293	28.8	-82.6033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.32999999999999985	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HALLS RIVER BRIDGE, HALLS RIVER	FL
95206	Ozello, St. Martins River, Florida	NOS	8727306	28.825	-82.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.34999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OZELLO	FL
95207	Ozello North, Crystal Bay, Florida	NOS	8727328	28.8633	-82.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8400000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OZELLO NORTH	FL
95208	Mangrove Pt., Crystal Bay, Florida	NOS	8727333	28.87	-82.7233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mangrove Point	FL
95209	Dixie Bay, Salt River, Crystal Bay, Florida	NOS	8727336	28.8817	-82.635	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DIXIE BAY	FL
95210	Crystal River, Kings Bay, Florida	NOS	8727343	28.8983	-82.5983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRYSTAL RIVER, KINGS BAY	FL
95211	Twin Rivers Marina, Crystal River, Florida	NOS	8727348	28.905	-82.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2399999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Twin Rivers Marina	FL
95212	Shell Island, north end, Crystal River, Florida	NOS	8727359	28.9233	-82.6917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5099999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELL ISLAND, CRYSTAL RIVER	FL
95213	Cedar Key, Florida	NOS	8727520	29.135000228881836	-83.03170013427734	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cedar Key	FL
95214	Shell Mound, Cedar Keys NWR, Florida	NOS	8727535	29.20639991760254	-83.0697021484375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shell Mound	FL
95215	Horseshoe Point, Florida	NOS	8727648	29.4367	-83.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HORSESHOE POINT	FL
95216	Hagens Cove, Florida	NOS	8727792	29.79669952392578	-83.58380126953125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hagens Cove	FL
95217	Spring Warrior Creek, Florida	NOS	8727843	29.92	-83.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPRING WARRIOR CREEK	FL
95218	Snipe Island, Econfina River State Park, Apalachee Bay, Florida	NOS	8727976	30.061899185180664	-83.95269775390625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.759999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snipe Island	FL
95219	Port Leon, Apalachee Bay, Florida	NOS	8728104	30.124399185180664	-84.14900207519531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9600000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Leon	FL
95220	St. Marks lighthouse, Apalachee Bay, Florida	NOS	8728130	30.0783	-84.1783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9200000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MARKS LHTSE., APALACHEE BAY	FL
95221	St. Marks, Wakulla River, Apalachee Bay, Florida	NOS	8728152	30.158899307250977	-84.21859741210938	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.030000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Marks, Wakulla River	FL
95222	Shell Point, Walker Creek, Apalachee Bay, Florida	NOS	8728229	30.05833333333333	-84.29055555555556	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELL POINT, WALKER CREEK	FL
95224	Turkey Point, Apalachee Bay, St. James Island, Florida	NOS	8728360	29.915	-84.5117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TURKEY POINT	FL
95225	Dog Island, east end, St. George Sound, Florida	NOS	8728408	29.81	-84.585	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DOG ISLAND, EAST END	FL
95226	Lanark, St. George Sound, Florida	NOS	8728412	29.878299713134766	-84.59500122070312	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LANARK, ST. GEORGES SOUND	FL
95227	Carrabelle, Carrabelle River, St. George Sound, Florida	NOS	8728464	29.85	-84.665	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CARRABELLE RIVER, ST. GEORGE SOUND	FL
95228	St. George Island, NE end, St. George Sound, Florida	NOS	8728486	29.766700744628906	-84.69999694824219	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NE END, ST. GEORGE ISLAND	FL
95229	South Carrabelle Beach, Florida	NOS	8728488	29.801700592041016	-84.73670196533203	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4000000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH CARRABELLE BEACH	FL
95230	East Bayou, Florida	NOS	8728593	29.818899154663086	-84.85030364990234	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Bayou	FL
95231	Cat Point, Apalachicola Bay, Florida	NOS	8728619	29.72361111111111	-84.88666666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAT POINT, APALACHICOLA BAY	FL
95232	St. George Island, 12th St. W (bayside), St. George Sound, Florida	NOS	8728626	29.6533	-84.8967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. GEORGE ISLAND, BAYSIDE	FL
95233	St. George Island, Sikes Cut, St. George Sound, Florida	NOS	8728669	29.613300323486328	-84.95829772949219	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SIKES CUT, ST. GEORGE ISLAND	FL
95234	Apalachicola, Apalachicola Bay, Florida	NOS	8728690	29.7244444	-84.9805556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9100000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Apalachicola	FL
95235	White Beach, East Bay, Florida	NOS	8728694	29.785	-84.8983	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WHITE BEACH, EAST BAY	FL
95236	Apalachicola River (A&N RR bridge), Apalachicola Bay, Florida	NOS	8728711	29.7633	-85.0333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	APALACHICOLA RIVER	FL
95237	Little St. George Island, Apalachicola Bay, Florida	NOS	8728728	29.603599548339844	-85.04280090332031	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.860000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Little St George Island	FL
95238	Huckleberry Landing, Jackson River, Florida	NOS	8728757	29.770000457763672	-85.08499908447266	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7000000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HUCKLEBERRY LANDING, JACKSON RIVER	FL
95239	Eleven Mile, St. Vincent Sound, Florida	NOS	8728786	29.70669937133789	-85.1532974243164	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ELEVEN MILE, ST. VINCENT SOUND	FL
95241	Indian Pass, St. Vincent Sound, Florida	NOS	8728852	29.685100555419922	-85.22129821777344	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Indian Pass	FL
95242	White City, ICWW, Florida	NOS	8728853	29.88069444444444	-85.22144444444444	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	White City, ICWW	FL
95240	Lake Wimico, Florida	NOS	8728819	29.821425	-85.173342	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4399999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Wimico	FL
95243	White City, Gulf County Canal, St. Joseph Bay, Florida	NOS	8728886	29.866792	-85.2706	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5399999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	White City, Gulf County Canal	FL
95244	Port Saint Joe, St. Joseph Bay, Florida	NOS	8728912	29.815	-85.3133	:America/New_York	USA	feet	\N	\N	\N	NOS uses UTC-6 for LST	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port St. Joe	FL
95246	Overstreet, St. Andrew Bay, Florida	NOS	8728957	29.996700286865234	-85.37000274658203	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OVERSTREET	FL
95247	St. Joseph Point, St. Joseph Bay, Florida	NOS	8728958	29.873300552368164	-85.38999938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.76	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. JOSEPH POINT, ST. JOSEPH BAY	FL
95248	Cape San Blas (western cape), St. Joseph Bay, Florida	NOS	8728978	29.764400482177734	-85.40249633789062	:America/Chicago	USA	feet	\N	\N	\N	NOS uses UTC-5 for LST	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape San Blas, Western Cape	FL
95249	Goose Point, East Bay, St. Andrew Bay, Florida	NOS	8729026	30.061199188232422	-85.48860168457031	:America/Chicago	USA	feet	\N	\N	\N	NOS uses UTC-5 for LST	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Bay, Goose Point	FL
95250	Deer Point Lake, St. Andrew Bay, Florida	NOS	8729082	30.26959991455078	-85.60790252685547	:America/Chicago	USA	feet	\N	\N	\N	NOS uses UTC-5 for LST	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deer Point Lake	FL
95251	Panama City, St. Andrew Bay, Florida	NOS	8729108	30.1497222	-85.6644444	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Panama City	FL
95252	Courtney Point, St. Andrew Bay, Florida	NOS	8729132	30.15169906616211	-85.66670227050781	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Courtney Point, St Andrew Bay	FL
95253	Sulphur Point, Port of Panama City, St. Andrew Bay, Florida	NOS	8729142	30.183000564575195	-85.73280334472656	:America/Chicago	USA	feet	\N	\N	\N	NOS uses UTC-5 for LST	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sulphur Point, Port of Panama City	FL
95254	West Bay Creek, West Bay, St. Andrew Bay, Florida	NOS	8729197	30.29330062866211	-85.8582992553711	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEST BAY CREEK  WEST BAY	FL
95255	Panama City Beach (outside), St. Andrew Bay, Florida	NOS	8729210	30.21375	-85.87858333333334	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Panama City Beach	FL
95257	Driftwood Point, Choctawhatchee Bay, Florida	NOS	8729425	30.389400482177734	-86.32879638671875	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Driftwood Point, Choctawhatcheee Bay	FL
95258	Rocky Bayou, Choctawhatchee Bay, Florida	NOS	8729479	30.50670051574707	-86.44670104980469	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.27000000000000135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ROCKY BAYOU	FL
95259	Valparaiso, Choctawhatchee Bay, Florida	NOS	8729501	30.503299713134766	-86.49330139160156	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.27999999999999936	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valparaiso	FL
95260	Okaloosa Island, Florida	NOS	8729547	30.391399383544922	-86.59320068359375	:America/Chicago	USA	feet	\N	\N	\N	NOS uses UTC-5 for LST	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Okaloosa Island	FL
95379	Sabine Naches Canal, Port Arthur, Texas	NOS	8770475	29.86669921875	-93.93000030517578	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Arthur	TX
95261	Mary Esther, Santa Rosa Sound, Florida	NOS	8729572	30.4064998626709	-86.65049743652344	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.43000000000000327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mary Esther	FL
95262	Navarre Beach, Florida	NOS	8729678	30.3767	-86.865	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAVARRE BEACH	FL
95263	East Bay, Pensacola Bay, Florida	NOS	8729702	30.450000762939453	-86.91829681396484	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.74	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST BAY, HOLLEY	FL
95264	Navarre (north side), East Bay, Pensacola Bay, Florida	NOS	8729717	30.443099975585938	-86.95140075683594	:America/Chicago	USA	feet	\N	\N	\N	NOS uses UTC-5 for LST	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7399999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Navarre, North Side	FL
95265	Woodlawn Beach, Florida	NOS	8729736	30.386699676513672	-86.99169921875	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6599999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WOODLAWN BEACH	FL
95267	Shield Point, Blackwater River, Florida	NOS	8729747	30.58169937133789	-87.01499938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHIELD POINT, BLACKWATER RIVER	FL
95268	Hawkins Recreational Park, Blackwater River, Florida	NOS	8729753	30.636699676513672	-87.0282974243164	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACKWATER RIVER	FL
95269	Hernandez Point North, Escambia Bay, Florida	NOS	8729791	30.454999923706055	-87.0999984741211	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6500000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HERNANDEZ POINT NORTH	FL
95270	Fishing Bend, Santa Rosa Sound, Florida	NOS	8729806	30.336700439453125	-87.13999938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6300000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FISHING BEND, SANTA ROSA SOUND	FL
95271	Pensacola Beach Pier, Florida	NOS	8729807	30.3275	-87.141944	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6600000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pensacola Beach Pier	FL
95272	Lora Point, Escambia Bay, Pensacola Bay, Florida	NOS	8729816	30.514999389648438	-87.16169738769531	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LORA POINT, ESCAMBIA BAY	FL
95273	Floridatown, Escambia Bay, Florida	NOS	8729824	30.58169937133789	-87.18000030517578	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FLORIDATOWN, ESCAMBIA BAY	FL
95274	Pensacola, Florida	NOS	8729840	30.404399871826172	-87.21119689941406	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.620000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pensacola	FL
95275	Millview, Perdido Bay, Florida	NOS	8729905	30.4183	-87.3567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Millview, Perdido Bay	FL
95276	Big Lagoon, Florida	NOS	8729909	30.32670021057129	-87.35669708251953	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BIG LAGOON	FL
95277	Blue Angels Park, Perdido Bay, Florida	NOS	8729941	30.38694444444445	-87.42880555555556	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blue Angels Park	FL
95278	Mill Point, Arnica Bay, Alabama	NOS	8730561	30.310199737548828	-87.51930236816406	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.379999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arnica Bay, Mill Point	AL
95279	Alabama Point, Perdido Pass, Alabama	NOS	8730667	30.27861111111111	-87.55500030517578	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alabama Point	AL
95280	Wolf Bay, Alabama	NOS	8730849	30.354999542236328	-87.5999984741211	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4200000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wolf Bay	AL
95281	Gulf State Park Pier, Alabama	NOS	8731269	30.248300552368164	-87.66829681396484	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulf State Park Pier	AL
95282	Gulf Shores, ICWW, Alabama	NOS	8731439	30.27988888888889	-87.68427777777778	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulf Shores, ICWW	AL
95283	Weeks Bay, Alabama	NOS	8732828	30.416900634765625	-87.82540130615234	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weeks Bay, Mobile Bay	AL
95284	Fly Creek, Mobile Bay, Alabama	NOS	8733502	30.542800903320312	-87.9010009765625	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fly Creek, Mobile Bay	AL
95285	Point Clear, Mobile Bay, Alabama	NOS	8733821	30.48663888888889	-87.93452777777777	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7800000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Clear, Mobile Bay	AL
95286	Meaher State Park, Mobile Bay, Alabama	NOS	8733839	30.66716666666667	-87.93644444444445	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Meaher State Park, Mobile Bay	AL
95287	Dauphin Island, Mobile Bay, Alabama	NOS	8735180	30.25	-88.075	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5699999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dauphin Island	AL
95288	Dauphin Island Hydro, Alabama	NOS	8735181	30.25131944444444	-88.07948611111111	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dauphin Island Hydro	AL
95289	Dog River Bridge, Alabama	NOS	8735391	30.565200805664062	-88.08799743652344	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dog River Bridge	AL
95290	East Fowl River Bridge, Alabama	NOS	8735523	30.443700790405273	-88.11389923095703	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Fowl River Bridge	AL
95291	Coast Guard sector, Mobile, Alabama	NOS	8736897	30.6495	-88.05811111111112	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coast Guard Sector Mobile	AL
95292	Mobile (Mobile State Docks), Alabama	NOS	8737048	30.70461111111111	-88.03961111111111	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8199999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mobile State Docks	AL
95293	Chickasaw Creek, Alabama	NOS	8737138	30.78190040588379	-88.07360076904297	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.860000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chickasaw Creek	AL
95294	Lower Bryant Landing, Tensay River, Alabama	NOS	8737373	30.9783	-87.8733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9300000000000033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Bryant Landing	AL
95295	West Fowl River Bridge, Alabama	NOS	8738043	30.37660026550293	-88.15859985351562	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Fowl River Bridge	AL
95296	Bayou La Batre Bridge, Alabama	NOS	8739803	30.40570068359375	-88.2477035522461	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bayou La Batre Bridge	AL
95297	Grand Bay NERR, Mississippi Sound, Mississippi	NOS	8740166	30.41319444444444	-88.4028888888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grand Bay NERR, Mississippi Sound	MS
95298	Petit Bois Island, Mississippi Sound, Mississippi	NOS	8740405	30.2033	-88.4417	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PETIT BOIS ISLAND, MISS. SOUND	MS
95299	Pascagoula, south side, Mississippi	NOS	8740993	30.322200775146484	-88.50800323486328	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8099999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pascagoula, South Side	MS
95300	Dock E, Port of Pascagoula, Mississippi	NOS	8741041	30.3477778	-88.5058333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dock E, Port of Pascagoula	MS
95301	Pascagoula Point, Mississippi Sound, Mississippi	NOS	8741196	30.34	-88.5333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pascagoula Point	MS
95302	Pascagoula NOAA Lab, Pascagoula River, Mississippi	NOS	8741533	30.36777777777778	-88.56305555555555	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pascagoula NOAA Lab	MS
95303	Gautier, Mississippi	NOS	8741798	30.3833	-88.61	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gautier	MS
95304	Graveline Bayou entrance, Mississippi	NOS	8742205	30.3617	-88.6633	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAVELINE BAYOU ENTRANCE	MS
95305	Horn Island, Mississippi Sound, Mississippi	NOS	8742221	30.2383	-88.6667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horn Island	MS
95306	North Shore, Mississippi	NOS	8742523	30.3733	-88.705	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8699999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Shore	MS
95307	Hollingsworth Point, Davis Bayou, Mississippi	NOS	8743081	30.3867	-88.7733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9099999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HOLLINGSWORTH POINT, DAVIS BAYOU	MS
95308	Ocean Springs Marina, Old Fort Bayou, Mississippi	NOS	8743181	30.4217	-88.7883	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Fort Bayou, Ocean Springs Marina	MS
95309	Ocean Springs, Mississippi	NOS	8743281	30.3917	-88.7983	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.870000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocean Springs	MS
95310	Bayou Talla, Back Bay, Biloxi, Mississippi	NOS	8743301	30.43	-88.8	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8599999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYOU TALLA, BACK BAY OF BILOXI	MS
95311	Ocean Springs, Old Fort Bayou, Mississippi	NOS	8743495	30.42	-88.8283	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9300000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OCEAN SPRINGS, OLD FORT BAYOU	MS
95312	Bayou Poito, Back Bay, Biloxi, Mississippi	NOS	8743639	30.4383	-88.845	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYOU POITO, BACK BAY OF BILOXI	MS
95313	Biloxi (Cadet Point), Biloxi Bay, Mississippi	NOS	8743735	30.39	-88.8567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biloxi (Cadet Point)	MS
95314	Deer Island, Mississippi	NOS	8743812	30.3833	-88.8667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deer Island	MS
95315	Langley Point, Mississippi	NOS	8743838	30.425	-88.87	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Langley Point	MS
95316	Biloxi, Biloxi Bay, Mississippi	NOS	8744117	30.4117	-88.9033	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biloxi	MS
95319	Popps Ferry, Back Bay, Biloxi, Mississippi	NOS	8744671	30.4133	-88.975	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POPPS FERRY, BACK BAY OF BILOXI	MS
95320	Ship Island, Mississippi Sound, Mississippi	NOS	8744756	30.2133	-88.9717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7899999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, Mississippi Sound	MS
95321	Biloxi River, lower end, Mississippi	NOS	8744934	30.435	-89.0083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BILOXI RIVER, LOWER END	MS
95322	Handsboro Bridge, Bernard Bayou, Mississippi	NOS	8745101	30.4067	-89.0267	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HANDSBORO BRIDGE, BERNARD BAYOU	MS
95323	Landon, Mississippi	NOS	8745555	30.4317	-89.0817	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Landon	MS
95324	Gulfport, Gulfport Harbor, Mississippi	NOS	8745557	30.36	-89.0817	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulfport Harbor	MS
95325	Pass Christian Yacht Club, Mississippi Sound, Mississippi	NOS	8746819	30.31	-89.245	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PASS CHRISTIAN YACHT CLUB, MISS. SOUND	MS
95326	Bay Waveland Yacht Club, Bay St. Louis, Mississippi	NOS	8747437	30.32634166666667	-89.3258	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Waveland Yacht Club	MS
95327	Waveland, Mississipi Sound, Mississippi	NOS	8747766	30.2817	-89.3667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waveland	MS
95328	Devon Energy Facility, Louisiana	NOS	8760417	29.20075	-89.04446666666666	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devon Energy Facility	LA
95329	South Pass, Louisiana	NOS	8760551	28.99	-89.14	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Pass	LA
95330	Grand Pass, Louisiana	NOS	8760668	30.126699447631836	-89.2217025756836	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAND PASS	LA
95331	Pilottown, Louisiana	NOS	8760721	29.17930555555556	-89.25883333333333	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilottown	LA
95333	Olga Compressor Station, Grand Bay, Louisiana	NOS	8760889	29.38655555555556	-89.3801388888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olga Compressor Station, Grand Bay	LA
95334	Pilots Station (east), Southwest Pass, Louisiana	NOS	8760922	28.9322	-89.4075	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilots Station East, S.W. Pass	LA
95335	Pilot Station, Southwest Pass, Louisiana	NOS	8760943	28.925	-89.4183	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6300000000000008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SW Pass	LA
95336	Shell Beach, Lake Borgne, Louisiana	NOS	8761305	29.86811111111111	-89.67325	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shell Beach	LA
95337	University of New Orleans vicinity, Chef Menteur Pass, Louisiana	NOS	8761385	30.06875	-89.802083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5799999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VICINITY OF UNO CHEF MENTEUR	LA
95338	The Rigolets, US Highway 90, Louisiana	NOS	8761402	30.1667	-89.7367	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Rigolets	LA
95339	Martello Castle, Lake Borgne, Louisiana	NOS	8761529	29.945	-89.835	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MARTELLO CASTLE, LAKE BORGNE	LA
95341	Grand Isle, Mississippi River Delta, Louisiana (2)	NOS	8761724	29.26333333333333	-89.95666666666666	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grand Isle	LA
95342	Mendicant Island, Barataria Bay, Louisiana	NOS	8761742	29.318300247192383	-89.9800033569336	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MENDICANT ISLAND, BARATARIA BAY	LA
95343	Texaco Dock, Hackberry Bay, Louisiana	NOS	8761819	29.4017	-90.0383	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.45999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TEXACO DOCK, HACKBERRY BAY	LA
95344	Caminada Pass (bridge), Louisiana	NOS	8761826	29.209999084472656	-90.04000091552734	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.48999999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHENIERE CAMINADA, CAMINADA PASS	LA
95345	Lafitte, Barataria Waterway, Louisiana	NOS	8761899	29.6667	-90.1117	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.17000000000000037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAFITTE, BARATARIA WATERWAY	LA
95346	New Canal USCG station, Lake Pontchartrain, Louisiana	NOS	8761927	30.02722222222222	-90.11333333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.27000000000000046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Canal Station	LA
95347	Port Fourchon, Belle Pass, Louisiana	NOS	8762075	29.114200592041016	-90.19930267333984	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.629999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Fourchon, Belle Pass	LA
95348	Leeville, Bayou Lafourche, Louisiana	NOS	8762084	29.2483	-90.2117	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LEEVILLE, BAYOU LAFOURCHE	LA
95349	Golden Meadow, Plaisance Canal, Louisiana	NOS	8762184	29.373300552368164	-90.26499938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2999999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GOLDEN MEADOW, PLAISANCE CANAL	LA
95350	East Timbalier Island, Timbalier Bay, Louisiana	NOS	8762223	29.0767	-90.285	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EAST TIMBALIER ISLAND, TIMBALIER BAY	LA
95428	Bayside, Copano Bay, Texas	NOS	8774652	28.068300247192383	-97.19560241699219	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.23000000000000043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BAYSIDE, COPANO BAY	TX
95351	East Bank 1, Norco, Bayou LaBranche, Louisiana	NOS	8762372	30.05033333333333	-90.368	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Bank 1, Norco, B. LaBranche	LA
95352	I-10 Bonnet Carre Floodway, Louisiana	NOS	8762483	30.067899703979492	-90.38999938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.29000000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-10 Bonnet Carre Floodway	LA
95354	East Isle Dernire, Lake Pelto, Louisiana	NOS	8762888	29.0717	-90.64	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	E. ISLE DERNIERES, LAKE PELTO	LA
95355	Cocodrie, Terrebonne Bay, Louisiana	NOS	8762928	29.245	-90.6617	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5599999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cocodrie	LA
95356	Texas Gas Platform, Caillou Bay, Louisiana	NOS	8763535	29.17477777777778	-90.97644444444444	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Texas Gas Platform, Caillou Bay	LA
95357	Fourleague Bay, Atchafalaya Bay, Louisiana	NOS	8763843	29.341800689697266	-91.135498046875	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fourleague Bay	LA
95358	Stouts Pass at Six Mile Lake, Louisiana	NOS	8764025	29.7433	-91.23	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4200000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stouts Pass at Six Mile Lake	LA
95359	Tesoro Marine Term., Atchafalaya River, Louisiana	NOS	8764044	29.6675	-91.23761111111111	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.28999999999999915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Berwick, Atchafalaya River	LA
95360	Lawma, Amerada Pass, Atchafalaya Bay, Louisiana	NOS	8764227	29.449600219726562	-91.33809661865234	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAWMA, Amerada Pass	LA
95362	Eugene Island, north of, Louisiana	NOS	8764314	29.36750030517578	-91.38390350341797	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0200000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eugene Island, North of, Atchafalaya Bay	LA
95363	Weeks Bay, Louisiana	NOS	8765148	29.83722222222222	-91.8375	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.89	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weeks Bay	LA
95364	Cypremort Point, Louisiana	NOS	8765251	29.71336111111111	-91.88	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cypremort Point	LA
95365	Bayou Fearman, Vermillion Bay, Louisiana	NOS	8765746	29.674400329589844	-92.13520050048828	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bayou Fearman, Vermillion Bay	LA
95366	Intracoastal City, Louisiana	NOS	8765785	29.783000946044922	-92.15560150146484	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Intracoastal City	LA
95367	Freshwater Bayou, Louisiana	NOS	8765969	29.655399322509766	-92.25070190429688	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4499999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freshwater Bayou	LA
95368	Schooner Bayou, Vermillion Bay, Louisiana	NOS	8765994	29.758100509643555	-92.26380157470703	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.620000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Schooner Bayou	LA
95369	Freshwater Canal Locks, Louisiana	NOS	8766072	29.55169444444444	-92.30519444444444	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freshwater Canal Locks	LA
95370	Joseph Harbor, Louisiana	NOS	8766941	29.637500762939453	-92.76719665527344	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2399999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Joseph Harbor	LA
95371	Catfish Point, Louisiana	NOS	8767095	29.862899780273438	-92.8488998413086	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.740000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Catfish Point	LA
95372	Mermentau River, Grand Chenier, Louisiana	NOS	8767403	29.774999618530273	-93.00830078125	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0399999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MERMENTAU RIVER, GRAND CHENIER	LA
95373	Lake Charles, Calcasieu River, Louisiana	NOS	8767816	30.2236111	-93.2216667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7800000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Charles	LA
95374	East Calcasieu Lake, Louisiana	NOS	8767911	29.993900299072266	-93.27050018310547	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Calcasieu Lake	LA
95375	Bulk terminal, Calcasieu Ship Channel, Louisiana	NOS	8767961	30.19029998779297	-93.30069732666016	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bulk Terminal	LA
95376	Calcasieu Pass, east jetty, Louisiana	NOS	8768094	29.76816666666667	-93.3428888888889	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.120000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Calcasieu Pass	LA
95377	Gum Cove, ICWW, Louisiana	NOS	8768772	30.058700561523438	-93.52259826660156	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.509999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gum Cove, ICWW	LA
95378	East Sabine Lake, Louisiana	NOS	8769858	29.812700271606445	-93.86209869384766	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Sabine Lake	LA
95380	Rainbow Bridge, Neches River, Texas	NOS	8770520	29.979999542236328	-93.88169860839844	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5499999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rainbow Bridge	TX
95381	Mesquite Point, Sabine Pass, Texas	NOS	8770539	29.7667	-93.895	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mesquite Point	TX
95382	Buffalo Bayou, Houston Ship Channel, Galveston Bay, Texas	NOS	8770542	29.761899948120117	-95.34429931640625	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buffalo Bayou	TX
95383	Round Point, Trinity Bay, Galveston Bay, Texas	NOS	8770559	29.7133	-94.69	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.76	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Round Point	TX
95384	Sabine Pass (north), Texas	NOS	8770570	29.7284	-93.8701	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9700000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass North	TX
95385	Orange (Old Navy Base), Texas	NOS	8770597	30.0983	-93.7217	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orange	TX
95386	Barbours Cut, Morgans Point, Galveston Bay, Texas	NOS	8770613	29.6816667	-94.985	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Morgans Point, Barbours Cut	TX
95387	Umbrella Point, Trinity Bay, Texas	NOS	8770625	29.68	-94.8683	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7000000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UMBRELLA POINT, TRINITY BAY	TX
95388	Cypress, San Jacinto River, Galveston Bay, Texas	NOS	8770653	29.84670066833496	-95.08830261230469	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CYPRESS, SAN JACINTO RIVER	TX
95389	Lynchburg Landing, San Jacinto River, Galveston Bay, Texas	NOS	8770733	29.76486111111111	-95.07886111111111	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lynchburg Landing	TX
95390	San Jacinto Battleground State Historic Site, Texas	NOS	8770743	29.75670051574707	-95.08999633789062	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Battleship Texas State Park	TX
95391	COX WC-53 Platform, Louisiana	NOS	8770752	29.62400054931641	-93.75	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3299999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COX WC-53 Platform	LA
95906	Hanamaulu Bay, Kauai Island, Hawaii	NOS	1611443	21.995	-159.335	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94650	00:04:00	\N	0.91	00:10:00	\N	1	\N	\N	Hanamaulu Bay	HI
95392	Houston Ship Channel, Galveston Bay, Manchester, Texas	NOS	8770777	29.726299285888672	-95.26580047607422	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Manchester	TX
95393	High Island (TCOON), Texas	NOS	8770808	29.59469985961914	-94.39029693603516	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	High Island	TX
95394	Texas Point, Sabine Pass, Texas	NOS	8770822	29.689300537109375	-93.841796875	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Texas Point, Sabine Pass	TX
95395	Smith Point, Galveston Bay, Texas	NOS	8770931	29.535	-94.7817	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SMITH POINT, GALVESTON BAY	TX
95396	Clear Lake, Galveston Bay, Texas	NOS	8770933	29.5633	-95.0667	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6399999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clear Lake	TX
95397	Rollover Pass, Texas	NOS	8770971	29.514999389648438	-94.51329803466797	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7399999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rollover Pass	TX
95398	Eagle Point, Galveston Bay, Texas	NOS	8771013	29.48130555555555	-94.91725277777778	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6100000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Point, Galveston Bay	TX
95399	Renaissance SA-13 Platform, Louisiana	NOS	8771050	29.47900009155273	-93.63999938964844	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Renaissance SA-13 Platform	LA
95400	Fieldwood WC-289 Platform, Louisiana	NOS	8771074	29.34700012207031	-93.63500213623047	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2199999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fieldwood WC-289 Platform	LA
95402	Goat Island, Galveston Bay, Texas	NOS	8771165	29.431100845336914	-94.71040344238281	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6599999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goat Island	TX
95403	Texas City, Galveston Bay, Texas	NOS	8771262	29.390600204467773	-94.88490295410156	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Texas City	TX
95404	Port Bolivar, Galveston Bay, Texas	NOS	8771328	29.365	-94.78	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8400000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Bolivar	TX
95405	Galveston Bay entrance, north jetty, Texas	NOS	8771341	29.35746111111111	-94.724725	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9700000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Bay Entrance, North Jetty	TX
95907	Hanalei Bay, Kauai Island, Hawaii	NOS	1611683	22.215	-159.502	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94650	-01:22:00	\N	0.91	-01:01:00	\N	1.07	\N	\N	Hanalei Bay	HI
95908	Hanauma Bay, Oahu Island, Hawaii	NOS	1612301	21.275	-157.697	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94651	-00:45:00	\N	1	-00:59:00	\N	1	\N	\N	Hanauma Bay	HI
95406	Sabine Offshore Light (USCG S-1 Platform), Louisiana	NOS	8771367	29.4689998626709	-93.72000122070312	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\nThese data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Offshore Light	LA
95407	Galveston Bay entrance, south jetty, Texas	NOS	8771416	29.32670021057129	-94.69329833984375	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.169999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Bay Entrance, South Jetty	TX
95408	Galveston Pier 21, Galveston Channel, Texas	NOS	8771450	29.31	-94.79330555555556	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Pier 21	TX
95409	Galveston Railroad Bridge, Texas	NOS	8771486	29.302600860595703	-94.89710235595703	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Railroad Bridge	TX
95410	Galveston Pleasure Pier, Galveston, Texas	NOS	8771510	29.2853	-94.7894	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1100000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Pleasure Pier	TX
95411	Jamaica Beach, Texas	NOS	8771722	29.19860076904297	-94.98829650878906	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.48999999999999844	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jamaica Beach	TX
95412	San Luis Pass (TCOON), Texas	NOS	8771972	29.094999313354492	-95.11329650878906	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6900000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Luis Pass	TX
95413	Old Brazos River, Freeport, Texas	NOS	8772391	28.96109962463379	-95.36740112304688	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Brazos River Freeport	TX
95414	Freeport, DOW Barge Canal, Texas	NOS	8772440	28.9483	-95.3083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9500000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport	TX
95415	USCG Freeport, Texas	NOS	8772447	28.94330555555555	-95.3025	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9000000000000021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport	TX
95416	Freeport SPIP, Freeport Harbor, Texas	NOS	8772471	28.935699462890625	-95.29419708251953	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9100000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport Harbor	TX
95417	Quintana Jetty (Freeport entrance jetty), Texas	NOS	8772479	28.930299758911133	-95.30590057373047	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9200000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Freeport Entrance Jetty	TX
95418	Sargent (TCOON), Texas	NOS	8772985	28.77163888888889	-95.61683333333333	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sargent	TX
95419	Seadrift, San Antonio Bay, Texas	NOS	8773037	28.40690040588379	-96.71240234375	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.18999999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seadrift	TX
95420	Matagorda City (TCOON), Texas	NOS	8773146	28.709999084472656	-95.91390228271484	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matagorda City	TX
95421	Port Lavaca, Lavaca Causeway, Matagorda Bay, Texas	NOS	8773259	28.640600204467773	-96.60980224609375	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Lavaca	TX
95422	Port O'Connor, Matagorda Bay, Texas	NOS	8773701	28.45170021057129	-96.38829803466797	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.40000000000000036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port O'Connor	TX
95423	Matagorda Bay entrance channel, Texas	NOS	8773767	28.42690086364746	-96.3301010131836	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.740000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matagorda Bay Entrance Channel	TX
95424	Barroom Bay, Espiritu Santo Bay, Texas	NOS	8773808	28.402999877929688	-96.48079681396484	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.21999999999999886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barroom Bay	TX
95425	Shoalwater Flats, Espiritu Santo Bay, Texas	NOS	8773896	28.364500045776367	-96.5802993774414	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.1700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shoalwater Flats	TX
95426	Aransas Wildlife Refuge (TCOON), Texas	NOS	8774230	28.228300094604492	-96.79499816894531	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.1700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aransas Wildlife Refuge	TX
95427	Copano Bay State Fishing Pier, Texas	NOS	8774513	28.11440086364746	-97.02439880371094	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.20999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Copano Bay	TX
95429	Rockport, Aransas Bay, Texas	NOS	8774770	28.0216667	-97.0466667	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.1899999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockport	TX
95430	Conn Brown Harbor, Aransas Pass, Texas	NOS	8775083	27.908100128173828	-97.13529968261719	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ARANSAS PASS, REDFISH BAY	TX
95431	Portland, Nueces Bay, Corpus Christi Bay, Texas	NOS	8775131	27.88279914855957	-97.34310150146484	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland	TX
95432	La Quinta Channel North, Corpus Christi Bay, Texas	NOS	8775132	27.880399703979492	-97.27349853515625	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	La Quinta Channel North	TX
95433	White Point Bay, Texas	NOS	8775188	27.858299255371094	-97.4749984741211	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	White Point	TX
95434	Viola Turning Basin, Corpus Christi Bay, Texas	NOS	8775222	27.846099853515625	-97.52069854736328	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.40000000000000213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Viola Turning Basin	TX
95435	Port Aransas, Texas	NOS	8775237	27.83970069885254	-97.07250213623047	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6499999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Aransas	TX
95436	Aransas, Aransas Pass, Texas	NOS	8775241	27.836599349975586	-97.03910064697266	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8300000000000018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aransas, Aransas Pass	TX
95437	Nueces Bay (TCOON), Texas	NOS	8775244	27.832799911499023	-97.48590087890625	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.38000000000000256	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nueces Bay	TX
95438	Port Aransas (H. Caldwell Pier), Texas	NOS	8775270	27.82670021057129	-97.05000305175781	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9199999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PORT ARANSAS, H. CALDWELL PIER	TX
95439	Enbridge Energy dock, Ingleside, Corpus Christi Channel, Texas	NOS	8775283	27.81861111111111	-97.20894444444444	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Enbridge, Ingleside	TX
95440	Texas State Aquarium, Corpus Christi, Texas	NOS	8775296	27.814899444580078	-97.38919830322266	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	USS Lexington, Corpus Christi Bay	TX
95441	Corpus Christi Naval Air Station, Corpus Christi Bay, Texas	NOS	8775421	27.704999923706055	-97.27999877929688	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naval Air Station	TX
95442	Packery Channel, Texas	NOS	8775792	27.63330078125	-97.23670196533203	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Packery Channel	TX
95443	Bob Hall Pier, Corpus Christi, Texas	NOS	8775870	27.579999923706055	-97.2166976928711	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bob Hall Pier, Corpus Christi	TX
95444	Padre Island, Port Mansfield Channel ent., Texas	NOS	8778485	26.564199447631836	-97.27649688720703	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Padre Island, Port Mansfield Channel Ent	TX
95909	Waimanalo, Oahu Island, Hawaii	NOS	1612376	21.335	-157.693	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94655	00:05:00	\N	0.75	00:11:00	\N	0.88	\N	\N	Waimanalo	HI
95910	Waianae, Oahu Island, Hawaii	NOS	1612482	21.445	-158.192	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94651	00:18:00	\N	1	00:20:00	\N	0.93	\N	\N	Waianae	HI
95445	Realitos Peninsula, Texas	NOS	8779280	26.262399673461914	-97.2853012084961	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Realitos Peninsula	TX
95446	USCG station, South Padre Island, Texas	NOS	8779748	26.07309913635254	-97.1675033569336	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Padre Island CG Station	TX
95447	South Padre Island, Brazos Santiago Pass, Texas	NOS	8779749	26.0674991607666	-97.15480041503906	:America/Chicago	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data and associated tidal datums are derived from the Texas Coastal\nOcean Observation Network (TCOON), a state-wide coastal observing system.\nLeveling information used to verify vertical positioning for navigational\npurposes may not meet NOS standards. Subsequent review of these data based\nupon field inspections may result in revisions. Data users are cautioned\nbefore using these data for critical decisions such as those that concern\nphysical or public safety.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.870000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPI Brazos Santiago	TX
95448	Padre Island, Brazos Santiago Pass, Texas	NOS	8779750	26.0683	-97.1567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8799999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Padre Island, Brazos Santiago Pass	TX
95449	Port Isabel, Laguna Madre, Texas	NOS	8779770	26.06116666666667	-97.21552777777778	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.81	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Isabel	TX
95450	San Martin Lake Channel, Texas	NOS	8779911	26.001800537109375	-97.29859924316406	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Martin Lake Channel	TX
95451	Wilson Cove, San Clemente Island, California	NOS	9410032	33.005001068115234	-118.55699920654297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WILSON COVE, SAN CLEMENTE IS.	CA
95452	Avalon, Santa Catalina Island, California	NOS	9410079	33.345001220703125	-118.32499694824219	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.719999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AVALON, SANTA CATALINA ISLAND	CA
95453	South San Diego Bay, California	NOS	9410135	32.62910079956055	-117.10780334472656	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South San Diego Bay	CA
95454	Ballast Point, California	NOS	9410155	32.6867	-117.233	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.799999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ballast Point	CA
95455	San Diego, San Diego Bay, California	NOS	9410170	32.71555555555555	-117.1766666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Diego	CA
95456	Mission Bay, California	NOS	9410196	32.793701171875	-117.22380065917969	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8100000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mission Bay	CA
95457	La Jolla (Scripps Institution Wharf), California	NOS	9410230	32.86688888888889	-117.2571388888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	La Jolla	CA
95458	Newport Beach, Newport Bay entrance, Corona del Mar, California	NOS	9410580	33.6033	-117.883	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7800000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEWPORT BEACH, NEWPORT BAY ENTRANCE	CA
95459	Los Angeles (outer harbor), California	NOS	9410660	33.71994444444444	-118.2728611111111	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Los Angeles	CA
95460	Long Beach, Terminal Island, California	NOS	9410680	33.7517	-118.227	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LONG BEACH, TERMINAL ISLAND	CA
95461	Santa Monica, Municipal Pier, San Pedro Channel, California	NOS	9410840	34.0083	-118.5	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7900000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Monica	CA
95462	Rincon Island, Mussel Shoals, Santa Barbara Channel, California	NOS	9411270	34.3483	-119.443	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RINCON ISLAND, PACIFIC OCEAN	CA
95463	Santa Barbara, California	NOS	9411340	34.40458888888889	-119.6924944444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.78	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Barbara	CA
95464	Gaviota State Park, California	NOS	9411399	34.46938888888889	-120.2283055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gaviota State Park, Pacific Ocean	CA
95465	Oil Platform Harvest (Topex Project), California	NOS	9411406	34.46916666666667	-120.6819444444444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.719999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oil Platform Harvest	CA
95466	Port San Luis, California	NOS	9412110	35.176700592041016	-120.76000213623047	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port San Luis	CA
95467	Mansfield Cone, California	NOS	9412802	35.94952777777777	-121.4819444444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.7399999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mansfield Cone	CA
95468	Monterey, Monterey Harbor, California	NOS	9413450	36.6088889	-121.8913889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Monterey	CA
95469	Elkhorn Slough at Elkhorn, Monterey Bay, California	NOS	9413631	36.81829833984375	-121.74700164794922	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elkhorn Slough at Elkhorn	CA
95470	Tidal Creek, Elkhorn Slough, Monterey Bay, Port San Luis, California	NOS	9413643	36.83330154418945	-121.74500274658203	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8699999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tidal Creek, Elkhorn Slough	CA
95471	Kirby Park, Elkhorn Slough, Monterey Bay, Port San Luis, California	NOS	9413651	36.84130096435547	-121.74530029296875	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.950000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kirby Park, Elkhorn Slough	CA
95472	Elkhorn Slough railroad bridge, Monterey Bay, California	NOS	9413663	36.85667	-121.755	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9300000000000033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elkhorn Slough Railroad Bridge	CA
95473	Pillar Point Harbor, Half Moon Bay, California	NOS	9414131	37.5025	-122.4821666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9899999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point Harbor	CA
95474	San Francisco, San Francisco Bay, California	NOS	9414290	37.80630555555555	-122.4658888888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.119999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco	CA
95476	Rincon Point, Pier 22, San Francisco Bay, California	NOS	9414317	37.79	-122.387	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PIER 22 1/2, SAN FRANCISCO	CA
95477	Hunters Point, San Francisco Bay, California	NOS	9414358	37.73	-122.357	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.5600000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HUNTERS POINT, S.F. BAY	CA
95478	Oyster Point Marina, San Francisco Bay, California	NOS	9414392	37.665	-122.377	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7700000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OYSTER POINT MARINA, SAN FRANCISCO BAY	CA
95479	San Mateo Bridge (west end), San Francisco Bay, California	NOS	9414458	37.58	-122.253	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.109999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Mateo Bridge	CA
95481	Dumbarton Highway Bridge, San Francisco Bay, California	NOS	9414509	37.5067	-122.115	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.68	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dumbarton Bridge	CA
95482	Redwood City, Wharf 5, San Francisco Bay, California	NOS	9414523	37.50681388888889	-122.2119055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redwood City	CA
95483	Coyote Creek, Alviso Slough, San Francisco Bay, California	NOS	9414575	37.465	-122.023	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.869999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coyote Creek	CA
95484	San Leandro Marina, San Francisco Bay, California	NOS	9414688	37.695	-122.192	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.920000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Leandro Marina	CA
95485	Oakland Harbor, Park Street Bridge, San Francisco Bay, California	NOS	9414746	37.7717	-122.235	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3800000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PARK STREET BRIDGE	CA
95486	Alameda, San Francisco Bay, California	NOS	9414750	37.77195277777778	-122.3002611111111	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.45	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alameda	CA
95487	Oakland Inner Harbor, San Francisco Bay, California	NOS	9414764	37.795	-122.282	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor	CA
95488	Alameda Naval Air Station fuel pier, San Francisco Bay, California	NOS	9414767	37.7933	-122.315	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ALAMEDA NAS, NAVY FUEL PIER	CA
95489	Sausalito, San Francisco Bay, California	NOS	9414806	37.8467	-122.477	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0700000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAUSALITO, SAN FRANCISCO BAY	CA
95490	Nurse Slough, Bradmoor Island, Suisun Bay, California	NOS	9414811	38.1833	-121.923	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bradmoor Island	CA
95491	Berkeley, San Francisco Bay, California	NOS	9414816	37.8650016784668	-122.30699920654297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.2800000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BERKELEY,S.F.BAY	CA
95492	Sausalito, Corps of Engineers Dock, San Francisco Bay, California	NOS	9414819	37.865	-122.493	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SAUSALITO, COE DOCK, S.F. BAY	CA
95493	Chevron Oil Company Pier, Richmond, San Francisco Bay, California	NOS	9414863	37.92829895019531	-122.4000015258789	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond	CA
95494	Corte Madera Creek, San Francisco Bay, California	NOS	9414874	37.94329833984375	-122.51300048828125	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CORTE MADERA CREEK	CA
95495	Bolinas, Bolinas Lagoon, California	NOS	9414958	37.90800094604492	-122.67849731445312	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bolinas, Bolinas Lagoon	CA
95496	Drakes Bay, Point Reyes, California	NOS	9415020	37.9941667	-122.9736111	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.0999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Reyes	CA
95497	Blackslough Landing, San Joaquin River, California	NOS	9415021	37.994998931884766	-121.41999816894531	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8400000000000318	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BLACKSLOUGH LANDING, SAN JOAQUIN RIVER	CA
95498	Pinole Point, San Pablo Bay, California	NOS	9415056	38.015	-122.363	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Point, San Pablo Bay	CA
95499	Antioch, San Joaquin River, California	NOS	9415064	38.02	-121.815	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ANTIOCH, SAN JOAQUIN RIVER	CA
95500	Martinez-Amorco Pier, California	NOS	9415102	38.03463888888889	-122.1251944444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Martinez-Amorco Pier	CA
95501	Wards Island, Little Connection Slough, San Joaquin River, California	NOS	9415105	38.04999923706055	-121.49700164794922	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WARDS ISLAND, SAN JOAQUIN RIVER	CA
95502	Mallard Island Ferry Wharf, Suisun Bay, California	NOS	9415112	38.0433	-121.918	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MALLARD ISLAND, SUISUN BAY	CA
95503	Crockett, Carquinez Strait, California	NOS	9415143	38.0583	-122.223	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.210000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CROCKETT, CARQUINEZ STRAIT	CA
95504	Port Chicago, Suisun Bay, California	NOS	9415144	38.056	-122.0395	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5599999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Chicago	CA
95505	Threemile Slough entrance, San Joaquin River, California	NOS	9415193	38.086700439453125	-121.68499755859375	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THREE MILE SLOUGH,SAN JOAQUIN R.	CA
95506	Mare Island Naval Shipyard, Carquinez Strait, California	NOS	9415218	38.07	-122.25	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mare Island	CA
95507	Korths Harbor, San Joaquin River, California	NOS	9415229	38.097599029541016	-121.56839752197266	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.5999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KORTHS HBR, SAN JOAQUIN RIVER	CA
95508	Petaluma River entrance, San Pablo Bay, California	NOS	9415252	38.11530555555556	-122.5056666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.2300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PETALUMA RIVER ENTRANCE	CA
95509	Suisun Slough entrance, Suisun Bay, California	NOS	9415265	38.1283	-122.073	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.61	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SUISUN SLOUGH ENTRANCE	CA
95510	Rio Vista, Sacramento River, California	NOS	9415316	38.145	-121.692	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.129999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rio Vista	CA
95511	Sonoma Creek, San Pablo Bay, California	NOS	9415338	38.1567	-122.407	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sonoma Creek Entrance	CA
95512	Lakeville, Petaluma River, California	NOS	9415423	38.1983	-122.547	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.45	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LAKEVILLE, PETALUMA RIVER	CA
95513	Upper drawbridge, Petaluma River, San Pablo Bay, California	NOS	9415584	38.2283	-122.613	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Petaluma River, Upper Drawbridge	CA
95514	Green Cove, California	NOS	9416409	38.70433333333333	-123.4493888888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Cove	CA
95515	Arena Cove, California	NOS	9416841	38.91455555555556	-123.7110833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1400000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arena Cove	CA
95516	Noyo Harbor, Fort Bragg, California	NOS	9417426	39.42577777777778	-123.8051111111111	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NOYO HARBOR	CA
95517	Shelter Cove, California	NOS	9418024	40.025001525878906	-124.05799865722656	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SHELTER COVE	CA
95518	Cockrobin Island Bridge, Eel River, San Francisco, California	NOS	9418637	40.63719940185547	-124.2822036743164	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3699999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cockrobin Island Bridge	CA
95519	Fields Landing, Humboldt Bay, California	NOS	9418723	40.7233	-124.222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.72	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	FIELDS LANDING, HUMBOLDT BAY	CA
95520	North Spit, Humboldt Bay, California	NOS	9418767	40.76690555555555	-124.2173444444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Spit	CA
95521	Samoa, Humboldt Bay, California	NOS	9418817	40.8267	-124.18	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Samoa, Humboldt Bay	CA
95523	Crescent City, California	NOS	9419750	41.74561111111111	-124.1843888888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6999999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crescent City	CA
95524	Pyramid Point, Smith River, California	NOS	9419945	41.94525	-124.2009166666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.419999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pyramid Point	CA
95525	Gold Beach, Rogue River, Oregon	NOS	9431011	42.42163888888889	-124.4187222222222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9099999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gold Beach	OR
95526	Port Orford, Oregon	NOS	9431647	42.73899841308594	-124.49829864501953	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Orford	OR
95527	Rink Creek entrance, Coquille River, Oregon	NOS	9432436	43.157901763916016	-124.18180084228516	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.490000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coquille River	OR
95528	Charleston, Coos Bay, Oregon	NOS	9432780	43.345001220703125	-124.3219985961914	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston	OR
95529	Halfmoon Bay, Umpqua River, Oregon	NOS	9433445	43.675	-124.192	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Half Moon Bay	OR
95530	Reedsport, Umpqua River, Oregon	NOS	9433501	43.70830154418945	-124.0979995727539	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.950000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REEDSPORT	OR
95531	Cushman, Siuslaw River, Oregon	NOS	9434068	43.98500061035156	-124.04499816894531	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9399999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cushman	OR
95532	Florence USCG Pier, Siuslaw River, Oregon	NOS	9434098	44.00210189819336	-124.12300109863281	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Florence USCG Pier, Siuslaw River	OR
95533	Waldport, Alsea Bay, Oregon	NOS	9434939	44.43436111111111	-124.0580833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldport	OR
95534	Weiser Point, Yaquina River, Oregon	NOS	9435308	44.5933	-124.008	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEISER POINT, YAQUINA RIVER	OR
95535	South Beach, Yaquina Bay and River, Oregon	NOS	9435380	44.62544444444445	-124.0449444444444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.449999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Beach	OR
95536	Depoe Bay, Oregon	NOS	9435827	44.81	-124.058	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	DEPOE BAY	OR
95537	Chinook Bend, Siletz River, Oregon	NOS	9435992	44.880001068115234	-123.9636001586914	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.6999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chinook Bend	OR
95538	Cascade Head, Salmon River, Oregon	NOS	9436381	45.04794444444445	-124.0073055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cascade Head, Salmon River	OR
95539	Dick Point, Tillamook Bay, Oregon	NOS	9437381	45.4817	-123.902	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3099999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dick Point	OR
95540	Garibaldi, Tillamook Bay, Oregon	NOS	9437540	45.55453	-123.9189444443915	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Garibaldi	OR
95541	North jetty, Tillamook Bay, Oregon	NOS	9437585	45.56999969482422	-123.96499633789062	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.270000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH JETTY, TILLAMOOK BAY	OR
95542	North Fork, Nehalem River, Oregon	NOS	9437954	45.73379898071289	-123.87640380859375	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.450000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Fork	OR
95543	Cathcart Landing, Youngs River, Oregon	NOS	9438772	46.12425	-123.8043333333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.659999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cathcart Landing	OR
95544	Hammond, Oregon	NOS	9439011	46.2017	-123.945	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hammond	OR
95545	Tongue Point, Astoria, Columbia River, Oregon	NOS	9439040	46.20731	-123.76830555558205	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Astoria	OR
95546	Wauna, Columbia River, Oregon	NOS	9439099	46.15999984741211	-123.40499877929688	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wauna	OR
95547	Rocky Point, Multnomah Channel, Oregon	NOS	9439189	45.6967	-122.868	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4199999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rocky Point	OR
95548	Saint Helens, Columbia River, Oregon	NOS	9439201	45.8650016784668	-122.7969970703125	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.4900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Helens	OR
95549	Portland, Morrison Street Bridge, Oregon	NOS	9439221	45.51	-122.673	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Morrison Street Bridge	OR
95550	Washougal, Columbia River, Washington	NOS	9440047	45.57830047607422	-122.38200378417969	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WASHOUGAL, COLUMBIA RIVER	WA
95551	Beacon Rock State Park, Columbia River, Washington	NOS	9440079	45.62030029296875	-122.02030181884766	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7800000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beacon Rock State Park	WA
95552	Vancouver, Columbia River, Washington	NOS	9440083	45.63117222222222	-122.6957722222222	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3499999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vancouver	WA
95553	Knapp Landing, Columbia River, Washington	NOS	9440171	45.74169921875	-122.75499725341797	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KNAPP(THORNES)LNDG, WILLOW BAR	WA
95554	Temco Kalama Terminal, Columbia River, Washington	NOS	9440357	45.98366666666666	-122.8346111111111	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TEMCO Kalama Terminal	WA
95555	Longview, Columbia River, Washington	NOS	9440422	46.10609817504883	-122.9542007446289	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0199999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Longview	WA
95556	Cape Horn, Columbia River, Washington	NOS	9440482	46.15169906616211	-123.29000091552734	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9899999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE HORN, COLUMBIA RIVER	WA
95557	Barlow Point, Columbia River, Washington	NOS	9440483	46.152198791503906	-123.03919982910156	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.2699999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barlow Point	WA
95558	Skamokawa, Steamboat Slough, Columbia River, Washington	NOS	9440569	46.27030555555555	-123.4565	:America/Los_Angeles	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Columbia River Datum (CRD) is the adopted fixed low water reference plane for\nthis area. CRD is a U.S. Army Corps of Engineers non-tidal datum defined at\ndistinct river miles relative to NAVD88, and is used as chart datum above\nriver mile 23 on the Columbia River. Datums are computed using observations\nfrom the low river stages of the year, generally August through October due to\nthe masking of the tidal signal from strong seasonal river runoff during other\nportions of the year. Depending on river flow, water levels can be\nsignificantly higher than Columbia River Datum. As of 2014, the U.S. Army\nCorps of Engineers provided updated offsets for CRD that have been applied to\nthis station. Station Datum (STND) is no longer set equal to CRD.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6599999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skamokawa	WA
95559	Cape Disappointment, Washington	NOS	9440581	46.28102777777778	-124.0462777777778	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.299999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Disappointment	WA
95560	Greenhead Slough, Washington	NOS	9440650	46.37220001220703	-123.95030212402344	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.890000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Greenhead Slough	WA
95561	Nahcotta, Willapa Bay, Washington	NOS	9440747	46.5017	-124.023	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAHCOTTA, WILLAPA BAY	WA
95562	South Bend, Willapa River, Willapa Bay, Washington	NOS	9440875	46.6633	-123.798	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH BEND	WA
95563	Toke Point, Willapa Bay, Washington	NOS	9440910	46.7075	-123.9669444	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.780000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Toke Point	WA
95564	Westport, Point Chehalis, Grays Harbor, Washington	NOS	9441102	46.90431	-124.1050833331214	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Westport	WA
95565	Aberdeen, Grays Harbor, Washington	NOS	9441187	46.9683	-123.853	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.6000000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aberdeen	WA
95567	La Push, Quillayute River, Washington	NOS	9442396	47.91283611111111	-124.6357388888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	La Push, Quillayute River	WA
95568	Tskawahyah Island, Cape Alava, Washington	NOS	9442705	48.17110061645508	-124.73690032958984	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.669999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tskawahyah Island, Cape Alava	WA
95569	Neah Bay, Strait Of Juan De Fuca, Washington	NOS	9443090	48.37072222222222	-124.6015888888889	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Neah Bay	WA
95570	Sekiu, Clallam Bay, Strait of Juan de Fuca, Washington	NOS	9443361	48.2633	-124.297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SEKIU, CLALLAM BAY	WA
95571	Jim Creek, Washington	NOS	9443551	48.187198638916016	-124.0625	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.059999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jim Creek	WA
95572	Port Angeles, Strait Of Juan De Fuca, Washington	NOS	9444090	48.125	-123.44000244140625	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.240000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Angeles	WA
95573	Port Townsend (Point Hudson), Admiralty Inlet, Washington	NOS	9444900	48.11122222222222	-122.7596777777778	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Townsend	WA
95574	Foulweather Bluff, Washington	NOS	9445016	47.9267	-122.617	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.869999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff	WA
95575	Bangor Wharf, Washington	NOS	9445133	47.7483	-122.727	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor	WA
95576	Union, Hood Canal, Washington	NOS	9445478	47.3583	-123.098	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UNION, HOOD CANAL	WA
95577	Bremerton, Sinclair Inlet, Port Orchard, Puget Sound, Washington	NOS	9445958	47.56169891357422	-122.62300109863281	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.8199999999999985	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bremerton	WA
95578	Wauna, Carr Inlet, Puget Sound, Washington	NOS	9446291	47.378299713134766	-122.63400268554688	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.640000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wauna	WA
95579	Tacoma, Commencement Bay, Sitcum Waterway, Puget Sound, Washington	NOS	9446484	47.266700744628906	-122.41329956054688	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tacoma	WA
95580	Yoman Point, Anderson Island, Balch Passage, Puget Sound, Washington	NOS	9446705	47.18	-122.675	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	YOMAN POINT, ANDERSON ISLAND	WA
95581	Sandy Point, Anderson Island, Puget Sound, Washington	NOS	9446804	47.15299987792969	-122.67510223388672	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.619999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANDY POINT ANDERSON ISLAND, PUGET SOUND	WA
95582	Budd Inlet, south of Gull Harbor, Washington	NOS	9446807	47.0983	-122.895	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.329999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUDD INLET, SOUTH OF GULL HARBOR	WA
95583	Seattle, Puget Sound, Washington	NOS	9447130	47.60263888888889	-122.3393055555556	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.64	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seattle	WA
95584	Everett, Washington	NOS	9447659	47.98	-122.223	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EVERETT	WA
95585	Priest Point, Washington	NOS	9447717	48.03494444444444	-122.2271944444445	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Priest Point	WA
95586	Tulalip, Tulalip Bay, Washington	NOS	9447773	48.065	-122.288	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tulalip, Tulalip Bay	WA
95587	Greenbank, Whidbey Island, Washington	NOS	9447883	48.105	-122.57	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.609999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Bank	WA
95588	Naval Air Station Whidbey Island, Washington	NOS	9447973	48.34280014038086	-122.68579864501953	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.439999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NAS Whidbey Island	WA
95589	Spee-Bi-Dah, Washington	NOS	9448009	48.08825	-122.3223333333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spee-Bi-Dah	WA
95590	Tulare Beach, Port Susan, Washington	NOS	9448043	48.10680555555555	-122.3472777777778	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.459999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tulare Beach, Port Susan	WA
95591	Sneeoosh Point, Washington	NOS	9448576	48.4	-122.548	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.390000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sneeoosh Point	WA
95593	Deception Pass St. Park, Bowman Bay, Fidalgo I., Washington	NOS	9448614	48.415000915527344	-122.6520004272461	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.630000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOWMAN BAY, FIDALGO ISLAND	WA
95594	Turner Bay, Similk Bay, Washington	NOS	9448657	48.445	-122.555	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turner Bay	WA
95595	Swinomish Channel entrance, Padilla Bay, Washington	NOS	9448682	48.45830154418945	-122.51300048828125	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.040000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Swinomish	WA
95596	Village Point, Lummi Island, Washington	NOS	9449161	48.7167	-122.708	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.010000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VILLAGE POINT, LUMMI ISLAND	WA
95597	Cherry Point, Strait of Georgia, Washington	NOS	9449424	48.86271666666666	-122.7585833333333	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.279999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point	WA
95598	Point Roberts, Strait of Georgia, Washington	NOS	9449639	48.974998474121094	-123.08300018310547	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.640000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Roberts	WA
95599	Drayton Harbor, Blaine, Strait of Georgia, Washington	NOS	9449679	48.9917	-122.765	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blaine, Drayton Harbor	WA
95600	Waldron Island, Haro Strait, Washington	NOS	9449746	48.686798095703125	-123.03759765625	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Waldron Island	WA
95601	Rosario, East Sound, Orcas Island, Washington	NOS	9449771	48.64670181274414	-122.87000274658203	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario, Orcas Island	WA
95602	Hanbury Point, Mosquito Pass, San Juan I., Haro Strait, Washington	NOS	9449828	48.5817	-123.17	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HANBURY POINT, SAN JUAN ISLAND	WA
95603	Kanaka Bay, San Juan Island, Haro Strait, Washington	NOS	9449856	48.48500061035156	-123.08300018310547	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.390000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanaka Bay, San Juan Island	WA
95604	Friday Harbor, San Juan Island, San Juan Channel, Washington	NOS	9449880	48.54527777777778	-123.0125	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.550000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Friday Harbor	WA
95605	Upright Head, Lopez Island, Washington	NOS	9449911	48.57170104980469	-122.88500213623047	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.620000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Head	WA
95606	Armitage Island, Thatcher Pass, Washington	NOS	9449932	48.535	-122.797	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.660000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Armitage Island	WA
95607	Richardson, Lopez Island, San Juan Channel, Washington	NOS	9449982	48.4467	-122.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richardson	WA
95608	Telegraph Bay, Washington	NOS	9449988	48.44329833984375	-122.80500030517578	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.71	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Telegraph Bay	WA
95627	Bradfield Canal, Alaska	NOS	9451012	56.1833	-131.572	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bradfield Canal	AK
95628	Village Rock, Zimovia Strait, Alaska	NOS	9451037	56.22	-132.297	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.36	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Village Rock	AK
95609	Windy Cove entrance, Alaska	NOS	9450251	55.0354	-133.0238	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.85	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance to Windy Cove	AK
95610	Dunbar Inlet GPS Tide Buoy, Alaska	NOS	9450286	55.0879	-132.81583	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.859999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dunbar Inlet GPS Tide Buoy	AK
95611	Custom House Cove, Mary Island, Alaska	NOS	9450296	55.1	-131.217	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Custom House Cove, Mary Island	AK
95612	Metlakatla, Port Chester, Alaska	NOS	9450314	55.1283	-131.567	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Metlakatla, Port Chester, AK	AK
95613	Hydaburg, Sukkwan Strait, Alaska	NOS	9450364	55.201698303222656	-132.822998046875	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.8100000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hydaburg, Sukkwan Strait	AK
95614	Ketchikan, Tongass Narrows, Alaska	NOS	9450460	55.3319444	-131.6261111	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketchikan	AK
95615	Trocadero Bay, Alaska	NOS	9450463	55.35166666666667	-132.9380555555556	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trocadero Bay	AK
95616	Craig, Klawock Inlet, Bucareli Bay, Alaska	NOS	9450551	55.4883	-133.142	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.34	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRAIG	AK
95617	Lindeman Cove, Kasaan Bay, Alaska	NOS	9450625	55.6017	-132.512	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.209999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lindeman Cove	AK
95618	Northern Carroll Inlet GPS Tide Buoy, Alaska	NOS	9450642	55.629	-131.362694	:America/Juneau	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.149999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northern Carroll Inlet GPS Tide Buoy	AK
95619	Nossuk Bay, Tonowek Bay, Gulf of Esquibel, Alaska	NOS	9450711	55.72166666666666	-133.35	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.46	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nossuk Bay	AK
95620	Magnetic Point, Union Bay, Earnest Sound, Alaska	NOS	9450753	55.78828333333333	-132.1908833333334	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Magnetic Point, Union Bay, Earnest Sound	AK
95621	Hyder, Portland Canal, Alaska	NOS	9450831	55.90449905395508	-130.01080322265625	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.550000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hyder	AK
95622	Burrough Bay, Behm Canal, Alaska	NOS	9450914	56.0383	-131.095	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrough Bay, Behm Canal	AK
95623	Thoms Point, Zimovia Strait, Alaska	NOS	9450970	56.1183	-132.078	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thoms Point	AK
95624	El Capitan Passage, Alaska	NOS	9450997	56.1633	-133.33	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.86	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EL Capitan Passage	AK
95625	Dry Pass, El Capitan Passage, Alaska	NOS	9450998	56.1633	-133.413	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dry Pass, EL Capitan Passage	AK
95626	Point Harrington, Clarence Strait, Alaska	NOS	9451005	56.1783	-132.697	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	POINT HARRINGTON, CLARENCE STRAIT	AK
95629	Port Alexander, Baranof Island, Alaska	NOS	9451054	56.2467	-134.647	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Alexander	AK
95630	Bushy Island, Snow Passage, Alaska	NOS	9451074	56.2767	-132.985	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BUSHY ISLAND, SNOW PASSAGE	AK
95631	Reef Point, Stikine Strait, Alaska	NOS	9451124	56.3533	-132.553	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REEF POINT, STIKINE STRAIT	AK
95632	Madan Bay, Clarence Strait, Alaska	NOS	9451152	56.3922	-132.169	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Madan Bay	AK
95633	Wrangell, Wrangell Island, Alaska	NOS	9451204	56.47	-132.387	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrangell	AK
95634	Monte Carlo Island, Keku Strait, Alaska	NOS	9451247	56.535	-133.767	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.6	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Monte Carlo Island	AK
95635	Point Lockwood, Woewodski Island, Wrangell Narrows, Alaska	NOS	9451263	56.5583	-132.963	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.729999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Lockwood	AK
95636	Beecher Pass, Wrangell Narrows, Alaska	NOS	9451287	56.595	-132.987	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.9	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beecher Pass	AK
95637	Anchor Point, Wrangell Narrows, Alaska	NOS	9451317	56.6383	-132.927	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point	AK
95638	Papke's Landing, Wrangell Narrows, Alaska	NOS	9451346	56.6767	-132.933	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.540000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Papke's Landing	AK
95639	The Summit, Keku Strait, Alaska	NOS	9451349	56.68242222222222	-133.7369083333333	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Summit	AK
95640	Golf Island, Necker Islands, Alaska	NOS	9451421	56.7867	-135.393	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golf Island	AK
95641	Leconte Bay, Frederick Sound, Alaska	NOS	9451422	56.7883	-132.502	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LECONTE BAY	AK
95642	Turn Point, Alaska	NOS	9451434	56.8	-132.98	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.34	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point	AK
95643	Entrance Island, Keku Strait, Alaska	NOS	9451438	56.8117	-133.787	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance Island	AK
95644	Red Bluff Bay, Baranof Island, Alaska	NOS	9451467	56.8567	-134.723	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.789999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bluff Bay, Baranof Island	AK
95645	Saginaw Bay, Kuiu Island, Frederick Sound, Alaska	NOS	9451497	56.90333333333334	-134.3030555555556	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saginaw Bay, Kuiu Island	AK
95646	Kake Harbor, Keku Strait, Alaska	NOS	9451528	56.94830555555556	-133.8947222222222	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.509999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kake Harbor, Keku Strait	AK
95647	Sitka, Baronof Island, Sitka Sound, Alaska	NOS	9451600	57.05169444444444	-135.342	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.290000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitka	AK
95648	Baranof, Warm Spring Bay, Alaska	NOS	9451625	57.08833333333333	-134.825	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baranof,  Warm Spring Bay	AK
95649	Whitestone Narrows, Neva Strait, Alaska	NOS	9451741	57.25	-135.567	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.319999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WHITESTONE NARROWS, Neva Strait	AK
95650	The Brothers, Stephens Passage, Alaska	NOS	9451785	57.295	-133.797	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	THE BROTHERS, STEPHENS PASSAGE	AK
95651	Scraggy Island, Alaska	NOS	9451805	57.34	-135.707	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scraggy Island	AK
95652	Sergius Narrows, Alaska	NOS	9451853	57.41	-135.627	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.97	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sergius Narrows	AK
95653	Provorotni Island, Alaska	NOS	9451936	57.515	-135.555	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.930000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Provorotni Island	AK
95654	Target Island, Mitchell Bay, Kootznahoo Inlet, Alaska	NOS	9451953	57.5333	-134.417	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.710000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Target Island, Mitchell Bay	AK
95655	Juneau, Gastineau Channel, Stephens Pass, Alaska	NOS	9452210	58.2988	-134.4106	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau	AK
95656	Hawk Inlet entrance, Alaska	NOS	9452294	58.085	-134.777	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawk Inlet	AK
95657	False Bay, Chatham Strait, Alaska	NOS	9452328	57.9667	-134.935	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	False Bay, Chatham Strait	AK
95658	Skagway, Taiya Inlet, Lynn Canal, Alaska	NOS	9452400	59.4508	-135.328	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.83	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagway, Taiya Inlet	AK
95659	Chilkat Inlet, Lynn Canal, Alaska	NOS	9452421	59.17	-135.4	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHILKAT INLET	AK
95660	Hoonah, Port Fredrick, Alaska	NOS	9452438	58.10755555555556	-135.4441944444444	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.910000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hoonah, Port Fredrick	AK
95661	Bartlett Cove, Glacier Bay, Alaska	NOS	9452534	58.45669937133789	-135.88299560546875	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.719999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BARTLETT COVE, GLACIER BAY	AK
95663	Pelican Harbor, Lisianski Inlet, Alaska	NOS	9452611	57.95777777777778	-136.2267777777778	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pelican Harbor, Lisianski Inlet, AK	AK
95664	Elfin Cove, Port Althorp, Cross Sound, Alaska	NOS	9452634	58.19472222222223	-136.3469444444444	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elfin Cove	AK
95665	Tarr Inlet, Glacier Bay, Alaska	NOS	9452749	58.96477777777778	-136.8775833333333	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	8.780000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tarr Inlet, Glacier Bay	AK
95666	Yakutat, Yakutat Bay, Alaska	NOS	9453220	59.5483333	-139.7330556	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.300000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yakutat, Yakutat Bay	AK
95668	Moraine Bay, Icy Bay, Alaska	NOS	9453443	59.93000030517578	-141.36300659179688	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.130000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moraine Bay	AK
95669	Cordova, Orca Inlet, Prince William Sd, Alaska	NOS	9454050	60.5575	-145.7554083333333	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.739999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cordova	AK
95670	Gravina River, Prince William Sound, Alaska	NOS	9454153	60.766700744628906	-146.0845947265625	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAVINA RIVER	AK
95671	Valdez, Prince William Sound, Alaska	NOS	9454240	61.125	-146.36199951171875	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valdez	AK
95672	Cape Hinchinbrook, Hinchinbrook Island, Alaska	NOS	9454329	60.23830032348633	-146.6479949951172	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.949999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Hichinbrook	AK
95673	Perch Point, Montague Island, Alaska	NOS	9454561	60.1267	-147.395	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Perch Point	AK
95674	Wooded Islands, Montague Island, Alaska	NOS	9454562	59.875	-147.403	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.390000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wooded Island	AK
95675	Seal Island, Alaska	NOS	9454564	60.425	-147.41	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SEAL ISLAND	AK
95676	Storey Island (north side), Alaska	NOS	9454571	60.7317	-147.437	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	6.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	STOREY ISLAND NORTH SIDE	AK
95677	Montague Island, Alaska	NOS	9454616	60.025	-147.592	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Island	AK
95678	South Arm, Knight Island, Bay of Isles, Alaska	NOS	9454652	60.3667	-147.7	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH ARM, KNIGHT ISLAND, BAY OF ISLES	AK
95679	Snug Harbor, Knight Island, Alaska	NOS	9454662	60.25	-147.717	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snug Harbor	AK
95680	College Fiord, Prince William Sound, Alaska	NOS	9454672	61.2057991027832	-147.7613983154297	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COLLEGE FIORD	AK
95681	Herring Point, Knight Island, Prince William Sound, Alaska	NOS	9454691	60.475	-147.792	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HERRING POINT, KNIGHT ISLAND, PR WIL SND	AK
95682	South Bay, Perry Island, Alaska	NOS	9454721	60.6717	-147.932	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.36	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PERRY ISLAND (SOUTH BAY)	AK
95683	Guguak, Alaska	NOS	9454751	60.1	-148.038	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guguak	AK
95684	Bainbridge Point, Bainbridge Island, Prince William Sound, Alaska	NOS	9454755	60.19670104980469	-148.04200744628906	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bainbridge Point	AK
95685	Point Elrington, Elrington Island, Prince William Sound, Alaska	NOS	9454814	59.9383	-148.227	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.680000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Erlington, Erlington Island	AK
95686	Whittier, Prince William Sound, Alaska	NOS	9454949	60.7783	-148.665	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whittier	AK
95687	Seward, Resurrection Bay, Alaska	NOS	9455090	60.1193	-149.4281083333333	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.56	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seward	AK
95688	Agnes Cove, Aialik Peninsula, Alaska	NOS	9455120	59.7733	-149.588	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.59	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AGNES COVE	AK
95689	Aialik Bay, north end, Alaska	NOS	9455145	59.9533	-149.715	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.530000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AIALIK BAY, NORTH END	AK
95690	Aialik Sill, Aialik Bay, Alaska	NOS	9455146	59.885	-149.718	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.559999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AIALIK SILL, AIALIK BAY	AK
95691	Camp Cove, Harris Peninsula, Alaska	NOS	9455151	59.6933	-149.748	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAMP COVE, HARRIS PENNINSULA	AK
95692	Crater Bay, Harris Bay, Alaska	NOS	9455159	59.7133	-149.787	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CRATER BAY, HARRIS BAY	AK
95693	Upper Northwestern Fiord, Harris Bay, Alaska	NOS	9455204	59.79	-150.032	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UPPER NORTHWESTERN FIORD	AK
95694	McCarty Fiord, Kenai Peninsula, Alaska	NOS	9455258	59.511600494384766	-150.35519409179688	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.93	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	McCarty Fiord	AK
95695	Seldovia, Cook Inlet, Alaska	NOS	9455500	59.44049835205078	-151.7198944091797	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.559999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seldovia	AK
95696	Kasitsna Bay, Kachemak Bay, Alaska	NOS	9455517	59.46830555555555	-151.565	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kasitsna Bay, Kachemak Bay	AK
95697	Homer, Coal Point, Kachemak Bay, Cook Inlet, Alaska	NOS	9455558	59.60139846801758	-151.4105987548828	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COAL POINT	AK
95698	Bear Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455595	59.725	-151.023	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Cove, Kachemak Bay	AK
95699	Anchor Point, Cook Inlet, Alaska	NOS	9455606	59.77197222222223	-151.8670277777778	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.709999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, Cook Inlet	AK
95700	Ninilchik, Cook Inlet, Alaska	NOS	9455653	60.055	-151.682	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ninilchik, Cook Inlet	AK
95701	Cape Kasilof, Cook Inlet, Alaska	NOS	9455711	60.3367	-151.38	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kasilof	AK
95702	Kaligan Island (north end), Cook Inlet, Alaska	NOS	9455732	60.51169967651367	-151.95199584960938	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KALIGAN ISLAND (NORTH END),  COOK INLET	AK
95703	Chinulna Point, Cook Inlet, Alaska	NOS	9455735	60.5033	-151.283	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CHINULNA POINT, COOK INLET	AK
95704	Nikiski, Cook Inlet, Alaska	NOS	9455760	60.6833333	-151.3980556	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.290000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikiski	AK
95705	Point Possession, Alaska	NOS	9455866	61.0367	-150.413	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	14.260000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Possession	AK
95706	North Foreland, Alaska	NOS	9455869	61.04330555555556	-151.163	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	11.500000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Foreland	AK
95707	Fire Island, Cook Inlet, Alaska	NOS	9455912	61.1733	-150.213	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	14.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, Cook Inlet	AK
95708	Anchorage, Knik Arm, Cook Inlet, Alaska	NOS	9455920	61.2375	-149.8903888888889	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	16.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchorage	AK
95709	Port Mackenzie, Cook Inlet, Alaska	NOS	9455934	61.2682991027832	-149.91700744628906	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	16.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Mackenzie	AK
95710	Goose Creek, Knik Arm, Cook Inlet, Alaska	NOS	9455963	61.3933	-149.847	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	17.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goose Creek, Cook Inlet	AK
95711	Southwest Iniskin Bay, Cook Inlet, Alaska	NOS	9456525	59.65169906616211	-153.4680938720703	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.729999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SW Iniskin Bay	AK
95712	Nukshak Island, Shelikof Strait, Alaska	NOS	9456717	58.3917	-153.958	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NUKSHAK ISLAND, SHELIKOF STRAIT	AK
95713	Aguchik Island, Kukak Bay, Alaska	NOS	9456901	58.29	-154.27	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.22	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	AGUCHIK ISLAND, KUKAK BAY	AK
95714	Ouzinkie, Spruce Island, Alaska	NOS	9457287	57.9217	-152.498	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ouzinkie, Spruce Island	AK
95715	Kodiak, Women's Bay, Alaska	NOS	9457292	57.7302778	-152.5138889	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kodiak Island	AK
95716	Uzkosti Point, Kupreanof Strait, Alaska	NOS	9457376	57.9283	-152.812	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uzkosti Point	AK
95717	Port Lions, Kodiak Island, Alaska	NOS	9457391	57.87347222222222	-152.8671111111111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.789999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Lions, AK	AK
95719	Nachalni Island, Kupreanof Strait, Alaska	NOS	9457407	57.9783	-152.925	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nachalni Island	AK
95720	Terror Bay (southwest), Kodiak Island, Alaska	NOS	9457493	57.74402777777778	-153.1954722222222	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.39	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SW Terror Bay	AK
95721	Sitkalidak Island GPS Tide Buoy, Alaska	NOS	9457512	56.96572	-153.252194	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.340000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitkalidak Island GPS Tide Buoy	AK
95722	Old Harbor, Kodiak Island, Alaska	NOS	9457527	57.20277777777778	-153.3038888888889	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.430000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	OLD HARBOR, KODIAK ISLAND	AK
95723	West Raspberry Island, Alaska	NOS	9457535	58.10716666666666	-153.3401111111111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.3500000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Raspberry Island	AK
95724	Japanese Bay, Kodiak Island, Alaska	NOS	9457634	56.96	-153.687	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Japanese Bay, Kodiak Island	AK
95725	Larsen Bay, Kodiak Island, Alaska	NOS	9457724	57.5333	-153.99	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.140000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Larsen Bay, Kodiak Island, AK	AK
95726	Geese Island GPS Tide Buoy, Alaska	NOS	9457726	56.594694	-153.996028	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.609999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Geese Island GPS Tide Buoy	AK
95728	Alitak, Lazy Bay, Alaska	NOS	9457804	56.89738888888889	-154.248	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.170000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alitak	AK
95729	Puale Bay, Alaska	NOS	9458209	57.7067	-155.393	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.4799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puale Bay	AK
95730	Chirikof Island, Alaska	NOS	9458293	55.8083	-155.74	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.609999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chirikof Island	AK
95731	Chowiet Island, Semidi Island, Alaska	NOS	9458519	56.0517	-156.698	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.699999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chowiet island	AK
95733	Castle Bay, Northwest Arm, Alaska	NOS	9458907	56.2317	-158.347	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.640000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Castle Bay	AK
95734	Hump Island, Kuiukta Bay, Alaska	NOS	9458964	56.1133	-158.598	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hump Island, Kuiukta Bay	AK
95735	Mitrofania Island, Alaska	NOS	9459016	55.89	-158.82	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mitrofania Island	AK
95736	Herendeen Island, Shumagin Islands, Alaska	NOS	9459163	55.06555555555556	-159.4186666666667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.9399999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Herendeen Island, Shumagin Islands	AK
95737	Bird Island, Shumagin Bank, Shumagin Islands, Alaska	NOS	9459251	54.83522222222222	-159.7595555555556	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bird Island, Shumagin Bank	AK
95738	Sand Point, Popof Island, Alaska	NOS	9459450	55.33172222222223	-160.5043333333333	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sand Point	AK
95739	Zachary Bay, Unga Island, Shumagin Islands, Alaska	NOS	9459465	55.334999084472656	-160.61700439453125	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.969999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZACHARY BAY, UNGA IS (N. SIDE)	AK
95740	Dolgoi Harbor, Dolgoi Island, Alaska	NOS	9459758	55.121700286865234	-161.79200744628906	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolgoi Harbor, Dolgoi Island	AK
95741	King Cove, Deer Passage, Alaska	NOS	9459881	55.05988888888889	-162.3261111111111	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.6799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	King Cove	AK
95742	Cold Bay, Alaska	NOS	9459949	55.2083	-162.698	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.99	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cold Bay	AK
95743	Attu, Massacre Bay, Alaska	NOS	9460150	52.84000015258789	173.19500732421875	:America/Adak	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	A set of tidal harmonic constants based on data collected prior to 1960 have\nbeen calculated for use in generating tide predictions at this location. Due\nto the limitations of these historical observations, MSL is held fixed as the\nstation datum and MLLW is referenced to MSL in order to remove any reference\nto the terrestrial system. The removal of the terrestrial reference enables\nthe relationship between MSL and MLLW to remain consistent over time and not\nrequire periodic National Tidal Datum Epoch (NTDE) updates. Due to the remote\nnature of this location, there are no immediate plans to collect updated water\nlevels data in the area. If you require additional assistance, please contact\nCO-PS Customer Service via email at Tide.Predictions@noaa.gov.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.94	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ATTU, MASSACRE BAY	AK
95744	Sweeper Cove, Adak Island, Alaska	NOS	9461380	51.86063888888889	-176.6375833333333	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Adak Island	AK
95745	Atka, Nazan Bay, Atka Island, Alaska	NOS	9461710	52.23194444444444	-174.1725	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9699999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Atka	AK
95746	Nikolski, Umnak Island, Alaska	NOS	9462450	52.94061	-168.8713055557675	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikolski	AK
95747	Unalaska, Dutch Harbor, Alaska	NOS	9462620	53.87919444444444	-166.5403055555556	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.0799999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalaska	AK
95748	Biorka Village, Biverly Inlet, Alaska	NOS	9462645	53.82891666666667	-166.21625	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Biorka Village, Biverly Inlet	AK
95749	Reef Bight, Alaska	NOS	9462662	54.13072222222223	-166.0993333333333	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.009999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reef Bight	AK
95750	Broad Bight, Akutan Island, Aleutian Islands, Alaska	NOS	9462676	54.06458333333333	-165.9370555555556	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1799999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Broad Bight	AK
95751	Akutan, Aleutian Islands, Alaska	NOS	9462694	54.13327777777778	-165.7773055555556	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1599999999999966	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan, Alaska	AK
95752	Green Bight, Akutan Island, Aleutian Islands, Alaska	NOS	9462705	54.11027777777778	-165.6613888888889	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8700000000000045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Bight	AK
95753	Surf Bay, Akutan Bay, Alaska	NOS	9462711	54.15083333333333	-165.615	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.1899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Surf Bay, Akutan Bay	AK
95754	Akun Cove, Akun Island, Aleutian Islands, Alaska	NOS	9462719	54.2333	-165.533	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7200000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akun Cove, Akun Island	AK
95755	Trident Bay, Akun Island, Aleutian Islands, Alaska	NOS	9462721	54.14	-165.527	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.210000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trident Bay, Akun Island	AK
95756	Rootok Island, Rootok Strait, Alaska	NOS	9462723	54.05222222222222	-165.5141666666667	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.830000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rootok Island	AK
95757	Tigalda Bay, Tigalda Island, Alaska	NOS	9462782	54.12	-164.977	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6199999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tigalda Bay, Tigalda Island	AK
95758	SE Tigalda Island, Aleutian Islands, Alaska	NOS	9462786	54.10180555555556	-164.9415833333333	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.960000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SE Tigalda Island, Pacific Ocean	AK
95759	Cape Sarichef, Unimak Island, Alaska	NOS	9462787	54.6	-164.928	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.9799999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Sarichef, Unimak Island	AK
95760	Scotch Cap, Unimak Island, Alaska	NOS	9462808	54.39363888888889	-164.7457222222222	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Scotch Cap, Unimak Island, AK	AK
95761	Cape Chunak, Unimak Island, Alaska	NOS	9462941	55.06427777777778	-163.5341666666667	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.289999999999992	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chunak, AK	AK
95762	Neumans Cove, Bechevin Bay, Aleutian Islands, Alaska	NOS	9462948	54.9667	-163.44	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.58	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEUMANS COVE	AK
95763	False Pass, Isanotski Strait, Unimak Island, Alaska	NOS	9462955	54.8583	-163.407	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	False Pass, Unimak Island	AK
95764	Isanotski Strait entrance, Aleutian Islands, Alaska	NOS	9462961	54.77844444444445	-163.3642777777778	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.599999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ISANOTSKI STRAIT ENTRANCE	AK
95765	Port Moller, Bristol Bay, Alaska	NOS	9463502	55.9858333	-160.5736111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.849999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Moller	AK
95766	Zapadni Bay, St. George Island, Alaska	NOS	9463885	56.56669998168945	-169.6667022705078	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.9800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ZAPADNI BAY, ST. GEORGE ISLAND	AK
95767	Meshik, Port Heiden, Bristol Bay, Alaska	NOS	9464075	56.90829849243164	-158.68490600585938	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.420000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Meshik, Port Heiden	AK
95768	Village Cove, St. Paul Island, Pribilof Islands, Alaska	NOS	9464212	57.125301361083984	-170.2852020263672	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.88	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Village Cove, St Paul Island	AK
95769	Dago Creek Mouth, Ugashik Bay, Bristol Bay, Alaska	NOS	9464512	57.61479949951172	-157.60069274902344	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.880000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dago Creek Mouth, Ugashik Bay	AK
95770	Egegik, Egegik River, Alaska	NOS	9464874	58.21670150756836	-157.375	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	7.390000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	EGEGIK, EGEGIK R, BRISTOL BAY	AK
95771	Cape Constantine, Nushagak Peninsula, Bristol Bay, Alaska	NOS	9464961	58.52170181274414	-159.15199279785156	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.050000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE CONSTANTINE, NUSHAGAK PENINSULA	AK
95772	Protection Point, Nushagak Bay, Alaska	NOS	9465056	58.5	-158.712	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.4	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PROTECTION POINT, NUSHAGAK BAY	AK
95774	Cape Peirce, west side, Bristol Bay, Alaska	NOS	9465137	58.62670135498047	-161.83700561523438	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC+0 for LST; AKST (since 1983) is UTC-9	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.8100000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE PEIRCE, WEST SIDE	AK
95776	Naknek, Naknek River, Kvichak Bay, Alaska	NOS	9465203	58.73210144042969	-156.98330688476562	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	9.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naknek	AK
95779	Clarks Point, Nushagak Bay, Alaska	NOS	9465261	58.8483	-158.552	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.97	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CLARKS POINT, NUSHAGAK BAY	AK
95780	Kulukak Point, Kulukak Bay, Alaska	NOS	9465265	58.84000015258789	-159.64700317382812	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	6.060000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KULUKAK POINT	AK
95777	Hagemeister Island (north end), Alaska	NOS	9465234	58.7767	-160.777	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.6	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH END, HAGEMEISTER ISLAND	AK
95778	Estus Point, Hagemeister Strait, Alaska	NOS	9465249	58.8083	-161.1	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.94	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ESTUS POINT, HAGEMEISTER STRAIT	AK
95781	Summit Island, NE side, Togiak Bay, Alaska	NOS	9465283	58.8467	-160.21	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.\nNOS uses UTC-11 for LST; AKST (since 1983) is UTC-9	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.6899999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NE SIDE SUMMIT ISLAND, TOGIAK BAY A	AK
95782	Snag Point, Dillingham, Alaska	NOS	9465374	59.04	-158.447	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	10.839999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snag Point, Dillingham	AK
95783	Platinum, Alaska	NOS	9465396	59.0467	-161.818	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8399999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Platinum	AK
95784	Levelock, Kvichak River, Alaska	NOS	9465419	59.11330032348633	-156.83200073242188	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.219999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LEVELOCK, KVICHAK RIVER	AK
95786	Carter Bay, Kuskokwim Bay, Alaska	NOS	9465601	59.37801666666667	-162.0293333333333	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.700000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carter Bay, Kuskokwim Bay	AK
95787	Quinhagak (Kwinak), Kuskokwim River, Alaska	NOS	9465831	59.75055277777778	-161.9154361111111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.449999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quinhagak (Kwinak), Kushkokwin River	AK
95788	Kwigillingok, Alaska	NOS	9465911	59.87975	-163.166361	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.75	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kwigillinok	AK
95789	Kipnuk, Yukon Delta, Alaska	NOS	9465951	59.943199157714844	-164.04339599609375	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kipnuk, Kuguklik River	AK
95790	Kinak Bay, Yukon Delta, Alaska	NOS	9465953	59.947528	-164.2107	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.760000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kinak Bay	AK
95791	Cape Corwin GPS Tide Buoy, Nunivak Island, Alaska	NOS	9465988	60.004639	-165.590972	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.729999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Corwin GPS Tide Buoy	AK
95792	Eastern Nunivak Island, Alaska	NOS	9466012	60.04294	-165.680583	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.7700000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eastern Nunivak Island	AK
95793	Popokamute (Kokokamute), Kuskokwim River, Alaska	NOS	9466057	60.12327777777778	-162.5003611111111	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.050000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Popokamute (Kokokamute), Kuskokwim River	AK
95794	Chefornak, Kinia River, Yukon Delta, Alaska	NOS	9466084	60.159400939941406	-164.27259826660156	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.4800000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chefornak	AK
95795	Helmick Point (SE of), Kuskokwim River, Alaska	NOS	9466153	60.270301818847656	-162.4102020263672	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.760000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Helmick Point	AK
95796	Tuntutuliak, Tagayarak River, Alaska	NOS	9466197	60.34149932861328	-162.68600463867188	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tuntutuliak	AK
95797	Mekoryuk, Mekoryuk River entrance, Nunivak Island, Alaska	NOS	9466217	60.4167	-166.167	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8699999999999974	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mekoryuk, Mekoryuk River Entrance	AK
95798	Tooksook Bay, Nelson Island, Yukon Delta, Alaska	NOS	9466298	60.5167	-165.133	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	5.169999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nelson Island, Tooksook Bay	AK
95799	Lomavik, Kuskokwim River, Alaska	NOS	9466328	60.554298400878906	-162.29710388183594	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.879999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lomavik	AK
95800	Bethel, Kuskokwim River, Alaska	NOS	9466477	60.8	-161.75	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bethel, Kuskokwim River, AK	AK
95801	Newtok, Ningliq River, Yukon Delta, Alaska	NOS	9466563	60.93450164794922	-164.63870239257812	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.3900000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newtok	AK
95802	Dall Point, Hooper Bay, Yukon Delta, Alaska	NOS	9466931	61.5317	-166.148	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.8399999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dall Point	AK
95803	Kun River, Scammon Bay, Yukon Delta, Alaska	NOS	9467124	61.84170150756836	-165.56700134277344	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.1999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kun River	AK
95804	Nunam Iqua (Sheldon Point), Yukon Delta, Alaska	NOS	9467551	62.53294444444445	-164.8452777777778	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.0500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nunam Iqua (Sheldon Point)	AK
95805	Alakanuk, Yukon River, Alaska	NOS	9467645	62.687198638916016	-164.66690063476562	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9100000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alakanuk, Yukon River	AK
95806	Emmonak, Kwiguk Pass, Yukon Delta, Alaska	NOS	9467701	62.77750015258789	-164.54690551757812	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7999999999999972	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Emmonak	AK
95807	Kotlik, Kotlik River, Norton Sound, Alaska	NOS	9467861	63.037899017333984	-163.52650451660156	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1700000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kotlik, AK	AK
95808	Northeast Cape, St. Lawrence Island, Alaska	NOS	9468039	63.3167	-168.967	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northeast Cape, St. Lawrence Island	AK
95810	Stebbins, Norton Sound, Alaska	NOS	9468151	63.525001525878906	-162.29299926757812	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.\nNOS uses UTC-11 for LST; AKST (since 1983) is UTC-9	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2100000000000009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	STEBBINS, NORTON SOUND, EAST	AK
95811	Savoonga, St. Lawrence Island, Alaska	NOS	9468258	63.67908333333333	-170.5371111111111	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2800000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Savoonga	AK
95812	Kavalghak Bay, St. Lawrence Island, Alaska	NOS	9468261	63.682861	-171.750194	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.2199999999999989	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kavalghak Bay, AK	AK
95814	Unalakleet, Alaska	NOS	9468333	63.875	-160.78799438476562	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.55	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalakleet	AK
95815	Shaktoolik, Alaska	NOS	9468691	64.38022222222222	-161.2351388888889	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.6699999999999982	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shaktoolik	AK
95816	Nome, Norton Sound, Alaska	NOS	9468756	64.49461111111111	-165.4396388888889	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nome, Norton Sound	AK
95835	Kivalina, Alaska	NOS	9491253	67.7267	-164.592	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4400000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kivalina	AK
95817	Golovin, Golovnin Lagoon entrance, Norton Sound, Alaska	NOS	9468793	64.546278	-163.031667	:America/Nome	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golovin, Golovnin Lagoon Entrance	AK
95818	Upper Golovnin Lagoon, Norton Sound, Alaska	NOS	9468841	64.620833	-163.149	:America/Nome	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.22	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upper Golovnin Lagoon	AK
95819	Elim, Norton Bay, Alaska	NOS	9468863	64.6167	-162.248	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.\nNOS uses UTC-11 for LST; AKST (since 1983) is UTC-9	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ELIM, NORTON BAY	AK
95820	Koyuk, Norton Bay, Alaska	NOS	9469031	64.93119812011719	-161.1508026123047	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.3599999999999994	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Koyuk	AK
95822	Point Spencer, Port Clarence, Norton Sound, Alaska	NOS	9469237	65.2567	-166.847	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7299999999999995	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Spencer, Port Clarence	AK
95823	Teller, Port Clarence, Alaska	NOS	9469239	65.2667	-166.353	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TELLER, PORT CLARENCE	AK
95824	Lost River, Seward Peninsula, Alaska	NOS	9469338	65.39	-167.145	:America/Nome	USA	feet	\N	\N	\N	NOS uses UTC-11 for LST; AKST (since 1983) is UTC-9	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5200000000000005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	LOST RIVER, SEWARD PENINSULA	AK
95825	Tin City, Bering Sea, Alaska	NOS	9469439	65.55833333333334	-167.975	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.46999999999999975	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tin City, Bering Sea	AK
95826	Outside Lopp Lagoon, Alaska	NOS	9469515	65.728806	-168.032139	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.480000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Outside Lopp Lagoon	AK
95828	Deering, Kotzebue Sound, Alaska	NOS	9469751	66.09716666666667	-162.7404722222222	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.9499999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deering	AK
95829	Goodhope Bay, Kotzebue Sound, Alaska	NOS	9469833	66.23030090332031	-163.9040985107422	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8800000000000026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goodhope Bay	AK
95830	Shishmaref Inlet 2, Alaska	NOS	9469854	66.2633	-166.02	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5100000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shishmaref Inlet 2	AK
95911	Haleiwa, Waialua Bay, Oahu Island, Hawaii	NOS	1612668	21.5983	-158.108	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94651	-02:05:00	\N	0.8	-01:02:00	\N	0.8	\N	\N	Haleiwa, Waialua Bay	HI
95912	Kamalo Harbor, Molokai Island, Hawaii	NOS	1613077	21.0483	-156.877	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94651	-00:16:00	0	\N	-00:37:00	0.1	\N	\N	\N	Kamalo Harbor	HI
95831	Cape Espenberg, Kotzebue Sound, Alaska	NOS	9490096	66.58569444444444	-164.2508333333333	:America/Nome	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5300000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Espenberg, Kotzebue Sound	AK
95832	Kotzebue, Kotzebue Sound, Alaska	NOS	9490424	66.9017	-162.582	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kotzebue	AK
95833	Cape Krusenstern, Kotzebue Sound, Alaska	NOS	9490571	67.05419444444445	-163.3212777777778	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.23000000000000398	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Krusenstern	AK
95834	Red Dog Dock, Alaska	NOS	9491094	67.57580555555556	-164.0643888888889	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4900000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Dog Dock	AK
95827	Buckland, Buckland River, Alaska	NOS	9469677	65.9755	-161.124972	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.1400000000000006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Buckland	AK
95837	Wainwright, Chukchi Sea, Alaska	NOS	9494212	70.643798828125	-160.06509399414062	:America/Anchorage	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	Data from this station was collected using methodology that does not meet\nCO-OPS highest level of accuracy (no more than 10 cm, 95% Confidence Interval\n(CI) referenced to a tidal datum). Recognizing that lower quality data can be\nused for certain applications CO-OPS is making this data available to its\nusers with restraint. The average six-minute water level observations derived\nfrom this system have an accuracy ranging from 10.0 - 30.0 cm, 95% CI on\ndatum. Users are cautioned to consider the accuracy of these data before using\nthem for critical navigational or coastal engineering purposes.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.29000000000000625	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wainwright	AK
95838	Barrow (offshore), Alaska	NOS	9494935	71.36011111111111	-156.7298611111111	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3100000000000023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barrow Offshore	AK
95839	Prudhoe Bay, Alaska	NOS	9497645	70.4113889	-148.5316667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3399999999999963	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Prudhoe Bay	AK
95842	Barter Island, Alaska	NOS	9499176	70.12855555555555	-143.6110277777778	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.28000000000000025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barter Island	AK
95843	Grapetree Bay, St. Croix, Virgin Islands	NOS	9751082	17.740699768066406	-64.60579681396484	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grapetree Bay	VI
95844	Teague Bay, St. Croix, Virgin Islands	NOS	9751084	17.7549991607666	-64.60240173339844	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Teague Bay	VI
95845	Fareham Bay, St. Croix, Virgin Islands	NOS	9751219	17.709999084472656	-64.68280029296875	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fareham Bay	VI
95846	Johns Folly Bay, St. John, Virgin Islands	NOS	9751274	18.316999435424805	-64.70210266113281	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johns Folly Bay	VI
95847	Leinster Point, Leinster Bay, St. John, Virgin Islands	NOS	9751309	18.36761111111111	-64.72072222222222	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5299999999999976	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Leinster Point, Leinster Bay, St. John's	VI
95848	Christiansted Harbor, St. Croix, Virgin Islands	NOS	9751364	17.74769444444445	-64.69838888888889	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.379999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Christiansted Harbor, St Croix	VI
95849	Coral Harbor, St. John, Virgin Islands	NOS	9751373	18.34830093383789	-64.7166976928711	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41999999999999993	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST JOHN'S ISLAND, CORAL HARBOR	VI
95850	Lameshur Bay, St. John, Virgin Islands	NOS	9751381	18.31825	-64.72422222222222	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lameshur Bay, St John	VI
95851	Fish Bay, St. John, Virgin Islands	NOS	9751388	18.31920051574707	-64.76180267333984	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fish Bay	VI
95852	Salt River Bay, St. Croix, Virgin Islands	NOS	9751389	17.775299072265625	-64.76229858398438	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Salt River Bay	VI
95853	Lime Tree Bay, St. Croix, Virgin Islands	NOS	9751401	17.694700241088867	-64.75379943847656	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.37000000000000455	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lime Tree Bay	VI
95854	Hawksnest Beach, St. John, Virgin Islands	NOS	9751417	18.348899841308594	-64.77739715576172	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawksnest Beach	VI
95855	Haulover Bay, St. John, Virgin Islands	NOS	9751419	18.349700927734375	-64.67960357666016	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.46000000000000085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HAULOVER BAY, ST. JOHNS	VI
95856	Lovango Cay, St. John, Virgin Islands	NOS	9751467	18.36066666666667	-64.80352777777777	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.48999999999999844	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovango Cay, St. John	VI
95857	Cruz Bay, St. John, Virgin Islands	NOS	9751472	18.33289909362793	-64.79409790039062	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.45999999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cruz Bay	VI
95858	Dog Island, St. Thomas, Virgin Islands	NOS	9751494	18.29713888888889	-64.81775	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dog Island, St. Thomas	VI
95859	Pavilion Point, St. Thomas, Virgin Islands	NOS	9751561	18.33989906311035	-64.85240173339844	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5300000000000011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pavillion Point	VI
95861	Jersey Bay, St. Thomas, Virgin Islands	NOS	9751574	18.318099975585938	-64.8594970703125	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jersey Bay	VI
95862	Water Bay, St. Thomas, Virgin Islands	NOS	9751583	18.34894444444445	-64.86416666666666	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5599999999999987	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Water Bay	VI
95863	Fredericksted, St. Croix, Virgin Islands	NOS	9751584	17.7133	-64.8833	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fredericksted, St. Croix	VI
95864	Charlotte Amalie, St. Thomas, Virgin Islands	NOS	9751639	18.3305833	-64.9258056	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3799999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charlotte Amalie	VI
95865	Magens Bay, St. Thomas, Virgin Islands	NOS	9751693	18.366300582885742	-64.9220962524414	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Magens Bay	VI
95866	Crown Bay, St. Thomas, Virgin Islands	NOS	9751749	18.33289909362793	-64.95169830322266	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.379999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crown Bay	VI
95867	Dorothea Bay, St. Thomas, Virgin Islands	NOS	9751768	18.37125	-64.96347222222222	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5799999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dorothea Bay, Saint Thomas	VI
95868	Botany Bay, St. Thomas, Virgin Islands	NOS	9751774	18.3633	-65.035	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5900000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Botany Bay, St. Thomas	VI
95869	Culebrita, Puerto Rico	NOS	9752062	18.319400787353516	-65.23809814453125	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5799999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Culebrita	PR
95870	Culebra, Puerto Rico	NOS	9752235	18.30086111111111	-65.30247222222222	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5399999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Culebra	PR
95871	Punta la Plata, Vieques, Puerto Rico	NOS	9752426	18.116600036621094	-65.3729019165039	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.379999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Playa la Plata	PR
95872	Isabel Segunda, Vieques, Puerto Rico	NOS	9752619	18.15252777777778	-65.44380555555556	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5899999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isabel Segunda, Vieques Island	PR
95873	Esperanza, Vieques, Puerto Rico	NOS	9752695	18.09386111111111	-65.47136111111111	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Esperanza, Vieques Island	PR
95874	Mosquito Pier, Vieques, Puerto Rico	NOS	9752813	18.14889907836914	-65.51490020751953	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5500000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mosquito Pier	PR
95875	Isla Palominos, Puerto Rico	NOS	9752962	18.34497222222222	-65.5695	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7099999999999973	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isla Palominos	PR
95876	Punta Arenas, Vieques, Puerto Rico	NOS	9752998	18.11240005493164	-65.57589721679688	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.39000000000000057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUNTA ARENAS, VIEQUES ISLAND	PR
95877	Ceiba, Roosevelt Roads, Puerto Rico	NOS	9753182	18.228099822998047	-65.61969757080078	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.48999999999999844	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ceiba, Roosevelt Road	PR
95894	Magueyes Island, Caribbean Sea, Puerto Rico	NOS	9759110	17.97011111111111	-67.04638888888888	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Magueyes Island	PR
95878	Fajardo, Puerto Rico	NOS	9753216	18.3352778	-65.6311111	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7300000000000004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fajardo	PR
95879	Naguabo, Puerto Rico	NOS	9753641	18.18705555555556	-65.71138888888889	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3899999999999997	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Naguabo	PR
95880	Luquillo, Puerto Rico	NOS	9753766	18.38170051574707	-65.73650360107422	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7399999999999984	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Luquillo, PR	PR
95881	Palmas del Mar, Puerto Rico	NOS	9754057	18.078100204467773	-65.79560089111328	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Palmas del Mar	PR
95882	Yabucoa Harbor, Puerto Rico	NOS	9754228	18.05508333333333	-65.833	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.34999999999999964	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yabucoa Harbor	PR
95883	Puerto Maunabo, Puerto Rico	NOS	9754487	17.99139976501465	-65.88880157470703	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.370000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puerto Maunabo	PR
95884	Boca de Cangrejos, Puerto Rico	NOS	9754986	18.456600189208984	-65.99150085449219	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6899999999999977	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOCA DE CANGREJOS	PR
95885	San Juan, La Puntilla, San Juan Bay, Puerto Rico	NOS	9755371	18.45894444444445	-66.11641666666667	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.7600000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan, La Puntilla, San Juan Bay	PR
95886	Las Mareas, Puerto Rico	NOS	9755679	17.9283	-66.1583	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33000000000000007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Las Mareas	PR
95887	Central Aguirre, Puerto Rico	NOS	9755971	17.950000762939453	-66.22640228271484	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3299999999999983	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Central Aguirre	PR
95888	Boca del Cibuco, Puerto Rico	NOS	9756567	18.485200881958008	-66.3843994140625	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8399999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boca del Cibuco	PR
95889	Santa Isabel, Puerto Rico	NOS	9756639	17.955	-66.4067	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.35999999999999943	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Santa Isabel	PR
95890	Ponce, Puerto Rico	NOS	9757487	17.969600677490234	-66.61990356445312	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.33999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ponce	PR
95913	Pukoo Harbor, Molokai Island, Hawaii	NOS	1613155	21.0717	-156.8	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94651	-00:48:00	0	\N	-01:03:00	0.1	\N	\N	\N	Pukoo Harbor	HI
95914	Kolo, Molokai Island, Hawaii	NOS	1613226	21.0933	-157.197	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94651	00:01:00	0	\N	00:05:00	0	\N	\N	\N	Kolo	HI
95891	Arecibo, Puerto Rico	NOS	9757809	18.48052777777778	-66.70236111111112	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\nThese datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.8200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arecibo	PR
95892	Peuelas (Punta Guayanilla), Puerto Rico	NOS	9758053	17.97252777777778	-66.76177777777778	:America/Puerto_Rico	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These data are measured by the Puerto Rico Seismic Network (PRSN), located at\nthe University of Puerto Rico Mayaguez. PRSN is a National Ocean Service (NOS)\npartner that adheres to NOS data collection standards. For more information on\nthe PRSN, visit their website.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Penuelas (Punta Guayanilla)	PR
95893	Gunica, Puerto Rico	NOS	9758627	17.95800018310547	-66.90679931640625	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3500000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guanica	PR
95895	Boquern, Puerto Rico	NOS	9759173	18.02400016784668	-67.17310333251953	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3999999999999986	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boqueron	PR
95896	Joyuda, Puerto Rico	NOS	9759183	18.115800857543945	-67.18319702148438	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Joyuda	PR
95897	Puerto Real, Puerto Rico	NOS	9759189	18.07480555555556	-67.18877777777777	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.4200000000000017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Puerto Real	PR
95898	Baha Salinas, Puerto Rico	NOS	9759197	17.95144444444444	-67.19658333333334	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bahia Salinas	PR
95899	Mayagez, Puerto Rico	NOS	9759394	18.21883333333333	-67.16244444444445	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.6299999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayaguez	PR
95900	Aguadilla, Crashboat Beach, Puerto Rico	NOS	9759412	18.45663888888889	-67.16458333333334	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.629999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Aguadilla, Crashboat Beach	PR
95901	Punta Guanajibo, Mayagez, Puerto Rico	NOS	9759421	18.165000915527344	-67.18170166015625	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.5299999999999998	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PUNTA GUANAJIBO, MAYAGUES	PR
95902	Southeast Mona Island, Puerto Rico	NOS	9759866	18.06529998779297	-67.86609649658203	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3200000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southeast Mona Island	PR
95903	Mona Island, Puerto Rico	NOS	9759938	18.08928888888889	-67.93820833333334	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.41000000000000014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mona Island	PR
94668	Malakal Harbor, Palau	NOS	1841367	7.3333001136779785	134.46670532226562	:Pacific/Palau	Palau	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.64	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Malakal Harbor, Palau Island	PW
94716	Beverly Harbor, Beverly, Massachusetts	NOS	8442417	42.54	-70.8867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	4.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BEVERLY, BEVERLY HARBOR	MA
94744	New Bedford Harbor, marine terminal, Buzzards Bay, Massachusetts	NOS	8447636	41.62120056152344	-70.9136962890625	:America/New_York	USA	feet	\N	\N	\N	See station comments in 'about' for disclaimers.	These datums and any data referred to said datum are PROVISIONAL and subject\nto revision until they have been thoroughly reviewed and received final\napproval.  Subsequent review based on field inspections and additional\nmeasurements may result in revisions to the data and datums.  Data users are\ncautioned to consider the conditional nature of this information before using\nit for critical decisions such as those that concern physical or public\nsafety. Only after meeting all standards for quality control assurance will\nthe datums be classified as Accepted Datums.\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7899999999999991	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Bedford Harbor	MA
94990	Cedar Island, Pamlico Sound, North Carolina	NOS	8655151	35.01890182495117	-76.31430053710938	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CEDAR ISLAND	NC
95053	Little Wassaw Island, Green Island Sound, Georgia	NOS	8671946	31.889722	-81.061667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.8400000000000034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Little Wassaw Island, Green Island Sound	GA
95095	Tolomato River, ICWW, Florida	NOS	8720494	29.994400024414062	-81.32949829101562	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.5300000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	TOLOMATO RIVER, ICWW	FL
95116	Melbourne Causeway, Indian River, Florida	NOS	8721843	28.082222	-80.594722	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.16000000000000003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MELBOURNE CAUSEWAY	FL
95223	Wakulla Airport, Ochlockonee Bay, Florida	NOS	8728262	29.980199813842773	-84.3958969116211	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	1.7500000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ochlockonee Bay	FL
95353	Pointe au Chien, Cutoff Canal, Louisiana	NOS	8762525	29.41670036315918	-90.44670104980469	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.2400000000000002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pointe Au Chien, Cut Off Canal	LA
95785	Goodnews Bay, Alaska	NOS	9465438	59.11439895629883	-161.5843963623047	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	3.869999999999999	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goodnews Bay	AK
94692	Augusta, MCRR Bridge, Kennebec River, Maine	NOS	8417144	44.32	-69.77028	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.91	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Augusta, MCRR Bridge, Kennebec River	ME
94770	Vails Beach, Block Is. Sound, Rhode Island	NOS	8459449	41.1483	-71.575	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.49	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VAILS BEACH, BLOCK IS. SOUND	RI
94785	Montauk Point Light, Long Island Sound, New York	NOS	8510321	41.0717	-71.8567	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	MONTAUK POINT LIGHT	NY
94827	Worlds Fair Marina, Flushing Bay, New York	NOS	8517251	40.761	-73.85036111111111	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.7	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Worlds Fair Marina	NY
94828	College Pt, Ft. of 110th Street, Long Island, New York	NOS	8517276	40.7833	-73.8567	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	COLLEGE PT, FT. OF 110TH ST, LI	NY
94840	Spuyten Duyvil Creek entrance, Hudson River, New York	NOS	8518903	40.8783	-73.925	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SPUYTEN DUYVIL CK, ENT., HUDSON R,	NY
94852	South Amboy, Raritan River, New Jersey	NOS	8531232	40.4917	-74.2817	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.67	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SOUTH AMBOY  RARITAN RIVER	NJ
94912	St. Michaels, Miles River, Chesapeake Bay, Maryland	NOS	8572342	38.7867	-76.2217	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MICHAELS, MILES RIVER	MD
94953	New Point (Comfort Shoal), Virginia	NOS	8637590	37.2567	-76.2217	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NEW POINT, COMFORT SHOAL	VA
94959	Burwell Bay, James River, Virginia	NOS	8638421	37.0567	-76.6683	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BURWELL BAY, JAMES RIVER	VA
94989	Oriental, Neuse River, North Carolina	NOS	8655133	35.024594	-76.691797	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ORIENTAL, NEUSE RIVER	NC
95046	Savannah (Bull Street), Georgia	NOS	8670681	32.0817	-81.0917	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BULL STREET, SAVANNAH RIVER	GA
95048	Palmer Johnson Shipyard, Wilmington River, Georgia	NOS	8670893	32.0233	-81.0467	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.98	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PALMER JOHNSON SHIPYARD, WILMINGTON R.	GA
95114	Canaveral Harbor entrance, Florida	NOS	8721608	28.4083	-80.6017	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CANAVERAL HARBOR ENTRANCE	FL
95129	Boynton Beach, Lake Worth, Florida	NOS	8722706	26.54829978942871	-80.05329895019531	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BOYNTON BEACH	FL
95245	Richardson Hammock, St. Joseph Bay, Florida	NOS	8728949	29.69	-85.3633	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.7	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	RICHARDSON HAMMOCK, ST. JOSEPH BAY	FL
95266	Upper Blackwater River, Florida	NOS	8729738	30.6583	-86.9883	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.57	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	UPPER BLACKWATER RIVER	FL
95317	Keesler AFB, Back Bay, Biloxi, Mississippi	NOS	8744284	30.4183	-88.925	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.73	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	KEESLER AFB, BACK BAY OF BILOXI	MS
95318	Tchoutacabouffa River entrance, Mississippi	NOS	8744663	30.4417	-88.9733	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.79	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tchoutacabouffa River Entrance	MS
95332	Venice, Grand Pass, Louisiana	NOS	8760849	29.2733	-89.3517	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	VENICE, GRAND PASS	LA
95340	Grand Isle, Mississippi River Delta, Louisiana	NOS	8761720	29.255	-89.9683	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	GRAND ISLE	LA
95361	Eugene Island, Atchafalaya Bay, Louisiana	NOS	8764311	29.3717	-91.385	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eugene Island	LA
95401	Sabine (offshore), Louisiana	NOS	8771081	29.4983	-93.64	:America/Chicago	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM CST to 2002-01-01 12:00 AM CST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Offshore	LA
95475	North Point, Pier 41, San Francisco, San Francisco Bay, California	NOS	9414305	37.81	-122.413	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	3.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	NORTH POINT [PIER 41] S.F.BAY	CA
95480	Redwood Creek Marker 8, San Francisco Bay, California	NOS	9414501	37.5333	-122.193	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	REDWOOD CREEK,C.M. NO. 8,S.F.BAY	CA
95522	Requa Dock, California	NOS	9419551	41.545	-124.07	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Requa Dock	CA
95566	Taholah, Washington	NOS	9441644	47.34817	-124.28475	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.54	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Taholah	WA
95592	Yokeko Point, Deception Pass, Washington	NOS	9448601	48.4133	-122.615	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM PST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	5.96	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	YOKEKO POINT	WA
95662	Muir Inlet, Glacier Bay, Alaska	NOS	9452584	58.9133	-136.108	:America/Juneau	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM PST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	8.63	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Muir Inlet, Glacier Bay	AK
95667	Tyndall Glacier, Icy Bay, Alaska	NOS	9453431	60.0780556	-141.2769444	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	5.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tyndall Glacier, Taan Fiord	AK
95718	Dovolno Point, Kizhuyak Bay, Alaska	NOS	9457393	57.7394	-152.87472	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.87	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dovolno Point, Kizhuyak Bay	AK
95727	Uyak, Uyak Bay, Alaska	NOS	9457728	57.635	-154.007	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	7.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uyak	AK
95732	Sutwik Island, west end, Alaska	NOS	9458665	56.54	-157.327	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.91	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	WEST END, SUTWIK ISLAND	AK
95773	Pyrite Point, Bristol Bay, Alaska	NOS	9465123	58.62	-161.542	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	2.84	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PYRITE POINT, BRISTOL BAY	AK
95775	High Island, Bristol Bay, Alaska	NOS	9465173	58.721699	-160.427	:America/Anchorage	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	4.61	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	HIGH ISLAND, BRISTOL BAY	AK
95809	St. Michael, Norton Sound, Alaska	NOS	9468132	63.475	-162.027	:America/Nome	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.63	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ST. MICHAEL, NORTON SOUND	AK
95813	Akeftapak, St. Lawrence Island, Alaska	NOS	9468283	63.7185	-171.6447	:America/Adak	USA	feet	\N	\N	\N	NOS uses UTC-9 for LST; HAST (since 1983) is UTC-10	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM HST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akeftapak, St. Lawrence Island	AK
95840	Prudhoe Bay #2, Alaska	NOS	9497649	70.3883	-148.51	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	PRUDHOE BAY #2	AK
95841	Cross Island (Dinkum Sands), Alaska	NOS	9497778	70.4917	-147.95	:America/Anchorage	USA	feet	\N	\N	\N	NOS uses UTC-10 for LST; AKST (since 1983) is UTC-9	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AHST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CROSS ISLAND, (DINKUM SANDS)	AK
95860	Benner Bay, St. Thomas, Virgin Islands	NOS	9751567	18.32	-64.87	:America/St_Thomas	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM AST to 2002-01-01 12:00 AM AST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	BENNER BAY	VI
95821	Imuruk Basin, Alaska	NOS	9469146	65.118444	-165.472056	:America/Nome	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM BST to 2002-01-01 12:00 AM AKST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	0.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Imuruk Basin	AK
94939	Cape Charles Harbor (USCG wharf), Chesapeake Bay, Virginia	NOS	8632366	37.2633	-76.02	:America/New_York	USA	feet	\N	\N	\N	\N	Datum not available from MDAPI\nMLLW estimated from predictions over National Tidal Datum Epoch\nSearched interval from 1983-01-01 12:00 AM EST to 2002-01-01 12:00 AM EST\n	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Approximate Level of Mean Lower Low Water	1.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	CAPE CHARLES HBR (U.S. G. WHARF)	VA
95915	Kaumalapau, Lanai Island, Hawaii	NOS	1614465	20.79	-156.995	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94651	00:03:00	0	\N	00:02:00	0.2	\N	\N	\N	Kaumalapau, Lanai Island	HI
95916	Makena, Maui Island, Hawaii	NOS	1615202	20.6567	-156.445	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94657	01:09:00	\N	0.54	01:21:00	\N	0.73	\N	\N	Makena	HI
95917	Hana, Maui Island, Hawaii	NOS	1615395	20.7617	-155.987	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94657	00:18:00	\N	0.54	00:40:00	\N	1.05	\N	\N	Hana	HI
95918	Kuheia Bay, Kahoolawe Island, Hawaii	NOS	1616696	20.595	-156.607	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94651	-00:09:00	0	\N	-00:09:00	0.2	\N	\N	\N	Kuheia Bay	HI
95919	Mahukona, Hawaii Island, Hawaii	NOS	1617277	20.1867	-155.903	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94659	00:42:00	\N	0.67	00:38:00	\N	0.8	\N	\N	Mahukona	HI
95920	Kailua Kona, Hawaii Island, Hawaii	NOS	1617846	19.6433	-156	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94659	00:37:00	\N	0.67	00:38:00	\N	0.8	\N	\N	Kailua Kona	HI
95921	Napoopoo, Kealakekua Bay, Hawaii Island, Hawaii	NOS	1618021	19.4767	-155.922	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94659	00:47:00	\N	0.67	00:48:00	\N	0.8	\N	\N	Napoopoo, Kealakekua Bay	HI
95922	Honuapo, Hawaii Island, Hawaii	NOS	1618578	19.0883	-155.553	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94659	00:33:00	\N	1	00:38:00	\N	1.01	\N	\N	Honuapo	HI
95923	East Island, French Frigate Shoals, Hawaii	NOS	1619222	23.7833	-166.208	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94651	00:08:00	\N	0.73	00:03:00	\N	0.73	\N	\N	East Island, French Frigate Shoals	HI
95924	Laysan Island, Hawaii	NOS	1619645	25.7667	-171.75	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94651	01:12:00	\N	0.5	01:02:00	\N	0.53	\N	\N	Laysan Island	HI
95925	Koror, Palau	NOS	1841281	7.349999904632568	134.48300170898438	:Pacific/Palau	Palau	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94668	-00:04:00	0	\N	-00:07:00	-0.1	\N	\N	\N	Koror	PW
95926	Birch Islands, Cobscook Bay, Maine	NOS	8410875	44.875	-67.1583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94670	01:13:00	\N	0.75	00:59:00	\N	0.94	\N	\N	Birch Islands	ME
95927	Stone Island, Machias Bay, Maine	NOS	8411411	44.6033	-67.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94670	-00:28:00	\N	0.68	-00:11:00	\N	0.68	\N	\N	Stone Island, Machias Bay	ME
95928	Machiasport, Machias River, Maine	NOS	8411467	44.6983	-67.3933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94670	-00:09:00	\N	0.69	00:01:00	\N	0.69	\N	\N	Machiasport, Machias River	ME
95929	Shoppee Point, Englishman Bay, Maine	NOS	8411696	44.615	-67.4967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94670	-00:13:00	\N	0.66	-00:05:00	\N	0.66	\N	\N	Shoppee Point, Englishman Bay	ME
95930	Steele Harbor Island, Maine	NOS	8411801	44.4933	-67.5433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:20:00	\N	1.27	-00:28:00	\N	1.27	\N	\N	Steele Harbor Island	ME
95931	Green Island, Petit Manan Bar, Maine	NOS	8412568	44.3717	-67.87	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:24:00	\N	1.16	-00:28:00	\N	1.16	\N	\N	Green Island, Petit Manan Bar	ME
95932	Prospect Harbor, Maine	NOS	8412932	44.4	-68.0217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:15:00	\N	1.15	-00:24:00	\N	1.15	\N	\N	Prospect Harbor	ME
95933	Winter Harbor, Frenchman Bay, Maine	NOS	8413079	44.3883	-68.0867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	00:10:00	\N	0.95	-00:01:00	\N	0.95	\N	\N	Winter Harbor, Frenchman Bay	ME
95934	Southwest Harbor, Mount Desert Island, Maine	NOS	8413564	44.275	-68.3133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	-00:27:00	\N	0.95	00:00:00	\N	0.96	\N	\N	Southwest Harbor	ME
95935	Bass Harbor, Mount Desert Island, Maine	NOS	8413651	44.2417	-68.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	-00:27:00	\N	0.93	00:04:00	\N	0.93	\N	\N	Bass Harbor	ME
95936	Burnt Coat Harbor, Swans Island, Maine	NOS	8413857	44.145	-68.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	00:06:00	\N	0.88	-00:01:00	\N	0.89	\N	\N	Burnt Coat Harbor, Swans Island	ME
95937	Blue Hill Harbor, Blue Hill Bay, Maine	NOS	8414112	44.4083	-68.5633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	00:11:00	\N	0.95	00:09:00	\N	0.95	\N	\N	Blue Hill Harbor	ME
95938	Center Harbor, Eggemoggin Reach, Maine	NOS	8414168	44.2633	-68.5867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	00:12:00	\N	0.95	00:09:00	\N	0.95	\N	\N	Center Harbor	ME
95939	Isle Au Haut, Penobscot Bay, Maine	NOS	8414288	44.0733	-68.6367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	-00:27:00	\N	0.88	-00:01:00	\N	0.87	\N	\N	Isle Au Haut	ME
95940	Stonington, Deer Isle, Penobscot Bay, Maine	NOS	8414348	44.1533	-68.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	00:06:00	\N	0.9	00:08:00	\N	0.91	\N	\N	Stonington, Deer Isle	ME
95941	Little Deer Isle, Eggemoggin Reach, Maine	NOS	8414424	44.2917	-68.6933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	00:14:00	\N	0.93	00:16:00	\N	0.94	\N	\N	Little Deer Isle	ME
95942	Gross Point, Eastern Channel, Penobscot River, Maine	NOS	8414581	44.5367	-68.7583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	00:10:00	\N	0.98	-00:06:00	\N	0.99	\N	\N	Gross Point, Eastern Channel	ME
95943	Castine, Penobscot Bay, Maine	NOS	8414672	44.3867	-68.7967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	00:11:00	\N	1	00:15:00	\N	0.95	\N	\N	Castine	ME
95944	Bucksport, Penobscot River, Maine	NOS	8414684	44.5717	-68.8017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	00:11:00	\N	1	-00:04:00	\N	1.01	\N	\N	Bucksport	ME
95945	Sandy Point, Penobscot River, Maine	NOS	8414692	44.505	-68.805	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	00:08:00	\N	0.98	00:06:00	\N	0.99	\N	\N	Sandy Point	ME
95946	Vinalhaven, Vinalhaven Island, Penobscot Bay, Maine	NOS	8414776	44.0433	-68.84	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	00:10:00	\N	0.88	00:09:00	\N	0.87	\N	\N	Vinalhaven, Vinalhaven Island	ME
95947	North Haven, Penobscot Bay, Maine	NOS	8414856	44.1267	-68.8733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	00:10:00	\N	0.9	00:13:00	\N	0.91	\N	\N	North Haven	ME
95948	Matinicus Harbor, Wheaton Island, Penobscot Bay, Maine	NOS	8414876	43.8617	-68.8817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	-00:27:00	\N	0.85	00:05:00	\N	0.85	\N	\N	Matinicus Harbor, Wheaton Island	ME
95949	Belfast, Penobscot Bay, Maine	NOS	8415191	44.4267	-69.005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94678	00:04:00	\N	1.03	00:09:00	\N	0.97	\N	\N	Belfast	ME
95950	Tenants Harbor, Maine	NOS	8415809	43.965	-69.2167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:11:00	\N	1.02	-00:11:00	\N	1.02	\N	\N	Tenants Harbor	ME
95951	Otis Cove, St. George River, Maine	NOS	8415867	43.9867	-69.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:14:00	\N	1	-00:15:00	\N	1	\N	\N	Otis Cove	ME
95952	Port Clyde, St. George River, Maine	NOS	8415933	43.925	-69.26	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:07:00	\N	0.98	-00:11:00	\N	0.98	\N	\N	Port Clyde	ME
95953	Burnt Island, Georges Islands, Maine	NOS	8416028	43.8717	-69.295	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:12:00	\N	0.98	-00:13:00	\N	0.98	\N	\N	Burnt Island, Georges Islands	ME
95954	Monhegan Island, Maine	NOS	8416092	43.765	-69.3217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:09:00	\N	0.97	-00:13:00	\N	0.97	\N	\N	Monhegan Island	ME
95955	Friendship Harbor, Maine	NOS	8416141	43.97	-69.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:11:00	\N	0.99	-00:18:00	\N	0.99	\N	\N	Friendship Harbor	ME
95956	Waldoboro, Medomak River, Maine	NOS	8416224	44.0933	-69.3767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:04:00	\N	1.04	-00:16:00	\N	1.04	\N	\N	Waldoboro	ME
95957	Jones Neck, Medomak River, Maine	NOS	8416232	44.015	-69.38	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:05:00	\N	1	-00:10:00	\N	1	\N	\N	Jones Neck	ME
95958	Muscongus Harbor, Muscongus Sound, Maine	NOS	8416381	43.9667	-69.4417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:03:00	\N	0.99	-00:09:00	\N	0.99	\N	\N	Muscongus Harbor, Muscongus Sound	ME
95959	New Harbor, Muscongus Bay, Maine	NOS	8416501	43.875	-69.4917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:08:00	\N	0.97	-00:10:00	\N	0.97	\N	\N	New Harbor, Muscongus Bay	ME
95960	Pemaquid Harbor, Johns Bay, Maine	NOS	8416581	43.8767	-69.525	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:04:00	\N	0.97	-00:05:00	\N	0.97	\N	\N	Pemaquid Harbor, Johns Bay	ME
95961	Newcastle, Damariscotta River, Maine	NOS	8416608	44.0333	-69.5367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:25:00	\N	1.02	00:16:00	\N	1.02	\N	\N	Newcastle	ME
97717	Unalga Bight, Adak Island, Alaska	NOS	9461341	51.78	-176.807	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-00:21:00	\N	0.97	-00:07:00	\N	0.97	\N	\N	Unalga Bight	AK
95962	East Boothbay, Damariscotta River, Maine	NOS	8416721	43.865	-69.5833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:01:00	\N	0.98	-00:02:00	\N	0.98	\N	\N	East Boothbay	ME
95963	Damariscove Harbor, Damariscove Island, Maine	NOS	8416796	43.7583	-69.615	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:10:00	\N	0.97	-00:09:00	\N	0.97	\N	\N	Damariscove Harbor, Damariscove Island	ME
95964	Sheepscot (below rapids), Sheepscot River, Maine	NOS	8416804	44.05	-69.6183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:20:00	\N	1.05	00:20:00	\N	1.05	\N	\N	Sheepscot (below rapids)	ME
95965	Boothbay Harbor, Maine	NOS	8416828	43.85	-69.6283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:08:00	\N	0.97	-00:06:00	\N	0.97	\N	\N	Boothbay Harbor	ME
95966	Southport, Townsend Gut, Maine	NOS	8416908	43.8467	-69.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:01:00	\N	0.98	00:01:00	\N	0.98	\N	\N	Southport, Townsend Gut	ME
95967	Wiscasset, Sheepscot River, Maine (sub)	NOS	8416921	44	-69.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:04:00	\N	1.03	00:16:00	\N	1.03	\N	\N	Wiscasset	ME
95968	Cross River entrance, Sheepscot River, Maine	NOS	8416928	43.925	-69.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:04:00	\N	1	00:07:00	\N	1	\N	\N	Cross River entrance	ME
95969	Back River, Sheepscot River, Maine	NOS	8416961	43.9583	-69.6833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:31:00	\N	1	00:34:00	\N	1	\N	\N	Back River	ME
95970	Isle of Springs, Sheepscot River, Maine	NOS	8416968	43.86	-69.6867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:04:00	\N	0.98	-00:02:00	\N	0.98	\N	\N	Isle of Springs	ME
95971	Robinhood, Sasanoa River, Sheepscot River, Maine	NOS	8417067	43.8533	-69.7333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:14:00	\N	0.97	00:14:00	\N	0.97	\N	\N	Robinhood, Sasanoa River	ME
95972	Mill Point, Sasanoa River, Sheepscot River, Maine	NOS	8417127	43.8867	-69.7633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:43:00	\N	0.97	00:35:00	\N	0.97	\N	\N	Mill Point, Sasanoa River	ME
95973	Phippsburg, Kennebec River, Maine	NOS	8417221	43.8183	-69.81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:28:00	\N	0.88	00:26:00	\N	0.88	\N	\N	Phippsburg	ME
95974	Sturgeon Island, Merrymeeting Bay, Kennebec River, Maine	NOS	8417271	43.9817	-69.835	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	02:04:00	\N	0.58	02:00:00	\N	0.58	\N	\N	Sturgeon Island, Merrymeeting Bay	ME
95975	Howard Point, New Meadows River, Casco Bay, Maine	NOS	8417367	43.89	-69.8833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:01:00	\N	0.99	-00:05:00	\N	0.99	\N	\N	Howard Point, New Meadows River	ME
95976	Androscoggin River entrance, Kennebec River, Maine	NOS	8417377	43.95	-69.8883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	03:26:00	\N	0.52	02:24:00	\N	0.52	\N	\N	Androscoggin River entrance	ME
95977	Cundy Harbor, New Meadows River, Casco Bay, Maine	NOS	8417387	43.7883	-69.8933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:02:00	\N	0.98	-00:01:00	\N	0.98	\N	\N	Cundy Harbor, New Meadows River	ME
95978	Bowdoinham, Cathance River, Kennebec River, Maine	NOS	8417391	44.0083	-69.895	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	02:42:00	\N	0.63	02:34:00	\N	0.63	\N	\N	Bowdoinham, Cathance River	ME
95979	Brunswick, Androscoggin River, Kennebec River, Maine	NOS	8417527	43.9217	-69.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	04:36:00	\N	0.42	02:35:00	\N	0.42	\N	\N	Brunswick, Androscoggin River	ME
95980	Wilson Cove, Middle Bay, Casco Bay, Maine	NOS	8417553	43.825	-69.9767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:02:00	\N	1	00:02:00	\N	1	\N	\N	Wilson Cove, Middle Bay	ME
95981	South Harpswell, Potts Harbor, Casco Bay, Maine	NOS	8417647	43.7383	-70.0233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:01:00	\N	0.98	00:02:00	\N	0.98	\N	\N	South Harpswell, Potts Harbor	ME
95982	South Freeport, Casco Bay, Maine	NOS	8417801	43.82	-70.1033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:10:00	\N	0.99	00:12:00	\N	0.99	\N	\N	South Freeport	ME
95983	Cliff Island, Luckse Sound, Casco Bay, Maine	NOS	8417821	43.695	-70.11	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:02:00	\N	1	-00:02:00	\N	1	\N	\N	Cliff Island, Luckse Sound	ME
95984	Doyle Point, Casco Bay, Maine	NOS	8417874	43.7517	-70.14	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:03:00	\N	0.88	-00:02:00	\N	1	\N	\N	Doyle Point	ME
95985	Great Chebeague Island, Casco Bay, Maine	NOS	8417881	43.7217	-70.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:02:00	\N	1.03	00:02:00	\N	1	\N	\N	Great Chebeague Island	ME
95986	Vaill Island, Casco Bay, Maine	NOS	8417911	43.6767	-70.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:01:00	\N	1.03	00:05:00	\N	0.98	\N	\N	Vaill Island	ME
95987	Long Island, Casco Bay, Maine	NOS	8417941	43.69	-70.17	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:01:00	\N	1	-00:01:00	\N	1	\N	\N	Long Island	ME
95988	Prince Point, Casco Bay, Maine	NOS	8417948	43.7617	-70.1733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:01:00	\N	0.99	00:00:00	\N	1	\N	\N	Prince Point	ME
95989	Great Diamond Island, Casco Bay, Maine	NOS	8417988	43.67	-70.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:00:00	\N	1.03	00:00:00	\N	1	\N	\N	Great Diamond Island	ME
95990	Cushing Island, Casco Bay, Maine	NOS	8417997	43.645	-70.1983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:01:00	\N	1.03	00:01:00	\N	0.99	\N	\N	Cushing Island	ME
95991	Peak Island, Casco Bay, Maine	NOS	8418001	43.655	-70.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:08:00	\N	0.99	-00:04:00	\N	0.99	\N	\N	Peak Island	ME
95992	Cow Island, Casco Bay, Maine	NOS	8418009	43.69	-70.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:00:00	\N	1	-00:01:00	\N	1	\N	\N	Cow Island	ME
95993	Falmouth Foreside, Casco Bay, Maine	NOS	8418015	43.7317	-70.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:01:00	\N	0.97	00:01:00	\N	1	\N	\N	Falmouth Foreside	ME
95994	Portland Head Light, Casco Bay, Maine	NOS	8418031	43.6233	-70.2067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:01:00	\N	1	-00:02:00	\N	0.97	\N	\N	Portland Head Light	ME
95995	Presumpscot River Bridge, Casco Bay, Maine	NOS	8418137	43.6867	-70.2467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:04:00	\N	1.06	00:01:00	\N	1.01	\N	\N	Presumpscot River Bridge	ME
95996	Back Cove, Casco Bay, Maine	NOS	8418175	43.6767	-70.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:06:00	\N	0.97	00:02:00	\N	0.97	\N	\N	Back Cove	ME
95997	Fore River, Casco Bay, Maine	NOS	8418268	43.6417	-70.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:02:00	\N	1.03	00:02:00	\N	1	\N	\N	Fore River	ME
95998	Old Orchard Beach, Maine	NOS	8418557	43.5167	-70.3667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:06:00	\N	0.97	00:00:00	\N	0.97	\N	\N	Old Orchard Beach	ME
95999	Cape Porpoise, Maine	NOS	8418772	43.3667	-70.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:14:00	\N	0.95	00:12:00	\N	0.95	\N	\N	Cape Porpoise	ME
96000	Cape Neddick, Maine	NOS	8419399	43.1667	-70.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:08:00	\N	1	00:02:00	\N	0.95	\N	\N	Cape Neddick	ME
96001	York Harbor, Maine	NOS	8419518	43.1317	-70.6417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:13:00	\N	0.95	00:03:00	\N	0.95	\N	\N	York Harbor	ME
96002	Fort Point, York Harbor, Maine	NOS	8419528	43.13	-70.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:10:00	\N	0.94	-00:04:00	\N	0.95	\N	\N	Fort Point, York Harbor	ME
96003	Seapoint, Cutts Island, Maine	NOS	8419590	43.085	-70.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:04:00	\N	0.96	00:01:00	\N	0.96	\N	\N	Seapoint, Cutts Island	ME
96004	Gerrish Island, Portsmouth Harbor, Maine	NOS	8419688	43.0667	-70.6967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:03:00	\N	0.95	-00:02:00	\N	0.95	\N	\N	Gerrish Island	ME
96005	Kittery Point, Portsmouth Harbor, Maine	NOS	8419807	43.0817	-70.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:01:00	\N	0.96	-00:07:00	\N	0.96	\N	\N	Kittery Point	ME
96006	Salmon Falls River, Piscataqua River, New Hampshire	NOS	8419997	43.1917	-70.825	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	01:52:00	\N	0.75	01:35:00	\N	0.75	\N	\N	Salmon Falls River	NH
96007	Dover Point, Piscataqua River, New Hampshire	NOS	8421897	43.1217	-70.8333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	01:27:00	\N	0.7	01:33:00	\N	0.7	\N	\N	Dover Point	NH
96008	Squamscott River RR. Bridge, Piscataqua River, New Hampshire	NOS	8422687	43.0533	-70.9133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	02:41:00	\N	0.75	02:19:00	\N	0.75	\N	\N	Squamscott River RR. Bridge	NH
96009	Atlantic Heights, E of, Piscataqua River, Maine	NOS	8423635	43.09	-70.7633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:28:00	\N	0.82	00:37:00	\N	0.82	\N	\N	Atlantic Heights	ME
96010	Portsmouth, Portsmouth Harbor, New Hampshire	NOS	8423745	43.0783	-70.7517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:17:00	\N	0.86	00:22:00	\N	0.86	\N	\N	Portsmouth	NH
96011	Jaffrey Point, Portsmouth Harbor, New Hampshire	NOS	8424601	43.0567	-70.7133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:05:00	\N	0.95	-00:03:00	\N	0.95	\N	\N	Jaffrey Point	NH
96012	Gosport Harbor, Isles of Shoals, New Hampshire	NOS	8427031	42.9783	-70.615	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	-00:02:00	\N	0.93	00:02:00	\N	0.93	\N	\N	Gosport Harbor, Isles of Shoals	NH
96013	Hampton Harbor, New Hampshire	NOS	8429489	42.895	-70.8167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94696	00:32:00	\N	0.91	00:14:00	\N	0.91	\N	\N	Hampton Harbor	NH
96014	Charlestown, Charles River entrance, Boston Harbor, Massachusetts	NOS	8443838	42.3717	-71.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:01:00	\N	1	00:00:00	\N	1	\N	\N	Charlestown, Charles River entrance	MA
96015	Deer Island (south end), Boston Harbor, Massachusetts	NOS	8444012	42.3483	-70.96	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:00:00	\N	0.97	00:01:00	\N	0.97	\N	\N	Deer Island (south end)	MA
96016	Moon Head, Boston Harbor, Massachusetts	NOS	8444312	42.3083	-70.9917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:04:00	\N	0.99	00:01:00	\N	0.99	\N	\N	Moon Head	MA
96017	Hull, Massachusetts	NOS	8444351	42.3033	-70.92	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:07:00	\N	0.97	00:05:00	\N	0.97	\N	\N	Hull	MA
96018	Neponset, Neponset River, Boston Harbor, Massachusetts	NOS	8444488	42.285	-71.04	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:03:00	\N	1	-00:02:00	\N	1	\N	\N	Neponset, Neponset River	MA
96019	Nantasket Beach, Weir River, Massachusetts	NOS	8444601	42.27	-70.86	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:07:00	\N	0.99	00:06:00	\N	0.99	\N	\N	Nantasket Beach, Weir River	MA
96020	Crow Point, Hingham Harbor entrance, Massachusetts	NOS	8444662	42.2617	-70.8933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:05:00	\N	0.99	00:02:00	\N	0.99	\N	\N	Crow Point, Hingham Harbor entrance	MA
96021	Cohasset Harbor (White Head), Massachusetts	NOS	8444762	42.2483	-70.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	-00:02:00	\N	0.92	00:04:00	\N	0.92	\N	\N	Cohasset Harbor (White Head)	MA
96022	Hingham, Massachusetts	NOS	8444775	42.2467	-70.885	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:08:00	\N	1	00:09:00	\N	1	\N	\N	Hingham	MA
96023	Damons Point, North River, Massachusetts	NOS	8445425	42.16	-70.7333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:36:00	\N	0.89	00:20:00	\N	0.89	\N	\N	Damons Point, North River	MA
96024	Wellfleet, Cape Cod Bay, Massachusetts	NOS	8446613	41.93	-70.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:30:00	\N	1.05	00:14:00	\N	1.05	\N	\N	Wellfleet	MA
96025	Onset Beach, Onset Bay, Buzzards Bay, Massachusetts	NOS	8447277	41.7417	-70.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	01:25:00	\N	1.03	00:41:00	\N	1.03	\N	\N	Onset Beach, Onset Bay	MA
96026	Steep Brook, Taunton River, Massachusetts	NOS	8447281	41.74	-71.1317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:05:00	\N	1.29	00:26:00	\N	1.3	\N	\N	Steep Brook, Taunton River	MA
96027	Pleasant Bay, Cape Cod, Massachusetts	NOS	8447291	41.7367	-69.9817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	03:27:00	\N	0.34	02:28:00	\N	0.34	\N	\N	Pleasant Bay	MA
96028	Barnstable Harbor, Beach Point, Cape Cod Bay, Massachusetts	NOS	8447335	41.7217	-70.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:30:00	\N	1	00:11:00	\N	1	\N	\N	Barnstable Harbor, Beach Point	MA
96029	Monument Beach, Buzzards Bay, Massachusetts	NOS	8447355	41.715	-70.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:30:00	\N	1.15	00:16:00	\N	1.15	\N	\N	Monument Beach	MA
96030	Marion, Sippican Harbor, Buzzards Bay, Massachusetts	NOS	8447385	41.705	-70.7617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:12:00	\N	1.29	00:10:00	\N	1.13	\N	\N	Marion, Sippican Harbor	MA
96031	Texas Tower, Georges Shoal	NOS	8447436	41.6883	-67.76	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	-00:43:00	\N	0.44	-00:47:00	\N	0.44	\N	\N	Georges Shoal, Texas Tower	\N
96032	South Yarmouth, Bass River, Nantucket Sound, Massachusetts	NOS	8447504	41.665	-70.1833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	01:46:00	\N	0.29	01:48:00	\N	0.29	\N	\N	South Yarmouth, Bass River	MA
96033	Wychmere Harbor, Nantucket Sound, Massachusetts	NOS	8447506	41.665000915527344	-70.06500244140625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:25:00	\N	0.39	00:52:00	\N	0.39	\N	\N	Wychmere Harbor	MA
96034	Dennisport, Nantucket Sound, Massachusetts	NOS	8447525	41.6583	-70.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:38:00	\N	0.36	01:03:00	\N	0.36	\N	\N	Dennisport	MA
96035	Mattapoisett, Mattapoisett Harbor, Buzzards Bay, Massachusetts	NOS	8447531	41.6567	-70.8133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:20:00	\N	1	00:11:00	\N	1.09	\N	\N	Mattapoisett, Mattapoisett Harbor	MA
96036	Cotuit Highlands, Nantucket Sound, Massachusetts	NOS	8447675	41.6083	-70.4367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:47:00	\N	0.26	01:17:00	\N	0.26	\N	\N	Cotuit Highlands	MA
96037	Poponesset Island, Poponesset Bay, Nantucket Sound, Massachusetts	NOS	8447742	41.5867	-70.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	01:52:00	\N	0.24	02:03:00	\N	0.24	\N	\N	Poponesset Island, Poponesset Bay	MA
96038	Hix Bridge, East Branch, Westport River, Massachusetts	NOS	8447791	41.57	-71.0733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	02:30:00	\N	0.77	01:40:00	\N	0.77	\N	\N	Hix Bridge, East Branch	MA
96039	Falmouth Heights, Nantucket Sound, Massachusetts	NOS	8447865	41.545	-70.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	-00:09:00	\N	0.14	-00:16:00	\N	0.14	\N	\N	Falmouth Heights	MA
96040	Little Harbor, Woods Hole, Massachusetts	NOS	8447939	41.52	-70.665	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	02:21:00	\N	0.4	00:32:00	\N	0.4	\N	\N	Little Harbor	MA
96041	Uncatena Island (south side), Woods Hole, Massachusetts	NOS	8447941	41.52	-70.7083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:22:00	\N	1.02	00:12:00	\N	1.02	\N	\N	Uncatena Island (south side)	MA
96042	Westport Harbor, Westport River, Massachusetts	NOS	8447975	41.5083	-71.0933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:33:00	\N	0.85	00:09:00	\N	0.85	\N	\N	Westport Harbor	MA
96043	Oak Bluffs, Martha's Vineyard, Massachusetts	NOS	8448208	41.4583	-70.555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	03:47:00	\N	0.71	03:59:00	\N	0.5	\N	\N	Oak Bluffs	MA
96044	Quicks Hole, north side, Massachusetts	NOS	8448251	41.4483	-70.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	-00:08:00	\N	0.99	-00:08:00	\N	0.99	\N	\N	Quicks Hole, North side	MA
96045	Cedar Tree Neck, Martha's Vineyard, Massachusetts	NOS	8448325	41.435	-70.6967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	01:32:00	\N	0.62	00:10:00	\N	0.62	\N	\N	Cedar Tree Neck	MA
96046	Cuttyhunk, Massachusetts	NOS	8448376	41.42499923706055	-70.91670227050781	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	01:15:00	\N	0.93	01:20:00	\N	0.97	\N	\N	Cuttyhunk	MA
96047	Great Point, Nantucket Island, Massachusetts	NOS	8448566	41.3867	-70.0467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:28:00	\N	0.32	00:43:00	\N	0.32	\N	\N	Great Point	MA
96048	Wasque Point, Chappaquiddick Island, Martha's Vineyard, Massachusetts	NOS	8448683	41.3633	-70.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	03:20:00	\N	0.31	02:02:00	\N	0.31	\N	\N	Wasque Point, Chappaquiddick Island	MA
96049	Gay Head, Martha's Vineyard, Massachusetts	NOS	8448733	41.3533	-70.83	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:45:00	\N	0.82	-00:06:00	\N	0.82	\N	\N	Gay Head	MA
96050	Muskeget Island, north side, Nantucket Island, Massachusetts	NOS	8448817	41.3367	-70.305	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:15:00	\N	0.21	00:25:00	\N	0.21	\N	\N	Muskeget Island, north side	MA
96051	Squibnocket Point, Martha's Vineyard, Massachusetts	NOS	8448942	41.3117	-70.7683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	-00:02:00	\N	0.82	-00:45:00	\N	0.82	\N	\N	Squibnocket Point	MA
96052	Eel Point, Nantucket Island, Massachusetts	NOS	8449062	41.2917	-70.2083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94721	00:07:00	\N	0.24	00:39:00	\N	0.24	\N	\N	Eel Point	MA
96053	Nomans Land, Martha's Vineyard, Massachusetts	NOS	8449287	41.2617	-70.8183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:18:00	\N	0.85	-00:19:00	\N	0.85	\N	\N	Nomans Land	MA
96077	Lyme, highway bridge, Connecticut River, Connecticut	NOS	8462764	41.3217	-72.35	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	01:09:00	\N	0.95	01:36:00	\N	1.26	\N	\N	Lyme, highway bridge	CT
96054	North End, Bay Oil pier, Sakonnet River, Rhode Island	NOS	8450898	41.6517	-71.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:01:00	\N	1.07	00:20:00	\N	1.2	\N	\N	North End, Bay Oil pier	RI
96055	Anthony Point, Sakonnet River, Rhode Island	NOS	8450948	41.6383	-71.2117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	-00:01:00	\N	1.09	00:00:00	\N	1.09	\N	\N	Anthony Point	RI
96056	Nannaquaket Neck, Sakonnet River, Rhode Island	NOS	8450954	41.6183	-71.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	-00:13:00	\N	1.01	-00:12:00	\N	1.01	\N	\N	Nannaquaket Neck	RI
96057	The Glen, Sakonnet River, Rhode Island	NOS	8451301	41.5583	-71.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	-00:03:00	\N	1	-00:13:00	\N	0.98	\N	\N	The Glen	RI
96058	Sachuest, Flint Point, Sakonnet River, Rhode Island	NOS	8451351	41.4867	-71.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:15:00	\N	0.93	-00:05:00	\N	0.9	\N	\N	Sachuest, Flint Point	RI
96059	Bristol, Bristol Harbor, Narragansett Bay, Rhode Island	NOS	8451929	41.6683	-71.28	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:00:00	\N	1.14	00:13:00	\N	1.16	\N	\N	Bristol, Bristol Harbor	RI
96060	Prudence Island, south end, Narragansett Bay, Rhode Island	NOS	8452555	41.58	-71.3217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	-00:03:00	\N	1.14	00:08:00	\N	1.08	\N	\N	Prudence Island, (south end)	RI
96061	Bay Spring, Bullock Cove, Narragansett Bay, Rhode Island	NOS	8453033	41.7517	-71.3517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:01:00	\N	1.21	00:12:00	\N	1.22	\N	\N	Bay Spring, Bullock Cove	RI
96062	Castle Hill, Narragansett Bay, Rhode Island	NOS	8453201	41.4633	-71.3617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:13:00	\N	1	-00:05:00	\N	0.94	\N	\N	Castle Hill	RI
96063	Rumford, Seekonk River, Narragansett Bay, Rhode Island	NOS	8453433	41.84	-71.3733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:06:00	\N	1.29	00:12:00	\N	1.34	\N	\N	Rumford, Seekonk River	RI
96064	Conanicut Point, Conanicut Island, Rhode Island	NOS	8453465	41.5733	-71.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	-00:06:00	\N	1.07	00:07:00	\N	1.07	\N	\N	Conanicut Point	RI
96065	Pawtucket, Seekonk River, Narragansett Bay, Rhode Island	NOS	8453611	41.8683	-71.38	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:09:00	\N	1.29	00:18:00	\N	1.31	\N	\N	Pawtucket, Seekonk River	RI
96066	Pawtuxet, Pawtuxet Cove, Narragansett Bay, Rhode Island	NOS	8453767	41.7617	-71.3883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	-00:11:00	\N	1.29	00:06:00	\N	1.25	\N	\N	Pawtuxet, Pawtuxet Cove	RI
96067	Beavertail Point, Conanicut Island, Rhode Island	NOS	8453999	41.4517	-71.4017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:04:00	\N	0.98	-00:05:00	\N	0.98	\N	\N	Beavertail Point	RI
96068	Watson Pier, Boston Neck, Narragansett Bay, Rhode Island	NOS	8454341	41.46	-71.4283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:16:00	\N	0.93	-00:03:00	\N	0.96	\N	\N	Watson Pier, Boston Neck	RI
96069	Narragansett Pier, Narragansett Bay, Rhode Island	NOS	8454658	41.4217	-71.455	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	00:11:00	\N	0.93	-00:11:00	\N	0.91	\N	\N	Narragansett Pier	RI
96070	Westerly, Pawcatuck River, Rhode Island (sub)	NOS	8455189	41.3817	-71.8317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	00:03:00	\N	1	-00:21:00	\N	1.02	\N	\N	Westerly, Pawcatuck River	RI
96071	Watch Hill Point, Rhode Island	NOS	8458694	41.305	-71.86	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94758	01:16:00	\N	0.71	00:41:00	\N	0.74	\N	\N	Watch Hill Point	RI
96072	Norwich, Thames River, Connecticut	NOS	8461392	41.5233	-72.0783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	00:19:00	\N	1.21	00:24:00	\N	1.18	\N	\N	Norwich	CT
96073	Yale boathouse, Thames River, Connecticut	NOS	8461467	41.43	-72.0933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	00:10:00	\N	1.11	00:14:00	\N	1.07	\N	\N	Yale boathouse	CT
96074	Niantic, Niantic River, Connecticut	NOS	8461925	41.325	-72.1867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	00:57:00	\N	0.84	00:52:00	\N	0.99	\N	\N	Niantic, Niantic River	CT
96075	Saybrook Jetty, Connecticut River, Connecticut	NOS	8462723	41.2633	-72.3433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	00:45:00	\N	1.35	01:11:00	\N	1.36	\N	\N	Saybrook Jetty	CT
96076	Saybrook Point, Connecticut River, Connecticut	NOS	8462752	41.2833	-72.35	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	00:53:00	\N	1.25	01:11:00	\N	1.24	\N	\N	Saybrook Point	CT
96078	Essex, Connecticut River, Connecticut	NOS	8462925	41.3483	-72.385	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	01:38:00	\N	1.15	01:39:00	\N	1.16	\N	\N	Essex	CT
96079	Hadlyme, Connecticut River, Connecticut	NOS	8463155	41.42	-72.4283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	02:23:00	\N	1.05	02:19:00	\N	1.05	\N	\N	Hadlyme	CT
96080	Tylerville, Connecticut River, Connecticut	NOS	8463348	41.4517	-72.465	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	02:51:00	\N	1.02	02:38:00	\N	1.02	\N	\N	Tylerville	CT
96081	Westbrook, Duck Island Roads, Connecticut	NOS	8463409	41.2733	-72.475	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	-00:32:00	\N	0.6	-00:24:00	\N	0.61	\N	\N	Westbrook, Duck Island Roads	CT
96082	Haddam, Connecticut River, Connecticut	NOS	8463582	41.4817	-72.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	03:08:00	\N	0.95	02:48:00	\N	0.97	\N	\N	Haddam	CT
96083	Maromas, Connecticut River, Connecticut	NOS	8463827	41.5417	-72.5517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	04:01:00	\N	0.91	03:25:00	\N	0.91	\N	\N	Maromas	CT
96084	Higganum Creek, Connecticut River, Connecticut	NOS	8463836	41.5033	-72.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	03:40:00	\N	0.91	03:08:00	\N	0.91	\N	\N	Higganum Creek	CT
96085	Madison, Connecticut	NOS	8464041	41.27	-72.59	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	-00:30:00	\N	0.72	-00:21:00	\N	0.73	\N	\N	Madison	CT
96086	Rocky Hill, Connecticut River, Connecticut	NOS	8464255	41.6633	-72.63	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	05:36:00	\N	0.63	04:30:00	\N	0.72	\N	\N	Rocky Hill	CT
96087	Middletown, Connecticut River, Connecticut	NOS	8464336	41.56	-72.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	04:39:00	\N	0.83	03:54:00	\N	0.83	\N	\N	Middletown	CT
96088	South Hartford, Connecticut River, Connecticut	NOS	8464418	41.755	-72.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	06:54:00	\N	0.58	05:24:00	\N	0.74	\N	\N	South Hartford	CT
96089	Guilford Harbor, Connecticut	NOS	8464445	41.2717	-72.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	-00:21:00	\N	0.96	-00:11:00	\N	0.77	\N	\N	Guilford Harbor	CT
96090	Hartford, Connecticut River, Connecticut	NOS	8464464	41.77	-72.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	06:52:00	\N	0.75	05:30:00	\N	0.74	\N	\N	Hartford	CT
96091	Sachem Head, Connecticut	NOS	8464687	41.245	-72.7083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	-00:15:00	\N	0.8	-00:11:00	\N	0.8	\N	\N	Sachem Head	CT
96092	Branford, Branford River, Connecticut	NOS	8465233	41.2617	-72.8183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	-00:13:00	\N	0.96	-00:05:00	\N	0.87	\N	\N	Branford, Branford River	CT
96093	Lighthouse Point, New Haven Harbor, Connecticut	NOS	8465692	41.2517	-72.905	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	-00:07:00	\N	0.96	-00:04:00	\N	0.91	\N	\N	Lighthouse Point, New Haven Harbor	CT
96094	Gulf Beach, Connecticut	NOS	8466375	41.205	-73.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	-00:08:00	\N	1.04	-00:05:00	\N	0.94	\N	\N	Gulf Beach	CT
96095	Milford Harbor, Connecticut	NOS	8466442	41.2183	-73.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	-00:03:00	\N	1.04	-00:02:00	\N	0.94	\N	\N	Milford Harbor	CT
96096	Shelton, Housatonic River, Connecticut	NOS	8466573	41.3017	-73.0717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	01:19:00	\N	0.96	00:46:00	\N	1.04	\N	\N	Shelton	CT
96097	Long Hill, Housatonic River, Connecticut	NOS	8466664	41.275	-73.0883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	01:13:00	\N	1.04	00:43:00	\N	1.02	\N	\N	Long Hill	CT
96098	Sniffens Point, Housatonic River, Connecticut	NOS	8466791	41.1867	-73.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	00:09:00	\N	1	00:10:00	\N	0.96	\N	\N	Sniffens Point	CT
96099	Stratford, I-95 bridge, Housatonic River, Connecticut	NOS	8466797	41.2033	-73.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	00:23:00	\N	1	00:23:00	\N	0.98	\N	\N	Stratford, I-95 bridge	CT
96100	Rowayton, Fivemile River, Connecticut	NOS	8468609	41.065	-73.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	00:05:00	\N	1.08	00:00:00	\N	1.05	\N	\N	Rowayton, Fivemile River	CT
96101	Cos Cob Harbor, Connecticut	NOS	8469549	41.0167	-73.5967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	00:11:00	\N	1.08	00:05:00	\N	1.07	\N	\N	Cos Cob Harbor	CT
96102	Montauk Harbor entrance, Long Island, New York	NOS	8510502	41.075	-71.9367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	-00:16:00	\N	0.75	-00:24:00	\N	0.74	\N	\N	Montauk Harbor entrance	NY
96103	Little Gull Island, Long Island, New York	NOS	8510884	41.2067	-72.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	-00:22:00	\N	0.85	00:13:00	\N	0.85	\N	\N	Little Gull Island	NY
96104	Threemile Harbor entrance, Gardiners Bay, Long Island, New York (sub)	NOS	8511171	41.035	-72.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	00:19:00	\N	1	00:39:00	\N	0.96	\N	\N	Threemile Harbor entrance, Gardiners Bay	NY
96105	Noyack Bay, Shelter Island Sound, New York	NOS	8511779	40.995	-72.3317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	01:44:00	\N	0.89	02:06:00	\N	0.89	\N	\N	Noyack Bay	NY
96106	Hashamomuck Beach, Long Island, New York	NOS	8512053	41.095	-72.3983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	-00:13:00	\N	0.64	00:03:00	\N	0.64	\N	\N	Hashamomuck Beach	NY
96107	Southold, Shelter Island Sound, New York	NOS	8512114	41.06	-72.4133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	01:33:00	\N	0.89	01:44:00	\N	0.89	\N	\N	Southold	NY
96108	New Suffolk, Peconic Bays, New York	NOS	8512328	40.9917	-72.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94774	02:11:00	\N	1	02:27:00	\N	1.01	\N	\N	New Suffolk	NY
96109	Shinnecock Bay entrance, Shinnecock Bay, New York	NOS	8512671	40.82	-72.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	01:51:00	\N	0.37	01:12:00	\N	0.51	\N	\N	Shinnecock Bay entrance	NY
96110	Mount Sinai Harbor, Long Island, New York	NOS	8514421	40.9633	-73.04	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	00:18:00	\N	0.88	00:04:00	\N	0.89	\N	\N	Mount Sinai Harbor	NY
96111	Port Jefferson Harbor entrance, Long Island, New York	NOS	8514594	40.9717	-73.0917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	00:01:00	\N	0.98	00:02:00	\N	0.98	\N	\N	Port Jefferson Harbor entrance	NY
96112	Great River, Connetquot River, Great South Bay, New York	NOS	8514783	40.7233	-73.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:32:00	\N	0.15	03:19:00	\N	0.15	\N	\N	Great River, Connetquot River	NY
96113	West Fire Island, Great South Bay, New York	NOS	8514961	40.6567	-73.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:18:00	\N	0.13	02:10:00	\N	0.13	\N	\N	West Fire Island	NY
96114	Fire Island Light, Great South Bay, New York	NOS	8515014	40.635	-73.22	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	01:22:00	\N	0.15	00:46:00	\N	0.15	\N	\N	Fire Island Light	NY
96115	Bay Shore, Watchogue Creek entrance, Great South Bay, New York	NOS	8515102	40.7167	-73.24	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:27:00	\N	0.37	02:15:00	\N	0.22	\N	\N	Bay Shore, Watchogue Creek Entrance	NY
96116	Democrat Point, Fire Island Inlet, Long Island, New York	NOS	8515228	40.6333	-73.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	-00:27:00	\N	0.55	-00:39:00	\N	0.56	\N	\N	Democrat Point, Fire Island Inlet	NY
96117	Oak Beach, Great South Bay, New York	NOS	8515336	40.64	-73.295	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:58:00	\N	0.15	02:23:00	\N	0.15	\N	\N	Oak Beach	NY
96118	Babylon, Great South Bay, New York	NOS	8515421	40.685	-73.315	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:41:00	\N	0.15	02:11:00	\N	0.13	\N	\N	Babylon	NY
96119	Gilgo Heading, Great South Bay, New York	NOS	8515764	40.62	-73.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:58:00	\N	0.25	02:22:00	\N	0.24	\N	\N	Gilgo Heading	NY
96120	Amityville, Great South Bay, New York	NOS	8515864	40.655	-73.4183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:05:00	\N	0.25	02:20:00	\N	0.26	\N	\N	Amityville	NY
96121	Biltmore Shores, South Oyster Bay, Long Island, New York	NOS	8516055	40.6667	-73.4683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:32:00	\N	0.3	02:04:00	\N	0.3	\N	\N	Biltmore Shores, South Oyster Bay	NY
96122	Oyster Bay Harbor, Oyster Bay, New York	NOS	8516201	40.8667	-73.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94777	00:13:00	\N	1.08	00:07:00	\N	1.08	\N	\N	Oyster Bay Harbor	NY
96123	Bellmore, Bellmore Creek, Hempstead Bay, New York	NOS	8516211	40.6633	-73.52	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	01:58:00	\N	0.45	01:28:00	\N	0.43	\N	\N	Bellmore, Bellmore Creek	NY
96124	Cuba Island, Hempstead Bay, New York	NOS	8516221	40.62	-73.5233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	01:22:00	\N	0.5	01:07:00	\N	0.49	\N	\N	Cuba Island	NY
96125	Deep Creek Meadow, Hempstead Bay, New York	NOS	8516225	40.6033	-73.525	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	01:11:00	\N	0.5	01:01:00	\N	0.51	\N	\N	Deep Creek Meadow	NY
96126	Neds Creek, Hempstead Bay, New York	NOS	8516315	40.6233	-73.555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:54:00	\N	0.6	00:49:00	\N	0.58	\N	\N	Neds Creek	NY
96127	Jones Inlet (Point Lookout), Long Island, New York	NOS	8516385	40.5867	-73.5783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	-00:25:00	\N	0.75	-00:20:00	\N	0.77	\N	\N	Jones Inlet (Point Lookout)	NY
96128	Freeport, Baldwin Bay, Hempstead Bay, New York	NOS	8516411	40.6333	-73.5867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:55:00	\N	0.65	00:37:00	\N	0.64	\N	\N	Freeport, Baldwin Bay	NY
96129	Long Beach (Inside), Hempstead Bay, New York	NOS	8516601	40.6	-73.65	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:02:00	\N	0.85	00:18:00	\N	0.84	\N	\N	Long Beach (Inside)	NY
96130	Woodmere, Brosewere Bay, Hempstead Bay, New York	NOS	8516745	40.62	-73.6983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:50:00	\N	0.85	00:34:00	\N	0.84	\N	\N	Woodmere, Brosewere Bay	NY
96131	Motts Basin, Jamaica Bay, New York	NOS	8516925	40.6167	-73.7583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:48:00	\N	1.15	00:39:00	\N	1.16	\N	\N	Motts Basin	NY
96132	J.F.K. International Airport, Jamaica Bay, New York	NOS	8516999	40.6233	-73.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:45:00	\N	1.15	00:25:00	\N	1.14	\N	\N	J.F.K. International Airport	NY
96133	Whitestone, East River, New York	NOS	8517125	40.7983	-73.8133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94823	00:09:00	\N	1.04	00:07:00	\N	1	\N	\N	Whitestone	NY
96134	Beach Channel (bridge), Jamaica Bay, New York (sub)	NOS	8517137	40.5883	-73.82	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:24:00	\N	1.1	00:37:00	\N	1.09	\N	\N	Beach Channel (bridge)	NY
96135	College Pt, Ft. of 110th Street, Long Island, New York (sub)	NOS	8517276	40.7833	-73.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94823	00:16:00	\N	1.04	00:17:00	\N	0.95	\N	\N	College Point, Flushing Bay	NY
96136	Canarsie, Jamaica Bay, New York	NOS	8517381	40.63	-73.885	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:08:00	\N	1.1	00:27:00	\N	1.12	\N	\N	Canarsie	NY
96137	Barren Island, Rockaway Inlet, Jamaica Bay, New York	NOS	8517394	40.5783	-73.8883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	-00:04:00	\N	1.05	-00:01:00	\N	1.07	\N	\N	Barren Island, Rockaway Inlet	NY
96138	Hell Gate, Wards Island, East River, New York	NOS	8517401	40.7867	-73.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	03:45:00	\N	1.59	02:58:00	\N	1.33	\N	\N	Hell Gate, Wards Island	NY
96139	Mill Basin, Jamaica Bay, New York	NOS	8517519	40.6083	-73.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:04:00	\N	1.1	00:28:00	\N	1.12	\N	\N	Mill Basin	NY
96140	Plumb Beach Channel, Jamaica Bay, New York	NOS	8517531	40.585	-73.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	-00:03:00	\N	1.05	00:02:00	\N	1.05	\N	\N	Plumb Beach Channel	NY
96141	Hunters Point, Newtown Creek, East River, New York	NOS	8517673	40.74	-73.9617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	00:56:00	\N	0.9	01:22:00	\N	0.89	\N	\N	Hunters Point, Newtown Creek	NY
96142	Wallabout Bay, Brooklyn Navy Yard, East River, New York	NOS	8517732	40.7067	-73.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	00:22:00	\N	1.05	00:32:00	\N	0.94	\N	\N	Wallabout Bay, Brooklyn Navy Yard	NY
96143	Coney Island, New York	NOS	8517741	40.57	-73.9833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	-00:17:00	\N	1	-00:04:00	\N	1.01	\N	\N	Coney Island	NY
96144	Norton Point, Gravesend Bay, New York	NOS	8517811	40.59	-73.9983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:03:00	\N	1.15	-00:01:00	\N	1.02	\N	\N	Norton Point, Gravesend Bay	NY
96145	Gowanus Bay, New York	NOS	8517921	40.665	-74.0133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	-00:12:00	\N	0.95	-00:18:00	\N	1.03	\N	\N	Gowanus Bay	NY
96146	Fort Hamilton, The Narrows, New York	NOS	8517942	40.6083	-74.035	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:07:00	\N	1	00:02:00	\N	1.01	\N	\N	Fort Hamilton, The Narrows	NY
96147	New Rochelle, New York	NOS	8518490	40.8933	-73.7817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94823	-00:18:00	\N	0.93	-00:16:00	\N	1.01	\N	\N	New Rochelle	NY
96148	Hunts Point, East River, New York	NOS	8518621	40.8	-73.8733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94823	00:10:00	\N	1.07	00:12:00	\N	0.97	\N	\N	Hunts Point	NY
96149	North Brother Island, East River, New York	NOS	8518635	40.7983	-73.8983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94823	00:18:00	\N	1.11	00:18:00	\N	0.93	\N	\N	North Brother Island	NY
96150	East 41st Street, New York City, East River, New York	NOS	8518695	40.7467	-73.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	00:46:00	\N	1.09	01:03:00	\N	0.95	\N	\N	East 41st Street, New York City	NY
96151	Spuyten Duyvil Creek entrance, Hudson River, New York (sub)	NOS	8518903	40.8783	-73.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	00:48:00	\N	0.84	00:52:00	\N	0.84	\N	\N	Spuyten Duyvil Creek ent., N.Y.	NY
96152	Riverdale, Hudson River, New York (sub)	NOS	8518905	40.9033	-73.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	00:49:00	\N	0.85	00:48:00	\N	0.85	\N	\N	Riverdale, N.Y.	NY
96153	Tarrytown, Hudson River, New York	NOS	8518919	41.0783	-73.87	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	01:57:00	\N	0.7	01:49:00	\N	0.7	\N	\N	Tarrytown	NY
96154	Newburgh, Hudson River, New York	NOS	8518935	41.5	-74.0067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	04:03:00	\N	0.64	03:46:00	\N	0.62	\N	\N	Newburgh	NY
96155	New Hamburg, Hudson River, New York	NOS	8518939	41.5833	-73.95	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	04:28:00	\N	0.64	04:04:00	\N	0.64	\N	\N	New Hamburg	NY
96156	Poughkeepsie, Hudson River, New York	NOS	8518945	41.7	-73.9333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	04:46:00	\N	0.68	04:34:00	\N	0.68	\N	\N	Poughkeepsie	NY
96157	Peekskill, Hudson River, New York	NOS	8518949	41.2883	-73.9317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	03:03:00	\N	0.64	02:28:00	\N	0.64	\N	\N	Peekskill	NY
96158	Tivoli, Hudson River, New York	NOS	8518964	42.0583	-73.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	06:04:00	\N	0.86	05:50:00	\N	0.86	\N	\N	Tivoli	NY
96159	Hudson, Hudson River, New York	NOS	8518974	42.25	-73.8	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	07:12:00	\N	0.86	06:58:00	\N	0.88	\N	\N	Hudson	NY
96160	Castleton, Hudson River, New York	NOS	8518989	42.5333	-73.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94846	-00:29:00	0.1	\N	-00:17:00	-0.2	\N	\N	\N	Castleton	NY
96161	Kingston, Hudson River, New York	NOS	8518993	41.9183	-73.9833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	05:34:00	\N	0.82	05:20:00	\N	0.81	\N	\N	Kingston	NY
96162	Fort Wadsworth, The Narrows, Staten Island, New York	NOS	8519024	40.6067	-74.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:06:00	\N	1.05	00:06:00	\N	0.98	\N	\N	Fort Wadsworth, The Narrows	NY
96163	St. George, Staten Island, New York	NOS	8519112	40.6433	-74.0733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	-00:15:00	\N	0.99	-00:17:00	\N	0.99	\N	\N	St. George, Staten Island	NY
96164	Port Ivory, Howland Hook, Arthur Kill, New York	NOS	8519200	40.645	-74.18	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:39:00	\N	1.09	00:27:00	\N	1.09	\N	\N	Port Ivory, Howland Hook, N.Y.	NY
96165	Princes Bay, New York	NOS	8519726	40.5117	-74.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:06:00	\N	1.05	00:00:00	\N	1.05	\N	\N	Princes Bay	NY
96166	Rossville, Arthur Kill, New York	NOS	8519789	40.5567	-74.2233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:29:00	\N	1.12	00:20:00	\N	1.12	\N	\N	Rossville, N.Y.	NY
96167	Alpine, Hudson River, New Jersey	NOS	8530095	40.945	-73.9183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	01:02:00	\N	0.9	01:05:00	\N	0.83	\N	\N	Alpine, N.J.	NJ
96168	New Millford, Hackensack River, New Jersey	NOS	8530186	40.935	-74.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	02:49:00	\N	1.02	01:17:00	\N	1.02	\N	\N	New Millford	NJ
96169	Hackensack, Hackensack River, New Jersey	NOS	8530278	40.88	-74.04	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	01:00:00	\N	1.38	01:06:00	\N	1.33	\N	\N	Hackensack	NJ
96170	Ridgefield Park, Hackensack River, New Jersey	NOS	8530398	40.85	-74.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	01:00:00	\N	1.26	01:00:00	\N	1.26	\N	\N	Ridgefield Park	NJ
96440	Oyster Harbor, Virginia	NOS	8631591	37.2883	-75.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	00:36:00	\N	1.13	01:00:00	\N	1.34	\N	\N	Oyster Harbor	VA
96171	East Rutherford, Passaic River, New Jersey	NOS	8530403	40.8467	-74.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	01:06:00	\N	1.29	00:09:00	\N	1.29	\N	\N	East Rutherford	NJ
96172	Edgewater, Hudson River, New Jersey	NOS	8530505	40.8133	-73.9783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	00:28:00	\N	0.93	00:31:00	\N	0.93	\N	\N	Edgewater, N.J.	NJ
96173	Carlstadt, Garretts Reach, Hackensack River, New Jersey	NOS	8530528	40.8067	-74.06	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	00:45:00	\N	1.29	00:59:00	\N	1.26	\N	\N	Carlstadt, Garretts Reach	NJ
96174	North Secaucus, Garretts Reach, Hackensack River, New Jersey	NOS	8530531	40.805	-74.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	00:57:00	\N	1.23	00:57:00	\N	1.23	\N	\N	North Secaucus, Garretts Reach	NJ
96175	Fish Creek, Berrys Creek, Hackensack River, New Jersey	NOS	8530586	40.7933	-74.0917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	01:00:00	\N	1	01:02:00	\N	1.16	\N	\N	Fish Creek, Berrys Creek	NJ
96176	Belleville, Passaic River, New Jersey	NOS	8530591	40.7867	-74.1467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	00:49:00	\N	1.19	00:09:00	\N	1.23	\N	\N	Belleville	NJ
96177	Weehawken, Union City, Hudson River, New Jersey	NOS	8530645	40.765	-74.0183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	00:15:00	\N	0.96	00:13:00	\N	0.96	\N	\N	Weehawken, Union City, N.J.	NJ
96178	Amtrak RR. swing bridge, Hackensack River, New Jersey	NOS	8530696	40.7517	-74.0967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	00:39:00	\N	1.1	00:33:00	\N	1.16	\N	\N	Amtrak RR. swing bridge	NJ
96179	Point No Point, Passaic River, New Jersey	NOS	8530743	40.7317	-74.1167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	00:22:00	\N	1.04	00:00:00	\N	1.15	\N	\N	Point No Point	NJ
96180	Kearny Point, Hackensack River, New Jersey	NOS	8530772	40.7283	-74.1033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	00:22:00	\N	1.14	00:11:00	\N	1.15	\N	\N	Kearny Point	NJ
96181	Port Elizabeth, New Jersey	NOS	8530882	40.6733	-74.14	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	00:13:00	\N	0.95	-00:02:00	\N	1.11	\N	\N	Port Elizabeth	NJ
96182	Port Newark Terminal, New Jersey	NOS	8530884	40.69	-74.1333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	00:21:00	\N	1.12	00:03:00	\N	1.12	\N	\N	Port Newark Terminal	NJ
96183	Constable Hook, New Jersey	NOS	8530985	40.655	-74.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94838	-00:08:00	\N	1.02	-00:18:00	\N	1.02	\N	\N	Constable Hook	NJ
96184	Rahway River, RR. Bridge, Arthur Kill, New Jersey	NOS	8531077	40.5983	-74.2317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:30:00	\N	1.16	00:17:00	\N	1.14	\N	\N	Rahway River, RR. Bridge	NJ
96185	Carteret, Arthur Kill, New Jersey	NOS	8531095	40.5867	-74.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:33:00	\N	1.09	00:22:00	\N	1.09	\N	\N	Carteret	NJ
96186	Woodbridge Creek, 0.8 nmi above entrance, Arthur Kill, New Jersey	NOS	8531156	40.545	-74.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:21:00	\N	1	00:09:00	\N	1.1	\N	\N	Woodbridge Creek, 0.8 n.mi. above entrance	NJ
96187	South Amboy, Raritan River, New Jersey (sub)	NOS	8531232	40.4917	-74.2817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:08:00	\N	1.09	-00:04:00	\N	1.09	\N	\N	South Amboy	NJ
96188	Matawan Creek, Route 35 bridge, New Jersey	NOS	8531526	40.4333	-74.2183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:07:00	\N	1.08	-00:01:00	\N	1.08	\N	\N	Matawan Creek, Route 35 bridge	NJ
96189	Keyport, New Jersey	NOS	8531545	40.44	-74.1983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:06:00	\N	1.1	-00:04:00	\N	1.08	\N	\N	Keyport	NJ
96190	Waackaack Creek, New Jersey	NOS	8531592	40.4483	-74.1433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:21:00	\N	0.99	-00:06:00	\N	0.99	\N	\N	Waackaack Creek	NJ
96191	Atlantic Highlands, Sandy Hook Bay, New Jersey	NOS	8531662	40.4183	-74.035	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	-00:10:00	\N	1.01	-00:10:00	\N	1.01	\N	\N	Atlantic Highlands	NJ
96192	Highlands, Route 36 bridge, Shrewsbury River, New Jersey	NOS	8531712	40.3967	-73.9817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:14:00	\N	0.9	00:17:00	\N	0.9	\N	\N	Highlands, Route 36 bridge	NJ
96193	Oceanic Bridge, Navesink River, Shrewsbury River, New Jersey	NOS	8531753	40.3767	-74.015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	01:45:00	\N	0.63	01:13:00	\N	0.72	\N	\N	Oceanic Bridge, Navesink River	NJ
96194	Sea Bright, Shrewsbury River, New Jersey (sub)	NOS	8531804	40.365	-73.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	01:07:00	\N	0.68	01:15:00	\N	0.68	\N	\N	Sea Bright	NJ
96195	Red Bank, Navesink River, Shrewsbury River, New Jersey	NOS	8531833	40.355	-74.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	01:57:00	\N	0.63	01:17:00	\N	0.74	\N	\N	Red Bank, Navesink River	NJ
96196	Gooseneck Point, bridge, Shrewsbury River, New Jersey	NOS	8531925	40.3267	-74.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:41:00	\N	0.55	02:18:00	\N	0.55	\N	\N	Gooseneck Point, bridge	NJ
96197	Long Branch Reach, Shrewsbury River, New Jersey	NOS	8531942	40.325	-73.9967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:41:00	\N	0.63	02:18:00	\N	0.56	\N	\N	Long Branch Reach	NJ
96198	Long Branch (fishing pier), New Jersey	NOS	8531991	40.3033	-73.9767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	-00:36:00	\N	1	-00:26:00	\N	0.94	\N	\N	Long Branch (fishing pier)	NJ
96199	Shark River Hills, Shark River, New Jersey	NOS	8532322	40.1917	-74.0383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	-00:09:00	\N	0.94	-00:13:00	\N	0.94	\N	\N	Shark River Hills	NJ
96200	Belmar (ocean), New Jersey	NOS	8532337	40.185	-74.0083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	-00:45:00	\N	0.95	-00:35:00	\N	0.95	\N	\N	Belmar, Atlantic Ocean	NJ
96201	Shark River Island, fixed RR. bridge, Shark River, New Jersey	NOS	8532339	40.1867	-74.0267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	-00:08:00	\N	0.93	-00:13:00	\N	0.93	\N	\N	Shark River Island, fixed RR. bridge	NJ
96202	New Bedford, Shark River, New Jersey	NOS	8532371	40.1783	-74.0467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	-00:07:00	\N	0.95	-00:13:00	\N	0.95	\N	\N	New Bedford	NJ
96203	Brielle, Route 35 bridge, Manasquan River, New Jersey	NOS	8532585	40.105	-74.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	-00:20:00	\N	0.83	-00:06:00	\N	0.83	\N	\N	Brielle, Route 35 bridge	NJ
96204	Manasquan Inlet, USCG station, New Jersey	NOS	8532591	40.1017	-74.035	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	-00:24:00	\N	0.95	-00:12:00	\N	0.86	\N	\N	Manasquan Inlet, USCG Station	NJ
96205	Riviera Beach, Manasquan River, New Jersey	NOS	8532611	40.0967	-74.0867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:38:00	\N	0.73	00:08:00	\N	0.73	\N	\N	Riviera Beach	NJ
96206	Forge Pond, Metedeconk River, New Jersey	NOS	8532703	40.065	-74.135	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:07:00	\N	0.07	02:17:00	\N	0.07	\N	\N	Forge Pond	NJ
96207	Beaverdam Creek entrance, Metedeconk River, New Jersey	NOS	8532715	40.0617	-74.0617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:40:00	\N	0.37	02:41:00	\N	0.07	\N	\N	Beaverdam Creek entrance	NJ
96208	Beaverdam Creek, inside, Metedeconk River, New Jersey	NOS	8532716	40.0617	-74.0733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:47:00	\N	0.06	02:49:00	\N	0.06	\N	\N	Beaverdam Creek, inside	NJ
96209	Tall Pines Camp, Metedeconk River, New Jersey	NOS	8532721	40.0583	-74.1167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:24:00	\N	0.06	02:23:00	\N	0.06	\N	\N	Tall Pines Camp	NJ
96210	Mantoloking, Barnegat Bay, New Jersey	NOS	8532786	40.0367	-74.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	04:39:00	\N	0.07	04:28:00	\N	0.07	\N	\N	Mantoloking	NJ
96211	Kettle Creek, Green Island, Barnegat Bay, New Jersey	NOS	8532835	40.0133	-74.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	04:41:00	\N	0.08	04:23:00	\N	0.08	\N	\N	Kettle Creek, Green Island	NJ
96212	Ocean Beach, Barnegat Bay, New Jersey	NOS	8532885	39.9883	-74.0683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	04:36:00	\N	0.08	04:17:00	\N	0.08	\N	\N	Ocean Beach	NJ
96213	Silver Bay, Silver Bay Marina, Barnegat Bay, New Jersey	NOS	8532921	39.9967	-74.1483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	04:39:00	\N	0.08	04:26:00	\N	0.08	\N	\N	Silver Bay, Silver Bay Marina	NJ
96214	Goose Creek entrance, Barnegat Bay, New Jersey	NOS	8533005	39.9633	-74.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	04:29:00	\N	0.08	04:06:00	\N	0.08	\N	\N	Goose Creek entrance	NJ
96215	Coates Point, Barnegat Bay, New Jersey	NOS	8533055	39.9483	-74.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	04:21:00	\N	0.08	04:00:00	\N	0.08	\N	\N	Coates Point	NJ
96216	Seaside Heights, ocean, New Jersey	NOS	8533071	39.9433	-74.035	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	-00:32:00	\N	0.92	-00:30:00	\N	0.92	\N	\N	Seaside Heights, ocean	NJ
96217	Seaside Park, Barnegat Bay, New Jersey	NOS	8533135	39.9217	-74.0833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	04:05:00	\N	0.08	03:40:00	\N	0.08	\N	\N	Seaside Park	NJ
96218	Barnegat Pier, Barnegat Bay, New Jersey	NOS	8533141	39.9183	-74.11	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:55:00	\N	0.08	03:35:00	\N	0.08	\N	\N	Barnegat Pier	NJ
96219	Sloop Creek, Barnegat Bay, New Jersey	NOS	8533185	39.905	-74.1333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	04:01:00	\N	0.08	03:38:00	\N	0.08	\N	\N	Sloop Creek	NJ
96220	Cedar Creek, Barnegat Bay, New Jersey	NOS	8533295	39.87	-74.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:45:00	\N	0.08	03:23:00	\N	0.08	\N	\N	Cedar Creek	NJ
96221	Island Beach, Barnegat Bay, New Jersey	NOS	8533345	39.8517	-74.0883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:28:00	\N	0.08	03:04:00	\N	0.08	\N	\N	Island Beach	NJ
96222	Stouts Creek, Barnegat Bay, New Jersey (sub)	NOS	8533365	39.845	-74.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:33:00	\N	0.06	03:16:00	\N	0.06	\N	\N	Stouts Creek	NJ
96223	Forked River, Barnegat Bay, New Jersey	NOS	8533391	39.825	-74.1733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:20:00	\N	0.07	03:08:00	\N	0.07	\N	\N	Forked River	NJ
96224	Oyster Creek, Barnegat Bay, New Jersey	NOS	8533465	39.8083	-74.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:36:00	\N	0.06	03:30:00	\N	0.06	\N	\N	Oyster Creek	NJ
96225	Island Beach, Sedge Islands, Barnegat Bay, New Jersey	NOS	8533535	39.7883	-74.0983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:56:00	\N	0.07	03:00:00	\N	0.07	\N	\N	Island Beach, Sedge Islands	NJ
96226	Waretown, Barnegat Bay, New Jersey	NOS	8533541	39.7917	-74.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:00:00	\N	0.07	02:43:00	\N	0.07	\N	\N	Waretown	NJ
96227	High Bar, Barnegat Bay, New Jersey	NOS	8533631	39.7567	-74.1283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	01:55:00	\N	0.12	01:04:00	\N	0.12	\N	\N	High Bar	NJ
96228	Double Creek, Barnegat Bay, New Jersey	NOS	8533665	39.745	-74.2017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:33:00	\N	0.07	03:03:00	\N	0.07	\N	\N	Double Creek	NJ
96229	Loveladies Harbor, Barnegat Bay, New Jersey	NOS	8533738	39.725	-74.1367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:39:00	\N	0.1	03:02:00	\N	0.1	\N	\N	Loveladies Harbor	NJ
96230	Flat Creek, Manahawkin Bay, New Jersey	NOS	8533780	39.7067	-74.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	04:35:00	\N	0.18	03:33:00	\N	0.18	\N	\N	Flat Creek	NJ
96231	North Beach, Manahawkin Bay, New Jersey	NOS	8533862	39.675	-74.16	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	04:07:00	\N	0.22	03:02:00	\N	0.22	\N	\N	North Beach	NJ
96232	Mill Creek, 1 nmi above entrance, Little Egg Harbor, New Jersey	NOS	8533905	39.665	-74.2317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:33:00	\N	0.35	02:32:00	\N	0.35	\N	\N	Mill Creek, 1 n.mi. above entrance	NJ
96233	Manahawkin Creek, Manahawkin Bay, New Jersey	NOS	8533909	39.6667	-74.215	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:51:00	\N	0.27	02:50:00	\N	0.27	\N	\N	Manahawkin Creek	NJ
96234	Manahawkin Drawbridge, Manahawkin Bay, New Jersey	NOS	8533935	39.6533	-74.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:39:00	\N	0.27	02:47:00	\N	0.27	\N	\N	Manahawkin Drawbridge	NJ
96235	Cedar Run, Little Egg Harbor, New Jersey	NOS	8533941	39.6533	-74.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:56:00	\N	0.4	02:10:00	\N	0.4	\N	\N	Cedar Run	NJ
96236	Dinner Point Creek, upper end, Little Egg Harbor, New Jersey	NOS	8533982	39.6567	-74.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:17:00	\N	0.4	02:41:00	\N	0.4	\N	\N	Dinner Point Creek, upper end	NJ
96237	West Creek, Westecunk Creek, Little Egg Harbor, New Jersey	NOS	8533987	39.6317	-74.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:40:00	\N	0.47	02:10:00	\N	0.44	\N	\N	West Creek, Westecunk Creek	NJ
96238	Sweetwater, Mullica River Marina, Mullica River, New Jersey	NOS	8534002	39.625	-74.6417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	04:21:00	\N	0.56	03:23:00	\N	0.56	\N	\N	Sweetwater, Mullica River Marina	NJ
96239	Wading River (town), Wading River, Mullica River, New Jersey	NOS	8534043	39.6183	-74.4967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:44:00	\N	0.79	02:48:00	\N	0.64	\N	\N	Wading River (town), Wading River	NJ
96240	Westecunk Creek entrance, Little Egg Harbor, New Jersey	NOS	8534044	39.6133	-74.2633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:40:00	\N	0.47	02:00:00	\N	0.42	\N	\N	Westecunk Creek entrance	NJ
96241	Beach Haven Crest, Little Egg Harbor, New Jersey	NOS	8534048	39.6133	-74.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:59:00	\N	0.32	02:13:00	\N	0.38	\N	\N	Beach Haven Crest	NJ
96242	Parker Run, upper end, Little Egg Harbor, New Jersey	NOS	8534049	39.6167	-74.31	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:39:00	\N	0.47	02:05:00	\N	0.45	\N	\N	Parker Run, upper end	NJ
96243	Tuckerton, Tuckerton Creek, Little Egg Harbor, New Jersey	NOS	8534080	39.6017	-74.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:15:00	\N	0.47	01:45:00	\N	0.45	\N	\N	Tuckerton, Tuckerton Creek	NJ
96244	New Gretna, Bass River, Mullica River, New Jersey	NOS	8534104	39.5917	-74.4417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:06:00	\N	0.74	01:52:00	\N	0.66	\N	\N	New Gretna, Bass River	NJ
96245	Green Bank, Mullica River, New Jersey	NOS	8534117	39.6117	-74.59	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	03:16:00	\N	0.66	02:59:00	\N	0.66	\N	\N	Green Bank	NJ
96246	Tuckerton Creek entrance, Little Egg Harbor, New Jersey	NOS	8534139	39.5767	-74.3317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	01:59:00	\N	0.45	01:32:00	\N	0.45	\N	\N	Tuckerton Creek entrance	NJ
96247	Beach Haven USCG station, Little Egg Harbor, New Jersey	NOS	8534208	39.5483	-74.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	01:23:00	\N	0.58	01:18:00	\N	0.46	\N	\N	Beach Haven Coast Guard Station	NJ
96248	Cramers Boatyard, Mullica River, New Jersey	NOS	8534212	39.5483	-74.4617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	02:01:00	\N	0.79	01:27:00	\N	0.63	\N	\N	Chestnut Neck Boat Yard	NJ
96249	Graveling Point, Great Bay, New Jersey	NOS	8534244	39.540000915527344	-74.38670349121094	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	01:14:00	\N	0.68	00:44:00	\N	0.68	\N	\N	Graveling Point	NJ
96250	Nacote Creek, US Highway 9 bridge, Mullica River, New Jersey	NOS	8534256	39.535	-74.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	01:55:00	\N	0.68	01:34:00	\N	0.66	\N	\N	Nacote Creek, U.S. Highway 9 bridge	NJ
96251	Little Sheepshead Creek, Great Bay, New Jersey	NOS	8534287	39.5217	-74.32	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:44:00	\N	0.68	00:35:00	\N	0.66	\N	\N	Little Sheepshead Creek	NJ
96252	Seven Island, Newmans Thorofare, Great Bay, New Jersey	NOS	8534296	39.5167	-74.3367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:28:00	\N	0.73	00:32:00	\N	0.73	\N	\N	Seven Island, Newmans Thorofare	NJ
96253	Main Marsh Thorofare, New Jersey	NOS	8534393	39.4783	-74.3833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	01:52:00	\N	0.76	01:10:00	\N	0.8	\N	\N	Main Marsh Thorofare	NJ
96254	Brigantine Channel @ Hoffman Thorofare, New Jersey	NOS	8534496	39.435	-74.3633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	00:58:00	\N	0.88	00:59:00	\N	0.9	\N	\N	Brigantine Channel @ Hoffman Thorofare	NJ
96255	Absecon, Absecon Creek, US Hwy. 30 bridge, New Jersey	NOS	8534540	39.4233	-74.5	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	01:37:00	\N	0.94	01:28:00	\N	0.96	\N	\N	Absecon, Absecon Creek, U.S. Hwy. 30 bridge	NJ
96256	Absecon Channel, State Route 87 bridge, New Jersey	NOS	8534638	39.385	-74.425	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	00:26:00	\N	1.13	00:38:00	\N	0.96	\N	\N	Absecon Channel, State Route 87 bridge	NJ
96257	Pleasantville, Lakes Bay, Great Egg Harbor Inlet, New Jersey	NOS	8534657	39.3817	-74.5183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	01:37:00	\N	0.82	01:00:00	\N	0.98	\N	\N	Pleasantville, Lakes Bay, Great Egg Harbor Inlet	NJ
96258	River Bend Marina, Great Egg Harbor River, New Jersey	NOS	8534691	39.3683	-74.7167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	02:25:00	\N	1	02:12:00	\N	0.87	\N	\N	River Bend Marina, Great Egg Harbor River	NJ
96259	Dock Thorofare, Risley Channel, New Jersey	NOS	8534739	39.3517	-74.54	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	01:00:00	\N	0.94	00:55:00	\N	0.98	\N	\N	Dock Thorofare, Risley Channel	NJ
96260	Steelmanville, Patcong Ck., 2.5 nmi above ent., Great Egg Harbor Bay, New Jersey	NOS	8534778	39.335	-74.5967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	01:50:00	\N	0.94	01:28:00	\N	0.92	\N	\N	Steelmanville, Patcong Ck., 2.5 nm above ent.	NJ
96261	Beesleys Point, Great Egg Harbor Bay, New Jersey	NOS	8534975	39.2883	-74.6283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	01:32:00	\N	1	00:55:00	\N	0.87	\N	\N	Beesleys Point	NJ
96262	Cedar Swamp Creek, Tuckahoe River, Great Egg Harbor Bay, New Jersey	NOS	8535001	39.2467	-74.7183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	03:03:00	\N	1.53	03:14:00	\N	0.78	\N	\N	Cedar Swamp Creek, Tuckahoe River	NJ
96263	Middle Thorofare, Ocean Drive bridge, Corson Inlet, New Jersey	NOS	8535101	39.215	-74.6483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	00:30:00	\N	0.94	00:31:00	\N	0.95	\N	\N	Middle Thorofare, Ocean Drive bridge	NJ
96264	Strathmere, Strathmere Bay, Corson Inlet, New Jersey	NOS	8535163	39.2	-74.6567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	00:38:00	\N	1	00:31:00	\N	0.95	\N	\N	Strathmere, Strathmere Bay	NJ
96265	Ludlam Bay, west side, Corson Inlet, New Jersey	NOS	8535221	39.1767	-74.71	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	01:12:00	\N	0.94	00:56:00	\N	0.98	\N	\N	Ludlam Bay, west side	NJ
96266	Townsend Sound, Townsends Inlet, New Jersey	NOS	8535309	39.1467	-74.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	01:39:00	\N	0.59	01:08:00	\N	0.9	\N	\N	Townsend Sound	NJ
96267	Stites Sound, Townsends Inlet, New Jersey	NOS	8535357	39.12	-74.755	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	01:04:00	\N	1	00:49:00	\N	0.97	\N	\N	Stites Sound	NJ
96268	Ingram Thorofare, Townsends Inlet, New Jersey (sub)	NOS	8535419	39.11	-74.7383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	00:50:00	\N	1	00:44:00	\N	0.96	\N	\N	Ingram Thorofare	NJ
96269	Long Reach, Ingram Thorofare, Townsends Inlet, New Jersey	NOS	8535451	39.1017	-74.755	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	01:11:00	\N	1.06	01:06:00	\N	0.98	\N	\N	Long Reach, Ingram Thorofare	NJ
96270	Nummy Island, Grassy Sound Channel, Hereford Inlet, New Jersey	NOS	8535661	39.0283	-74.8017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	00:45:00	\N	1	00:32:00	\N	1	\N	\N	Nummy Island, Grassy Sound Channel	NJ
96271	Old Turtle Thorofare, RR. bridge, Hereford Inlet, New Jersey	NOS	8535695	39.0183	-74.8417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	01:10:00	\N	1	00:56:00	\N	1.06	\N	\N	Old Turtle Thorofare, RR. bridge	NJ
96272	West Wildwood, Grassy Sound, Hereford Inlet, New Jersey	NOS	8535726	39.005	-74.8267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	01:11:00	\N	1	00:57:00	\N	1.04	\N	\N	West Wildwood, Grassy Sound	NJ
96273	Swain Channel, Taylor Sound, Cape May Inlet, New Jersey	NOS	8535805	38.98	-74.8633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	00:40:00	\N	1.06	00:55:00	\N	1.09	\N	\N	Swain Channel, Taylor Sound	NJ
96274	Wildwood Crest, Sunset Lake, Cape May Inlet, New Jersey	NOS	8535838	38.9783	-74.8367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	00:47:00	\N	1.06	00:52:00	\N	1.1	\N	\N	Wildwood Crest, Sunset Lake	NJ
96275	Cape May Harbor, Cape May Inlet, New Jersey	NOS	8535901	38.9483	-74.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	00:19:00	\N	1.06	00:33:00	\N	1.1	\N	\N	Cape May Harbor	NJ
96276	Cape Island Creek, Cape May, New Jersey	NOS	8535902	38.9467	-74.9133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	00:20:00	\N	1.19	00:40:00	\N	1.11	\N	\N	Cape Island Creek, Cape May	NJ
96277	Cape May (ocean), New Jersey	NOS	8535962	38.93	-74.935	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94864	00:21:00	\N	1.06	00:34:00	\N	1.12	\N	\N	Cape May, Atlantic Ocean	NJ
96278	Cape May Point, Sunset Beach, Delaware Bay, New Jersey	NOS	8536021	38.9467	-74.9717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	-00:08:00	\N	1.16	-00:05:00	\N	1.16	\N	\N	Cape May Point, Sunset Beach	NJ
96279	North Highlands Beach, Delaware Bay, New Jersey	NOS	8536271	39.0183	-74.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	00:14:00	\N	1.26	00:04:00	\N	1.26	\N	\N	North Highlands Beach	NJ
96280	Dias Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536449	39.0833	-74.8867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	03:18:00	\N	0.46	01:09:00	\N	0.46	\N	\N	Dias Creek, Route 47 bridge	NJ
96281	Bidwell Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536551	39.1183	-74.8683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	00:48:00	\N	1.36	00:36:00	\N	1.36	\N	\N	Bidwell Creek, Route 47 bridge	NJ
96282	Sluice Creek, Route 47 bridge, Dennis Creek, Delaware Bay, New Jersey	NOS	8536687	39.1617	-74.8317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	01:36:00	\N	1.22	01:49:00	\N	1.22	\N	\N	Sluice Creek, Route 47 bridge, Dennis Creek	NJ
96283	Dennis Creek, 2.5 nmi above entrance, Delaware Bay, New Jersey	NOS	8536736	39.1783	-74.8517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	01:17:00	\N	1.26	00:55:00	\N	1.26	\N	\N	Dennis Creek, 2.5 n.mi. above entrance	NJ
96284	Dennis Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536752	39.1833	-74.8217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	01:30:00	\N	1.2	02:01:00	\N	1.2	\N	\N	Dennis Creek, Route 47 bridge	NJ
96285	West Creek, 0.7 nmi above entrance, Delaware Bay, New Jersey	NOS	8536764	39.1883	-74.915	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	01:31:00	\N	1.15	00:20:00	\N	1.15	\N	\N	West Creek, 0.7 n.mi. above entrance	NJ
96286	East Point, Maurice River Cove, Delaware Bay, New Jersey	NOS	8536780	39.2	-75.02	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	01:08:00	\N	1.39	00:40:00	\N	1.39	\N	\N	East Point, Maurice River Cove	NJ
96287	Riggins Ditch, 0.5 nmi above entrance, Delaware Bay, New Jersey	NOS	8536801	39.2	-74.97	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	01:29:00	\N	1.24	00:29:00	\N	1.24	\N	\N	Riggins Ditch, 0.5 n.mi. above entrance	NJ
96288	East Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536823	39.2083	-74.9017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	02:24:00	\N	0.94	01:46:00	\N	0.94	\N	\N	East Creek, Route 47 bridge	NJ
96289	Fishing Creek entrance, Delaware Bay, New Jersey	NOS	8536848	39.2167	-75.1583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	-02:10:00	\N	1.02	-01:51:00	\N	1.02	\N	\N	Fishing Creek entrance	NJ
96290	Dividing Creek entrance, Delaware Bay, New Jersey	NOS	8536849	39.2167	-75.1033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	01:05:00	\N	1.35	00:29:00	\N	1.35	\N	\N	Dividing Creek entrance	NJ
96291	West Creek, Route 47 bridge, Delaware Bay, New Jersey	NOS	8536851	39.2167	-74.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	03:17:00	\N	0.58	02:20:00	\N	0.58	\N	\N	West Creek, Route 47 bridge	NJ
96292	Riggins Ditch, Heislerville, Delaware Bay, New Jersey	NOS	8536855	39.2183	-74.98	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	01:40:00	\N	1.12	01:36:00	\N	1.12	\N	\N	Riggins Ditch, Heislerville	NJ
96293	Weir Creek bridge, Dividing Creek, Delaware Bay, New Jersey	NOS	8536935	39.25	-75.1283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	02:33:00	\N	0.71	01:38:00	\N	0.71	\N	\N	Weir Creek bridge, Dividing Creek	NJ
96294	Hollywood Beach, The Glades, Delaware Bay, New Jersey	NOS	8537026	39.275	-75.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	01:13:00	\N	0.21	01:45:00	\N	0.21	\N	\N	Hollywood Beach, The Glades	NJ
96295	Money Island, Nantuxent Creek entrance, Delaware Bay, New Jersey	NOS	8537052	39.285	-75.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	-01:58:00	\N	1.1	-01:43:00	\N	1.1	\N	\N	Money Island, Nantuxent Creek entrance	NJ
96296	Mauricetown, Maurice River, New Jersey	NOS	8537059	39.285	-74.9917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	02:30:00	\N	1.05	02:17:00	\N	1.05	\N	\N	Mauricetown	NJ
96297	Newport Landing, Nantuxent Creek, Delaware Bay, New Jersey	NOS	8537079	39.2917	-75.1983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	-00:28:00	\N	0.74	-00:03:00	\N	0.74	\N	\N	Newport Landing, Nantuxent Creek	NJ
96298	Cedar Creek entrance, Nantuxent Cove, Delaware Bay, New Jersey	NOS	8537101	39.2983	-75.2467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	-01:51:00	\N	1.08	-01:37:00	\N	1.08	\N	\N	Cedar Creek entrance, Nantuxent Cove	NJ
96299	Back Creek entrance, Nantuxent Cove, Delaware Bay, New Jersey	NOS	8537116	39.305	-75.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	-01:34:00	\N	1.07	-01:29:00	\N	1.07	\N	\N	Back Creek entrance, Nantuxent Cove	NJ
96300	Port Elizabeth, Manumuskin River, Maurice River, New Jersey	NOS	8537147	39.3133	-74.985	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	02:58:00	\N	1.05	02:52:00	\N	1.05	\N	\N	Port Elizabeth, Manumuskin River	NJ
96301	Menantico Creek entrance, Maurice River, New Jersey	NOS	8537242	39.3433	-75.0083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	03:09:00	\N	1.1	03:06:00	\N	1.1	\N	\N	Menantico Creek entrance	NJ
96302	Tindalls Wharf, Cohansey River, Delaware Bay, New Jersey	NOS	8537353	39.3783	-75.235	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	-00:02:00	\N	1.09	01:01:00	\N	1.09	\N	\N	Tindalls Wharf, Cohansey River	NJ
96303	Millville, Maurice River, New Jersey	NOS	8537359	39.3917	-75.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	03:36:00	\N	1.21	03:33:00	\N	1.21	\N	\N	Millville	NJ
96304	Greenwich Pier, Cohansey River, Delaware Bay, New Jersey	NOS	8537374	39.3833	-75.35	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	-00:54:00	\N	0.99	-00:42:00	\N	0.99	\N	\N	Greenwich Pier, Cohansey River	NJ
96305	Stathems Neck, Stow Creek, Delaware River, New Jersey	NOS	8537416	39.4067	-75.405	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	-00:37:00	\N	0.88	-00:22:00	\N	0.88	\N	\N	Stathems Neck, Stow Creek, N.J.	NJ
96306	Pine Island, Malapartis Creek, Mad Horse Creek, New Jersey	NOS	8537488	39.4217	-75.4283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	-00:18:00	\N	0.92	00:21:00	\N	0.92	\N	\N	Pine Island, Malapartis Creek, N.J.	NJ
96307	Raccoon Ditch, Newport Meadows, Stow Creek, Delaware River, New Jersey	NOS	8537489	39.4217	-75.3817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	00:33:00	\N	0.76	01:08:00	\N	0.76	\N	\N	Raccoon Ditch, Newport Meadows, Stow Creek, N.J.	NJ
96308	1 nmi above entrance, Mad Horse Creek, New Jersey	NOS	8537535	39.4317	-75.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	-00:47:00	\N	1.07	-00:20:00	\N	1.07	\N	\N	1 n.mi. above entrance, N.J.	NJ
96309	Canton, Stow Creek, Delaware River, New Jersey	NOS	8537562	39.4617	-75.4033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	00:45:00	\N	0.8	01:36:00	\N	0.8	\N	\N	Canton, Stow Creek, N.J.	NJ
96310	Artificial Island, Salem Nuclear Plant, Delaware River, New Jersey	NOS	8537614	39.46	-75.5317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	-00:33:00	\N	1.08	-00:35:00	\N	1.08	\N	\N	Artificial Island, Salem Nuclear Plant, N.J.	NJ
96311	Hope Creek, 0.6 nmi above entrance, Delaware River, New Jersey	NOS	8537667	39.4583	-75.495	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	-00:36:00	\N	1.05	-00:25:00	\N	1.05	\N	\N	Hope Creek, 0.6 n.mi. above entrance, N.J.	NJ
96312	0.8 nmi above entrance, Alloway Creek, New Jersey	NOS	8537731	39.4967	-75.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	-00:10:00	\N	0.99	00:21:00	\N	0.99	\N	\N	0.8 n.mi. above entrance	NJ
96313	2.5 nmi above entrance, Alloway Creek, New Jersey	NOS	8537753	39.505	-75.4833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	00:15:00	\N	0.9	00:51:00	\N	0.9	\N	\N	2.5 n.mi. above entrance	NJ
96314	Abbots Meadow, Alloway Creek, New Jersey	NOS	8537774	39.5117	-75.4933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	00:12:00	\N	0.94	00:44:00	\N	0.94	\N	\N	Abbots Meadow	NJ
96315	Coopers Creek bridge, Alloway Creek, New Jersey	NOS	8537779	39.5133	-75.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	01:00:00	\N	0.78	01:51:00	\N	0.78	\N	\N	Coopers Creek bridge	NJ
96316	Quinton, Alloway Creek, New Jersey	NOS	8537889	39.5483	-75.415	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	01:30:00	\N	0.69	02:24:00	\N	0.69	\N	\N	Quinton	NJ
96317	Sinnickson Landing, Salem River, New Jersey	NOS	8537961	39.57	-75.4983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	00:19:00	\N	0.97	00:04:00	\N	0.97	\N	\N	Sinnickson Landing	NJ
96318	Salem, Salem River, New Jersey	NOS	8537979	39.5767	-75.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	00:41:00	\N	0.76	00:49:00	\N	0.76	\N	\N	Salem	NJ
96319	Salem Canal entrance, Delaware River, New Jersey	NOS	8538231	39.6833	-75.51	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	00:52:00	\N	1	00:36:00	\N	1	\N	\N	Salem Canal entrance, N.J.	NJ
96320	Auburn, Oldmans Creek, Delaware River, New Jersey	NOS	8538274	39.715	-75.36	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	03:30:00	\N	0.55	04:12:00	\N	0.55	\N	\N	Auburn, Oldmans Creek, N.J.	NJ
96321	Pedricktown, Oldmans Creek, Delaware River, New Jersey	NOS	8538369	39.7617	-75.4033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	02:07:00	\N	0.75	02:11:00	\N	0.75	\N	\N	Pedricktown, Oldmans Creek, N.J.	NJ
96322	Mantua, Mantua Creek, New Jersey	NOS	8538438	39.795	-75.1767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	00:56:00	\N	0.71	01:28:00	\N	0.71	\N	\N	Mantua, Mantua Creek, N.J.	NJ
96323	Bridgeport, Raccoon Creek, New Jersey	NOS	8538449	39.8067	-75.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	-00:50:00	\N	1	-01:11:00	\N	0.91	\N	\N	Bridgeport, Raccoon Creek, N.J.	NJ
96324	Woodbury Creek, New Jersey	NOS	8538548	39.86	-75.1867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	-00:14:00	\N	0.95	-00:13:00	\N	0.96	\N	\N	Woodbury Creek, N.J.	NJ
96325	Billingsport, New Jersey	NOS	8538552	39.85	-75.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	-00:28:00	\N	0.95	-00:35:00	\N	0.93	\N	\N	Billingsport, N.J.	NJ
96326	Westville, Rt. 47 bridge, Big Timber Creek, New Jersey	NOS	8538601	39.8733	-75.1233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	00:03:00	\N	1	00:02:00	\N	0.97	\N	\N	Westville, Rt. 47 bridge, Big Timber Creek, N.J.	NJ
96327	Pavonia, Cooper River, RR. bridge, New Jersey	NOS	8538752	39.9467	-75.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	00:23:00	\N	1	00:14:00	\N	1.04	\N	\N	Pavonia, Cooper River, RR. bridge, N.J.	NJ
96328	Hainesport, South Branch, Rancocas Creek, New Jersey	NOS	8538824	39.9783	-74.8233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	03:05:00	\N	0.62	02:58:00	\N	0.62	\N	\N	Hainesport, South Branch	NJ
96329	North Branch, Rancocas Creek, New Jersey	NOS	8538848	39.9983	-74.8183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	03:29:00	\N	0.6	02:58:00	\N	0.48	\N	\N	North Branch	NJ
96330	Palmyra, Pennsauken Creek, Route 73 bridge, New Jersey	NOS	8538853	39.9933	-75.0283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	01:03:00	\N	0.89	00:51:00	\N	0.89	\N	\N	Palmyra, Pennsauken Creek, Route 73 bridge, N.J.	NJ
96331	Pompeston Creek, New Jersey	NOS	8538875	40.0133	-75.0083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	00:43:00	\N	1.05	00:21:00	\N	1.05	\N	\N	Pompeston Creek, N.J.	NJ
96332	Bridgeboro, Rancocas Creek, New Jersey	NOS	8538921	40.0283	-74.9317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	01:18:00	\N	1	01:15:00	\N	1.06	\N	\N	Bridgeboro	NJ
96333	Assiscunk Creek, Route 130 bridge, New Jersey	NOS	8539058	40.0733	-74.8483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	01:31:00	\N	0.85	01:04:00	\N	1.12	\N	\N	Assiscunk Creek, Route 130 bridge, N.J.	NJ
96334	Wanamaker Bridge, Darby Creek, Pennsylvania	NOS	8542425	39.8767	-75.305	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	-00:34:00	\N	0.95	-00:46:00	\N	0.95	\N	\N	Wanamaker Bridge	PA
96335	Norwood City, Darby Creek, Pennsylvania	NOS	8542699	39.88	-75.29	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	-00:35:00	\N	1	-00:42:00	\N	0.97	\N	\N	Norwood City	PA
96336	Tinicum National Wildlife Refuge, Darby Creek, Pennsylvania	NOS	8542885	39.8783	-75.2767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	-00:08:00	\N	0.9	-00:22:00	\N	0.91	\N	\N	Tinicum National Wildlife Refuge	PA
96337	Tinicum National Wildlife Refuge, Darby Creek, Pennsylvania (2)	NOS	8543024	39.8867	-75.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	00:27:00	\N	0.74	-00:24:00	\N	0.74	\N	\N	Tinicum National Wildlife Refuge	PA
96338	Penrose Avenue Bridge, Schuylkill River, Pennsylvania	NOS	8543925	39.8983	-75.2117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	-00:11:00	\N	0.85	-00:22:00	\N	0.96	\N	\N	Penrose Avenue Bridge	PA
96339	Market Street Bridge, Schuylkill River, Pennsylvania	NOS	8545120	39.955	-75.18	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	00:00:00	\N	0.8	-00:20:00	\N	0.99	\N	\N	Market Street Bridge	PA
96340	Cornwells Heights, Pennsylvania	NOS	8547333	40.0683	-74.9383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	00:58:00	\N	1	00:46:00	\N	1.17	\N	\N	Cornwells Heights, Pa.	PA
96341	Edgely, Pennsylvania	NOS	8549424	40.1283	-74.8233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94883	01:28:00	\N	1.15	01:08:00	\N	1.27	\N	\N	Edgely, Pa.	PA
96342	Edgemoor, Delaware River, Delaware	NOS	8550438	39.75	-75.4933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	01:11:00	\N	1.17	00:52:00	\N	1.02	\N	\N	Edgemoor, Del.	DE
96343	Millside, RR. bridge, Christina River, Delaware	NOS	8550658	39.725	-75.56	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	01:19:00	\N	1.06	01:08:00	\N	0.99	\N	\N	Millside, RR. bridge	DE
96344	Wilmington Marine Terminal, Christina River, Delaware	NOS	8550714	39.7183	-75.52	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	01:06:00	\N	1.11	00:50:00	\N	0.99	\N	\N	Wilmington Marine Terminal	DE
96345	New Castle, Delaware River, Delaware	NOS	8551201	39.6567	-75.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	00:40:00	\N	1	00:29:00	\N	0.98	\N	\N	New Castle, Delaware	DE
96346	Pea Patch Island, Bulkhead Shoal Channel, Delaware River, Delaware	NOS	8551702	39.5833	-75.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	00:00:00	\N	1	00:03:00	\N	1.05	\N	\N	Pea Patch Island, Bulkhead Shoal Channel, Del.	DE
96347	Delaware City Branch Channel bridge, Delaware River, Delaware	NOS	8551851	39.57	-75.59	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	00:05:00	\N	0.89	00:00:00	\N	1.02	\N	\N	Delaware City Branch Channel bridge	DE
96348	St. Georges, Chesapeake and Delaware Canal, Delaware	NOS	8551973	39.555	-75.6483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	-00:17:00	\N	1	-00:16:00	\N	0.83	\N	\N	St. Georges, Delaware	DE
96349	Summit Bridge, Chesapeake and Delaware Canal, Delaware	NOS	8552125	39.5333	-75.7333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	-00:52:00	\N	0.56	-00:28:00	\N	0.65	\N	\N	Summit Bridge, Delaware	DE
96350	Taylors Bridge, Blackbird Creek, Delaware River, Delaware	NOS	8553069	39.405	-75.5983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	00:57:00	\N	0.56	01:53:00	\N	0.54	\N	\N	Taylors Bridge, Blackbird Creek, Del.	DE
96351	Woodland Beach, Delaware River, Delaware	NOS	8553501	39.3333	-75.4667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94888	-01:10:00	\N	1.11	-01:07:00	\N	1.11	\N	\N	Woodland Beach, Del.	DE
96352	Leipsic, Leipsic River, Delaware Bay, Delaware	NOS	8554038	39.245	-75.5183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	03:49:00	\N	0.63	03:35:00	\N	0.85	\N	\N	Leipsic, Leipsic River	DE
96353	Murderkill River entrance, Delaware Bay, Delaware	NOS	8555388	39.0583	-75.3967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	01:11:00	\N	0.94	00:39:00	\N	1.25	\N	\N	Murderkill River entrance	DE
96354	Mispillion River entrance, Delaware Bay, Delaware	NOS	8556198	38.945	-75.3133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94891	00:50:00	\N	1	00:22:00	\N	1.13	\N	\N	Mispillion River entrance	DE
96355	Rehoboth Beach, Delaware	NOS	8557863	38.72	-75.0833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	00:08:00	\N	1.33	00:15:00	\N	1.13	\N	\N	Rehoboth Beach	DE
96356	Keydash, Isle of Wight Bay, Maryland	NOS	8570255	38.3417	-75.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	00:54:00	\N	0.81	-00:57:00	\N	0.47	\N	\N	Keydash, Isle of Wight Bay	MD
96357	Ocean City (Isle of Wight Bay), Maryland	NOS	8570282	38.3317	-75.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	00:23:00	\N	0.94	00:25:00	\N	0.67	\N	\N	Ocean City (Isle of Wight Bay)	MD
96359	Shelltown, Pocomoke River, Maryland	NOS	8571097	37.98	-75.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	05:16:00	\N	1	04:32:00	\N	0.94	\N	\N	Shelltown	MD
96360	Colburn Creek, Big Annemessex River, Chesapeake Bay, Maryland	NOS	8571181	38.0483	-75.8033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	05:30:00	\N	1.17	04:59:00	\N	0.78	\N	\N	Colburn Creek, Big Annemessex River	MD
96361	Long Point, Big Annemessex River, Chesapeake Bay, Maryland	NOS	8571201	38.0567	-75.8033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	05:47:00	\N	0.83	05:19:00	\N	0.82	\N	\N	Long Point, Big Annemessex River	MD
96362	Holland Island Bar Light, Chesapeake Bay, Maryland	NOS	8571214	38.0683	-76.0967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	05:30:00	\N	0.58	05:16:00	\N	0.56	\N	\N	Holland Island Bar Light	MD
96363	Teague Creek, Manokin River, Chesapeake Bay, Maryland	NOS	8571269	38.1083	-75.8383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	06:05:00	\N	0.83	05:38:00	\N	0.82	\N	\N	Teague Creek, Manokin River	MD
96364	Chance, Chesapeake Bay, Maryland	NOS	8571351	38.1717	-75.945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	05:57:00	\N	1.17	05:29:00	\N	0.78	\N	\N	Chance	MD
96365	Sharkfin Shoal Light, Chesapeake Bay, Maryland	NOS	8571396	38.2017	-75.9867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	06:06:00	\N	0.92	05:46:00	\N	0.86	\N	\N	Sharkfin Shoal Light	MD
96366	Hooper Strait Light, Chesapeake Bay, Maryland	NOS	8571402	38.2267	-76.0767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	05:51:00	\N	1.17	05:26:00	\N	0.61	\N	\N	Hooper Strait Light	MD
96367	Great Shoals Light, Monie Bay, Chesapeake Bay, Maryland	NOS	8571416	38.2167	-75.8833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	06:22:00	\N	0.92	06:00:00	\N	0.9	\N	\N	Great Shoals Light, Monie Bay	MD
96368	Roaring Point, Nanticoke River, Maryland	NOS	8571476	38.2617	-75.92	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	06:35:00	\N	0.92	06:00:00	\N	0.9	\N	\N	Roaring Point	MD
96369	Whitehaven, Wicomico River, Maryland	NOS	8571485	38.2683	-75.7883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	06:46:00	\N	1	06:26:00	\N	0.94	\N	\N	Whitehaven	MD
96370	Middle Hooper Island, Chesapeake Bay, Maryland	NOS	8571519	38.2967	-76.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-04:39:00	\N	1.5	-04:40:00	\N	1.32	\N	\N	Middle Hooper Island	MD
96371	Taylors Island, Slaughter Creek, Little Choptank River, Maryland	NOS	8571752	38.4667	-76.295	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-03:00:00	\N	1.18	-03:15:00	\N	1.1	\N	\N	Taylors Island, Slaughter Creek	MD
96372	Woolford, Church Creek, Little Choptank River, Maryland	NOS	8571807	38.5067	-76.1733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-02:55:00	\N	1.41	-03:11:00	\N	1.25	\N	\N	Woolford, Church Creek	MD
96373	Cherry Island, Beckwiths Creek, Little Choptank River, Maryland	NOS	8571881	38.5617	-76.2083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-02:57:00	\N	1.27	-03:07:00	\N	1.18	\N	\N	Cherry Island, Beckwiths Creek	MD
96374	Avalon, Dogwood Harbor, Chesapeake Bay, Maryland	NOS	8571901	38.71	-76.335	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-02:48:00	\N	1.36	-02:54:00	\N	1.18	\N	\N	Avalon, Dogwood Harbor	MD
96375	Dover Bridge, Choptank River, Maryland	NOS	8571944	38.7567	-75.9983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-00:41:00	\N	1.68	-00:18:00	\N	1.54	\N	\N	Dover Bridge	MD
96376	Ferry Cove, Tilghman Island, Chesapeake Bay, Maryland	NOS	8571979	38.765	-76.3283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-02:42:00	\N	1	-02:33:00	\N	0.98	\N	\N	Tilghman Island, Ferry Cove, Eastern Bay	MD
96377	Oxford, Tred Avon River, Maryland	NOS	8572108	38.6933	-76.1733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-02:45:00	\N	1.41	-02:50:00	\N	1.25	\N	\N	Oxford	MD
96378	Deep Neck Point, Broad Creek, Chesapeake Bay, Maryland	NOS	8572204	38.7317	-76.235	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-02:47:00	\N	1.41	-02:57:00	\N	1.25	\N	\N	Deep Neck Point, Broad Creek	MD
96379	Easton Point, Tred Avon River, Maryland	NOS	8572296	38.7683	-76.095	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-02:35:00	\N	1.59	-02:45:00	\N	1.47	\N	\N	Easton Point	MD
96380	St. Michaels, San Domingo Creek, Chesapeake Bay, Maryland	NOS	8572313	38.775	-76.2333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-02:52:00	\N	1.41	-02:55:00	\N	1.25	\N	\N	St. Michaels, San Domingo Creek	MD
96381	St. Michaels, Miles River, Chesapeake Bay, Maryland (sub)	NOS	8572342	38.7867	-76.2217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-02:02:00	\N	1.18	-02:12:00	\N	1.22	\N	\N	St. Michaels, Miles River	MD
96382	Claiborne, Eastern Bay, Chesapeake Bay, Maryland	NOS	8572468	38.8367	-76.28	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-02:28:00	\N	1.09	-02:26:00	\N	0.96	\N	\N	Claiborne, Eastern Bay	MD
96383	Kent Island Narrows, Chesapeake Bay, Maryland	NOS	8572792	38.9667	-76.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-01:23:00	\N	1.18	-01:30:00	\N	1.1	\N	\N	Kent Island Narrows	MD
96384	Queenstown, Chester River, Maryland	NOS	8572867	38.9967	-76.1583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-00:08:00	\N	1.27	00:05:00	\N	1.18	\N	\N	Queenstown	MD
96385	Centreville Landing, Corsica River, Chester River, Maryland	NOS	8573006	39.0533	-76.075	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	00:14:00	\N	1.89	00:20:00	\N	1.47	\N	\N	Centreville Landing, Corsica River	MD
96386	Cliffs Point, Chester River, Maryland	NOS	8573125	39.1067	-76.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-00:02:00	\N	1.5	00:12:00	\N	1.32	\N	\N	Cliffs Point	MD
96387	Cliffs Wharf, Chester River, Maryland	NOS	8573137	39.11	-76.1383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-00:08:00	\N	1.27	00:09:00	\N	1.33	\N	\N	Cliffs Wharf	MD
96388	Deep Landing, Swan Creek, Chesapeake Bay, Maryland	NOS	8573211	39.145	-76.26	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-00:04:00	\N	1.09	00:02:00	\N	0.96	\N	\N	Deep Landing, Swan Creek	MD
96389	Chestertown, Chester River, Maryland	NOS	8573343	39.2067	-76.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	00:36:00	\N	1.77	01:03:00	\N	1.62	\N	\N	Chestertown	MD
96390	Worton Creek entrance, Chesapeake Bay, Maryland	NOS	8573442	39.2967	-76.1717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	01:19:00	\N	1.27	01:22:00	\N	1.18	\N	\N	Worton Creek entrance	MD
96391	Saxis, Starling Creek, Pocomoke Sound, Chesapeake Bay, Virginia (sub)	NOS	8573777	37.92166666666701	-75.728333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	04:36:00	\N	1.17	03:52:00	\N	0.89	\N	\N	Saxis, Starling Creek, Pocomoke Sound	VA
96392	Charlestown, Northeast River, Chesapeake Bay, Maryland	NOS	8573968	39.5733	-75.97	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	04:03:00	\N	1.86	03:52:00	\N	1.69	\N	\N	Charlestown, Northeast River	MD
96393	Old Frenchtown Wharf, Elk River, Maryland	NOS	8573969	39.575	-75.8433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	03:00:00	\N	2.27	03:13:00	\N	2.06	\N	\N	Old Frenchtown Wharf	MD
96394	Port Deposit, Susquehanna River, Maryland	NOS	8574008	39.6033	-76.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	03:49:00	\N	1.14	03:24:00	\N	1.51	\N	\N	Port Deposit	MD
96395	Hawkins Point, Patapsco River, Maryland	NOS	8574821	39.2083	-76.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	00:06:00	\N	0.95	00:00:00	\N	1.03	\N	\N	Hawkins Point	MD
96396	North Point, Patapsco River, Maryland	NOS	8574857	39.1967	-76.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	00:04:00	\N	1.09	00:12:00	\N	0.93	\N	\N	North Point	MD
96397	Stony Creek, Patapsco River, Maryland	NOS	8574931	39.1633	-76.5267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-00:05:00	\N	0.91	00:03:00	\N	0.95	\N	\N	Stony Creek	MD
96398	Cornfield Creek, Magothy River, Chesapeake Bay, Maryland	NOS	8575109	39.1	-76.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-00:38:00	\N	0.95	-00:29:00	\N	0.89	\N	\N	Cornfield Creek, Magothy River	MD
96399	Mountain Point, Magothy River, Chesapeake Bay, Maryland	NOS	8575229	39.0617	-76.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-00:04:00	\N	0.77	-00:04:00	\N	0.74	\N	\N	Mountain Point, Magothy River	MD
96400	Brewer Point, Severn River, Maryland	NOS	8575331	39.0267	-76.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-00:54:00	\N	0.91	-00:45:00	\N	0.74	\N	\N	Brewer Point	MD
96401	Gingerville Creek, South River, Chesapeake Bay, Maryland	NOS	8575550	38.9583	-76.555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-02:06:00	\N	1	-02:01:00	\N	0.92	\N	\N	Gingerville Creek, South River	MD
96402	Edgewater, South River, Chesapeake Bay, Maryland	NOS	8575579	38.95	-76.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-02:07:00	\N	0.91	-01:51:00	\N	0.81	\N	\N	Edgewater, South River	MD
96403	Thomas Point Shoal Light, Chesapeake Bay, Maryland	NOS	8575737	38.9	-76.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-02:11:00	\N	0.91	-01:56:00	\N	0.81	\N	\N	Thomas Point Shoal Light	MD
96404	Rhode River (County Wharf), Chesapeake Bay, Maryland	NOS	8575787	38.8867	-76.54	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-02:17:00	\N	1	-02:07:00	\N	0.88	\N	\N	Rhode River (County Wharf)	MD
96405	Galesville, West River, Chesapeake Bay, Maryland	NOS	8575923	38.8417	-76.54	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-01:34:00	\N	0.91	-01:39:00	\N	0.81	\N	\N	Galesville, West River	MD
96406	Rose Haven, Chesapeake Bay, Maryland	NOS	8576256	38.725	-76.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-02:44:00	\N	0.91	-02:37:00	\N	0.81	\N	\N	Rose Haven	MD
96407	Chesapeake Beach, Chesapeake Bay, Maryland	NOS	8576363	38.7	-76.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-03:05:00	\N	1	-02:47:00	\N	0.88	\N	\N	Chesapeake Beach	MD
96408	Broomes Island, Patuxent River, Maryland	NOS	8577123	38.415	-76.545	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-04:19:00	\N	1.36	-04:13:00	\N	1.18	\N	\N	Broomes Island	MD
96409	Cornfield Harbor, Potomac River, Maryland	NOS	8577940	38.06	-76.3617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-07:35:00	\N	0.53	-06:16:00	\N	0.48	\N	\N	Cornfield Harbor, Md.	MD
96410	Point Lookout, Chesapeake Bay, Maryland	NOS	8578002	38.04	-76.3233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-05:37:00	\N	0.77	-05:28:00	\N	1.02	\N	\N	Point Lookout	MD
96411	Piney Point, Potomac River, Maryland	NOS	8578240	38.1333333	-76.5333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-07:16:00	\N	0.6	-05:54:00	\N	0.51	\N	\N	Piney Point, Md.	MD
96412	Colton Point, Potomac River, Maryland	NOS	8578465	38.2233	-76.7483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-06:43:00	\N	0.73	-05:18:00	\N	0.65	\N	\N	Colton Point, Md.	MD
96413	Mills Point (south of), Wicomico River, Maryland	NOS	8578551	38.3267	-76.8333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-06:05:00	\N	0.73	-05:05:00	\N	0.65	\N	\N	Mills Point (south of), Wicomico Riv., Md.	MD
96414	Lower Cedar Point, Potomac River, Maryland	NOS	8578693	38.3417	-76.9767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-05:56:00	\N	0.6	-04:48:00	\N	0.54	\N	\N	Lower Cedar Point, Md.	MD
96415	Goose Creek, Port Tobacco River, Potomac River, Maryland	NOS	8578769	38.4533	-77.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-05:07:00	\N	0.6	-04:08:00	\N	0.54	\N	\N	Goose Creek, Port Tobacco River, Md.	MD
96416	Riverside, Potomac River, Maryland	NOS	8578853	38.3867	-77.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-04:24:00	\N	0.53	-03:23:00	\N	0.48	\N	\N	Riverside, Md.	MD
96417	Clifton Beach, Smith Point, Potomac River, Maryland	NOS	8578931	38.41333333333299	-77.266666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-02:46:00	\N	0.67	-01:42:00	\N	0.41	\N	\N	Clifton Beach, Smith Point, Md.	MD
96418	Liverpool Point, Potomac River, Maryland	NOS	8578984	38.46	-77.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-01:58:00	\N	0.67	-00:39:00	\N	0.44	\N	\N	Liverpool Point, Md.	MD
96419	Benedict, Patuxent River, Maryland	NOS	8579135	38.5133	-76.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94924	-03:54:00	\N	1.82	-03:54:00	\N	1.47	\N	\N	Benedict	MD
96420	Indian Head, Potomac River, Maryland	NOS	8579381	38.6017	-77.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-01:33:00	\N	0.73	-00:14:00	\N	0.65	\N	\N	Indian Head, Md.	MD
96421	Marshall Hall, Potomac River, Maryland	NOS	8579629	38.6867	-77.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-00:55:00	\N	0.93	00:10:00	\N	0.82	\N	\N	Marshall Hall, Md.	MD
96422	Bellevue, Potomac River, DC	NOS	8590111	38.8267	-77.0267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-00:11:00	\N	1.33	00:34:00	\N	1.02	\N	\N	Bellevue, D.C.	DC
96423	Washington Naval Yard, Anacostia River, DC	NOS	8593005	38.8717	-76.995	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-00:06:00	\N	1.2	00:18:00	\N	1.01	\N	\N	Washington Naval Yard	DC
96424	Kingman Lake, Anacostia River, DC	NOS	8593545	38.895	-76.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	00:04:00	\N	1.2	00:22:00	\N	1.03	\N	\N	Kingman Lake	DC
96425	Kenilworth Aquatic Garden, Anacostia River, DC	NOS	8593909	38.91	-76.955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	00:10:00	\N	1.07	00:29:00	\N	1.05	\N	\N	Kenilworth Aquatic Garden	DC
96426	Franklin City, Virginia	NOS	8630055	38.0067	-75.3817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	03:00:00	\N	0.63	02:20:00	\N	0.22	\N	\N	Franklin City	VA
96427	Chincoteague Island, Blake Cove, Virginia	NOS	8630194	37.9517	-75.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	02:32:00	\N	0.56	01:51:00	\N	0.28	\N	\N	Chincoteague Island, Blake Cove	VA
96428	Chincoteague Island, Oyster Bay, Virginia	NOS	8630225	37.9417	-75.3467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	02:05:00	\N	0.56	01:44:00	\N	0.46	\N	\N	Chincoteague Island, Oyster Bay	VA
96429	Chincoteague Island, Lewis Creek, Virginia	NOS	8630229	37.9383	-75.3733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	01:38:00	\N	0.63	01:17:00	\N	0.4	\N	\N	Chincoteague Island, Lewis Creek	VA
96430	Wishart Point, Bogues Bay, Virginia	NOS	8630371	37.8817	-75.4917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	01:13:00	\N	0.63	00:52:00	\N	0.77	\N	\N	Wishart Point, Bogues Bay	VA
96431	Assateague Beach, Toms Cove, Virginia	NOS	8630413	37.865	-75.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	00:48:00	\N	1.25	00:35:00	\N	1.08	\N	\N	Assateague Beach, Toms Cove	VA
96432	Wallops Island, Virginia	NOS	8630440	37.8417	-75.4783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	-00:04:00	\N	0.31	00:04:00	\N	1.06	\N	\N	Wallops Island	VA
96433	Gargathy Neck, Virginia	NOS	8630637	37.7767	-75.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	01:27:00	\N	0.63	01:31:00	\N	0.88	\N	\N	Gargathy Neck	VA
96434	Folly Creek, Metompkin Inlet, Virginia	NOS	8630839	37.6967	-75.635	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	01:12:00	\N	0.63	01:24:00	\N	0.97	\N	\N	Folly Creek, Metompkin Inlet	VA
96435	Metompkin Inlet, Virginia	NOS	8630901	37.6717	-75.595	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	00:44:00	\N	1.25	01:01:00	\N	1.08	\N	\N	Metompkin Inlet	VA
96436	Revel Island, Revel Creek, Virginia	NOS	8631234	37.4967	-75.6833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	00:27:00	\N	1	00:35:00	\N	1.19	\N	\N	Revel Creek, Revel Island	VA
96437	Upshur Neck, south end, Virginia	NOS	8631287	37.4667	-75.8	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	01:14:00	\N	1.25	01:09:00	\N	1.31	\N	\N	Upshur Neck, south end	VA
96438	Great Machipongo Inlet (inside), Virginia	NOS	8631411	37.3933	-75.7133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	00:56:00	\N	1.25	01:05:00	\N	1.16	\N	\N	Great Machipongo Inlet (inside)	VA
96439	Sand Shoal Inlet (USCG station), Virginia	NOS	8631542	37.3017	-75.7783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	00:17:00	\N	1	00:32:00	\N	1.18	\N	\N	Sand Shoal Inlet (Coast Guard Station)	VA
96441	Smith Island (USCG station), Virginia	NOS	8631874	37.1233	-75.9117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94895	01:29:00	\N	1.25	00:52:00	\N	1.05	\N	\N	Smith Island (Coast Guard Station)	VA
96442	Fishermans Island, Chesapeake Bay, Virginia	NOS	8632085	37.0967	-75.9833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	00:11:00	\N	1.25	00:02:00	\N	1.19	\N	\N	Fishermans Island	VA
96443	Old Plantation Light, Chesapeake Bay, Virginia	NOS	8632314	37.2333	-76.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	00:52:00	\N	0.83	00:33:00	\N	0.92	\N	\N	Old Plantation Light	VA
96444	Cape Charles Harbor (USCG wharf), Chesapeake Bay, Virginia (sub)	NOS	8632366	37.2633	-76.02	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	01:03:00	\N	0.92	00:45:00	\N	0.9	\N	\N	Cape Charles Harbor	VA
96445	Harborton, Pungoteague Creek, Chesapeake Bay, Virginia	NOS	8633091	37.6667	-75.8333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	03:33:00	\N	0.83	03:11:00	\N	0.7	\N	\N	Harborton, Pungoteague Creek	VA
96446	Onancock, Onancock Creek, Chesapeake Bay, Virginia	NOS	8633214	37.7117	-75.7567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	04:19:00	\N	0.83	03:55:00	\N	0.71	\N	\N	Onancock, Onancock Creek	VA
96447	Chesconessex Creek, Schooner Bay, Chesapeake Bay, Virginia	NOS	8633362	37.7633	-75.7733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	03:59:00	\N	1.25	03:41:00	\N	0.78	\N	\N	Chesconessex Creek, Schooner Bay	VA
96448	Watts Island, Chesapeake Bay, Virginia	NOS	8633451	37.7983	-75.8967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	04:12:00	\N	0.83	04:02:00	\N	0.64	\N	\N	Watts Island	VA
96449	Guard Shore, Chesapeake Bay, Virginia	NOS	8633596	37.85	-75.7	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	04:47:00	\N	0.83	04:06:00	\N	0.9	\N	\N	Guard Shore	VA
96450	Muddy Creek entrance, Chesapeake Bay, Virginia	NOS	8633604	37.855	-75.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	04:51:00	\N	0.83	04:14:00	\N	0.86	\N	\N	Muddy Creek Entrance	VA
96451	Alexandria, Potomac River, Virginia	NOS	8634214	38.805	-77.0383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-00:11:00	\N	1.33	00:18:00	\N	0.96	\N	\N	Alexandria, Va.	VA
96452	Quantico, Potomac River, Virginia	NOS	8634689	38.52	-77.2867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-02:04:00	\N	0.67	-00:52:00	\N	0.51	\N	\N	Quantico, Va.	VA
96453	Aquia Creek, Potomac River, Virginia	NOS	8634858	38.4183	-77.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-02:32:00	\N	0.67	-01:28:00	\N	0.48	\N	\N	Aquia Creek, Va.	VA
96454	Mathias Point, Potomac River, Virginia	NOS	8634892	38.3983	-77.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-04:56:00	\N	0.67	-04:00:00	\N	0.44	\N	\N	Mathias Point, Va.	VA
96455	Massaponax Sand & Gravel, Rappahannock River, Virginia	NOS	8635154	38.255	-77.41	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-00:41:00	\N	1.33	-00:39:00	\N	0.88	\N	\N	Massaponax	VA
96456	Hopyard Landing, Rappahannock River, Virginia	NOS	8635171	38.2433	-77.2267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-01:57:00	\N	0.67	-01:07:00	\N	0.75	\N	\N	Hopyard Landing	VA
96457	Port Royal, Rappahannock River, Virginia	NOS	8635299	38.1733	-77.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-03:02:00	\N	0.67	-02:19:00	\N	0.68	\N	\N	Port Royal	VA
96458	Mount Holly, Nomini Creek, Potomac River, Virginia	NOS	8635409	38.0983	-76.735	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-06:14:00	\N	0.67	-04:51:00	\N	0.54	\N	\N	Mount Holly, Nomini Creek, Va.	VA
96459	Ragged Point, Coles Neck, Potomac River, Virginia	NOS	8635485	38.1417	-76.6133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-07:03:00	\N	0.67	-05:35:00	\N	0.54	\N	\N	Ragged Point, Coles Neck, Va.	VA
96460	Saunders Wharf, Rappahannock River, Virginia	NOS	8635554	38.09	-77.0333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-04:41:00	\N	0.66	-03:53:00	\N	0.54	\N	\N	Saunders Wharf	VA
96461	Kinsale, Yeocomico River, Virginia	NOS	8635671	38.0317	-76.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-06:53:00	\N	0.67	-05:46:00	\N	0.44	\N	\N	Kinsale, Yeocomico River, Va.	VA
96462	Travis Point, Coan River, Potomac River, Virginia	NOS	8635762	37.9967	-76.4667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-07:05:00	\N	0.67	-06:00:00	\N	0.44	\N	\N	Travis Point, Coan River, Va.	VA
96463	Tappahannock, Rappahannock River, Virginia	NOS	8635881	37.93	-76.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	05:18:00	\N	0.83	04:40:00	\N	0.71	\N	\N	Tappahannock	VA
96464	Sunnybank, Little Wicomico River, Chesapeake Bay, Virginia	NOS	8635959	37.8867	-76.2667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	06:45:00	\N	0.3	06:41:00	\N	0.3	\N	\N	Sunnybank, Little Wicomico River	VA
96465	Glebe Point, Great Wicomico River, Chesapeake Bay, Virginia	NOS	8636046	37.8467	-76.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	04:37:00	\N	0.83	04:15:00	\N	0.49	\N	\N	Glebe Point, Great Wicomico River	VA
96466	Fleeton Point, Chesapeake Bay, Virginia	NOS	8636128	37.8133	-76.275	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	04:14:00	\N	0.41	03:58:00	\N	0.41	\N	\N	Fleeton Point	VA
96467	Great Wicomico River Light, Chesapeake Bay, Virginia	NOS	8636142	37.805	-76.2683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	04:11:00	\N	0.41	03:58:00	\N	0.41	\N	\N	Great Wicomico River Light	VA
96468	Bayport, Rappahannock River, Virginia	NOS	8636261	37.755	-76.6733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	03:51:00	\N	0.83	03:22:00	\N	0.67	\N	\N	Bayport	VA
96469	Millenbeck, Corrotoman River, Rappahannock River, Virginia	NOS	8636458	37.6683	-76.4867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	03:05:00	\N	0.83	02:37:00	\N	0.55	\N	\N	Millenbeck, Corrotoman River	VA
96470	Wakema (Fraziers Ferry), Mattaponi River, Virginia	NOS	8636499	37.65	-76.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	03:57:00	\N	1.67	03:34:00	\N	1.41	\N	\N	Wakema (Fraziers Ferry), Mattaponi River	VA
96471	Urbanna, Rappahannock River, Virginia	NOS	8636522	37.65	-76.575	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	03:09:00	\N	0.83	02:50:00	\N	0.59	\N	\N	Urbanna	VA
96472	Northbury, Pamunkey River, Virginia	NOS	8636558	37.625	-77.1217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	06:18:00	\N	1.67	06:03:00	\N	1.37	\N	\N	Northbury	VA
96473	Windmill Point Light, Chesapeake Bay, Virginia	NOS	8636623	37.5967	-76.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	03:12:00	\N	0.41	02:48:00	\N	0.41	\N	\N	Windmill Point Light	VA
96474	Mill Creek (Grey Point), Rappahannock River, Virginia	NOS	8636654	37.5833	-76.4183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	02:42:00	\N	0.83	02:28:00	\N	0.55	\N	\N	Mill Creek (Grey Point)	VA
96475	Jackson Creek, Deltaville, Piankatank River, Virginia	NOS	8636735	37.5483	-76.3317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	02:04:00	\N	0.83	01:36:00	\N	0.51	\N	\N	Jackson Creek, Deltaville	VA
96476	West Point, York River, Virginia	NOS	8636769	37.535	-76.7933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	02:38:00	\N	0.83	02:12:00	\N	1.14	\N	\N	West Point	VA
96477	Dixie, Piankatank River, Virginia	NOS	8636831	37.5067	-76.4167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	02:14:00	\N	0.83	01:34:00	\N	0.55	\N	\N	Dixie	VA
96478	Roane Point, York River, Virginia	NOS	8636969	37.4467	-76.7083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	01:50:00	\N	0.83	01:47:00	\N	1.14	\N	\N	Roane Point	VA
96479	Belleville, Mobjack Bay, Virginia	NOS	8637072	37.4117	-76.4383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	00:00:00	\N	0.83	-00:06:00	\N	1.02	\N	\N	Belleville	VA
96480	Wolf Trap Light, Chesapeake Bay, Virginia	NOS	8637144	37.39	-76.19	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	00:32:00	\N	0.83	-00:02:00	\N	0.67	\N	\N	Wolf Trap Light	VA
96481	Mobjack, East River, Mobjack Bay, Virginia	NOS	8637199	37.3733	-76.3467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	00:02:00	\N	0.83	-00:17:00	\N	0.98	\N	\N	Mobjack, East River	VA
96482	Browns Bay, Mobjack Bay, Virginia	NOS	8637444	37.3	-76.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	-00:03:00	\N	1.58	-00:11:00	\N	0.98	\N	\N	Browns Bay	VA
96483	Cheatham Annex, York River, Virginia	NOS	8637472	37.2917	-76.5867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	00:40:00	\N	0.83	00:48:00	\N	1.02	\N	\N	Cheatham Annex	VA
96484	Tue Marshes Light, York River, Virginia	NOS	8637663	37.235	-76.385	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	00:03:00	\N	0.83	00:03:00	\N	0.9	\N	\N	Tue Marshes Light	VA
96485	Goodwin Neck, Yorktown, York River, Virginia	NOS	8637686	37.23	-76.4367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	00:15:00	\N	0.83	00:18:00	\N	0.9	\N	\N	Yorktown, Goodwin Neck	VA
96486	Messick Point, Back River, Chesapeake Bay, Virginia	NOS	8638051	37.1083	-76.3183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	00:02:00	\N	0.97	-00:07:00	\N	0.97	\N	\N	Messick Point, Back River	VA
96487	Old Point Comfort, Hampton Roads, Virginia	NOS	8638288	37.0033	-76.315	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	00:09:00	\N	0.83	00:01:00	\N	1.02	\N	\N	Old Point Comfort	VA
96488	Newport News, James River, Virginia	NOS	8638379	36.9733	-76.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	00:28:00	\N	0.83	00:29:00	\N	1.08	\N	\N	Newport News	VA
96489	Huntington Park, James River, Virginia	NOS	8638401	37.0133	-76.4583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	00:39:00	\N	0.92	00:38:00	\N	1.07	\N	\N	Huntington Park	VA
96490	Town Point, Nansemond River, Virginia	NOS	8638406	36.8833	-76.5083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	00:44:00	\N	0.83	00:37:00	\N	1.22	\N	\N	Town Point	VA
96491	Menchville, James River, Virginia	NOS	8638407	37.0817	-76.525	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	01:19:00	\N	0.83	01:03:00	\N	1.06	\N	\N	Menchville	VA
96492	Hollidays Point (Kings Highway bridge), Nansemond River, Virginia	NOS	8638409	36.8383	-76.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	01:03:00	\N	1.67	00:56:00	\N	1.25	\N	\N	Hollidays Point (Kings Highway bridge)	VA
96493	Smithfield, Pagan River, James River, Virginia	NOS	8638418	36.9833	-76.63	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	01:38:00	\N	0.83	01:34:00	\N	1.14	\N	\N	Smithfield, Pagan River	VA
96494	Burwell Bay, James River, Virginia (sub)	NOS	8638421	37.0567	-76.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	01:39:00	\N	1.17	01:17:00	\N	1	\N	\N	Burwell Bay	VA
96495	Wright Island Landing, Chickahominy River, Virginia	NOS	8638441	37.345	-76.875	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	05:03:00	\N	0.83	04:44:00	\N	0.9	\N	\N	Wright Island Landing	VA
96496	Ferry Point (bridge), Chickahominy River, Virginia	NOS	8638442	37.2633	-76.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	04:26:00	\N	0.83	04:01:00	\N	0.78	\N	\N	Ferry Point (bridge)	VA
96497	Claremont, James River, Virginia	NOS	8638449	37.2317	-76.9483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	04:25:00	\N	1.17	03:51:00	\N	0.76	\N	\N	Claremont	VA
96498	Sturgeon Point, James River, Virginia	NOS	8638455	37.3067	-77.0067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	05:09:00	\N	0.83	04:37:00	\N	0.86	\N	\N	Sturgeon Point	VA
96499	Jordan Point, James River, Virginia	NOS	8638476	37.3133	-77.2233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	06:39:00	\N	0.83	06:16:00	\N	1.02	\N	\N	Jordan Point	VA
96500	Haxall, James River, Virginia	NOS	8638478	37.3733	-77.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-04:53:00	\N	1.33	-04:10:00	\N	0.99	\N	\N	Haxall	VA
96501	Meadowville, James River, Virginia	NOS	8638486	37.3783	-77.3233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-04:17:00	\N	1.33	-03:46:00	\N	1.05	\N	\N	Meadowville	VA
96502	Chester, James River, Virginia	NOS	8638491	37.3833	-77.3783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94932	-03:59:00	\N	0.67	-03:39:00	\N	1.02	\N	\N	Chester	VA
96503	Pig Point, Nansemond River, Virginia	NOS	8638514	36.9167	-76.435	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	00:40:00	\N	0.83	00:42:00	\N	1.05	\N	\N	Pig Point	VA
96504	Craney Island Light, Elizabeth River, Virginia	NOS	8638596	36.8917	-76.3383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	00:04:00	\N	0.83	00:18:00	\N	1.06	\N	\N	Craney Island Light	VA
96505	Norfolk, Elizabeth River, Virginia	NOS	8638654	36.8517	-76.2983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	00:20:00	\N	0.83	00:23:00	\N	1.14	\N	\N	Norfolk	VA
96506	Little Creek NAB, Chesapeake Bay, Virginia	NOS	8638776	36.9117	-76.175	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	00:09:00	\N	1.17	00:08:00	\N	1.01	\N	\N	Little Creek, NAB	VA
96507	Buchanan Creek entrance, Lynnhaven Bay, Virginia	NOS	8638854	36.8617	-76.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	02:56:00	\N	0.83	02:02:00	\N	0.75	\N	\N	Buchanan Creek entrance	VA
96508	Bayville, Lynnhaven Bay, Virginia	NOS	8638867	36.8933	-76.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	02:48:00	\N	0.83	01:52:00	\N	0.67	\N	\N	Bayville	VA
96509	Virginia pilot's dock, Lynnhaven Inlet, Chesapeake Bay, Virginia	NOS	8638888	36.9067	-76.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	00:38:00	\N	1.08	00:40:00	\N	0.88	\N	\N	Lynnhaven Inlet, Virginia Pilots Dock	VA
96510	Long Creek, Lynnhaven Bay, Virginia	NOS	8638916	36.9033	-76.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	01:15:00	\N	1.08	01:15:00	\N	0.68	\N	\N	Long Creek	VA
96511	Brown Cove, Lynnhaven Bay, Virginia	NOS	8638922	36.875	-76.0617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	02:43:00	\N	0.83	02:05:00	\N	0.65	\N	\N	Brown Cove	VA
96512	Broad Bay Canal, Lynnhaven Bay, Virginia	NOS	8638923	36.9017	-76.0617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	02:00:00	\N	0.92	02:05:00	\N	0.56	\N	\N	Broad Bay Canal	VA
96513	Cape Henry, Virginia	NOS	8638999	36.93	-76.00669444444445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94975	00:36:00	\N	0.93	00:31:00	\N	0.96	\N	\N	Cape Henry	VA
96514	Virginia Beach, Virginia	NOS	8639168	36.8433	-75.9717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94975	00:16:00	\N	1.07	00:15:00	\N	1.07	\N	\N	Virginia Beach	VA
96515	Rudee Inlet entrance, Virginia	NOS	8639208	36.8317	-75.9683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94975	00:02:00	\N	0.86	00:02:00	\N	1.01	\N	\N	Rudee Inlet entrance	VA
96516	Rudee Heights, Lake Wesley, Virginia	NOS	8639214	36.825	-75.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94975	00:16:00	\N	1	00:18:00	\N	1.03	\N	\N	Rudee Heights, Lake Wesley	VA
96517	Lake Rudee, south end, Virginia	NOS	8639219	36.825	-75.9817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94975	00:19:00	\N	1.07	00:20:00	\N	1.05	\N	\N	Lake Rudee, south end	VA
96518	Deep Creek entrance, Elizabeth River, Virginia	NOS	8639414	36.755	-76.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94968	00:18:00	\N	1.25	00:22:00	\N	1.21	\N	\N	Deep Creek Entrance	VA
96519	Sandbridge, Virginia	NOS	8639428	36.6917	-75.92	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94975	00:07:00	\N	1.04	00:07:00	\N	1.04	\N	\N	Sandbridge	VA
96520	Kitty Hawk (ocean), North Carolina	NOS	8651605	36.1017	-75.71	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94975	00:02:00	\N	1.43	-00:01:00	\N	1.01	\N	\N	Kitty Hawk (ocean)	NC
96521	Jennettes Pier, Nags Head (ocean), North Carolina	NOS	8652226	35.91	-75.5917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94975	00:01:00	\N	1.43	-00:05:00	\N	1.04	\N	\N	Jennettes Pier, Nags Head (ocean)	NC
96522	Roanoke Sound Channel, North Carolina	NOS	8652591	35.7983	-75.5833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94979	01:17:00	\N	0.14	01:37:00	\N	0.47	\N	\N	Roanoke Sound Channel	NC
96523	Oregon Inlet Channel, Pamlico Sound, North Carolina	NOS	8652657	35.7733	-75.5583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94979	-00:34:00	\N	0.43	-00:09:00	\N	1.23	\N	\N	Oregon Inlet Channel	NC
96524	Oregon Inlet Bridge, North Carolina	NOS	8652659	35.7733	-75.5383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94979	-00:55:00	\N	0.64	-00:17:00	\N	1.89	\N	\N	Oregon Inlet Bridge	NC
96525	Davis Slough, Pamlico Sound, North Carolina	NOS	8652737	35.7483	-75.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94979	-00:01:00	\N	0.29	00:09:00	\N	0.85	\N	\N	Davis Slough	NC
96526	Rodanthe, Pamlico Sound, North Carolina (sub)	NOS	8653215	35.595	-75.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94979	01:36:00	\N	0.69	02:03:00	\N	0.79	\N	\N	Rodanthe, Pamlico Sound	NC
96527	North River Bridge, North Carolina	NOS	8656225	34.7917	-76.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	03:08:00	\N	0.67	02:25:00	\N	0.59	\N	\N	North River Bridge	NC
96528	Newport River (Yacht Club), North Carolina	NOS	8656306	34.7683	-76.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	01:13:00	\N	1	01:03:00	\N	1.03	\N	\N	Newport River (Yacht Club)	NC
96529	Gallants Channel, North Carolina	NOS	8656451	34.7283	-76.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	00:44:00	\N	1.25	00:49:00	\N	1.01	\N	\N	Gallant Channel	NC
96530	Morehead City, North Carolina	NOS	8656496	34.7183	-76.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	00:27:00	\N	1.25	00:26:00	\N	1.04	\N	\N	Morehead City	NC
96531	Atlantic Beach Bridge, North Carolina	NOS	8656499	34.7183	-76.7367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	01:02:00	\N	0.83	00:48:00	\N	0.79	\N	\N	Atlantic Beach Bridge	NC
96532	Morehead City Harbor, North Carolina	NOS	8656502	34.72	-76.71083333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	00:37:00	\N	1.17	00:35:00	\N	1.04	\N	\N	Morehead City Harbor	NC
96533	Harkers Island Bridge, North Carolina	NOS	8656503	34.715	-76.5783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	02:31:00	\N	0.67	02:08:00	\N	0.52	\N	\N	Harkers Island Bridge	NC
96534	Beaufort, Taylor Creek, North Carolina	NOS	8656518	34.7117	-76.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	00:48:00	\N	1.17	00:52:00	\N	0.95	\N	\N	Beaufort, Taylor Creek	NC
96535	Lenoxville Point, North Carolina	NOS	8656539	34.7083	-76.62	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	01:11:00	\N	1	01:18:00	\N	0.8	\N	\N	Lenoxville Point	NC
96536	Channel Marker Lt. 59, North Carolina	NOS	8656554	34.7033	-76.62	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	01:27:00	\N	0.83	01:25:00	\N	0.66	\N	\N	Channel Marker Lt. 59	NC
96537	Coral Bay, Atlantic Beach, North Carolina	NOS	8656566	34.7	-76.7683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	02:14:00	\N	0.83	01:47:00	\N	0.53	\N	\N	Coral Bay, Atlantic Beach	NC
96538	Beaufort Inlet Channel Range, North Carolina	NOS	8656569	34.6983	-76.665	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	00:11:00	\N	1.67	00:07:00	\N	1.07	\N	\N	Beaufort Inlet Channel Range	NC
96539	Fort Macon, USCG station, North Carolina	NOS	8656571	34.6983	-76.6817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	00:18:00	\N	1.25	00:17:00	\N	1.03	\N	\N	Fort Macon, USCG Station	NC
96540	Cape Lookout (ocean), North Carolina	NOS	8656937	34.6083	-76.5283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	-00:22:00	\N	1.25	-00:22:00	\N	1.15	\N	\N	Cape Lookout (ocean)	NC
96541	New River Inlet, North Carolina	NOS	8657167	34.5333	-77.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	00:17:00	\N	0.83	00:16:00	\N	0.98	\N	\N	New River Inlet	NC
96542	Ocean City Beach (fishing pier), North Carolina	NOS	8657419	34.4517	-77.495	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	-00:01:00	\N	1.33	00:03:00	\N	1.4	\N	\N	Ocean City Beach (fishing pier)	NC
96543	Orton Point, Cape Fear River, North Carolina	NOS	8658501	34.0567	-77.94	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95001	-00:58:00	\N	1	-00:36:00	\N	0.98	\N	\N	Orton Point	NC
96544	Wilmington Beach, North Carolina	NOS	8658559	34.0317	-77.8933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	00:10:00	\N	1.25	00:18:00	\N	1.4	\N	\N	Wilmington Beach	NC
96545	Reaves Point, Cape Fear River, North Carolina	NOS	8658622	34.0033	-77.955	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95001	-01:18:00	\N	1.07	-00:54:00	\N	0.96	\N	\N	Reaves Point	NC
96546	Sunny Point Army Base, Wharf No. 1, Cape Fear River, North Carolina	NOS	8658654	33.99	-77.9567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95001	-01:45:00	\N	0.93	-01:03:00	\N	0.95	\N	\N	Sunny Point Army Base, Wharf no.1	NC
96547	Federal Point, Cape Fear River, North Carolina	NOS	8658715	33.9617	-77.94	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95001	-01:52:00	\N	0.93	-01:17:00	\N	0.94	\N	\N	Federal Point	NC
96548	Bald Head, Cape Fear River, North Carolina	NOS	8658901	33.88	-78.0017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95001	-02:43:00	\N	1.13	-02:06:00	\N	1.05	\N	\N	Bald Head	NC
96549	Fort Caswell, Cape Fear River, North Carolina	NOS	8659086	33.8967	-78.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95001	-02:45:00	\N	1.25	-02:02:00	\N	1.03	\N	\N	Fort Caswell	NC
96550	Sunset Beach Bridge, North Carolina	NOS	8659899	33.88166666666701	-78.51	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95012	00:56:00	\N	0.84	00:34:00	\N	0.94	\N	\N	Sunset Beach Bridge	NC
96551	Little River Neck, north end, South Carolina	NOS	8660098	33.87	-78.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95012	00:46:00	\N	0.84	00:32:00	\N	0.92	\N	\N	Little River Neck, north end	SC
96552	Little River (town), South Carolina	NOS	8660121	33.87	-78.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:39:00	\N	0.79	00:13:00	\N	0.84	\N	\N	Little River (town)	SC
96553	Dunn Sound, north end, South Carolina	NOS	8660147	33.86	-78.58	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95012	00:40:00	\N	0.84	00:25:00	\N	0.93	\N	\N	Dunn Sound, north end	SC
96554	Dunn Sound, Little River Inlet, South Carolina	NOS	8660148	33.8583	-78.57	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95012	00:41:00	\N	0.8	00:15:00	\N	0.91	\N	\N	Dunn Sound, Little River Inlet	SC
96555	Nixon Crossroads, South Carolina	NOS	8660166	33.855	-78.6483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:51:00	\N	0.68	00:27:00	\N	0.78	\N	\N	Nixon Crossroads	SC
96556	Dunn Sound, west end, South Carolina	NOS	8660195	33.8517	-78.5883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95012	00:36:00	\N	1	00:29:00	\N	0.96	\N	\N	Dunn Sound, west end	SC
96557	Cherry Grove (inside), South Carolina	NOS	8660265	33.835	-78.6333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95012	00:44:00	\N	0.74	00:40:00	\N	0.92	\N	\N	Cherry Grove (inside)	SC
96558	Hog Inlet Pier, South Carolina	NOS	8660266	33.8367	-78.6067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95012	-00:07:00	\N	0.9	-00:06:00	\N	0.99	\N	\N	Hog Inlet Pier	SC
96559	Conway, RR. bridge, Waccamaw River, South Carolina	NOS	8660275	33.835	-79.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	07:28:00	\N	0.74	07:19:00	\N	0.25	\N	\N	Conway, RR. bridge	SC
96560	Grahamville, Waccamaw River, South Carolina	NOS	8660315	33.83	-78.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	08:32:00	\N	0.58	08:17:00	\N	0.2	\N	\N	Grahamville	SC
96561	Myrtle Beach Airport, South Carolina	NOS	8660401	33.82	-78.7183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	01:47:00	\N	0.84	01:09:00	\N	0.56	\N	\N	Myrtle Beach Airport	SC
96562	Pitch Landing, Waccamaw River, South Carolina	NOS	8660475	33.8	-79.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	07:30:00	\N	0.74	07:25:00	\N	0.2	\N	\N	Pitch Landing	SC
96563	North Myrtle Beach, South Carolina	NOS	8660642	33.766700744628906	-78.81500244140625	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	03:12:00	\N	0.84	02:15:00	\N	0.36	\N	\N	North Myrtle Beach, ICWW	SC
96564	Keysfield, Waccamaw River, South Carolina	NOS	8660831	33.745	-79.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	06:20:00	\N	0.89	06:09:00	\N	0.28	\N	\N	Keysfield	SC
96565	Myrtle Beach, Combination Bridge, South Carolina	NOS	8660854	33.7133	-78.9217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	04:18:00	\N	0.89	02:56:00	\N	0.35	\N	\N	Myrtle Beach, Combination Bridge	SC
96566	Socastee Bridge, South Carolina	NOS	8660983	33.6867	-79.005	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	04:41:00	\N	0.74	03:27:00	\N	0.41	\N	\N	Socastee Bridge	SC
96567	Enterprise Landing, Waccamaw River, South Carolina	NOS	8661067	33.6667	-79.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	05:35:00	\N	0.37	05:01:00	\N	0.38	\N	\N	Enterprise Landing	SC
96568	Yauhannah Bridge, Great Pee Dee River, South Carolina	NOS	8661093	33.66	-79.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	05:24:00	\N	0.68	04:33:00	\N	0.33	\N	\N	Yauhannah Bridge	SC
96569	Little Bull Creek entrance, Bull Creek, Waccamaw River, South Carolina	NOS	8661119	33.6017	-79.1183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	04:43:00	\N	0.84	03:59:00	\N	0.46	\N	\N	Little Bull Creek entrance, Bull Creek	SC
96570	Lower Topsaw Landing, Great Pee Dee River, South Carolina	NOS	8661299	33.6083	-79.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	05:20:00	\N	0.53	04:48:00	\N	0.2	\N	\N	Lower Topsaw Landing	SC
96571	Bull Creek entrance, Waccamaw River, South Carolina	NOS	8661347	33.5967	-79.0983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	04:22:00	\N	0.79	03:36:00	\N	0.48	\N	\N	Bull Creek entrance	SC
96572	Rhems, Black Mingo Creek, Black River, Great Pee Dee River, South Carolina	NOS	8661367	33.6033	-79.4267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	06:13:00	\N	1.05	06:00:00	\N	0.36	\N	\N	Rhems, Black Mingo Creek, Black River	SC
96573	Captain Alex's Marina, Parsonage Creek, Murrells Inlet, South Carolina	NOS	8661529	33.5517	-79.0367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95012	01:28:00	\N	0.68	00:57:00	\N	0.85	\N	\N	Captain Alex's Marina, Parsonage Creek	SC
96574	Holly Grove Plantation, Great Pee Dee River, South Carolina	NOS	8661558	33.5517	-79.1767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	04:12:00	\N	0.68	03:20:00	\N	0.5	\N	\N	Holly Grove Plantation	SC
96575	Smith's Dock, Murrells Inlet, South Carolina	NOS	8661559	33.545	-79.045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95012	01:36:00	\N	0.95	01:01:00	\N	0.86	\N	\N	Smith's Dock	SC
96576	Divine's Dock, Murrells Inlet, South Carolina	NOS	8661582	33.5417	-79.0283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95012	01:18:00	\N	0.84	00:40:00	\N	0.84	\N	\N	Divine's Dock	SC
96577	Winea Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8661593	33.535	-79.3883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	04:39:00	\N	0.84	04:23:00	\N	0.47	\N	\N	Winea Plantation, Black River	SC
96578	Allston Creek, Murrells Inlet, South Carolina	NOS	8661608	33.5317	-79.0533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95012	01:32:00	\N	0.95	00:52:00	\N	0.84	\N	\N	Allston Creek	SC
96579	Oaks Creek, 0.5 mi above entrance, Murrells Inlet, South Carolina	NOS	8661609	33.53	-79.0433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95012	01:03:00	\N	0.95	00:38:00	\N	0.85	\N	\N	Oaks Creek, 0.5 mi. above entrance	SC
96580	Black River (south of Dunbar), Great Pee Dee River, South Carolina	NOS	8661686	33.5117	-79.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	04:09:00	\N	0.89	03:29:00	\N	0.47	\N	\N	Black River (south of Dunbar)	SC
96581	Mt. Pleasant Plantation, Black River, Great Pee Dee River, South Carolina	NOS	8661734	33.495	-79.4617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	06:04:00	\N	1.05	05:38:00	\N	0.37	\N	\N	Mt. Pleasant Plantation, Black River	SC
96582	Arundel Plantation, Great Pee Dee River, South Carolina	NOS	8661741	33.4833	-79.1783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	03:39:00	\N	0.79	02:38:00	\N	0.53	\N	\N	Arundel Plantation	SC
96583	South of Sam Worth Game Management Area, Great Pee Dee River, South Carolina	NOS	8661866	33.4683	-79.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	03:06:00	\N	0.68	02:21:00	\N	0.69	\N	\N	South of Sam Worth Game Management Area	SC
96584	Litchfield Beach bridge, South Carolina	NOS	8661867	33.4717	-79.1017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95012	03:02:00	\N	0.75	01:10:00	\N	0.58	\N	\N	Litchfield Beach bridge	SC
96585	Carr Creek, 1 mi above entrance, Great Pee Dee River, South Carolina	NOS	8661873	33.465	-79.1867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	03:00:00	\N	0.84	02:13:00	\N	0.69	\N	\N	Carr Creek, 1 mile above entrance	SC
96586	Weymouth Plantation, Great Pee Dee River, South Carolina	NOS	8661913	33.455	-79.205	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	03:02:00	\N	0.89	02:16:00	\N	0.68	\N	\N	Weymouth Plantation	SC
96587	Midway Inlet North, Pawleys Island, South Carolina	NOS	8661947	33.4483	-79.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95012	00:42:00	\N	1	00:16:00	\N	0.87	\N	\N	Midway Inlet North, Pawleys Island	SC
96588	Hagley Landing, Waccamaw River, South Carolina	NOS	8661991	33.435	-79.1817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	02:53:00	\N	0.79	01:58:00	\N	0.67	\N	\N	Hagley Landing	SC
96589	Cumberland, Sampit River, South Carolina	NOS	8662216	33.37	-79.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	02:29:00	\N	0.74	02:42:00	\N	0.77	\N	\N	Cumberland	SC
96590	Jacobs Wharf, Sampit River, South Carolina	NOS	8662237	33.3633	-79.355	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	02:22:00	\N	0.74	02:15:00	\N	0.73	\N	\N	Jacobs Wharf	SC
96591	Jamestown Bridge, Santee River, South Carolina	NOS	8662405	33.305	-79.6783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	06:30:00	\N	0.37	04:15:00	\N	0.22	\N	\N	Jamestown Bridge, Santee River	SC
96592	South Island Ferry, ICWW, South Carolina	NOS	8662549	33.2517	-79.2683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	01:25:00	\N	0.74	00:54:00	\N	0.71	\N	\N	South Island Ferry, Intracoastal Waterway	SC
96593	Pleasant Hill Landing, Santee River, South Carolina	NOS	8662670	33.245	-79.5217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	03:47:00	\N	0.74	02:28:00	\N	0.45	\N	\N	Pleasant Hill Landing, Santee River	SC
96594	South Island Plantation (USCG station), Winyah Bay, South Carolina (sub)	NOS	8662746	33.235	-79.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:36:00	\N	0.84	00:35:00	\N	0.74	\N	\N	South Island Plantation (C.G. Station)	SC
96595	Georgetown Lighthouse, South Carolina	NOS	8662747	33.2233	-79.185	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:25:00	\N	1.05	00:26:00	\N	0.75	\N	\N	Georgetown Lighthouse	SC
96596	North Santee Bridge, South Carolina	NOS	8662793	33.21	-79.385	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	01:54:00	\N	0.74	01:09:00	\N	0.72	\N	\N	North Santee Bridge	SC
96597	Minim Creek ent., ICWW, North Santee Bay, South Carolina	NOS	8662796	33.195	-79.275	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	01:00:00	\N	0.95	00:16:00	\N	0.77	\N	\N	Minim Creek ent., ICWW, North Santee Bay	SC
96598	US Highway 17 bridge, South Santee River, South Carolina	NOS	8662799	33.185	-79.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	01:43:00	\N	0.95	00:43:00	\N	0.78	\N	\N	U.S. Highway 17 bridge, South Santee River	SC
96599	Cape Romain, South Carolina	NOS	8663101	33.025	-79.3483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:17:00	\N	0.89	-00:22:00	\N	0.89	\N	\N	Cape Romain	SC
96600	Cedar Island, North Santee Bay, South Carolina	NOS	8663261	33.14	-79.245	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:17:00	\N	0.95	-00:03:00	\N	0.8	\N	\N	Cedar Island, North Santee Bay	SC
96601	Cedar Island Point, South Santee River, South Carolina	NOS	8663381	33.12	-79.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:08:00	\N	0.79	-00:16:00	\N	0.78	\N	\N	Cedar Island Point, South Santee River	SC
96602	Casino Creek, ICWW, South Carolina	NOS	8663461	33.1083	-79.3933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:53:00	\N	0.79	00:40:00	\N	0.87	\N	\N	Casino Creek, ICWW	SC
96603	Quinby Creek bridge, East Branch, Cooper River, South Carolina	NOS	8663535	33.095	-79.8083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	04:12:00	\N	1.42	04:37:00	\N	0.56	\N	\N	Quinby Creek bridge, East Branch	SC
96604	Pimlico, West Branch, Cooper River, South Carolina	NOS	8663539	33.095	-79.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	03:53:00	\N	0.89	03:19:00	\N	0.34	\N	\N	Pimlico, West Branch	SC
96605	McClellanville, Jeremy Creek, Bulls Bay, South Carolina	NOS	8663618	33.0783	-79.46	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:24:00	\N	0.89	00:31:00	\N	0.93	\N	\N	McClellanville, Jeremy Creek	SC
96606	Old Rice Mill, West Branch, Cooper River, South Carolina	NOS	8663631	33.0783	-79.925	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	02:51:00	\N	1.63	02:56:00	\N	0.53	\N	\N	Old Rice Mill, West Branch	SC
96607	Richmond Plantation, East Branch, Cooper River, South Carolina	NOS	8663665	33.0767	-79.855	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	03:43:00	\N	1.37	03:43:00	\N	0.54	\N	\N	Richmond Plantation, East Branch	SC
96608	Bonneau Ferry, East Branch, Cooper River, South Carolina	NOS	8663731	33.0717	-79.8833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	02:49:00	\N	1.79	03:14:00	\N	0.63	\N	\N	Bonneau Ferry, East Branch	SC
96609	Dupont, Dean Hall, Cooper River, South Carolina	NOS	8663757	33.0583	-79.9367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	02:07:00	\N	1.58	02:21:00	\N	0.68	\N	\N	Dupont, Dean Hall	SC
96610	Blessing Plantation, East Branch, Cooper River, South Carolina	NOS	8663781	33.055	-79.88	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	03:20:00	\N	1.32	03:24:00	\N	0.56	\N	\N	Blessing Plantation, East Branch	SC
96611	Harbor River entrance, Bulls Bay, South Carolina	NOS	8663899	33.0333	-79.535	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:36:00	\N	0.95	00:03:00	\N	0.93	\N	\N	Harbor River entrance	SC
96612	Five Fathom Creek entrance, Bulls Bay, South Carolina	NOS	8664099	33	-79.4967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:07:00	\N	0.95	-00:06:00	\N	0.93	\N	\N	Five Fathom Creek entrance	SC
96613	Back River Reservoir, West Branch, Cooper River, South Carolina	NOS	8664131	32.995	-79.9367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	05:57:00	\N	0.79	05:44:00	\N	0.17	\N	\N	Back River Reservoir, West Branch	SC
96614	Moores Landing, ICWW, Sewee Bay, South Carolina	NOS	8664442	32.9367	-79.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:08:00	\N	1	00:11:00	\N	0.96	\N	\N	Moores Landing, ICWW, Sewee Bay	SC
96615	Snow Point, 0.4 mi north of, Cooper River, South Carolina	NOS	8664515	32.9483	-79.9317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:45:00	\N	1.05	00:59:00	\N	1.02	\N	\N	Snow Point, 0.4 mi. North of	SC
96616	Bacon Bridge, Ashley River, South Carolina	NOS	8664531	32.9583	-80.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	03:41:00	\N	0.16	02:45:00	\N	0.39	\N	\N	Bacon Bridge	SC
96617	Greggs Landing, Matceba Gardens, Ashley River, South Carolina	NOS	8664532	32.9317	-80.1567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	01:42:00	\N	1.16	02:06:00	\N	1.15	\N	\N	Greggs Landing, Mateeba Gardens	SC
96618	Yeamans Hall, Goose Creek, Cooper River, South Carolina	NOS	8664541	32.925	-79.9867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	01:31:00	\N	1.37	02:06:00	\N	1	\N	\N	Yeamans Hall, Goose Creek	SC
96619	Woodville, Wando River, South Carolina	NOS	8664582	32.92	-79.7333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	01:22:00	\N	1.19	02:07:00	\N	1.19	\N	\N	Woodville	SC
96620	Hanahan, Turkey Creek, Goose Creek, Cooper River, South Carolina	NOS	8664589	32.9183	-80.0117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	02:13:00	\N	0.79	02:51:00	\N	0.9	\N	\N	Hanahan, Turkey Creek, Goose Creek	SC
96621	Big Paradise Island, Wando River, South Carolina	NOS	8664611	32.915	-79.7467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:52:00	\N	1.11	01:24:00	\N	1.24	\N	\N	Big Paradise Island	SC
96622	Wharf Creek entrance, Bulls Bay, South Carolina	NOS	8664621	32.9133	-79.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:08:00	\N	0.95	00:12:00	\N	0.97	\N	\N	Wharf Creek entrance	SC
96623	Clouter Creek, north entrance, Cooper River, South Carolina	NOS	8664688	32.9067	-79.935	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:33:00	\N	1	00:45:00	\N	1.04	\N	\N	Clouter Creek, north entrance	SC
96624	Nowell Creek, Wando River, South Carolina	NOS	8664701	32.9	-79.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:23:00	\N	1.05	00:47:00	\N	1.13	\N	\N	Nowell Creek	SC
96625	Parker Island, Horlbeck Creek, Wando River, South Carolina	NOS	8664782	32.885	-79.845	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:27:00	\N	1.11	00:43:00	\N	1.09	\N	\N	Parker Island, Horlbeck Creek	SC
96626	Price Creek, North Capers Island, South Carolina	NOS	8664801	32.8817	-79.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:21:00	\N	0.89	-00:01:00	\N	0.92	\N	\N	Price Creek, North Capers Island	SC
96627	Magnolia Gardens, Ashley River, South Carolina	NOS	8664841	32.8767	-80.0833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:54:00	\N	1.05	01:02:00	\N	1.1	\N	\N	Magnolia Gardens	SC
96628	Old Capers Landing, Santee Pass, Capers Island, South Carolina	NOS	8664878	32.87	-79.6867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:09:00	\N	0.84	00:21:00	\N	0.94	\N	\N	Old Capers Landing, Santee Pass, Capers Island	SC
96629	Clouter Creek, south entrance, Cooper River, South Carolina	NOS	8664945	32.86	-79.9383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:19:00	\N	1	00:25:00	\N	1.02	\N	\N	Clouter Creek, south entrance	SC
96630	North Dewees Island, Capers Inlet, South Carolina	NOS	8664992	32.85	-79.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:11:00	\N	0.95	-00:02:00	\N	0.91	\N	\N	North Dewees Island, Capers Inlet	SC
96631	Drayton, Bee's Ferry, Ashley River, South Carolina	NOS	8665002	32.8483	-80.0517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:39:00	\N	1.05	00:41:00	\N	1.09	\N	\N	Drayton, Bee's Ferry	SC
96632	Cosgrove Bridge, Ashley River, South Carolina	NOS	8665101	32.835	-79.9867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:17:00	\N	1.05	00:25:00	\N	1.07	\N	\N	Cosgrove Bridge	SC
96633	South Dewees Island, Dewees Inlet, South Carolina	NOS	8665111	32.8333	-79.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:17:00	\N	0.89	-00:01:00	\N	0.94	\N	\N	South Dewees Island, Dewees Inlet	SC
96634	Duck Island, Ashley River, South Carolina	NOS	8665145	32.83	-79.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:17:00	\N	1.06	00:23:00	\N	1.06	\N	\N	Duck Island	SC
96635	Hamlin Sound, South Carolina	NOS	8665167	32.8267	-79.7867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:13:00	\N	1	00:13:00	\N	0.99	\N	\N	Hamlin Sound	SC
96636	Hobcaw Point, Wando River, South Carolina	NOS	8665192	32.8217	-79.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:13:00	\N	0.95	00:19:00	\N	1.03	\N	\N	Hobcaw Point	SC
96637	Canaday Landing, south of, Edisto River, South Edisto River, South Carolina	NOS	8665257	32.8133	-80.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	05:34:00	\N	0.32	04:20:00	\N	0.13	\N	\N	Canaday Landing, south of, Edisto River	SC
96638	Hamlin Creek, Isle of Palms, South Carolina	NOS	8665387	32.7867	-79.7917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:12:00	\N	1	00:06:00	\N	0.97	\N	\N	Hamlin Creek, Isle of Palms	SC
96639	Folly Creek, Hwy. 171 bridge, South Carolina	NOS	8665424	32.675	-79.9517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:06:00	\N	1	00:25:00	\N	1.04	\N	\N	Folly Creek, Hwy. 171 bridge	SC
96640	Shem Creek, South Carolina	NOS	8665426	32.7933	-79.8817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:03:00	\N	1	-00:02:00	\N	0.99	\N	\N	Shem Creek	SC
96641	Limehouse Bridge, Stono River, South Carolina	NOS	8665475	32.7867	-80.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	01:34:00	\N	1.08	01:43:00	\N	1.08	\N	\N	Limehouse Bridge	SC
96642	Isle of Palms Pier, South Carolina	NOS	8665494	32.7833	-79.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:28:00	\N	0.89	-00:25:00	\N	0.95	\N	\N	Isle of Palms Pier	SC
96643	South Ashley Bridge, Ashley River, South Carolina	NOS	8665495	32.7833	-79.9567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:07:00	\N	1.05	00:04:00	\N	1.01	\N	\N	South Ashley Bridge	SC
96644	Breach Inlet, Isle of Palms, South Carolina	NOS	8665552	32.7767	-79.8117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:14:00	\N	1.05	-00:05:00	\N	0.95	\N	\N	Breach Inlet, Isle of Palms	SC
96645	Ben Sawyer Bridge, ICWW, South Carolina	NOS	8665567	32.7733	-79.8417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:12:00	\N	1	00:06:00	\N	0.97	\N	\N	Ben Sawyer Bridge, ICWW	SC
96646	Sandblasters, Pennys Creek, Stono River, South Carolina	NOS	8665589	32.77	-80.0633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	01:18:00	\N	1.02	01:30:00	\N	1.02	\N	\N	Sandblasters, Pennys Creek	SC
96647	Pennys Creek, west entrance, Stono River, South Carolina	NOS	8665599	32.7683	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	01:20:00	\N	1.32	01:23:00	\N	1.03	\N	\N	Pennys Creek, west entrance	SC
96648	Wappoo Creek, highway bridge, Ashley River, South Carolina	NOS	8665613	32.7667	-79.9733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:22:00	\N	0.99	00:22:00	\N	0.99	\N	\N	Wappoo Creek, highway bridge	SC
96649	The Cove, Fort Moultrie, South Carolina	NOS	8665637	32.7633	-79.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:10:00	\N	0.95	-00:01:00	\N	0.97	\N	\N	The Cove, Fort Moultrie	SC
96650	Elliott Cut entrance, Stono River, South Carolina	NOS	8665641	32.7633	-80.0017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:52:00	\N	1.16	00:48:00	\N	0.99	\N	\N	Elliott Cut entrance	SC
96651	Fort Johnson, South Carolina	NOS	8665726	32.7517	-79.8983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:02:00	\N	1	-00:05:00	\N	0.97	\N	\N	Fort Johnson	SC
96652	Fort Sumter, South Carolina	NOS	8665728	32.7533	-79.8767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:01:00	\N	0.95	00:02:00	\N	0.97	\N	\N	Fort Sumter	SC
96653	Jacksonboro Camp, South Edisto River, South Carolina	NOS	8665737	32.7533	-80.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	03:34:00	\N	0.86	02:46:00	\N	0.59	\N	\N	Jacksonboro Camp	SC
96654	James Island Creek, 1 mi above ent., Ashley River, South Carolina	NOS	8665775	32.745	-79.9483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:07:00	\N	1.05	00:17:00	\N	1.02	\N	\N	James Island Creek, 1 mi. above ent.	SC
96655	Ashepoo, Ashepoo River, South Carolina	NOS	8665814	32.7433	-80.5567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	04:00:00	\N	1.05	04:18:00	\N	0.34	\N	\N	Ashepoo	SC
96656	Penny Creek, south of, Edisto River, South Edisto River, South Carolina	NOS	8666017	32.715	-80.4367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	02:43:00	\N	1.18	02:10:00	\N	0.73	\N	\N	Penny Creek, south of, Edisto River	SC
96657	Church Creek bridge, Wadmalaw River, South Carolina	NOS	8666029	32.715	-80.0917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:58:00	\N	1	01:58:00	\N	1.3	\N	\N	Church Creek bridge	SC
96658	Johns Island, Church Creek, Wadmalaw River, South Carolina	NOS	8666101	32.7067	-80.1567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	01:00:00	\N	1.16	01:43:00	\N	1.3	\N	\N	Johns Island, Church Creek	SC
96659	Lower Toogoodoo Creek, 2 mi above entrance, North Edisto River, South Carolina	NOS	8666131	32.7033	-80.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:47:00	\N	1.26	01:26:00	\N	1.29	\N	\N	Lower Toogoodoo Creek, 2 mi. above entrance	SC
96660	Cuckolds Creek, Combahee River, South Carolina	NOS	8666166	32.7133	-80.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	04:12:00	\N	1.73	04:45:00	\N	0.51	\N	\N	Cuckolds Creek	SC
96661	Hope Creek, Edisto River, South Edisto River, South Carolina	NOS	8666167	32.7	-80.4267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	02:13:00	\N	1.05	01:46:00	\N	0.82	\N	\N	Hope Creek, Edisto River	SC
96662	Yonges Island, Wadmalaw River, South Carolina	NOS	8666217	32.695	-80.2233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:45:00	\N	1.16	01:22:00	\N	1.24	\N	\N	Yonges Island	SC
96663	Oak Branch, Bohicket Creek, North Edisto River, South Carolina	NOS	8666282	32.6833	-80.0967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:57:00	\N	1.16	01:39:00	\N	1.26	\N	\N	Oak Branch, Bohicket Creek	SC
96664	Abbapoola Creek entrance, Stono River, South Carolina	NOS	8666283	32.6767	-80.0067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:02:00	\N	0.95	00:17:00	\N	1.01	\N	\N	Abbapoola Creek entrance	SC
96665	Bluff Plantation, Combahee River, South Carolina	NOS	8666359	32.6833	-80.7383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	03:51:00	\N	1.59	04:17:00	\N	0.5	\N	\N	Bluff Plantation	SC
96666	Willtown Bluff, Edisto River, South Edisto River, South Carolina	NOS	8666367	32.6817	-80.4167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	02:03:00	\N	1	01:34:00	\N	0.83	\N	\N	Willtown Bluff, Edisto River	SC
96667	Toogoodoo Creek, 2 mi above entrance, North Edisto River, South Carolina	NOS	8666433	32.6683	-80.2933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:38:00	\N	1.05	01:06:00	\N	1.21	\N	\N	Toogoodoo Creek, 2 mi. above entrance	SC
96668	Folly River, north, Folly Island, South Carolina	NOS	8666467	32.67	-79.9167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:05:00	\N	0.95	00:24:00	\N	1.03	\N	\N	Folly River, north, Folly Island	SC
96669	Park Island, Tom Point Creek, North Edisto River, South Carolina	NOS	8666552	32.665	-80.3167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:34:00	\N	1.21	01:19:00	\N	1.21	\N	\N	Park Island, Tom Point Creek	SC
96670	Dawho River, South Edisto River, South Carolina	NOS	8666616	32.6567	-80.3917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:31:00	\N	0.95	01:07:00	\N	0.89	\N	\N	Dawho River	SC
96671	Folly River Bridge, Folly Island, South Carolina	NOS	8666652	32.6617	-79.945	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:03:00	\N	0.95	00:21:00	\N	1.01	\N	\N	Folly River Bridge, Folly Island	SC
96672	US 17 Bridge, Combahee River, South Carolina	NOS	8666659	32.6517	-80.6833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	02:29:00	\N	1.14	03:00:00	\N	0.71	\N	\N	U.S. 17 Bridge	SC
96673	Bluff Point, Wadmalaw River, South Carolina	NOS	8666699	32.6467	-80.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:31:00	\N	1.11	00:58:00	\N	1.17	\N	\N	Bluff Point	SC
96674	Airy Hall Plantation, Ashepoo River, South Carolina	NOS	8666749	32.6317	-80.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:59:00	\N	1	01:57:00	\N	0.6	\N	\N	Airy Hall Plantation	SC
96675	Snake Island, Stono River, South Carolina	NOS	8666767	32.64	-80.015	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:12:00	\N	1	00:01:00	\N	1.01	\N	\N	Snake Island	SC
96676	Leadenwah Creek, 3 mi above entrance, North Edisto River, South Carolina	NOS	8666775	32.6367	-80.2017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:23:00	\N	1.11	00:54:00	\N	1.15	\N	\N	Leadenwah Creek, 3 mi. above entrance	SC
96677	Dawho Bridge, Dawho River, North Edisto River, South Carolina	NOS	8666799	32.6367	-80.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:47:00	\N	1.11	00:56:00	\N	1.18	\N	\N	Dawho Bridge, Dawho River	SC
96678	Ho-Non-Wah Boy Scout Camp, Bohicket Creek, North Edisto River, South Carolina	NOS	8666918	32.625	-80.1667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:30:00	\N	1.11	00:49:00	\N	1.13	\N	\N	Ho-Non-Wah Boy Scout Camp, Bohicket Creek	SC
96679	Brickyard Ferry, swing bridge, Ashepoo River, South Carolina	NOS	8667017	32.6133	-80.4817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:34:00	\N	0.86	01:27:00	\N	0.71	\N	\N	Brickyard Ferry, swing bridge	SC
96680	Kiawah River Bridge, South Carolina	NOS	8667062	32.6033	-80.1317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:06:00	\N	0.89	00:14:00	\N	1.07	\N	\N	Kiawah River Bridge	SC
96681	Pine Landing, South Edisto River, South Carolina	NOS	8667067	32.6033	-80.3883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:45:00	\N	0.95	00:29:00	\N	0.92	\N	\N	Pine Landing	SC
96682	Wiggins, Chehaw River, Combahee River, South Carolina	NOS	8667074	32.6017	-80.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:20:00	\N	1.18	01:45:00	\N	0.88	\N	\N	Wiggins, Chehaw River	SC
96683	Steamboat Landing, Steamboat Creek, North Edisto River, South Carolina	NOS	8667075	32.6033	-80.2867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:25:00	\N	1.11	00:45:00	\N	1.15	\N	\N	Steamboat Landing, Steamboat Creek	SC
96684	Tulifiny River, I-95 bridge, Broad River, South Carolina	NOS	8667076	32.6017	-80.9033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	03:31:00	\N	0.73	03:24:00	\N	0.73	\N	\N	Tulifiny River, I-95 bridge	SC
96685	Rockville, Bohicket Creek, North Edisto River, South Carolina	NOS	8667089	32.5983	-80.195	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:07:00	\N	1.11	00:19:00	\N	1.09	\N	\N	Rockville, Bohicket Creek	SC
96686	Windsor Plantation, Russel Creek, North Edisto River, South Carolina	NOS	8667101	32.5983	-80.345	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:35:00	\N	1.11	01:16:00	\N	1.21	\N	\N	Windsor Plantation, Russel Creek	SC
96687	North Dawson Landing, Coosawhatchie River, Broad River, South Carolina	NOS	8667146	32.5617	-80.91	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	02:10:00	\N	1.14	02:34:00	\N	1.12	\N	\N	North Dawson Landing, Coosawhatchie River	SC
96688	Sheldon, Huspa Creek, Whale Branch, Coosaw River, South Carolina	NOS	8667172	32.5833	-80.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:52:00	\N	0.77	02:11:00	\N	1.16	\N	\N	Sheldon, Huspa Creek, Whale Branch	SC
96689	Point of Pines, North Edisto River, South Carolina	NOS	8667178	32.585	-80.2283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:11:00	\N	1.05	00:15:00	\N	1.08	\N	\N	Point of Pines	SC
96690	Briars Creek ent., Wimbee Creek, Bull River, Coosaw River, South Carolina	NOS	8667199	32.5783	-80.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:24:00	\N	0.95	02:06:00	\N	0.93	\N	\N	Briars Creek ent., Wimbee Creek, Bull River	SC
96691	Bluff Islands, Ashepoo River, South Carolina	NOS	8667201	32.5783	-80.4933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:04:00	\N	0.91	00:46:00	\N	0.84	\N	\N	Bluff Islands	SC
96692	Musselboro Island, Mosquito Creek, Ashepoo River, South Carolina	NOS	8667209	32.5783	-80.4483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:57:00	\N	0.91	01:21:00	\N	0.9	\N	\N	Musselboro Island, Mosquito Creek	SC
96693	Fields Point, Combahee River, South Carolina	NOS	8667259	32.5683	-80.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:52:00	\N	0.91	00:42:00	\N	0.91	\N	\N	Fields Point	SC
96694	Bowles Island, New Chehaw River, Combahee River, South Carolina	NOS	8667272	32.565	-80.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:42:00	\N	1	01:02:00	\N	0.96	\N	\N	Bowles Island, New Chehaw River	SC
96695	Ocella Creek, 2 mi above entrance, North Edisto River, South Carolina	NOS	8667281	32.5617	-80.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:09:00	\N	1.08	00:32:00	\N	1.08	\N	\N	Ocella Creek, 2 mi. above entrance	SC
96696	Fenwick Island, South Edisto River, South Carolina	NOS	8667309	32.56	-80.4183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:25:00	\N	1.09	00:15:00	\N	0.9	\N	\N	Fenwick Island	SC
96697	Hutchinson Island, Ashepoo River, South Carolina	NOS	8667351	32.5517	-80.4817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:44:00	\N	0.91	00:31:00	\N	0.87	\N	\N	Hutchinson Island	SC
96698	Lobeco, Whale Branch, Coosaw River, South Carolina	NOS	8667411	32.5733	-80.745	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:28:00	\N	0.95	01:40:00	\N	1.11	\N	\N	Lobeco, Whale Branch	SC
96699	Peters Point, St. Pierre Creek, South Edisto River, South Carolina	NOS	8667425	32.54	-80.34	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:09:00	\N	0.95	00:22:00	\N	0.88	\N	\N	Peters Point, St. Pierre Creek	SC
96700	Ashepoo-Coosaw Cutoff, ICWW, Ashepoo River, South Carolina	NOS	8667482	32.525	-80.4517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:23:00	\N	0.91	00:15:00	\N	0.9	\N	\N	Ashepoo-Coosaw Cutoff, ICWW	SC
96701	Whale Branch entrance, Coosaw River, South Carolina	NOS	8667491	32.525	-80.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:20:00	\N	0.95	01:27:00	\N	1.06	\N	\N	Whale Branch entrance	SC
96702	Summerhouse Point, Bull River, Coosaw River, South Carolina	NOS	8667493	32.5267	-80.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:37:00	\N	0.95	00:55:00	\N	0.96	\N	\N	Summerhouse Point, Bull River	SC
96703	RR. Bridge, Hall Island, Broad River, South Carolina	NOS	8667508	32.5217	-80.8383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:24:00	\N	1.05	01:39:00	\N	1.17	\N	\N	RR. Bridge, Hall Island	SC
96704	Seabrook, Ashepoo River, South Carolina	NOS	8667524	32.5233	-80.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:18:00	\N	0.91	00:11:00	\N	0.9	\N	\N	Seabrook	SC
96705	Pilot Island, West Branch Boyds Creek, Broad River, South Carolina	NOS	8667591	32.505	-80.8633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:24:00	\N	0.91	01:50:00	\N	1.15	\N	\N	Pilot Island, West Branch Boyds Creek	SC
96706	Brickyard Point, Brickyard Creek, Coosaw River, South Carolina	NOS	8667624	32.4933	-80.685	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:19:00	\N	0.95	01:27:00	\N	1.08	\N	\N	Brickyard Point, Brickyard Creek	SC
96707	Edisto Beach, Edisto Island, South Carolina	NOS	8667630	32.5017	-80.2967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	-00:29:00	\N	0.95	-00:21:00	\N	0.84	\N	\N	Edisto Beach, Edisto Island	SC
96708	Edisto Marina, Big Bay Creek entrance, South Edisto River, South Carolina	NOS	8667676	32.4933	-80.34	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	-00:13:00	\N	0.91	-00:06:00	\N	0.86	\N	\N	Edisto Marina, Big Bay Creek entrance	SC
96709	Carters Dock, Big Bay Creek, South Edisto River, South Carolina	NOS	8667679	32.4933	-80.3267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	-00:07:00	\N	0.91	00:08:00	\N	0.87	\N	\N	Carters Dock, Big Bay Creek	SC
96710	Sams Point, Lucy Point Creek, Coosaw River, South Carolina	NOS	8667733	32.4833	-80.6	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:45:00	\N	0.91	00:55:00	\N	0.97	\N	\N	Sams Point, Lucy Point Creek	SC
96711	Otter Island, St. Helena Sound, South Carolina	NOS	8667783	32.4767	-80.42	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:07:00	\N	0.95	00:04:00	\N	0.87	\N	\N	Otter Island	SC
96712	Marine Corps Air Station, Brickyard Creek, Beaufort River, South Carolina	NOS	8667864	32.465	-80.6917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:11:00	\N	0.95	01:27:00	\N	1.1	\N	\N	Marine Corps Air Station, Brickyard Creek	SC
96713	Lucy Point Creek entrance, Morgan River, South Carolina	NOS	8667901	32.4517	-80.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:33:00	\N	0.88	00:53:00	\N	0.9	\N	\N	Lucy Point Creek entrance	SC
96714	Albergottie Creek, Rt. 21 bridge, Beaufort River, South Carolina	NOS	8667909	32.45	-80.7317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	02:02:00	\N	0.45	01:48:00	\N	0.98	\N	\N	Albergottie Creek, Rt. 21 bridge	SC
96715	Village Creek entrance, Morgan River, South Carolina	NOS	8667927	32.445	-80.5033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:07:00	\N	1	00:17:00	\N	0.93	\N	\N	Village Creek Entrance	SC
96716	Edding Point, Edding Creek, Morgan River, South Carolina	NOS	8667972	32.4467	-80.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:14:00	\N	0.95	00:31:00	\N	0.93	\N	\N	Edding Point, Edding Creek	SC
96717	Jenkins Creek, 1 mi above entrance, Morgan River, South Carolina	NOS	8667982	32.44	-80.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:17:00	\N	0.95	00:41:00	\N	0.98	\N	\N	Jenkins Creek, 1 mi. above entrance	SC
96718	Village Creek Cemetery, Morgan River, South Carolina	NOS	8668077	32.4167	-80.52	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:15:00	\N	0.95	00:36:00	\N	0.94	\N	\N	Village Creek Cemetery	SC
96719	Jenkins Creek, Polawana Island, Morgan River, South Carolina	NOS	8668091	32.42	-80.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:27:00	\N	1.05	00:55:00	\N	1.01	\N	\N	Jenkins Creek, Polawana Island	SC
96720	Battery Creek, 4 mi above entrance, Beaufort River, South Carolina	NOS	8668092	32.4133	-80.7	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:37:00	\N	0.91	01:14:00	\N	1.1	\N	\N	Battery Creek, 4 mi. above entrance	SC
96721	Broughton Point, Hazzard Creek, Broad River, South Carolina	NOS	8668109	32.41	-80.885	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:30:00	\N	0.82	01:34:00	\N	1.1	\N	\N	Broughton Point, Hazzard Creek	SC
96722	Harbor River Bridge, St. Helena Sound, South Carolina	NOS	8668146	32.4033	-80.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	-00:06:00	\N	0.95	00:03:00	\N	0.88	\N	\N	Harbor River Bridge	SC
96723	Distant Island Creek, upper end, Cowen Creek, Beaufort River, South Carolina	NOS	8668155	32.4017	-80.6533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:08:00	\N	0.36	01:00:00	\N	0.98	\N	\N	Distant Island Creek, upper end, Cowen Creek	SC
96724	Cowen Creek, Rt. 21 bridge, Beaufort River, South Carolina	NOS	8668173	32.3983	-80.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:58:00	\N	0.55	00:55:00	\N	1	\N	\N	Cowen Creek, Rt. 21 bridge	SC
96725	Hwy. 170 bridge, Broad River, South Carolina	NOS	8668223	32.3867	-80.7767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:45:00	\N	0.91	00:51:00	\N	1.06	\N	\N	Hwy. 170 bridge	SC
96726	Johnson Creek Bridge, Hunting Island, St. Helena Sound, South Carolina	NOS	8668227	32.3917	-80.4383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:03:00	\N	0.86	00:03:00	\N	0.85	\N	\N	Johnson Creek Bridge, Hunting Island	SC
96727	Capers Creek, Cowen Creek, St. Helena Island, Beaufort River, South Carolina	NOS	8668255	32.3717	-80.605	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:34:00	\N	0.95	00:58:00	\N	1.08	\N	\N	Capers Creek, Cowen Creek, St. Helena Island	SC
96728	Distant Island, Cowen Creek, Beaufort River, South Carolina	NOS	8668282	32.3783	-80.6333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:27:00	\N	1.05	00:43:00	\N	1.06	\N	\N	Distant Island, Cowen Creek	SC
96729	Chechessee Bluff, Chechessee River, South Carolina	NOS	8668301	32.3733	-80.8367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:48:00	\N	1	01:06:00	\N	1.1	\N	\N	Chechessee Bluff, Chechessee River	SC
96730	Parris Island, Marine Corps Recruit Depot, Beaufort River, South Carolina	NOS	8668445	32.35	-80.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:26:00	\N	0.91	00:37:00	\N	1.02	\N	\N	Parris Island, Marine Corps Recruit Depot	SC
96731	Baileys Landing, Okatee River, Colleton River, South Carolina	NOS	8668482	32.3467	-80.89	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:57:00	\N	1.05	01:25:00	\N	1.17	\N	\N	Baileys Landing, Okatee River, Colleton River	SC
96732	Callawassie Island Bridge, Colleton River, South Carolina	NOS	8668511	32.3417	-80.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:49:00	\N	1.14	01:12:00	\N	1.13	\N	\N	Callawassie Island Bridge, Colleton River	SC
96733	Club Bridge Creek ent., Trenchards Inlet, South Carolina	NOS	8668529	32.335	-80.5417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	-00:24:00	\N	1	00:15:00	\N	0.99	\N	\N	Club Bridge Creek ent., Trenchards Inlet	SC
96734	Station Creek, County Landing, South Carolina	NOS	8668601	32.325	-80.6017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	-00:16:00	\N	1	00:27:00	\N	0.99	\N	\N	Station Creek, County Landing	SC
96735	Colleton River entrance, South Carolina	NOS	8668619	32.3217	-80.7917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:37:00	\N	1.05	00:49:00	\N	1.05	\N	\N	Colleton River Entrance	SC
96736	Callawassie Creek, Colleton River, South Carolina	NOS	8668636	32.3167	-80.8417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:53:00	\N	1.14	01:15:00	\N	1.13	\N	\N	Callawassie Creek, Colleton River	SC
96737	Callawassie Island, south, Colleton River, South Carolina	NOS	8668655	32.3133	-80.86	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:40:00	\N	1.11	01:09:00	\N	1.19	\N	\N	Callawassie Island, south, Colleton River	SC
96738	Fort Fremont, Beaufort River, South Carolina	NOS	8668686	32.3067	-80.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:17:00	\N	0.64	00:19:00	\N	0.95	\N	\N	Fort Fremont	SC
96739	Purrysburg Landing, Savannah River, South Carolina	NOS	8668701	32.3033	-81.1217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	03:38:00	\N	0.41	02:14:00	\N	0.44	\N	\N	Purrysburg Landing, S.C.	SC
96740	Station Creek, west end, South Carolina	NOS	8668836	32.28	-80.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:13:00	\N	0.91	00:16:00	\N	0.96	\N	\N	Station Creek, west end	SC
96741	Capers Island, Trenchards Inlet, South Carolina	NOS	8668837	32.2733	-80.585	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	-00:18:00	\N	0.95	-00:01:00	\N	0.93	\N	\N	Capers Island, Trenchards Inlet	SC
96742	Pinckney Island, Mackay Creek, Chechessee River, South Carolina	NOS	8668944	32.26	-80.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:25:00	\N	0.91	00:36:00	\N	1.04	\N	\N	Pinckney Island, Mackay Creek, Chechessee River	SC
96743	Rt. 170 bridge, New River, South Carolina	NOS	8669072	32.2367	-81.0117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	03:53:00	\N	0.51	04:12:00	\N	0.51	\N	\N	Rt. 170 bridge	SC
96744	Bluffton, May River, South Carolina	NOS	8669103	32.23	-80.8617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:37:00	\N	1.05	01:00:00	\N	1.16	\N	\N	Bluffton	SC
96745	Skull Creek, south entrance, Hilton Head Island, South Carolina	NOS	8669133	32.2233	-80.7717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:23:00	\N	1.05	00:34:00	\N	1.05	\N	\N	Skull Creek, south entrance, Hilton Head Island	SC
96746	Port Royal Plantation, Hilton Head Island, South Carolina	NOS	8669167	32.22	-80.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	-00:11:00	\N	1	00:01:00	\N	0.88	\N	\N	Port Royal Plantation, Hilton Head Island	SC
96747	Bull Island North, May River, South Carolina	NOS	8669262	32.2	-80.815	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:25:00	\N	1.05	00:40:00	\N	1.09	\N	\N	Bull Island North	SC
96748	Cook Landing Cemetery, New River, South Carolina	NOS	8669277	32.195	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	03:00:00	\N	1.41	03:09:00	\N	0.69	\N	\N	Cook Landing Cemetery	SC
96749	Savage I., Savage Creek, Bull Creek, South Carolina	NOS	8669323	32.185	-80.86	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:19:00	\N	1	00:46:00	\N	1.1	\N	\N	Savage I., Savage Creek, Bull Creek	SC
96750	Broad Creek, Hilton Head Island, South Carolina	NOS	8669338	32.185	-80.7533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:17:00	\N	1.05	00:33:00	\N	1.08	\N	\N	Broad Creek, Hilton Head Island	SC
96751	Good Hope Landing, south of, New River, South Carolina	NOS	8669346	32.1767	-80.9667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	02:06:00	\N	1.55	02:19:00	\N	0.85	\N	\N	Good Hope Landing, south of	SC
96752	Moreland Cemetery, May River, South Carolina	NOS	8669369	32.175	-80.8917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:23:00	\N	0.77	00:49:00	\N	1.11	\N	\N	Moreland Cemetery	SC
96753	Bull Creek, Bull Island South, Cooper River, South Carolina	NOS	8669414	32.165	-80.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:12:00	\N	1.05	00:28:00	\N	1.05	\N	\N	Bull Creek, Bull Island South, Cooper River	SC
96754	Little Back River, Hwy. 17, Back River, Savannah River, Georgia	NOS	8669415	32.165	-81.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:41:00	\N	1.14	01:28:00	\N	1.1	\N	\N	Little Back River, Hwy. 17, Back River, S.C.	GA
96755	Calibogue Cay, Broad Creek, Hilton Head Island, South Carolina	NOS	8669464	32.1533	-80.795	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:09:00	\N	1	00:20:00	\N	1.04	\N	\N	Calibogue Cay, Broad Creek, Hilton Head Island	SC
96756	Haig Point, Daufuskie Island, Cooper River, South Carolina	NOS	8669493	32.1467	-80.8367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:10:00	\N	1	00:20:00	\N	1.02	\N	\N	Haig Point, Daufuskie Island, Cooper River	SC
96757	Doughboy Island, New River, South Carolina	NOS	8669531	32.1383	-80.9317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:06:00	\N	1.05	01:04:00	\N	1.01	\N	\N	Doughboy Island	SC
96758	Turnbridge Landing, Salt Water Creek, South Carolina	NOS	8669575	32.1283	-81.0117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:59:00	\N	1.09	01:41:00	\N	1.06	\N	\N	Turnbridge Landing, Salt Water Creek	SC
96759	Pine Island, Ramshorn Creek, Cooper River, South Carolina	NOS	8669601	32.1217	-80.8983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:28:00	\N	0.91	00:34:00	\N	1.03	\N	\N	Pine Island, Ramshorn Creek, Cooper River	SC
96760	Braddock Point, Hilton Head Island, South Carolina	NOS	8669625	32.1133	-80.83	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	-00:02:00	\N	1	00:05:00	\N	0.98	\N	\N	Braddock Point, Hilton Head Island	SC
96761	Daufuskie Landing, Daufuskie Island, New River, South Carolina	NOS	8669691	32.1033	-80.895	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:33:00	\N	0.95	00:30:00	\N	1.01	\N	\N	Daufuskie Landing, Daufuskie Island	SC
96762	Hargray Pier, Daufuskie Island, New River, South Carolina	NOS	8669722	32.0983	-80.8983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:27:00	\N	1.05	00:19:00	\N	1.01	\N	\N	Hargray Pier, Daufuskie Island	SC
96763	Bloody Point, Daufuskie Island, New River, South Carolina	NOS	8669801	32.0817	-80.8783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:19:00	\N	0.91	00:01:00	\N	0.98	\N	\N	Bloody Point, Daufuskie Island	SC
96764	Fields Cut, Wright River, South Carolina	NOS	8669815	32.0867	-80.9333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:29:00	\N	1.05	00:16:00	\N	1.02	\N	\N	Fields Cut, Wright River	SC
96765	S.C.L. RR. bridge, Savannah River, South Carolina	NOS	8670073	32.2317	-81.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	03:08:00	\N	0.91	01:51:00	\N	0.9	\N	\N	S.C.L. RR. bridge	SC
96766	Fort Jackson, Savannah River, Georgia	NOS	8670678	32.0817	-81.0367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:42:00	\N	1.09	00:29:00	\N	1.09	\N	\N	Fort Jackson	GA
96767	Savannah (Bull Street), Georgia (sub)	NOS	8670681	32.0817	-81.0917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:33:00	\N	1.14	00:44:00	\N	1.14	\N	\N	SAVANNAH	GA
96768	Tybee Light, Savannah River, Georgia	NOS	8670892	32.0283	-80.855	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	-00:12:00	\N	0.99	-00:10:00	\N	0.99	\N	\N	Tybee Light	GA
96769	Vernon View, Burnside River, Georgia	NOS	8671642	31.9267	-81.0983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:31:00	\N	1.09	00:40:00	\N	1.09	\N	\N	Vernon View, Burnside River	GA
96770	Florida Passage, Ogeechee River, Georgia	NOS	8672219	31.8533	-81.1467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:46:00	\N	0.91	00:34:00	\N	1.05	\N	\N	Florida Passage, Ogeechee River	GA
96771	Bradley Point, Bradley River, Georgia	NOS	8672455	31.8217	-81.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:13:00	\N	0.95	00:04:00	\N	1.02	\N	\N	Bradley Point, Bradley River	GA
96772	Belfast, Belfast River, Georgia	NOS	8672462	31.8217	-81.2983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:10:00	\N	1.14	01:23:00	\N	1.13	\N	\N	Belfast, Belfast River	GA
96773	Kilkenny Club, Kilkenny Creek, Georgia	NOS	8672696	31.7883	-81.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:37:00	\N	0.91	00:48:00	\N	1.09	\N	\N	Kilkenny Club, Kilkenny Creek	GA
96774	Halfmoon, Timmons River, Georgia	NOS	8673381	31.695	-81.2717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:09:00	\N	1.05	01:21:00	\N	1.06	\N	\N	Halfmoon, Timmons River	GA
96775	Walburg Creek entrance, Georgia	NOS	8673437	31.69	-81.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:21:00	\N	1	00:16:00	\N	1.03	\N	\N	Walburg Creek entrance	GA
96776	North Newport River (Daymark 119), Georgia	NOS	8673499	31.6817	-81.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:31:00	\N	1	00:35:00	\N	1.05	\N	\N	North Newport River (Daymark 119)	GA
96777	Thomas Landing, S. Newport River, Georgia	NOS	8673812	31.6433	-81.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:46:00	\N	0.95	00:57:00	\N	1.06	\N	\N	Thomas Landing, S. Newport River	GA
96778	Eagle Neck, South Newport River, Georgia	NOS	8673875	31.65	-81.305	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:06:00	\N	1	01:16:00	\N	1.09	\N	\N	Eagle Neck, South Newport River	GA
96779	Harris Neck, Barbour Island River, Georgia	NOS	8673962	31.6233	-81.2633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:32:00	\N	1	00:54:00	\N	1.08	\N	\N	Harris Neck, Barbour Island River	GA
96780	Barbour Island, Barbour Island River, Georgia	NOS	8674251	31.5783	-81.24	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:24:00	\N	1	00:36:00	\N	1.06	\N	\N	Barbour Island, Barbour Island River	GA
96781	Pine Harbor, Sapelo River, Georgia	NOS	8674512	31.5483	-81.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:04:00	\N	1.05	01:03:00	\N	1.05	\N	\N	Pine Harbor, Sapelo River	GA
96782	Dog Hammock, Sapelo River, Georgia	NOS	8674623	31.5317	-81.27	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:22:00	\N	0.91	00:33:00	\N	1.04	\N	\N	Dog Hammock, Sapelo River	GA
96783	Bellville Point, Sapelo River, Georgia	NOS	8674638	31.5317	-81.36	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:02:00	\N	0.86	01:12:00	\N	1.08	\N	\N	Bellville Point, Sapelo River	GA
96784	Eagle Creek, Mud River, Georgia	NOS	8674801	31.51	-81.2783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:19:00	\N	1.05	00:21:00	\N	1.05	\N	\N	Eagle Creek, Mud River	GA
96785	Creighton Narrows entrance, Crescent River, Georgia	NOS	8674875	31.4983	-81.325	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:37:00	\N	1.09	00:49:00	\N	1.08	\N	\N	Creighton Narrows Entrance, Crescent River	GA
96786	Blackbeard Creek, Blackbeard Island, Georgia	NOS	8674962	31.4883	-81.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:47:00	\N	0.95	00:19:00	\N	0.94	\N	\N	Blackbeard Creek, Blackbeard Island	GA
96787	Hudson Creek entrance, Georgia	NOS	8675245	31.4467	-81.3433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:31:00	\N	1.05	00:37:00	\N	1.05	\N	\N	Hudson Creek entrance	GA
96788	Old Tea Kettle Creek (Daymark 173), Georgia	NOS	8675365	31.4317	-81.3067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:39:00	\N	0.82	00:39:00	\N	0.96	\N	\N	Old Tea Kettle Creek (Daymark 173)	GA
96789	Old Tower, Sapelo Island, Georgia	NOS	8675622	31.39	-81.2883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:14:00	\N	0.95	00:15:00	\N	0.99	\N	\N	Old Tower, Sapelo Island	GA
96790	Darien, Darien River, Georgia	NOS	8675779	31.3683	-81.435	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:15:00	\N	1.05	01:08:00	\N	1.06	\N	\N	Darien, Darien River	GA
96791	Threemile Cut entrance, Darien River, Georgia	NOS	8675843	31.3567	-81.3767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:55:00	\N	1.05	00:44:00	\N	1.03	\N	\N	Threemile Cut entrance, Darien River	GA
96792	Champney Island, South Altamaha River, Georgia	NOS	8676012	31.3317	-81.46	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	02:33:00	\N	0.77	01:10:00	\N	0.76	\N	\N	Champney Island, South Altamaha River	GA
96793	Mackay River (ICWW), Buttermilk Sound, Georgia	NOS	8676329	31.285	-81.385	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:23:00	\N	1.09	00:58:00	\N	1	\N	\N	Mackay River (ICWW), Buttermilk Sound	GA
96794	Dillard Creek, Turtle River, Georgia	NOS	8676722	31.225	-81.5717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:02:00	\N	1.18	01:32:00	\N	1.16	\N	\N	Dillard Creek	GA
96795	Frederica River, Georgia	NOS	8676743	31.2217	-81.3933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:56:00	\N	1.05	00:48:00	\N	1.05	\N	\N	Frederica River	GA
96796	Mackay River (Daymark 239), Georgia	NOS	8676766	31.21	-81.425	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:56:00	\N	1.09	00:58:00	\N	1.03	\N	\N	Mackay River (Daymark 239)	GA
96797	Buffalo River entrance, Turtle River, Georgia	NOS	8676787	31.215	-81.5833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:58:00	\N	1.18	01:37:00	\N	1.16	\N	\N	Buffalo River entrance	GA
96798	Frederick River Bridge, Georgia	NOS	8677045	31.1683	-81.4133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:45:00	\N	1.09	00:43:00	\N	1	\N	\N	Frederick River Bridge	GA
96799	8 mi above mouth, Little Satilla River, Georgia	NOS	8677566	31.0983	-81.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	01:02:00	\N	1.2	00:24:00	\N	1.2	\N	\N	8 miles above mouth	GA
96800	Jointer Island, Jointer Creek, Georgia	NOS	8677576	31.095	-81.505	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:31:00	\N	1.18	00:11:00	\N	1.18	\N	\N	Jointer Island, Jointer Creek	GA
96801	Jekyll Island Marina, Jekyll Creek, Georgia	NOS	8677832	31.0567	-81.4233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:36:00	\N	1.16	00:03:00	\N	1.13	\N	\N	Jekyll Island Marina, Jekyll Creek	GA
96802	2.5 mi above mouth, Little Satilla River, Georgia	NOS	8677833	31.0583	-81.4933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:31:00	\N	1.12	-00:04:00	\N	1.12	\N	\N	2.5 miles above mouth	GA
96803	Dover Bluff, Dover Creek, Georgia	NOS	8678111	31.0167	-81.5283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:31:00	\N	1.15	00:06:00	\N	1.15	\N	\N	Dover Bluff, Dover Creek	GA
96804	Todd Creek entrance, Satilla River, Georgia	NOS	8678412	30.9717	-81.52	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:41:00	\N	1.1	-00:08:00	\N	1.1	\N	\N	Todd Creek entrance	GA
96805	Ceylon, Satilla River, Georgia	NOS	8678466	30.9633	-81.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	01:35:00	\N	1.09	00:34:00	\N	1.09	\N	\N	Ceylon	GA
96806	Floyd Creek, 2.8 mi above entrance, Georgia	NOS	8678642	30.9367	-81.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:21:00	\N	1.17	00:08:00	\N	1.17	\N	\N	Floyd Creek, 2.8 miles above entrance	GA
96807	Cumberland Wharf, Cumberland River, Georgia	NOS	8678688	30.93	-81.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:26:00	\N	1.12	00:00:00	\N	1.12	\N	\N	Cumberland Wharf, Cumberland River	GA
96808	Harrietts Bluff, Crooked River, Georgia	NOS	8679083	30.87	-81.585	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	01:56:00	\N	1.05	01:29:00	\N	1.05	\N	\N	Harrietts Bluff, Crooked River	GA
96809	Crooked River, Cumberland Dividings, Georgia	NOS	8679242	30.8433	-81.4867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:56:00	\N	1.12	00:44:00	\N	1.12	\N	\N	Crooked River, Cumberland Dividings	GA
96810	Beach Creek ent., Cumberland Island, Georgia	NOS	8679945	30.7267	-81.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	-00:04:00	\N	0.95	00:00:00	\N	0.98	\N	\N	Beach Creek ent., Cumberland Island	GA
96811	St. Marys entrance, north jetty, Georgia	NOS	8679997	30.72	-81.445	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	-00:03:00	\N	0.96	-00:36:00	\N	0.96	\N	\N	St. Marys Entrance, North Jetty	GA
96812	Kings Ferry, St. Marys River, Florida	NOS	8720001	30.7867	-81.84	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	04:09:00	\N	1.16	04:05:00	\N	0.49	\N	\N	Kings Ferry	FL
96813	Little St. Marys River, St. Marys River, Florida	NOS	8720006	30.7317	-81.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	02:36:00	\N	0.79	02:49:00	\N	0.71	\N	\N	Little St. Marys River	FL
96814	Roses Bluff, Bells River, Florida	NOS	8720007	30.7033	-81.5767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:35:00	\N	0.95	00:35:00	\N	1.03	\N	\N	Roses Bluff, Bells River	FL
96815	Kingsley Creek, RR. bridge, Florida	NOS	8720058	30.6317	-81.4767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:25:00	\N	1	00:27:00	\N	0.99	\N	\N	Kingsley Creek, RR. bridge	FL
96816	Boggy Creek, 2 mi above entrance, Nassau River, Florida	NOS	8720084	30.5883	-81.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	03:50:00	\N	0.89	03:29:00	\N	0.49	\N	\N	Boggy Creek, 2 mi. above entrance	FL
96817	Amelia City, South Amelia River, Florida	NOS	8720086	30.5867	-81.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:42:00	\N	0.89	00:21:00	\N	0.89	\N	\N	Amelia City, South Amelia River	FL
96818	Halfmoon Island, highway bridge, Nassau River, Florida	NOS	8720093	30.5767	-81.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	02:39:00	\N	1.05	02:00:00	\N	0.7	\N	\N	Halfmoon Island, highway bridge	FL
96819	Cuno, Lofton Creek, Nassau River, Florida	NOS	8720097	30.5767	-81.5717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	02:48:00	\N	1.05	02:14:00	\N	0.6	\N	\N	Cuno, Lofton Creek	FL
97501	View Cove, Tlevak Strait, Alaska	NOS	9450283	55.0833	-133.017	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:02:00	0	\N	-00:02:00	2.8	\N	\N	\N	View Cove	AK
96820	Mink Creek entrance, Nassau River, Florida	NOS	8720119	30.5367	-81.5817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	02:05:00	\N	1.05	01:13:00	\N	0.72	\N	\N	Mink Creek entrance	FL
96821	Nassau River entrance, Florida	NOS	8720135	30.5183	-81.4533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:41:00	\N	1	-00:18:00	\N	0.86	\N	\N	entrance	FL
96822	Sawpit Creek entrance, bridge, Florida	NOS	8720137	30.5133	-81.4567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:21:00	\N	1	-00:14:00	\N	0.84	\N	\N	Sawpit Creek entrance, bridge	FL
96823	Sawpit Creek, 1 mi above entrance, Florida	NOS	8720143	30.5033	-81.4717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:31:00	\N	0.74	00:05:00	\N	0.84	\N	\N	Sawpit Creek, 1 mi. above entrance	FL
96824	Tiger Point, Pumpkin Hill Creek, Nassau River, Florida	NOS	8720148	30.5017	-81.495	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	01:46:00	\N	0.95	01:22:00	\N	0.82	\N	\N	Tiger Point, Pumpkin Hill Creek	FL
96825	Simpson Creek, A1A highway bridge, Florida	NOS	8720168	30.465	-81.4317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:17:00	\N	0.63	00:04:00	\N	0.84	\N	\N	Simpson Creek, A1A highway bridge	FL
96826	Fort George Island, Fort George River, Florida	NOS	8720186	30.44	-81.4383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:33:00	\N	0.74	00:10:00	\N	0.79	\N	\N	Fort George Island, Fort George River	FL
96827	Little Talbot Island, ocean, Florida	NOS	8720194	30.43	-81.405	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	-00:13:00	\N	1	-00:36:00	\N	0.91	\N	\N	Little Talbot Island, ocean	FL
96828	Blount Island Bridge, Florida	NOS	8720203	30.4133	-81.545	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95084	01:05:00	\N	0.73	00:42:00	\N	0.77	\N	\N	Blount Island Bridge	FL
96829	Jacksonville, Navy Fuel Depot, Florida	NOS	8720215	30.4	-81.6267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95084	01:48:00	\N	0.53	01:14:00	\N	0.56	\N	\N	Jacksonville, Navy Fuel Depot	FL
96830	Lake Forest, Ribault River, Trout River, Florida	NOS	8720216	30.3983	-81.6983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95084	02:10:00	\N	0.6	01:13:00	\N	0.58	\N	\N	Lake Forest, Ribault River	FL
96831	Moncrief Creek entrance, Trout River, Florida	NOS	8720217	30.3917	-81.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95084	01:53:00	\N	0.53	01:11:00	\N	0.55	\N	\N	Moncrief Creek entrance	FL
96832	Fulton, Florida	NOS	8720221	30.39	-81.5067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95084	00:40:00	\N	0.73	00:24:00	\N	0.8	\N	\N	Fulton	FL
96833	Pablo Creek entrance, Florida	NOS	8720232	30.3767	-81.4483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95084	00:33:00	\N	0.73	00:29:00	\N	0.85	\N	\N	Pablo Creek entrance	FL
96834	Atlantic Beach, Florida	NOS	8720259	30.335	-81.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	-00:23:00	\N	0.86	-00:41:00	\N	0.86	\N	\N	Atlantic Beach	FL
96835	Pablo Creek, ICWW bridge, Florida	NOS	8720267	30.3233	-81.4383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95084	01:20:00	\N	1	01:14:00	\N	0.84	\N	\N	Pablo Creek, ICWW bridge	FL
96836	Little Pottsburg Creek, Florida	NOS	8720274	30.31	-81.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95084	02:09:00	\N	0.53	01:31:00	\N	0.44	\N	\N	Little Pottsburg Creek	FL
96837	Ortega River entrance, Florida	NOS	8720296	30.2783	-81.705	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95084	02:47:00	\N	0.47	02:09:00	\N	0.25	\N	\N	Ortega River entrance	FL
96838	Oak Landing, ICWW, Florida	NOS	8720305	30.2533	-81.43	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	02:03:00	\N	0.8	02:15:00	\N	0.68	\N	\N	Oak Landing, ICWW	FL
96839	Piney Point, Florida	NOS	8720333	30.2283	-81.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95084	03:36:00	\N	0.4	02:39:00	\N	0.2	\N	\N	Piney Point	FL
96840	Orange Park Landing, Orange Park, Florida	NOS	8720374	30.16830062866211	-81.69499969482422	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95084	04:44:00	\N	0.2	03:24:00	\N	0.2	\N	\N	Orange Park Landing, Orange Park	FL
96841	Palm Valley, ICWW, Florida	NOS	8720398	30.1333	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	01:49:00	\N	0.75	02:00:00	\N	0.79	\N	\N	Palm Valley, ICWW	FL
96842	Julington Creek, Florida	NOS	8720409	30.135000228881836	-81.62999725341797	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95084	05:13:00	\N	0.2	03:58:00	\N	0.2	\N	\N	Julington Creek	FL
96843	Green Cove Springs, Florida	NOS	8720496	29.99	-81.6633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95084	05:55:00	\N	0.27	04:57:00	\N	0.17	\N	\N	Green Cove Springs	FL
96844	St. Augustine, city dock, Florida	NOS	8720576	29.8917	-81.31	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:01:00	\N	0.89	-00:20:00	\N	0.75	\N	\N	St. Augustine, city dock	FL
96845	Tocoi, Florida	NOS	8720596	29.8583	-81.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95084	07:03:00	\N	0.27	06:02:00	\N	0.21	\N	\N	Tocoi	FL
96846	Palmetto Bluff, Florida	NOS	8720653	29.7633	-81.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95084	07:36:00	\N	0.47	06:35:00	\N	0.23	\N	\N	Palmetto Bluff	FL
96847	Fort Matanzas, Matanzas River, ICWW, Florida	NOS	8720686	29.715	-81.2383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	00:49:00	\N	0.95	00:03:00	\N	0.65	\N	\N	Fort Matanzas, Matanzas River, ICWW	FL
96848	Sutherlands Still, Dunns Creek, Florida	NOS	8720782	29.5717	-81.6067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95084	09:05:00	\N	0.2	07:35:00	\N	0.18	\N	\N	Sutherlands Still, Dunns Creek	FL
96849	Smith Creek, Flagler Beach, Florida	NOS	8720833	29.4783	-81.1367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	05:00:00	\N	0.3	04:33:00	\N	0.15	\N	\N	Smith Creek, Flagler Beach	FL
96850	Ormond Beach, Halifax River, Florida	NOS	8720954	29.28499984741211	-81.05329895019531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	04:31:00	\N	0.45	03:17:00	\N	0.11	\N	\N	Ormond Beach, Halifax River	FL
96851	Daytona Beach Shores, Sunglow Pier, Florida (sub)	NOS	8721120	29.1467	-80.9633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	-00:42:00	\N	0.84	-00:56:00	\N	0.65	\N	\N	Daytona Beach Shores, Sunglow Pier	FL
96852	Ponce Inlet, Halifax River, Florida	NOS	8721138	29.0817	-80.9367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:33:00	\N	1	00:05:00	\N	1.18	\N	\N	Ponce Inlet, Halifax River	FL
96853	Patrick Air Force Base, Florida	NOS	8721727	28.245	-80.6	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	-00:38:00	\N	1.43	-01:04:00	\N	1.5	\N	\N	Patrick Air Force Base	FL
96854	Canova Beach, Florida	NOS	8721804	28.1383	-80.5783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	-00:26:00	\N	1.5	-00:53:00	\N	1.49	\N	\N	Canova Beach	FL
96855	Micco, Indian River, Florida	NOS	8721994	27.8733	-80.4967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	02:19:00	\N	0.57	01:14:00	\N	0.14	\N	\N	Micco	FL
96856	Sebastian Inlet bridge, Florida	NOS	8722004	27.86	-80.4483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	-00:24:00	\N	1	-00:48:00	\N	0.93	\N	\N	Sebastian Inlet bridge	FL
96857	Sebastian, Indian River, Florida	NOS	8722029	27.8117	-80.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	02:36:00	\N	0.5	01:32:00	\N	0.15	\N	\N	Sebastian	FL
96858	Wabasso, Indian River, Florida	NOS	8722059	27.755	-80.425	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	03:24:00	\N	0.42	02:20:00	\N	0.17	\N	\N	Wabasso	FL
96859	Vero Beach (ocean), Florida	NOS	8722105	27.67	-80.36	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	-00:35:00	\N	1.36	-00:55:00	\N	1.45	\N	\N	Vero Beach (ocean)	FL
96860	Oslo, Indian River, Florida	NOS	8722146	27.5933	-80.3567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	03:59:00	\N	0.5	03:00:00	\N	0.34	\N	\N	Oslo	FL
96861	St. Lucie, Indian River, Florida	NOS	8722207	27.48	-80.3333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:46:00	\N	1	00:41:00	\N	0.48	\N	\N	St. Lucie	FL
96862	Fort Pierce Inlet, south jetty, Florida	NOS	8722212	27.47	-80.2883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	-00:18:00	\N	1.5	-00:31:00	\N	1.14	\N	\N	Fort Pierce Inlet, south jetty	FL
96863	Ankona, Indian River, Florida (sub)	NOS	8722274	27.355	-80.2733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	03:03:00	\N	0.85	02:16:00	\N	0.52	\N	\N	Ankona	FL
96864	Eden, Nettles Island, Indian River, Florida	NOS	8722312	27.2867	-80.2267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	03:31:00	\N	0.92	02:35:00	\N	0.45	\N	\N	Eden, Nettles Island	FL
96865	North Fork, St. Lucie River, Florida	NOS	8722334	27.2433	-80.3133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	03:28:00	\N	0.92	02:28:00	\N	0.46	\N	\N	North Fork	FL
96866	Jensen Beach, Indian River, Florida	NOS	8722338	27.235	-80.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	03:04:00	\N	0.92	02:17:00	\N	0.48	\N	\N	Jensen Beach	FL
96867	Stuart, St. Lucie River, Florida	NOS	8722357	27.2	-80.2583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	03:30:00	\N	0.86	02:13:00	\N	0.4	\N	\N	Stuart	FL
96868	Seminole Shores, Florida	NOS	8722366	27.1833	-80.1583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	-00:35:00	\N	1.28	-00:59:00	\N	1.29	\N	\N	Seminole Shores	FL
96869	Sewall Point, St. Lucie River, Florida (sub)	NOS	8722371	27.175	-80.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	02:10:00	\N	0.93	01:13:00	\N	0.43	\N	\N	Sewall Point	FL
96870	South Fork, St. Lucie River, Florida	NOS	8722376	27.165	-80.255	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	03:32:00	\N	0.92	02:35:00	\N	0.43	\N	\N	South Fork	FL
96872	Port Salerno, Manatee Pocket, St. Lucie River, Florida	NOS	8722383	27.1517	-80.195	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:46:00	\N	0.92	00:51:00	\N	0.42	\N	\N	Port Salerno, Manatee Pocket	FL
96873	Peck Lake, ICWW, Florida	NOS	8722404	27.1133	-80.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	02:10:00	\N	1	01:13:00	\N	0.58	\N	\N	Peck Lake, ICWW	FL
96874	Gomez, South Jupiter Narrows, Florida	NOS	8722414	27.0933	-80.1367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	02:37:00	\N	1.07	01:33:00	\N	0.6	\N	\N	Gomez, South Jupiter Narrows	FL
96875	Hobe Sound bridge, Florida	NOS	8722429	27.065	-80.1233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	02:25:00	\N	1	01:28:00	\N	0.68	\N	\N	Hobe Sound bridge	FL
96876	Hobe Sound, Jupiter Island, Florida	NOS	8722445	27.0367	-80.1067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	02:12:00	\N	1	01:16:00	\N	0.75	\N	\N	Hobe Sound, Jupiter Island	FL
96877	Conch Bar, Jupiter Sound, Florida	NOS	8722471	26.9883	-80.0933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:34:00	\N	1.07	00:56:00	\N	0.74	\N	\N	Conch Bar, Jupiter Sound	FL
96878	Boy Scout Dock, Loxahatchee River, Florida	NOS	8722472	26.9867	-80.1417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:57:00	\N	1.36	01:01:00	\N	0.92	\N	\N	Boy Scout Dock	FL
96879	North Fork, 2 mi above entrance, Loxahatchee River, Florida	NOS	8722478	26.975	-80.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:55:00	\N	1.14	01:04:00	\N	0.86	\N	\N	North Fork, 2 miles above entrance	FL
96880	3 mi above A1A highway bridge, Loxahatchee River, Florida	NOS	8722481	26.97	-80.1267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:49:00	\N	1.14	00:56:00	\N	0.86	\N	\N	3 miles above A1A highway bridge	FL
96881	Tequesta, North Fork, Loxahatchee River, Florida	NOS	8722486	26.96	-80.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	02:13:00	\N	1	01:14:00	\N	0.75	\N	\N	Tequesta, North Fork	FL
96882	Jupiter Sound, south end, Florida	NOS	8722491	26.9517	-80.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:45:00	\N	1.36	00:22:00	\N	0.88	\N	\N	Jupiter Sound, south end	FL
96883	A1A highway bridge, Loxahatchee River, Florida	NOS	8722492	26.9467	-80.09	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:54:00	\N	1.14	00:34:00	\N	0.87	\N	\N	A1A highway bridge	FL
96884	Southwest Fork, 0.5 mi above entrance, Loxahatchee River, Florida	NOS	8722494	26.9433	-80.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:35:00	\N	1.42	00:41:00	\N	0.89	\N	\N	Southwest Fork, 0.5 mile above entrance	FL
96885	Jupiter Inlet, south jetty, Florida	NOS	8722495	26.9433	-80.0733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	-00:09:00	\N	1.42	-00:10:00	\N	1.08	\N	\N	Jupiter Inlet, south jetty	FL
96886	Southwest Fork (spillway), Loxahatchee River, Florida	NOS	8722496	26.935	-80.1433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:45:00	\N	1.28	00:52:00	\N	0.86	\N	\N	Southwest Fork (spillway)	FL
96887	Jupiter, Lake Worth Creek, ICWW, Florida	NOS	8722499	26.935	-80.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:12:00	\N	1.28	00:34:00	\N	0.91	\N	\N	Jupiter, Lake Worth Creek, ICWW	FL
96888	Lake Worth Creek, Day Beacon 19, ICWW, Florida	NOS	8722512	26.9117	-80.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:08:00	\N	1.21	00:29:00	\N	0.92	\N	\N	Lake Worth Creek, Day Beacon 19, ICWW	FL
96889	Donald Ross Bridge, ICWW, Florida	NOS	8722528	26.8817	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:50:00	\N	1.21	00:20:00	\N	1	\N	\N	Donald Ross Bridge, ICWW	FL
96890	North Palm Beach, Lake Worth, Florida	NOS	8722557	26.8267	-80.055	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:15:00	\N	1.29	-00:17:00	\N	1.22	\N	\N	North Palm Beach	FL
96891	Palm Beach, Lake Worth, Florida	NOS	8722607	26.7333	-80.0417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:16:00	\N	1.29	-00:11:00	\N	1.17	\N	\N	Palm Beach	FL
96892	Palm Beach, Highway 704 bridge, Lake Worth, Florida	NOS	8722621	26.705	-80.045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:40:00	\N	1.07	00:18:00	\N	1.1	\N	\N	Palm Beach, Highway 704 bridge	FL
96893	West Palm Beach Canal, Lake Worth, Florida	NOS	8722654	26.645	-80.045	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:35:00	\N	1.14	00:48:00	\N	1.07	\N	\N	West Palm Beach Canal	FL
96894	Boynton Beach, Lake Worth, Florida (sub)	NOS	8722706	26.54829978942871	-80.05329895019531	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	02:07:00	\N	1.07	01:05:00	\N	1.06	\N	\N	Boynton Beach, Lake Worth	FL
96895	Delray Beach, ICWW, Florida	NOS	8722746	26.4733	-80.0617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	02:07:00	\N	1.14	01:24:00	\N	1.07	\N	\N	Delray Beach, ICWW	FL
96896	Yamato, ICWW, Florida	NOS	8722784	26.4033	-80.07	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:57:00	\N	1.14	01:22:00	\N	1.02	\N	\N	Yamato, ICWW	FL
96897	Deerfield Beach, Hillsboro River, Florida	NOS	8722832	26.3133	-80.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:03:00	\N	1.07	00:28:00	\N	1.02	\N	\N	Deerfield Beach, Hillsboro River	FL
96898	Hillsboro Beach, ICWW, Florida	NOS	8722854	26.2733	-80.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:34:00	\N	1.07	00:02:00	\N	1.06	\N	\N	Hillsboro Beach, ICWW	FL
96899	Hillsboro Inlet, USCG light station, Florida	NOS	8722861	26.2583	-80.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:03:00	\N	1.14	-00:16:00	\N	1.08	\N	\N	Hillsboro Inlet, Coast Guard Light Station	FL
96900	Hillsboro Inlet (ocean), Florida	NOS	8722862	26.2567	-80.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:00:00	\N	1.21	-00:23:00	\N	1.12	\N	\N	Hillsboro Inlet (ocean)	FL
96901	Andrews Avenue bridge, New River, Fort Lauderdale, Florida	NOS	8722937	26.1183	-80.145	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:51:00	\N	1.07	00:15:00	\N	0.92	\N	\N	Andrews Avenue bridge, New River	FL
96902	Bahia Mar Yacht Club, Fort Lauderdale, Florida	NOS	8722939	26.1133	-80.1083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:33:00	\N	1.21	-00:05:00	\N	1.05	\N	\N	Bahia Mar Yacht Club	FL
96903	Mayan Lake, Florida	NOS	8722946	26.1	-80.1083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:02:00	\N	1	00:20:00	\N	0.91	\N	\N	Mayan Lake	FL
96904	Port Everglades, Turning Basin, Florida	NOS	8722951	26.0917	-80.1233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	-00:09:00	\N	1.14	-00:29:00	\N	1.09	\N	\N	Port Everglades, Turning Basin	FL
96905	Whiskey Creek, north end, Florida	NOS	8722957	26.08	-80.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	-00:06:00	\N	1.28	-00:23:00	\N	1.1	\N	\N	Whiskey Creek, north end	FL
96906	Port Laudania, Dania cut-off Canal, Florida	NOS	8722968	26.06	-80.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:11:00	\N	1.21	00:01:00	\N	1	\N	\N	Port Laudania, Dania cut-off Canal	FL
96907	Whiskey Creek, south entrance, ICWW, Florida	NOS	8722971	26.055	-80.1133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:31:00	\N	1.14	00:04:00	\N	0.96	\N	\N	Whiskey Creek, south entrance, ICWW	FL
96908	Hollywood Beach, West Lake, north end, Florida	NOS	8722977	26.0433	-80.1267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:42:00	\N	1.07	01:08:00	\N	0.85	\N	\N	Hollywood Beach, West Lake, north end	FL
96909	Hollywood Beach, Florida	NOS	8722979	26.04	-80.115	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:41:00	\N	1.14	00:37:00	\N	0.91	\N	\N	Hollywood Beach	FL
96910	Hollywood Beach, West Lake, south end, Florida	NOS	8722982	26.0333	-80.1233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:45:00	\N	1.14	01:02:00	\N	0.88	\N	\N	Hollywood Beach, West Lake, south end	FL
96911	Golden Beach, ICWW, Florida	NOS	8723026	25.9667	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:57:00	\N	1.07	01:13:00	\N	0.91	\N	\N	Golden Beach, ICWW	FL
96912	Dumfoundling Bay, Florida	NOS	8723044	25.9417	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	02:07:00	\N	1	01:17:00	\N	0.88	\N	\N	Dumfoundling Bay	FL
96913	North Miami Beach, Newport Fishing Pier, Florida	NOS	8723050	25.93	-80.12	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:00:00	\N	1.21	-00:22:00	\N	1.08	\N	\N	North Miami Beach, Newport Fishing Pier	FL
96914	Bakers Haulover Inlet (inside), Florida	NOS	8723073	25.9033	-80.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:37:00	\N	0.92	00:57:00	\N	0.87	\N	\N	Bakers Haulover Inlet (inside)	FL
96915	Sunny Isles, Biscayne Creek, Florida	NOS	8723087	25.9283	-80.13	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	02:24:00	\N	0.71	02:00:00	\N	0.77	\N	\N	Sunny Isles, Biscayne Creek	FL
96916	Biscayne Creek, ICWW, Florida	NOS	8723089	25.88	-80.1633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:39:00	\N	1	00:47:00	\N	0.93	\N	\N	Biscayne Creek, ICWW	FL
96917	Indian Creek Golf Club, ICWW, Florida	NOS	8723094	25.875	-80.1433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:46:00	\N	0.92	01:13:00	\N	0.92	\N	\N	Indian Creek Golf Club, ICWW	FL
96918	Dodge Island, Fishermans Channel, Biscayne Bay, Florida	NOS	8723155	25.77	-80.1683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:10:00	\N	1	00:34:00	\N	0.91	\N	\N	Dodge Island, Fishermans Channel	FL
96919	San Marino Island, Biscayne Bay, Florida	NOS	8723156	25.7933	-80.1633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:58:00	\N	1	00:37:00	\N	0.92	\N	\N	San Marino Island	FL
96920	Dinner Key Marina, Biscayne Bay, Florida	NOS	8723205	25.7267	-80.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:48:00	\N	0.92	00:54:00	\N	0.84	\N	\N	Dinner Key Marina	FL
96921	Key Biscayne Yacht Club, Biscayne Bay, Florida	NOS	8723232	25.6983	-80.17	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:31:00	\N	0.92	00:44:00	\N	0.86	\N	\N	Key Biscayne Yacht Club, Biscayne Bay	FL
96922	Coral Shoal, Biscayne Channel, Florida	NOS	8723251	25.6517	-80.16	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:37:00	\N	0.92	00:11:00	\N	0.88	\N	\N	Coral Shoal, Biscayne Channel	FL
96923	Soldier Key, Florida	NOS	8723303	25.59	-80.1617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:16:00	\N	0.71	00:30:00	\N	0.81	\N	\N	Soldier Key	FL
96924	Ragged Keys, Biscayne Bay, Florida	NOS	8723350	25.5333	-80.1717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:18:00	\N	1	00:43:00	\N	0.73	\N	\N	Ragged Keys, Biscayne Bay	FL
96925	Sands Key, northwest point, Biscayne Bay, Florida	NOS	8723372	25.5067	-80.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	02:26:00	\N	0.64	01:25:00	\N	0.63	\N	\N	Sands Key, northwest point, Biscayne Bay	FL
96926	Coon Point, Elliott Key, Biscayne Bay, Florida	NOS	8723391	25.48	-80.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	02:56:00	\N	0.71	01:55:00	\N	0.63	\N	\N	Coon Point, Elliott Key, Biscayne Bay	FL
96927	Sea Grape Point, Elliott Key, Florida	NOS	8723393	25.4767	-80.18	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	-00:05:00	\N	1.03	-00:25:00	\N	1.03	\N	\N	Sea Grape Point, Elliott Key	FL
96928	Billys Point, south of, Elliott Key, Biscayne Bay, Florida	NOS	8723439	25.415	-80.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	03:20:00	\N	0.64	02:08:00	\N	0.63	\N	\N	Billys Point, south of, Elliott Key, Biscayne Bay	FL
96929	Adams Key, south end, Biscayne Bay, Florida	NOS	8723453	25.3967	-80.2333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:08:00	\N	1	01:01:00	\N	0.67	\N	\N	Adams Key, south end, Biscayne Bay	FL
96930	Christmas Point, Elliott Key, Florida	NOS	8723457	25.3917	-80.23	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:37:00	\N	1.07	00:13:00	\N	0.8	\N	\N	Christmas Point, Elliott Key	FL
96931	Totten Key, west side, Biscayne Bay, Florida	NOS	8723467	25.3783	-80.2567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	03:21:00	\N	0.57	02:19:00	\N	0.54	\N	\N	Totten Key, west side, Biscayne Bay	FL
96932	Card Sound, western side, Florida	NOS	8723491	25.345	-80.3317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	03:40:00	\N	0.43	02:51:00	\N	0.3	\N	\N	Card Sound, western side	FL
96933	Wednesday Point, Key Largo, Card Sound, Florida	NOS	8723518	25.31	-80.2983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	03:30:00	\N	0.57	02:38:00	\N	0.34	\N	\N	Wednesday Point, Key Largo, Card Sound	FL
96934	Ocean Reef Harbor, Key Largo, Florida	NOS	8723519	25.3083	-80.2767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:17:00	\N	1.5	-00:08:00	\N	1.02	\N	\N	Ocean Reef Harbor, Key Largo	FL
96935	Cormorant Point, Key Largo, Card Sound, Florida	NOS	8723532	25.29	-80.34	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	03:01:00	\N	0.5	02:45:00	\N	0.32	\N	\N	Cormorant Point, Key Largo, Card Sound	FL
96936	Main Key, Barnes Sound, Florida	NOS	8723571	25.24	-80.4	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	06:16:00	\N	0.36	05:04:00	\N	0.19	\N	\N	Main Key, Barnes Sound	FL
97412	Triton Head, Washington	NOS	9445326	47.6033	-122.982	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:06:00	\N	1.02	-00:06:00	\N	1	\N	\N	Triton Head	WA
96937	Manatee Creek, Manatee Bay, Barnes Sound, Florida	NOS	8723575	25.235	-80.43	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	06:20:00	\N	0.36	05:14:00	\N	0.18	\N	\N	Manatee Creek, Manatee Bay, Barnes Sound	FL
96938	Carysfort Reef, Florida	NOS	8723583	25.2217	-80.2117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:39:00	\N	1.36	00:19:00	\N	1.03	\N	\N	Carysfort Reef	FL
96939	Garden Cove, Key Largo, Florida	NOS	8723622	25.1717	-80.3667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:25:00	\N	1.14	-00:01:00	\N	0.94	\N	\N	Garden Cove, Key Largo	FL
96940	Flamingo, Florida Bay, Florida	NOS	8723644	25.1417	-80.9233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	07:20:00	\N	1.08	05:28:00	\N	1.47	\N	\N	Flamingo, Florida Bay	FL
96941	Largo Sound, Key Largo, Florida	NOS	8723651	25.14	-80.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	03:03:00	\N	0.5	02:13:00	\N	0.35	\N	\N	Largo Sound, Key Largo	FL
96942	Key Largo, South Sound, Key Largo, Florida	NOS	8723667	25.113333333332992	-80.41666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:49:00	\N	0.64	00:23:00	\N	0.66	\N	\N	Key Largo, South Sound, Key Largo	FL
96943	Rock Harbor, Key Largo, Florida	NOS	8723689	25.0817	-80.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:36:00	\N	1.21	00:22:00	\N	0.94	\N	\N	Rock Harbor, Key Largo	FL
96944	Point Charles, Key Largo, Florida	NOS	8723691	25.0817	-80.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:53:00	\N	0.64	00:25:00	\N	0.77	\N	\N	Point Charles, Key Largo	FL
96945	Crane Keys, north side, Florida Bay, Florida	NOS	8723746	25.005	-80.6183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	04:35:00	\N	0.21	02:52:00	\N	0.17	\N	\N	Crane Keys, north side, Florida Bay	FL
96946	Tavernier Harbor, Hawk Channel, Florida	NOS	8723747	25.005	-80.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:26:00	\N	1.36	00:07:00	\N	0.9	\N	\N	Tavernier Harbor, Hawk Channel	FL
96947	Tavernier Creek, Hwy. 1 bridge, Hawk Channel, Florida	NOS	8723748	25.0033	-80.53	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:52:00	\N	1.07	00:25:00	\N	0.6	\N	\N	Tavernier Creek, Hwy. 1 bridge, Hawk Channel	FL
96948	East Key, southern end, Florida Bay, Florida	NOS	8723752	24.9967	-80.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	04:06:00	\N	0.14	02:43:00	\N	0.22	\N	\N	East Key, southern end, Florida Bay	FL
96949	Plantation Key, Hawk Channel, Florida	NOS	8723769	24.9733	-80.55	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:12:00	\N	1.21	00:05:00	\N	0.96	\N	\N	Plantation Key, Hawk Channel	FL
96950	Yacht Harbor, Cowpens Anchorage, Plantation Key, Florida	NOS	8723776	24.965	-80.5683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	04:00:00	\N	0.29	02:45:00	\N	0.23	\N	\N	Yacht Harbor, Cowpens Anchorage, Plantation Key	FL
96951	Snake Creek, USCG station, Plantation Key, Florida	NOS	8723786	24.9533	-80.5867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:56:00	\N	0.5	01:08:00	\N	0.36	\N	\N	Snake Creek, USCG Station, Plantation Key	FL
96952	Snake Creek, Hwy. 1 bridge, Windley Key, Florida	NOS	8723787	24.9517	-80.5883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:56:00	\N	0.5	00:49:00	\N	0.46	\N	\N	Snake Creek, Hwy. 1 bridge, Windley Key	FL
96953	Whale Harbor, Windley Key, Hawk Channel, Florida	NOS	8723795	24.94	-80.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:51:00	\N	0.36	00:07:00	\N	0.65	\N	\N	Whale Harbor, Windley Key, Hawk Channel	FL
96954	Whale Harbor Channel, Hwy. 1 bridge, Windley Key, Florida	NOS	8723797	24.9383	-80.61	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:00:00	\N	0.71	00:16:00	\N	0.59	\N	\N	Whale Harbor Channel, Hwy. 1 bridge, Windley Key	FL
96955	Shell Key, northwest side, Lignumvitae Basin, Florida	NOS	8723807	24.9233	-80.6717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:57:00	\N	0.46	00:31:00	\N	0.46	\N	\N	Shell Key, northwest side, Lignumvitae Basin	FL
96956	Islamorada, Upper Matecumbe Key, Florida Bay, Florida	NOS	8723808	24.925	-80.6317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	02:07:00	\N	0.37	00:39:00	\N	0.37	\N	\N	Islamorada, Upper Matecumbe Key, Florida Bay	FL
96957	Shell Key Channel, Florida Bay, Florida	NOS	8723812	24.9133	-80.66	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:45:00	\N	0.78	-00:20:00	\N	0.78	\N	\N	Shell Key Channel, Florida Bay	FL
96958	Little Basin, Upper Matecumbe Key, Florida Bay, Florida	NOS	8723813	24.915	-80.64	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:15:00	\N	0.61	00:08:00	\N	0.61	\N	\N	Little Basin, Upper Matecumbe Key, Florida Bay	FL
96959	Upper Matecumbe Key, Hawk Channel, Florida	NOS	8723814	24.915	-80.6317	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:49:00	\N	1.21	00:34:00	\N	0.87	\N	\N	Upper Matecumbe Key, Hawk Channel	FL
96960	Lignumvitae Key, NE side, Florida Bay, Florida	NOS	8723824	24.9033	-80.695	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:31:00	\N	0.52	00:09:00	\N	0.52	\N	\N	Lignumvitae Key, NE side, Florida Bay	FL
96961	Lignumvitae Key, west side, Florida Bay, Florida	NOS	8723825	24.9	-80.705	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:54:00	\N	0.47	00:32:00	\N	0.47	\N	\N	Lignumvitae Key, west side, Florida Bay	FL
96962	Upper Matecumbe Key, west end, Hawk Channel, Florida	NOS	8723828	24.8967	-80.6583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:14:00	\N	0.33	-01:00:00	\N	0.98	\N	\N	Upper Matecumbe Key, west end, Hawk Channel	FL
96963	Indian Key, Hawk Channel, Florida	NOS	8723843	24.8767	-80.6767	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:35:00	\N	0.71	-00:58:00	\N	1.3	\N	\N	Indian Key, Hawk Channel	FL
96964	Indian Key Anchorage, Lower Matecumbe Key, Florida	NOS	8723851	24.8683	-80.7033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:54:00	\N	0.88	-01:25:00	\N	1.38	\N	\N	Indian Key Anchorage, Lower Matecumbe Key	FL
96965	Matecumbe Bight, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723852	24.865	-80.7167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:33:00	\N	0.38	-00:18:00	\N	0.55	\N	\N	Matecumbe Bight, Lower Matecumbe Key, Fla. Bay	FL
96966	Alligator Reef, Hawk Channel, Florida	NOS	8723861	24.85	-80.6183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	00:24:00	\N	1.36	00:08:00	\N	0.86	\N	\N	Alligator Reef, Hawk Channel	FL
96967	Matecumbe Harbor, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723862	24.8517	-80.74	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:23:00	\N	0.33	-00:25:00	\N	0.59	\N	\N	Matecumbe Harbor, Lower Matecumbe Key, Fla. Bay	FL
96968	Channel Two, east, Lower Matecumbe Key, Fla. Bay, Florida	NOS	8723868	24.845	-80.7483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:42:00	\N	0.54	-00:49:00	\N	0.85	\N	\N	Channel Two, east, Lower Matecumbe Key, Fla. Bay	FL
96969	Channel Two, west side, Hawk Channel, Florida	NOS	8723869	24.8417	-80.7533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:54:00	\N	0.75	-01:06:00	\N	1.12	\N	\N	Channel Two, west side, Hawk Channel	FL
96970	Channel Five, west side, Hawk Channel, Florida	NOS	8723872	24.84	-80.78	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:41:00	\N	0.67	-00:58:00	\N	1	\N	\N	Channel Five, west side, Hawk Channel	FL
96971	Jewfish Hole, Long Key, Florida Bay, Florida	NOS	8723873	24.83830555555556	-80.79830555555556	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:32:00	\N	0.38	-00:11:00	\N	0.42	\N	\N	Jewfish Hole, Long Key, Florida Bay	FL
96972	Channel Five, east side, Hawk Channel, Florida	NOS	8723874	24.8367	-80.7667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:42:00	\N	0.58	-00:54:00	\N	0.9	\N	\N	Channel Five, east side, Hawk Channel	FL
96973	Long Key Bight, Long Key, Florida	NOS	8723879	24.8283	-80.8083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:43:00	\N	0.62	-00:59:00	\N	1.03	\N	\N	Long Key Bight, Long Key	FL
96974	Long Key Lake, Long Key, Florida	NOS	8723887	24.82	-80.8167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:57:00	\N	0.46	00:33:00	\N	0.62	\N	\N	Long Key Lake, Long Key	FL
96975	Long Key, western end, Florida	NOS	8723899	24.8033	-80.85	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:54:00	\N	0.33	-01:01:00	\N	0.82	\N	\N	Long Key, western end	FL
96976	Conch Key, eastern end, Florida	NOS	8723906	24.7917	-80.8833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:45:00	\N	0.54	-01:09:00	\N	0.85	\N	\N	Conch Key, eastern end	FL
96977	Toms Harbor Cut, Florida	NOS	8723912	24.7833	-80.9067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:30:00	\N	0.38	-01:19:00	\N	0.37	\N	\N	Toms Harbor Cut	FL
96978	Toms Harbor Channel, Hwy. 1 bridge, Florida	NOS	8723918	24.7767	-80.9233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	04:49:00	\N	0.38	05:07:00	\N	0.38	\N	\N	Toms Harbor Channel, Hwy. 1 bridge	FL
96979	Grassy Key, north side, Florida Bay, Florida	NOS	8723921	24.7717	-80.94	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	06:48:00	\N	1.04	05:40:00	\N	0.73	\N	\N	Grassy Key, north side, Florida Bay	FL
96980	Duck Key, Hawk Channel, Florida	NOS	8723927	24.765	-80.9133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:40:00	\N	0.55	-01:11:00	\N	0.97	\N	\N	Duck Key, Hawk Channel	FL
96981	Grassy Key, south side, Hawk Channel, Florida	NOS	8723933	24.755	-80.9583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:26:00	\N	0.71	-00:52:00	\N	1.22	\N	\N	Grassy Key, south side, Hawk Channel	FL
96982	Fat Deer Key, Florida Bay, Florida	NOS	8723949	24.7333	-81.0167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	06:26:00	\N	0.87	05:09:00	\N	0.87	\N	\N	Fat Deer Key, Florida Bay	FL
96983	Vaca Key-Fat Deer Key bridge, Florida	NOS	8723950	24.73	-81.03	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:36:00	\N	0.71	-01:11:00	\N	0.95	\N	\N	Vaca Key-Fat Deer Key bridge	FL
96984	Boot Key Harbor bridge, Boot Key, Florida	NOS	8723971	24.7033	-81.105	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:37:00	\N	0.75	-01:03:00	\N	1.13	\N	\N	Boot Key Harbor bridge, Boot Key	FL
96985	Sombrero Key, Hawk Channel, Florida	NOS	8723999	24.6267	-81.1117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:39:00	\N	0.79	-01:03:00	\N	1.18	\N	\N	Sombrero Key, Hawk Channel	FL
96986	Knight Key Channel, Knight Key, Florida Bay, Florida	NOS	8724008	24.7067	-81.125	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:18:00	\N	0.5	-00:02:00	\N	0.54	\N	\N	Knight Key Channel, Knight Key, Florida Bay	FL
96987	Pigeon Key, south side, Hawk Channel, Florida	NOS	8724032	24.7033	-81.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:26:00	\N	0.5	-00:55:00	\N	0.81	\N	\N	Pigeon Key, south side, Hawk Channel	FL
96988	Pigeon Key, north side, Florida Bay, Florida	NOS	8724033	24.705	-81.1567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:45:00	\N	0.46	-00:10:00	\N	0.46	\N	\N	Pigeon Key, north side, Florida Bay	FL
96989	Molasses Key Channel, Molasses Keys, Florida	NOS	8724062	24.6833	-81.1917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:16:00	\N	0.5	-00:56:00	\N	0.79	\N	\N	Molasses Key Channel, Molasses Keys	FL
96990	Money Key, Florida	NOS	8724082	24.6833	-81.2167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:17:00	\N	0.58	00:03:00	\N	0.58	\N	\N	Money Key	FL
96991	Little Duck Key, east end, Hawk Channel, Florida	NOS	8724093	24.6817	-81.2283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:05:00	\N	0.67	-00:49:00	\N	0.67	\N	\N	Little Duck Key, east end, Hawk Channel	FL
96992	East Bahia Honda Key, south end, Florida Bay, Florida	NOS	8724094	24.775	-81.2267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	02:49:00	\N	0.69	04:04:00	\N	0.69	\N	\N	East Bahia Honda Key, south end, Florida Bay	FL
96993	Cocoanut Key, Florida Bay, Florida	NOS	8724098	24.745	-81.2367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	02:50:00	\N	0.55	03:52:00	\N	0.55	\N	\N	Cocoanut Key, Florida Bay	FL
96994	Missouri Key-Little Duck Key Channel, Florida	NOS	8724099	24.68	-81.235	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:36:00	\N	0.46	-00:52:00	\N	0.7	\N	\N	Missouri Key-Little Duck Key Channel	FL
96995	Missouri Key-Ohio Key Channel, west side, Florida	NOS	8724107	24.6733	-81.2433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:22:00	\N	0.5	-00:47:00	\N	0.77	\N	\N	Missouri Key-Ohio Key Channel, west side	FL
96996	Ohio Key-Bahia Honda Key Channel, west side, Florida	NOS	8724112	24.67	-81.2517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:14:00	\N	0.62	-00:57:00	\N	0.81	\N	\N	Ohio Key-Bahia Honda Key Channel, west side	FL
96997	West Bahia Honda Key, Florida	NOS	8724129	24.78	-81.2717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	04:01:00	\N	1	03:59:00	\N	0.97	\N	\N	West Bahia Honda Key	FL
96998	Bahia Honda Key, Bahia Honda Channel, Florida	NOS	8724138	24.655	-81.2817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:28:00	\N	0.63	-00:46:00	\N	0.86	\N	\N	Bahia Honda Key, Bahia Honda Channel	FL
96999	Horseshoe Keys, south end, Florida	NOS	8724139	24.7667	-81.2833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	03:09:00	\N	1	03:54:00	\N	0.86	\N	\N	Horseshoe Keys, south end	FL
97000	Johnson Keys, south end, Florida	NOS	8724153	24.7433	-81.3	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	02:33:00	\N	0.96	03:36:00	\N	0.72	\N	\N	Johnson Keys, south end	FL
97001	Little Pine Key, south end, Florida	NOS	8724154	24.7133	-81.3033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:07:00	\N	0.79	01:07:00	\N	0.56	\N	\N	Little Pine Key, south end	FL
97002	No Name Key, east side, Bahia Honda Channel, Florida	NOS	8724168	24.6983	-81.3183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:33:00	\N	0.83	01:35:00	\N	0.58	\N	\N	No Name Key, east side, Bahia Honda Channel	FL
97003	Johnson Keys, north end, Florida	NOS	8724172	24.7667	-81.3233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	04:22:00	\N	1.38	03:35:00	\N	1.31	\N	\N	Johnson Keys, north end	FL
97004	Little Pine Key, north end, Florida	NOS	8724177	24.75	-81.3283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	03:28:00	\N	1.21	03:38:00	\N	1.05	\N	\N	Little Pine Key, north end	FL
97005	Big Pine Key, Spanish Harbor, Florida	NOS	8724178	24.6483	-81.33	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:03:00	\N	0.42	-00:44:00	\N	0.75	\N	\N	Big Pine Key, Spanish Harbor	FL
97006	Water Key, west end, Big Spanish Channel, Florida	NOS	8724189	24.74	-81.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	02:37:00	\N	1.04	03:23:00	\N	0.81	\N	\N	Water Key, west end, Big Spanish Channel	FL
97007	Big Pine Key, Coupon Bight, Florida	NOS	8724192	24.6517	-81.35	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:49:00	\N	0.5	-00:20:00	\N	0.87	\N	\N	Big Pine Key, Coupon Bight	FL
97008	Big Pine Key, Bogie Channel Bridge, Florida	NOS	8724193	24.6967	-81.3483	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	02:11:00	\N	0.83	02:10:00	\N	0.65	\N	\N	Big Pine Key, Bogie Channel Bridge	FL
97009	Porpoise Key, Big Spanish Channel, Florida	NOS	8724196	24.7183	-81.3517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	02:29:00	\N	1	03:23:00	\N	0.72	\N	\N	Porpoise Key, Big Spanish Channel	FL
97010	Crawl Key, Big Spanish Channel, Florida	NOS	8724199	24.7567	-81.3583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	04:13:00	\N	1.33	03:34:00	\N	1.33	\N	\N	Crawl Key, Big Spanish Channel	FL
97011	Big Pine Key, Doctors Arm, Bogie Channel, Florida	NOS	8724201	24.69	-81.3567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:47:00	\N	0.71	00:41:00	\N	0.63	\N	\N	Big Pine Key, Doctors Arm, Bogie Channel	FL
97012	Mayo Key, Big Spanish Channel, Florida	NOS	8724205	24.7333	-81.3617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	03:01:00	\N	1.08	03:35:00	\N	0.92	\N	\N	Mayo Key, Big Spanish Channel	FL
97013	Little Spanish Key, Spanish Banks, Florida	NOS	8724209	24.7733	-81.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	04:30:00	\N	1.62	03:25:00	\N	1.74	\N	\N	Little Spanish Key, Spanish Banks	FL
97014	Big Pine Key, Pine Channel Bridge, north side, Florida	NOS	8724211	24.67	-81.3683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:43:00	\N	0.33	00:03:00	\N	0.57	\N	\N	Big Pine Key, Pine Channel Bridge, north side	FL
97015	Big Pine Key, Pine Channel Bridge, south side, Florida	NOS	8724213	24.6683	-81.3717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:03:00	\N	0.33	-00:13:00	\N	0.67	\N	\N	Big Pine Key, Pine Channel Bridge, south side	FL
97016	Big Pine Key, Newfound Harbor Channel, Florida	NOS	8724215	24.6517	-81.375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:44:00	\N	0.46	-00:09:00	\N	0.82	\N	\N	Big Pine Key, Newfound Harbor Channel	FL
97017	Little Torch Key, Pine Channel Bridge, south side, Florida	NOS	8724223	24.665	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:57:00	\N	0.33	-00:15:00	\N	0.68	\N	\N	Little Torch Key, Pine Channel Bridge, south side	FL
97018	Little Torch Key, Pine Channel Bridge, south side, Florida (2)	NOS	8724224	24.665	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:54:00	\N	0.38	-00:13:00	\N	0.69	\N	\N	Little Torch Key, Pine Channel Bridge, south side	FL
97019	Big Pine Key, northeast shore, Florida	NOS	8724226	24.7283	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	02:30:00	\N	1.08	03:19:00	\N	0.86	\N	\N	Big Pine Key, northeast shore	FL
97020	Big Pine Key, west side, Pine Channel, Florida	NOS	8724227	24.69	-81.3833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:52:00	\N	0.42	00:21:00	\N	0.52	\N	\N	Big Pine Key, west side, Pine Channel	FL
97021	Annette Key, north end, Big Spanish Channel, Florida	NOS	8724229	24.7583	-81.39	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	04:33:00	\N	1.29	03:30:00	\N	1.44	\N	\N	Annette Key, north end, Big Spanish Channel	FL
97022	Big Pine Key, north end, Florida	NOS	8724231	24.745	-81.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	05:56:00	\N	0.83	04:24:00	\N	0.96	\N	\N	Big Pine Key, north end	FL
97023	Little Torch Key, Torch Channel, Florida	NOS	8724232	24.665	-81.395	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:45:00	\N	0.33	00:11:00	\N	0.57	\N	\N	Little Torch Key, Torch Channel	FL
97024	Middle Torch Key, Torch Ramrod Channel, Florida	NOS	8724237	24.6617	-81.4017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:29:00	\N	0.38	-00:16:00	\N	0.69	\N	\N	Middle Torch Key, Torch Ramrod Channel	FL
97025	Munson Island, Newfound Harbor Channel, Florida	NOS	8724238	24.6233	-81.4033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:12:00	\N	0.67	-00:40:00	\N	0.98	\N	\N	Munson Island, Newfound Harbor Channel	FL
97026	Ramrod Key, Newfound Harbor, Florida	NOS	8724239	24.65	-81.4033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:05:00	\N	0.5	-00:41:00	\N	0.9	\N	\N	Ramrod Key, Newfound Harbor	FL
97027	Howe Key, south end, Harbor Channel, Florida	NOS	8724243	24.725	-81.4067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	04:49:00	\N	0.62	04:43:00	\N	0.72	\N	\N	Howe Key, south end, Harbor Channel	FL
97028	Big Spanish Key, Florida	NOS	8724246	24.7883	-81.4117	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	04:29:00	\N	1.5	03:19:00	\N	1.97	\N	\N	Big Spanish Key	FL
97029	Ramrod Key, Niles Channel Bridge, Florida	NOS	8724255	24.66	-81.4233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:12:00	\N	0.46	-00:13:00	\N	0.67	\N	\N	Ramrod Key, Niles Channel Bridge	FL
97030	Howe Key, northwest end, Florida	NOS	8724257	24.7583	-81.4283	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	05:22:00	\N	1.33	03:29:00	\N	1.68	\N	\N	Howe Key, northwest end	FL
97031	Big Torch Key, Niles Channel, Florida	NOS	8724264	24.705	-81.4333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	02:05:00	\N	0.71	03:15:00	\N	0.61	\N	\N	Big Torch Key, Niles Channel	FL
97032	Summerland Key, Niles Channel South, Florida	NOS	8724266	24.6517	-81.435	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:11:00	\N	0.71	-00:36:00	\N	0.85	\N	\N	Summerland Key, Niles Channel South	FL
97033	Summerland Key, Niles Channel Bridge, Florida	NOS	8724267	24.66	-81.4367	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:56:00	\N	0.58	-00:10:00	\N	0.67	\N	\N	Summerland Key, Niles Channel Bridge	FL
97034	Water Keys, south end, Harbor Channel, Florida	NOS	8724273	24.7467	-81.45	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	05:41:00	\N	1	03:42:00	\N	1.52	\N	\N	Water Keys, south end, Harbor Channel	FL
97035	Big Torch Key, Harbor Channel, Florida	NOS	8724274	24.7367	-81.4433	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	05:51:00	\N	1.29	03:47:00	\N	1.58	\N	\N	Big Torch Key, Harbor Channel	FL
97036	Summerland Key, southwest side, Kemp Channel, Florida	NOS	8724276	24.65	-81.4467	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:50:00	\N	0.54	-00:26:00	\N	0.81	\N	\N	Summerland Key, southwest side, Kemp Channel	FL
97037	Kemp Channel Viaduct, Florida Keys, Florida	NOS	8724292	24.6617	-81.4683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	02:04:00	\N	0.46	00:47:00	\N	0.58	\N	\N	Kemp Channel Viaduct	FL
97038	Key Lois, southeast end, Florida	NOS	8724293	24.6067	-81.47	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:45:00	\N	0.75	-01:15:00	\N	1.06	\N	\N	Key Lois, southeast end	FL
97039	Knockemdown Key, north end, Florida	NOS	8724302	24.715	-81.4783	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	04:54:00	\N	1.21	03:30:00	\N	1.35	\N	\N	Knockemdown Key, north end	FL
97040	Gopher Key, Cudjoe Bay, Florida	NOS	8724306	24.6417	-81.485	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:17:00	\N	0.71	-00:46:00	\N	0.9	\N	\N	Gopher Key, Cudjoe Bay	FL
97041	Content Keys, Content Passage, Florida	NOS	8724307	24.79	-81.4833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	03:49:00	\N	1.83	02:46:00	\N	2.13	\N	\N	Content Keys, Content Passage	FL
97042	Raccoon Key, east side, Florida	NOS	8724311	24.7417	-81.4833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	05:09:00	\N	1.21	03:20:00	\N	1.5	\N	\N	Raccoon Key, east side	FL
97043	Cudjoe Key, Cudjoe Bay, Florida	NOS	8724313	24.66	-81.4917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:41:00	\N	0.71	-00:38:00	\N	0.87	\N	\N	Cudjoe Key, Cudjoe Bay	FL
97044	Sugarloaf Key, Pirates Cove, Florida	NOS	8724326	24.6533	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:41:00	\N	0.75	-00:48:00	\N	0.59	\N	\N	Sugarloaf Key, Pirates Cove	FL
97718	Boot Bay, Adak Island, Alaska	NOS	9461391	51.7133	-176.53	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-02:09:00	\N	0.97	-01:38:00	\N	0.97	\N	\N	Boot Bay	AK
97045	Sugarloaf Key, east side, Tarpon Creek, Florida	NOS	8724327	24.6283	-81.51	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:15:00	\N	0.58	-00:41:00	\N	0.89	\N	\N	Sugarloaf Key, east side, Tarpon Creek	FL
97046	Cudjoe Key, north end, Kemp Channel, Florida	NOS	8724328	24.7	-81.505	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	04:40:00	\N	1.46	03:33:00	\N	1.61	\N	\N	Cudjoe Key, north end, Kemp Channel	FL
97047	Cudjoe Key, Pirates Cove, Florida	NOS	8724332	24.6617	-81.515	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	02:54:00	\N	0.79	03:50:00	\N	0.77	\N	\N	Cudjoe Key, Pirates Cove	FL
97048	Tarpon Creek, Upper Sugarloaf Sound, Florida	NOS	8724334	24.63	-81.5167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:17:00	\N	0.38	-00:29:00	\N	0.35	\N	\N	Tarpon Creek	FL
97049	Sugarloaf Key, northeast side, Bow Channel, Florida	NOS	8724347	24.6717	-81.5333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	03:24:00	\N	0.71	03:47:00	\N	1.01	\N	\N	Sugarloaf Key, northeast side, Bow Channel	FL
97050	Park Channel Bridge, Upper Sugarloaf Sound, Florida	NOS	8724353	24.655	-81.54	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	08:33:00	\N	0.29	05:47:00	\N	0.26	\N	\N	Park Channel Bridge	FL
97051	North Harris Channel, Upper Sugarloaf Sound, Florida	NOS	8724367	24.6533	-81.5533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	08:04:00	\N	0.25	05:32:00	\N	0.25	\N	\N	North Harris Channel	FL
97052	Sugarloaf Key, north end, Bow Channel, Florida	NOS	8724368	24.6933	-81.555	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	05:20:00	\N	0.75	03:37:00	\N	1.29	\N	\N	Sugarloaf Key, north end, Bow Channel	FL
97053	Sawyer Key, inside, Cudjoe Channel, Florida	NOS	8724369	24.7583	-81.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	05:19:00	\N	0.5	02:37:00	\N	1.43	\N	\N	Sawyer Key, inside, Cudjoe Channel	FL
97054	Sawyer Key, outside, Cudjoe Channel, Florida	NOS	8724370	24.7583	-81.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	05:24:00	\N	0.5	02:45:00	\N	1.57	\N	\N	Sawyer Key, outside, Cudjoe Channel	FL
97055	Pumpkin Key, Bow Channel, Florida	NOS	8724373	24.7167	-81.5617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	04:39:00	\N	1.17	03:17:00	\N	1.56	\N	\N	Pumpkin Key, Bow Channel	FL
97056	Perky, Upper Sugarloaf Sound, Florida	NOS	8724378	24.6483	-81.57	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	08:25:00	\N	0.08	05:37:00	\N	0.28	\N	\N	Perky	FL
97057	Johnston Key, southwest end, Turkey Basin, Florida	NOS	8724397	24.71	-81.5933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	05:38:00	\N	0.5	03:26:00	\N	1.1	\N	\N	Johnston Key, southwest end, Turkey Basin	FL
97058	Saddlebunch Keys, Channel No. 3, Florida	NOS	8724405	24.6233	-81.6033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:10:00	\N	0.21	01:44:00	\N	0.43	\N	\N	Saddlebunch Keys, Channel No. 3	FL
97059	Snipe Keys, southeast end, Inner Narrows, Florida	NOS	8724409	24.6583	-81.6083	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	05:39:00	\N	0.83	03:25:00	\N	1.28	\N	\N	Snipe Keys, southeast end, Inner Narrows	FL
97060	Saddlebunch Keys, Channel No. 4, Florida	NOS	8724417	24.615	-81.6167	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	05:36:00	\N	0.29	04:35:00	\N	0.54	\N	\N	Saddlebunch Keys, Channel No. 4	FL
97061	Saddlebunch Keys, Similar Sound, Florida	NOS	8724422	24.6	-81.6217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	02:41:00	\N	0.21	00:39:00	\N	0.37	\N	\N	Saddlebunch Keys, Similar Sound	FL
97062	Saddlebunch Keys, Channel No. 5, Florida	NOS	8724423	24.6117	-81.6233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	06:58:00	\N	1.12	04:32:00	\N	0.66	\N	\N	Saddlebunch Keys, Channel No. 5	FL
97063	Snipe Keys, Middle Narrows, Florida	NOS	8724427	24.6667	-81.63	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	05:54:00	\N	0.67	03:44:00	\N	1.02	\N	\N	Snipe Keys, Middle Narrows	FL
97064	Bird Key, Similar Sound, Florida	NOS	8724436	24.5883	-81.6383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:03:00	\N	0.42	-00:21:00	\N	0.59	\N	\N	Bird Key, Similar Sound	FL
97065	Shark Key, southeast end, Similar Sound, Florida	NOS	8724438	24.6033	-81.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:51:00	\N	0.46	00:18:00	\N	0.52	\N	\N	Shark Key, southeast end, Similar Sound	FL
97066	O'Hara Key, north end, Waltz Key Basin, Florida	NOS	8724441	24.6167	-81.645	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	05:39:00	\N	0.83	03:53:00	\N	1.03	\N	\N	O'Hara Key, north end, Waltz Key Basin	FL
97067	Waltz Key, Waltz Key Basin, Florida	NOS	8724448	24.6467	-81.6533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	05:33:00	\N	0.96	03:53:00	\N	1.03	\N	\N	Waltz Key, Waltz Key Basin	FL
97068	Rockland Key, Rockland Channel Bridge, Florida	NOS	8724459	24.5917	-81.67	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	06:06:00	\N	0.88	05:02:00	\N	0.76	\N	\N	Rockland Key, Rockland Channel Bridge	FL
97069	Snipe Keys, Snipe Point, Florida	NOS	8724463	24.6917	-81.6733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	03:33:00	\N	1.29	02:15:00	\N	1.69	\N	\N	Snipe Keys, Snipe Point	FL
97070	Duck Key Point, Duck Key, Waltz Key Basin, Florida	NOS	8724474	24.6233	-81.685	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	04:57:00	\N	0.96	03:27:00	\N	1.19	\N	\N	Duck Key Point, Duck Key, Waltz Key Basin	FL
97071	Boca Chica Key, Long Point, Florida	NOS	8724485	24.6033	-81.6983	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	05:22:00	\N	0.71	03:54:00	\N	0.94	\N	\N	Boca Chica Key, Long Point	FL
97072	Big Coppitt Key, northeast side, Waltz Key Basin, Florida	NOS	8724489	24.6017	-81.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	06:54:00	\N	0.33	04:21:00	\N	0.84	\N	\N	Big Coppitt Key, northeast side, Waltz Key Basin	FL
97073	Boca Chica Key, southwest end, Florida	NOS	8724499	24.5633	-81.7133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:16:00	\N	0.63	-00:14:00	\N	0.66	\N	\N	Boca Chica Key, Southwest end	FL
97074	Boca Chica Channel Bridge, Florida	NOS	8724503	24.5767	-81.7217	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:29:00	\N	0.67	01:23:00	\N	0.57	\N	\N	Boca Chica Channel Bridge	FL
97075	Channel Key, west side, Florida	NOS	8724507	24.6033	-81.725	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	03:07:00	\N	0.71	03:09:00	\N	0.7	\N	\N	Channel Key, west side	FL
97076	Key Haven - Stock Island Channel, Florida	NOS	8724517	24.58	-81.7383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	02:57:00	\N	0.79	02:25:00	\N	0.73	\N	\N	Key Haven - Stock Island Channel	FL
97077	Cow Key Channel, Florida	NOS	8724527	24.57	-81.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	02:05:00	\N	0.71	01:55:00	\N	0.65	\N	\N	Cow Key Channel	FL
97078	Riviera Canal, Key West, Florida	NOS	8724529	24.565	-81.7517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	01:00:00	\N	0.63	-00:12:00	\N	0.65	\N	\N	Riveria Canal, Key West	FL
97079	Sigsbee Park, Garrison Bight Channel, Florida	NOS	8724542	24.585	-81.775	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	02:06:00	\N	0.88	01:59:00	\N	0.81	\N	\N	Sigsbee Park, Garrison Bight Channel	FL
97080	Key West, south side, White Street Pier, Florida	NOS	8724557	24.545	-81.7833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	-00:31:00	\N	0.92	-00:53:00	\N	1.07	\N	\N	Key West, south side, White Street Pier	FL
97081	Garden Key, Dry Tortugas, Florida	NOS	8724697	24.6267	-82.8717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95153	00:33:00	\N	1.33	00:29:00	\N	0.94	\N	\N	Garden Key, Dry Tortugas	FL
97082	Shark River entrance, Florida	NOS	8724769	25.345	-81.1267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95163	01:45:00	\N	0.98	00:57:00	\N	1.43	\N	\N	Shark River entrance	FL
97083	Lostmans River entrance, Florida	NOS	8724842	25.5533	-81.2133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95163	01:59:00	\N	0.98	01:09:00	\N	1.33	\N	\N	Lostmans River entrance	FL
97084	Onion Key, Lostmans River, Florida	NOS	8724863	25.6117	-81.1333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95163	04:53:00	\N	0.16	03:09:00	\N	0.26	\N	\N	Onion Key, Lostmans River	FL
97085	Chatham River entrance, Florida	NOS	8724891	25.69	-81.285	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95163	01:53:00	\N	0.66	00:59:00	\N	1.43	\N	\N	Chatham River entrance	FL
97086	Chokoloskee, Florida	NOS	8724919	25.8133	-81.3633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95163	03:14:00	\N	0.62	02:15:00	\N	1.11	\N	\N	Chokoloskee	FL
97087	Indian Key, Ten Thousand Islands, Florida	NOS	8724932	25.799999237060547	-81.4666976928711	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95163	01:19:00	\N	0.98	00:55:00	\N	1.48	\N	\N	Indian Key	FL
97088	Cape Romano, Florida	NOS	8724947	25.8533	-81.675	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95163	01:04:00	\N	0.98	00:43:00	\N	1.19	\N	\N	Cape Romano	FL
97089	Everglades City, Barron River, Florida	NOS	8724948	25.8583	-81.3867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95163	03:26:00	\N	0.57	02:25:00	\N	0.99	\N	\N	Everglades City, Barron River	FL
97090	Naples, Naples Bay, north end, Florida	NOS	8725114	26.1367	-81.7883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95163	00:56:00	\N	0.9	00:43:00	\N	0.97	\N	\N	Naples, Naples Bay, north end	FL
97091	Cocohatchee River, US 41 bridge, Florida	NOS	8725228	26.2817	-81.8017	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95163	01:28:00	\N	0.65	01:10:00	\N	0.74	\N	\N	Cocohatchee River, U.S. 41 bridge	FL
97092	Wiggins Pass, Cocohatchee River, Florida	NOS	8725235	26.29	-81.8183	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95163	00:59:00	\N	0.73	00:44:00	\N	0.77	\N	\N	Wiggins Pass, Cocohatchee River	FL
97093	Little Hickory Island, Estero Bay, Florida (sub)	NOS	8725283	26.3533	-81.855	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-01:05:00	\N	1.09	-00:58:00	\N	1.09	\N	\N	Little Hickory Island	FL
97094	Estero River, Estero Bay, Florida	NOS	8725346	26.43	-81.8567	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-00:10:00	\N	1.11	-00:45:00	\N	1.09	\N	\N	Estero River	FL
97095	Matanzas Pass (fixed bridge) Estero Island, Florida	NOS	8725366	26.4567	-81.9533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-01:34:00	\N	1.22	-01:10:00	\N	1.22	\N	\N	Matanzas Pass (fixed bridge) Estero Island	FL
97096	Captiva Island (outside), Florida	NOS	8725383	26.4783	-82.1833	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-02:28:00	\N	1.13	-02:20:00	\N	1.13	\N	\N	Captiva Island (outside)	FL
97097	St. James City, Pine Island, Florida (sub)	NOS	8725393	26.4917	-82.0817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-00:44:00	\N	1.04	-00:30:00	\N	1.04	\N	\N	St. James City, Pine Island	FL
97098	Galt Island, Pine Island Sound, Florida	NOS	8725411	26.5133	-82.1067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	00:16:00	\N	0.91	-00:25:00	\N	0.91	\N	\N	Galt Island, Pine Island Sound	FL
97099	Captiva Island, Pine Island Sound, Florida	NOS	8725417	26.5217	-82.1883	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-00:20:00	\N	0.91	-00:46:00	\N	0.91	\N	\N	Captiva Island, Pine Island Sound	FL
97100	Iona Shores, Caloosahatchee River, Florida	NOS	8725418	26.5217	-81.965	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	01:40:00	\N	0.43	01:08:00	\N	0.43	\N	\N	Iona Shores	FL
97101	Tropical Homesites Landing, Pine Island, Florida	NOS	8725439	26.5483	-82.08	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	00:22:00	\N	0.87	-00:08:00	\N	0.87	\N	\N	Tropical Homesites Landing, Pine Island	FL
97102	Redfish Pass, Captiva Island (north end), Florida	NOS	8725441	26.55	-82.1967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-01:14:00	\N	0.91	-00:55:00	\N	0.91	\N	\N	Redfish Pass, Captiva Island (north end)	FL
97103	Matlacha Pass (bascule bridge), Florida (sub)	NOS	8725506	26.63222222222222	-82.06916666666666	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	01:28:00	\N	0.83	00:43:00	\N	0.83	\N	\N	Matlacha Pass (bascule bridge)	FL
97104	Pineland, Pine Island, Florida	NOS	8725528	26.66	-82.155	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	00:26:00	\N	0.83	-00:19:00	\N	0.83	\N	\N	Pineland, Pine Island	FL
97105	Placida, Gasparilla Sound, Florida	NOS	8725667	26.8333	-82.265	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-00:56:00	\N	0.94	-00:43:00	\N	0.59	\N	\N	Placida, Gasparilla Sound	FL
97106	Punta Gorda, Charlotte Harbor, Florida	NOS	8725744	26.9283	-82.065	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	01:27:00	\N	0.83	01:06:00	\N	0.83	\N	\N	Punta Gorda, Charlotte Harbor	FL
97107	Englewood, Lemon Bay, Florida	NOS	8725747	26.9333	-82.3533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-00:17:00	\N	0.82	-00:17:00	\N	0.66	\N	\N	Englewood, Lemon Bay	FL
97108	El Jobean, Myakka River, Florida	NOS	8725769	26.9617	-82.21	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	01:56:00	\N	0.83	01:38:00	\N	0.83	\N	\N	El Jobean, Myakka River	FL
97109	Venice Inlet (inside), Florida	NOS	8725889	27.1117	-82.4633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-01:38:00	\N	0.91	-02:02:00	\N	0.91	\N	\N	Venice Inlet (inside)	FL
97110	Sarasota, Sarasota Bay, Florida	NOS	8726083	27.3317	-82.545	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-00:58:00	\N	0.91	-01:38:00	\N	0.91	\N	\N	Sarasota, Sarasota Bay	FL
97111	Cortez, Sarasota Bay, Florida	NOS	8726217	27.4667	-82.6867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-01:25:00	\N	0.96	-02:00:00	\N	0.96	\N	\N	Cortez, Sarasota Bay	FL
97112	Anna Maria Key, Bradenton Beach, Florida	NOS	8726243	27.4967	-82.7133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-03:32:00	\N	1	-02:27:00	\N	0.99	\N	\N	Anna Maria Key, Bradenton Beach	FL
97113	Bradenton, Manatee River, Florida	NOS	8726247	27.5	-82.5733	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-00:55:00	\N	0.95	-01:24:00	\N	0.97	\N	\N	Bradenton, Manatee River	FL
97114	Redfish Point, Manatee River, Florida	NOS	8726278	27.5267	-82.4817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	00:14:00	\N	1	-00:30:00	\N	0.92	\N	\N	Redfish Point, Manatee River	FL
97115	Anna Maria Key, city pier, Florida	NOS	8726282	27.5333	-82.73	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-02:19:00	\N	0.99	-02:10:00	\N	0.99	\N	\N	Anna Maria Key, city pier	FL
97116	Point Pinellas, Florida	NOS	8726454	27.7017	-82.64	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-00:29:00	\N	0.86	-00:22:00	\N	0.86	\N	\N	Point Pinellas	FL
97117	Shell Point, Florida	NOS	8726468	27.7183	-82.48	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	00:17:00	\N	0.91	00:08:00	\N	0.91	\N	\N	Shell Point	FL
97118	Gulfport, Boca Ciega Bay, Florida	NOS	8726486	27.7367	-82.7067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-01:05:00	\N	0.96	-01:32:00	\N	0.96	\N	\N	Gulfport	FL
97119	Long Key, 0.5 mi N. of Corey Causeway, Boca Ciega Bay, Florida	NOS	8726494	27.7517	-82.7533	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-00:44:00	\N	1	-01:18:00	\N	0.92	\N	\N	Long Key, 0.5mi N. of Corey Causeway	FL
97120	Johns Pass, Boca Ciega Bay, Florida	NOS	8726533	27.785	-82.7817	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-02:04:00	\N	1.02	-02:14:00	\N	0.97	\N	\N	Johns Pass	FL
97121	Apollo Beach, Hillsborough Bay, Tampa Bay, Florida	NOS	8726537	27.786699295043945	-82.42669677734375	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	00:32:00	\N	1.2	00:53:00	\N	1.1	\N	\N	APOLLO BEACH, HILLSBOROUGH BAY	FL
97122	Madeira Beach Causeway, Boca Ciega Bay, Florida	NOS	8726574	27.8083	-82.795	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-01:45:00	\N	1.18	-01:32:00	\N	1.08	\N	\N	Madeira Beach Causeway	FL
97123	Indian Rocks Beach (inside), Florida	NOS	8726625	27.8767	-82.85	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	-00:53:00	\N	0.63	-00:57:00	\N	0.65	\N	\N	Indian Rocks Beach (inside)	FL
97124	Gandy Bridge, Old Tampa Bay, Florida	NOS	8726641	27.8933	-82.5383	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	00:57:00	\N	1.24	00:59:00	\N	1.12	\N	\N	Gandy Bridge, Old Tampa Bay	FL
97125	Pendola Point, Hillsborough Bay, Florida	NOS	8726651	27.8983	-82.4267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	00:05:00	\N	1.18	00:21:00	\N	1.14	\N	\N	Pendola Point, Hillsborough Bay	FL
97126	Davis Island, Hillsborough Bay, Florida	NOS	8726657	27.9083	-82.4517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	00:32:00	\N	1.24	00:03:00	\N	1.16	\N	\N	Davis Island, Hillsborough Bay	FL
97127	Bay Aristocrat Village, Old Tampa Bay, Florida	NOS	8726689	27.9417	-82.72	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	01:32:00	\N	1.37	01:01:00	\N	1.24	\N	\N	Bay Aristocrat Village, Old Tampa Bay	FL
97128	Clearwater, Florida	NOS	8726706	27.955	-82.8067	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	-01:35:00	\N	0.63	-01:48:00	\N	0.65	\N	\N	Clearwater	FL
97129	Dunedin, St. Joseph Sound, Florida	NOS	8726761	28.0133	-82.7933	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	-01:45:00	\N	0.79	-01:50:00	\N	0.7	\N	\N	Dunedin, St. Joseph Sound	FL
97130	Mobbly Bayou, Florida	NOS	8726769	28.0217	-82.655	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	02:54:00	\N	0.45	02:38:00	\N	0.71	\N	\N	Mobbly Bayou	FL
97131	Tarpon Springs, Anclote River, Florida	NOS	8726905	28.16	-82.7683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	-01:03:00	\N	0.83	-01:16:00	\N	0.77	\N	\N	Tarpon Springs, Anclote River	FL
97132	Anclote, Anclote River, Florida	NOS	8726924	28.1717	-82.785	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	-01:24:00	\N	0.87	-01:28:00	\N	0.78	\N	\N	Anclote, Anclote River	FL
97133	North Anclote Key, Florida	NOS	8726942	28.21	-82.84	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	-01:38:00	\N	0.86	-01:55:00	\N	0.8	\N	\N	North Anclote Key	FL
97134	Gulf Harbors, Florida	NOS	8726995	28.2433	-82.7633	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	-00:52:00	\N	0.9	-01:15:00	\N	0.84	\N	\N	Gulf Harbors	FL
97135	New Port Richey, Pithlachascotee River, Florida	NOS	8727001	28.2483	-82.7233	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	-00:11:00	\N	0.87	-00:58:00	\N	0.88	\N	\N	New Port Richey, Pithlachascotee River	FL
97136	Hwy. 19 bridge, Pithlachascotee River, Florida	NOS	8727012	28.2683	-82.7267	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	-00:40:00	\N	0.84	-01:16:00	\N	0.85	\N	\N	Hwy. 19 bridge, Pithlachascotee River	FL
97137	Hudson, Hudson Creek, Florida	NOS	8727061	28.3617	-82.71	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	-01:02:00	\N	0.89	-01:12:00	\N	0.91	\N	\N	Hudson, Hudson Creek	FL
97138	Aripeka, Hammock Creek, Florida	NOS	8727097	28.4333	-82.6683	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	00:23:00	\N	0.63	-00:37:00	\N	0.81	\N	\N	Aripeka, Hammock Creek	FL
97139	Hernando Beach, Rocky Creek, Little Pine I. Bay, Florida	NOS	8727122	28.4867	-82.6617	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	00:58:00	\N	0.83	-00:20:00	\N	0.83	\N	\N	Hernando Beach, Rocky Creek, Little Pine I. Bay	FL
97140	Florida Power, Crystal River, Florida	NOS	8727386	28.96	-82.725	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	00:30:00	\N	0.89	-00:03:00	\N	1.04	\N	\N	Florida Power	FL
97141	Withlacoochee River entrance, Florida	NOS	8727395	29.0017	-82.7583	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	00:55:00	\N	0.95	00:07:00	\N	0.91	\N	\N	Withlacoochee River entrance	FL
97142	Suwannee, Salt Creek, Florida	NOS	8727577	29.3283	-83.1517	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	00:24:00	\N	0.83	-00:07:00	\N	0.91	\N	\N	Suwannee, Salt Creek	FL
97143	Steinhatchee River ent., Deadman Bay, Florida	NOS	8727695	29.6717	-83.39	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	00:00:00	\N	1.08	00:02:00	\N	1.03	\N	\N	Steinhatchee River ent., Deadman Bay	FL
97144	Mandalay, Aucilla River, Apalachee Bay, Florida	NOS	8727989	30.1267	-83.975	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95220	00:57:00	\N	0.55	00:25:00	\N	0.69	\N	\N	Mandalay, Aucilla River	FL
97145	St. Marks, St. Marks River, Apalachee Bay, Florida	NOS	8728142	30.1533	-84.2033	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95220	01:04:00	\N	0.91	00:36:00	\N	0.93	\N	\N	St. Marks, St. Marks River	FL
97146	Bald Point, Ochlockonee Bay, Apalachee Bay, Florida	NOS	8728237	29.9483	-84.3417	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95220	00:19:00	\N	0.7	00:33:00	\N	0.85	\N	\N	Bald Point, Ochlockonee Bay	FL
97147	Panacea, Dickerson Bay, Apalachee Bay, Florida	NOS	8728269	30.02611111111111	-84.38588888888889	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95220	00:20:00	\N	0.82	00:16:00	\N	1.01	\N	\N	Panacea, Dickerson Bay	FL
97148	Alligator Point, St. James Island, Apalachee Bay, Florida	NOS	8728288	29.9033	-84.4133	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95220	00:11:00	\N	0.73	-00:08:00	\N	0.75	\N	\N	Alligator Point, St. James Island	FL
97149	Carrabelle, Carrabelle River, St. George Sound, Florida (sub)	NOS	8728464	29.85	-84.665	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95234	-02:13:00	\N	1.6	-01:25:00	\N	1.6	\N	\N	Carrabelle, Carrabelle River	FL
97150	Dog Island, west end, St. George Sound, Florida	NOS	8728465	29.785	-84.6667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95234	-02:38:00	\N	1.4	-01:53:00	\N	1.73	\N	\N	Dog Island, west end	FL
97151	St. George Island, east end, St. George Sound, Florida	NOS	8728548	29.6867	-84.7867	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95234	-02:48:00	\N	1	-02:02:00	\N	1.13	\N	\N	St. George Island, East End	FL
97152	St. George Island, Rattlesnake Cove, St. George Sound, Florida	NOS	8728552	29.6917	-84.7917	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95234	-01:35:00	\N	1.2	-01:00:00	\N	1.33	\N	\N	St. George Island, Rattlesnake Cove	FL
97153	Cat Point, Apalachicola Bay, Florida (sub)	NOS	8728619	29.72361111111111	-84.88666666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95234	-01:17:00	\N	0.6	-00:40:00	\N	1.07	\N	\N	Cat Point	FL
97154	St. George Island, 12th St. W (bayside), St. George Sound, Florida (sub)	NOS	8728626	29.6533	-84.8967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95234	-01:08:00	\N	1.26	-00:55:00	\N	1.26	\N	\N	St. George Island, 12th St. W (Bayside)	FL
97155	Apalachicola River (A&N RR bridge), Apalachicola Bay, Florida (sub)	NOS	8728711	29.7633	-85.0333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95234	00:35:00	\N	0.83	00:28:00	\N	0.85	\N	\N	Apalachicola River (A&N RR bridge)	FL
97156	West Pass, Apalachicola Bay, Florida	NOS	8728766	29.6333	-85.0967	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95234	-00:27:00	\N	1	-00:27:00	\N	0.87	\N	\N	West Pass	FL
97157	Wetappo Creek, East Bay, St. Andrew Bay, Florida	NOS	8728973	30.0383	-85.3933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95274	01:40:00	\N	1.1	01:01:00	\N	1.1	\N	\N	Wetappo Creek, East Bay	FL
97158	Allanton, East Bay, St. Andrew Bay, Florida	NOS	8729015	30.03	-85.465	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95274	-01:01:00	\N	1.15	-00:16:00	\N	1.15	\N	\N	Allanton, East Bay	FL
97159	Farmdale, East Bay, St. Andrew Bay, Florida	NOS	8729017	30.0167	-85.47	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95274	-00:59:00	\N	1.17	-00:16:00	\N	1.17	\N	\N	Farmdale, East Bay	FL
97160	Laird Bayou, East Bay, St. Andrew Bay, Florida	NOS	8729045	30.1217	-85.5283	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95274	-01:05:00	\N	1.13	-00:28:00	\N	1.13	\N	\N	Laird Bayou, East Bay	FL
97161	Parker, St. Andrew Bay, Florida	NOS	8729084	30.1267	-85.6117	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95274	00:22:00	\N	1.2	-00:05:00	\N	1.2	\N	\N	Parker	FL
97162	Lynn Haven, North Bay, St. Andrew Bay, Florida	NOS	8729102	30.255	-85.6483	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95274	-01:01:00	\N	1.1	-00:31:00	\N	1.1	\N	\N	Lynn Haven, North Bay	FL
97163	Channel entrance, St. Andrew Bay, Florida	NOS	8729136	30.125	-85.73	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95274	-01:50:00	\N	1.02	-01:39:00	\N	1.02	\N	\N	Channel entrance	FL
97164	Alligator Bayou, St. Andrew Bay, Florida	NOS	8729152	30.17	-85.755	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95274	-01:10:00	\N	1.07	-00:47:00	\N	1.07	\N	\N	Alligator Bayou	FL
97165	East Pass (Destin), Choctawhatchee Bay, Florida	NOS	8729511	30.395	-86.5133	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95274	-00:34:00	\N	0.33	-00:33:00	\N	0.49	\N	\N	East Pass (Destin)	FL
97166	Shalimar, Garnier Bayou, Choctawhatchee Bay, Florida	NOS	8729538	30.435	-86.5867	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95274	03:03:00	\N	0.32	03:33:00	\N	0.32	\N	\N	Shalimar, Garnier Bayou	FL
97167	Harris, The Narrows, Florida	NOS	8729613	30.4083	-86.7317	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95274	02:51:00	\N	1.1	01:37:00	\N	1.1	\N	\N	Harris, The Narrows	FL
97168	Bay Point, Blackwater River, Pensacola Bay, Florida	NOS	8729742	30.5717	-87.005	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95274	01:27:00	\N	1.2	01:23:00	\N	1.2	\N	\N	Bay Point, Blackwater River	FL
97169	Warrington, 2 mi south of, Pensacola Bay, Florida	NOS	8729868	30.345	-87.2733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95274	-00:30:00	\N	1	-00:27:00	\N	1	\N	\N	Warrington, 2 miles south of	FL
97170	Fort McRee Breakwater, Pensacola Bay, Florida	NOS	8729887	30.3267	-87.3117	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95274	-00:34:00	\N	0.8	-01:23:00	\N	0.8	\N	\N	Fort McRee Breakwater	FL
97171	Nix Point, Perdido Bay, Florida	NOS	8729962	30.3933	-87.425	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95274	03:37:00	\N	0.33	02:29:00	\N	0.57	\N	\N	Nix Point, Perdido Bay	FL
97172	Bon Secour, Bon Secour River, Alabama	NOS	8731952	30.3033	-87.735	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95292	-01:17:00	\N	1.07	-01:13:00	\N	1.07	\N	\N	Bon Secour, Bon Secour River	AL
97173	Mobile Point (Fort Morgan), Alabama	NOS	8734635	30.2333	-88.02	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95292	-01:32:00	\N	0.8	-01:46:00	\N	0.8	\N	\N	Mobile Point (Fort Morgan)	AL
97174	Lower Hall Landing, Tensaw River, Alabama	NOS	8737182	30.8183	-87.915	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95292	03:05:00	\N	0.87	02:16:00	\N	0.87	\N	\N	Lower Hall Landing, Tensaw River	AL
97175	Bayou La Batre, Mississippi Sound, Alabama	NOS	8739051	30.3717	-88.275	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	01:14:00	\N	1.23	01:52:00	\N	1.23	\N	\N	Bayou La Batre, Mississippi Sound	AL
97176	Point of Pines, Bayou Cumbest, Mississippi	NOS	8740448	30.3867	-88.44	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	01:09:00	\N	1.25	01:49:00	\N	1.25	\N	\N	Point of Pines, Bayou Cumbest	MS
97177	Hollingsworth Point, Davis Bayou, Mississippi (sub)	NOS	8743081	30.3867	-88.7733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	01:52:00	\N	1.42	02:24:00	\N	1.42	\N	\N	Hollingsworth Point, Davis Bayou	MS
97178	Biloxi (Cadet Point), Biloxi Bay, Mississippi (sub)	NOS	8743735	30.39	-88.8567	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	01:30:00	\N	1.38	02:04:00	\N	1.38	\N	\N	Biloxi (Cadet Point), Biloxi Bay	MS
97179	Turkey Creek, Bernard Bayou, Mississippi	NOS	8745375	30.4267	-89.0533	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	02:27:00	\N	1.54	03:23:00	\N	1.54	\N	\N	Turkey Creek, Bernard Bayou	MS
97180	Cat Island, Mississippi	NOS	8745799	30.2317	-89.1167	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	02:00:00	\N	1.23	02:13:00	\N	1.23	\N	\N	Cat Island	MS
97181	Pass Christian Yacht Club, Mississippi Sound, Mississippi (sub)	NOS	8746819	30.31	-89.245	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	02:04:00	\N	1.37	02:36:00	\N	1.37	\N	\N	Pass Christian Yacht Club, Mississippi Sound	MS
97182	Wolf River, Henderson Avenue bridge, Mississippi	NOS	8748038	30.358333333332993	-89.27333333333299	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	02:51:00	\N	1.36	03:18:00	\N	1.36	\N	\N	Wolf River, Henderson Avenue bridge	MS
97183	Pearlington, Pearl River, Mississippi	NOS	8749704	30.24	-89.615	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	05:31:00	\N	0.99	05:51:00	\N	0.99	\N	\N	Pearlington, Pearl River	MS
97184	Chandeleur Light, Louisiana	NOS	8760172	30.0483	-88.8717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	01:54:00	\N	0.98	01:50:00	\N	0.98	\N	\N	Chandeleur Light	LA
97185	North Pass, Mississippi River, Louisiana	NOS	8760412	29.205	-89.0367	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	00:43:00	\N	0.91	00:42:00	\N	0.91	\N	\N	North Pass, Pass a Loutre	LA
97186	Southeast Pass, Mississippi River, Louisiana	NOS	8760416	29.1167	-89.045	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	-00:28:00	\N	0.98	00:37:00	\N	0.98	\N	\N	Southeast Pass	LA
97187	Lonesome Bayou (Thomasin), Louisiana	NOS	8760424	29.2283	-89.05	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	-00:29:00	\N	0.9	00:34:00	\N	0.9	\N	\N	Lonesome Bayou (Thomasin)	LA
97188	Port Eads, South Pass, Mississippi River, Louisiana	NOS	8760579	29.015	-89.16	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	-00:17:00	\N	0.9	00:56:00	\N	0.9	\N	\N	Port Eads, South Pass	LA
97189	Breton Islands, Louisiana	NOS	8760595	29.4933	-89.1733	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	02:08:00	\N	1.14	02:07:00	\N	1.14	\N	\N	Breton Islands	LA
97190	Joseph Bayou, Mississippi River, Louisiana	NOS	8760736	29.0583	-89.2717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	-00:17:00	\N	1.15	00:37:00	\N	1.15	\N	\N	Joseph Bayou	LA
97191	Comfort Island, Louisiana	NOS	8760742	29.8233	-89.27	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	02:14:00	\N	1.28	02:47:00	\N	1.28	\N	\N	Comfort Island	LA
97192	Jack Bay, Louisiana	NOS	8760841	29.3667	-89.345	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	02:48:00	\N	1	03:12:00	\N	1	\N	\N	Jack Bay	LA
97193	Southwest Pass, Mississippi River, Louisiana	NOS	8760959	28.9317	-89.4283	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	-00:13:00	\N	1.07	00:35:00	\N	1.07	\N	\N	Southwest Pass	LA
97194	Bay Gardene, Louisiana	NOS	8761108	29.5983	-89.6183	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	04:04:00	\N	1.16	04:04:00	\N	1.16	\N	\N	Bay Gardene	LA
97195	Empire Jetty, Louisiana	NOS	8761212	29.25	-89.6083	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95341	-01:45:00	\N	1.23	-01:03:00	\N	1.23	\N	\N	Empire Jetty	LA
97196	Bastian Island, Louisiana	NOS	8761289	29.2867	-89.6633	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95341	00:12:00	\N	1.13	00:41:00	\N	1.13	\N	\N	Bastian Island	LA
97197	Bayou BonFouca, Route 433, Louisiana	NOS	8761473	30.2717	-89.7933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	11:31:00	\N	0.43	11:12:00	\N	0.43	\N	\N	Bayou BonFouca, Route 433	LA
97198	Chef Menteur, Chef Menteur Pass, Louisiana	NOS	8761487	30.065	-89.8	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	06:27:00	\N	0.88	06:25:00	\N	0.88	\N	\N	Chef Menteur, Chef Menteur Pass	LA
97199	Quatre Bayous Pass, Louisiana	NOS	8761557	29.31	-89.8533	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95341	00:17:00	\N	1.23	02:18:00	\N	1.23	\N	\N	Quatre Bayous Pass	LA
97200	Independence Island, Barataria Bay, Louisiana	NOS	8761677	29.31	-89.9383	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95341	01:59:00	\N	0.85	02:29:00	\N	0.85	\N	\N	Independence Island	LA
97201	Michoud Substation, ICWW, Louisiana	NOS	8761678	30.0067	-89.9367	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	06:22:00	\N	1.09	06:37:00	\N	1.09	\N	\N	Michoud Substation, ICWW	LA
97202	Barataria Pass, Louisiana	NOS	8761687	29.275	-89.945	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95341	-00:10:00	\N	1.13	01:00:00	\N	1.13	\N	\N	Barataria Pass	LA
97203	Manilla, Barataria Bay, Louisiana	NOS	8761732	29.4267	-89.9767	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95341	03:13:00	\N	0.94	02:32:00	\N	0.94	\N	\N	Manilla	LA
97204	Tchefuncta River, Lake Pontchartrain, Louisiana	NOS	8761993	30.3783	-90.16	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95329	12:21:00	\N	0.48	11:36:00	\N	0.48	\N	\N	Tchefuncta River, Lake Pontchartrain	LA
97205	Pelican Islands, Timbalier Bay, Louisiana	NOS	8762481	29.1283	-90.4233	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95341	02:26:00	\N	1.13	02:26:00	\N	1.13	\N	\N	Pelican Islands, Timbalier Bay	LA
97206	Timbalier Island, Timbalier Bay, Louisiana	NOS	8762675	29.0867	-90.5267	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95341	00:23:00	\N	1.13	00:19:00	\N	1.13	\N	\N	Timbalier Island, Timbalier Bay	LA
97207	Wine Island, Terrebonne Bay, Louisiana	NOS	8762850	29.0783	-90.5867	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95341	01:02:00	\N	1.23	01:08:00	\N	1.23	\N	\N	Wine Island, Terrebonne Bay	LA
97208	Caillou Boca, Louisiana	NOS	8763206	29.0633	-90.8067	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95341	00:48:00	\N	1.32	00:40:00	\N	1.32	\N	\N	Caillou Boca	LA
97209	Raccoon Point, Caillou Bay, Louisiana	NOS	8763506	29.0633	-90.9617	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95341	-00:20:00	\N	1.6	-00:03:00	\N	1.6	\N	\N	Raccoon Point, Caillou Bay	LA
97210	Ship Shoal Light, Louisiana	NOS	8763719	28.915	-91.0717	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95341	-01:50:00	\N	1.51	-01:54:00	\N	1.51	\N	\N	Ship Shoal Light	LA
97211	Shell Island, Atchafalaya Bay, Louisiana	NOS	8764165	29.4733	-91.305	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95408	-00:39:00	\N	1.07	00:54:00	\N	1.07	\N	\N	Shell Island	LA
97212	Point Au Fer, Atchafalaya Bay, Louisiana	NOS	8764256	29.3333	-91.3533	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95408	-02:26:00	\N	1.4	-00:21:00	\N	1.4	\N	\N	Point Au Fer	LA
97213	Point Chevreuil, Atchafalaya Bay, Louisiana	NOS	8764634	29.5183	-91.555	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95408	-00:54:00	\N	1.07	01:02:00	\N	1.07	\N	\N	Point Chevreuil	LA
97214	Rabbit Island, 5 mi south of, Atchafalaya Bay, Louisiana	NOS	8764706	29.42	-91.5933	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95408	-02:00:00	\N	1.4	-00:13:00	\N	1.4	\N	\N	Rabbit Island, 5 miles south of	LA
97215	Cote Blanche Island, West Cote Blanche Bay, Louisiana	NOS	8764931	29.735	-91.7133	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95408	02:16:00	\N	1	02:19:00	\N	1	\N	\N	Cote Blanche Island, West Cote Blanche Bay	LA
97216	South Point, Marsh Island, Louisiana	NOS	8765026	29.485	-91.7633	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95408	-01:57:00	\N	1.3	-00:19:00	\N	1.3	\N	\N	South Point, Marsh Island	LA
97217	Southwest Pass, Vermilion Bay, Louisiana	NOS	8765551	29.58	-92.035	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95408	-00:33:00	\N	1.14	-00:32:00	\N	1.14	\N	\N	Southwest Pass, Vermilion Bay	LA
97218	Lighthouse Point, off Marsh Island, Louisiana	NOS	8765568	29.5233	-92.0433	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95408	-02:17:00	\N	1.4	-01:16:00	\N	1.4	\N	\N	Lighthouse Point	LA
97219	Point Barrow, Trinity Bay, Galveston Bay, Texas	NOS	8770557	29.74	-94.8317	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95408	04:43:00	\N	0.79	05:48:00	\N	0.79	\N	\N	Point Barrow, Trinity Bay	TX
97220	Alligator Point, West Bay, Texas	NOS	8771801	29.1667	-95.125	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95408	02:33:00	\N	0.64	02:39:00	\N	0.64	\N	\N	Alligator Point, West Bay	TX
97221	Christmas Bay, Texas	NOS	8772132	29.0417	-95.175	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95408	02:37:00	\N	0.23	04:47:00	\N	0.58	\N	\N	Christmas Bay	TX
97222	Queen Isabella Causeway (east end), Texas	NOS	8779724	26.0783	-97.17	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95448	00:21:00	\N	0.75	00:24:00	\N	0.87	\N	\N	Queen Isabella Causeway (east end)	TX
97223	Queen Isabella Causeway (west end), Texas	NOS	8779739	26.0717	-97.1917	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95448	00:30:00	\N	0.63	00:52:00	\N	0.81	\N	\N	Queen Isabella Causeway (west end)	TX
97224	South Bay entrance, Texas	NOS	8779768	26.0517	-97.1817	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95448	00:21:00	\N	0.94	00:14:00	\N	0.91	\N	\N	South Bay entrance	TX
97225	San Nicolas Island, California	NOS	9410068	33.2667	-119.497	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	00:21:00	\N	0.88	00:10:00	\N	0.88	\N	\N	San Nicolas Island	CA
97226	Catalina Harbor, Santa Catalina Island, California	NOS	9410092	33.4317	-118.503	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	00:17:00	\N	0.94	00:11:00	\N	0.94	\N	\N	Catalina Harbor, Santa Catalina Island	CA
97227	Imperial Beach, California	NOS	9410120	32.5783	-117.135	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95455	-00:03:00	\N	0.96	00:00:00	\N	0.93	\N	\N	Imperial Beach	CA
97228	National City, San Diego Bay, California	NOS	9410152	32.665	-117.118	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95455	00:10:00	0	\N	00:04:00	0.2	\N	\N	\N	National City, San Diego Bay	CA
97229	San Diego, Quarantine Station, California	NOS	9410166	32.7033	-117.235	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95455	00:02:00	\N	0.96	-00:04:00	\N	0.96	\N	\N	San Diego, Quarantine Station	CA
97230	Balboa Pier, Newport Beach, California	NOS	9410583	33.6	-117.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	00:00:00	\N	0.96	-00:09:00	\N	0.96	\N	\N	Balboa Pier, Newport Beach	CA
97231	Santa Ana River entrance (inside), California	NOS	9410599	33.63	-117.958	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	01:47:00	\N	0.2	00:23:00	\N	0.54	\N	\N	Santa Ana River entrance (inside)	CA
97232	Cabrillo Beach, California	NOS	9410650	33.7067	-118.273	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	00:00:00	\N	1	00:00:00	\N	1	\N	\N	Cabrillo Beach	CA
97233	Long Beach, Inner Harbor, California	NOS	9410686	33.7717	-118.21	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	00:05:00	\N	0.96	00:04:00	\N	0.96	\N	\N	Long Beach, Inner Harbor	CA
97234	King Harbor, Santa Monica Bay, California	NOS	9410738	33.8467	-118.398	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	00:07:00	\N	1	00:08:00	\N	0.96	\N	\N	King Harbor, Santa Monica Bay	CA
97235	El Segundo, Santa Monica Bay, California	NOS	9410777	33.9083	-118.433	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	00:13:00	\N	0.96	00:13:00	\N	0.96	\N	\N	El Segundo, Santa Monica Bay	CA
97236	Bechers Bay, Santa Rosa Island, California	NOS	9410962	34.0083	-120.047	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	00:27:00	\N	1.03	00:27:00	\N	0.93	\N	\N	Bechers Bay, Santa Rosa Island	CA
97237	Prisoners Harbor, Santa Cruz Island, California	NOS	9410971	34.02	-119.683	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	00:18:00	\N	1.01	00:19:00	\N	0.94	\N	\N	Prisoners Harbor, Santa Cruz Island	CA
97238	Cuyler Harbor, San Miguel Island, California	NOS	9410988	34.0567	-120.355	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	00:34:00	\N	0.94	00:33:00	\N	0.94	\N	\N	Cuyler Harbor, San Miguel Island	CA
97239	Port Hueneme, California	NOS	9411065	34.1483	-119.203	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	00:13:00	0	\N	00:10:00	-0.1	\N	\N	\N	Port Hueneme	CA
97240	Ventura, California	NOS	9411189	34.2667	-119.283	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	00:16:00	0	\N	00:09:00	-0.1	\N	\N	\N	Ventura	CA
97241	Rincon Island, Mussel Shoals, Santa Barbara Channel, California (sub)	NOS	9411270	34.3483	-119.443	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	00:18:00	\N	1.05	00:20:00	\N	0.99	\N	\N	Rincon Island, Mussel Shoals	CA
97242	San Simeon, California	NOS	9412553	35.6417	-121.188	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95466	00:07:00	\N	1	00:08:00	\N	0.99	\N	\N	San Simeon	CA
97243	Carmel Cove, Carmel Bay, California	NOS	9413375	36.52	-121.94	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95468	-00:04:00	\N	0.99	-00:03:00	\N	0.97	\N	\N	Carmel Cove, Carmel Bay	CA
97244	Ocean Pier, Moss Landing, Monterey Bay, California	NOS	9413616	36.8017	-121.79	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95468	-00:01:00	\N	0.9	-00:01:00	\N	0.95	\N	\N	Moss Landing, Ocean Pier	CA
97245	General Fish Company Pier, Moss Landing, Monterey Bay, California	NOS	9413617	36.8017	-121.787	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95468	00:01:00	\N	0.95	00:01:00	\N	0.98	\N	\N	General Fish Company Pier	CA
97246	Elkhorn Slough, Highway 1 Bridge, Monterey Bay, California	NOS	9413623	36.81	-121.785	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95468	-00:02:00	\N	0.9	00:03:00	\N	0.95	\N	\N	Elkhorn Slough, Highway 1 Bridge	CA
97247	Pacific Mariculture Dock, Monterey Bay, California	NOS	9413624	36.8133	-121.758	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95468	00:07:00	\N	0.98	00:15:00	\N	1	\N	\N	Pacific Mariculture Dock	CA
97248	Elkhorn Yacht Club, Monterey Bay, California	NOS	9413626	36.8133	-121.787	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95468	00:02:00	\N	0.95	00:00:00	\N	0.97	\N	\N	Elkhorn Yacht Club	CA
97249	Santa Cruz, Monterey Bay, California	NOS	9413745	36.9583	-122.017	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95468	-00:11:00	\N	0.99	-00:06:00	\N	0.97	\N	\N	Santa Cruz, Monterey Bay	CA
97250	Ano Nuevo Island, California	NOS	9413878	37.1083	-122.338	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	-01:04:00	-0.1	\N	-01:24:00	-0.7	\N	\N	\N	Ano Nuevo Island	CA
97251	Southeast Farallon Island, California	NOS	9414262	37.7	-123	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	-00:19:00	0	\N	-00:39:00	-0.3	\N	\N	\N	Southeast Farallon Island	CA
97252	Ocean Beach, outer coast, California	NOS	9414275	37.775	-122.513	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	-00:35:00	0	\N	-00:49:00	0.1	\N	\N	\N	Ocean Beach, outer coast	CA
97253	North Point, Pier 41, San Francisco, San Francisco Bay, California (sub)	NOS	9414305	37.81	-122.413	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:11:00	0	\N	00:13:00	0.2	\N	\N	\N	San Francisco, North Point, Pier 41	CA
97254	Potrero Point, San Francisco Bay, California	NOS	9414334	37.7583	-122.383	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:46:00	0	\N	00:33:00	0.5	\N	\N	\N	Potrero Point	CA
97255	Borden Highway Bridge, San Joaquin River, California	NOS	9414367	37.93666666666701	-121.33333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	04:48:00	\N	0.64	04:28:00	\N	0.78	\N	\N	Borden Highway Bridge, San Joaquin River	CA
97256	South San Francisco, San Francisco Bay, California	NOS	9414391	37.6667	-122.39	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:56:00	0	\N	00:38:00	1.2	\N	\N	\N	South San Francisco	CA
97257	Oyster Point Marina, San Francisco Bay, California (sub)	NOS	9414392	37.665	-122.377	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:00:00	\N	1	00:41:00	\N	1.23	\N	\N	Oyster Point Marina	CA
97258	Point San Bruno, San Francisco Bay, California	NOS	9414402	37.65	-122.377	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:10:00	0.1	\N	00:38:00	1.1	\N	\N	\N	Point San Bruno	CA
97259	Seaplane Harbor, San Francisco Bay, California	NOS	9414413	37.6367	-122.383	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:03:00	0	\N	00:42:00	1.4	\N	\N	\N	Seaplane Harbor	CA
97260	Coyote Point Marina, San Francisco Bay, California	NOS	9414449	37.5917	-122.313	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:08:00	\N	1.01	00:42:00	\N	1.29	\N	\N	Coyote Point Marina	CA
97261	Bay Slough, west end, San Francisco Bay, California	NOS	9414483	37.5517	-122.243	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:28:00	\N	1	00:48:00	\N	1.35	\N	\N	Bay Slough, west end	CA
97262	Bay Slough, east end, San Francisco Bay, California	NOS	9414486	37.545	-122.222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:52:00	\N	0.77	00:49:00	\N	1.27	\N	\N	Bay Slough, east end	CA
97263	Redwood Creek Marker 8, San Francisco Bay, California (sub)	NOS	9414501	37.5333	-122.193	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:28:00	\N	1.05	00:53:00	\N	1.41	\N	\N	Redwood Creek Marker 8	CA
97264	Corkscrew Slough, San Francisco Bay, California	NOS	9414505	37.5083	-122.21	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:42:00	0.1	\N	01:03:00	2.2	\N	\N	\N	Corkscrew Slough	CA
97265	Newark Slough, San Francisco Bay, California	NOS	9414506	37.5133	-122.08	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:58:00	0.1	\N	01:11:00	2.6	\N	\N	\N	Newark Slough	CA
97266	West Point Slough, San Francisco Bay, California	NOS	9414507	37.505	-122.192	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:30:00	\N	1.04	00:56:00	\N	1.44	\N	\N	West Point Slough	CA
97267	Smith Slough, San Francisco Bay, California	NOS	9414511	37.5017	-122.223	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:58:00	0	\N	01:15:00	2.1	\N	\N	\N	Smith Slough	CA
97268	Granite Rock, Redwood Creek, San Francisco Bay, California	NOS	9414513	37.495	-122.213	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:31:00	\N	1.04	00:55:00	\N	1.43	\N	\N	Granite Rock, Redwood Creek	CA
97269	Mowry Slough, San Francisco Bay, California	NOS	9414519	37.4933	-122.042	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	02:07:00	0	\N	01:12:00	2.6	\N	\N	\N	Mowry Slough	CA
97270	Palo Alto Yacht Harbor, San Francisco Bay, California	NOS	9414525	37.4583	-122.105	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	02:14:00	\N	0.68	00:59:00	\N	1.34	\N	\N	Palo Alto Yacht Harbor	CA
97271	Calaveras Point, west of, San Francisco Bay, California	NOS	9414539	37.4667	-122.067	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:49:00	0.1	\N	01:05:00	2.8	\N	\N	\N	Calaveras Point, west of	CA
97272	Upper Guadalupe Slough, San Francisco Bay, California	NOS	9414549	37.435	-122.007	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	02:13:00	\N	1.13	01:14:00	\N	1.66	\N	\N	Upper Guadalupe Slough	CA
97273	Gold Street Bridge, Alviso Slough, San Francisco Bay, California	NOS	9414551	37.4233	-121.975	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	02:21:00	\N	0.96	01:03:00	\N	1.67	\N	\N	Gold Street Bridge, Alviso Slough	CA
97274	Coyote Creek, Tributary No. 1, San Francisco Bay, California	NOS	9414561	37.4467	-121.963	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	02:45:00	-0.3	\N	01:21:00	2.6	\N	\N	\N	Coyote Creek, Tributary no.1	CA
97275	South Bay Wreck, San Francisco Bay, California	NOS	9414609	37.5517	-122.162	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:37:00	0.1	\N	01:02:00	2.2	\N	\N	\N	South Bay Wreck	CA
97276	Coyote Hills Slough entrance, San Francisco Bay, California	NOS	9414621	37.5633	-122.128	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	02:21:00	\N	0.45	00:52:00	\N	1.17	\N	\N	Coyote Hills Slough entrance	CA
97277	Alameda Creek, San Francisco Bay, California	NOS	9414632	37.595	-122.145	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	02:25:00	\N	0.27	00:57:00	\N	1.05	\N	\N	Alameda Creek	CA
97278	San Mateo Bridge (east end), San Francisco Bay, California	NOS	9414637	37.6083	-122.182	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:19:00	0	\N	00:48:00	1.8	\N	\N	\N	San Mateo Bridge (east end)	CA
97279	Oakland Airport, San Francisco Bay, California	NOS	9414711	37.7317	-122.208	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:45:00	\N	0.96	00:40:00	\N	1.15	\N	\N	Oakland Airport	CA
97280	San Leandro Channel, San Leandro Bay, San Francisco Bay, California	NOS	9414724	37.7483	-122.235	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:52:00	\N	0.98	00:42:00	\N	1.16	\N	\N	San Leandro Channel, San Leandro Bay	CA
97281	Oakland Berth 67, San Francisco Bay, California	NOS	9414763	37.795	-122.283	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:42:00	0	\N	00:33:00	0.4	\N	\N	\N	Oakland Harbor, Grove Street	CA
97282	Oakland Pier, San Francisco Bay, California	NOS	9414765	37.795	-122.33	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:48:00	0	\N	00:33:00	0.2	\N	\N	\N	Oakland Pier	CA
97283	Alameda Naval Air Station fuel pier, San Francisco Bay, California (sub)	NOS	9414767	37.7933	-122.315	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:33:00	\N	1	00:24:00	\N	1.11	\N	\N	Alameda Naval Air Station	CA
97284	Oakland Middle Harbor, San Francisco Bay, California	NOS	9414777	37.805	-122.338	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:31:00	\N	0.96	00:21:00	\N	1.07	\N	\N	Oakland Middle Harbor	CA
97285	Oakland, Matson Wharf, San Francisco Bay, California	NOS	9414779	37.81	-122.327	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:36:00	0	\N	00:28:00	0.3	\N	\N	\N	Oakland, Matson Wharf	CA
97286	Yerba Buena Island, San Francisco Bay, California	NOS	9414782	37.81	-122.36	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:33:00	\N	0.99	00:25:00	\N	1.06	\N	\N	Yerba Buena Island	CA
97287	Grant Line Canal (drawbridge), San Joaquin River, California	NOS	9414785	37.82	-121.447	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	06:20:00	\N	0.68	06:14:00	\N	0.76	\N	\N	Grant Line Canal (drawbridge)	CA
97288	Alcatraz Island, San Francisco Bay, California	NOS	9414792	37.8267	-122.417	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:18:00	0	\N	00:14:00	0	\N	\N	\N	Alcatraz Island	CA
97289	Sausalito, San Francisco Bay, California (sub)	NOS	9414806	37.8467	-122.477	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:14:00	\N	1	00:10:00	\N	0.97	\N	\N	Sausalito	CA
97290	Angel Island (west side), San Francisco Bay, California	NOS	9414817	37.86	-122.443	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:21:00	0	\N	00:13:00	-0.2	\N	\N	\N	Angel Island (west side)	CA
97291	Angel Island, East Garrison, San Francisco Bay, California	NOS	9414818	37.8633	-122.42	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:20:00	\N	1.04	00:16:00	\N	1.02	\N	\N	Angel Island, East Garrison	CA
97292	Sausalito, Corps of Engineers Dock, San Francisco Bay, California (sub)	NOS	9414819	37.865	-122.493	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:21:00	\N	1	00:10:00	\N	0.98	\N	\N	Sausalito, Corps of Engineers Dock	CA
97293	Borden Highway Bridge, Middle River, San Joaquin River, California	NOS	9414835	37.8917	-121.488	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	04:54:00	\N	0.62	04:50:00	\N	0.67	\N	\N	Borden Highway Bridge, Middle River	CA
97294	Borden Highway Bridge, Old River, San Joaquin River, California	NOS	9414836	37.8833	-121.577	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	04:35:00	\N	0.61	04:40:00	\N	0.64	\N	\N	Borden Highway Bridge, Old River	CA
97295	Point Chauncey, San Francisco Bay, California	NOS	9414837	37.8917	-122.443	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:32:00	\N	0.96	00:28:00	\N	0.98	\N	\N	Point Chauncey	CA
97296	Point Isabel, San Francisco Bay, California	NOS	9414843	37.8983	-122.32	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:33:00	0	\N	00:23:00	0.1	\N	\N	\N	Point Isabel	CA
97297	Richmond Inner Harbor, San Francisco Bay, California	NOS	9414849	37.91	-122.358	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:30:00	\N	0.98	00:16:00	\N	1.04	\N	\N	Richmond Inner Harbor	CA
97298	Holt, Whiskey Slough, San Joaquin River, California	NOS	9414866	37.935	-121.435	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	04:39:00	\N	0.68	04:18:00	\N	0.8	\N	\N	Holt, Whiskey Slough	CA
97299	Orwood, Old River, San Joaquin River, California	NOS	9414868	37.9383	-121.56	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	04:33:00	\N	0.68	04:32:00	\N	0.76	\N	\N	Orwood, Old River	CA
97300	Point San Quentin, San Francisco Bay, California	NOS	9414873	37.945	-122.475	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:50:00	\N	0.93	00:42:00	\N	0.99	\N	\N	Point San Quentin	CA
97301	Point Orient, San Francisco Bay, California	NOS	9414881	37.9583	-122.425	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:52:00	\N	0.96	00:50:00	\N	1.03	\N	\N	Point Orient	CA
97302	Stockton, San Joaquin River, California	NOS	9414883	37.9583	-121.29	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	04:33:00	\N	0.66	04:06:00	\N	0.81	\N	\N	Stockton	CA
97303	Point Bonita, Bonita Cove, San Francisco Bay, California	NOS	9414906	37.8183	-122.528	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	-00:10:00	0	\N	-00:17:00	0.3	\N	\N	\N	Point Bonita, Bonita Cove	CA
97304	Point San Pedro, San Pablo Bay, California	NOS	9415009	37.9933	-122.447	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:07:00	\N	0.92	01:02:00	\N	1.01	\N	\N	Point San Pedro	CA
97305	Gallinas, Gallinas Creek, San Pablo Bay, California	NOS	9415052	38.015	-122.503	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:25:00	\N	0.89	01:18:00	\N	1.02	\N	\N	Gallinas, Gallinas Creek	CA
97306	Davis Slough, San Joaquin River, California	NOS	9415053	38.0117	-121.638	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	02:46:00	\N	0.72	02:33:00	\N	0.68	\N	\N	Dutch Slough	CA
97307	Hercules, Refugio Landing, San Pablo Bay, California	NOS	9415074	38.0233	-122.292	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:39:00	\N	0.85	01:15:00	\N	1.05	\N	\N	Hercules, Refugio Landing	CA
97308	Irish Landing, Sand Mound Slough, San Joaquin River, California	NOS	9415095	38.0333	-121.583	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	03:34:00	\N	0.68	03:29:00	\N	0.73	\N	\N	Irish Landing, Sand Mound Slough	CA
97309	Pittsburg, New York Slough, Suisun Bay, California	NOS	9415096	38.0367	-121.88	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	01:05:00	\N	0.84	00:59:00	\N	0.83	\N	\N	Pittsburg, New York Slough	CA
97310	Benicia, California	NOS	9415111	38.0433	-122.13	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	-00:33:00	\N	1.18	-00:24:00	\N	1.09	\N	\N	Benicia	CA
97311	Bishop Cut, Disappointment Slough, San Joaquin River, California	NOS	9415117	38.045	-121.42	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	04:12:00	\N	0.66	04:12:00	\N	0.79	\N	\N	Bishop Cut, Disappointment Slough	CA
97312	Selby, California	NOS	9415142	38.0583	-122.243	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	02:04:00	0	\N	01:29:00	0.6	\N	\N	\N	Selby	CA
97313	False River, San Joaquin River, California	NOS	9415145	38.055	-121.657	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	02:45:00	\N	0.64	02:45:00	\N	0.66	\N	\N	False River	CA
97314	Prisoners Point, San Joaquin River, California	NOS	9415149	38.0617	-121.555	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	03:29:00	\N	0.69	03:25:00	\N	0.73	\N	\N	Prisoners Point	CA
97315	Vallejo, Mare Island Strait, California	NOS	9415165	38.1117	-122.273	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	02:12:00	\N	0.84	01:47:00	\N	1.02	\N	\N	Vallejo, Mare Island Strait	CA
97316	Collinsville, Sacramento River, California	NOS	9415176	38.0733	-121.848	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	01:20:00	\N	0.8	01:11:00	\N	0.8	\N	\N	Collinsville	CA
97317	Montezuma Slough, Suisun Bay, California	NOS	9415205	38.0767	-121.885	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	01:27:00	\N	0.82	01:16:00	\N	0.84	\N	\N	Montezuma Slough	CA
97318	Point Buckler, Suisun Bay, California	NOS	9415227	38.1	-122.033	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	00:22:00	\N	1.08	00:13:00	\N	1.12	\N	\N	Point Buckler	CA
97319	Inverness, Tomales Bay, California	NOS	9415228	38.1133	-122.868	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:08:00	\N	0.91	00:29:00	\N	0.94	\N	\N	Inverness, Tomales Bay	CA
97320	Threemile Slough, Sacramento River, California	NOS	9415236	38.1067	-121.7	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	01:58:00	\N	0.78	01:49:00	\N	0.82	\N	\N	Threemile Slough	CA
97321	Petaluma River entrance, San Pablo Bay, California (sub)	NOS	9415252	38.11530555555556	-122.5056666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	02:08:00	\N	0.86	01:23:00	\N	1.06	\N	\N	Petaluma River entrance	CA
97322	Terminous, South Fork, Mokelumne River, California	NOS	9415257	38.11	-121.498	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	04:11:00	\N	0.59	03:53:00	\N	0.7	\N	\N	Terminous, South Fork	CA
97323	Pierce Harbor, Goodyear Slough, Suisun Bay, California	NOS	9415266	38.1267	-122.1	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	00:41:00	\N	0.96	00:27:00	\N	1	\N	\N	Pierce Harbor, Goodyear Slough	CA
97324	Georgiana Slough entrance, Mokelumne River, California	NOS	9415287	38.125	-121.578	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	03:41:00	\N	0.59	03:29:00	\N	0.67	\N	\N	Georgiana Slough entrance	CA
97325	Meins Landing, Montezuma Slough, Suisun Bay, California	NOS	9415307	38.1367	-121.907	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	01:11:00	\N	0.93	00:57:00	\N	1.01	\N	\N	Meins Landing, Montezuma Slough	CA
97326	Reynolds, Tomales Bay, California	NOS	9415320	38.1467	-122.883	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:59:00	\N	0.83	00:26:00	\N	0.89	\N	\N	Reynolds, Tomales Bay	CA
97327	Marshall, Tomales Bay, California	NOS	9415339	38.1617	-122.893	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:16:00	-0.1	\N	00:38:00	-0.6	\N	\N	\N	Marshall, Tomales Bay	CA
97328	Hog Island, San Antonio Creek, San Pablo Bay, California	NOS	9415344	38.1617	-122.55	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	02:36:00	\N	0.79	01:47:00	\N	1.07	\N	\N	Hog Island, San Antonio Creek	CA
97329	Joice Island, Suisun Slough, Suisun Bay, California	NOS	9415379	38.18	-122.045	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	00:41:00	\N	1	00:21:00	\N	1.07	\N	\N	Joice Island, Suisun Slough	CA
97330	Blakes Landing, Tomales Bay, California	NOS	9415396	38.19	-122.917	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:15:00	\N	0.79	00:32:00	\N	0.86	\N	\N	Blakes Landing, Tomales Bay	CA
97331	Montezuma Slough Bridge, Suisun Bay, California	NOS	9415402	38.1867	-121.98	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	00:46:00	\N	0.95	00:37:00	\N	1.01	\N	\N	Montezuma Slough Bridge	CA
97332	Steamboat Slough, Snug Harbor Marina, Sacramento River, California	NOS	9415414	38.1833	-121.655	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	02:48:00	\N	0.65	02:24:00	\N	0.8	\N	\N	Steamboat Slough, Snug Harbor Marina	CA
97333	Edgerley Island, Napa River, California	NOS	9415415	38.1917	-122.312	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	02:29:00	\N	0.76	02:02:00	\N	1.06	\N	\N	Edgerley Island, Napa River	CA
97334	Brazos Drawbridge, Napa River, California	NOS	9415446	38.21	-122.307	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	02:29:00	\N	0.86	02:02:00	\N	1.14	\N	\N	Brazos Drawbridge, Napa River	CA
97335	Wingo, Sonoma Creek, San Pablo Bay, California	NOS	9415447	38.21	-122.427	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	03:11:00	-0.3	\N	02:12:00	0.1	\N	\N	\N	Wingo, Sonoma Creek	CA
97336	Tomales Bay entrance, California	NOS	9415469	38.2283	-122.977	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	00:20:00	\N	0.91	-00:12:00	\N	0.87	\N	\N	Tomales Bay entrance	CA
97337	New Hope Bridge, Mokelumne River, California	NOS	9415478	38.2267	-121.49	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	04:56:00	\N	0.68	04:22:00	\N	0.73	\N	\N	New Hope Bridge	CA
97338	Suisun City, Suisun Slough, Suisun Bay, California	NOS	9415498	38.2367	-122.03	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	01:01:00	\N	1	00:36:00	\N	1.11	\N	\N	Suisun City, Suisun Slough	CA
97339	Snodgrass Slough, Sacramento River, California	NOS	9415565	38.2767	-121.495	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	05:36:00	\N	0.39	05:00:00	\N	0.49	\N	\N	Snodgrass Slough	CA
97340	Upper drawbridge, Petaluma River, San Pablo Bay, California (sub)	NOS	9415584	38.2283	-122.613	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	02:59:00	\N	0.82	02:11:00	\N	1.15	\N	\N	Upper drawbridge, Petaluma River	CA
97341	Napa, Napa River, California	NOS	9415623	38.2983	-122.28	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	02:37:00	\N	0.9	02:05:00	\N	1.22	\N	\N	Napa, Napa River	CA
97342	Bodega Harbor entrance, California	NOS	9415625	38.3083	-123.055	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	-00:16:00	0.1	\N	-00:38:00	-0.2	\N	\N	\N	Bodega Harbor entrance	CA
97343	Clarksburg, Sacramento River, California	NOS	9415846	38.4167	-121.523	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	05:02:00	\N	0.41	03:58:00	\N	0.6	\N	\N	Clarksburg	CA
97344	Fort Ross, California	NOS	9416024	38.5133	-123.245	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	-00:30:00	\N	0.96	-00:51:00	\N	0.96	\N	\N	Fort Ross	CA
97345	Sacramento, Sacramento River, California	NOS	9416174	38.58	-121.507	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95504	06:32:00	\N	0.41	05:07:00	\N	0.6	\N	\N	Sacramento	CA
97346	Westport, California	NOS	9417624	39.6333	-123.783	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95515	00:00:00	\N	0.95	00:14:00	\N	0.98	\N	\N	Westport	CA
97347	Hookton Slough, Humboldt Bay, California	NOS	9418686	40.6867	-124.222	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95520	00:15:00	\N	0.98	00:06:00	\N	1.01	\N	\N	Hookton Slough	CA
97348	Elk River Railroad Bridge, Humboldt Bay, California	NOS	9418757	40.7567	-124.193	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95520	01:32:00	\N	0.31	00:19:00	\N	0.71	\N	\N	Elk River Railroad Bridge	CA
97349	Bucksport, Humboldt Bay, California	NOS	9418778	40.7783	-124.197	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95520	00:16:00	\N	1	00:17:00	\N	1.01	\N	\N	Bucksport	CA
97350	Eureka, Humboldt Bay, California	NOS	9418801	40.8067	-124.167	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95520	00:13:00	\N	1.03	00:26:00	\N	1.06	\N	\N	Eureka	CA
97351	Eureka Slough Bridge, Humboldt Bay, California	NOS	9418802	40.8067	-124.142	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95520	00:19:00	\N	1.02	00:33:00	\N	1.08	\N	\N	Eureka Slough Bridge	CA
97352	Arcata Wharf, Humboldt Bay, California	NOS	9418851	40.85	-124.117	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95520	00:54:00	0.1	\N	00:48:00	0.1	\N	\N	\N	Arcata Wharf	CA
97353	Mad River Slough, Arcata Bay, Humboldt Bay, California	NOS	9418865	40.865	-124.148	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95520	00:35:00	\N	1.07	00:43:00	\N	1.12	\N	\N	Mad River Slough, Arcata Bay	CA
97354	Trinidad Harbor, California	NOS	9419059	41.0567	-124.147	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95523	-00:03:00	\N	0.98	-00:02:00	\N	0.97	\N	\N	Trinidad Harbor	CA
97355	Brookings, Chetco Cove, Oregon	NOS	9430104	42.0433	-124.285	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95523	00:04:00	\N	1	00:01:00	\N	1	\N	\N	Brookings, Chetco Cove	OR
97356	Bandon, Coquille River, Oregon	NOS	9432373	43.12	-124.413	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95528	00:02:00	\N	0.94	-00:05:00	\N	0.92	\N	\N	Bandon, Coquille River	OR
97357	Coos Bay, Oregon	NOS	9432845	43.38	-124.215	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95528	01:28:00	\N	0.88	01:26:00	\N	0.96	\N	\N	Coos Bay	OR
97358	Empire, Coos Bay, Oregon	NOS	9432864	43.3917	-124.28	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95528	00:50:00	\N	0.88	00:37:00	\N	0.86	\N	\N	Empire	OR
97359	Sitka Dock, Coos Bay, Oregon	NOS	9432879	43.3767	-124.297	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95528	00:08:00	\N	1.01	00:07:00	\N	1.01	\N	\N	Sitka Dock, Coos Bay	OR
97360	Florence, Siuslaw River, Oregon	NOS	9434032	43.96670150756836	-124.10299682617188	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95528	00:58:00	\N	0.8	00:44:00	\N	0.86	\N	\N	Florence, Siuslaw River	OR
97361	Siuslaw River entrance, Oregon	NOS	9434132	44.016700744628906	-124.12999725341797	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95528	00:03:00	\N	0.96	00:06:00	\N	0.96	\N	\N	Siuslaw River Entrance	OR
97362	Drift Creek, Alsea River, Oregon	NOS	9434938	44.4133	-123.99	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95528	01:51:00	\N	0.53	00:44:00	\N	0.83	\N	\N	Drift Creek, Alsea River	OR
97363	Toledo, Yaquina River, Oregon	NOS	9435362	44.6167	-123.937	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95523	01:17:00	\N	1.02	01:02:00	\N	1.31	\N	\N	TOLEDO	OR
97364	Yaquina USCG station, Newport, Yaquina Bay, Oregon	NOS	9435385	44.6267	-124.055	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95523	00:35:00	\N	1.11	00:39:00	\N	1.22	\N	\N	YAQUINA USCG STA, NEWPORT	OR
97365	Kernville, Siletz River, Oregon	NOS	9436031	44.8967	-124	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95523	01:53:00	\N	0.67	01:24:00	\N	0.86	\N	\N	Kernville, Siletz River	OR
97366	Taft, Siletz Bay, Oregon	NOS	9436101	44.9267	-124.013	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95523	01:13:00	\N	0.75	00:48:00	\N	0.94	\N	\N	Taft, Siletz Bay	OR
97367	Netarts, Netarts Bay, Oregon	NOS	9437262	45.43	-123.945	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95523	01:38:00	\N	0.85	01:17:00	\N	0.98	\N	\N	Netarts, Netarts Bay	OR
97368	Tillamook, Hoquarten Slough, Tillamook Bay, Oregon	NOS	9437331	45.46	-123.845	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95523	03:15:00	\N	0.58	01:52:00	\N	0.94	\N	\N	Tillamook, Hoquarten Slough	OR
97369	Barview, Tillamook Bay, Oregon	NOS	9437581	45.5683	-123.943	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95523	00:56:00	\N	0.92	00:42:00	\N	1.08	\N	\N	Barview	OR
97370	Brighton, Nehalem River, Oregon	NOS	9437815	45.67	-123.925	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95523	00:54:00	\N	1	00:51:00	\N	1.13	\N	\N	Brighton	OR
97371	Nehalem, Nehalem River, Oregon	NOS	9437908	45.71	-123.89	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95523	01:56:00	\N	0.75	01:17:00	\N	1.03	\N	\N	Nehalem	OR
97372	Astoria (Port Docks), Oregon	NOS	9439023	46.1867	-123.86	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95545	-00:03:00	0	\N	-00:08:00	-0.5	\N	\N	\N	Astoria (Port Docks), Oreg.	OR
97373	Astoria (Youngs Bay), Oregon	NOS	9439026	46.1717	-123.842	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95545	-00:14:00	0.1	\N	-00:13:00	0.1	\N	\N	\N	Astoria (Youngs Bay), Oreg.	OR
97374	Settlers Point, Oregon	NOS	9439054	46.175	-123.678	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95545	00:53:00	-0.1	\N	00:22:00	-0.5	\N	\N	\N	Settlers Point, Oreg.	OR
97375	Knappa, Knappa Slough, Oregon	NOS	9439069	46.1867	-123.588	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95545	00:58:00	\N	0.86	00:29:00	\N	0.97	\N	\N	Knappa, Knappa Slough	OR
97376	Hungry Harbor, Washington	NOS	9440563	46.2583	-123.848	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95545	-00:09:00	0.1	\N	00:04:00	-0.2	\N	\N	\N	Hungry Harbor, Wash.	WA
97377	Fort Canby, Jetty A, Washington	NOS	9440572	46.2683	-124.037	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95545	-01:05:00	\N	1.22	-00:41:00	\N	0.97	\N	\N	Fort Canby, Jetty 'A', Wash.	WA
97378	Chinook, Baker Bay, Washington	NOS	9440573	46.2717	-123.948	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95545	-00:52:00	\N	1.12	-00:30:00	\N	0.95	\N	\N	Chinook, Baker Bay, Wash.	WA
97379	Columbia River entrance (north jetty), Washington	NOS	9440574	46.2733	-124.072	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95545	-01:00:00	0.1	\N	-00:44:00	-1	\N	\N	\N	Columbia River entrance (N. Jetty)	WA
97380	Ilwaco, Baker Bay, Washington	NOS	9440597	46.3033	-124.04	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95545	00:01:00	-0.1	\N	-00:13:00	-0.8	\N	\N	\N	Ilwaco, Baker Bay, Wash.	WA
97381	Naselle River, 4 mi above swing bridge, Willapa Bay, Washington	NOS	9440662	46.3883	-123.84	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	01:02:00	\N	0.93	01:02:00	\N	1.22	\N	\N	Naselle River, 4 miles above swing bridge	WA
97382	Naselle River, swing bridge, Willapa Bay, Washington	NOS	9440691	46.43	-123.903	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	00:37:00	\N	1.08	00:42:00	\N	1.22	\N	\N	Naselle River, swing bridge	WA
97383	Paradise Point, Long Island, Willapa Bay, Washington	NOS	9440723	46.4683	-123.945	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	00:41:00	\N	1.04	00:43:00	\N	1.15	\N	\N	Paradise Point, Long Island	WA
97384	Nahcotta, Willapa Bay, Washington (sub)	NOS	9440747	46.5017	-124.023	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	00:28:00	\N	1.01	00:29:00	\N	1.13	\N	\N	Nahcotta	WA
97385	Palix River, south fork, Willapa Bay, Washington	NOS	9440813	46.5867	-123.91	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	00:31:00	\N	0.96	00:25:00	\N	1.04	\N	\N	Palix River, south fork	WA
97386	Bay Center, Palix River, Willapa Bay, Washington	NOS	9440846	46.6233	-123.945	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	00:22:00	\N	1.03	00:09:00	\N	1.04	\N	\N	Bay Center, Palix River	WA
97387	Raymond, Willapa River, Willapa Bay, Washington	NOS	9440886	46.6833	-123.755	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	00:17:00	\N	1.04	00:27:00	\N	1.13	\N	\N	Raymond, Willapa River	WA
97388	Bay City, South Bay, Grays Harbor, Washington	NOS	9441038	46.8617	-124.06	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	-00:26:00	\N	1.13	-00:01:00	\N	1.1	\N	\N	Bay City, South Bay	WA
97389	Markham, Grays Harbor, Washington	NOS	9441098	46.9067	-123.998	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	-00:15:00	\N	1.02	00:05:00	\N	1.06	\N	\N	Markham	WA
97390	Point Brown, Grays Harbor, Washington	NOS	9441156	46.95	-124.128	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	-00:24:00	\N	1.04	-00:09:00	\N	1.06	\N	\N	Point Brown	WA
97391	Cosmopolis, Chehalis River, Grays Harbor, Washington	NOS	9441158	46.9667	-123.778	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	00:15:00	\N	1.12	00:26:00	\N	1.23	\N	\N	Cosmopolis, Chehalis River	WA
97392	Point Grenville, Washington	NOS	9441627	47.3033	-124.27	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	-00:44:00	\N	0.9	-00:37:00	\N	0.92	\N	\N	Point Grenville	WA
97393	James Island, Washington	NOS	9442388	47.9067	-124.647	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	-00:32:00	\N	0.96	-00:39:00	\N	0.92	\N	\N	James Island	WA
97394	Makah Bay, Washington	NOS	9442861	48.2967	-124.672	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	-00:28:00	\N	1.1	-00:25:00	\N	0.99	\N	\N	Makah Bay	WA
97395	Tatoosh Island, Cape Flattery, Strait of Juan de Fuca, Washington	NOS	9442971	48.391700744628906	-124.73699951171875	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95569	-00:10:00	\N	1	-00:08:00	\N	1.01	\N	\N	Tatoosh Island, Cape Flattery	WA
97396	Twin Rivers, Strait of Juan de Fuca, Washington	NOS	9443644	48.17499923706055	-123.94999694824219	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95569	00:59:00	\N	1.2	00:47:00	\N	0.89	\N	\N	Twin Rivers	WA
97397	Crescent Bay, Strait of Juan de Fuca, Washington	NOS	9443826	48.1617	-123.725	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	-02:02:00	\N	0.8	-02:41:00	\N	0.8	\N	\N	Crescent Bay	WA
97398	Ediz Hook, Port Angeles, Strait of Juan de Fuca, Washington	NOS	9444122	48.14	-123.413	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	-01:13:00	\N	0.9	-01:37:00	\N	0.81	\N	\N	Ediz Hook, Port Angeles	WA
97399	Dungeness, Strait of Juan de Fuca, Washington	NOS	9444471	48.1667	-123.117	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	-00:38:00	\N	0.9	-00:54:00	\N	0.9	\N	\N	Dungeness	WA
97400	Sequim Bay entrance, Strait of Juan de Fuca, Washington	NOS	9444555	48.0817	-123.043	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	-00:07:00	\N	0.94	-00:39:00	\N	0.94	\N	\N	Sequim Bay entrance	WA
97401	Gardiner, Discovery Bay, Strait of Juan de Fuca, Washington	NOS	9444705	48.0583	-122.917	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	-00:17:00	\N	0.94	-00:47:00	\N	0.94	\N	\N	Gardiner, Discovery Bay	WA
97402	Mystery Bay, Marrowstone Island, Admiralty Inlet, Washington	NOS	9444971	48.0583	-122.692	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	00:52:00	\N	0.99	00:15:00	\N	0.95	\N	\N	Mystery Bay, Marrowstone Island	WA
97403	Marrowstone Point, Admiralty Inlet, Washington	NOS	9444972	48.0917	-122.69	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	00:05:00	-0.1	\N	00:02:00	0.4	\N	\N	\N	Marrowstone Point	WA
97404	Port Ludlow, Washington	NOS	9445017	47.925	-122.68	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:14:00	\N	0.95	-00:14:00	\N	0.87	\N	\N	Port Ludlow	WA
97405	Port Gamble, Washington	NOS	9445059	47.8583	-122.58	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:05:00	\N	0.95	-00:09:00	\N	0.9	\N	\N	Port Gamble	WA
97406	Lofall, Washington	NOS	9445088	47.815	-122.657	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:06:00	\N	1.01	-00:08:00	\N	0.94	\N	\N	Lofall	WA
97407	Whitney Point, Dabob Bay, Washington	NOS	9445246	47.7617	-122.85	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:02:00	\N	1.06	-00:05:00	\N	1.01	\N	\N	Whitney Point, Dabob Bay	WA
97408	Zelatched Point, Dabob Bay, Washington	NOS	9445269	47.7117	-122.822	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:05:00	\N	1.02	-00:09:00	\N	1	\N	\N	Zelatched Point, Dabob Bay	WA
97409	Quilcene, Quilcene Bay, Dabob Bay, Washington	NOS	9445272	47.8	-122.858	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:02:00	\N	1.04	-00:08:00	\N	1	\N	\N	Quilcene, Quilcene Bay, Dabob Bay	WA
97410	Pleasant Harbor, Washington	NOS	9445293	47.665	-122.912	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:01:00	\N	1.02	-00:14:00	\N	1.01	\N	\N	Pleasant Harbor	WA
97411	Seabeck, Seabeck Bay, Washington	NOS	9445303	47.6417	-122.828	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:01:00	\N	1.06	-00:04:00	\N	1.01	\N	\N	Seabeck, Seabeck Bay	WA
97413	Ayock Point, Washington	NOS	9445388	47.5083	-123.052	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:05:00	\N	1.07	-00:03:00	\N	0.99	\N	\N	Ayock Point	WA
97414	Lynch Cove Dock, Washington	NOS	9445441	47.4183	-122.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:06:00	\N	1.08	00:00:00	\N	1.07	\N	\N	Lynch Cove Dock	WA
97415	Hansville, Puget Sound, Washington	NOS	9445526	47.9183	-122.545	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:08:00	\N	0.98	-00:07:00	\N	0.92	\N	\N	Hansville	WA
97416	Kingston, Appletree Cove, Puget Sound, Washington	NOS	9445639	47.7967	-122.493	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:05:00	\N	1	-00:05:00	\N	0.97	\N	\N	Kingston, Appletree Cove	WA
97417	Port Jefferson, Puget Sound, Washington	NOS	9445683	47.7467	-122.477	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:04:00	\N	0.98	-00:03:00	\N	0.95	\N	\N	Port Jefferson	WA
97418	Poulsbo, Liberty Bay, Puget Sound, Washington	NOS	9445719	47.725	-122.638	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:12:00	\N	1.01	00:05:00	\N	1.03	\N	\N	Poulsbo, Liberty Bay	WA
97419	Port Madison, Puget Sound, Washington	NOS	9445753	47.705	-122.525	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:03:00	\N	0.99	00:09:00	\N	1	\N	\N	Port Madison	WA
97420	Brownsville, Port Orchard, Puget Sound, Washington	NOS	9445832	47.6517	-122.615	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:09:00	\N	1.03	00:07:00	\N	1.04	\N	\N	Brownsville, Port Orchard	WA
97421	Eagle Harbor, Bainbridge Island, Puget Sound, Washington	NOS	9445882	47.62	-122.515	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:05:00	\N	1.02	00:04:00	\N	1	\N	\N	Eagle Harbor, Bainbridge Island	WA
97422	Tracyton, Dyes Inlet, Puget Sound, Washington	NOS	9445901	47.61	-122.66	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:53:00	\N	0.95	00:28:00	\N	1.06	\N	\N	Tracyton, Dyes Inlet	WA
97423	Port Blakely, Puget Sound, Washington	NOS	9445913	47.5967	-122.51	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:04:00	\N	0.99	00:04:00	\N	1.01	\N	\N	Port Blakely	WA
97424	Clam Bay, Rich Passage, Puget Sound, Washington	NOS	9445938	47.5733	-122.543	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:04:00	\N	1	00:03:00	\N	1.01	\N	\N	Clam Bay, Rich Passage	WA
97425	Harper, Yukon Harbor, Puget Sound, Washington	NOS	9445993	47.5233	-122.517	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:01:00	\N	0.99	-00:06:00	\N	1.02	\N	\N	Harper, Yukon Harbor	WA
97426	Point Vashon, Vashon Island, Puget Sound, Washington	NOS	9446025	47.5117	-122.463	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:02:00	\N	1.01	00:02:00	\N	1.02	\N	\N	Point Vashon, Vashon Island	WA
97427	Des Moines, east passage, Puget Sound, Washington	NOS	9446248	47.4	-122.328	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:08:00	\N	1.01	00:05:00	\N	1.03	\N	\N	Des Moines, East Passage	WA
97428	Burton, Quartermaster Hbr. (inside), Vashon I., Puget Sound, Washington	NOS	9446254	47.395	-122.463	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:03:00	\N	1.02	00:01:00	\N	1.06	\N	\N	Burton, Quartermaster Hbr. (inside), Vashon I.	WA
97429	Allyn, Case Inlet, Puget Sound, Washington	NOS	9446281	47.3833	-122.823	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:59:00	\N	1.07	00:48:00	\N	1.26	\N	\N	Allyn, Case Inlet	WA
97430	Vaughn, Case Inlet, Puget Sound, Washington	NOS	9446366	47.3417	-122.775	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:57:00	\N	1.06	00:51:00	\N	1.26	\N	\N	Vaughn, Case Inlet	WA
97431	Gig Harbor, Puget Sound, Washington	NOS	9446369	47.34	-122.588	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:22:00	\N	0.99	00:18:00	\N	1.05	\N	\N	Gig Harbor	WA
97432	Tahlequah, Neil Pt., Dalco Passage, Vashon I., Puget Sound, Washington	NOS	9446375	47.3333	-122.507	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:05:00	\N	1.01	00:04:00	\N	1.05	\N	\N	Tahlequah, Neil Pt., Dalco Passage, Vashon I.	WA
97433	Horsehead Bay, Carr Inlet, Puget Sound, Washington	NOS	9446451	47.3017	-122.682	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:46:00	\N	1.05	00:38:00	\N	1.2	\N	\N	Horsehead Bay, Carr Inlet	WA
97434	Tacoma Narrows Bridge, Puget Sound, Washington	NOS	9446486	47.2717	-122.552	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:23:00	\N	1.02	00:28:00	\N	1.11	\N	\N	Tacoma Narrows Bridge	WA
97435	Walkers Landing, Pickering Passage, Puget Sound, Washington	NOS	9446489	47.2817	-122.923	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:55:00	\N	1.07	00:44:00	\N	1.26	\N	\N	Walkers Landing, Pickering Passage	WA
97436	Arletta, Hale Passage, Puget Sound, Washington	NOS	9446491	47.28	-122.652	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:40:00	\N	1.04	00:31:00	\N	1.18	\N	\N	Arletta, Hale Passage	WA
97437	Home, Von Geldern Cove, Carr Inlet, Puget Sound, Washington	NOS	9446500	47.275	-122.758	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:45:00	\N	1.04	00:37:00	\N	1.19	\N	\N	Home, Von Geldern Cove, Carr Inlet	WA
97438	McMicken Island, Case Inlet, Puget Sound, Washington	NOS	9446583	47.2467	-122.862	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:52:00	\N	1.06	00:40:00	\N	1.24	\N	\N	McMicken Island, Case Inlet	WA
97439	Shelton, Oakland Bay, Puget Sound, Washington	NOS	9446628	47.215	-123.083	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	02:05:00	\N	0.92	01:26:00	\N	1.26	\N	\N	Shelton, Oakland Bay	WA
97440	Longbranch, Filucy Bay, Puget Sound, Washington	NOS	9446638	47.21	-122.753	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:47:00	\N	1.02	00:38:00	\N	1.2	\N	\N	Longbranch, Filucy Bay	WA
97441	Arcadia, Totten Inlet, Puget Sound, Washington	NOS	9446666	47.1967	-122.938	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	01:05:00	\N	1.06	00:49:00	\N	1.28	\N	\N	Arcadia, Totten Inlet	WA
97442	Devils Head, Drayton Passage, Puget Sound, Washington	NOS	9446671	47.1667	-122.763	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:50:00	\N	1.1	00:40:00	\N	1.25	\N	\N	Devils Head, Drayton Passage	WA
97443	Steilacoom, Cormorant Passage, Puget Sound, Washington	NOS	9446714	47.1733	-122.603	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:45:00	\N	1.05	00:37:00	\N	1.2	\N	\N	Steilacoom, Cormorant Passage	WA
97444	Barron Point, Little Skookum Inlet entrance, Puget Sound, Washington	NOS	9446742	47.156700134277344	-123.00800323486328	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:59:00	\N	1.06	00:50:00	\N	1.29	\N	\N	Barron Point, Little Skookum Inlet Entrance	WA
97445	Henderson Inlet, Puget Sound, Washington	NOS	9446752	47.155	-122.838	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:58:00	\N	1.06	00:47:00	\N	1.24	\N	\N	Henderson Inlet	WA
97446	Dofflemeyer Point, Boston Hbr., Budd Inlet, Puget Sound, Washington	NOS	9446800	47.1417	-122.903	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:57:00	\N	1.09	00:44:00	\N	1.28	\N	\N	Dofflemeyer Point, Boston Hbr., Budd Inlet	WA
97447	Dupont Wharf, Nisqually Reach, Puget Sound, Washington	NOS	9446828	47.1183	-122.665	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:49:00	\N	1.04	00:41:00	\N	1.2	\N	\N	Dupont Wharf, Nisqually Reach	WA
97448	Olympia, Budd Inlet, Puget Sound, Washington	NOS	9446969	47.06	-122.903	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:57:00	\N	1.08	00:45:00	\N	1.29	\N	\N	Olympia, Budd Inlet	WA
97449	Duwamish Waterway, Eighth Ave. South, Puget Sound, Washington	NOS	9447029	47.535	-122.322	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:11:00	\N	0.95	00:10:00	\N	0.97	\N	\N	Duwamish Waterway, Eighth Ave. South	WA
97450	Lockheed Shipyard, Harbor Island, Puget Sound, Washington	NOS	9447110	47.585	-122.362	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:01:00	\N	1	-00:01:00	\N	1	\N	\N	Lockheed Shipyard, Harbor Island	WA
97451	Meadow Point, Shilshole Bay, Puget Sound, Washington	NOS	9447265	47.6883	-122.403	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:01:00	\N	0.99	00:00:00	\N	0.98	\N	\N	Meadow Point, Shilshole Bay	WA
97452	Edmonds, Puget Sound, Washington	NOS	9447427	47.8133	-122.383	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:04:00	\N	0.99	00:00:00	\N	0.96	\N	\N	Edmonds	WA
97453	Glendale, Whidbey Island, Washington	NOS	9447814	47.94	-122.357	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:03:00	\N	0.99	00:01:00	\N	0.97	\N	\N	Glendale, Whidbey Island	WA
97454	Bush Point, Whidbey Island, Admiralty Inlet, Washington	NOS	9447854	48.0333	-122.607	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	00:45:00	\N	1.08	00:10:00	\N	1.09	\N	\N	Bush Point, Whidbey Island	WA
97455	Holly Farms Harbor, Holmes Harbor, Whidbey I., Washington	NOS	9447855	48.0267	-122.535	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:04:00	\N	0.99	00:01:00	\N	1.01	\N	\N	Holly Farms Harbor, Holmes Harbor, Whidbey I.	WA
97456	Sandy Point, Whidbey Island, Washington	NOS	9447856	48.035	-122.377	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:01:00	\N	1	00:03:00	\N	0.99	\N	\N	Sandy Point, Whidbey Island	WA
97457	Admiralty Head, Admiralty Inlet, Washington	NOS	9447905	48.1583	-122.668	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	00:20:00	-0.1	\N	-00:11:00	0	\N	\N	\N	Admiralty Head	WA
97458	Coupeville, Penn Cove, Whidbey Island, Washington	NOS	9447929	48.2233	-122.69	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:09:00	\N	0.99	00:15:00	\N	1.01	\N	\N	Coupeville, Penn Cove, Whidbey Island	WA
97459	Point Partridge, Whidbey Island, Strait of Juan de Fuca, Washington	NOS	9447934	48.2317	-122.765	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	-00:15:00	\N	0.92	-00:11:00	\N	0.92	\N	\N	Point Partridge, Whidbey Island	WA
97460	Sunset Beach, Whidbey Island, Strait of Juan de Fuca, Washington	NOS	9447951	48.2833	-122.728	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	-00:16:00	\N	0.95	-00:27:00	\N	0.87	\N	\N	Sunset Beach, Whidbey Island	WA
97461	Crescent Harbor, N. Whidbey Island, Washington	NOS	9447952	48.2867	-122.617	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:04:00	\N	0.99	00:04:00	\N	1.03	\N	\N	Crescent Harbor, N. Whidbey Island	WA
97462	Smith Island, Strait of Juan de Fuca, Washington	NOS	9447985	48.3167	-122.837	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	-00:25:00	\N	0.83	-00:13:00	\N	0.83	\N	\N	Smith Island	WA
97463	Ala Spit, Whidbey Island, Washington	NOS	9447993	48.3967	-122.587	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:26:00	\N	0.95	00:12:00	\N	0.92	\N	\N	Ala Spit, Whidbey Island	WA
97464	Cornet Bay, Deception Pass, Washington	NOS	9447995	48.4017	-122.623	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:26:00	\N	0.95	00:15:00	\N	0.89	\N	\N	Cornet Bay, Deception Pass	WA
97465	Kayak Point, Washington	NOS	9448094	48.1367	-122.367	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	-00:02:00	\N	0.99	00:00:00	\N	0.99	\N	\N	Kayak Point	WA
97466	La Conner, Swinomish Channel, Washington	NOS	9448558	48.3917	-122.497	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:39:00	\N	0.95	00:21:00	\N	0.9	\N	\N	La Conner, Swinomish Channel	WA
97467	Yokeko Point, Deception Pass, Washington (sub)	NOS	9448601	48.4133	-122.615	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:38:00	-0.2	\N	00:26:00	-1	\N	\N	\N	Yokeko Point, Deception Pass	WA
97468	Burrows Bay (Allan Island), Washington	NOS	9448683	48.46	-122.695	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	00:03:00	\N	0.88	00:09:00	\N	0.95	\N	\N	Burrows Bay (Allan Island)	WA
97469	Ship Harbor, Fidalgo Island, Washington	NOS	9448772	48.5067	-122.677	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	00:29:00	\N	1.02	00:18:00	\N	0.93	\N	\N	Ship Harbor, Fidalgo Island	WA
97470	Anacortes, Guemes Channel, Washington	NOS	9448794	48.5183	-122.62	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	00:33:00	\N	1	00:22:00	\N	0.96	\N	\N	Anacortes, Guemes Channel	WA
97471	Strawberry Bay, Cypress Island, Washington	NOS	9448876	48.565	-122.722	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	00:52:00	\N	0.95	00:34:00	\N	0.95	\N	\N	Strawberry Bay, Cypress Island	WA
97472	Tide Point, Cypress Island, Washington	NOS	9448918	48.5867	-122.748	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	00:41:00	\N	0.95	00:31:00	\N	0.94	\N	\N	Tide Point, Cypress Island	WA
97473	Gooseberry Point, Hale Passage, Washington	NOS	9449184	48.73	-122.67	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	01:10:00	\N	0.97	00:41:00	\N	1.04	\N	\N	Gooseberry Point	WA
97474	Bellingham, Bellingham Bay, Washington	NOS	9449211	48.745	-122.495	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	01:11:00	\N	0.94	00:43:00	\N	0.99	\N	\N	Bellingham	WA
97475	Sandy Point, Lummi Bay, Washington	NOS	9449292	48.79	-122.708	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	01:24:00	\N	1.03	00:52:00	\N	1.05	\N	\N	Sandy Point, Lummi Bay	WA
97476	Patos Island Wharf, Boundary Pass, Washington	NOS	9449704	48.7867	-122.97	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	01:30:00	0	\N	01:03:00	0.2	\N	\N	\N	Patos Island Wharf	WA
97502	Boca de Quadra, Revillagigedo Channel, Alaska	NOS	9450305	55.1167	-130.798	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:02:00	\N	0.98	00:00:00	\N	0.98	\N	\N	Boca de Quadra	AK
97477	Echo Bay, Sucia Islands, Strait of Georgia, Washington	NOS	9449712	48.7567	-122.897	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	01:34:00	0	\N	01:01:00	0.1	\N	\N	\N	Echo Bay, Sucia Islands	WA
97478	Orcas, Orcas Island, Washington	NOS	9449798	48.6	-122.95	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	00:56:00	\N	0.9	00:33:00	\N	0.9	\N	\N	Orcas, Orcas Island	WA
97479	Roche Harbor, San Juan Island, Haro Strait, Washington	NOS	9449834	48.61	-123.155	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	00:47:00	\N	0.99	00:33:00	\N	0.9	\N	\N	Roche Harbor, San Juan Island	WA
97480	Shaw Island, Ferry Terminal, Harney Channel, San Juan Channel, Washington	NOS	9449904	48.585	-122.928	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	00:56:00	\N	0.99	00:31:00	\N	0.9	\N	\N	Shaw Island, Ferry Terminal, Harney Channel	WA
97481	Aleck Bay, Lopez Island, Washington	NOS	9449994	48.425	-122.853	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	-00:08:00	\N	0.88	-00:18:00	\N	0.88	\N	\N	Aleck Bay, Lopez Island	WA
97482	Minnie Bay, Alaska	NOS	9450041	54.7267	-132.302	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:00:00	0.1	\N	-00:05:00	2.7	\N	\N	\N	Minnie Bay	AK
97483	Security Cove, Dall Island, Alaska	NOS	9450055	54.7483	-132.855	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:24:00	0	\N	-00:20:00	1	\N	\N	\N	Security Cove	AK
97484	Nakat Harbor, Dixon Entrance, Alaska	NOS	9450104	54.82	-130.7	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:09:00	\N	0.89	00:01:00	\N	0.95	\N	\N	Nakat Harbor, Alaska	AK
97485	American Bay, Kaigani Strait, Alaska	NOS	9450125	54.85	-132.83	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:01:00	0	\N	00:01:00	2.5	\N	\N	\N	American Bay, Kaigani Strait	AK
97486	Hunter Bay, Alaska	NOS	9450139	54.8717	-132.322	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:03:00	0.1	\N	-00:02:00	2.7	\N	\N	\N	Hunter Bay	AK
97487	Kelp Island Passage, Duke Island, Dixon Entrance, Alaska	NOS	9450142	54.8767	-131.3	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:03:00	\N	0.96	-00:04:00	\N	0.94	\N	\N	Kelp Island Passage, Duke Island	AK
97488	Elbow Bay, Alaska	NOS	9450158	54.9	-132.653	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:04:00	0.1	\N	-00:04:00	2.6	\N	\N	\N	Elbow Bay	AK
97489	Morse Cove, Duke Island, Revillagigedo Channel, Alaska	NOS	9450172	54.92	-131.255	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:15:00	\N	0.96	00:03:00	\N	0.96	\N	\N	Morse Cove, Duke Island	AK
97490	Kassa Inlet entrance, Alaska	NOS	9450176	54.9267	-132.522	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:01:00	0.1	\N	-00:03:00	2.6	\N	\N	\N	Kassa Inlet entrance	AK
97491	Ingraham Bay, Prince of Wales Island, Alaska	NOS	9450212	54.98	-132.007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:04:00	\N	0.96	00:03:00	\N	0.93	\N	\N	Ingraham Bay, Prince of Wales Island	AK
97492	Mabel Island, Alaska	NOS	9450226	55	-132.592	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:01:00	0.1	\N	-00:10:00	2.8	\N	\N	\N	Mabel Island	AK
97493	Menefee Anch., Prince of Wales Island, Alaska	NOS	9450244	55.0267	-132.013	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:01:00	\N	0.89	-00:02:00	\N	0.94	\N	\N	Menefee Anch., Prince of Wales Island	AK
97494	Kah Shakes Cove, Revillagigedo Channel, Alaska	NOS	9450254	55.0417	-130.98	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:06:00	\N	0.96	00:00:00	\N	0.97	\N	\N	Kah Shakes Cove	AK
97495	Keete Island, Nutkwa Inlets, Alaska	NOS	9450258	55.0467	-132.577	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:05:00	0.1	\N	-00:13:00	2.8	\N	\N	\N	Keete Island, Nutkwa Inlets	AK
97496	Niblack Anchorage, Moira Sound, Alaska	NOS	9450271	55.0667	-132.12	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:09:00	\N	0.96	00:03:00	\N	0.94	\N	\N	Niblack Anchorage, Moira Sound	AK
97497	Sakie Bay, Dall Island, Alaska	NOS	9450272	55.0667	-133.2	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:05:00	0	\N	00:01:00	0.3	\N	\N	\N	Sakie Bay	AK
97498	Tamgas Harbor, Annette Island, Alaska	NOS	9450273	55.0667	-131.542	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	-00:08:00	\N	0.89	-00:09:00	\N	0.98	\N	\N	Tamgas Harbor, Annette Island	AK
97499	Keete Inlet, Alaska	NOS	9450281	55.08	-132.49	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:01:00	0.1	\N	-00:11:00	2.9	\N	\N	\N	Keete Inlet	AK
97500	Mud Bay, Hetta Inlet, Alaska	NOS	9450282	55.0817	-132.632	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:01:00	0.1	\N	-00:05:00	2.8	\N	\N	\N	Mud Bay	AK
97503	Sea Otter Harbor, Dall Island, Alaska	NOS	9450312	55.1267	-133.167	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:04:00	-0.1	\N	-00:04:00	-0.2	\N	\N	\N	Sea Otter Harbor	AK
97504	Nehenta Bay, Gravina Island, Alaska	NOS	9450339	55.1667	-131.797	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	-00:01:00	\N	0.96	-00:01:00	\N	0.95	\N	\N	Nehenta Bay, Gravina Island	AK
97505	South Pass, Sukkwan Strait, Tlevak Strait, Alaska	NOS	9450341	55.1667	-132.87	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:02:00	0.1	\N	-00:02:00	2.9	\N	\N	\N	South Pass, Sukkwan Strait	AK
97506	Saltery Point, Tlevak Strait, Alaska	NOS	9450351	55.1817	-132.795	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:05:00	0.1	\N	-00:08:00	2.9	\N	\N	\N	Saltery Point	AK
97507	North Pass, west end, Tlevak Strait, Alaska	NOS	9450366	55.205	-132.94	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:06:00	0.1	\N	-00:12:00	3	\N	\N	\N	North Pass, West End	AK
97508	Copper Harbor, Hetta Inlet, Alaska	NOS	9450369	55.21	-132.625	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:08:00	0.1	\N	-00:10:00	2.8	\N	\N	\N	Copper Harbor	AK
97509	Lancaster Cove, Cholmondeley Sound, Alaska	NOS	9450373	55.2133	-132.095	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:03:00	\N	0.96	00:05:00	\N	0.98	\N	\N	Lancaster Cove, Cholmondeley Sound	AK
97510	Alva Bay, Revillagigedo Island, Alaska	NOS	9450382	55.2283	-131.133	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	-00:03:00	\N	0.96	-00:05:00	\N	0.98	\N	\N	Alva Bay, Revillagigedo Island	AK
97511	Natalia Point, Tlevak Strait, Alaska	NOS	9450387	55.2333	-133.043	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:01:00	0.1	\N	-00:05:00	2.9	\N	\N	\N	Natalia Point	AK
97512	Divide Head, Cholmondeley Sound, Alaska	NOS	9450399	55.2517	-132.3	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	-00:08:00	\N	0.96	-00:05:00	\N	0.98	\N	\N	Divide Head, Cholmondeley Sound	AK
97513	Block Island, Tlevak Strait, Alaska	NOS	9450406	55.263301849365234	-133.11500549316406	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:02:00	\N	1	00:07:00	\N	1.2	\N	\N	Block Island, Tlevak Narrows	AK
97514	Soda Bay, Tlevak Strait, Alaska	NOS	9450413	55.275	-132.967	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:07:00	0.1	\N	00:03:00	3	\N	\N	\N	Soda Bay	AK
97515	Sulzer, Hetta Inlet, Alaska	NOS	9450421	55.285	-132.622	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:08:00	0.1	\N	-00:02:00	2.9	\N	\N	\N	Sulzer	AK
97516	Mop Point, Thorne Arm, Revillagigedo Channel, Alaska	NOS	9450483	55.3833	-131.235	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	-00:03:00	\N	0.98	-00:05:00	\N	0.98	\N	\N	Mop Point, Thorne Arm	AK
97517	Ward Cove, Revillagigedo Channel, Alaska	NOS	9450492	55.3983	-131.727	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	-00:03:00	\N	0.96	-00:05:00	\N	1.02	\N	\N	Ward Cove	AK
97518	Saltery Cove, Skowl Arm, Kasaan Bay, Alaska	NOS	9450495	55.4017	-132.328	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:02:00	\N	1.01	00:04:00	\N	1.01	\N	\N	Saltery Cove, Skowl Arm	AK
97519	Vallenar Point, Alaska	NOS	9450511	55.4267	-131.847	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	-00:06:00	\N	0.96	-00:01:00	\N	0.99	\N	\N	Vallenar Point	AK
97520	Coon Island, George Inlet, Revillagigedo Channel, Alaska	NOS	9450533	55.4617	-131.505	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	-00:07:00	\N	0.96	-00:03:00	\N	0.99	\N	\N	Coon Island, George Inlet	AK
97521	Hollis Anchorage, Kasaan Bay, Alaska	NOS	9450544	55.48	-132.645	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:02:00	\N	1.01	00:06:00	\N	1.03	\N	\N	Hollis Anchorage	AK
97522	Steamboat Bay, Noyes Island, Gulf of Esquibel, Alaska	NOS	9450578	55.5333	-133.637	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:13:00	\N	0.93	-00:12:00	\N	1.04	\N	\N	Steamboat Bay, Noyes Island	AK
97523	Kasaan, Kasaan Bay, Alaska	NOS	9450581	55.535	-132.397	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:03:00	\N	1.01	00:05:00	\N	1.02	\N	\N	Kasaan	AK
97524	Cruz Pass, San Fernando Island, Bucareli Bay, Alaska	NOS	9450584	55.5417	-133.315	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:12:00	-0.1	\N	-00:15:00	0.1	\N	\N	\N	Cruz Pass, San Fernando Island	AK
97525	Loring, Naha Bay, Alaska	NOS	9450624	55.6017	-131.632	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	-00:06:00	\N	0.96	-00:02:00	\N	1.02	\N	\N	Loring, Naha Bay	AK
97526	Rudyerd Bay, Alaska	NOS	9450651	55.6417	-130.645	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:02:00	\N	0.96	00:01:00	\N	1.02	\N	\N	Rudyerd Bay	AK
97527	Anguilla Island, Gulf of Esquibel, Alaska	NOS	9450679	55.6833	-133.587	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:14:00	-0.1	\N	-00:18:00	0.4	\N	\N	\N	Anguilla Island	AK
97528	Davis River entrance, Alaska	NOS	9450729	55.76	-130.177	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:00:00	\N	0.96	-00:02:00	\N	1.08	\N	\N	Davis River entrance, Alaska	AK
97529	Port Alice, Heceta Island, Davidson Inlet, Alaska	NOS	9450768	55.8117	-133.605	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:14:00	0	\N	-00:20:00	0.9	\N	\N	\N	Port Alice, Heceta Island	AK
97530	Ratz Harbor, Prince of Wales Island, Alaska	NOS	9450815	55.88	-132.595	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:00:00	\N	0.99	00:09:00	\N	1.03	\N	\N	Ratz Harbor, Prince of Wales Island	AK
97531	Tuxekan, 0.5 mi south of, Davidson Inlet, Alaska	NOS	9450817	55.8833	-133.243	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:07:00	-0.1	\N	-00:17:00	0.9	\N	\N	\N	Tuxekan, 0.5 mile south of	AK
97532	Coronation Island, Alaska	NOS	9450829	55.9033	-134.118	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:17:00	0	\N	-00:16:00	0.8	\N	\N	\N	Coronation Island	AK
97533	Yes Cannery, Yes Bay, Alaska	NOS	9450836	55.9133	-131.797	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:01:00	\N	0.96	00:00:00	\N	1.02	\N	\N	Yes Cannery, Yes Bay	AK
97534	El Capitan Island, Davidson Inlet, Alaska	NOS	9450851	55.9367	-133.325	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:10:00	-0.1	\N	-00:11:00	0.9	\N	\N	\N	El Capitan Island	AK
97535	Edna Bay, Davidson Inlet, Alaska	NOS	9450859	55.95	-133.662	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:08:00	0	\N	-00:20:00	0.9	\N	\N	\N	Edna Bay	AK
97536	Pole Anchorage, Kosciusko Island, Alaska	NOS	9450862	55.955	-133.81	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:22:00	-0.1	\N	-00:22:00	1.4	\N	\N	\N	Pole Anchorage, Kosciusko Island	AK
97537	Fitzgibbon Cove, Alaska	NOS	9450879	55.9833	-131.175	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	-00:01:00	\N	0.96	-00:05:00	\N	1.02	\N	\N	Fitzgibbon Cove	AK
97538	Lake Bay, Alaska	NOS	9450904	56.0233	-132.92	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:01:00	\N	0.89	00:10:00	\N	1.03	\N	\N	Lake Bay	AK
97539	Beck Island, Clarence Strait, Alaska	NOS	9450906	56.0467	-132.862	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:05:00	\N	1.01	00:10:00	\N	1.05	\N	\N	Beck Island, Clarence Strait	AK
97540	Kuiu Island, Affleck Canal, Alaska	NOS	9450913	56.0369	-134.115	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:06:00	\N	0.95	-00:09:00	\N	1.09	\N	\N	Affleck Canal entrance, Kuiu Island	AK
97541	El Capitan Passage, Alaska (sub)	NOS	9450937	56.0733	-133.313	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:02:00	-0.1	\N	-00:05:00	0.9	\N	\N	\N	El Capitan Passage, S. of Devilfish Bay	AK
97542	Thorne Island, Whale Passage, Alaska	NOS	9450938	56.0583	-132.968	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:01:00	\N	0.98	00:12:00	\N	1.04	\N	\N	Thorne Island, Whale Passage	AK
97543	Point St. Albans, Alaska	NOS	9450943	56.0817	-133.97	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:13:00	0	\N	-00:17:00	1.4	\N	\N	\N	Point St. Albans	AK
97544	Blashke Island, Clarence Strait, Alaska	NOS	9450973	56.1267	-132.895	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:24:00	\N	0.93	00:13:00	\N	1.03	\N	\N	Blashke Island	AK
97545	Shakan Bay entrance, Alaska	NOS	9450982	56.14	-133.61	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:12:00	0	\N	-00:13:00	1.8	\N	\N	\N	Shakan Bay Entrance	AK
97546	Shakan Strait, Kosciusko Island, Alaska	NOS	9450987	56.1483	-133.46	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:10:00	\N	0.95	-00:07:00	\N	1.16	\N	\N	Shakan Strait, Kosciusko Island	AK
97547	Kell Bay, Affleck Canal, Kuiu Island, Alaska	NOS	9450988	56.15	-134.133	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:01:00	0	\N	00:01:00	1.3	\N	\N	\N	Kell Bay, Affleck Canal, Kuiu Island	AK
97548	Table Bay, Kuiu Island, Alaska	NOS	9451001	56.1667	-134.245	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:13:00	0	\N	-00:15:00	1.1	\N	\N	\N	Table Bay, Kuiu Island	AK
97549	Port Beauclerc, Kuiu Island, Alaska	NOS	9451082	56.2883	-133.962	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:12:00	-0.1	\N	-00:14:00	1.9	\N	\N	\N	Port Beauclerc, Kuiu Island	AK
97550	Port Malmesbury, Kuiu Island, Alaska	NOS	9451093	56.305	-134.238	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:13:00	0.1	\N	00:04:00	1.2	\N	\N	\N	Port Malmesbury, Kuiu Island	AK
97551	Port Protection, Prince of Wales Island, Alaska	NOS	9451095	56.3083	-133.6	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:11:00	0	\N	-00:13:00	2.4	\N	\N	\N	Port Protection, Prince of Wales Island.	AK
97552	Reid Bay, Alaska	NOS	9451148	56.3883	-133.883	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:19:00	0	\N	-00:11:00	2.5	\N	\N	\N	Reid Bay	AK
97553	Port Walter, Baranof Island, Alaska	NOS	9451151	56.3917	-134.66	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:13:00	0.1	\N	00:04:00	1.5	\N	\N	\N	Port Walter, Baranof Island	AK
97554	Sumner Island, Alaska	NOS	9451163	56.41	-133.793	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:12:00	0	\N	-00:19:00	2.6	\N	\N	\N	Sumner Island	AK
97555	Greys Island, Alaska	NOS	9451238	56.5217	-132.542	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:05:00	\N	0.94	00:11:00	\N	1.01	\N	\N	Greys Island	AK
97556	Dry Strait, Frederick Sound, Alaska	NOS	9451301	56.615	-132.575	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:03:00	0	\N	-00:18:00	-0.2	\N	\N	\N	Dry Strait	AK
97557	Cosmos Point, Frederick Sound, Alaska	NOS	9451335	56.6633	-132.617	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:05:00	\N	0.99	-00:05:00	\N	0.98	\N	\N	Cosmos Point	AK
97558	Dorothy Cove, Necker Bay, Baranof Island, Alaska	NOS	9451376	56.7217	-135.075	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:02:00	\N	0.95	-00:02:00	\N	0.97	\N	\N	Dorothy Cove, Necker Bay	AK
97559	Petersburg, Wrangell Narrows, Alaska	NOS	9451439	56.815	-132.957	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95614	00:37:00	\N	0.97	00:28:00	\N	1.04	\N	\N	Petersburg	AK
97560	Symonds Bay, Biorka Island, Sitka Sound, Alaska	NOS	9451468	56.8567	-135.52	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:16:00	0	\N	-00:15:00	-0.1	\N	\N	\N	Symonds Bay, Biorka Island	AK
97561	Thomas Bay, Frederick Sound, Alaska	NOS	9451561	56.9967	-132.785	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:07:00	-0.1	\N	00:07:00	-0.8	\N	\N	\N	Thomas Bay	AK
97562	Herring Bay, Frederick Sound, Alaska	NOS	9451634	57.1133	-134.38	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:07:00	\N	0.91	-00:08:00	\N	0.84	\N	\N	Herring Bay	AK
97563	Eliza Harbor, Admiralty Island, Frederick Sound, Alaska	NOS	9451706	57.1883	-134.287	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:04:00	\N	0.92	-00:06:00	\N	0.87	\N	\N	Eliza Harbor, Admiralty Island	AK
97564	Kasnyku Bay, Alaska	NOS	9451717	57.2167	-134.868	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:06:00	-0.1	\N	-00:10:00	-2.4	\N	\N	\N	Kasnyku Bay	AK
97565	Cleveland Passage, Whitney Island, Frederick Sound, Alaska	NOS	9451718	57.2183	-133.512	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:03:00	-0.1	\N	-00:01:00	-1.2	\N	\N	\N	Cleveland Passage, Whitney Island	AK
97566	Olga Point, Olga Strait, Sitka Sound, Alaska	NOS	9451725	57.2283	-135.537	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:14:00	0	\N	00:00:00	0	\N	\N	\N	Olga Point, Olga Strait	AK
97567	Cannery Cove, Pybus Bay, Frederick Sound, Alaska	NOS	9451781	57.3067	-134.133	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:06:00	\N	0.94	-00:08:00	\N	0.9	\N	\N	Cannery Cove, Pybus Bay	AK
97568	Scraggy Point, Alaska	NOS	9451802	57.3367	-135.723	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:00:00	0.1	\N	-00:09:00	-0.1	\N	\N	\N	Scraggy Point	AK
97569	Haley Anchorage, Fish Bay, Alaska	NOS	9451826	57.3717	-135.618	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:12:00	0.1	\N	00:03:00	0.2	\N	\N	\N	Haley Anchorage, Fish Bay	AK
97570	Hobart Bay, Alaska	NOS	9451851	57.4067	-133.42	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:03:00	-0.1	\N	-00:06:00	-1.1	\N	\N	\N	Hobart Bay	AK
97571	Klokachef Island, Alaska	NOS	9451858	57.4167	-135.89	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:06:00	0.1	\N	-00:10:00	-0.1	\N	\N	\N	Klokachef Island	AK
97572	Bear Bay, Alaska	NOS	9451859	57.4183	-135.583	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:29:00	0.2	\N	00:18:00	3.7	\N	\N	\N	Bear Bay	AK
97573	Killisnoo, Alaska	NOS	9451895	57.47	-134.565	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:04:00	0	\N	-00:06:00	-2.1	\N	\N	\N	Killisnoo	AK
97574	Gambier Bay (cannery wharf), Alaska	NOS	9451906	57.4833	-133.96	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:01:00	\N	0.96	-00:01:00	\N	0.92	\N	\N	Gambier Bay (cannery wharf)	AK
97575	Good Island, Gambier Bay, Alaska	NOS	9451909	57.4867	-133.898	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:04:00	\N	0.96	-00:05:00	\N	0.93	\N	\N	Good Island, Gambier Bay	AK
97576	Windham Bay, Alaska	NOS	9451962	57.5433	-133.498	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:00:00	-0.1	\N	00:00:00	-1.1	\N	\N	\N	Windham Bay	AK
97577	Nismeni Cove, Alaska	NOS	9451979	57.5617	-135.412	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:03:00	-0.1	\N	-00:15:00	-1.3	\N	\N	\N	Nismeni Cove	AK
97578	Upper Endicott Arm, North Shore, Stephens Passage, Alaska	NOS	9452005	57.5217	-133.055	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:06:00	\N	0.99	00:01:00	\N	0.98	\N	\N	Upper Endicott Arm, North Shore	AK
97579	Sawyer Island, Tracy Arm, Alaska	NOS	9452022	57.8783	-133.19	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:06:00	\N	1.01	00:02:00	\N	0.97	\N	\N	Sawyer Island, Tracy Arm	AK
97580	Holkham Bay, Wood Spit, Alaska	NOS	9452064	57.7183	-133.578	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:06:00	-0.1	\N	00:03:00	-0.8	\N	\N	\N	Holkham Bay, Wood Spit	AK
97581	Holkham Bay, Tracy Arm entrance, Alaska	NOS	9452067	57.76	-133.603	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:02:00	\N	0.96	00:01:00	\N	0.96	\N	\N	Holkham Bay, Tracy Arm Entrance	AK
97582	Port Snettisham, Crib Point, Alaska	NOS	9452082	58.0967	-133.742	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:03:00	\N	0.97	-00:03:00	\N	0.98	\N	\N	Port Snettisham, Crib Point	AK
97583	Taku Harbor, Alaska	NOS	9452123	58.0683	-134.012	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:04:00	\N	1	-00:03:00	\N	0.97	\N	\N	Taku Harbor	AK
97584	Taku Point, Taku Inlet, Alaska	NOS	9452124	58.4	-134.015	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:13:00	0	\N	00:14:00	0.4	\N	\N	\N	Taku Point, Taku Inlet	AK
97585	Rasp Ledge, Seymour Canal, Alaska	NOS	9452128	57.6783	-134.038	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:05:00	0.1	\N	00:06:00	-0.7	\N	\N	\N	Rasp Ledge, Seymour Canal	AK
97586	Greely Point, Taku Inlet, Alaska	NOS	9452133	58.2233	-134.06	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:04:00	-0.1	\N	-00:01:00	-0.6	\N	\N	\N	Greely Point, Taku Inlet	AK
97587	Young Bay, Alaska	NOS	9452249	58.1833	-134.587	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:02:00	\N	1	00:00:00	\N	1	\N	\N	Young Bay	AK
97588	Auke Bay, Alaska	NOS	9452263	58.3817	-134.645	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:03:00	0	\N	-00:06:00	-0.4	\N	\N	\N	Auke Bay	AK
97589	Barlow Cove, Mansfield Peninsula, Lynn Canal, Alaska	NOS	9452318	58.3217	-134.878	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:01:00	\N	0.99	-00:04:00	\N	0.96	\N	\N	Barlow Cove, Mansfield Peninsula	AK
97590	Funter, Funter Bay, Lynn Canal, Alaska	NOS	9452321	58.255	-134.895	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:01:00	0	\N	00:00:00	-1.1	\N	\N	\N	Funter, Funter Bay	AK
97591	Lincoln Island, Lynn Canal, Alaska	NOS	9452336	58.4983	-134.965	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:01:00	\N	1	-00:03:00	\N	0.98	\N	\N	Lincoln Island	AK
97592	Cove Point, Berner's Bay, Lynn Canal, Alaska	NOS	9452346	58.7517	-135.028	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:00:00	\N	1.02	-00:02:00	\N	1	\N	\N	Cove Point, Berner's Bay	AK
97593	Swanson Harbor, Icy Strait, Alaska	NOS	9452368	58.215	-135.127	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	00:11:00	\N	1.08	00:14:00	\N	1.41	\N	\N	Swanson Harbor	AK
97594	Tenakee Springs, Tenakee Inlet, Alaska	NOS	9452386	57.78	-135.212	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:05:00	-0.1	\N	-00:04:00	-1.5	\N	\N	\N	Tenakee Springs, Tenakee Inlet	AK
97595	William Henry Bay, Lynn Canal, Alaska	NOS	9452391	58.7133	-135.232	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:09:00	0	\N	00:02:00	-0.5	\N	\N	\N	William Henry Bay	AK
97596	Taiyasanka Harbor, Taiya Inlet, Lynn Canal, Alaska	NOS	9452434	59.3017	-135.428	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:02:00	\N	1.01	-00:04:00	\N	1.03	\N	\N	Taiyasanka Harbor, Taiya Inlet	AK
97597	Haines Inlet, Lynn Canal, Alaska	NOS	9452435	59.23	-135.433	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:06:00	0	\N	-00:09:00	0.5	\N	\N	\N	Haines Inlet	AK
97598	Excursion Inlet entrance, Icy Strait, Alaska	NOS	9452437	58.4167	-135.447	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	00:16:00	\N	1.05	00:15:00	\N	1.38	\N	\N	Excursion Inlet Entrance	AK
97599	Excursion Inlet, Icy Strait, Alaska	NOS	9452447	58.4967	-135.488	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	00:24:00	\N	1.07	00:26:00	\N	1.36	\N	\N	Excursion Inlet, North End	AK
97600	Point Adolphus, Icy Strait, Alaska	NOS	9452516	58.2867	-135.803	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	00:35:00	\N	1.11	00:29:00	\N	1.31	\N	\N	Point Adolphus	AK
97601	Mud Bay, Goose Island, Icy Strait, Alaska	NOS	9452567	58.2117	-136.035	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	00:06:00	\N	0.96	00:06:00	\N	1.2	\N	\N	Mud Bay, Goose Island	AK
97602	Elbow Passage, Klag Bay, Chichagof Island, Alaska	NOS	9452579	57.6133	-136.087	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	00:13:00	\N	1.03	00:08:00	\N	0.98	\N	\N	Elbow Passage, Klag Bay	AK
97603	Kimshan Cove, Ogden Passage, Chichagof Island, Alaska	NOS	9452583	57.6867	-136.107	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	00:06:00	\N	1.03	00:05:00	\N	0.92	\N	\N	Kimshan Cove, Ogden Passage	AK
97604	Muir Inlet, Glacier Bay, Alaska (sub)	NOS	9452584	58.9133	-136.108	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	00:49:00	\N	1.19	00:39:00	\N	1.55	\N	\N	Muir Inlet	AK
97605	Willoughby Island, Glacier Bay, Alaska	NOS	9452586	58.6083	-136.117	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	00:50:00	\N	1.16	00:41:00	\N	1.5	\N	\N	Willoughby Island	AK
97606	Inian Cove, North Inian Pass, Cross Sound, Alaska	NOS	9452629	58.2633	-136.325	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	00:03:00	\N	1.01	00:12:00	\N	1.05	\N	\N	Inian Cove, North Inian Pass	AK
97607	Wachusett Inlet, Glacier Bay, Alaska	NOS	9452632	58.9467	-136.333	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	00:50:00	\N	1.2	00:39:00	\N	1.57	\N	\N	Wachusett Inlet, Glacier Bay	AK
97608	Miner Island, Lisianski Strait and Inlet, Alaska	NOS	9452633	58.01	-136.342	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	-00:06:00	\N	0.96	-00:08:00	\N	0.94	\N	\N	Miner Island	AK
97609	Canoe Cove, North Pass, Lisianski Strait and Inlet, Alaska	NOS	9452649	57.8467	-136.422	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	-00:01:00	\N	0.89	00:02:00	\N	0.91	\N	\N	Canoe Cove, North Pass	AK
97610	Takanis Bay, Yakobi Island, outer coast, Alaska	NOS	9452671	57.9283	-136.52	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	-00:01:00	\N	1.03	-00:04:00	\N	0.9	\N	\N	Takanis Bay	AK
97611	Surge Bay, Yakobi Island, outer coast, Alaska	NOS	9452672	58.0183	-136.528	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	00:02:00	\N	0.96	00:00:00	\N	0.88	\N	\N	Surge Bay	AK
97612	Composite Island, Glacier Bay, Alaska	NOS	9452682	58.8883	-136.573	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	00:51:00	\N	1.2	00:45:00	\N	1.54	\N	\N	Composite Island	AK
97613	Graves Harbor, Alaska	NOS	9452704	58.2767	-136.678	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	00:07:00	\N	1.03	00:04:00	\N	0.91	\N	\N	Graves Harbor	AK
97614	Dixon Harbor, Alaska	NOS	9452747	58.3833	-136.867	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	00:07:00	\N	0.96	00:07:00	\N	0.89	\N	\N	Dixon Harbor	AK
97615	Lituya Bay, 2 mi inside entrance, Alaska	NOS	9452928	58.6167	-137.65	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	00:36:00	\N	0.89	00:06:00	\N	0.87	\N	\N	Lituya Bay, 2 miles inside entrance	AK
97616	Redfield Cove, Yakutat Bay, Alaska	NOS	9453208	59.6117	-139.58	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95666	00:00:00	\N	0.92	00:01:00	\N	1	\N	\N	Redfield Cove, Yakutat Bay	AK
97617	Point Latouche, Yakutat Bay, Alaska	NOS	9453210	59.9033	-139.627	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95666	00:03:00	\N	0.93	00:06:00	\N	1	\N	\N	Point Latouche, Yakutat Bay	AK
97618	Johnstone Passage, Yakutat Bay, Alaska	NOS	9453215	59.5817	-139.702	:America/Yakutat	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95666	00:03:00	\N	1	00:01:00	\N	1	\N	\N	Johnstone Passage, Yakutat Bay	AK
97619	Tyndall Glacier, Icy Bay, Alaska (sub)	NOS	9453431	60.0780556	-141.2769444	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95666	00:17:00	\N	0.97	00:20:00	\N	0.96	\N	\N	Tyndall Glacier, Icy Bay	AK
97620	Riou Bay, Alaska	NOS	9453456	59.885	-141.457	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95666	00:03:00	\N	1.01	00:02:00	\N	0.98	\N	\N	Icy Bay	AK
97621	Shag Rock, Orca Inlet, Alaska	NOS	9454125	60.465	-145.988	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:16:00	-0.1	\N	-00:11:00	-1.1	\N	\N	\N	Shag Rock	AK
97622	Comfort Cove, Port Gravina, Prince William Sound, Alaska	NOS	9454157	60.71	-146.085	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:06:00	-0.1	\N	-00:16:00	-0.7	\N	\N	\N	Comfort Cove, Port Gravina	AK
97623	Middleton Island (north end), Alaska	NOS	9454224	59.4617	-146.31	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:14:00	-0.1	\N	-00:21:00	-2.2	\N	\N	\N	Middleton Island (north end)	AK
97624	Landlocked Bay, Port Fidalgo, Prince William Sound, Alaska	NOS	9454296	60.8533	-146.535	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:08:00	-0.1	\N	-00:12:00	-0.7	\N	\N	\N	Landlocked Bay, Port Fidalgo	AK
97625	Jack Bay, Valdez Arm, Alaska	NOS	9454309	61.04	-146.615	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95671	-00:02:00	\N	0.99	-00:01:00	\N	0.99	\N	\N	Jack Bay	AK
97626	Johnstone Point, Hinchinbrook Island, Alaska	NOS	9454319	60.4817	-146.61	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	00:02:00	-0.1	\N	-00:07:00	-0.8	\N	\N	\N	Johnstone Point	AK
97627	Rocky Point, Valdez Arm, Alaska	NOS	9454363	60.94670104980469	-146.7550048828125	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95671	-00:03:00	\N	0.99	00:00:00	\N	0.99	\N	\N	Rocky Point	AK
97628	Busby Island, Valdez Arm, Alaska	NOS	9454374	60.8983	-146.782	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95671	-00:02:00	\N	0.98	-00:02:00	\N	0.98	\N	\N	Busby Island	AK
97629	Jackson Cove, Glacier Island, Prince William Sound, Alaska	NOS	9454507	60.88	-147.223	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:02:00	0	\N	-00:10:00	-0.6	\N	\N	\N	Jackson Cove, Glacier Island	AK
97630	Port Chalmers, Montague Island, Alaska	NOS	9454511	60.2418	-147.249	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:01:00	\N	0.97	-00:02:00	\N	0.94	\N	\N	Port Chalmers	AK
97631	Naked Island, McPherson Passage, Prince William Sound, Alaska	NOS	9454563	60.6833	-147.388	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:08:00	-0.1	\N	-00:18:00	-0.7	\N	\N	\N	Naked Island, McPherson Passage	AK
97632	Gibbon Anchorage, Green Island, Prince William Sound, Alaska	NOS	9454573	60.27	-147.438	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:06:00	-0.2	\N	-00:21:00	-0.8	\N	\N	\N	Gibbon Anchorage, Green Island	AK
97633	Patton Bay, Montague Island, Alaska	NOS	9454574	59.9067	-147.45	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:05:00	-0.1	\N	-00:12:00	-2.3	\N	\N	\N	Patton Bay	AK
97634	Louis Bay, Knight Island, Prince William Sound, Alaska	NOS	9454642	60.4617	-147.672	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	00:03:00	\N	1.04	00:00:00	\N	0.96	\N	\N	Louis Bay	AK
97635	Point Helen, Knight Island, Alaska	NOS	9454671	60.1533	-147.767	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:01:00	\N	1	-00:03:00	\N	0.92	\N	\N	Point Helen	AK
97636	Port Audrey, Knight Island, Alaska	NOS	9454673	60.3433	-147.768	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	00:03:00	\N	0.95	00:00:00	\N	0.92	\N	\N	Port Audrey	AK
97637	Macleod Harbor, Montague Island, Prince William Sound, Alaska	NOS	9454674	59.88999938964844	-147.7949981689453	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:04:00	\N	0.96	00:10:00	\N	0.89	\N	\N	Macleod Harbor	AK
97638	Latouche, Latouche Island, Prince William Sound, Alaska	NOS	9454713	60.0533	-147.907	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:02:00	0	\N	-00:05:00	-1	\N	\N	\N	Latouche, Latouche Island	AK
97639	Eshamy Bay, Knight Island Passage, Prince William Sound, Alaska	NOS	9454735	60.4483	-147.978	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	00:04:00	0	\N	00:01:00	-0.4	\N	\N	\N	Eshamy Bay, Knight Island Passage	AK
97640	Eshamy Lagoon, Prince William Sound, Alaska	NOS	9454757	60.4617	-148.045	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	00:00:00	\N	1.03	-00:11:00	\N	0.92	\N	\N	Eshamy Lagoon	AK
97641	Sawmill Bay, Evans Island, Prince William Sound, Alaska	NOS	9454764	60.0517	-148.065	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	00:03:00	0	\N	-00:03:00	-1.2	\N	\N	\N	Sawmill Bay, Evans Island	AK
97642	Chenega Island, southwest end, Prince William Sound, Alaska	NOS	9454777	60.2833	-148.113	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	00:00:00	\N	1	-00:03:00	\N	0.94	\N	\N	Chenega Island, southwest end	AK
97643	Chenega Island, Dangerous Passage, Prince William Sound, Alaska	NOS	9454787	60.33	-148.143	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	00:06:00	0	\N	-00:01:00	-0.9	\N	\N	\N	Chenega Island, Dangerous Passage	AK
97644	Applegate Island, Prince William Sound, Alaska	NOS	9454794	60.6233	-148.165	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	00:06:00	0	\N	-00:01:00	-0.6	\N	\N	\N	Applegate Island	AK
97645	Culross Bay, Wells Passage, Prince William Sound, Alaska	NOS	9454798	60.7417	-148.172	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:01:00	0	\N	-00:15:00	-0.4	\N	\N	\N	Culross Bay, Wells Passage	AK
97646	Hogg Bay, Port Bainbridge, Prince William Sound, Alaska	NOS	9454805	60.0767	-148.195	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:03:00	-0.1	\N	-00:12:00	-1.9	\N	\N	\N	Hogg Bay, Port Bainbridge	AK
95256	Santa Rosa, Hogtown Bayou, Choctawhatchee Bay, Florida	NOS	8729376	30.4	-86.2283	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	SANTA ROSA HOGTOWN BAYOU	FL
97647	Long Bay entrance, Culross Passage, Prince William Sound, Alaska	NOS	9454825	60.6917	-148.263	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	00:09:00	-0.1	\N	00:03:00	-0.9	\N	\N	\N	Long Bay Entrance, Culross Passage	AK
97648	Kings Bay, Port Nellie Juan, Prince William Sound, Alaska	NOS	9454887	60.5417	-148.46	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	00:09:00	0	\N	-00:01:00	-0.6	\N	\N	\N	Kings Bay, Port Nellie Juan	AK
97649	Day Harbor, Alaska	NOS	9455036	60.01	-149.062	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95687	00:00:00	\N	1.01	-00:02:00	\N	0.99	\N	\N	Day Harbor	AK
97650	Bear Cove, Aialik Peninsula, Alaska	NOS	9455128	59.8017	-149.615	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95687	00:01:00	\N	0.97	00:01:00	\N	1	\N	\N	Bear Cove, Aialik Peninsula	AK
97651	Two Arm Bay, Harris Bay, Alaska	NOS	9455217	59.6617	-150.108	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95687	-00:05:00	\N	0.94	-00:10:00	\N	1.03	\N	\N	Two Arm Bay, Harris Bay	AK
97652	Chance Cove (Lagoon), Alaska	NOS	9455249	59.4883	-150.312	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95687	00:01:00	\N	1.01	00:00:00	\N	1.04	\N	\N	Chance Cove (Lagoon)	AK
97653	Beauty Bay, Nuka Bay, Alaska	NOS	9455304	59.5267	-150.628	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95687	00:14:00	\N	1.01	00:12:00	\N	1.08	\N	\N	Beauty Bay, Nuka Bay	AK
97654	Nuka Passage, Alaska	NOS	9455308	59.4083	-150.667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95687	00:12:00	\N	1.01	00:11:00	\N	1.09	\N	\N	Nuka Passage	AK
97655	Takoma Cove, Port Dick, Alaska	NOS	9455347	59.2617	-150.982	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95687	00:18:00	\N	1.01	00:23:00	\N	1.15	\N	\N	Takoma Cove, Port Dick	AK
97656	Picnic Harbor, Rocky Bay, Alaska	NOS	9455399	59.255	-151.42	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95687	00:21:00	\N	1.01	00:26:00	\N	1.23	\N	\N	Picnic Harbor, Rocky Bay	AK
97657	Port Chatham, Cook Inlet, Alaska	NOS	9455428	59.2133	-151.728	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	-00:34:00	\N	0.92	-00:28:00	\N	0.78	\N	\N	Port Chatham	AK
97658	Port Graham, Cook Inlet, Alaska	NOS	9455437	59.35	-151.8266666666667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	-00:14:00	0	\N	-00:08:00	-1	\N	\N	\N	Port Graham	AK
97659	Ushagat Island, Barren Islands, Cook Inlet, Alaska	NOS	9455478	58.9467	-152.268	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	-00:04:00	\N	0.76	-00:08:00	\N	0.76	\N	\N	Ushagat Island, Barren Islands	AK
97660	Tutka Bay,Kachemak Bay, Cook Inlet, Alaska	NOS	9455506	59.4317	-151.357	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	-00:01:00	0	\N	-00:01:00	0.2	\N	\N	\N	Tutka Bay,Kachemak Bay	AK
97661	Sadie Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455514	59.49	-151.365	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	-00:04:00	-0.1	\N	-00:04:00	0.1	\N	\N	\N	Sadie Cove, Kachemak Bay	AK
97662	Halibut Cove, Kachemak Bay, Cook Inlet, Alaska	NOS	9455556	59.5967	-151.22	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	-00:05:00	0	\N	-00:03:00	0.7	\N	\N	\N	Halibut Cove, Kachemak Bay	AK
97663	Drift River Terminal, Cook Inlet, Alaska	NOS	9455741	60.555	-152.133	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	02:04:00	\N	1.18	01:39:00	\N	1.01	\N	\N	Drift River Terminal	AK
97664	Kenai City Pier, Cook Inlet, Alaska	NOS	9455742	60.545	-151.218	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	02:55:00	-0.1	\N	01:54:00	1.9	\N	\N	\N	Kenai City Pier	AK
97665	Snug Harbor, Cook Inlet, Alaska	NOS	9456173	60.10747222222222	-152.5816666666667	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	01:15:00	0	\N	01:04:00	-2.3	\N	\N	\N	Snug Harbor, Cook Inlet	AK
97666	Tuxedni Channel, Cook Inlet, Alaska	NOS	9456204	60.1533	-152.635	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	00:53:00	0.2	\N	00:39:00	-1.3	\N	\N	\N	Tuxedni Channel	AK
97667	Oil Bay, Kamishak Bay, Cook Inlet, Alaska	NOS	9456463	59.64	-153.262	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	01:16:00	\N	0.83	01:15:00	\N	0.77	\N	\N	Oil Bay, Kamishak Bay	AK
97668	Nordyke Island, Kamishak Bay, Cook Inlet, Alaska	NOS	9456822	59.1783	-154.087	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	00:22:00	-0.2	\N	00:10:00	-2.8	\N	\N	\N	Nordyke Island, Kamishak Bay	AK
97669	Kukak, Kukak Bay, Alaska	NOS	9456835	58.3417	-154.117	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	00:05:00	\N	0.74	-00:08:00	\N	0.74	\N	\N	Kukak, Kukak Bay	AK
97670	Takli Island, Shelikof Strait, Alaska	NOS	9456992	58.0633	-154.477	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	00:03:00	\N	1	-00:09:00	\N	0.73	\N	\N	Takli Island, Shelikof Strait	AK
97671	Tonki Bay, Alaska	NOS	9457152	58.31669998168945	-152.06700134277344	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:21:00	0.2	\N	00:12:00	2.3	\N	\N	\N	Tonki Bay	AK
97672	Seal Bay, Alaska	NOS	9457201	58.3717	-152.238	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:36:00	0.3	\N	00:29:00	2.4	\N	\N	\N	Seal Bay	AK
97673	Andreon Bay, Shuyak Island, Alaska	NOS	9457259	58.5183	-152.415	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:44:00	0.3	\N	00:35:00	2.5	\N	\N	\N	Andreon Bay, Shuyak Island	AK
97674	Kodiak, Port of Kodiak, Alaska	NOS	9457261	57.7833	-152.428	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	-00:02:00	0	\N	-00:03:00	0	\N	\N	\N	Kodiak, Port of Kodiak	AK
97675	Spruce Island (north side), Alaska	NOS	9457262	57.9383	-152.417	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:08:00	0.1	\N	00:02:00	0.4	\N	\N	\N	Spruce Island (north side)	AK
97676	Perenosa Bay, Afognak Island, Alaska	NOS	9457271	58.3567	-152.448	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:39:00	0.3	\N	00:28:00	2.5	\N	\N	\N	Perenosa Bay	AK
97677	Kodiak, St. Paul Harbor, Alaska	NOS	9457283	57.745	-152.483	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	-00:02:00	0	\N	-00:05:00	-0.1	\N	\N	\N	Kodiak, St. Paul Harbor	AK
97678	Carry Inlet, Shuyak Island, Alaska	NOS	9457293	58.5867	-152.513	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	00:07:00	\N	0.73	00:06:00	\N	0.73	\N	\N	Carry Inlet	AK
97679	Redfox Bay, Shuyak Strait, Alaska	NOS	9457316	58.4533	-152.595	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	-00:02:00	-0.2	\N	-00:14:00	-4.4	\N	\N	\N	Redfox Bay, Shuyak Strait	AK
97680	Big Bay, Shuyak Island, Alaska	NOS	9457321	58.555	-152.613	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	00:15:00	\N	0.77	00:10:00	\N	0.77	\N	\N	Big Bay	AK
97681	Ugak Bay (Saltery Cove), Alaska	NOS	9457351	57.4817	-152.718	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	-00:20:00	-0.1	\N	-00:29:00	-0.3	\N	\N	\N	Ugak Bay (Saltery Cove)	AK
97682	Fox Bay, Whale Island, Alaska	NOS	9457361	57.9783	-152.755	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:37:00	0.2	\N	00:22:00	1.2	\N	\N	\N	Fox Bay, Whale Island	AK
97683	Kizhuyak Bay, Alaska	NOS	9457401	57.82	-152.9	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:11:00	0	\N	00:06:00	0.8	\N	\N	\N	Kizhuyak Bay	AK
97684	Port Hobron, Sitkalidak Island, Alaska	NOS	9457479	57.1633	-153.152	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	-00:06:00	0.1	\N	-00:18:00	-0.3	\N	\N	\N	Port Hobron, Sitkalidak Island	AK
97685	Dolphin Point, Raspberry Strait, Alaska	NOS	9457481	58.11	-153.155	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	-00:05:00	-0.1	\N	-00:25:00	-4.1	\N	\N	\N	Dolphin Point, Raspberry Strait	AK
97686	Zachar Bay, Uyak Bay, Alaska	NOS	9457648	57.5483	-153.735	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	00:00:00	\N	0.77	-00:09:00	\N	0.77	\N	\N	Zachar Bay	AK
97687	Mining Camp, Uyak Bay, Alaska	NOS	9457671	57.46	-153.817	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	-00:10:00	-0.1	\N	-00:37:00	-4.1	\N	\N	\N	Mining Camp	AK
97688	Moser Bay (Trap Point), Alaska	NOS	9457773	57.0017	-154.148	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95728	00:10:00	\N	1.01	00:11:00	\N	0.99	\N	\N	Moser Bay (Trap Point)	AK
97689	Olga Bay (A. P. A. Cannery), Alaska	NOS	9457798	57.1617	-154.228	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95728	03:54:00	\N	0.06	03:46:00	\N	0.1	\N	\N	Olga Bay (A. P. A. Cannery)	AK
97690	Kanatak Lagoon, Portage Bay, Alaska	NOS	9458365	57.52000045776367	-156.052001953125	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:51:00	0.3	\N	00:21:00	3	\N	\N	\N	Kanatak Lagoon, Portage Bay	AK
97691	Unavikshak Island, Alaska	NOS	9458762	56.4917	-157.74	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:44:00	\N	1.24	00:31:00	\N	1.05	\N	\N	Unavikshak Island	AK
97692	Nakchamik Island, Alaska	NOS	9458779	56.3517	-157.812	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:41:00	\N	1.33	00:29:00	\N	1.04	\N	\N	Nakchamik Island	AK
97693	Kujulik Bay (North Shore), Alaska	NOS	9458819	56.6133	-157.983	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:46:00	\N	1.35	00:31:00	\N	1.1	\N	\N	Kujulik Bay (North Shore)	AK
97694	Chankliut Island, Alaska	NOS	9458849	56.1467	-158.107	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:43:00	\N	1.27	00:32:00	\N	0.98	\N	\N	Chankliut Island	AK
97695	Chignik, Anchorage Bay, Alaska	NOS	9458917	56.2967	-158.4	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:44:00	\N	1.28	00:34:00	\N	1.04	\N	\N	Chignik, Anchorage Bay	AK
97696	Chiachi Island (east side), Alaska	NOS	9459085	55.8433	-159.105	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:37:00	\N	1.28	00:22:00	\N	0.89	\N	\N	Chiachi Island (east side)	AK
97697	Kupreanof Harbor, Paul Island, Alaska	NOS	9459145	55.79	-159.35	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:35:00	\N	1.28	00:19:00	\N	0.89	\N	\N	Kupreanof Harbor, Paul Island	AK
97698	Dent Point, Stepovak Bay, Alaska	NOS	9459281	55.7833	-159.88	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:33:00	\N	1.19	00:17:00	\N	0.86	\N	\N	Dent Point, Stepovak Bay	AK
97699	Sanborn Harbor, Nagai Island, Shumagin Islands, Alaska	NOS	9459311	55.155	-159.995	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95738	-00:03:00	\N	0.98	00:03:00	\N	1	\N	\N	Sanborn Harbor, Nagai Island	AK
97700	Pirate Cove, Popof Island, Shumagin Islands, Alaska	NOS	9459398	55.3617	-160.36	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95738	00:03:00	\N	0.98	00:08:00	\N	1.03	\N	\N	Pirate Cove, Popof Island	AK
97701	Albatross Anchorage, Balboa Bay, Alaska	NOS	9459464	55.59	-160.613	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95738	00:03:00	\N	1.05	-00:02:00	\N	1.06	\N	\N	Albatross Anchorage, Balboa Bay	AK
97702	Beaver Bay, Alaska	NOS	9459522	55.4733	-160.84	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:02:00	\N	1.05	00:03:00	\N	1.01	\N	\N	Beaver Bay	AK
97703	Seal Cape, Coal Bay, Alaska	NOS	9459643	55.365	-161.325	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95738	00:05:00	\N	1.05	00:00:00	\N	0.98	\N	\N	Seal Cape, Coal Bay	AK
97704	Ukolnoi Island, Alaska	NOS	9459696	55.2583	-161.537	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95738	00:00:00	\N	0.98	00:07:00	\N	0.97	\N	\N	Ukolnoi Island	AK
97705	Lenard Harbor, Cold Bay, Alaska	NOS	9459895	55.1183	-162.378	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95738	00:17:00	\N	0.98	00:12:00	\N	0.98	\N	\N	Lenard Harbor, Cold Bay	AK
97706	Peterson Bay, Sanak Islands, Alaska	NOS	9459939	54.3933	-162.637	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95738	-00:08:00	\N	1.05	-00:05:00	\N	0.83	\N	\N	Peterson Bay	AK
97707	Sanak Harbor, Sanak Islands, Alaska	NOS	9459968	54.4817	-162.812	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95738	00:03:00	\N	1.05	00:14:00	\N	0.89	\N	\N	Sanak Harbor	AK
97708	Ogliuga Island (east coast), Delarof Islands, Alaska	NOS	9461081	51.6033	-178.617	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-00:43:00	\N	0.95	00:01:00	\N	0.95	\N	\N	Ogliuga Island (east coast)	AK
97709	Lash Bay, Tanaga Island, Alaska	NOS	9461132	51.6717	-178.045	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-01:39:00	\N	1.14	-00:56:00	\N	1.14	\N	\N	Lash Bay	AK
97710	Tanaga Bay, Tanaga Island, Alaska	NOS	9461138	51.7183	-177.997	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-00:32:00	\N	1.08	-00:06:00	\N	1.08	\N	\N	Tanaga Bay	AK
97711	Hot Springs Bay, Tanaga Island, Alaska	NOS	9461162	51.7783	-177.8	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-00:12:00	\N	0.84	-00:40:00	\N	0.84	\N	\N	Hot Springs Bay	AK
97712	Cape Chunu, Kanaga Island, Alaska	NOS	9461183	51.665	-177.637	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-01:54:00	\N	1.11	-01:44:00	\N	1.11	\N	\N	Cape Chunu	AK
97713	Kanaga Bay, Kanaga Island, Alaska	NOS	9461264	51.7183	-177.2	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-01:44:00	\N	1.05	-01:39:00	\N	1.05	\N	\N	Kanaga Bay	AK
97714	Cape Chlanak, Kanaga Island, Alaska	NOS	9461276	51.71	-177.145	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-01:34:00	\N	0.92	-01:22:00	\N	0.92	\N	\N	Cape Chlanak	AK
97715	Shoal Point, Kanaga Island, Alaska	NOS	9461292	51.87	-177.068	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-00:16:00	\N	0.86	00:01:00	\N	0.86	\N	\N	Shoal Point	AK
97716	Bay of Waterfalls, Adak Island, Alaska	NOS	9461337	51.6417	-176.825	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-02:04:00	\N	0.95	-01:20:00	\N	0.95	\N	\N	Bay of Waterfalls	AK
97719	Adak Bight, Adak Island, Alaska	NOS	9461406	51.77	-176.435	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-02:02:00	\N	1	-01:24:00	\N	1	\N	\N	Adak Bight	AK
97720	Laska Cove, Kagalaska Island, Aleutian Islands, Alaska	NOS	9461411	51.825	-176.402	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	00:07:00	\N	0.97	-00:04:00	\N	0.97	\N	\N	Laska Cove, Kagalaska Island	AK
97721	Sand Bay, Great Sitkin Island, Aleutian Islands, Alaska	NOS	9461453	51.9733	-176.085	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-00:20:00	\N	0.97	-00:05:00	\N	0.97	\N	\N	Sand Bay, Great Sitkin Island	AK
97722	Bugle Point, Great Sitkin Island, Aleutian Islands, Alaska	NOS	9461467	52.0383	-175.98	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-00:05:00	\N	0.89	00:01:00	\N	0.89	\N	\N	Bugle Point, Great Sitkin Island	AK
97723	Fenimore Pass, Aleutian Islands, Alaska	NOS	9461519	51.96	-175.588	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-00:13:00	\N	0.89	-00:04:00	\N	0.89	\N	\N	Fenimore Pass	AK
97724	Atka Pass, east end, Atka Island, Alaska	NOS	9461555	52.0067	-175.32	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-02:10:00	\N	1.24	-01:07:00	\N	1.24	\N	\N	Atka Pass, east end	AK
97725	Bechevin Bay, Atka Island, Alaska	NOS	9461582	52.0367	-175.115	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	00:04:00	\N	0.95	00:11:00	\N	0.95	\N	\N	Bechevin Bay	AK
97726	Explorer Bay, Atka Island, Alaska	NOS	9461656	52.0733	-174.568	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-02:24:00	\N	1.24	-02:43:00	\N	1.24	\N	\N	Explorer Bay	AK
97727	Sagchudak Island, Atka Island, Alaska	NOS	9461667	52.0267	-174.48	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-02:25:00	\N	1.24	-01:26:00	\N	1.24	\N	\N	Sagchudak Island	AK
97728	Martin Harbor, Korovin Bay, Atka Island, Alaska	NOS	9461693	52.2267	-174.292	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	00:21:00	\N	0.87	00:19:00	\N	0.87	\N	\N	Martin Harbor, Korovin Bay	AK
97729	Cape Utalug (4 mi west of), Atka Island, Alaska	NOS	9461704	52.1183	-174.207	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-02:32:00	\N	1.19	-01:38:00	\N	1.19	\N	\N	Cape Utalug (4 miles west of)	AK
97730	Finch Cove, Seguam Island, Aleutian Islands, Alaska	NOS	9461945	52.3917	-172.405	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	00:07:00	\N	0.87	-01:00:00	\N	0.87	\N	\N	Finch Cove, Seguam Island	AK
97731	North side, Yunaska Island, Alaska	NOS	9462144	52.6817	-170.707	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-01:29:00	\N	1.19	-01:05:00	\N	1.02	\N	\N	North side	AK
97732	East Cove, Yunaska Island, Alaska	NOS	9462161	52.6533	-170.563	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-02:35:00	\N	0.85	-01:36:00	\N	0.88	\N	\N	East Cove	AK
97733	Applegate Cove, Chuginadak Island, Aleutian Islands, Alaska	NOS	9462239	52.8617	-169.862	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-00:58:00	\N	1.27	-00:21:00	\N	1.08	\N	\N	Applegate Cove, Chuginadak Island	AK
97734	Adugak Island, Aleutian Islands, Alaska	NOS	9462317	52.9117	-169.165	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-00:56:00	\N	1.1	-00:33:00	\N	1.02	\N	\N	Adugak Island	AK
97735	Cape Sagak, Umnak Island, Alaska	NOS	9462331	52.8417	-169.043	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-03:16:00	\N	1.02	-03:03:00	\N	1.2	\N	\N	Cape Sagak	AK
97736	Okee Bay, Umnak Island, Alaska	NOS	9462354	53.0167	-168.835	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-00:43:00	\N	1.1	-00:07:00	\N	0.99	\N	\N	Okee Bay	AK
97737	Driftwood Bay, Umnak Island, Alaska	NOS	9462367	52.9583	-168.72	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-03:22:00	\N	1.1	-02:56:00	\N	1.35	\N	\N	Driftwood Bay	AK
97738	Kigul Island, Umnak Island, Alaska	NOS	9462398	53.045	-168.442	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-03:42:00	\N	1.27	-03:04:00	\N	1.37	\N	\N	Kigul Island	AK
97739	Inanudak Bay, Umnak Island, Alaska	NOS	9462408	53.2967	-168.352	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-00:30:00	\N	0.93	-00:06:00	\N	0.96	\N	\N	Inanudak Bay	AK
97740	Bogoslof Island, Aleutian Islands, Alaska	NOS	9462444	53.93	-168.033	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-00:55:00	\N	1.1	-00:30:00	\N	1.08	\N	\N	Bogoslof Island	AK
97741	Otter Point, Umnak Island, Alaska	NOS	9462465	53.3967	-167.843	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-00:40:00	\N	0.93	-00:27:00	\N	0.88	\N	\N	Otter Point	AK
97742	Chernofski Harbor, Unalaska Island, Alaska	NOS	9462501	53.395	-167.533	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-00:29:00	\N	1.1	-00:10:00	\N	1.02	\N	\N	Chernofski Harbor	AK
97743	Skan Bay, Unalaska Island, Alaska	NOS	9462554	53.61	-167.045	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-00:19:00	\N	1.1	-00:07:00	\N	1.05	\N	\N	Skan Bay	AK
97744	Kuliliak Bay, Unalaska Island, Alaska	NOS	9462557	53.4617	-167.02	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-03:35:00	\N	1.27	-03:10:00	\N	1.46	\N	\N	Kuliliak Bay	AK
97745	Raven Bay, Unalaska Island, Alaska	NOS	9462573	53.475	-166.873	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-03:48:00	\N	1.27	-03:16:00	\N	1.49	\N	\N	Raven Bay	AK
97746	Anderson Bay, Unalaska Island, Alaska	NOS	9462578	53.6783	-166.832	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	00:28:00	\N	1.1	-00:01:00	\N	1.08	\N	\N	Anderson Bay	AK
97747	Usof Bay, Unalaska Island, Alaska	NOS	9462582	53.515	-166.79	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-03:45:00	\N	1.19	-03:30:00	\N	1.55	\N	\N	Usof Bay	AK
97748	Kisselen Bay, Beaver Inlet, Unalaska Island, Alaska	NOS	9462606	53.7133	-166.572	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-03:14:00	\N	1.1	-02:59:00	\N	1.4	\N	\N	Kisselen Bay, Beaver Inlet	AK
97749	Dutch Harbor, Amaknak Island, Unalaska Island, Alaska	NOS	9462611	53.8917	-166.537	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-00:07:00	\N	1	00:00:00	\N	1	\N	\N	Dutch Harbor, Amaknak Island	AK
97750	Udagak Strait, Unalaska Island, Alaska	NOS	9462637	53.7367	-166.295	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-03:59:00	\N	1.02	-03:32:00	\N	1.37	\N	\N	Udagak Strait	AK
97751	English Bay, Unalaska Island, Alaska	NOS	9462641	53.925	-166.257	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-00:01:00	\N	0.76	00:16:00	\N	0.79	\N	\N	English Bay	AK
97752	Akutan Harbor, Akutan Island, Aleutian Islands, Alaska	NOS	9462691	54.1283	-165.808	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-00:07:00	\N	1.1	-00:17:00	\N	1.08	\N	\N	Akutan Harbor, Akutan Island	AK
97753	Cape Mordvinof, Unimak Island, Alaska	NOS	9462838	54.9283	-164.467	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	00:19:00	\N	1.36	00:26:00	\N	1.73	\N	\N	Cape Mordvinof	AK
97754	St. Catherine Cove, Unimak Island, Alaska	NOS	9462944	55.01	-163.507	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-00:18:00	\N	1.36	00:04:00	\N	1.23	\N	\N	St. Catherine Cove	AK
97755	Dora Harbor, Unimak Island, Alaska	NOS	9462971	54.71	-163.267	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95738	00:15:00	\N	1.05	00:15:00	\N	0.87	\N	\N	Dora Harbor	AK
97756	Amak Island, Bristol Bay, Alaska	NOS	9462987	55.4133	-163.115	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	01:48:00	\N	1.78	01:47:00	\N	2.13	\N	\N	Amak Island	AK
97757	Grant Point, Izembek Lagoon, Bristol Bay, Alaska	NOS	9463058	55.27	-162.9	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	04:05:00	\N	0.85	03:03:00	\N	1.23	\N	\N	Grant Point, Izembek Lagoon	AK
97758	Settlement Point, Pavlof Bay, Alaska	NOS	9463195	55.5	-161.46666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95738	00:08:00	\N	0.9	00:09:00	\N	0.98	\N	\N	Settlement Point, Pavlof Bay	AK
97759	Egegik River entrance, Alaska	NOS	9464881	58.2383	-157.5	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95765	03:47:00	\N	1.14	03:16:00	\N	1.69	\N	\N	Egegik River Ent, Bristol Bay	AK
97760	Middle Bluff, Kvichak Bay, Bristol Bay, Alaska	NOS	9465022	58.4533	-157.5	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95765	04:10:00	\N	1.14	03:56:00	\N	1.84	\N	\N	Middle Bluff, Kvichak Bay	AK
97761	King Salmon Airport, Naknek River, Alaska	NOS	9465149	58.67169952392578	-156.65699768066406	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95776	00:23:00	\N	0.67	-02:11:00	\N	0.17	\N	\N	King Salmon Airport	AK
97762	Omakstalia Point, Naknek River, Alaska	NOS	9465174	58.70669937133789	-156.7570037841797	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95776	-00:48:00	\N	1.03	-02:54:00	\N	0.44	\N	\N	Omakstalia Point	AK
97763	Black Rock, Walrus Islands, Nushagak Bay, Alaska	NOS	9465182	58.70830154418945	-160.18800354003906	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95765	04:53:00	\N	0.82	04:53:00	\N	0.8	\N	\N	Black Rock, Walrus Islands	AK
97764	Kvichak, Kvichak River, Alaska	NOS	9465342	58.97	-156.947	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95765	07:49:00	\N	0.41	05:21:00	\N	1.54	\N	\N	Kvichak	AK
97765	Goodnews Bay entrance, Alaska	NOS	9465368	59.045	-161.808	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95783	00:11:00	\N	0.95	00:04:00	\N	1.01	\N	\N	Goodnews Bay entrance	AK
97766	Apokak Creek entrance, Eenayarak River, Alaska	NOS	9466079	60.1367	-162.158	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95783	04:30:00	\N	0.79	03:18:00	\N	1.47	\N	\N	Apokak Creek entrance	AK
97767	St. Matthew Island, Bering Sea, Alaska	NOS	9466203	60.358299255371094	-172.71499633789062	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95768	00:29:00	\N	0.61	00:06:00	\N	0.61	\N	\N	St. Matthew Island	AK
97768	Pikmiktalik River entrance, Norton Sound, Alaska	NOS	9468011	63.28	-162.602	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95814	-01:13:00	\N	1.08	-01:13:00	\N	1.08	\N	\N	Pikmiktalik River entrance	AK
97769	Fossil River entrance, St. Lawrence Island, Alaska	NOS	9468123	63.4667	-170.017	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95816	-03:08:00	\N	0.67	-03:00:00	\N	1.13	\N	\N	Fossil River entrance	AK
97770	St. Michael, Norton Sound, Alaska (sub)	NOS	9468132	63.475	-162.027	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95814	-02:16:00	\N	1	-00:11:00	\N	1	\N	\N	St. Michael	AK
97771	Niyrakpak Lagoon entrance, St. Lawrence Island, Alaska	NOS	9468216	63.62	-171.383	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95816	-03:31:00	\N	0.67	-03:27:00	\N	0.83	\N	\N	Niyrakpak Lagoon entrance	AK
97772	North Bay, Stuart Island, Norton Sound, Alaska	NOS	9468226	63.6283	-162.517	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95814	-00:28:00	\N	0.72	-00:28:00	\N	0.72	\N	\N	North Bay, Stuart Island	AK
97773	Point Barrow, Alaska	NOS	9495048	71.36	-156.353	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	-00:26:00	\N	0.04	-00:37:00	\N	0.04	\N	\N	Point Barrow	AK
97774	Redhook Bay, St. Thomas, Virgin Islands	NOS	9751540	18.3267	-64.8517	:America/St_Thomas	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95864	00:44:00	\N	1.28	-00:46:00	\N	1.28	\N	\N	Redhook Bay, St. Thomas Island	VI
97775	Troy, Hudson River, New York	NOS	TEC1603	42.71666666666667	-73.7	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94846	00:10:00	\N	1	00:08:00	\N	1	\N	\N	Troy	NY
97776	Chelsea, Arthur Kill, New Jersey	NOS	TEC1645	40.6	-74.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94857	00:37:00	\N	1.05	00:23:00	\N	1.07	\N	\N	Chelsea	NJ
97777	Cape Hatteras, North Carolina	NOS	TEC2789	35.23333333333299	-75.516666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	00:01:00	\N	1.08	00:01:00	\N	1	\N	\N	Cape Hatteras	NC
97778	Hatteras Inlet, North Carolina	NOS	TEC2791	35.2	-75.733333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	00:13:00	\N	0.83	00:08:00	\N	0.66	\N	\N	Hatteras Inlet	NC
97779	Ocracoke Inlet, North Carolina	NOS	TEC2793	35.06666666666701	-76.016666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	00:11:00	\N	0.83	00:09:00	\N	0.63	\N	\N	Ocracoke Inlet	NC
97780	Shell Point, Harkers Island, Back Sound, North Carolina	NOS	TEC2801	34.68333333333299	-76.53333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	02:34:00	\N	0.83	01:52:00	\N	0.54	\N	\N	Shell Point, Harkers Island	NC
97781	N.C. State Fisheries, Bogue Sound, North Carolina	NOS	TEC2831	34.71666666666701	-76.75	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	01:32:00	\N	0.83	01:05:00	\N	0.66	\N	\N	N.C. State Fisheries	NC
97782	Bogue Inlet, North Carolina	NOS	TEC2837	34.650001525878906	-77.0999984741211	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	00:15:00	\N	0.83	00:13:00	\N	0.73	\N	\N	Bogue Inlet	NC
97783	Cape Fear, North Carolina	NOS	TEC2847	33.85	-77.96666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94985	00:07:00	\N	1.33	00:04:00	\N	1.47	\N	\N	Cape Fear	NC
97784	Castle Hayne, Northeast River, Cape Fear River, North Carolina	NOS	TEC2863	34.35	-77.933333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95001	02:54:00	\N	0.42	02:44:00	\N	0.42	\N	\N	Castle Hayne, Northeast River	NC
97785	Lockwoods Folly Inlet, North Carolina	NOS	TEC2869	33.916666666667005	-78.233333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95012	00:15:00	\N	1	00:04:00	\N	0.84	\N	\N	Lockwoods Folly Inlet	NC
97786	Winyah Bay entrance (south jetty), South Carolina	NOS	TEC2929	33.18333333333299	-79.15	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:24:00	\N	0.89	-00:21:00	\N	0.87	\N	\N	Winyah Bay Entrance (South Jetty)	SC
97787	Frazier Point, South Carolina	NOS	TEC2937	33.31666666666701	-79.28333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	02:07:00	\N	0.68	01:26:00	\N	0.66	\N	\N	Frazier Point	SC
97788	North Santee River Inlet, South Carolina	NOS	TEC2991	33.13333333333299	-79.25	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:04:00	\N	0.84	-00:09:00	\N	0.85	\N	\N	North Santee River Inlet	SC
97789	Brown Island, South Santee River, South Carolina	NOS	TEC3001	33.15	-79.33333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	01:31:00	\N	0.79	00:27:00	\N	0.78	\N	\N	Brown Island, South Santee River	SC
97790	Cape Romain, 46 mi east of, South Carolina	NOS	TEC3011	33.1	-78.433333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-01:13:00	\N	0.79	-01:05:00	\N	0.78	\N	\N	Cape Romain, 46 miles east of	SC
97791	Jack Creek entrance, Bulls Bay, South Carolina	NOS	TEC3023	32.93333333333299	-79.58333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:15:00	\N	0.95	-00:14:00	\N	0.95	\N	\N	Jack Creek entrance	SC
97792	Sullivans Island (outer coast), South Carolina	NOS	TEC3047	32.76666666666701	-79.83333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:12:00	\N	1	-00:08:00	\N	0.99	\N	\N	Sullivans Island (outer coast)	SC
97793	Shipyard Creek, 0.8 mi above entrance., South Carolina	NOS	TEC3061	32.833333333332995	-79.95	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	00:20:00	\N	1	00:34:00	\N	1.01	\N	\N	Shipyard Creek, 0.8 mile above entrance.	SC
97794	Folly Island (outer coast), South Carolina	NOS	TEC3127	32.65	-79.933333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95036	-00:14:00	\N	1	-00:08:00	\N	0.98	\N	\N	Folly Island (outer coast)	SC
97795	Euhaw Creek, 2.5 mi above entrance, Broad River, South Carolina	NOS	TEC3327	32.435	-80.85166666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:09:00	\N	0.91	01:33:00	\N	1.14	\N	\N	Euhaw Creek, 2.5 mi. above entrance	SC
97796	Tybee Creek entrance, Georgia	NOS	TEC3399	31.983333333332993	-80.85	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:05:00	\N	1	-00:09:00	\N	0.99	\N	\N	Tybee Creek entrance	GA
97797	Beach Hammock, Georgia	NOS	TEC3401	31.95	-80.933333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	-00:07:00	\N	1	-00:01:00	\N	1	\N	\N	Beach Hammock	GA
97798	Romerly Marsh Creek, Georgia	NOS	TEC3403	31.933333333332993	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	-00:03:00	\N	1.03	00:08:00	\N	1.03	\N	\N	Romerly Marsh Creek	GA
97799	Savannah Sheraton Resort Hotel, Wilmington River, Georgia	NOS	TEC3405	32	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:06:00	\N	1.14	00:14:00	\N	1.13	\N	\N	Savannah Sheraton Resort Hotel	GA
97800	Thunderbolt, Wilmington River, Georgia	NOS	TEC3407	32.03333333333299	-81.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:12:00	\N	1.14	00:32:00	\N	1.15	\N	\N	Thunderbolt	GA
97801	North entrance, Wilmington River, Georgia	NOS	TEC3409	32.06666666666701	-81	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:44:00	\N	1.09	00:40:00	\N	1.1	\N	\N	North entrance	GA
97802	Isle of Hope, Skidaway River, Georgia	NOS	TEC3411	31.983333333332993	-81.05	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:28:00	\N	1.13	00:50:00	\N	1.13	\N	\N	Isle of Hope, Skidaway River	GA
97803	Egg Islands, Georgia	NOS	TEC3413	31.83333333333299	-81.08333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:10:00	\N	1.04	00:04:00	\N	1.04	\N	\N	Egg Islands	GA
97804	Coffee Bluff, Forest River, Georgia	NOS	TEC3417	31.933333333332993	-81.15	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:42:00	\N	1.09	01:05:00	\N	1.09	\N	\N	Coffee Bluff, Forest River	GA
97805	Fort McAllister, Ogeechee River, Georgia	NOS	TEC3419	31.883333333332992	-81.21666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:16:00	\N	1	00:48:00	\N	1	\N	\N	Fort McAllister, Ogeechee River	GA
97806	Highway bridge, Ogeechee River, Georgia	NOS	TEC3421	31.983333333332993	-81.28333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	04:25:00	\N	0.14	03:19:00	\N	0.15	\N	\N	Highway bridge, Ogeechee River	GA
97807	Florida Passage, Bear River, Georgia	NOS	TEC3425	31.816666666667007	-81.16666666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:49:00	\N	0.95	00:46:00	\N	1.09	\N	\N	Florida Passage, Bear River	GA
97808	Cane Patch Creek entrance, Georgia	NOS	TEC3427	31.816666666667007	-81.15	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:43:00	\N	1.05	00:55:00	\N	1.05	\N	\N	Cane Patch Creek entrance	GA
97809	North Newport River, Georgia	NOS	TEC3445	31.66666666666701	-81.266666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:36:00	\N	1.09	00:56:00	\N	1.1	\N	\N	North Newport River	GA
97810	South Newport Cut, N. Newport River, Georgia	NOS	TEC3447	31.66666666666701	-81.266666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:54:00	\N	1.04	01:01:00	\N	1.08	\N	\N	South Newport Cut, N. Newport River	GA
97811	Dallas Bluff, Julienton River, Georgia	NOS	TEC3457	31.58333333333299	-81.316666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	01:04:00	\N	1.09	00:48:00	\N	1.1	\N	\N	Dallas Bluff, Julienton River	GA
97812	Blackbeard Island, Georgia	NOS	TEC3463	31.53333333333299	-81.2	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:22:00	\N	1	00:18:00	\N	1	\N	\N	Blackbeard Island	GA
97813	Wolf Island, south end, Georgia	NOS	TEC3491	31.33333333333299	-81.316666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:45:00	\N	1.09	00:25:00	\N	0.97	\N	\N	Wolf Island, south end	GA
97814	Hampton River entrance, Georgia	NOS	TEC3495	31.21666666666701	-81.316666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:04:00	\N	0.95	00:16:00	\N	0.96	\N	\N	Hampton River entrance	GA
97815	Jones Creek entrance, Hampton River, Georgia	NOS	TEC3497	31.3	-81.33333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:13:00	\N	1.05	01:03:00	\N	1.05	\N	\N	Jones Creek entrance, Hampton River	GA
97816	St. Simons Sound Bar, Georgia	NOS	TEC3499	31.1	-81.316666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	-00:02:00	\N	0.95	-00:01:00	\N	0.95	\N	\N	St. Simons Sound Bar	GA
97817	Allied Chemical Corp. docks, Turtle River, Georgia	NOS	TEC3515	31.183333333332993	-81.516666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:42:00	\N	1.09	01:03:00	\N	1.1	\N	\N	Allied Chemical Corp. docks	GA
97818	Highway bridge, South Brunswick River, Georgia	NOS	TEC3521	31.15	-81.566666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95047	00:49:00	\N	1.09	01:07:00	\N	1.1	\N	\N	Highway bridge, South Brunswick River	GA
97819	Below Spring Bluff, Little Satilla River, Georgia	NOS	TEC3531	31.16666666666701	-81.616666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	01:31:00	\N	1.23	01:09:00	\N	1.23	\N	\N	Below Spring Bluff	GA
97820	Burnt Fort, Satilla River, Georgia	NOS	TEC3541	30.95	-81.9	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95073	05:05:00	\N	0.53	03:55:00	\N	0.53	\N	\N	Burnt Fort	GA
97821	Cape Canaveral, Florida	NOS	TEC3693	28.433333333332993	-80.566666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	-00:44:00	\N	1.42	-01:06:00	\N	1.5	\N	\N	Cape Canaveral	FL
97822	Jupiter Inlet, US Highway 1 Bridge, Florida	NOS	TEC3783	26.948333333332993	-80.085	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:05:00	\N	1.14	00:28:00	\N	0.86	\N	\N	Jupiter Inlet, U.S. Highway 1 Bridge	FL
97823	Tequesta, Loxahatchee River, Florida	NOS	TEC3787	26.95	-80.10166666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:58:00	\N	1.14	00:59:00	\N	0.8	\N	\N	Tequesta	FL
97824	Tequesta, North Fork entrance, Loxahatchee River, Florida	NOS	TEC3789	26.95166666666701	-80.10166666666701	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:42:00	\N	0.92	00:51:00	\N	0.78	\N	\N	Tequesta, North Fork entrance	FL
97825	Cape Sable, East Cape, Florida	NOS	TEC4165	25.116666666667008	-81.08333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95163	01:50:00	\N	0.98	01:33:00	\N	1.3	\N	\N	Cape Sable, East Cape	FL
97826	Whitewater Bay, Florida	NOS	TEC4169	25.316666666667007	-81.03333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95163	04:38:00	\N	0.33	03:53:00	\N	0.26	\N	\N	Whitewater Bay	FL
97827	Point Ybel, San Carlos Bay entrance, Florida	NOS	TEC4207	26.45	-82.016666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-01:12:00	\N	1.21	-01:50:00	\N	1.21	\N	\N	Point Ybel, San Carlos Bay entrance	FL
97828	Pass-a-Grille Beach, Boca Ciega Bay, Florida	NOS	TEC4271	27.683333333332993	-82.733333333333	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95191	-01:30:00	\N	0.87	-01:34:00	\N	0.87	\N	\N	Pass-a-Grille Beach	FL
97829	Suwannee River entrance, Florida	NOS	TEC4299	29.28333333333299	-83.15	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	00:18:00	\N	0.95	00:06:00	\N	0.88	\N	\N	Suwannee River entrance	FL
97830	Pepperfish Keys, Florida	NOS	TEC4301	29.5	-83.366666666667	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95213	00:24:00	\N	0.95	00:12:00	\N	0.88	\N	\N	Pepperfish Keys	FL
97831	Fishermans Rest, Florida	NOS	TEC4305	29.733333333332993	-83.53333333333299	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95220	-00:02:00	\N	0.86	-00:14:00	\N	0.93	\N	\N	Fishermans Rest	FL
97832	Rock Islands, Florida	NOS	TEC4309	29.966699600219727	-83.83329772949219	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95220	00:04:00	\N	0.91	-00:03:00	\N	0.93	\N	\N	Rock Islands	FL
97833	Milton, Blackwater River, Pensacola Bay, Florida	NOS	TEC4383	30.616666666667008	-87.03333333333299	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95274	01:47:00	\N	1.2	01:40:00	\N	1.2	\N	\N	Milton, Blackwater River	FL
97834	Paris Road Bridge (ICWW), Louisiana	NOS	TEC4445	30	-89.933333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95341	05:58:00	\N	1.04	05:53:00	\N	1.04	\N	\N	Paris Road Bridge (ICWW)	LA
97835	Bayou Rigaud, Grand Isle, Barataria Bay, Louisiana	NOS	TEC4455	29.266666666667007	-89.96666666666701	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95341	00:46:00	\N	0.94	01:32:00	\N	0.94	\N	\N	Bayou Rigaud, Grand Isle	LA
97836	Texas City, Turning Basin, Galveston Bay, Texas	NOS	TEC4513	29.383333333332992	-94.883333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95408	00:41:00	\N	1	00:33:00	\N	1	\N	\N	Texas City, Turning Basin	TX
97837	Gilchrist, East Bay, Galveston Bay, Texas	NOS	TEC4525	29.516666666667007	-94.483333333333	:America/Chicago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95408	04:18:00	\N	0.86	03:16:00	\N	0.86	\N	\N	Gilchrist, East Bay	TX
97838	Playa de Ponce, Puerto Rico	NOS	TEC4733	17.96666666666701	-66.616666666667	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95894	-00:13:00	\N	1.14	-00:39:00	\N	1.14	\N	\N	Playa de Ponce	PR
97839	Playa Cortada, Puerto Rico	NOS	TEC4735	17.983333333332993	-66.45	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95894	-00:37:00	\N	1.14	00:16:00	\N	1.14	\N	\N	Playa Cortada	PR
97840	Arroyo, Puerto Rico	NOS	TEC4737	17.96666666666701	-66.066666666667	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95894	00:13:00	\N	1.14	00:52:00	\N	1.14	\N	\N	Arroyo	PR
97841	Ensenada Honda, Culebra Island, Puerto Rico	NOS	TEC4749	18.3	-65.28333333333299	:America/Puerto_Rico	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95885	-00:15:00	\N	0.63	-00:34:00	\N	0.63	\N	\N	Ensenada Honda, Culebra Island	PR
97842	Pagan Island, Marianas	NOS	TPT2621	18.1333	145.76666	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94662	00:01:00	\N	0.94	00:05:00	\N	0.94	\N	\N	Pagan Island	MP
97843	Saipan Harbor, Saipan Island, Marianas	NOS	TPT2623	15.2	145.71666666667008	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94662	00:07:00	\N	0.8	00:02:00	\N	0.8	\N	\N	Saipan Harbor, Saipan Island	MP
97844	Tinian Island, Marianas	NOS	TPT2625	14.966666666667008	145.61666666667008	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94662	-00:23:00	\N	0.33	-00:02:00	\N	0.74	\N	\N	Tinian Island	MP
97845	Rota Island, Marianas	NOS	TPT2627	14.1333	145.1333	:Pacific/Saipan	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94662	-00:06:00	\N	0.94	-00:03:00	\N	0.94	\N	\N	Rota Island	MP
97846	Shonian Harbor, Palau	NOS	TPT2631	7.050000190734863	134.26669311523438	:Pacific/Palau	Palau	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94668	-00:13:00	\N	1	00:07:00	\N	0.89	\N	\N	Shonian Harbor	PW
97847	West Passage, Palau	NOS	TPT2637	7.5	134.51669311523438	:Pacific/Palau	Palau	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94668	-00:41:00	0	\N	-00:21:00	-0.1	\N	\N	\N	West Passage	PW
97849	Ifalik Atoll, Caroline Islands, FSM	NOS	TPT2647	7.25	144.45	:Pacific/Yap	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94662	-00:13:00	\N	1.33	-00:54:00	\N	1	\N	\N	Ifalik Atoll	FM
97850	Pulap Atoll, Chuuk, FSM	NOS	TPT2651	7.633333333333304	149.41666666667007	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94667	00:43:00	\N	0.74	-00:53:00	\N	0.74	\N	\N	Pulap Atoll	FM
97851	Namonuito Atoll, Caroline Islands, FSM	NOS	TPT2653	8.583333333333297	149.65	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94667	00:21:00	\N	0.69	-01:23:00	\N	0.69	\N	\N	Namonuito Atoll	FM
97852	Nomwin Atoll, Hall Islands, Chuuk, FSM	NOS	TPT2655	8.45	151.78333333332992	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94667	00:20:00	\N	0.8	-00:08:00	\N	0.8	\N	\N	Nomwin Atoll, Hall Islands	FM
97853	Murilo Atoll, Hall Islands, Chuuk, FSM	NOS	TPT2657	8.6	152.25	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94667	00:00:00	\N	0.85	-00:28:00	\N	0.85	\N	\N	Murilo Atoll, Hall Islands	FM
97854	Chuuk, Moen Island, E. Caroline Islands, FSM (sub)	NOS	TPT2659	7.45	151.85	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94667	00:11:00	\N	0.85	00:10:00	\N	0.85	\N	\N	Moen Island, Truk Islands	FM
97855	Dublon Island, Chuuk, FSM	NOS	TPT2661	7.366666666666704	151.88333333332992	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94667	00:30:00	\N	1.07	00:02:00	\N	1.07	\N	\N	Dublon Island, Truk Islands	FM
97856	Losap Atoll, Chuuk, FSM	NOS	TPT2663	6.9	152.7333333333299	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94667	00:25:00	\N	0.8	-00:03:00	\N	0.8	\N	\N	Losap Atoll	FM
97857	Namoluk Atoll, Chuuk, FSM	NOS	TPT2665	5.9	153.13333333332992	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94667	00:27:00	\N	0.8	-00:01:00	\N	0.8	\N	\N	Namoluk Atoll	FM
97858	Satawan Anchorage, Nomoi Islands, Chuuk, FSM	NOS	TPT2667	5.333333333333304	153.7333333333299	:Pacific/Truk	FSM	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94667	00:25:00	\N	0.96	-00:03:00	\N	0.96	\N	\N	Satawan Anchorage, Nomoi Islands	FM
97859	Bikini Atoll, Marshall Islands	NOS	TPT2687	11.6	165.55	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:19:00	0	\N	-00:19:00	0	\N	\N	\N	Bikini Atoll	MH
97860	Eniirikku Island, Bikini Atoll, Marshall Islands	NOS	TPT2689	11.5	165.33333333332993	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:16:00	\N	0.85	-00:15:00	\N	0.85	\N	\N	Eniirikku Island, Bikini Atoll	MH
97861	Rongelap Island, Rongelap Atoll, Marshall Islands	NOS	TPT2691	11.15	166.9	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:07:00	\N	0.96	-00:07:00	\N	0.96	\N	\N	Rongelap Island, Rongelap Atoll	MH
97862	Rongerik Atoll, Marshall Islands	NOS	TPT2693	11.383333333333008	167.5166666666701	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:15:00	0	\N	-00:14:00	0.1	\N	\N	\N	Rongerik Atoll	MH
97863	Ujae Atoll, Marshall Islands	NOS	TPT2695	9.033333333333296	165.6	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Ujae Atoll	MH
97864	Kwajalein Atoll (Namur Island), Marshall Islands	NOS	TPT2697	9.4	167.4833333333299	:Pacific/Kwajalein	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:05:00	0	\N	-00:02:00	0	\N	\N	\N	Kwajalein Atoll (Namur Island)	MH
97865	Ailinglapalap Atoll, Marshall Islands	NOS	TPT2701	7.283333333333304	168.75	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	00:07:00	0.3	\N	00:08:00	0.4	\N	\N	\N	Ailinglapalap Atoll	MH
97866	Jaluit Atoll (SE Pass), Marshall Islands	NOS	TPT2703	5.916666666666696	169.65	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:08:00	-0.1	\N	-00:12:00	-0.1	\N	\N	\N	Jaluit Atoll (SE Pass)	MH
97867	Ebon (Boston) Atoll, Marshall Islands	NOS	TPT2705	4.6	168.68333333332993	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:10:00	0.1	\N	-00:10:00	0.1	\N	\N	\N	Ebon (Boston) Atoll	MH
97868	Taongi Atoll, Marshall Islands	NOS	TPT2707	14.566666666667007	168.95	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:20:00	0	\N	-00:20:00	0	\N	\N	\N	Taongi Atoll	MH
97869	Bikar (Dawson) Atoll, Marshall Islands	NOS	TPT2709	12.25	170.13333333332992	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Bikar (Dawson) Atoll	MH
97870	Ailuk Atoll, Marshall Islands	NOS	TPT2711	10.216666666667008	169.9833333333299	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Ailuk Atoll	MH
97871	Likiep Atoll, Marshall Islands	NOS	TPT2713	9.816666666666704	169.31666666667007	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:01:00	0	\N	00:00:00	0.1	\N	\N	\N	Likiep Atoll	MH
97872	Wotje Atoll, Marshall Islands	NOS	TPT2715	9.466666666666704	170.2333333333299	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:11:00	-0.2	\N	-00:11:00	-0.2	\N	\N	\N	Wotje Atoll	MH
97873	Erikub Atoll, Marshall Islands	NOS	TPT2717	9.2	169.91666666667007	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:10:00	0	\N	-00:10:00	0	\N	\N	\N	Erikub Atoll	MH
97874	Maloelap Atoll, Marshall Islands	NOS	TPT2719	8.716666666666704	171.2333333333299	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:05:00	-0.1	\N	-00:04:00	0.1	\N	\N	\N	Maloelap Atoll	MH
97875	Majuro Atoll, Marshall Islands	NOS	TPT2721	7.116666666666704	171.36666666667008	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:06:00	0.1	\N	-00:05:00	0.3	\N	\N	\N	Majuro Atoll	MH
97876	Arno Atoll, Marshall Islands	NOS	TPT2723	7.133333333333304	171.7	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	-00:05:00	-0.1	\N	-00:04:00	0.6	\N	\N	\N	Arno Atoll	MH
97877	Port Rhin, Mili Atoll, Marshall Islands	NOS	TPT2725	6.233333333333296	171.8	:Pacific/Majuro	RMI	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94666	00:04:00	0	\N	00:04:00	0.7	\N	\N	\N	Port Rhin, Mili Atoll	MH
97878	Howland Island	NOS	TPT2737	0.8	-176.63333333332992	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94651	03:46:00	0.4	\N	03:48:00	4.2	\N	\N	\N	Howland Island	\N
97879	Palmyra Island	NOS	TPT2739	5.883333333333304	-162.08333333332993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94651	01:13:00	-0.2	\N	01:19:00	0.6	\N	\N	\N	Palmyra Island	\N
97880	Waikane, Kaneohe Bay, Oahu Island, Hawaii	NOS	TPT2777	21.5	-157.85	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94655	-00:04:00	\N	1	-00:22:00	\N	1.13	\N	\N	Waikane, Kaneohe Bay	HI
97881	Laie Bay, Oahu Island, Hawaii	NOS	TPT2779	21.65	-157.93333333332993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94655	-00:32:00	\N	0.75	-00:21:00	\N	1	\N	\N	Laie Bay	HI
97882	Kihei, Maalaea Bay, Maui Island, Hawaii	NOS	TPT2797	20.78333333333299	-156.46666666667008	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94657	01:19:00	\N	0.54	01:52:00	\N	0.94	\N	\N	Kihei, Maalaea Bay	HI
97883	Lahaina, Maui Island, Hawaii	NOS	TPT2799	20.883333333332992	-156.68333333332993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94657	01:01:00	\N	0.81	01:18:00	\N	0.89	\N	\N	Lahaina	HI
97884	Smuggler Cove, Kahoolawe Island, Hawaii	NOS	TPT2803	20.516666666667007	-156.68333333332993	:Pacific/Honolulu	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94651	00:03:00	0	\N	-00:15:00	0.2	\N	\N	\N	Smuggler Cove	HI
97885	Tau Island, Manua Islands, American Samoa	NOS	TPT2865	-14.21666666666667	-169.5333333333333	:Pacific/Pago_Pago	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94665	-00:24:00	\N	1	-00:25:00	\N	1.43	\N	\N	Tau Island, Manua Islands	AS
97886	Point Loma, California	NOS	TWC0405	32.666666666667005	-117.23333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95455	-00:02:00	\N	0.92	-00:09:00	\N	0.92	\N	\N	Point Loma	CA
97887	Quivira Basin, Mission Bay, California	NOS	TWC0413	32.76666666666701	-117.23333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95455	00:04:00	\N	0.95	00:05:00	\N	0.95	\N	\N	Quivira Basin, Mission Bay	CA
97888	San Clemente, California	NOS	TWC0419	33.416666666667005	-117.61666666666996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95455	-00:11:00	\N	0.92	-00:15:00	\N	0.92	\N	\N	San Clemente	CA
97889	Los Patos (highway bridge), California	NOS	TWC0427	33.71666666666701	-118.05	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	01:12:00	\N	0.6	01:00:00	\N	0.83	\N	\N	Los Patos (highway bridge)	CA
97890	Los Angeles Harbor, Mormon Island, California	NOS	TWC0439	33.75	-118.26666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	00:02:00	0	\N	00:04:00	-0.1	\N	\N	\N	Los Angeles Harbor, Mormon Island	CA
97891	Mugu Lagoon (ocean pier), California	NOS	TWC0445	34.1	-119.1	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	00:11:00	\N	0.96	00:03:00	\N	0.96	\N	\N	Mugu Lagoon (ocean pier)	CA
97892	Santa Barbara Island, California	NOS	TWC0463	33.48333333333299	-119.03333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95459	00:04:00	\N	0.92	-00:02:00	\N	0.92	\N	\N	Santa Barbara Island	CA
97893	Point Arguello, California	NOS	TWC0473	34.583333333332995	-120.65	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95466	-00:08:00	\N	0.96	-00:03:00	\N	0.96	\N	\N	Point Arguello	CA
97894	San Francisco Bar, California	NOS	TWC0509	37.76666666666701	-122.63333333333004	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	-00:31:00	0	\N	-00:35:00	-0.2	\N	\N	\N	San Francisco Bar	CA
97895	Roberts Landing, 1.3 mi west of, San Francisco Bay, California	NOS	TWC0547	37.666666666667005	-122.2	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	01:28:00	0.1	\N	00:52:00	1.4	\N	\N	\N	Roberts Landing, 1.3 miles west of	CA
97896	Lakeville, Petaluma River, San Pablo Bay, California	NOS	TWC0649	38.2	-122.56666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95474	02:50:00	\N	0.81	01:59:00	\N	1.11	\N	\N	Lakeville, Petaluma River	CA
97897	Point Arena, California	NOS	TWC0771	38.95	-123.73333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95515	00:01:00	\N	0.95	00:03:00	\N	0.98	\N	\N	Point Arena	CA
97898	Mendocino, Mendocino Bay, California	NOS	TWC0777	39.3	-123.8	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95515	00:01:00	\N	0.95	00:07:00	\N	0.98	\N	\N	Mendocino, Mendocino Bay	CA
97899	Wedderburn, Rogue River, Oregon	NOS	TWC0817	42.43333333333299	-124.41666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95523	00:16:00	\N	0.92	00:09:00	\N	0.95	\N	\N	Wedderburn, Rogue River	OR
97900	Gardiner, Umpqua River, Oregon	NOS	TWC0831	43.73333333333299	-124.11666666666996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95528	01:09:00	\N	0.8	00:56:00	\N	0.88	\N	\N	Gardiner	OR
97901	Nestucca Bay entrance, Oregon	NOS	TWC0857	45.166666666667005	-123.96666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95523	01:12:00	\N	0.92	00:55:00	\N	1.1	\N	\N	Nestucca Bay entrance	OR
97902	Miami Cove, Tillamook Bay, Oregon	NOS	TWC0863	45.55	-123.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95523	01:26:00	\N	0.92	01:15:00	\N	1.06	\N	\N	Miami Cove	OR
97903	Bay City, Tillamook Bay, Oregon	NOS	TWC0865	45.51666666666701	-123.9	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95523	02:00:00	\N	0.83	01:33:00	\N	1.02	\N	\N	Bay City	OR
97904	Point Adams, Oregon	NOS	TWC0881	46.2	-123.95	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95545	-00:38:00	0.1	\N	-00:25:00	-0.2	\N	\N	\N	Point Adams, Oreg.	OR
97905	Warrenton, Skipanon River, Oregon	NOS	TWC0883	46.166666666667005	-123.91666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95545	-00:19:00	0.1	\N	-00:13:00	-0.1	\N	\N	\N	Warrenton, Skipanon River, Oreg.	OR
97906	Harrington Point, Washington	NOS	TWC0895	46.26666666666701	-123.65	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95545	00:52:00	-0.2	\N	00:21:00	-0.8	\N	\N	\N	Harrington Point, Wash.	WA
97907	Tarlatt Slough, Willapa Bay, Washington	NOS	TWC0933	46.37	-124.005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	01:14:00	\N	1.05	00:45:00	\N	1.05	\N	\N	Tarlatt Slough	WA
97908	Mailboat Slough, Willapa River, Willapa Bay, Washington	NOS	TWC0940	46.68833333333299	-123.81666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	00:11:00	\N	1.02	00:18:00	\N	1.07	\N	\N	Mailboat Slough, Willapa River	WA
97909	Montesano, Chehalis River, Grays Harbor, Washington	NOS	TWC0959	46.96833333333299	-123.6	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	01:45:00	\N	0.94	01:34:00	\N	0.94	\N	\N	Montesano, Chehalis River	WA
97910	Destruction Island, Washington	NOS	TWC0965	47.666666666667005	-124.48333333333005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95563	-00:43:00	\N	1.02	-00:37:00	\N	0.98	\N	\N	Destruction Island	WA
97911	Rocky Point, Eld Inlet, Puget Sound, Washington	NOS	TWC1115	47.081666666667005	-123.005	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:56:00	\N	1.1	00:39:00	\N	1.31	\N	\N	Rocky Point, Eld Inlet	WA
97912	Marysville, Quilceda Creek, Washington	NOS	TWC1125	48.045	-122.21166666666996	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	00:29:00	\N	0.89	00:09:00	\N	0.95	\N	\N	Marysville, Quilceda Creek	WA
97913	Stanwood, Stillaguamish River, Washington	NOS	TWC1131	48.21666666666667	-122.3666666666667	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95583	02:14:00	\N	0.29	00:23:00	\N	0.62	\N	\N	Stanwood, Stillaguamish River	WA
97914	Peavine Pass, Washington	NOS	TWC1165	48.6	-122.8	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	00:18:00	\N	0.92	00:34:00	\N	0.98	\N	\N	Peavine Pass	WA
97915	Point Migley, Hale Passage, Washington	NOS	TWC1173	48.75	-122.71666666666995	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	00:51:00	0	\N	00:56:00	0.1	\N	\N	\N	Point Migley	WA
97916	Ferndale, Strait of Georgia, Washington	NOS	TWC1189	48.83330154418945	-122.7166976928711	:America/Los_Angeles	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95573	01:20:00	\N	1.04	00:49:00	\N	1.05	\N	\N	Ferndale	WA
97917	Tah Bay, Alaska	NOS	TWC1487	54.833333333332995	-132.33333333332993	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:03:00	0.1	\N	-00:04:00	2.6	\N	\N	\N	Tah Bay	AK
97918	Kasook Inlet, Sukkwan Island, Tlevak Strait, Alaska	NOS	TWC1513	55.01666666666701	-132.78333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:05:00	0	\N	-00:13:00	2.8	\N	\N	\N	Kasook Inlet, Sukkwan Island	AK
97919	Cyrus Cove, Sea Otter Sound, Davidson Inlet, Alaska	NOS	TWC1579	55.916666666667005	-133.4	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:12:00	0	\N	-00:16:00	1.1	\N	\N	\N	Cyrus Cove, Sea Otter Sound	AK
97920	Marble Island, Davidson Inlet, Alaska	NOS	TWC1583	56	-133.46666666667008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:15:00	-0.1	\N	-00:19:00	0.8	\N	\N	\N	Marble Island	AK
97921	Port McArthur, Kuiu Island, Alaska	NOS	TWC1593	56.06666666666701	-134.11666666667008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	-00:07:00	-0.1	\N	-00:11:00	0.6	\N	\N	\N	Port McArthur, Kuiu Island	AK
97922	Ideal Cove, Mitkof Island, Frederick Sound, Alaska	NOS	TWC1657	56.666666666667005	-132.63333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:05:00	0	\N	-00:09:00	-0.2	\N	\N	\N	Ideal Cove, Mitkof Island	AK
97923	Brown Cove, Frederick Sound, Alaska	NOS	TWC1659	56.88333333333299	-132.8	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:10:00	-0.1	\N	-00:14:00	-0.3	\N	\N	\N	Brown Cove	AK
97924	Portage Bay, Kupreanof Island, Frederick Sound, Alaska	NOS	TWC1663	57	-133.31666666667007	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:15:00	0	\N	-00:19:00	-0.7	\N	\N	\N	Portage Bay, Kupreanof Island	AK
97925	Eliza Harbor, Liesnoi Island, Frederick Sound, Alaska	NOS	TWC1669	57.166666666667005	-134.28333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:19:00	-0.1	\N	-00:19:00	-1.9	\N	\N	\N	Eliza Harbor, Liesnoi Island	AK
97926	Port Houghton, Robert Islands, Alaska	NOS	TWC1673	57.3	-133.46666666667008	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:17:00	-0.1	\N	-00:21:00	-0.8	\N	\N	\N	Port Houghton, Robert Islands	AK
97927	Windfall Harbor, Seymour Canal, Alaska	NOS	TWC1683	57.86666666666701	-134.2666666666701	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:18:00	0	\N	00:14:00	-0.2	\N	\N	\N	Windfall Harbor, Seymour Canal	AK
97928	Port Snettisham, Point Styleman, Alaska	NOS	TWC1687	57.96666666666701	-133.88333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:06:00	-0.1	\N	-00:12:00	-0.4	\N	\N	\N	Port Snettisham, Point Styleman	AK
97929	Fritz Cove, Douglas Island, Alaska	NOS	TWC1697	58.31666666666701	-134.6	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:05:00	-0.1	\N	-00:01:00	-0.3	\N	\N	\N	Fritz Cove, Douglas Island	AK
97930	Tebenkof Bay, Kuiu Island, Alaska	NOS	TWC1723	56.416666666667005	-134.13333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95647	00:11:00	0.1	\N	00:04:00	1.8	\N	\N	\N	Tebenkof Bay, Kuiu Island	AK
97931	Whitewater Bay, Admiralty Island, Alaska	NOS	TWC1731	57.23333333333299	-134.6	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:15:00	0.3	\N	-00:19:00	-2	\N	\N	\N	Whitewater Bay, Admiralty Island	AK
97932	Point Thatcher, Alaska	NOS	TWC1735	57.416666666667005	-134.85	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:11:00	0.2	\N	-00:15:00	-1.9	\N	\N	\N	Point Thatcher	AK
97933	Favorite Bay, Kootznahoo Inlet, Alaska	NOS	TWC1739	57.48333333333299	-134.55	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:15:00	0.3	\N	00:11:00	-2.8	\N	\N	\N	Favorite Bay	AK
97934	Mitchell Bay, Kootznahoo Inlet, Alaska	NOS	TWC1741	57.53333333333299	-134.4	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	01:31:00	\N	0.62	01:22:00	\N	0.67	\N	\N	Mitchell Bay	AK
97935	Freshwater Bay, Chichagof Island, Alaska	NOS	TWC1743	57.85	-135.0166666666701	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	00:00:00	0.3	\N	-00:08:00	-1.5	\N	\N	\N	Freshwater Bay, Chichagof Island	AK
97936	Point Elizabeth, Alaska	NOS	TWC1783	57.51666666666701	-135.28333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:05:00	0	\N	-00:15:00	-1.6	\N	\N	\N	Point Elizabeth	AK
97937	Lindenburg Head, Alaska	NOS	TWC1785	57.45	-135.03333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:05:00	0	\N	-00:15:00	-1.8	\N	\N	\N	Lindenburg Head	AK
97938	Fairway Island, Alaska	NOS	TWC1787	57.45	-134.88333333332992	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95655	-00:05:00	0	\N	-00:15:00	-2.1	\N	\N	\N	Fairway Island	AK
97939	Falcon Arm, Slocum Arm, Chichagof Island, Alaska	NOS	TWC1789	57.55	-135.93333333332993	:America/Juneau	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95664	-00:07:00	\N	1.1	-00:05:00	\N	0.96	\N	\N	Falcon Arm, Slocum Arm	AK
97940	Wingham Island, Controller Bay, Alaska	NOS	TWC1863	60.05	-144.4	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95666	00:08:00	\N	1.01	00:05:00	\N	0.99	\N	\N	Wingham Island, Controller Bay	AK
97941	Pete Dahl Slough, Copper River Delta, Alaska	NOS	TWC1867	60.38333333333299	-145.4	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	00:38:00	0	\N	00:06:00	-2.4	\N	\N	\N	Pete Dahl Slough	AK
97942	Eyak River entrance, Alaska	NOS	TWC1869	60.46666666666701	-145.66666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	00:58:00	-0.1	\N	00:14:00	-1.6	\N	\N	\N	Eyak River entrance	AK
97943	Gravel Point, Orca Inlet, Alaska	NOS	TWC1875	60.46666666666701	-145.96666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	00:31:00	0	\N	00:01:00	-0.1	\N	\N	\N	Gravel Point	AK
97944	Orca, Orca Inlet, Alaska	NOS	TWC1879	60.583333333332995	-145.71666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	00:01:00	0	\N	00:01:00	-0.2	\N	\N	\N	Orca	AK
97945	Windy Bay, Hawkins Island, Prince William Sound, Alaska	NOS	TWC1881	60.56666666666701	-145.96666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:01:00	0	\N	-00:08:00	-0.5	\N	\N	\N	Windy Bay, Hawkins Island	AK
97946	Port Etches, Hinchinbrook Island, Alaska	NOS	TWC1887	60.333333333332995	-146.55	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	00:01:00	-0.2	\N	-00:09:00	-1.3	\N	\N	\N	Port Etches	AK
97947	Hanning Bay, Montague Island, Alaska	NOS	TWC1893	59.95	-147.68333333332993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:05:00	-0.1	\N	-00:08:00	-1	\N	\N	\N	Hanning Bay	AK
97948	Smith Island, Prince William Sound, Alaska	NOS	TWC1907	60.53333333333299	-147.31666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:04:00	-0.1	\N	-00:05:00	-0.8	\N	\N	\N	Smith Island	AK
97949	Snug Corner Cove, Port Fidalgo, Prince William Sound, Alaska	NOS	TWC1909	60.73333333333299	-146.65	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95669	-00:06:00	0	\N	-00:07:00	-0.6	\N	\N	\N	Snug Corner Cove, Port Fidalgo	AK
97950	Cape Ninilchik, Cook Inlet, Alaska	NOS	TWC1979	60.01666666666701	-151.71666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	00:54:00	0.2	\N	00:41:00	1.2	\N	\N	\N	Cape Ninilchik	AK
97951	Kenai River entrance, Cook Inlet, Alaska	NOS	TWC1983	60.55	-151.28333333332992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	02:18:00	0.5	\N	01:52:00	2.7	\N	\N	\N	Kenai River entrance	AK
97952	East Foreland, Cook Inlet, Alaska	NOS	TWC1989	60.71666666666701	-151.41666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	02:58:00	0.5	\N	02:37:00	3	\N	\N	\N	East Foreland	AK
97953	Iliamna Bay, Cook Inlet, Alaska	NOS	TWC2009	59.61666666666701	-153.58333333332993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	00:16:00	\N	0.82	00:12:00	\N	0.8	\N	\N	Iliamna Bay	AK
97954	Marmot Island, Marmot Strait, Alaska	NOS	TWC2021	58.23333333333299	-151.86666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:07:00	0	\N	00:18:00	0.9	\N	\N	\N	Marmot Island, Marmot Strait	AK
97955	Izhut Bay, Alaska	NOS	TWC2023	58.21666666666701	-152.31666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:21:00	0	\N	00:12:00	0.1	\N	\N	\N	Izhut Bay	AK
97956	Kazakof Bay, Marmot Bay, Alaska	NOS	TWC2025	58.13333333333299	-152.56666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:06:00	0.2	\N	00:04:00	0.6	\N	\N	\N	Kazakof Bay, Marmot Bay	AK
97957	Kizhuyak Point, Alaska	NOS	TWC2031	57.9	-152.65	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:09:00	0.1	\N	00:05:00	0.6	\N	\N	\N	Kizhuyak Point	AK
97958	Three Saints Bay, Alaska	NOS	TWC2047	57.11666666666701	-153.5166666666701	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	-00:13:00	0.1	\N	-00:22:00	-0.2	\N	\N	\N	Three Saints Bay	AK
97959	Sitkinak Lagoon, Alaska	NOS	TWC2051	56.5	-154.13333333332992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:07:00	0.2	\N	-00:20:00	-1	\N	\N	\N	Sitkinak Lagoon	AK
97960	Village Islands, Uganik Bay, Alaska	NOS	TWC2067	57.78333333333299	-153.55	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	-00:02:00	\N	0.8	-00:15:00	\N	0.8	\N	\N	Village Islands	AK
97961	Northeast Arm, Uganik Bay, Alaska	NOS	TWC2069	57.73333333333299	-153.33333333332993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	-00:01:00	\N	0.77	-00:12:00	\N	0.77	\N	\N	Northeast Arm	AK
97962	Uganik Passage, Uganik Bay, Alaska	NOS	TWC2071	57.8	-153.3	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	00:02:00	\N	0.81	-00:07:00	\N	0.81	\N	\N	Uganik Passage	AK
97963	Viekoda Bay, Alaska	NOS	TWC2073	57.9	-153.16666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	-00:03:00	\N	0.8	-00:11:00	\N	0.8	\N	\N	Viekoda Bay	AK
97964	Onion Bay, Kupreanof Strait, Alaska	NOS	TWC2075	58.05	-153.2333333333299	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	-00:01:00	\N	0.8	00:00:00	\N	0.8	\N	\N	Onion Bay	AK
97965	Dry Spruce Island, Kupreanof Strait, Alaska	NOS	TWC2077	57.95	-153.03333333332992	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	00:13:00	\N	0.77	00:02:00	\N	0.77	\N	\N	Dry Spruce Island	AK
97966	Malina Bay, Shelikof Strait, Alaska	NOS	TWC2085	58.18333333333299	-152.95	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	00:00:00	\N	0.81	-00:14:00	\N	0.81	\N	\N	Malina Bay, Shelikof Strait	AK
97967	Katmai Bay, Shelikof Strait, Alaska	NOS	TWC2095	58	-154.9833333333299	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95695	00:01:00	\N	0.71	-00:14:00	\N	0.71	\N	\N	Katmai Bay, Shelikof Strait	AK
97968	Lees Cabins, Wide Bay, Alaska	NOS	TWC2101	57.43333333333299	-156.3	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:32:00	0.2	\N	00:21:00	3.2	\N	\N	\N	Lees Cabins, Wide Bay	AK
97969	Three Star Point, Alaska	NOS	TWC2105	55.9	-159.16666666667007	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:37:00	\N	1.28	00:28:00	\N	0.9	\N	\N	Three Star Point	AK
97970	Fox Bay, Kupreanof Peninsula, Alaska	NOS	TWC2111	55.63333333333299	-159.61666666667008	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	00:33:00	\N	1.19	00:18:00	\N	0.86	\N	\N	Fox Bay, Kupreanof Peninsula	AK
97971	Mist Harbor, Nagai Island, Shumagin Islands, Alaska	NOS	TWC2119	55.13333333333299	-159.85	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95738	-00:01:00	\N	0.9	00:01:00	\N	0.97	\N	\N	Mist Harbor, Nagai Island	AK
97972	Malga Bay, Unalga Island, Aleutian Islands, Alaska	NOS	TWC2175	53.98333333333299	-166.16666666667007	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-01:05:00	\N	0.93	-00:18:00	\N	0.85	\N	\N	Malga Bay, Unalga Island	AK
97973	Kashega Bay, Unalaska Island, Alaska	NOS	TWC2187	53.46666666666701	-167.08333333332993	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-00:24:00	\N	1.19	-00:08:00	\N	1.08	\N	\N	Kashega Bay	AK
97974	Eagle Bay, Unalaska Island, Alaska	NOS	TWC2193	53.48333333333299	-166.93333333332993	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-03:16:00	\N	1.02	-02:56:00	\N	1.46	\N	\N	Eagle Bay	AK
97975	Herbert Island, west side, Aleutian Islands, Alaska	NOS	TWC2223	52.71666666666701	-170.15	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-01:51:00	\N	0.93	-01:40:00	\N	1.14	\N	\N	Herbert Island, west side	AK
97976	Amukta Island, north side, Aleutian Islands, Alaska	NOS	TWC2229	52.51666666666701	-171.2333333333299	:America/Adak	USA	feet	\N	\N	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95747	-02:03:00	\N	1.1	-01:32:00	\N	0.94	\N	\N	Amukta Island, north side	AK
97977	Gareloi Island, Delarof Islands, Alaska	NOS	TWC2297	51.75	-178.8	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-00:30:00	\N	1	-00:08:00	\N	1	\N	\N	Gareloi Island	AK
97978	Constantine Harbor, Amchitka Island, Rat Islands, Alaska	NOS	TWC2303	51.41669845581055	179.28329467773438	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-01:06:00	\N	0.76	00:19:00	\N	0.76	\N	\N	Constantine Harbor, Amchitka Island	AK
97979	Gertrude Cove, Kiska Island, Rat Islands, Alaska	NOS	TWC2305	51.93330001831055	177.4499969482422	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-01:19:00	\N	0.86	00:02:00	\N	0.86	\N	\N	Gertrude Cove, Kiska Island	AK
97980	Kiska Harbor, Kiska Island, Rat Islands, Alaska	NOS	TWC2307	51.983299255371094	177.5500030517578	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95744	-01:13:00	\N	0.97	00:24:00	\N	0.97	\N	\N	Kiska Harbor, Kiska Island	AK
97981	Alcan Harbor, Shemya Island, Aleutian Islands, Alaska	NOS	TWC2309	52.71670150756836	174.0666961669922	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95743	-01:03:00	\N	1.03	00:00:00	\N	1.03	\N	\N	Alcan Harbor, Shemya Island	AK
97982	Otkriti Bay, Agattu Island, Aleutian Islands, Alaska	NOS	TWC2311	52.36669921875	173.61669921875	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95743	-01:13:00	\N	1.03	-01:14:00	\N	1.03	\N	\N	Otkriti Bay, Agattu Island	AK
97983	Chichagof Harbor, Attu Island, Alaska	NOS	TWC2315	52.91669845581055	173.21670532226562	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95743	00:16:00	\N	1.09	00:13:00	\N	1.09	\N	\N	Chichagof Harbor	AK
97984	Holtz Bay, Attu Island, Alaska	NOS	TWC2317	52.91669845581055	173.1667022705078	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95743	00:18:00	\N	1.12	-01:04:00	\N	1.12	\N	\N	Holtz Bay	AK
97985	Steller Cove, Attu Island, Alaska	NOS	TWC2319	52.96670150756836	172.89999389648438	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95743	00:11:00	\N	1.12	-01:13:00	\N	1.12	\N	\N	Steller Cove	AK
97986	Etienne Bay, Attu Island, Alaska	NOS	TWC2321	52.91669845581055	172.61669921875	:America/Adak	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95743	00:03:00	\N	1.12	-01:17:00	\N	1.12	\N	\N	Etienne Bay	AK
97987	Apoon Mouth, Pastol Bay, Norton Sound, Alaska	NOS	TWC2405	63.05	-163.38333333332992	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95814	-01:30:00	\N	1.03	-01:30:00	\N	1.03	\N	\N	Apoon Mouth, Yukon River	AK
97988	Flaxman Island, Alaska	NOS	TWC2423	70.183333333333	-145.83333333332993	:America/Anchorage	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95715	-00:28:00	\N	0.09	-00:57:00	\N	0.08	\N	\N	Flaxman Island	AK
97989	Pollock Rip Channel (Butler Hole) (depth 7 ft), Massachusetts Current	NOS	ACT1616_1	41.54999923706055	-69.9832992553711	:America/New_York	USA	knots	226	37	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pollock Rip Channel (Butler Hole)	MA
97990	Baltimore Harbor approach (off Sandy Point) (depth 43 ft), Maryland Current	NOS	ACT4996_1	39.01300048828125	-76.36830139160156	:America/New_York	USA	knots	189	25	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baltimore Harbor Approach (off Sandy Point)	MD
97991	Charleston Harbor (off Fort Sumter) (depth 5 ft), South Carolina Current	NOS	ACT6651_1	32.75600051879883	-79.87030029296875	:America/New_York	USA	knots	127	313	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charleston Harbor (off Fort Sumter)	SC
97992	Savannah River entrance (between jetties) (depth 11 ft), South Carolina Current	NOS	ACT7351_1	32.035701751708984	-80.89029693603516	:America/New_York	USA	knots	110	286	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Savannah River Entrance (between jetties)	SC
97993	Tampa Bay entrance (Egmont Channel) (depth 15 ft), Florida Current	NOS	ACT8411_1	27.604299545288086	-82.76029968261719	:America/New_York	USA	knots	298	120	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tampa Bay Entrance (Egmont Channel)	FL
97994	Galveston Bay ent. (between jetties) (depth 15 ft), Texas Current	NOS	ACT8851_2	29.34869956970215	-94.71420288085938	:America/Chicago	USA	knots	88	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Bay Ent. (between jetties)	TX
97995	Bolivar Roads (depth 14 ft), Galveston Bay, Texas Current	NOS	ACT8856_2	29.343299865722656	-94.78130340576172	:America/Chicago	USA	knots	123	296	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bolivar Roads	TX
97996	Vieques Passage (depth 5 ft), Puerto Rico Current	NOS	ACT8926_1	18.18829917907715	-65.61830139160156	:America/Puerto_Rico	USA	knots	57	250	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vieques Passage	PR
97997	Little Misery Island (depth 50 ft), Salem Sound, Massachusetts Current	NOS	BOS1101_1	42.54217	-70.80013	:America/New_York	USA	knots	90	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Little Misery Island	MA
97998	Little Misery Island (depth 18 ft), Salem Sound, Massachusetts Current	NOS	BOS1101_11	42.54217	-70.80013	:America/New_York	USA	knots	102	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Little Misery Island	MA
97999	Little Misery Island (depth 5 ft), Salem Sound, Massachusetts Current	NOS	BOS1101_15	42.54217	-70.80013	:America/New_York	USA	knots	105	249	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Little Misery Island	MA
98000	Haste Shoal (depth 15 ft), Salem Sound, Massachusetts Current	NOS	BOS1102_2	42.53935	-70.84496	:America/New_York	USA	knots	67	268	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haste Shoal	MA
98001	Haste Shoal (depth 4 ft), Salem Sound, Massachusetts Current	NOS	BOS1102_9	42.53935	-70.84496	:America/New_York	USA	knots	93	273	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haste Shoal	MA
98002	Fort Pickering, 0.2 nmi south of (depth 29 ft), Salem Sound, Massachusetts Current	NOS	BOS1104_1	42.52238	-70.86795	:America/New_York	USA	knots	\N	261.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pickering, 0.2nm south of	MA
98003	Fort Pickering, 0.2 nmi south of (depth 16 ft), Salem Sound, Massachusetts Current	NOS	BOS1104_5	42.52238	-70.86795	:America/New_York	USA	knots	81	268	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pickering, 0.2nm south of	MA
98004	Fort Pickering, 0.2 nmi south of (depth 6 ft), Salem Sound, Massachusetts Current	NOS	BOS1104_8	42.52238	-70.86795	:America/New_York	USA	knots	80	264	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pickering, 0.2nm south of	MA
98005	Marblehead Channel (depth 30 ft), Salem Sound, Massachusetts Current	NOS	BOS1105_1	42.5007	-70.82023	:America/New_York	USA	knots	\N	319.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marblehead Channel	MA
98006	Marblehead Channel (depth 17 ft), Salem Sound, Massachusetts Current	NOS	BOS1105_5	42.5007	-70.82023	:America/New_York	USA	knots	\N	338.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marblehead Channel	MA
98007	Marblehead Channel (depth 4 ft), Salem Sound, Massachusetts Current	NOS	BOS1105_9	42.5007	-70.82023	:America/New_York	USA	knots	171	280	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marblehead Channel	MA
98008	Northeast Grave (depth 45 ft), Massachusetts Current	NOS	BOS1106_1	42.37176	-70.8618	:America/New_York	USA	knots	114	301	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northeast Grave	MA
98009	Northeast Grave (depth 25 ft), Massachusetts Current	NOS	BOS1106_7	42.37176	-70.8618	:America/New_York	USA	knots	90	266	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northeast Grave	MA
98010	Northeast Grave (depth 8 ft), Massachusetts Current	NOS	BOS1106_12	42.37176	-70.8618	:America/New_York	USA	knots	86	251	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northeast Grave	MA
98011	Commissioners Ledge (depth 16 ft), Massachusetts Current	NOS	BOS1107_1	42.33584	-70.91296	:America/New_York	USA	knots	29	215	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Commissioners Ledge	MA
98012	Commissioners Ledge (depth 6 ft), Massachusetts Current	NOS	BOS1107_4	42.33584	-70.91296	:America/New_York	USA	knots	37	222	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Commissioners Ledge	MA
98013	Lovell Island, 1.3 nmi north of (depth 30 ft), Massachusetts Current	NOS	BOS1108_1	42.35498	-70.9319	:America/New_York	USA	knots	27	187	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovell Island, 1.3nm north of	MA
98014	Lovell Island, 1.3 nmi north of (depth 20 ft), Massachusetts Current	NOS	BOS1108_4	42.35498	-70.9319	:America/New_York	USA	knots	27	192	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovell Island, 1.3nm north of	MA
98015	Lovell Island, 1.3 nmi north of (depth 4 ft), Massachusetts Current	NOS	BOS1108_9	42.35498	-70.9319	:America/New_York	USA	knots	29	198	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovell Island, 1.3nm north of	MA
98016	South Channel Aldridge Ledge (depth 30 ft), Massachusetts Current	NOS	BOS1109_1	42.34958	-70.91286	:America/New_York	USA	knots	39	219	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Channel Aldridge Ledge	MA
98017	South Channel Aldridge Ledge (depth 20 ft), Massachusetts Current	NOS	BOS1109_4	42.34958	-70.91286	:America/New_York	USA	knots	45	222	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Channel Aldridge Ledge	MA
98018	South Channel Aldridge Ledge (depth 4 ft), Massachusetts Current	NOS	BOS1109_9	42.34958	-70.91286	:America/New_York	USA	knots	57	229	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Channel Aldridge Ledge	MA
98019	Deer Island, 0.7 nmi ESE of (depth 36 ft), Massachusetts Current	NOS	BOS1110_1	42.34413	-70.93888	:America/New_York	USA	knots	35	219	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.164	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deer Island, 0.7 nm ESE of	MA
98020	Deer Island, 0.7 nmi ESE of (depth 16 ft), Massachusetts Current	NOS	BOS1110_7	42.34413	-70.93888	:America/New_York	USA	knots	47	220	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deer Island, 0.7 nm ESE of	MA
98021	Deer Island, 0.7 nmi ESE of (depth 7 ft), Massachusetts Current	NOS	BOS1110_10	42.34413	-70.93888	:America/New_York	USA	knots	46	220	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deer Island, 0.7 nm ESE of	MA
98022	Boston Harbor (Deer Island Light) (depth 51 ft), Massachusetts Current	NOS	BOS1111_1	42.33778	-70.95578	:America/New_York	USA	knots	102	273	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Harbor (Deer Island Light)	MA
98023	Boston Harbor (Deer Island Light) (depth 28 ft), Massachusetts Current	NOS	BOS1111_8	42.33778	-70.95578	:America/New_York	USA	knots	100	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Harbor (Deer Island Light)	MA
98024	Boston Harbor (Deer Island Light) (depth 8 ft), Massachusetts Current	NOS	BOS1111_14	42.33778	-70.95578	:America/New_York	USA	knots	112	264	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Harbor (Deer Island Light)	MA
98025	Spectacle Island, 0.4 nmi north of (depth 33 ft), Massachusetts Current	NOS	BOS1112_1	42.33422	-70.98598	:America/New_York	USA	knots	99	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spectacle Island, 0.4nm north of	MA
98026	Spectacle Island, 0.4 nmi north of (depth 16 ft), Massachusetts Current	NOS	BOS1112_11	42.33422	-70.98598	:America/New_York	USA	knots	86	283	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spectacle Island, 0.4nm north of	MA
98027	Spectacle Island, 0.4 nmi north of (depth 3 ft), Massachusetts Current	NOS	BOS1112_19	42.33422	-70.98598	:America/New_York	USA	knots	91	284	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spectacle Island, 0.4nm north of	MA
98028	Boston Channel Light No. 5 (depth 33 ft), Massachusetts Current	NOS	BOS1113_3	42.33578	-71.00028	:America/New_York	USA	knots	119	297	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Channel Light No.5	MA
98029	Boston Channel Light No. 5 (depth 15 ft), Massachusetts Current	NOS	BOS1113_14	42.33578	-71.00028	:America/New_York	USA	knots	95	276	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.126	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Channel Light No.5	MA
98030	Boston Channel Light No. 5 (depth 3 ft), Massachusetts Current	NOS	BOS1113_21	42.33578	-71.00028	:America/New_York	USA	knots	104	283	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boston Channel Light No.5	MA
98031	Fort Independence, 0.1 nmi north of (depth 26 ft), Massachusetts Current	NOS	BOS1114_2	42.3418	-71.00892	:America/New_York	USA	knots	103	300	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.184	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Independence, 0.1nm north of	MA
98032	Fort Independence, 0.1 nmi north of (depth 16 ft), Massachusetts Current	NOS	BOS1114_5	42.3418	-71.00892	:America/New_York	USA	knots	108	297	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Independence, 0.1nm north of	MA
98033	Fort Independence, 0.1 nmi north of (depth 6 ft), Massachusetts Current	NOS	BOS1114_8	42.3418	-71.00892	:America/New_York	USA	knots	108	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Independence, 0.1nm north of	MA
98034	Ted William Tunnel (depth 26 ft), Massachusetts Current	NOS	BOS1115_1	42.3517	-71.02611	:America/New_York	USA	knots	125	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ted William Tunnel	MA
98035	Ted William Tunnel (depth 16 ft), Massachusetts Current	NOS	BOS1115_4	42.3517	-71.02611	:America/New_York	USA	knots	136	315	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ted William Tunnel	MA
98036	Ted William Tunnel (depth 7 ft), Massachusetts Current	NOS	BOS1115_7	42.3517	-71.02611	:America/New_York	USA	knots	124	312	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ted William Tunnel	MA
98037	Charlestown Pier 1 (depth 57 ft), Massachusetts Current	NOS	BOS1118_1	42.37996	-71.04502	:America/New_York	USA	knots	\N	357.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charlestown Pier 1	MA
98038	Charlestown Pier 1 (depth 31 ft), Massachusetts Current	NOS	BOS1118_9	42.37996	-71.04502	:America/New_York	USA	knots	\N	7.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charlestown Pier 1	MA
98039	Charlestown Pier 1 (depth 8 ft), Massachusetts Current	NOS	BOS1118_16	42.37996	-71.04502	:America/New_York	USA	knots	188	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Charlestown Pier 1	MA
98040	Nixes Mate (depth 27 ft), Massachusetts Current	NOS	BOS1119_1	42.33248	-70.9394	:America/New_York	USA	knots	352	147	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nixes Mate	MA
98041	Nixes Mate (depth 14 ft), Massachusetts Current	NOS	BOS1119_5	42.33248	-70.9394	:America/New_York	USA	knots	12	176	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nixes Mate	MA
98042	Nixes Mate (depth 4 ft), Massachusetts Current	NOS	BOS1119_8	42.33248	-70.9394	:America/New_York	USA	knots	23	180	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nixes Mate	MA
98043	Lovell Island Narrows (depth 25 ft), Massachusetts Current	NOS	BOS1120_1	42.32817	-70.93313	:America/New_York	USA	knots	320	149	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovell Island Narrows	MA
98044	Lovell Island Narrows (depth 14 ft), Massachusetts Current	NOS	BOS1120_8	42.32817	-70.93313	:America/New_York	USA	knots	320	139	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovell Island Narrows	MA
98045	Lovell Island Narrows (depth 2 ft), Massachusetts Current	NOS	BOS1120_15	42.32817	-70.93313	:America/New_York	USA	knots	326	142	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lovell Island Narrows	MA
98046	Georges Island, 0.4 nmi southeast of (depth 72 ft), Massachusetts Current	NOS	BOS1122_1	42.31293	-70.91995	:America/New_York	USA	knots	76	235	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 59.3 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Georges Island, 0.4nm southeast of	MA
98047	Georges Island, 0.4 nmi southeast of (depth 33 ft), Massachusetts Current	NOS	BOS1122_9	42.31293	-70.91995	:America/New_York	USA	knots	56	234	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Georges Island, 0.4nm southeast of	MA
98066	Stellwagen Basin, east end (depth 30 ft), Massachusetts Current	NOS	BOS1130_17	42.33813	-70.532	:America/New_York	USA	knots	147	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Basin, east end	MA
98048	Georges Island, 0.4 nmi southeast of (depth 7 ft), Massachusetts Current	NOS	BOS1122_17	42.31293	-70.91995	:America/New_York	USA	knots	51	233	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Georges Island, 0.4nm southeast of	MA
98049	Hull Gut (depth 35 ft), Massachusetts Current	NOS	BOS1123_1	42.30338	-70.92492	:America/New_York	USA	knots	343	152	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hull Gut	MA
98050	Hull Gut (depth 22 ft), Massachusetts Current	NOS	BOS1123_5	42.30338	-70.92492	:America/New_York	USA	knots	341	159	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hull Gut	MA
98051	Hull Gut (depth 9 ft), Massachusetts Current	NOS	BOS1123_9	42.30338	-70.92492	:America/New_York	USA	knots	340	162	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hull Gut	MA
98052	The Piglets, 0.4 nmi northest of (depth 30 ft), Massachusetts Current	NOS	BOS1124_1	42.28338	-70.93093	:America/New_York	USA	knots	36	207	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Piglets, 0.4 n.mi. northest of	MA
98053	The Piglets, 0.4 nmi northest of (depth 17 ft), Massachusetts Current	NOS	BOS1124_5	42.28338	-70.93093	:America/New_York	USA	knots	41	213	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Piglets, 0.4 n.mi. northest of	MA
98054	The Piglets, 0.4 nmi northest of (depth 7 ft), Massachusetts Current	NOS	BOS1124_8	42.28338	-70.93093	:America/New_York	USA	knots	41	224	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Piglets, 0.4 n.mi. northest of	MA
98055	Jacknife Ledge (depth 32 ft), Massachusetts Current	NOS	BOS1125_1	42.25878	-70.94102	:America/New_York	USA	knots	30	203	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jacknife Ledge	MA
98056	Jacknife Ledge (depth 16 ft), Massachusetts Current	NOS	BOS1125_6	42.25878	-70.94102	:America/New_York	USA	knots	17	216	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jacknife Ledge	MA
98057	Jacknife Ledge (depth 6 ft), Massachusetts Current	NOS	BOS1125_9	42.25878	-70.94102	:America/New_York	USA	knots	24	219	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Jacknife Ledge	MA
98058	Weymouth Harbor entrance (depth 29 ft), Massachusetts Current	NOS	BOS1126_1	42.2482	-70.96072	:America/New_York	USA	knots	65	249	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.174	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weymouth Harbor Entrance	MA
98059	Weymouth Harbor entrance (depth 16 ft), Massachusetts Current	NOS	BOS1126_5	42.2482	-70.96072	:America/New_York	USA	knots	73	250	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.098	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weymouth Harbor Entrance	MA
98060	Weymouth Harbor entrance (depth 6 ft), Massachusetts Current	NOS	BOS1126_8	42.2482	-70.96072	:America/New_York	USA	knots	76	250	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Weymouth Harbor Entrance	MA
98061	Point Allerton, 0.65 nmi NNW of (depth 30 ft), Massachusetts Current	NOS	BOS1127_1	42.31926	-70.88706	:America/New_York	USA	knots	71	236	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Allerton, 0.65 n.mi. NNW of	MA
98062	Point Allerton, 0.65 nmi NNW of (depth 17 ft), Massachusetts Current	NOS	BOS1127_5	42.31926	-70.88706	:America/New_York	USA	knots	71	253	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Allerton, 0.65 n.mi. NNW of	MA
98063	Point Allerton, 0.65 nmi NNW of (depth 4 ft), Massachusetts Current	NOS	BOS1127_9	42.31926	-70.88706	:America/New_York	USA	knots	72	266	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Allerton, 0.65 n.mi. NNW of	MA
98064	Stellwagen Basin, east end (depth 240 ft), Massachusetts Current	NOS	BOS1130_1	42.33813	-70.532	:America/New_York	USA	knots	97	266.8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Basin, east end	MA
98065	Stellwagen Basin, east end (depth 122 ft), Massachusetts Current	NOS	BOS1130_10	42.33813	-70.532	:America/New_York	USA	knots	93	255.7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Basin, east end	MA
98067	Stellwagen Bank, 16 nmi north of Race Point (depth 90 ft), Massachusetts Current	NOS	BOS1131_1	42.32397	-70.29397	:America/New_York	USA	knots	92	268	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 16nm North of Race Point	MA
98068	Stellwagen Bank, 16 nmi north of Race Point (depth 51 ft), Massachusetts Current	NOS	BOS1131_13	42.32397	-70.29397	:America/New_York	USA	knots	86	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.162	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 16nm North of Race Point	MA
98069	Stellwagen Bank, 16 nmi north of Race Point (depth 8 ft), Massachusetts Current	NOS	BOS1131_26	42.32397	-70.29397	:America/New_York	USA	knots	100	253	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.198	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 16nm North of Race Point	MA
98070	Stellwagen Bank, 15 nmi NNE of Race Point (depth 210 ft), Massachusetts Current	NOS	BOS1132_1	42.31213	-70.11202	:America/New_York	USA	knots	121	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 15nm NNE of Race Point	MA
98071	Stellwagen Bank, 15 nmi NNE of Race Point (depth 105 ft), Massachusetts Current	NOS	BOS1132_9	42.31213	-70.11202	:America/New_York	USA	knots	125	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 15nm NNE of Race Point	MA
98072	Stellwagen Bank, 15 nmi NNE of Race Point (depth 27 ft), Massachusetts Current	NOS	BOS1132_15	42.31213	-70.11202	:America/New_York	USA	knots	121	254	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 15nm NNE of Race Point	MA
98073	Stellwagen Bank, 13.4 nmi SE of Eastern Pt. Light (depth 71 ft), Massachusetts Current	NOS	BOS1133_1	42.4224	-70.44982	:America/New_York	USA	knots	49	223	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 13.4nm SE of Eastern Pt. Light	MA
98074	Stellwagen Bank, 13.4 nmi SE of Eastern Pt. Light (depth 38 ft), Massachusetts Current	NOS	BOS1133_6	42.4224	-70.44982	:America/New_York	USA	knots	70	236	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 13.4nm SE of Eastern Pt. Light	MA
98075	Stellwagen Bank, 13.4 nmi SE of Eastern Pt. Light (depth 12 ft), Massachusetts Current	NOS	BOS1133_10	42.4224	-70.44982	:America/New_York	USA	knots	93	252	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 13.4nm SE of Eastern Pt. Light	MA
98076	Stellwagen Basin, 13.8 nmi SE of Eastern Pt. Light (depth 245 ft), Massachusetts Current	NOS	BOS1134_1	42.38818	-70.48302	:America/New_York	USA	knots	\N	296	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Basin, 13.8nm SE of Eastern Pt. Light	MA
98077	Stellwagen Basin, 13.8 nmi SE of Eastern Pt. Light (depth 100 ft), Massachusetts Current	NOS	BOS1134_12	42.38818	-70.48302	:America/New_York	USA	knots	\N	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Basin, 13.8nm SE of Eastern Pt. Light	MA
98078	Stellwagen Basin, 13.8 nmi SE of Eastern Pt. Light (depth 35 ft), Massachusetts Current	NOS	BOS1134_17	42.38818	-70.48302	:America/New_York	USA	knots	195	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Basin, 13.8nm SE of Eastern Pt. Light	MA
98079	Stellwagen Bank, 17 nmi ESE of Eastern Pt. Light (depth 308 ft), Massachusetts Current	NOS	BOS1135_1	42.47305	-70.31203	:America/New_York	USA	knots	108	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 17nm ESE of Eastern Pt. Light	MA
98080	Stellwagen Bank, 17 nmi ESE of Eastern Pt. Light (depth 150 ft), Massachusetts Current	NOS	BOS1135_9	42.47305	-70.31203	:America/New_York	USA	knots	95	272.7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 17nm ESE of Eastern Pt. Light	MA
98081	Stellwagen Bank, 17 nmi ESE of Eastern Pt. Light (depth 52 ft), Massachusetts Current	NOS	BOS1135_14	42.47305	-70.31203	:America/New_York	USA	knots	91	269	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stellwagen Bank, 17nm ESE of Eastern Pt. Light	MA
98082	Portland Harbor entrance (depth 39 ft), Casco Bay, Maine Current	NOS	CAB1401_2	43.628	-70.2095	:America/New_York	USA	knots	140	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Harbor Entrance	ME
98083	Portland Harbor entrance (depth 19 ft), Casco Bay, Maine Current	NOS	CAB1401_8	43.628	-70.2095	:America/New_York	USA	knots	137	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Harbor Entrance	ME
98084	Portland Harbor entrance (depth 9 ft), Casco Bay, Maine Current	NOS	CAB1401_11	43.628	-70.2095	:America/New_York	USA	knots	138	310	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Harbor Entrance	ME
98085	Spring Point, NE of (depth 36 ft), Casco Bay, Maine Current	NOS	CAB1402_1	43.65367	-70.22267	:America/New_York	USA	knots	113	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Point, NE of	ME
98086	Spring Point, NE of (depth 20 ft), Casco Bay, Maine Current	NOS	CAB1402_6	43.65367	-70.22267	:America/New_York	USA	knots	123	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Point, NE of	ME
98087	Spring Point, NE of (depth 7 ft), Casco Bay, Maine Current	NOS	CAB1402_10	43.65367	-70.22267	:America/New_York	USA	knots	124	343	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Point, NE of	ME
98088	Portland Breakwater Light, 0.3 nmi east of (depth 36 ft), Casco Bay, Maine Current	NOS	CAB1403_2	43.65534	-70.22783	:America/New_York	USA	knots	102	247	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Breakwater Light, 0.3 n.mi east of	ME
98089	Portland Breakwater Light, 0.3 nmi east of (depth 20 ft), Casco Bay, Maine Current	NOS	CAB1403_7	43.65534	-70.22783	:America/New_York	USA	knots	121	256	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.159	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Breakwater Light, 0.3 n.mi east of	ME
98090	Portland Breakwater Light, 0.3 nmi east of (depth 6 ft), Casco Bay, Maine Current	NOS	CAB1403_11	43.65534	-70.22783	:America/New_York	USA	knots	114	268	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Breakwater Light, 0.3 n.mi east of	ME
98091	Diamond Island Roads (depth 34 ft), Casco Bay, Maine Current	NOS	CAB1404_3	43.66253	-70.21567	:America/New_York	USA	knots	168	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Diamond Island Roads	ME
98092	Diamond Island Roads (depth 17 ft), Casco Bay, Maine Current	NOS	CAB1404_8	43.66253	-70.21567	:America/New_York	USA	knots	165	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Diamond Island Roads	ME
98093	Diamond Island Roads (depth 7 ft), Casco Bay, Maine Current	NOS	CAB1404_11	43.66253	-70.21567	:America/New_York	USA	knots	164	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.145	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Diamond Island Roads	ME
98094	Ocean Gate Terminal (depth 21 ft), Casco Bay, Maine Current	NOS	CAB1405_1	43.661	-70.24	:America/New_York	USA	knots	28	208	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.157	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocean Gate Terminal	ME
98095	Ocean Gate Terminal (depth 3 ft), Casco Bay, Maine Current	NOS	CAB1405_12	43.661	-70.24	:America/New_York	USA	knots	50	230	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ocean Gate Terminal	ME
98096	State Pier, Portland Harbor (depth 30 ft), Casco Bay, Maine Current	NOS	CAB1406_1	43.65466	-70.245	:America/New_York	USA	knots	41	221	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Pier, Portland Harbor	ME
98097	State Pier, Portland Harbor (depth 17 ft), Casco Bay, Maine Current	NOS	CAB1406_5	43.65466	-70.245	:America/New_York	USA	knots	56	221	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Pier, Portland Harbor	ME
98098	State Pier, Portland Harbor (depth 3 ft), Casco Bay, Maine Current	NOS	CAB1406_9	43.65466	-70.245	:America/New_York	USA	knots	54	214	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Pier, Portland Harbor	ME
98099	Fore River, Portland River Bridge (depth 21 ft), Casco Bay, Maine Current	NOS	CAB1407_2	43.64583	-70.25733	:America/New_York	USA	knots	64	227	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fore River, Portland River Bridge	ME
98100	Fore River, Portland River Bridge (depth 5 ft), Casco Bay, Maine Current	NOS	CAB1407_7	43.64583	-70.25733	:America/New_York	USA	knots	65	229	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fore River, Portland River Bridge	ME
98101	Chandler Cove, S. ent. (depth 37 ft), Casco Bay, Maine Current	NOS	CAB1409_1	43.70698	-70.1323	:America/New_York	USA	knots	187	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chandler Cove, S. Ent	ME
98102	Chandler Cove, S. ent. (depth 17 ft), Casco Bay, Maine Current	NOS	CAB1409_7	43.70698	-70.1323	:America/New_York	USA	knots	180	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chandler Cove, S. Ent	ME
98103	Chandler Cove, S. ent. (depth 4 ft), Casco Bay, Maine Current	NOS	CAB1409_11	43.70698	-70.1323	:America/New_York	USA	knots	179	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chandler Cove, S. Ent	ME
98104	Hussey Sound, Between Long and Peaks Island (depth 70 ft), Casco Bay, Maine Current	NOS	CAB1410_1	43.670799255371094	-70.17632293701172	:America/New_York	USA	knots	140	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hussey Sound, Between Long and Peaks Island	ME
98105	Hussey Sound, Between Long and Peaks Island (depth 31 ft), Casco Bay, Maine Current	NOS	CAB1410_7	43.670799255371094	-70.17632293701172	:America/New_York	USA	knots	147	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hussey Sound, Between Long and Peaks Island	ME
98106	Hussey Sound, Between Long and Peaks Island (depth 11 ft), Casco Bay, Maine Current	NOS	CAB1410_10	43.670799255371094	-70.17632293701172	:America/New_York	USA	knots	145	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hussey Sound, Between Long and Peaks Island	ME
98107	Long Island, Mariner Ledge (depth 26 ft), Casco Bay, Maine Current	NOS	CAB1411_4	43.702	-70.16417	:America/New_York	USA	knots	194	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Long Island, Mariner Ledge	ME
98108	Long Island, Mariner Ledge (depth 9 ft), Casco Bay, Maine Current	NOS	CAB1411_9	43.702	-70.16417	:America/New_York	USA	knots	182	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Long Island, Mariner Ledge	ME
98109	Hussey Sound, Cow Island (depth 57 ft), Casco Bay, Maine Current	NOS	CAB1412_1	43.68983	-70.17834	:America/New_York	USA	knots	195	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hussey Sound, Cow Island	ME
98110	Hussey Sound, Cow Island (depth 30 ft), Casco Bay, Maine Current	NOS	CAB1412_5	43.68983	-70.17834	:America/New_York	USA	knots	185	12	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hussey Sound, Cow Island	ME
98111	Hussey Sound, Cow Island (depth 11 ft), Casco Bay, Maine Current	NOS	CAB1412_8	43.68983	-70.17834	:America/New_York	USA	knots	178	12	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hussey Sound, Cow Island	ME
98112	Cow Island, NE of (depth 39 ft), Casco Bay, Maine Current	NOS	CAB1413_2	43.69417	-70.181	:America/New_York	USA	knots	152	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cow Island, NE of	ME
98113	Cow Island, NE of (depth 13 ft), Casco Bay, Maine Current	NOS	CAB1413_6	43.69417	-70.181	:America/New_York	USA	knots	144	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cow Island, NE of	ME
98114	Lucksee Sound Between Hope and Cliff Is. (depth 40 ft), Casco Bay, Maine Current	NOS	CAB1414_1	43.69838	-70.11567	:America/New_York	USA	knots	227	51	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lucksee Sound Between Hope and Cliff Is.	ME
98115	Lucksee Sound Between Hope and Cliff Is. (depth 27 ft), Casco Bay, Maine Current	NOS	CAB1414_3	43.69838	-70.11567	:America/New_York	USA	knots	228	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lucksee Sound Between Hope and Cliff Is.	ME
98116	Lucksee Sound Between Hope and Cliff Is. (depth 14 ft), Casco Bay, Maine Current	NOS	CAB1414_5	43.69838	-70.11567	:America/New_York	USA	knots	227	50	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lucksee Sound Between Hope and Cliff Is.	ME
98117	Stepping Stones (depth 42 ft), Casco Bay, Maine Current	NOS	CAB1415_1	43.69583	-70.13267	:America/New_York	USA	knots	169	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stepping Stones	ME
98118	Stepping Stones (depth 19 ft), Casco Bay, Maine Current	NOS	CAB1415_8	43.69583	-70.13267	:America/New_York	USA	knots	191	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stepping Stones	ME
98119	Stepping Stones (depth 6 ft), Casco Bay, Maine Current	NOS	CAB1415_12	43.69583	-70.13267	:America/New_York	USA	knots	197	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stepping Stones	ME
98120	Eagle Island W. of, Broad Sound (depth 91 ft), Casco Bay, Maine Current	NOS	CAB1416_3	43.71	-70.06283	:America/New_York	USA	knots	191	340	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.263	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Island W. of., Broad Sound	ME
98121	Eagle Island W. of, Broad Sound (depth 39 ft), Casco Bay, Maine Current	NOS	CAB1416_11	43.71	-70.06283	:America/New_York	USA	knots	187	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Island W. of., Broad Sound	ME
98122	Eagle Island W. of, Broad Sound (depth 19 ft), Casco Bay, Maine Current	NOS	CAB1416_14	43.71	-70.06283	:America/New_York	USA	knots	187	351	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Island W. of., Broad Sound	ME
98123	Littlejohn Island, south of Town Ledge (depth 36 ft), Casco Bay, Maine Current	NOS	CAB1417_1	43.75417	-70.12767	:America/New_York	USA	knots	210	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Littlejohn Island, South of Town Ledge	ME
98124	Littlejohn Island, south of Town Ledge (depth 20 ft), Casco Bay, Maine Current	NOS	CAB1417_6	43.75417	-70.12767	:America/New_York	USA	knots	214	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Littlejohn Island, South of Town Ledge	ME
98125	Littlejohn Island, south of Town Ledge (depth 6 ft), Casco Bay, Maine Current	NOS	CAB1417_10	43.75417	-70.12767	:America/New_York	USA	knots	221	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Littlejohn Island, South of Town Ledge	ME
98126	Maine Kennebec Bridge, 0.2 nmi SW of (depth 19 ft), Kennebec River, Maine Current	NOS	CAB1418_1	44.088	-69.78517	:America/New_York	USA	knots	202	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.337	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Maine Kennebec Bridge, 0.2 n.mi. SW of	ME
98127	Maine Kennebec Bridge, 0.2 nmi SW of (depth 4 ft), Kennebec River, Maine Current	NOS	CAB1418_10	44.088	-69.78517	:America/New_York	USA	knots	208	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.413	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Maine Kennebec Bridge, 0.2 n.mi. SW of	ME
98128	Goose Cove, south of Chops Passage, Kennebec River (depth 27 ft), Maine Current	NOS	CAB1419_1	43.97516	-69.82667	:America/New_York	USA	knots	158	338	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.388	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goose Cove, south of Chops Passage, Kennebec River	ME
98129	Goose Cove, south of Chops Passage, Kennebec River (depth 14 ft), Maine Current	NOS	CAB1419_5	43.97516	-69.82667	:America/New_York	USA	knots	154	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.419	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goose Cove, south of Chops Passage, Kennebec River	ME
98130	Goose Cove, south of Chops Passage, Kennebec River (depth 4 ft), Maine Current	NOS	CAB1419_8	43.97516	-69.82667	:America/New_York	USA	knots	154	343	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.407	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Goose Cove, south of Chops Passage, Kennebec River	ME
98131	Bath Iron Works, Kennebec River (depth 36 ft), Maine Current	NOS	CAB1420_1	43.90383	-69.80933	:America/New_York	USA	knots	176	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 38.9 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bath Iron Works, Kennebec River	ME
98132	Bath Iron Works, Kennebec River (depth 16 ft), Maine Current	NOS	CAB1420_8	43.90383	-69.80933	:America/New_York	USA	knots	178	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bath Iron Works, Kennebec River	ME
98133	Bath Iron Works, Kennebec River (depth 4 ft), Maine Current	NOS	CAB1420_12	43.90383	-69.80933	:America/New_York	USA	knots	178	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 2.8 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.242	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bath Iron Works, Kennebec River	ME
98134	Merrymeeting Bay, N of Chops Pass, Kennebec River (depth 40 ft), Maine Current	NOS	CAB1421_1	43.98433	-69.83617	:America/New_York	USA	knots	137	307	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Merrymeeting Bay, N of Chops Pass., Kennebec River	ME
98135	Merrymeeting Bay, N of Chops Pass, Kennebec River (depth 20 ft), Maine Current	NOS	CAB1421_7	43.98433	-69.83617	:America/New_York	USA	knots	120	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Merrymeeting Bay, N of Chops Pass., Kennebec River	ME
98136	Merrymeeting Bay, N of Chops Pass, Kennebec River (depth 4 ft), Maine Current	NOS	CAB1421_12	43.98433	-69.83617	:America/New_York	USA	knots	108	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.252	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Merrymeeting Bay, N of Chops Pass., Kennebec River	ME
98137	Seal Cove, Cape Elizabeth (depth 29 ft), Maine Current	NOS	CAB1423_1	43.55233	-70.21767	:America/New_York	USA	knots	\N	315.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seal Cove, Cape Elizabeth	ME
98697	Cape Trinity (depth 106 ft), Sitkinak Strait, Alaska Current	NOS	KOD0918_13	56.74982	-154.201	:America/Anchorage	USA	knots	131	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.201	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Trinity	AK
98138	Seal Cove, Cape Elizabeth (depth 19 ft), Maine Current	NOS	CAB1423_4	43.55233	-70.21767	:America/New_York	USA	knots	\N	319.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seal Cove, Cape Elizabeth	ME
98139	Seal Cove, Cape Elizabeth (depth 3 ft), Maine Current	NOS	CAB1423_9	43.55233	-70.21767	:America/New_York	USA	knots	112	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seal Cove, Cape Elizabeth	ME
98140	Saco River entrance (depth 13 ft), Maine Current	NOS	CAB1425_4	43.4621	-70.35116	:America/New_York	USA	knots	\N	272.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saco River Entrance	ME
98141	Saco River entrance (depth 1 ft), Maine Current	NOS	CAB1425_11	43.4621	-70.35116	:America/New_York	USA	knots	78	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saco River Entrance	ME
98142	Cape May Harbor entrance (depth 28 ft), New Jersey Current	NOS	CAM0001_2	38.9475	-74.87267	:America/New_York	USA	knots	143	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May Harbor entrance	NJ
98143	Cape May Harbor entrance (depth 15 ft), New Jersey Current	NOS	CAM0001_10	38.9475	-74.87267	:America/New_York	USA	knots	142	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May Harbor entrance	NJ
98144	Cape May Harbor entrance (depth 5 ft), New Jersey Current	NOS	CAM0001_16	38.9475	-74.87267	:America/New_York	USA	knots	142	324	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May Harbor entrance	NJ
98145	Hilton RR Bridge, 0.1 nmi N of (depth 31 ft), Cape Fear River, North Carolina Current	NOS	CFR1601_1	34.25918960571289	-77.94805908203125	:America/New_York	USA	knots	173	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 25.8 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hilton RR Bridge, 0.1 nm N of	NC
98146	Hilton RR Bridge, 0.1 nmi N of (depth 12 ft), Cape Fear River, North Carolina Current	NOS	CFR1601_7	34.25918960571289	-77.94805908203125	:America/New_York	USA	knots	169	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 6.1 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hilton RR Bridge, 0.1 nm N of	NC
98147	Isabel Holmes Bridge (depth 29 ft), Cape Fear River, North Carolina Current	NOS	CFR1602_1	34.252410888671875	-77.95008850097656	:America/New_York	USA	knots	224	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isabel Holmes Bridge	NC
98148	Isabel Holmes Bridge (depth 6 ft), Cape Fear River, North Carolina Current	NOS	CFR1602_8	34.252410888671875	-77.95008850097656	:America/New_York	USA	knots	215	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isabel Holmes Bridge	NC
98149	Wilmington, Northeast River (depth 34 ft), Cape Fear River, North Carolina Current	NOS	CFR1603_1	34.241939544677734	-77.95394134521484	:America/New_York	USA	knots	161	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilmington, Northeast River	NC
98150	Wilmington, Northeast River (depth 14 ft), Cape Fear River, North Carolina Current	NOS	CFR1603_13	34.241939544677734	-77.95394134521484	:America/New_York	USA	knots	169	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilmington, Northeast River	NC
98151	Wilmington, Northeast River (depth 4 ft), Cape Fear River, North Carolina Current	NOS	CFR1603_19	34.241939544677734	-77.95394134521484	:America/New_York	USA	knots	171	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilmington, Northeast River	NC
98152	Point Peter (depth 23 ft), Cape Fear River, North Carolina Current	NOS	CFR1604_1	34.242488861083984	-77.95768737792969	:America/New_York	USA	knots	133	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Peter	NC
98153	Point Peter (depth 5 ft), Cape Fear River, North Carolina Current	NOS	CFR1604_12	34.242488861083984	-77.95768737792969	:America/New_York	USA	knots	132	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.249	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Peter	NC
98154	Wilmington, USS North Carolina (depth 25 ft), Cape Fear River, North Carolina Current	NOS	CFR1605_3	34.23347854614258	-77.9503173828125	:America/New_York	USA	knots	180	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilmington, USS North Carolina	NC
98155	Wilmington, USS North Carolina (depth 5 ft), Cape Fear River, North Carolina Current	NOS	CFR1605_9	34.23347854614258	-77.9503173828125	:America/New_York	USA	knots	179	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wilmington, USS North Carolina	NC
98156	State Pier, N end, sidelooking (depth 20 ft), Cape Fear River, North Carolina Current	NOS	CFR1607_1	34.207801818847656	-77.9554214477539	:America/New_York	USA	knots	192	11	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Pier, N end, sidelooking	NC
98157	State Pier, N end, sidelooking (depth 151 ft), Cape Fear River, North Carolina Current	NOS	CFR1607_9	34.207801818847656	-77.9554214477539	:America/New_York	USA	knots	185	11	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Pier, N end, sidelooking	NC
98158	State Pier, N end, sidelooking (depth 315 ft), Cape Fear River, North Carolina Current	NOS	CFR1607_19	34.207801818847656	-77.9554214477539	:America/New_York	USA	knots	185	7	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.289	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	State Pier, N end, sidelooking	NC
98159	Dram Tree Point (depth 32 ft), Cape Fear River, North Carolina Current	NOS	CFR1608_2	34.190608978271484	-77.9577407836914	:America/New_York	USA	knots	178	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dram Tree Point	NC
98160	Dram Tree Point (depth 6 ft), Cape Fear River, North Carolina Current	NOS	CFR1608_10	34.190608978271484	-77.9577407836914	:America/New_York	USA	knots	181	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.375	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dram Tree Point	NC
98161	Port of Wilmington, south end (depth 43 ft), Cape Fear River, North Carolina Current	NOS	CFR1609_3	34.17580032348633	-77.9569091796875	:America/New_York	USA	knots	182	5	\N	\N	Depth provided in the stations list was duplicated for all bins.  Depth is as\nspecified in the harcon record.  Unknown whether it is below surface or chart\ndatum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.241	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of Wilmington, South End	NC
98162	Port of Wilmington, south end (depth 200 ft), Cape Fear River, North Carolina Current	NOS	CFR1609_15	34.17580032348633	-77.9569091796875	:America/New_York	USA	knots	174	357	\N	\N	Depth provided in the stations list was duplicated for all bins.  Depth is as\nspecified in the harcon record.  Unknown whether it is below surface or chart\ndatum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.371	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of Wilmington, South End	NC
98163	Port of Wilmington, south end (depth 331 ft), Cape Fear River, North Carolina Current	NOS	CFR1609_25	34.17580032348633	-77.9569091796875	:America/New_York	USA	knots	173	355	\N	\N	Depth provided in the stations list was duplicated for all bins.  Depth is as\nspecified in the harcon record.  Unknown whether it is below surface or chart\ndatum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of Wilmington, South End	NC
98164	Lower Brunswick Range (depth 39 ft), Cape Fear River, North Carolina Current	NOS	CFR1610_1	34.155941009521484	-77.95828247070312	:America/New_York	USA	knots	147	324	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.255	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Brunswick Range	NC
98165	Lower Brunswick Range (depth 16 ft), Cape Fear River, North Carolina Current	NOS	CFR1610_8	34.155941009521484	-77.95828247070312	:America/New_York	USA	knots	141	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Brunswick Range	NC
98166	Lower Brunswick Range (depth 9 ft), Cape Fear River, North Carolina Current	NOS	CFR1610_10	34.155941009521484	-77.95828247070312	:America/New_York	USA	knots	140	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lower Brunswick Range	NC
98167	Upper Big I Range (depth 36 ft), Cape Fear River, North Carolina Current	NOS	CFR1611_1	34.135501861572266	-77.94210052490234	:America/New_York	USA	knots	136	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.279	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upper Big I Range	NC
98168	Upper Big I Range (depth 20 ft), Cape Fear River, North Carolina Current	NOS	CFR1611_6	34.135501861572266	-77.94210052490234	:America/New_York	USA	knots	124	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upper Big I Range	NC
98169	Upper Big I Range (depth 6 ft), Cape Fear River, North Carolina Current	NOS	CFR1611_10	34.135501861572266	-77.94210052490234	:America/New_York	USA	knots	126	310	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.203	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upper Big I Range	NC
98170	Campbell Island, east side (depth 35 ft), Cape Fear River, North Carolina Current	NOS	CFR1612_1	34.119911193847656	-77.93521881103516	:America/New_York	USA	knots	187	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.184	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Campbell Island, East Side	NC
98171	Campbell Island, east side (depth 15 ft), Cape Fear River, North Carolina Current	NOS	CFR1612_7	34.119911193847656	-77.93521881103516	:America/New_York	USA	knots	185	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Campbell Island, East Side	NC
98172	Campbell Island, east side (depth 9 ft), Cape Fear River, North Carolina Current	NOS	CFR1612_9	34.119911193847656	-77.93521881103516	:America/New_York	USA	knots	189	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Campbell Island, East Side	NC
98173	Keg Island, west side (depth 30 ft), Cape Fear River, North Carolina Current	NOS	CFR1613_1	34.09700012207031	-77.93463897705078	:America/New_York	USA	knots	167	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Keg Island, West Side	NC
98174	Keg Island, west side (depth 7 ft), Cape Fear River, North Carolina Current	NOS	CFR1613_8	34.09700012207031	-77.93463897705078	:America/New_York	USA	knots	161	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.396	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Keg Island, West Side	NC
98175	Doctor Point, 0.6 nmi NNW of (depth 32 ft), Cape Fear River, North Carolina Current	NOS	CFR1614_1	34.07883071899414	-77.93205261230469	:America/New_York	USA	knots	163	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Doctor Point, 0.6 NM NNW of	NC
98176	Doctor Point, 0.6 nmi NNW of (depth 16 ft), Cape Fear River, North Carolina Current	NOS	CFR1614_6	34.07883071899414	-77.93205261230469	:America/New_York	USA	knots	166	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Doctor Point, 0.6 NM NNW of	NC
98177	Doctor Point, 0.6 nmi NNW of (depth 6 ft), Cape Fear River, North Carolina Current	NOS	CFR1614_9	34.07883071899414	-77.93205261230469	:America/New_York	USA	knots	166	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.384	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Doctor Point, 0.6 NM NNW of	NC
98178	Myrtle Sound, south end, ICW (depth 16 ft), Cape Fear River, North Carolina Current	NOS	CFR1615_1	34.07929992675781	-77.8843994140625	:America/New_York	USA	knots	233	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Myrtle Sound, south end, ICW	NC
98179	Snows Cut, ICW (depth 3 ft), Cape Fear River, North Carolina Current	NOS	CFR1616_4	34.05580139160156	-77.89900207519531	:America/New_York	USA	knots	254	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snows Cut, ICW	NC
98180	Orton Point, 0.5 nmi S of (depth 38 ft), Cape Fear River, North Carolina Current	NOS	CFR1617_1	34.047340393066406	-77.94104766845703	:America/New_York	USA	knots	179	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.272	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orton Point, 0.5 NM S of	NC
98181	Orton Point, 0.5 nmi S of (depth 15 ft), Cape Fear River, North Carolina Current	NOS	CFR1617_8	34.047340393066406	-77.94104766845703	:America/New_York	USA	knots	181	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orton Point, 0.5 NM S of	NC
98182	Orton Point, 0.5 nmi S of (depth 8 ft), Cape Fear River, North Carolina Current	NOS	CFR1617_10	34.047340393066406	-77.94104766845703	:America/New_York	USA	knots	189	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.268	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Orton Point, 0.5 NM S of	NC
98183	Upper Midnight Channel (depth 33 ft), Cape Fear River, North Carolina Current	NOS	CFR1618_2	34.02907943725586	-77.94080352783203	:America/New_York	USA	knots	183	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upper Midnight Channel	NC
98184	Upper Midnight Channel (depth 20 ft), Cape Fear River, North Carolina Current	NOS	CFR1618_6	34.02907943725586	-77.94080352783203	:America/New_York	USA	knots	188	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upper Midnight Channel	NC
98185	Upper Midnight Channel (depth 7 ft), Cape Fear River, North Carolina Current	NOS	CFR1618_10	34.02907943725586	-77.94080352783203	:America/New_York	USA	knots	183	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upper Midnight Channel	NC
98186	Reaves Point, 0.9 nmi NE of (depth 33 ft), Cape Fear River, North Carolina Current	NOS	CFR1619_1	34.005950927734375	-77.94020080566406	:America/New_York	USA	knots	205	20	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reaves Point, 0.9 NM NE of	NC
98187	Reaves Point, 0.9 nmi NE of (depth 20 ft), Cape Fear River, North Carolina Current	NOS	CFR1619_5	34.005950927734375	-77.94020080566406	:America/New_York	USA	knots	191	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reaves Point, 0.9 NM NE of	NC
98188	Reaves Point, 0.9 nmi NE of (depth 10 ft), Cape Fear River, North Carolina Current	NOS	CFR1619_8	34.005950927734375	-77.94020080566406	:America/New_York	USA	knots	191	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reaves Point, 0.9 NM NE of	NC
96871	Great Pocket, St. Lucie River, Florida	NOS	8722381	27.155	-80.1717	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	95140	01:42:00	\N	1	00:55:00	\N	0.5	\N	\N	Great Pocket	FL
98189	Sunny Point, 0.5 nmi SE of (depth 12 ft), Cape Fear River, North Carolina Current	NOS	CFR1620_1	33.978248596191406	-77.94994354248047	:America/New_York	USA	knots	190	17	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunny Point, 0.5 nm SE of	NC
98190	Sunny Point, 0.5 nmi SE of (depth 18 ft), Cape Fear River, North Carolina Current	NOS	CFR1620_3	33.978248596191406	-77.94994354248047	:America/New_York	USA	knots	178	14	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunny Point, 0.5 nm SE of	NC
98191	Sunny Point, 0.5 nmi SE of (depth 35 ft), Cape Fear River, North Carolina Current	NOS	CFR1620_8	33.978248596191406	-77.94994354248047	:America/New_York	USA	knots	178	0	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.182	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunny Point, 0.5 nm SE of	NC
98192	Snows Marsh Channel (depth 12 ft), Cape Fear River, North Carolina Current	NOS	CFR1621_1	33.93717956542969	-77.9778823852539	:America/New_York	USA	knots	262	49	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snows Marsh Channel	NC
98193	Snows Marsh Channel (depth 25 ft), Cape Fear River, North Carolina Current	NOS	CFR1621_5	33.93717956542969	-77.9778823852539	:America/New_York	USA	knots	239	51	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snows Marsh Channel	NC
98194	Snows Marsh Channel (depth 38 ft), Cape Fear River, North Carolina Current	NOS	CFR1621_9	33.93717956542969	-77.9778823852539	:America/New_York	USA	knots	247	54	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snows Marsh Channel	NC
98195	Southport at Dutchman Creek, ICW (depth 12 ft), Cape Fear River, North Carolina Current	NOS	CFR1622_1	33.91761016845703	-78.0430679321289	:America/New_York	USA	knots	117	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport at Dutchman Creek, ICW	NC
98196	Southport at Dutchman Creek, ICW (depth 4 ft), Cape Fear River, North Carolina Current	NOS	CFR1622_6	33.91761016845703	-78.0430679321289	:America/New_York	USA	knots	119	295	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport at Dutchman Creek, ICW	NC
98197	Oak Island Bridge, ICW (depth 11 ft), Cape Fear River, North Carolina Current	NOS	CFR1623_3	33.921661376953125	-78.07276153564453	:America/New_York	USA	knots	86	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.276	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oak Island Bridge, ICW	NC
98198	Southport (depth 37 ft), Cape Fear River, North Carolina Current	NOS	CFR1624_1	33.91537857055664	-78.01215362548828	:America/New_York	USA	knots	225	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport	NC
98199	Southport (depth 20 ft), Cape Fear River, North Carolina Current	NOS	CFR1624_6	33.91537857055664	-78.01215362548828	:America/New_York	USA	knots	231	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport	NC
98200	Southport (depth 7 ft), Cape Fear River, North Carolina Current	NOS	CFR1624_10	33.91537857055664	-78.01215362548828	:America/New_York	USA	knots	235	48	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.595	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southport	NC
98201	Fort Caswell (depth 12 ft), Cape Fear River, North Carolina Current	NOS	CFR1625_1	33.888328552246094	-78.00763702392578	:America/New_York	USA	knots	161	12	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.265	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Caswell	NC
98202	Fort Caswell (depth 18 ft), Cape Fear River, North Carolina Current	NOS	CFR1625_3	33.888328552246094	-78.00763702392578	:America/New_York	USA	knots	161	6	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Caswell	NC
98203	Fort Caswell (depth 28 ft), Cape Fear River, North Carolina Current	NOS	CFR1625_6	33.888328552246094	-78.00763702392578	:America/New_York	USA	knots	162	347	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Caswell	NC
98204	Bald Head Shoal (depth 12 ft), Cape Fear River, North Carolina Current	NOS	CFR1626_1	33.8543586730957	-78.0271987915039	:America/New_York	USA	knots	208	13	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.388	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bald Head Shoal	NC
98205	Bald Head Shoal (depth 28 ft), Cape Fear River, North Carolina Current	NOS	CFR1626_6	33.8543586730957	-78.0271987915039	:America/New_York	USA	knots	203	13	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bald Head Shoal	NC
98206	Cedar Point, 4.7 nmi east of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	CHB0301_6	38.2985	-76.273	:America/New_York	USA	knots	144	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cedar Point, 4.7 n.mi. east of	MD
98207	Cedar Point, 4.7 nmi east of (depth 5 ft), Chesapeake Bay, Maryland Current	NOS	CHB0301_14	38.2985	-76.273	:America/New_York	USA	knots	145	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.187	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cedar Point, 4.7 n.mi. east of	MD
98208	Love Point, 2.0 nmi north of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	CHB0302_10	39.074	-76.30317	:America/New_York	USA	knots	240	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Love Point, 2.0 nmi north of	MD
98209	Love Point, 2.0 nmi north of (depth 5 ft), Chesapeake Bay, Maryland Current	NOS	CHB0302_18	39.074	-76.30317	:America/New_York	USA	knots	238	67	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Love Point, 2.0 nmi north of	MD
98210	Smith Point Light, 5.0 nmi NW of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	CHB0303_7	37.93652	-76.26135	:America/New_York	USA	knots	125	296	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Point Light, 5.0 n.mi. NW of	MD
98211	Smith Point Light, 5.0 nmi NW of (depth 5 ft), Chesapeake Bay, Maryland Current	NOS	CHB0303_16	37.93652	-76.26135	:America/New_York	USA	knots	125	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.304	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Point Light, 5.0 n.mi. NW of	MD
98212	James Island, 1.6 nmi SW of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	CHB0304_4	38.48573	-76.36457	:America/New_York	USA	knots	156	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	James Island, 1.6 n.mi. SW of	MD
98213	James Island, 1.6 nmi SW of (depth 5 ft), Chesapeake Bay, Maryland Current	NOS	CHB0304_13	38.48573	-76.36457	:America/New_York	USA	knots	165	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	James Island, 1.6 n.mi. SW of	MD
98214	0.75 nmi west, Thimble Shoal Channel (depth 39 ft), Chesapeake Bay, Virginia Current	NOS	CHB9902_1	36.97739	-76.1242	:America/New_York	USA	knots	96	281	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.157	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.75nm west, Thimble Shoal Channel	VA
98215	0.75 nmi west, Thimble Shoal Channel (depth 29 ft), Chesapeake Bay, Virginia Current	NOS	CHB9902_4	36.97739	-76.1242	:America/New_York	USA	knots	101	284	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.75nm west, Thimble Shoal Channel	VA
98216	0.75 nmi west, Thimble Shoal Channel (depth 16 ft), Chesapeake Bay, Virginia Current	NOS	CHB9902_8	36.97739	-76.1242	:America/New_York	USA	knots	111	289	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.179	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.75nm west, Thimble Shoal Channel	VA
98217	0.75 nmi west, Thimble Shoal Channel (depth 6 ft), Chesapeake Bay, Virginia Current	NOS	CHB9902_11	36.97739	-76.1242	:America/New_York	USA	knots	113	288	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.75nm west, Thimble Shoal Channel	VA
98218	Hampton Roads entrance, midchannel (depth 61 ft), Virginia Current	NOS	CHB9903_1	36.99428	-76.30527	:America/New_York	USA	knots	55	229	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hampton Roads entrance, midchannel	VA
98219	Hampton Roads entrance, midchannel (depth 44 ft), Virginia Current	NOS	CHB9903_6	36.99428	-76.30527	:America/New_York	USA	knots	59	241	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hampton Roads entrance, midchannel	VA
98220	Hampton Roads entrance, midchannel (depth 31 ft), Virginia Current	NOS	CHB9903_10	36.99428	-76.30527	:America/New_York	USA	knots	65	243	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hampton Roads entrance, midchannel	VA
98221	Hampton Roads entrance, midchannel (depth 15 ft), Virginia Current	NOS	CHB9903_15	36.99428	-76.30527	:America/New_York	USA	knots	62	244	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hampton Roads entrance, midchannel	VA
98222	Hampton Roads entrance, midchannel (depth 8 ft), Virginia Current	NOS	CHB9903_17	36.99428	-76.30527	:America/New_York	USA	knots	59	243	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hampton Roads entrance, midchannel	VA
98223	0.15 nmi WSW of Pier No. 2 (depth 42 ft), Newport News, Hampton Roads, Virginia Current	NOS	CHB9904_1	36.97925	-76.44348	:America/New_York	USA	knots	165	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.15nm WSW of Pier No.2	VA
95836	Point Hope, Chukchi Sea, Alaska	NOS	9491873	68.3417	-166.808	:America/Nome	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	0.3299999999999996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Hope	AK
98224	0.15 nmi WSW of Pier No. 2 (depth 29 ft), Newport News, Hampton Roads, Virginia Current	NOS	CHB9904_5	36.97925	-76.44348	:America/New_York	USA	knots	162	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.15nm WSW of Pier No.2	VA
98225	0.15 nmi WSW of Pier No. 2 (depth 15 ft), Newport News, Hampton Roads, Virginia Current	NOS	CHB9904_9	36.97925	-76.44348	:America/New_York	USA	knots	161	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.15nm WSW of Pier No.2	VA
98226	0.15 nmi WSW of Pier No. 2 (depth 6 ft), Newport News, Hampton Roads, Virginia Current	NOS	CHB9904_12	36.97925	-76.44348	:America/New_York	USA	knots	161	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	0.15nm WSW of Pier No.2	VA
98227	Craney Island Reach (depth 43 ft), Elizabeth River, Virginia Current	NOS	CHB9905_1	36.89053	-76.33575	:America/New_York	USA	knots	4	182	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.184	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Craney Island Reach	VA
98228	Craney Island Reach (depth 33 ft), Elizabeth River, Virginia Current	NOS	CHB9905_4	36.89053	-76.33575	:America/New_York	USA	knots	8	185	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.166	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Craney Island Reach	VA
98229	Craney Island Reach (depth 17 ft), Elizabeth River, Virginia Current	NOS	CHB9905_9	36.89053	-76.33575	:America/New_York	USA	knots	4	184	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Craney Island Reach	VA
98230	Craney Island Reach (depth 7 ft), Elizabeth River, Virginia Current	NOS	CHB9905_12	36.89053	-76.33575	:America/New_York	USA	knots	9	184	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Craney Island Reach	VA
98231	Cape Cod Canal, east end (depth 34 ft), Massachusetts Current	NOS	COD0901_2	41.77553	-70.49932	:America/New_York	USA	knots	231	48	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, east end	MA
98232	Cape Cod Canal, east end (depth 15 ft), Massachusetts Current	NOS	COD0901_8	41.77553	-70.49932	:America/New_York	USA	knots	232	53	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, east end	MA
98233	Cape Cod Canal, east end (depth 8 ft), Massachusetts Current	NOS	COD0901_10	41.77553	-70.49932	:America/New_York	USA	knots	233	53	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, east end	MA
98234	Sagamore Bridge (depth 42 ft), Cape Cod Canal, Massachusetts Current	NOS	COD0902_1	41.77617	-70.5433	:America/New_York	USA	knots	256	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sagamore Bridge	MA
98235	Sagamore Bridge (depth 26 ft), Cape Cod Canal, Massachusetts Current	NOS	COD0902_6	41.77617	-70.5433	:America/New_York	USA	knots	259	79	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sagamore Bridge	MA
98236	Sagamore Bridge (depth 6 ft), Cape Cod Canal, Massachusetts Current	NOS	COD0902_12	41.77617	-70.5433	:America/New_York	USA	knots	260	77	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sagamore Bridge	MA
98237	Bournedale (depth 46 ft), Cape Cod Canal, Massachusetts Current	NOS	COD0903_1	41.76654	-70.56702	:America/New_York	USA	knots	214	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bournedale	MA
98238	Bournedale (depth 30 ft), Cape Cod Canal, Massachusetts Current	NOS	COD0903_6	41.76654	-70.56702	:America/New_York	USA	knots	217	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bournedale	MA
98239	Bournedale (depth 13 ft), Cape Cod Canal, Massachusetts Current	NOS	COD0903_11	41.76654	-70.56702	:America/New_York	USA	knots	219	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bournedale	MA
98240	Cape Cod Canal, Railroad Bridge, midchannel (depth 71 ft), Massachusetts Current	NOS	COD0904_5	41.74268	-70.61418	:America/New_York	USA	knots	\N	67.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, Railroad Bridge, midchannel	MA
98693	Sitkinak Strait, southwest entrance (depth 81 ft), Alaska Current	NOS	KOD0917_1	56.65504	-154.13396	:America/Anchorage	USA	knots	112	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.256	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitkinak Strait, southwest entrance	AK
98241	Cape Cod Canal, Railroad Bridge, midchannel (depth 13 ft), Massachusetts Current	NOS	COD0904_15	41.74268	-70.61418	:America/New_York	USA	knots	248	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 201.8 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, Railroad Bridge, midchannel	MA
98242	Cape Cod Canal, Railroad Bridge, midchannel (depth 399 ft), Massachusetts Current	NOS	COD0904_30	41.74268	-70.61418	:America/New_York	USA	knots	\N	61.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, Railroad Bridge, midchannel	MA
98243	Hog Neck (depth 28 ft), Buzzards Bay, Massachusetts Current	NOS	COD0905_1	41.72389	-70.63938	:America/New_York	USA	knots	208	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hog Neck	MA
98244	Hog Neck (depth 15 ft), Buzzards Bay, Massachusetts Current	NOS	COD0905_5	41.72389	-70.63938	:America/New_York	USA	knots	209	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.105	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hog Neck	MA
98245	Hog Neck (depth 2 ft), Buzzards Bay, Massachusetts Current	NOS	COD0905_9	41.72389	-70.63938	:America/New_York	USA	knots	210	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.163	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hog Neck	MA
98246	Abiels ledge (depth 31 ft), Buzzards Bay, Massachusetts Current	NOS	COD0906_1	41.68973	-70.67081	:America/New_York	USA	knots	235	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Abiels ledge	MA
98247	Abiels ledge (depth 15 ft), Buzzards Bay, Massachusetts Current	NOS	COD0906_11	41.68973	-70.67081	:America/New_York	USA	knots	235	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Abiels ledge	MA
98248	Abiels ledge (depth 3 ft), Buzzards Bay, Massachusetts Current	NOS	COD0906_18	41.68973	-70.67081	:America/New_York	USA	knots	236	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.222	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Abiels ledge	MA
98249	Cleveland Ledge (depth 34 ft), Buzzards Bay, Massachusetts Current	NOS	COD0907_1	41.63223	-70.69685	:America/New_York	USA	knots	217	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cleveland Ledge	MA
98250	Cleveland Ledge (depth 15 ft), Buzzards Bay, Massachusetts Current	NOS	COD0907_7	41.63223	-70.69685	:America/New_York	USA	knots	213	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cleveland Ledge	MA
98251	Cleveland Ledge (depth 8 ft), Buzzards Bay, Massachusetts Current	NOS	COD0907_9	41.63223	-70.69685	:America/New_York	USA	knots	212	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cleveland Ledge	MA
98252	West Island, 1 mi southeast of (depth 27 ft), Buzzards Bay, Massachusetts Current	NOS	COD0908_1	41.5657	-70.81098	:America/New_York	USA	knots	243	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Island, 1 mile Southeast of	MA
98253	West Island, 1 mi southeast of (depth 15 ft), Buzzards Bay, Massachusetts Current	NOS	COD0908_8	41.5657	-70.81098	:America/New_York	USA	knots	233	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Island, 1 mile Southeast of	MA
98254	West Island, 1 mi southeast of (depth 4 ft), Buzzards Bay, Massachusetts Current	NOS	COD0908_15	41.5657	-70.81098	:America/New_York	USA	knots	225	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Island, 1 mile Southeast of	MA
98255	New Bedford Hurricane Barrier (depth 24 ft), Buzzards Bay, Massachusetts Current	NOS	COD0909_1	41.62324	-70.90509	:America/New_York	USA	knots	134	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Bedford Hurricane Barrier	MA
98256	New Bedford Hurricane Barrier (depth 14 ft), Buzzards Bay, Massachusetts Current	NOS	COD0909_4	41.62324	-70.90509	:America/New_York	USA	knots	134	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.146	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Bedford Hurricane Barrier	MA
98257	New Bedford Hurricane Barrier (depth 4 ft), Buzzards Bay, Massachusetts Current	NOS	COD0909_7	41.62324	-70.90509	:America/New_York	USA	knots	134	320	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.271	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Bedford Hurricane Barrier	MA
95012	Springmaid Pier, Springmaid Beach, South Carolina	NOS	8661070	33.6555556	-78.9163889	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-29	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	Mean Lower Low Water	2.710000000000001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Springmaid Pier	SC
98258	North end (depth 17 ft), Woods Hole, Massachusetts Current	NOS	COD0910_1	41.52297	-70.693	:America/New_York	USA	knots	13	197	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North end	MA
98259	North end (depth 4 ft), Woods Hole, Massachusetts Current	NOS	COD0910_9	41.52297	-70.693	:America/New_York	USA	knots	4	195	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North end	MA
98260	Woods Hole, The Strait (depth 21 ft), Massachusetts Current	NOS	COD0911_1	41.51929	-70.68289	:America/New_York	USA	knots	274	96	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.579	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woods Hole, The Strait	MA
98261	Woods Hole, The Strait (depth 14 ft), Massachusetts Current	NOS	COD0911_5	41.51929	-70.68289	:America/New_York	USA	knots	267	79	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woods Hole, The Strait	MA
98262	Woods Hole, The Strait (depth 5 ft), Massachusetts Current	NOS	COD0911_11	41.51929	-70.68289	:America/New_York	USA	knots	261	77	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woods Hole, The Strait	MA
98263	Juniper Point (depth 29 ft), Woods Hole, Massachusetts Current	NOS	COD0912_1	41.51588	-70.67167	:America/New_York	USA	knots	333	169	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juniper Point	MA
98264	Juniper Point (depth 15 ft), Woods Hole, Massachusetts Current	NOS	COD0912_5	41.51588	-70.67167	:America/New_York	USA	knots	333	166	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juniper Point	MA
98265	Juniper Point (depth 5 ft), Woods Hole, Massachusetts Current	NOS	COD0912_8	41.51588	-70.67167	:America/New_York	USA	knots	331	165	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juniper Point	MA
98266	Robinsons Hole, Nashuon Point (depth 24 ft), Massachusetts Current	NOS	COD0913_1	41.44972	-70.8067	:America/New_York	USA	knots	329	157	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robinsons Hole, Nashuon Point	MA
98267	Robinsons Hole, Nashuon Point (depth 14 ft), Massachusetts Current	NOS	COD0913_7	41.44972	-70.8067	:America/New_York	USA	knots	330	153	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robinsons Hole, Nashuon Point	MA
98268	Robinsons Hole, Nashuon Point (depth 4 ft), Massachusetts Current	NOS	COD0913_13	41.44972	-70.8067	:America/New_York	USA	knots	332	151	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robinsons Hole, Nashuon Point	MA
98269	Middle (depth 40 ft), Quicks Hole, Massachusetts Current	NOS	COD0914_1	41.44269	-70.84825	:America/New_York	USA	knots	336	153	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle	MA
98270	Middle (depth 17 ft), Quicks Hole, Massachusetts Current	NOS	COD0914_8	41.44269	-70.84825	:America/New_York	USA	knots	329	156	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle	MA
98271	Middle (depth 7 ft), Quicks Hole, Massachusetts Current	NOS	COD0914_11	41.44269	-70.84825	:America/New_York	USA	knots	327	157	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle	MA
98272	Canapitsit Channel (depth 4 ft), Massachusetts Current	NOS	COD0915_1	41.42414	-70.90788	:America/New_York	USA	knots	312	131	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.225	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Canapitsit Channel	MA
98273	Point Woronzof, 1.2 nmi NE of (depth 85 ft), Cook Inlet, Alaska Current	NOS	COI0206_3	61.21685	-149.98435	:America/Anchorage	USA	knots	271	106	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 87.6 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Woronzof, 1.2nm NE of	AK
98274	Point Woronzof, 1.2 nmi NE of (depth 58 ft), Cook Inlet, Alaska Current	NOS	COI0206_7	61.21685	-149.98435	:America/Anchorage	USA	knots	268	94	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 61.4 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.188	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Woronzof, 1.2nm NE of	AK
98275	Point Woronzof, 1.2 nmi NE of (depth 26 ft), Cook Inlet, Alaska Current	NOS	COI0206_12	61.21685	-149.98435	:America/Anchorage	USA	knots	262	84	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 28.5 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.413	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Woronzof, 1.2nm NE of	AK
98276	Fire Island, 1.0 nmi east of (depth 28 ft), Cook Inlet, Alaska Current	NOS	COI0207_2	61.17923	-150.12553	:America/Anchorage	USA	knots	271	95	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.0nm east of	AK
98277	Fire Island, 1.0 nmi east of (depth 14 ft), Cook Inlet, Alaska Current	NOS	COI0207_6	61.17923	-150.12553	:America/Anchorage	USA	knots	266	95	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.0nm east of	AK
98278	Fire Island, 1.0 nmi east of (depth 2 ft), Cook Inlet, Alaska Current	NOS	COI0207_10	61.17923	-150.12553	:America/Anchorage	USA	knots	258	95	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.0nm east of	AK
98279	Fire Island, 1.0 nmi north of (depth 41 ft), Cook Inlet, Alaska Current	NOS	COI0213_2	61.19218	-150.17585	:America/Anchorage	USA	knots	265	76	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 44.8 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.0nm north of	AK
98280	Fire Island, 1.0 nmi north of (depth 25 ft), Cook Inlet, Alaska Current	NOS	COI0213_6	61.19218	-150.17585	:America/Anchorage	USA	knots	265	76	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 31.7 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.0nm north of	AK
98281	Fire Island, 1.0 nmi north of (depth 15 ft), Cook Inlet, Alaska Current	NOS	COI0213_10	61.19218	-150.17585	:America/Anchorage	USA	knots	264	77	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 18.6 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.0nm north of	AK
98282	Knik Arm, NW of Anchorage (depth 23 ft), Cook Inlet, Alaska Current	NOS	COI0301_5	61.27822	-149.89452	:America/Anchorage	USA	knots	187	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.464	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Knik Arm, NW of Anchorage	AK
98283	Knik Arm, NW of Anchorage (depth 16 ft), Cook Inlet, Alaska Current	NOS	COI0301_7	61.27822	-149.89452	:America/Anchorage	USA	knots	189	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.473	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Knik Arm, NW of Anchorage	AK
98284	Knik Arm, NW of Anchorage (depth 10 ft), Cook Inlet, Alaska Current	NOS	COI0301_9	61.27822	-149.89452	:America/Anchorage	USA	knots	192	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.471	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Knik Arm, NW of Anchorage	AK
98285	Knik Arm, east side (depth 30 ft), Cook Inlet, Alaska Current	NOS	COI0302_4	61.27463	-149.88222	:America/Anchorage	USA	knots	206	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.513	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Knik Arm, east side	AK
98286	Knik Arm, east side (depth 17 ft), Cook Inlet, Alaska Current	NOS	COI0302_8	61.27463	-149.88222	:America/Anchorage	USA	knots	209	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.484	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Knik Arm, east side	AK
98287	Knik Arm, east side (depth 10 ft), Cook Inlet, Alaska Current	NOS	COI0302_10	61.27463	-149.88222	:America/Anchorage	USA	knots	210	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.448	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Knik Arm, east side	AK
98288	Port Mackenzie, south of (depth 71 ft), Cook Inlet, Alaska Current	NOS	COI0303_1	61.25225	-149.92067	:America/Anchorage	USA	knots	213	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.501	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Mackenzie, south of	AK
98289	Port Mackenzie, south of (depth 41 ft), Cook Inlet, Alaska Current	NOS	COI0303_10	61.25225	-149.92067	:America/Anchorage	USA	knots	214	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.696	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Mackenzie, south of	AK
98290	Port Mackenzie, south of (depth 22 ft), Cook Inlet, Alaska Current	NOS	COI0303_16	61.25225	-149.92067	:America/Anchorage	USA	knots	214	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.829	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Mackenzie, south of	AK
98291	Port Mackenzie, south of (depth 15 ft), Cook Inlet, Alaska Current	NOS	COI0303_18	61.25225	-149.92067	:America/Anchorage	USA	knots	214	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.868	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Mackenzie, south of	AK
98292	Fire Island Shoal, northwest of (depth 22 ft), Cook Inlet, Alaska Current	NOS	COI0306_6	61.16085	-150.56492	:America/Anchorage	USA	knots	272	91	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.234	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island Shoal, northwest of	AK
98694	Sitkinak Strait, southwest entrance (depth 48 ft), Alaska Current	NOS	KOD0917_6	56.65504	-154.13396	:America/Anchorage	USA	knots	113	297	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.261	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitkinak Strait, southwest entrance	AK
98293	Fire Island Shoal, northwest of (depth 16 ft), Cook Inlet, Alaska Current	NOS	COI0306_8	61.16085	-150.56492	:America/Anchorage	USA	knots	272	91	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.324	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island Shoal, northwest of	AK
98294	Fire Island Shoal, northwest of (depth 9 ft), Cook Inlet, Alaska Current	NOS	COI0306_10	61.16085	-150.56492	:America/Anchorage	USA	knots	271	92	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.395	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island Shoal, northwest of	AK
98295	Beluga Shoal, south of (depth 31 ft), Cook Inlet, Alaska Current	NOS	COI0307_5	61.10137	-150.56155	:America/Anchorage	USA	knots	256	86	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beluga Shoal, south of	AK
98296	Beluga Shoal, south of (depth 21 ft), Cook Inlet, Alaska Current	NOS	COI0307_8	61.10137	-150.56155	:America/Anchorage	USA	knots	257	86	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.245	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beluga Shoal, south of	AK
98297	Beluga Shoal, south of (depth 15 ft), Cook Inlet, Alaska Current	NOS	COI0307_10	61.10137	-150.56155	:America/Anchorage	USA	knots	258	86	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.287	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beluga Shoal, south of	AK
98298	Kennedy entrance (depth 100 ft), Cook Inlet, Alaska Current	NOS	COI0418_15	59.0658	-151.98232	:America/Anchorage	USA	knots	119	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kennedy Entrance	AK
98299	Kennedy entrance (depth 47 ft), Cook Inlet, Alaska Current	NOS	COI0418_19	59.0658	-151.98232	:America/Anchorage	USA	knots	114	307	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kennedy Entrance	AK
98300	Kennedy entrance (depth 21 ft), Cook Inlet, Alaska Current	NOS	COI0418_21	59.0658	-151.98232	:America/Anchorage	USA	knots	110	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kennedy Entrance	AK
98301	Anchor Point, 15 nmi west of (depth 75 ft), Cook Inlet, Alaska Current	NOS	COI0419_9	59.83933	-152.36833	:America/Anchorage	USA	knots	203	28	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, 15nm west of	AK
98302	Anchor Point, 15 nmi west of (depth 49 ft), Cook Inlet, Alaska Current	NOS	COI0419_13	59.83933	-152.36833	:America/Anchorage	USA	knots	200	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.495	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, 15nm west of	AK
98303	Anchor Point, 15 nmi west of (depth 23 ft), Cook Inlet, Alaska Current	NOS	COI0419_17	59.83933	-152.36833	:America/Anchorage	USA	knots	198	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.537	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, 15nm west of	AK
98304	Anchor Point, 8 nmi west of (depth 59 ft), Cook Inlet, Alaska Current	NOS	COI0420_7	59.8187	-152.15553	:America/Anchorage	USA	knots	197	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, 8nm west of	AK
98305	Anchor Point, 8 nmi west of (depth 39 ft), Cook Inlet, Alaska Current	NOS	COI0420_10	59.8187	-152.15553	:America/Anchorage	USA	knots	198	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, 8nm west of	AK
98306	Anchor Point, 8 nmi west of (depth 13 ft), Cook Inlet, Alaska Current	NOS	COI0420_14	59.8187	-152.15553	:America/Anchorage	USA	knots	200	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.109	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, 8nm west of	AK
98307	Barabara Point (depth 147 ft), Cook Inlet, Alaska Current	NOS	COI0421_1	59.57542	-151.6519	:America/Anchorage	USA	knots	258	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barabara Point	AK
98308	Barabara Point (depth 82 ft), Cook Inlet, Alaska Current	NOS	COI0421_11	59.57542	-151.6519	:America/Anchorage	USA	knots	\N	66.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barabara Point	AK
98327	Kenai River, north of (depth 12 ft), Cook Inlet, Alaska Current	NOS	COI0506_6	60.58083	-151.44453	:America/Anchorage	USA	knots	183	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kenai River, north of	AK
98695	Sitkinak Strait, southwest entrance (depth 15 ft), Alaska Current	NOS	KOD0917_11	56.65504	-154.13396	:America/Anchorage	USA	knots	114	296	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.266	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sitkinak Strait, southwest entrance	AK
98309	Barabara Point (depth 23 ft), Cook Inlet, Alaska Current	NOS	COI0421_20	59.57542	-151.6519	:America/Anchorage	USA	knots	\N	44.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barabara Point	AK
98310	Glacier Spit (depth 146 ft), Cook Inlet, Alaska Current	NOS	COI0422_1	59.66667	-151.19163	:America/Anchorage	USA	knots	233	46	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Spit	AK
98311	Glacier Spit (depth 87 ft), Cook Inlet, Alaska Current	NOS	COI0422_10	59.66667	-151.19163	:America/Anchorage	USA	knots	230	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Spit	AK
98312	Glacier Spit (depth 14 ft), Cook Inlet, Alaska Current	NOS	COI0422_21	59.66667	-151.19163	:America/Anchorage	USA	knots	234	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Spit	AK
98313	The Forelands (depth 66 ft), Cook Inlet, Alaska Current	NOS	COI0502_1	60.72067	-151.55733	:America/Anchorage	USA	knots	198	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Forelands	AK
98314	The Forelands (depth 37 ft), Cook Inlet, Alaska Current	NOS	COI0502_4	60.72067	-151.55733	:America/Anchorage	USA	knots	200	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Forelands	AK
98315	The Forelands (depth 17 ft), Cook Inlet, Alaska Current	NOS	COI0502_6	60.72067	-151.55733	:America/Anchorage	USA	knots	201	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Forelands	AK
98316	East Foreland (depth 119 ft), Cook Inlet, Alaska Current	NOS	COI0503_1	60.71727	-151.43297	:America/Anchorage	USA	knots	179	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Foreland	AK
98317	East Foreland (depth 80 ft), Cook Inlet, Alaska Current	NOS	COI0503_5	60.71727	-151.43297	:America/Anchorage	USA	knots	184	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Foreland	AK
98318	East Foreland (depth 21 ft), Cook Inlet, Alaska Current	NOS	COI0503_11	60.71727	-151.43297	:America/Anchorage	USA	knots	191	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Foreland	AK
98319	Nikiski, 0.8 mi west of (depth 92 ft), Cook Inlet, Alaska Current	NOS	COI0504_1	60.68338	-151.41787	:America/Anchorage	USA	knots	167	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.264	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikiski, 0.8 mile west of	AK
98320	Nikiski, 0.8 mi west of (depth 52 ft), Cook Inlet, Alaska Current	NOS	COI0504_7	60.68338	-151.41787	:America/Anchorage	USA	knots	170	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.189	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikiski, 0.8 mile west of	AK
98321	Nikiski, 0.8 mi west of (depth 20 ft), Cook Inlet, Alaska Current	NOS	COI0504_12	60.68338	-151.41787	:America/Anchorage	USA	knots	173	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nikiski, 0.8 mile west of	AK
98322	West Foreland, south of (depth 38 ft), Cook Inlet, Alaska Current	NOS	COI0505_1	60.59667	-151.73981	:America/Anchorage	USA	knots	232	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Foreland, south of	AK
98323	West Foreland, south of (depth 18 ft), Cook Inlet, Alaska Current	NOS	COI0505_4	60.59667	-151.73981	:America/Anchorage	USA	knots	231	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.292	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Foreland, south of	AK
98324	West Foreland, south of (depth 11 ft), Cook Inlet, Alaska Current	NOS	COI0505_5	60.59667	-151.73981	:America/Anchorage	USA	knots	230	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.335	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Foreland, south of	AK
98325	Kenai River, north of (depth 45 ft), Cook Inlet, Alaska Current	NOS	COI0506_1	60.58083	-151.44453	:America/Anchorage	USA	knots	181	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.195	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kenai River, north of	AK
98326	Kenai River, north of (depth 26 ft), Cook Inlet, Alaska Current	NOS	COI0506_4	60.58083	-151.44453	:America/Anchorage	USA	knots	182	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kenai River, north of	AK
98328	Drift River Terminal (depth 42 ft), Cook Inlet, Alaska Current	NOS	COI0507_3	60.5517	-152.12773	:America/Anchorage	USA	knots	228	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.175	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drift River Terminal	AK
98329	Drift River Terminal (depth 29 ft), Cook Inlet, Alaska Current	NOS	COI0507_5	60.5517	-152.12773	:America/Anchorage	USA	knots	229	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drift River Terminal	AK
98330	Drift River Terminal (depth 15 ft), Cook Inlet, Alaska Current	NOS	COI0507_7	60.5517	-152.12773	:America/Anchorage	USA	knots	230	47	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drift River Terminal	AK
98331	Kalgin Island, east of (depth 117 ft), Cook Inlet, Alaska Current	NOS	COI0508_1	60.48295	-151.67325	:America/Anchorage	USA	knots	189	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, east of	AK
98332	Kalgin Island, east of (depth 58 ft), Cook Inlet, Alaska Current	NOS	COI0508_7	60.48295	-151.67325	:America/Anchorage	USA	knots	192	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.487	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, east of	AK
98333	Kalgin Island, east of (depth 28 ft), Cook Inlet, Alaska Current	NOS	COI0508_10	60.48295	-151.67325	:America/Anchorage	USA	knots	194	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.752	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, east of	AK
98334	Harriot Point, west of (depth 259 ft), Cook Inlet, Alaska Current	NOS	COI0509_1	60.37918	-152.1817	:America/Anchorage	USA	knots	184	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harriot Point, west of	AK
98335	Harriot Point, west of (depth 161 ft), Cook Inlet, Alaska Current	NOS	COI0509_11	60.37918	-152.1817	:America/Anchorage	USA	knots	188	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harriot Point, west of	AK
98336	Harriot Point, west of (depth 43 ft), Cook Inlet, Alaska Current	NOS	COI0509_23	60.37918	-152.1817	:America/Anchorage	USA	knots	193	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harriot Point, west of	AK
98337	Kalgin Island, southeast of (depth 58 ft), Cook Inlet, Alaska Current	NOS	COI0510_1	60.24802	-151.75453	:America/Anchorage	USA	knots	203	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, southeast of	AK
98338	Kalgin Island, southeast of (depth 32 ft), Cook Inlet, Alaska Current	NOS	COI0510_5	60.24802	-151.75453	:America/Anchorage	USA	knots	203	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, southeast of	AK
98339	Kalgin Island, southeast of (depth 18 ft), Cook Inlet, Alaska Current	NOS	COI0510_7	60.24802	-151.75453	:America/Anchorage	USA	knots	204	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.238	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, southeast of	AK
98340	Cape Ninilchik, west of (depth 184 ft), Cook Inlet, Alaska Current	NOS	COI0511_1	60.02327	-152.12018	:America/Anchorage	USA	knots	205	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Ninilchik, west of	AK
98341	Cape Ninilchik, west of (depth 89 ft), Cook Inlet, Alaska Current	NOS	COI0511_11	60.02327	-152.12018	:America/Anchorage	USA	knots	209	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 85.3 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Ninilchik, west of	AK
98342	Cape Ninilchik, west of (depth 36 ft), Cook Inlet, Alaska Current	NOS	COI0511_16	60.02327	-152.12018	:America/Anchorage	USA	knots	216	32	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.45	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Ninilchik, west of	AK
98343	Seldovia (depth 56 ft), Cook Inlet, Alaska Current	NOS	COI0513_1	59.4828	-151.75505	:America/Anchorage	USA	knots	235	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seldovia	AK
98344	Seldovia (depth 36 ft), Cook Inlet, Alaska Current	NOS	COI0513_3	59.4828	-151.75505	:America/Anchorage	USA	knots	235	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seldovia	AK
98345	Seldovia (depth 16 ft), Cook Inlet, Alaska Current	NOS	COI0513_5	59.4828	-151.75505	:America/Anchorage	USA	knots	236	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Seldovia	AK
98346	Augustine Island (depth 208 ft), Cook Inlet, Alaska Current	NOS	COI0514_1	59.3018	-152.93028	:America/Anchorage	USA	knots	186	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Augustine Island	AK
98347	Augustine Island (depth 119 ft), Cook Inlet, Alaska Current	NOS	COI0514_10	59.3018	-152.93028	:America/Anchorage	USA	knots	182	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Augustine Island	AK
98348	Augustine Island (depth 21 ft), Cook Inlet, Alaska Current	NOS	COI0514_20	59.3018	-152.93028	:America/Anchorage	USA	knots	177	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Augustine Island	AK
98349	Kachemak Bay, southwest of (depth 244 ft), Cook Inlet, Alaska Current	NOS	COI0515_1	59.31487	-152.36497	:America/Anchorage	USA	knots	178	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kachemak Bay, southwest of	AK
98350	Kachemak Bay, southwest of (depth 136 ft), Cook Inlet, Alaska Current	NOS	COI0515_12	59.31487	-152.36497	:America/Anchorage	USA	knots	179	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kachemak Bay, southwest of	AK
98351	Kachemak Bay, southwest of (depth 57 ft), Cook Inlet, Alaska Current	NOS	COI0515_20	59.31487	-152.36497	:America/Anchorage	USA	knots	171	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kachemak Bay, southwest of	AK
98352	Kachemak Bay, southwest of (depth 27 ft), Cook Inlet, Alaska Current	NOS	COI0515_23	59.31487	-152.36497	:America/Anchorage	USA	knots	167	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kachemak Bay, southwest of	AK
98353	Port Graham (depth 114 ft), Cook Inlet, Alaska Current	NOS	COI0516_1	59.40002	-151.9659	:America/Anchorage	USA	knots	202	32	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Graham	AK
98354	Port Graham (depth 75 ft), Cook Inlet, Alaska Current	NOS	COI0516_5	59.40002	-151.9659	:America/Anchorage	USA	knots	204	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Graham	AK
98355	Port Graham (depth 25 ft), Cook Inlet, Alaska Current	NOS	COI0516_10	59.40002	-151.9659	:America/Anchorage	USA	knots	203	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Graham	AK
98356	Cape Douglas (depth 455 ft), Cook Inlet, Alaska Current	NOS	COI0517_1	58.89005	-153.1842	:America/Anchorage	USA	knots	165	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Douglas	AK
98357	Cape Douglas (depth 337 ft), Cook Inlet, Alaska Current	NOS	COI0517_7	58.89005	-153.1842	:America/Anchorage	USA	knots	168	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.105	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Douglas	AK
98358	Cape Douglas (depth 199 ft), Cook Inlet, Alaska Current	NOS	COI0517_14	58.89005	-153.1842	:America/Anchorage	USA	knots	164	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Douglas	AK
98359	Stevenson Passage (depth 388 ft), Cook Inlet, Alaska Current	NOS	COI0519_3	58.808	-152.40778	:America/Anchorage	USA	knots	95	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.299	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stevenson Passage	AK
98360	Stevenson Passage (depth 240 ft), Cook Inlet, Alaska Current	NOS	COI0519_12	58.808	-152.40778	:America/Anchorage	USA	knots	103	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.307	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stevenson Passage	AK
98361	Stevenson Passage (depth 60 ft), Cook Inlet, Alaska Current	NOS	COI0519_23	58.808	-152.40778	:America/Anchorage	USA	knots	121	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.273	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stevenson Passage	AK
98362	West Amatuli Island, north (depth 238 ft), Cook Inlet, Alaska Current	NOS	COI0520_20	59.049198150634766	-152.15185546875	:America/Anchorage	USA	knots	111	299	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Amatuli Island, North	AK
98363	West Amatuli Island, north (depth 120 ft), Cook Inlet, Alaska Current	NOS	COI0520_29	59.049198150634766	-152.15185546875	:America/Anchorage	USA	knots	119	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.299	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Amatuli Island, North	AK
98364	Cape Elizabeth (depth 229 ft), Cook Inlet, Alaska Current	NOS	COI0521_1	59.12072	-151.89483	:America/Anchorage	USA	knots	128	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Elizabeth	AK
98365	Cape Elizabeth (depth 137 ft), Cook Inlet, Alaska Current	NOS	COI0521_8	59.12072	-151.89483	:America/Anchorage	USA	knots	130	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Elizabeth	AK
98366	Cape Elizabeth (depth 32 ft), Cook Inlet, Alaska Current	NOS	COI0521_16	59.12072	-151.89483	:America/Anchorage	USA	knots	125	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Elizabeth	AK
98367	Port Chatham (depth 70 ft), Cook Inlet, Alaska Current	NOS	COI0522_1	59.21125	-151.78703	:America/Anchorage	USA	knots	223	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Chatham	AK
98368	Port Chatham (depth 40 ft), Cook Inlet, Alaska Current	NOS	COI0522_4	59.21125	-151.78703	:America/Anchorage	USA	knots	224	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Chatham	AK
98369	Port Chatham (depth 21 ft), Cook Inlet, Alaska Current	NOS	COI0522_6	59.21125	-151.78703	:America/Anchorage	USA	knots	230	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Chatham	AK
98370	Chugach Passage (depth 221 ft), Cook Inlet, Alaska Current	NOS	COI0523_1	59.16658	-151.77543	:America/Anchorage	USA	knots	173	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.251	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chugach Passage	AK
98371	Chugach Passage (depth 129 ft), Cook Inlet, Alaska Current	NOS	COI0523_8	59.16658	-151.77543	:America/Anchorage	USA	knots	175	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.301	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chugach Passage	AK
98372	Chugach Passage (depth 37 ft), Cook Inlet, Alaska Current	NOS	COI0523_15	59.16658	-151.77543	:America/Anchorage	USA	knots	176	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.336	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chugach Passage	AK
98373	Chugach Passage, east of (depth 52 ft), Cook Inlet, Alaska Current	NOS	COI0524_1	59.13387	-151.7055	:America/Anchorage	USA	knots	75	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chugach Passage, east of	AK
98374	Chugach Passage, east of (depth 32 ft), Cook Inlet, Alaska Current	NOS	COI0524_3	59.13387	-151.7055	:America/Anchorage	USA	knots	77	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chugach Passage, east of	AK
98375	Chugach Passage, east of (depth 12 ft), Cook Inlet, Alaska Current	NOS	COI0524_5	59.13387	-151.7055	:America/Anchorage	USA	knots	76	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chugach Passage, east of	AK
98376	Tesoro Pier (depth 55 ft), Cook Inlet, Alaska Current	NOS	COI0801_1	60.6869	-151.4037	:America/Anchorage	USA	knots	154	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.691	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tesoro Pier	AK
98377	Tesoro Pier (depth 35 ft), Cook Inlet, Alaska Current	NOS	COI0801_4	60.6869	-151.4037	:America/Anchorage	USA	knots	151	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.657	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tesoro Pier	AK
98378	Tesoro Pier (depth 15 ft), Cook Inlet, Alaska Current	NOS	COI0801_7	60.6869	-151.4037	:America/Anchorage	USA	knots	149	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.576	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tesoro Pier	AK
98379	Unocal Pier, south of (depth 51 ft), Cook Inlet, Alaska Current	NOS	COI0802_1	60.66782	-151.39162	:America/Anchorage	USA	knots	152	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.331	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unocal Pier, south of	AK
98380	Unocal Pier, south of (depth 32 ft), Cook Inlet, Alaska Current	NOS	COI0802_4	60.66782	-151.39162	:America/Anchorage	USA	knots	154	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.244	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unocal Pier, south of	AK
98381	Unocal Pier, south of (depth 12 ft), Cook Inlet, Alaska Current	NOS	COI0802_7	60.66782	-151.39162	:America/Anchorage	USA	knots	155	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unocal Pier, south of	AK
98382	Homer Spit (depth 198 ft), Cook Inlet, Alaska Current	NOS	COI1201_1	59.5925	-151.40017	:America/Anchorage	USA	knots	222	46	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Homer Spit	AK
98383	Homer Spit (depth 87 ft), Cook Inlet, Alaska Current	NOS	COI1201_18	59.5925	-151.40017	:America/Anchorage	USA	knots	236	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Homer Spit	AK
98384	Homer Spit (depth 21 ft), Cook Inlet, Alaska Current	NOS	COI1201_28	59.5925	-151.40017	:America/Anchorage	USA	knots	203	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Homer Spit	AK
98385	Point Pogishi, southwest of (depth 101 ft), Cook Inlet, Alaska Current	NOS	COI1202_1	59.42247	-151.91688	:America/Anchorage	USA	knots	210	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.163	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Pogishi, southwest of	AK
98386	Point Pogishi, southwest of (depth 61 ft), Cook Inlet, Alaska Current	NOS	COI1202_7	59.42247	-151.91688	:America/Anchorage	USA	knots	215	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.178	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Pogishi, southwest of	AK
98387	Point Pogishi, southwest of (depth 15 ft), Cook Inlet, Alaska Current	NOS	COI1202_14	59.42247	-151.91688	:America/Anchorage	USA	knots	218	32	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Pogishi, southwest of	AK
98388	Anchor Point, west of (depth 104 ft), Cook Inlet, Alaska Current	NOS	COI1203_1	59.74383	-152.03417	:America/Anchorage	USA	knots	170	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, west of	AK
98389	Anchor Point, west of (depth 58 ft), Cook Inlet, Alaska Current	NOS	COI1203_8	59.74383	-152.03417	:America/Anchorage	USA	knots	176	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, west of	AK
98390	Anchor Point, west of (depth 12 ft), Cook Inlet, Alaska Current	NOS	COI1203_15	59.74383	-152.03417	:America/Anchorage	USA	knots	182	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anchor Point, west of	AK
98391	North Forelands, 2.5 nmi northeast of (depth 66 ft), Cook Inlet, Alaska Current	NOS	COI1204_1	61.05982	-151.08065	:America/Anchorage	USA	knots	214	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Forelands, 2.5nm northeast of	AK
98392	North Forelands, 2.5 nmi northeast of (depth 39 ft), Cook Inlet, Alaska Current	NOS	COI1204_9	61.05982	-151.08065	:America/Anchorage	USA	knots	215	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.305	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Forelands, 2.5nm northeast of	AK
98393	North Forelands, 2.5 nmi northeast of (depth 10 ft), Cook Inlet, Alaska Current	NOS	COI1204_18	61.05982	-151.08065	:America/Anchorage	USA	knots	220	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.526	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Forelands, 2.5nm northeast of	AK
98394	Kalgin Island, 4 nmi east of (depth 169 ft), Cook Inlet, Alaska Current	NOS	COI1205_1	60.47183	-151.70633	:America/Anchorage	USA	knots	184	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, 4nm east of	AK
98395	Kalgin Island, 4 nmi east of (depth 97 ft), Cook Inlet, Alaska Current	NOS	COI1205_12	60.47183	-151.70633	:America/Anchorage	USA	knots	189	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.453	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, 4nm east of	AK
98396	Kalgin Island, 4 nmi east of (depth 18 ft), Cook Inlet, Alaska Current	NOS	COI1205_24	60.47183	-151.70633	:America/Anchorage	USA	knots	193	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.937	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalgin Island, 4nm east of	AK
98397	Point Possession, northeast of (depth 137 ft), Cook Inlet, Alaska Current	NOS	COI1207_1	61.0566	-150.36035	:America/Anchorage	USA	knots	291	107	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Possession, northeast of	AK
98398	Point Possession, northeast of (depth 78 ft), Cook Inlet, Alaska Current	NOS	COI1207_10	61.0566	-150.36035	:America/Anchorage	USA	knots	295	104	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Possession, northeast of	AK
98399	Point Possession, northeast of (depth 19 ft), Cook Inlet, Alaska Current	NOS	COI1207_19	61.0566	-150.36035	:America/Anchorage	USA	knots	296	101	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Possession, northeast of	AK
98400	Fire Island, 1.2 nmi south of (depth 80 ft), Cook Inlet, Alaska Current	NOS	COI1208_1	61.1036	-150.26492	:America/Anchorage	USA	knots	322	116	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.157	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.2nm south of	AK
98401	Fire Island, 1.2 nmi south of (depth 47 ft), Cook Inlet, Alaska Current	NOS	COI1208_11	61.1036	-150.26492	:America/Anchorage	USA	knots	317	113	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.2nm south of	AK
98402	Fire Island, 1.2 nmi south of (depth 11 ft), Cook Inlet, Alaska Current	NOS	COI1208_22	61.1036	-150.26492	:America/Anchorage	USA	knots	315	110	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 1.2nm south of	AK
98403	Fire Island, 0.8 nmi north of (depth 49 ft), Cook Inlet, Alaska Current	NOS	COI1209_2	61.18483	-150.2015	:America/Anchorage	USA	knots	268	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 0.8nm north of	AK
98404	Fire Island, 0.8 nmi north of (depth 16 ft), Cook Inlet, Alaska Current	NOS	COI1209_12	61.18483	-150.2015	:America/Anchorage	USA	knots	271	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 0.8nm north of	AK
98405	Fire Island, 0.8 nmi north of (depth 6 ft), Cook Inlet, Alaska Current	NOS	COI1209_15	61.18483	-150.2015	:America/Anchorage	USA	knots	271	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fire Island, 0.8nm north of	AK
98406	Middle Ground Shoal, east of (depth 102 ft), Cook Inlet, Alaska Current	NOS	COI1210_1	60.88697	-151.23268	:America/Anchorage	USA	knots	235	51	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Ground Shoal, east of	AK
98407	Middle Ground Shoal, east of (depth 43 ft), Cook Inlet, Alaska Current	NOS	COI1210_10	60.88697	-151.23268	:America/Anchorage	USA	knots	239	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Ground Shoal, east of	AK
98408	Middle Ground Shoal, east of (depth 17 ft), Cook Inlet, Alaska Current	NOS	COI1210_14	60.88697	-151.23268	:America/Anchorage	USA	knots	240	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.308	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Ground Shoal, east of	AK
98409	Delaware Bay entrance (depth 96 ft), Delaware Current	NOS	DEB0002_7	38.85362	-75.07703	:America/New_York	USA	knots	149	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.265	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware Bay Entrance	DE
98410	Delaware Bay entrance (depth 57 ft), Delaware Current	NOS	DEB0002_13	38.85362	-75.07703	:America/New_York	USA	knots	154	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.239	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware Bay Entrance	DE
98411	Delaware Bay entrance (depth 37 ft), Delaware Current	NOS	DEB0002_16	38.85362	-75.07703	:America/New_York	USA	knots	155	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.174	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware Bay Entrance	DE
98412	Delaware Bay entrance (depth 18 ft), Delaware Current	NOS	DEB0002_19	38.85362	-75.07703	:America/New_York	USA	knots	152	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware Bay Entrance	DE
98413	Delaware Bay entrance channel (depth 44 ft), Delaware Current	NOS	DEB2101_1	38.78129959106445	-75.04299926757812	:America/New_York	USA	knots	156	312	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.163	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware Bay Entrance Channel	DE
98414	Delaware Bay entrance channel (depth 15 ft), Delaware Current	NOS	DEB2101_10	38.78129959106445	-75.04299926757812	:America/New_York	USA	knots	158	316	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.582	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware Bay Entrance Channel	DE
98415	Delaware Bay entrance channel (depth 5 ft), Delaware Current	NOS	DEB2101_13	38.78129959106445	-75.04299926757812	:America/New_York	USA	knots	158	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.731	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware Bay Entrance Channel	DE
98416	Cape Henlopen, 2 mi NE of (depth 78 ft), Delaware Current	NOS	DEB2102_2	38.81990051269531	-75.05280303955078	:America/New_York	USA	knots	136	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Henlopen, 2 mi NE of	DE
98417	Cape Henlopen, 2 mi NE of (depth 28 ft), Delaware Current	NOS	DEB2102_17	38.81990051269531	-75.05280303955078	:America/New_York	USA	knots	142	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Henlopen, 2 mi NE of	DE
98418	Cape Henlopen, 2 mi NE of (depth 15 ft), Delaware Current	NOS	DEB2102_21	38.81990051269531	-75.05280303955078	:America/New_York	USA	knots	141	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Henlopen, 2 mi NE of	DE
98419	Cape Henlopen, 5 mi north of (depth 61 ft), Delaware Current	NOS	DEB2103_1	38.883399963378906	-75.08329772949219	:America/New_York	USA	knots	159	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.182	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Henlopen, 5 mi north of	DE
98420	Cape Henlopen, 5 mi north of (depth 15 ft), Delaware Current	NOS	DEB2103_15	38.883399963378906	-75.08329772949219	:America/New_York	USA	knots	166	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Henlopen, 5 mi north of	DE
98421	Cape Henlopen, 5 mi north of (depth 9 ft), Delaware Current	NOS	DEB2103_17	38.883399963378906	-75.08329772949219	:America/New_York	USA	knots	169	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Henlopen, 5 mi north of	DE
98422	Cape May Canal, west end (depth 16 ft), New Jersey Current	NOS	DEB2104_3	38.96839904785156	-74.97239685058594	:America/New_York	USA	knots	190	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May Canal, West End	NJ
98423	Cape May Canal, west end (depth 5 ft), New Jersey Current	NOS	DEB2104_10	38.96839904785156	-74.97239685058594	:America/New_York	USA	knots	194	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.237	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May Canal, West End	NJ
98424	Cape May Canal, west end (depth 2 ft), New Jersey Current	NOS	DEB2104_12	38.96839904785156	-74.97239685058594	:America/New_York	USA	knots	193	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.269	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape May Canal, West End	NJ
98425	Brandywine Shoal Light, 0.5 nmi west of (depth 41 ft), New Jersey Current	NOS	DEB2105_1	38.98820114135742	-75.12650299072266	:America/New_York	USA	knots	141	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Shoal Light, 0.5 nm west of	NJ
98426	Brandywine Shoal Light, 0.5 nmi west of (depth 15 ft), New Jersey Current	NOS	DEB2105_9	38.98820114135742	-75.12650299072266	:America/New_York	USA	knots	151	329	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.105	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Shoal Light, 0.5 nm west of	NJ
98427	Brandywine Shoal Light, 0.5 nmi west of (depth 5 ft), New Jersey Current	NOS	DEB2105_12	38.98820114135742	-75.12650299072266	:America/New_York	USA	knots	154	329	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Shoal Light, 0.5 nm west of	NJ
98431	Brandywine Range at Miah Maull Range (depth 36 ft), New Jersey Current	NOS	DEB2107_1	39.087501525878906	-75.19129943847656	:America/New_York	USA	knots	145	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Range at Miah Maull Range	NJ
98432	Brandywine Range at Miah Maull Range (depth 16 ft), New Jersey Current	NOS	DEB2107_7	39.087501525878906	-75.19129943847656	:America/New_York	USA	knots	159	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Range at Miah Maull Range	NJ
98433	Brandywine Range at Miah Maull Range (depth 6 ft), New Jersey Current	NOS	DEB2107_10	39.087501525878906	-75.19129943847656	:America/New_York	USA	knots	162	343	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.249	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brandywine Range at Miah Maull Range	NJ
98434	Cross Ledge Light (depth 39 ft), Delaware Current	NOS	DEB2108_1	39.17470169067383	-75.2699966430664	:America/New_York	USA	knots	169	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.159	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Ledge Light	DE
98435	Cross Ledge Light (depth 20 ft), Delaware Current	NOS	DEB2108_7	39.17470169067383	-75.2699966430664	:America/New_York	USA	knots	186	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Ledge Light	DE
98436	Cross Ledge Light (depth 6 ft), Delaware Current	NOS	DEB2108_11	39.17470169067383	-75.2699966430664	:America/New_York	USA	knots	185	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.343	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Ledge Light	DE
98429	Big Stone Beach Anchorage, Buoy G (depth 15 ft), Delaware Current	NOS	DEB2106_10	38.963199615478516	-75.17939758300781	:America/New_York	USA	knots	162	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Big Stone Beach Anchorage, buoy "G"	DE
98430	Big Stone Beach Anchorage, Buoy G (depth 8 ft), Delaware Current	NOS	DEB2106_12	38.963199615478516	-75.17939758300781	:America/New_York	USA	knots	165	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Big Stone Beach Anchorage, buoy "G"	DE
98437	Ben Davis Point, 3.2 nmi southwest of (depth 26 ft), Delaware Current	NOS	DEB2109_3	39.2681999206543	-75.34539794921875	:America/New_York	USA	knots	137	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ben Davis Point, 3.2 nm southwest of	DE
98438	Ben Davis Point, 3.2 nmi southwest of (depth 13 ft), Delaware Current	NOS	DEB2109_7	39.2681999206543	-75.34539794921875	:America/New_York	USA	knots	144	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ben Davis Point, 3.2 nm southwest of	DE
98439	Ben Davis Point, 3.2 nmi southwest of (depth 3 ft), Delaware Current	NOS	DEB2109_10	39.2681999206543	-75.34539794921875	:America/New_York	USA	knots	147	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ben Davis Point, 3.2 nm southwest of	DE
98440	Arnold Point, 1.8 nmi WSW of (depth 35 ft), New Jersey Current	NOS	DEB2110_1	39.376800537109375	-75.46620178222656	:America/New_York	USA	knots	135	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arnold Point, 1.8 nm WSW of	NJ
98441	Arnold Point, 1.8 nmi WSW of (depth 15 ft), New Jersey Current	NOS	DEB2110_7	39.376800537109375	-75.46620178222656	:America/New_York	USA	knots	148	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arnold Point, 1.8 nm WSW of	NJ
98442	Arnold Point, 1.8 nmi WSW of (depth 6 ft), New Jersey Current	NOS	DEB2110_10	39.376800537109375	-75.46620178222656	:America/New_York	USA	knots	146	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arnold Point, 1.8 nm WSW of	NJ
98445	Reedy Island Wreck (depth 48 ft), Delaware Current	NOS	DEB2112_1	39.537498474121094	-75.54180145263672	:America/New_York	USA	knots	200	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 43.7 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Island Wreck	DE
98446	Reedy Island Wreck (depth 18 ft), Delaware Current	NOS	DEB2112_9	39.537498474121094	-75.54180145263672	:America/New_York	USA	knots	197	12	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.312	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Island Wreck	DE
98447	Reedy Island Wreck (depth 4 ft), Delaware Current	NOS	DEB2112_13	39.537498474121094	-75.54180145263672	:America/New_York	USA	knots	197	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.335	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Island Wreck	DE
98452	Salem River entrance, east of marker 11 (depth 20 ft), New Jersey Current	NOS	DEB2114_1	39.57080078125	-75.502197265625	:America/New_York	USA	knots	242	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Salem River Entrance, east of marker 11	NJ
98453	Salem River entrance, east of marker 11 (depth 15 ft), New Jersey Current	NOS	DEB2114_4	39.57080078125	-75.502197265625	:America/New_York	USA	knots	243	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Salem River Entrance, east of marker 11	NJ
98454	Salem River entrance, east of marker 11 (depth 1 ft), New Jersey Current	NOS	DEB2114_12	39.57080078125	-75.502197265625	:America/New_York	USA	knots	242	71	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Salem River Entrance, east of marker 11	NJ
98444	Baker Range Channel (depth 38 ft), New Jersey Current	NOS	DEB2111_9	39.469398498535156	-75.55999755859375	:America/New_York	USA	knots	175	322	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baker Range Channel	NJ
98448	Chesapeake and Delaware Canal entrance (depth 12 ft), Delaware Current	NOS	DEB2113_2	39.56439971923828	-75.55490112304688	:America/New_York	USA	knots	134	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake and Deleware Canal Entrance	DE
98449	Chesapeake and Delaware Canal entrance (depth 15 ft), Delaware Current	NOS	DEB2113_4	39.56439971923828	-75.55490112304688	:America/New_York	USA	knots	134	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake and Deleware Canal Entrance	DE
98450	Chesapeake and Delaware Canal entrance (depth 20 ft), Delaware Current	NOS	DEB2113_7	39.56439971923828	-75.55490112304688	:America/New_York	USA	knots	134	356	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake and Deleware Canal Entrance	DE
98451	Chesapeake and Delaware Canal entrance (depth 30 ft), Delaware Current	NOS	DEB2113_13	39.56439971923828	-75.55490112304688	:America/New_York	USA	knots	136	359	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake and Deleware Canal Entrance	DE
98455	Pea Patch Island (depth 37 ft), Delaware Current	NOS	DEB2115_1	39.592201232910156	-75.56069946289062	:America/New_York	USA	knots	160	330	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pea Patch Island	DE
98456	Pea Patch Island (depth 14 ft), Delaware Current	NOS	DEB2115_8	39.592201232910156	-75.56069946289062	:America/New_York	USA	knots	155	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.174	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pea Patch Island	DE
98457	Pea Patch Island (depth 4 ft), Delaware Current	NOS	DEB2115_11	39.592201232910156	-75.56069946289062	:America/New_York	USA	knots	155	338	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.201	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pea Patch Island	DE
98458	Kelly Point, 0.7 nmi N of (depth 7 ft), Delaware Current	NOS	DEB2116_1	39.65679931640625	-75.54100036621094	:America/New_York	USA	knots	206	29	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.294	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kelly Point, 0.7nm N of	DE
98459	Kelly Point, 0.7 nmi N of (depth 15 ft), Delaware Current	NOS	DEB2116_3	39.65679931640625	-75.54100036621094	:America/New_York	USA	knots	202	25	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kelly Point, 0.7nm N of	DE
98460	Kelly Point, 0.7 nmi N of (depth 41 ft), Delaware Current	NOS	DEB2116_11	39.65679931640625	-75.54100036621094	:America/New_York	USA	knots	203	18	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kelly Point, 0.7nm N of	DE
98461	Deepwater Point, 0.5 nmi NW of (depth 47 ft), Delaware Current	NOS	DEB2117_1	39.70130157470703	-75.5105972290039	:America/New_York	USA	knots	203	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deepwater Point, 0.5 nm NW of	DE
98462	Deepwater Point, 0.5 nmi NW of (depth 14 ft), Delaware Current	NOS	DEB2117_11	39.70130157470703	-75.5105972290039	:America/New_York	USA	knots	208	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deepwater Point, 0.5 nm NW of	DE
98463	Deepwater Point, 0.5 nmi NW of (depth 8 ft), Delaware Current	NOS	DEB2117_13	39.70130157470703	-75.5105972290039	:America/New_York	USA	knots	208	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deepwater Point, 0.5 nm NW of	DE
98464	Edgemoor (depth 11 ft), Delaware Current	NOS	DEB2118_2	39.747501373291016	-75.49089813232422	:America/New_York	USA	knots	198	10	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgemoor	DE
98465	Edgemoor (depth 18 ft), Delaware Current	NOS	DEB2118_4	39.747501373291016	-75.49089813232422	:America/New_York	USA	knots	198	9	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgemoor	DE
98466	Edgemoor (depth 41 ft), Delaware Current	NOS	DEB2118_11	39.747501373291016	-75.49089813232422	:America/New_York	USA	knots	197	11	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgemoor	DE
98467	Marcus Hook Bar (north) (depth 23 ft), Delaware Current	NOS	DEB2119_1	39.79330062866211	-75.43379974365234	:America/New_York	USA	knots	247	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marcus Hook Bar (north)	DE
98468	Marcus Hook Bar (north) (depth 16 ft), Delaware Current	NOS	DEB2119_3	39.79330062866211	-75.43379974365234	:America/New_York	USA	knots	248	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.212	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marcus Hook Bar (north)	DE
98469	Marcus Hook Bar (north) (depth 6 ft), Delaware Current	NOS	DEB2119_6	39.79330062866211	-75.43379974365234	:America/New_York	USA	knots	248	65	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.245	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marcus Hook Bar (north)	DE
98470	Eddystone (depth 34 ft), Pennsylvania Current	NOS	DEB2121_1	39.850399017333984	-75.33480072021484	:America/New_York	USA	knots	249	71	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eddystone	PA
98471	Eddystone (depth 14 ft), Pennsylvania Current	NOS	DEB2121_13	39.850399017333984	-75.33480072021484	:America/New_York	USA	knots	252	70	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.146	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eddystone	PA
98472	Eddystone (depth 3 ft), Pennsylvania Current	NOS	DEB2121_20	39.850399017333984	-75.33480072021484	:America/New_York	USA	knots	253	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eddystone	PA
98473	Crab Point, 0.5 mi east of (depth 48 ft), New Jersey Current	NOS	DEB2122_1	39.8468017578125	-75.28299713134766	:America/New_York	USA	knots	276	95	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crab Point, 0.5 mi East of	NJ
98474	Crab Point, 0.5 mi east of (depth 15 ft), New Jersey Current	NOS	DEB2122_11	39.8468017578125	-75.28299713134766	:America/New_York	USA	knots	273	96	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crab Point, 0.5 mi East of	NJ
98475	Crab Point, 0.5 mi east of (depth 9 ft), New Jersey Current	NOS	DEB2122_13	39.8468017578125	-75.28299713134766	:America/New_York	USA	knots	272	96	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crab Point, 0.5 mi East of	NJ
98480	Girard Point (depth 6 ft), Pennsylvania Current	NOS	DEB2126_3	39.89250183105469	-75.19509887695312	:America/New_York	USA	knots	130	314	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Girard Point	PA
98481	Gloucester Point (depth 44 ft), New Jersey Current	NOS	DEB2128_1	39.897300720214844	-75.1322021484375	:America/New_York	USA	knots	205	20	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gloucester Point	NJ
98482	Gloucester Point (depth 15 ft), New Jersey Current	NOS	DEB2128_10	39.897300720214844	-75.1322021484375	:America/New_York	USA	knots	202	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gloucester Point	NJ
98483	Gloucester Point (depth 8 ft), New Jersey Current	NOS	DEB2128_12	39.897300720214844	-75.1322021484375	:America/New_York	USA	knots	201	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gloucester Point	NJ
98487	Fisher Point (depth 7 ft), Pennsylvania Current	NOS	DEB2130_1	39.97850036621094	-75.07599639892578	:America/New_York	USA	knots	233	87	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.452	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fisher Point	PA
98488	Fisher Point (depth 15 ft), Pennsylvania Current	NOS	DEB2130_3	39.97850036621094	-75.07599639892578	:America/New_York	USA	knots	234	86	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.355	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fisher Point	PA
98489	Fisher Point (depth 41 ft), Pennsylvania Current	NOS	DEB2130_11	39.97850036621094	-75.07599639892578	:America/New_York	USA	knots	238	81	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fisher Point	PA
98490	Frankford Range at Tacony Range (depth 7 ft), New Jersey Current	NOS	DEB2131_1	40.01530075073242	-75.03230285644531	:America/New_York	USA	knots	256	62	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Frankford Range at Tacony Range	NJ
98491	Frankford Range at Tacony Range (depth 15 ft), New Jersey Current	NOS	DEB2131_3	40.01530075073242	-75.03230285644531	:America/New_York	USA	knots	254	59	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.157	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Frankford Range at Tacony Range	NJ
98492	Frankford Range at Tacony Range (depth 35 ft), New Jersey Current	NOS	DEB2131_9	40.01530075073242	-75.03230285644531	:America/New_York	USA	knots	251	59	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Frankford Range at Tacony Range	NJ
98477	Mantua Creek Anchorage (depth 34 ft), Pennsylvania Current	NOS	DEB2124_1	39.856998443603516	-75.2417984008789	:America/New_York	USA	knots	243	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.192	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mantua Creek Anchorage	PA
98478	Mantua Creek Anchorage (depth 14 ft), Pennsylvania Current	NOS	DEB2124_7	39.856998443603516	-75.2417984008789	:America/New_York	USA	knots	242	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.283	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mantua Creek Anchorage	PA
98479	Mantua Creek Anchorage (depth 8 ft), Pennsylvania Current	NOS	DEB2124_9	39.856998443603516	-75.2417984008789	:America/New_York	USA	knots	242	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mantua Creek Anchorage	PA
98484	Kaighn Point (depth 37 ft), New Jersey Current	NOS	DEB2129_1	39.928199768066406	-75.13529968261719	:America/New_York	USA	knots	166	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kaighn Point	NJ
98485	Kaighn Point (depth 14 ft), New Jersey Current	NOS	DEB2129_8	39.928199768066406	-75.13529968261719	:America/New_York	USA	knots	170	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.112	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kaighn Point	NJ
98486	Kaighn Point (depth 8 ft), New Jersey Current	NOS	DEB2129_10	39.928199768066406	-75.13529968261719	:America/New_York	USA	knots	170	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kaighn Point	NJ
98502	Estes Head, Eastport (depth 78 ft), Maine Current	NOS	EPT0003_4	44.88793	-66.99565	:America/New_York	USA	knots	79	271	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Estes Head, Eastport	ME
98503	Estes Head, Eastport (depth 52 ft), Maine Current	NOS	EPT0003_8	44.88793	-66.99565	:America/New_York	USA	knots	85	266	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Estes Head, Eastport	ME
98504	Estes Head, Eastport (depth 32 ft), Maine Current	NOS	EPT0003_11	44.88793	-66.99565	:America/New_York	USA	knots	88	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Estes Head, Eastport	ME
98505	Estes Head, Eastport (depth 13 ft), Maine Current	NOS	EPT0003_14	44.88793	-66.99565	:America/New_York	USA	knots	90	260	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Estes Head, Eastport	ME
98506	Robbinston, St. Croix River (depth 58 ft), Maine Current	NOS	EPT0004_4	45.0763	-67.10097	:America/New_York	USA	knots	171	340	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 56.9 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robbinston, St. Croix River	ME
98507	Robbinston, St. Croix River (depth 32 ft), Maine Current	NOS	EPT0004_8	45.0763	-67.10097	:America/New_York	USA	knots	166	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 30.7 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robbinston, St. Croix River	ME
98508	Robbinston, St. Croix River (depth 12 ft), Maine Current	NOS	EPT0004_11	45.0763	-67.10097	:America/New_York	USA	knots	165	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robbinston, St. Croix River	ME
98509	St. Marys River entrance (depth 42 ft), Cumberland Sound, Florida Current	NOS	FEB1102_1	30.70792	-81.44463	:America/New_York	USA	knots	92	271	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Mary's River Entrance	FL
98510	St. Marys River entrance (depth 25 ft), Cumberland Sound, Florida Current	NOS	FEB1102_6	30.70792	-81.44463	:America/New_York	USA	knots	93	272	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Mary's River Entrance	FL
98494	Edgewater Range at Devlin Range (depth 16 ft), Pennsylvania Current	NOS	DEB2132_6	40.077598571777344	-74.8865966796875	:America/New_York	USA	knots	252	71	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.321	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgewater Range at Devlin Range	PA
98495	Edgewater Range at Devlin Range (depth 6 ft), Pennsylvania Current	NOS	DEB2132_9	40.077598571777344	-74.8865966796875	:America/New_York	USA	knots	253	72	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.318	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgewater Range at Devlin Range	PA
98496	Florence Bend (depth 11 ft), New Jersey Current	NOS	DEB2133_1	40.12730026245117	-74.81580352783203	:America/New_York	USA	knots	304	105	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.486	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Florence Bend	NJ
98497	Florence Bend (depth 14 ft), New Jersey Current	NOS	DEB2133_2	40.12730026245117	-74.81580352783203	:America/New_York	USA	knots	304	106	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.478	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Florence Bend	NJ
98498	Florence Bend (depth 37 ft), New Jersey Current	NOS	DEB2133_9	40.12730026245117	-74.81580352783203	:America/New_York	USA	knots	299	113	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.294	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Florence Bend	NJ
98499	Newbold Island, north of, main channel (depth 7 ft), New Jersey Current	NOS	DEB2134_1	40.13370132446289	-74.75890350341797	:America/New_York	USA	knots	258	55	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.263	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newbold Island north of, Main Channel	NJ
98500	Newbold Island, north of, main channel (depth 15 ft), New Jersey Current	NOS	DEB2134_3	40.13370132446289	-74.75890350341797	:America/New_York	USA	knots	257	56	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.251	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newbold Island north of, Main Channel	NJ
98501	Newbold Island, north of, main channel (depth 31 ft), New Jersey Current	NOS	DEB2134_8	40.13370132446289	-74.75890350341797	:America/New_York	USA	knots	258	60	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newbold Island north of, Main Channel	NJ
98511	St. Marys River entrance (depth 8 ft), Cumberland Sound, Florida Current	NOS	FEB1102_11	30.70792	-81.44463	:America/New_York	USA	knots	93	272	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Mary's River Entrance	FL
98512	Quarantine Reach, 0.4 nmi W of Fort Clinch (depth 46 ft), Florida Current	NOS	FEB1103_1	30.7047	-81.462	:America/New_York	USA	knots	65	226	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quarantine Reach, 0.4nm W of Fort Clinch	FL
98513	Quarantine Reach, 0.4 nmi W of Fort Clinch (depth 27 ft), Florida Current	NOS	FEB1103_7	30.7047	-81.462	:America/New_York	USA	knots	47	232	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quarantine Reach, 0.4nm W of Fort Clinch	FL
98514	Quarantine Reach, 0.4 nmi W of Fort Clinch (depth 7 ft), Florida Current	NOS	FEB1103_13	30.7047	-81.462	:America/New_York	USA	knots	34	235	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quarantine Reach, 0.4nm W of Fort Clinch	FL
98515	Old Fernandina, Amelia River, Old Town Reach (depth 24 ft), Florida Current	NOS	FEB1104_1	30.68604	-81.46074	:America/New_York	USA	knots	10	193	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Fernandina, Amelia River, Old Town Reach	FL
98516	Old Fernandina, Amelia River, Old Town Reach (depth 14 ft), Florida Current	NOS	FEB1104_4	30.68604	-81.46074	:America/New_York	USA	knots	15	189	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Fernandina, Amelia River, Old Town Reach	FL
98517	Old Fernandina, Amelia River, Old Town Reach (depth 4 ft), Florida Current	NOS	FEB1104_7	30.68604	-81.46074	:America/New_York	USA	knots	18	188	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Fernandina, Amelia River, Old Town Reach	FL
98518	Fernandina Beach, City Front Reach, Amelia River (depth 29 ft), Florida Current	NOS	FEB1107_1	30.67019	-81.46789	:America/New_York	USA	knots	59	239	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 19.5 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.109	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fernandina Beach, City Front Reach, Amelia River	FL
98519	Fernandina Beach, City Front Reach, Amelia River (depth 11 ft), Florida Current	NOS	FEB1107_6	30.67019	-81.46789	:America/New_York	USA	knots	63	239	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fernandina Beach, City Front Reach, Amelia River	FL
98520	Fernandina Beach, City Front Reach, Amelia River (depth 5 ft), Florida Current	NOS	FEB1107_10	30.67019	-81.46789	:America/New_York	USA	knots	68	240	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fernandina Beach, City Front Reach, Amelia River	FL
98521	South jetty (depth 34 ft), St. Marys River, Cumberland Sound, Florida Current	NOS	FEB1108_1	30.70693	-81.39861	:America/New_York	USA	knots	114	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.146	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	south jetty	FL
98522	South jetty (depth 18 ft), St. Marys River, Cumberland Sound, Florida Current	NOS	FEB1108_6	30.70693	-81.39861	:America/New_York	USA	knots	112	329	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	south jetty	FL
98523	South jetty (depth 8 ft), St. Marys River, Cumberland Sound, Florida Current	NOS	FEB1108_9	30.70693	-81.39861	:America/New_York	USA	knots	110	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.267	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	south jetty	FL
98524	Key West, 0.3 mi W of Ft. Taylor (depth 14 ft), Florida Current	NOS	FLK1301_1	24.54798	-81.81686	:America/New_York	USA	knots	186	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West, 0.3 mi. W of Ft. Taylor	FL
98525	Key West, 0.3 mi W of Ft. Taylor (depth 4 ft), Florida Current	NOS	FLK1301_4	24.54798	-81.81686	:America/New_York	USA	knots	187	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West, 0.3 mi. W of Ft. Taylor	FL
98526	Main Ship Channel entrance (depth 17 ft), Key West, Florida Current	NOS	FLK1302_2	24.47071	-81.81177	:America/New_York	USA	knots	182	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Main Ship Channel Entrance	FL
98527	Main Ship Channel entrance (depth 4 ft), Key West, Florida Current	NOS	FLK1302_6	24.47071	-81.81177	:America/New_York	USA	knots	187	339	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Main Ship Channel Entrance	FL
98528	Key West Channel, Cut-A Cut-B Turn (depth 26 ft), Florida Current	NOS	FLK1303_1	24.52603	-81.81819	:America/New_York	USA	knots	161	324	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West Channel, Cut-A Cut-B Turn	FL
98529	Key West Channel, Cut-A Cut-B Turn (depth 6 ft), Florida Current	NOS	FLK1303_7	24.52603	-81.81819	:America/New_York	USA	knots	164	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West Channel, Cut-A Cut-B Turn	FL
98530	Southwest channel (depth 20 ft), Key West, Florida Current	NOS	FLK1304_1	24.53421	-81.83212	:America/New_York	USA	knots	202	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southwest channel	FL
98531	Southwest channel (depth 3 ft), Key West, Florida Current	NOS	FLK1304_6	24.53421	-81.83212	:America/New_York	USA	knots	202	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southwest channel	FL
98532	Key West Harbor Range channel (depth 19 ft), Florida Current	NOS	FLK1306_1	24.56301	-81.80934	:America/New_York	USA	knots	212	32	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West Harbor Range channel	FL
98533	Key West Harbor Range channel (depth 6 ft), Florida Current	NOS	FLK1306_5	24.56301	-81.80934	:America/New_York	USA	knots	215	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Key West Harbor Range channel	FL
98534	Turning Basin (depth 23 ft), Key West, Florida Current	NOS	FLK1307_1	24.56389	-81.80622	:America/New_York	USA	knots	24	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turning Basin	FL
98535	Turning Basin (depth 6 ft), Key West, Florida Current	NOS	FLK1307_6	24.56389	-81.80622	:America/New_York	USA	knots	210	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turning Basin	FL
98536	Man of War Harbor (depth 16 ft), Florida Current	NOS	FLK1308_1	24.58701	-81.80624	:America/New_York	USA	knots	182	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Man of War Harbor	FL
98537	Man of War Harbor (depth 3 ft), Florida Current	NOS	FLK1308_5	24.58701	-81.80624	:America/New_York	USA	knots	187	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Man of War Harbor	FL
98538	Fleming Key, north of (depth 9 ft), Florida Current	NOS	FLK1309_1	24.59673	-81.7986	:America/New_York	USA	knots	241	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fleming Key, North of	FL
98539	Fleming Key, north of (depth 2 ft), Florida Current	NOS	FLK1309_5	24.59673	-81.7986	:America/New_York	USA	knots	242	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.332	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fleming Key, North of	FL
98540	Fleming Key Cut (depth 17 ft), Florida Current	NOS	FLK1310_1	24.56814	-81.80182	:America/New_York	USA	knots	274	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.458	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fleming Key Cut	FL
98541	Fleming Key Cut (depth 4 ft), Florida Current	NOS	FLK1310_5	24.56814	-81.80182	:America/New_York	USA	knots	279	68	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.551	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fleming Key Cut	FL
98542	Northwest Channel, W of Calda Bank (depth 22 ft), Key West, Florida Current	NOS	FLK1313_1	24.61539	-81.87154	:America/New_York	USA	knots	144	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northwest Channel, W of Calda Bank	FL
98543	Northwest Channel, W of Calda Bank (depth 5 ft), Key West, Florida Current	NOS	FLK1313_6	24.61539	-81.87154	:America/New_York	USA	knots	145	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northwest Channel, W of Calda Bank	FL
98544	Northwest Channel, W of Middle Ground (depth 17 ft), Key West, Florida Current	NOS	FLK1315_1	24.56827	-81.83502	:America/New_York	USA	knots	140	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northwest Channel, W of Middle Ground	FL
98545	Northwest Channel, W of Middle Ground (depth 4 ft), Key West, Florida Current	NOS	FLK1315_5	24.56827	-81.83502	:America/New_York	USA	knots	162	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Northwest Channel, W of Middle Ground	FL
98546	Boca Grande Channel (depth 12 ft), Florida Current	NOS	FLK1316_1	24.56656	-82.06678	:America/New_York	USA	knots	191	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boca Grande Channel	FL
98547	Boca Grande Channel (depth 2 ft), Florida Current	NOS	FLK1316_7	24.56656	-82.06678	:America/New_York	USA	knots	190	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boca Grande Channel	FL
98548	New Ground (depth 32 ft), Florida Current	NOS	FLK1317_1	24.65071	-82.4162	:America/New_York	USA	knots	259	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Ground	FL
98549	New Ground (depth 6 ft), Florida Current	NOS	FLK1317_9	24.65071	-82.4162	:America/New_York	USA	knots	260	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Ground	FL
98550	Moser Channel, between Molasses and Pigeon Keys (depth 9 ft), Florida Current	NOS	FLK1324_1	24.698169708251953	-81.16924285888672	:America/New_York	USA	knots	163	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moser Channel, between Molasses and Pigeon Keys	FL
98551	Moser Channel, between Molasses and Pigeon Keys (depth 3 ft), Florida Current	NOS	FLK1324_5	24.698169708251953	-81.16924285888672	:America/New_York	USA	knots	164	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.143	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Moser Channel, between Molasses and Pigeon Keys	FL
98552	Loggerhead Key, east of (depth 8 ft), Florida Current	NOS	FLK1325_1	24.61617	-81.45322	:America/New_York	USA	knots	154	330	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Loggerhead Key, East of	FL
98553	Loggerhead Key, east of (depth 2 ft), Florida Current	NOS	FLK1325_5	24.61617	-81.45322	:America/New_York	USA	knots	158	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Loggerhead Key, East of	FL
98554	Bahia Honda Harbor (depth 4 ft), Florida Current	NOS	FLK1327_4	24.6563	-81.28848	:America/New_York	USA	knots	183	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bahia Honda Harbor	FL
98555	Fort Pierce Inlet entrance (depth 33 ft), Florida Current	NOS	FPI0901_1	27.47114	-80.29258	:America/New_York	USA	knots	77	260	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pierce Inlet Entrance	FL
98556	Fort Pierce Inlet entrance (depth 23 ft), Florida Current	NOS	FPI0901_4	27.47114	-80.29258	:America/New_York	USA	knots	79	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pierce Inlet Entrance	FL
98557	Fort Pierce Inlet entrance (depth 16 ft), Florida Current	NOS	FPI0901_6	27.47114	-80.29258	:America/New_York	USA	knots	80	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pierce Inlet Entrance	FL
98558	Fort Pierce Inlet entrance (depth 6 ft), Florida Current	NOS	FPI0901_9	27.47114	-80.29258	:America/New_York	USA	knots	81	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.159	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Pierce Inlet Entrance	FL
98559	Inner Range, north of USCG station (depth 21 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0902_1	27.46641	-80.30824	:America/New_York	USA	knots	61	243	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Inner Range, north of USCG station	FL
98560	Inner Range, north of USCG station (depth 14 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0902_3	27.46641	-80.30824	:America/New_York	USA	knots	65	243	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Inner Range, north of USCG station	FL
98561	Inner Range, north of USCG station (depth 5 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0902_6	27.46641	-80.30824	:America/New_York	USA	knots	76	242	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Inner Range, north of USCG station	FL
98562	South Bridge (ICW) (depth 16 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0903_1	27.45997	-80.3192	:America/New_York	USA	knots	53	232	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Bridge (ICW)	FL
98563	South Bridge (ICW) (depth 9 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0903_5	27.45997	-80.3192	:America/New_York	USA	knots	36	236	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Bridge (ICW)	FL
98564	South Bridge (ICW) (depth 3 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0903_9	27.45997	-80.3192	:America/New_York	USA	knots	31	238	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Bridge (ICW)	FL
98565	Turning Basin (depth 19 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0904_1	27.46014	-80.32093	:America/New_York	USA	knots	23	218	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turning Basin	FL
98566	Turning Basin (depth 16 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0904_2	27.46014	-80.32093	:America/New_York	USA	knots	22	219	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turning Basin	FL
98567	Turning Basin (depth 6 ft), Fort Pierce Inlet, Florida Current	NOS	FPI0904_5	27.46014	-80.32093	:America/New_York	USA	knots	20	218	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turning Basin	FL
98568	Barbers Point entrance (depth 166 ft), Oahu Island, Hawaii Current	NOS	HAI1103_1	21.31235	-158.13288	:Pacific/Honolulu	USA	knots	340	165	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barbers Point Entrance	HI
98569	Barbers Point entrance (depth 94 ft), Oahu Island, Hawaii Current	NOS	HAI1103_12	21.31235	-158.13288	:Pacific/Honolulu	USA	knots	345	151	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barbers Point Entrance	HI
98570	Barbers Point entrance (depth 22 ft), Oahu Island, Hawaii Current	NOS	HAI1103_23	21.31235	-158.13288	:Pacific/Honolulu	USA	knots	350	152	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.224	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Barbers Point Entrance	HI
98571	South of Barbers Point (depth 224 ft), Oahu Island, Hawaii Current	NOS	HAI1105_1	21.2696	-158.10157	:Pacific/Honolulu	USA	knots	293	112	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South of Barbers Point	HI
98572	South of Barbers Point (depth 136 ft), Oahu Island, Hawaii Current	NOS	HAI1105_10	21.2696	-158.10157	:Pacific/Honolulu	USA	knots	289	115	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South of Barbers Point	HI
98573	South of Barbers Point (depth 27 ft), Oahu Island, Hawaii Current	NOS	HAI1105_21	21.2696	-158.10157	:Pacific/Honolulu	USA	knots	285	122	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.112	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South of Barbers Point	HI
98574	Diamond Head (depth 186 ft), Oahu Island, Hawaii Current	NOS	HAI1106_1	21.2395	-157.8058	:Pacific/Honolulu	USA	knots	104	290	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Diamond Head	HI
98575	Diamond Head (depth 107 ft), Oahu Island, Hawaii Current	NOS	HAI1106_13	21.2395	-157.8058	:Pacific/Honolulu	USA	knots	96	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Diamond Head	HI
98576	Diamond Head (depth 22 ft), Oahu Island, Hawaii Current	NOS	HAI1106_26	21.2395	-157.8058	:Pacific/Honolulu	USA	knots	97	274	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Diamond Head	HI
98577	Iroquois Point, Pearl Harbor (depth 64 ft), Oahu Island, Hawaii Current	NOS	HAI1110_1	21.33498	-157.97023	:Pacific/Honolulu	USA	knots	\N	6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Iroquois Point, Pearl Harbor	HI
98578	Iroquois Point, Pearl Harbor (depth 35 ft), Oahu Island, Hawaii Current	NOS	HAI1110_10	21.33498	-157.97023	:Pacific/Honolulu	USA	knots	181	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Iroquois Point, Pearl Harbor	HI
98579	Iroquois Point, Pearl Harbor (depth 9 ft), Oahu Island, Hawaii Current	NOS	HAI1110_18	21.33498	-157.97023	:Pacific/Honolulu	USA	knots	180	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.098	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Iroquois Point, Pearl Harbor	HI
98580	Makapu'u Point (depth 257 ft), Oahu Island, Hawaii Current	NOS	HAI1111_1	21.26423	-157.60542	:Pacific/Honolulu	USA	knots	70	210	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Makapu'u Point	HI
98581	Makapu'u Point (depth 109 ft), Oahu Island, Hawaii Current	NOS	HAI1111_16	21.26423	-157.60542	:Pacific/Honolulu	USA	knots	42	217	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.271	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Makapu'u Point	HI
98582	Makapu'u Point (depth 41 ft), Oahu Island, Hawaii Current	NOS	HAI1111_23	21.26423	-157.60542	:Pacific/Honolulu	USA	knots	42	217	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.239	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Makapu'u Point	HI
98583	Kahuku Point (depth 189 ft), Oahu Island, Hawaii Current	NOS	HAI1112_1	21.72998	-157.98995	:Pacific/Honolulu	USA	knots	76	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kahuku Point	HI
98584	Kahuku Point (depth 110 ft), Oahu Island, Hawaii Current	NOS	HAI1112_13	21.72998	-157.98995	:Pacific/Honolulu	USA	knots	79	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kahuku Point	HI
98585	Kahuku Point (depth 25 ft), Oahu Island, Hawaii Current	NOS	HAI1112_26	21.72998	-157.98995	:Pacific/Honolulu	USA	knots	73	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kahuku Point	HI
98586	Laau Point, southwest of (depth 181 ft), Molokai Island, Hawaii Current	NOS	HAI1113_1	21.07645	-157.3616	:Pacific/Honolulu	USA	knots	340	160	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Laau Point, Southwest of	HI
98587	Laau Point, southwest of (depth 103 ft), Molokai Island, Hawaii Current	NOS	HAI1113_13	21.07645	-157.3616	:Pacific/Honolulu	USA	knots	338	170	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Laau Point, Southwest of	HI
98588	Laau Point, southwest of (depth 24 ft), Molokai Island, Hawaii Current	NOS	HAI1113_25	21.07645	-157.3616	:Pacific/Honolulu	USA	knots	340	172	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Laau Point, Southwest of	HI
98589	Pailalo Channel (depth 244 ft), Molokai Island, Hawaii Current	NOS	HAI1115_1	21.08695	-156.73148	:Pacific/Honolulu	USA	knots	33	227	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pailalo Channel	HI
98590	Pailalo Channel (depth 136 ft), Molokai Island, Hawaii Current	NOS	HAI1115_12	21.08695	-156.73148	:Pacific/Honolulu	USA	knots	39	229	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pailalo Channel	HI
98591	Pailalo Channel (depth 28 ft), Molokai Island, Hawaii Current	NOS	HAI1115_23	21.08695	-156.73148	:Pacific/Honolulu	USA	knots	39	233	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.175	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pailalo Channel	HI
98592	Kalohi Channel (depth 237 ft), Hawaii Current	NOS	HAI1116_1	21.0033	-156.95883	:Pacific/Honolulu	USA	knots	96	281	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalohi Channel	HI
98593	Kalohi Channel (depth 139 ft), Hawaii Current	NOS	HAI1116_11	21.0033	-156.95883	:Pacific/Honolulu	USA	knots	102	283	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalohi Channel	HI
98594	Kalohi Channel (depth 21 ft), Hawaii Current	NOS	HAI1116_22	21.0033	-156.95883	:Pacific/Honolulu	USA	knots	106	284	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 30.7 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kalohi Channel	HI
98595	Hawea Point (depth 243 ft), Maui Island, Hawaii Current	NOS	HAI1118_1	21.00178	-156.69182	:Pacific/Honolulu	USA	knots	34	230	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawea Point	HI
98596	Hawea Point (depth 99 ft), Maui Island, Hawaii Current	NOS	HAI1118_23	21.00178	-156.69182	:Pacific/Honolulu	USA	knots	21	208	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.364	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawea Point	HI
98597	Hawea Point (depth 27 ft), Maui Island, Hawaii Current	NOS	HAI1118_34	21.00178	-156.69182	:Pacific/Honolulu	USA	knots	14	215	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.431	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawea Point	HI
98598	Auau Channel (depth 210 ft), Maui Island, Hawaii Current	NOS	HAI1119_1	20.86727	-156.74717	:Pacific/Honolulu	USA	knots	342	164	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Auau Channel	HI
98599	Auau Channel (depth 105 ft), Maui Island, Hawaii Current	NOS	HAI1119_17	20.86727	-156.74717	:Pacific/Honolulu	USA	knots	344	172	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.282	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Auau Channel	HI
98600	Auau Channel (depth 26 ft), Maui Island, Hawaii Current	NOS	HAI1119_29	20.86727	-156.74717	:Pacific/Honolulu	USA	knots	347	168	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.293	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Auau Channel	HI
98601	Lahaina (depth 49 ft), Maui Island, Hawaii Current	NOS	HAI1120_1	20.86845	-156.68528	:Pacific/Honolulu	USA	knots	334	139	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.203	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lahaina	HI
98602	Lahaina (depth 29 ft), Maui Island, Hawaii Current	NOS	HAI1120_7	20.86845	-156.68528	:Pacific/Honolulu	USA	knots	333	137	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.244	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lahaina	HI
98603	Lahaina (depth 7 ft), Maui Island, Hawaii Current	NOS	HAI1120_14	20.86845	-156.68528	:Pacific/Honolulu	USA	knots	330	134	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.276	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lahaina	HI
98696	Cape Trinity (depth 185 ft), Sitkinak Strait, Alaska Current	NOS	KOD0918_1	56.74982	-154.201	:America/Anchorage	USA	knots	114	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Trinity	AK
98604	Alalakeiki Channel (depth 56 ft), Maui Island, Hawaii Current	NOS	HAI1121_28	20.61252	-156.50812	:Pacific/Honolulu	USA	knots	\N	330.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alalakeiki Channel	HI
98605	Upolu Point (depth 204 ft), Hawaii Island, Hawaii Current	NOS	HAI1127_1	20.26502	-155.90157	:Pacific/Honolulu	USA	knots	28	241	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.381	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upolu Point	HI
98606	Upolu Point (depth 100 ft), Hawaii Island, Hawaii Current	NOS	HAI1127_17	20.26502	-155.90157	:Pacific/Honolulu	USA	knots	34	237	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upolu Point	HI
98607	Upolu Point (depth 34 ft), Hawaii Island, Hawaii Current	NOS	HAI1127_27	20.26502	-155.90157	:Pacific/Honolulu	USA	knots	30	241	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.626	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upolu Point	HI
98608	Humboldt Bay ent., 0.1 nmi NE of South Spit Light (depth 30 ft), California Current	NOS	HUB0202_4	40.75792	-124.23278	:America/Los_Angeles	USA	knots	346	171	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldt Bay Entr., 0.1nm NE of South Spit Light	CA
98609	Humboldt Bay ent., 0.1 nmi NE of South Spit Light (depth 14 ft), California Current	NOS	HUB0202_9	40.75792	-124.23278	:America/Los_Angeles	USA	knots	341	168	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.299	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldt Bay Entr., 0.1nm NE of South Spit Light	CA
98610	North Bay Channel, west of Eureka (depth 28 ft), Humboldt Bay, California Current	NOS	HUB0203_2	40.78715	-124.19268	:America/Los_Angeles	USA	knots	200	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 29.2 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Bay Channel, west of Eureka	CA
98611	North Bay Channel, west of Eureka (depth 15 ft), Humboldt Bay, California Current	NOS	HUB0203_6	40.78715	-124.19268	:America/Los_Angeles	USA	knots	197	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 16.1 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Bay Channel, west of Eureka	CA
98612	South Spit, 0.1 nmi E of (depth 15 ft), Humboldt Bay, California Current	NOS	HUB0207_3	40.74785	-124.2241	:America/Los_Angeles	USA	knots	2	178	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 17.0 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Spit, 0.1 n.mi. E of	CA
98613	Humboldy Bay Bar Channel, 0.4 nmi WNW of (depth 31 ft), Humboldt Bay, California Current	NOS	HUB0401_1	40.76688	-124.25298	:America/Los_Angeles	USA	knots	230	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldy Bay Bar Channel, 0.4 nm WNW of	CA
98614	Humboldy Bay Bar Channel, 0.4 nmi WNW of (depth 4 ft), Humboldt Bay, California Current	NOS	HUB0401_9	40.76688	-124.25298	:America/Los_Angeles	USA	knots	232	48	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldy Bay Bar Channel, 0.4 nm WNW of	CA
98615	Humboldt Bay entrance channel (depth 34 ft), California Current	NOS	HUB0402_1	40.7651	-124.23753	:America/Los_Angeles	USA	knots	323	141	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldt Bay Entrance Channel	CA
98616	Humboldt Bay entrance channel (depth 15 ft), California Current	NOS	HUB0402_7	40.7651	-124.23753	:America/Los_Angeles	USA	knots	323	140	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldt Bay Entrance Channel	CA
98617	Haverstraw (depth 20 ft), Hudson River (midchannel), New York Current	NOS	HUR0401_1	41.20917	-73.95133	:America/New_York	USA	knots	162	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haverstraw	NY
98618	Haverstraw (depth 12 ft), Hudson River (midchannel), New York Current	NOS	HUR0401_6	41.20917	-73.95133	:America/New_York	USA	knots	166	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haverstraw	NY
98619	Haverstraw (depth 4 ft), Hudson River (midchannel), New York Current	NOS	HUR0401_11	41.20917	-73.95133	:America/New_York	USA	knots	165	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.275	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haverstraw	NY
98620	Tappan Zee Bridge (depth 35 ft), Hudson River (midchannel), New York Current	NOS	HUR0502_1	41.06743	-73.88154	:America/New_York	USA	knots	178	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tappan Zee Bridge	NY
98621	Tappan Zee Bridge (depth 16 ft), Hudson River (midchannel), New York Current	NOS	HUR0502_7	41.06743	-73.88154	:America/New_York	USA	knots	174	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tappan Zee Bridge	NY
98622	Tappan Zee Bridge (depth 5 ft), Hudson River (midchannel), New York Current	NOS	HUR0502_10	41.06743	-73.88154	:America/New_York	USA	knots	175	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tappan Zee Bridge	NY
98623	Stony Point (depth 83 ft), Hudson River (midchannel), New York Current	NOS	HUR0503_1	41.24158	-73.96668	:America/New_York	USA	knots	170	338	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stony Point	NY
98624	Stony Point (depth 50 ft), Hudson River (midchannel), New York Current	NOS	HUR0503_11	41.24158	-73.96668	:America/New_York	USA	knots	165	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stony Point	NY
98625	Stony Point (depth 14 ft), Hudson River (midchannel), New York Current	NOS	HUR0503_22	41.24158	-73.96668	:America/New_York	USA	knots	154	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.237	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stony Point	NY
98626	Bear Mountain Bridge (depth 88 ft), Hudson River (midchannel), New York Current	NOS	HUR0504_1	41.31592	-73.98385	:America/New_York	USA	knots	161	339	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Mountain Bridge	NY
98627	Bear Mountain Bridge (depth 52 ft), Hudson River (midchannel), New York Current	NOS	HUR0504_12	41.31592	-73.98385	:America/New_York	USA	knots	167	343	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Mountain Bridge	NY
98628	Bear Mountain Bridge (depth 13 ft), Hudson River (midchannel), New York Current	NOS	HUR0504_24	41.31592	-73.98385	:America/New_York	USA	knots	180	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.311	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Mountain Bridge	NY
98629	Newburgh Beacon Bridge (depth 24 ft), Hudson River (midchannel), New York Current	NOS	HUR0506_1	41.51658	-73.99168	:America/New_York	USA	knots	168	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newburgh Beacon Bridge	NY
98630	Newburgh Beacon Bridge (depth 17 ft), Hudson River (midchannel), New York Current	NOS	HUR0506_3	41.51658	-73.99168	:America/New_York	USA	knots	169	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newburgh Beacon Bridge	NY
98631	Newburgh Beacon Bridge (depth 4 ft), Hudson River (midchannel), New York Current	NOS	HUR0506_7	41.51658	-73.99168	:America/New_York	USA	knots	171	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newburgh Beacon Bridge	NY
98632	Roseton (depth 41 ft), Hudson River (midchannel), New York Current	NOS	HUR0507_1	41.56247	-73.97053	:America/New_York	USA	knots	215	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roseton	NY
98633	Roseton (depth 15 ft), Hudson River (midchannel), New York Current	NOS	HUR0507_9	41.56247	-73.97053	:America/New_York	USA	knots	214	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roseton	NY
98634	Roseton (depth 5 ft), Hudson River (midchannel), New York Current	NOS	HUR0507_12	41.56247	-73.97053	:America/New_York	USA	knots	213	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roseton	NY
98635	Kingston Point, south of (depth 30 ft), Hudson River (midchannel), New York Current	NOS	HUR0509_1	41.91827	-73.9595	:America/New_York	USA	knots	178	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingston Point, south of	NY
98636	Kingston Point, south of (depth 17 ft), Hudson River (midchannel), New York Current	NOS	HUR0509_5	41.91827	-73.9595	:America/New_York	USA	knots	177	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingston Point, south of	NY
98637	Kingston Point, south of (depth 4 ft), Hudson River (midchannel), New York Current	NOS	HUR0509_9	41.91827	-73.9595	:America/New_York	USA	knots	177	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingston Point, south of	NY
98638	George Washington Bridge (depth 63 ft), Hudson River (midchannel), New York Current	NOS	HUR0611_1	40.84958	-73.94982	:America/New_York	USA	knots	177	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	George Washington Bridge	NY
98639	George Washington Bridge (depth 40 ft), Hudson River (midchannel), New York Current	NOS	HUR0611_8	40.84958	-73.94982	:America/New_York	USA	knots	198	12	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	George Washington Bridge	NY
98640	George Washington Bridge (depth 14 ft), Hudson River (midchannel), New York Current	NOS	HUR0611_16	40.84958	-73.94982	:America/New_York	USA	knots	203	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.237	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	George Washington Bridge	NY
98641	Kingston-Rhinecliff Bridge (depth 27 ft), Hudson River (midchannel), New York Current	NOS	HUR0612_1	41.97708	-73.95225	:America/New_York	USA	knots	190	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingston-Rhinecliff Bridge	NY
98642	Kingston-Rhinecliff Bridge (depth 14 ft), Hudson River (midchannel), New York Current	NOS	HUR0612_5	41.97708	-73.95225	:America/New_York	USA	knots	191	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingston-Rhinecliff Bridge	NY
98643	Kingston-Rhinecliff Bridge (depth 4 ft), Hudson River (midchannel), New York Current	NOS	HUR0612_8	41.97708	-73.95225	:America/New_York	USA	knots	192	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kingston-Rhinecliff Bridge	NY
98644	Silver Point, south of (depth 31 ft), Hudson River (midchannel), New York Current	NOS	HUR0613_1	42.13818	-73.90852	:America/New_York	USA	knots	205	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Silver Point, south of	NY
98645	Silver Point, south of (depth 14 ft), Hudson River (midchannel), New York Current	NOS	HUR0613_6	42.13818	-73.90852	:America/New_York	USA	knots	205	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Silver Point, south of	NY
98646	Silver Point, south of (depth 4 ft), Hudson River (midchannel), New York Current	NOS	HUR0613_9	42.13818	-73.90852	:America/New_York	USA	knots	205	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Silver Point, south of	NY
98647	Hudson (depth 40 ft), Hudson River (midchannel), New York Current	NOS	HUR0614_1	42.24792	-73.8184	:America/New_York	USA	knots	238	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.308	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson	NY
98648	Hudson (depth 24 ft), Hudson River (midchannel), New York Current	NOS	HUR0614_6	42.24792	-73.8184	:America/New_York	USA	knots	242	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.378	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson	NY
98649	Hudson (depth 14 ft), Hudson River (midchannel), New York Current	NOS	HUR0614_9	42.24792	-73.8184	:America/New_York	USA	knots	242	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.384	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson	NY
98650	Coxsackie (depth 31 ft), Hudson River (midchannel), New York Current	NOS	HUR0615_1	42.35135	-73.78992	:America/New_York	USA	knots	184	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coxsackie	NY
98651	Coxsackie (depth 14 ft), Hudson River (midchannel), New York Current	NOS	HUR0615_6	42.35135	-73.78992	:America/New_York	USA	knots	189	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coxsackie	NY
98652	Coxsackie (depth 4 ft), Hudson River (midchannel), New York Current	NOS	HUR0615_9	42.35135	-73.78992	:America/New_York	USA	knots	190	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.236	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coxsackie	NY
98653	Houghtaling Island, south of (depth 27 ft), Hudson River (midchannel), New York Current	NOS	HUR0616_1	42.42258	-73.77995	:America/New_York	USA	knots	181	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.145	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Houghtaling Island, south of	NY
98654	Houghtaling Island, south of (depth 14 ft), Hudson River (midchannel), New York Current	NOS	HUR0616_5	42.42258	-73.77995	:America/New_York	USA	knots	180	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.164	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Houghtaling Island, south of	NY
98655	Houghtaling Island, south of (depth 4 ft), Hudson River (midchannel), New York Current	NOS	HUR0616_8	42.42258	-73.77995	:America/New_York	USA	knots	180	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Houghtaling Island, south of	NY
98656	Castleton-on-Hudson Bridge (depth 32 ft), Hudson River (midchannel), New York Current	NOS	HUR0617_1	42.50435	-73.77738	:America/New_York	USA	knots	229	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Castleton-on-Hudson Bridge	NY
98657	Castleton-on-Hudson Bridge (depth 16 ft), Hudson River (midchannel), New York Current	NOS	HUR0617_6	42.50435	-73.77738	:America/New_York	USA	knots	232	50	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Castleton-on-Hudson Bridge	NY
98658	Castleton-on-Hudson Bridge (depth 6 ft), Hudson River (midchannel), New York Current	NOS	HUR0617_9	42.50435	-73.77738	:America/New_York	USA	knots	233	51	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Castleton-on-Hudson Bridge	NY
98659	Port of Albany (depth 30 ft), Hudson River (midchannel), New York Current	NOS	HUR0618_1	42.62317	-73.75558	:America/New_York	USA	knots	200	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of Albany	NY
98660	Port of Albany (depth 16 ft), Hudson River (midchannel), New York Current	NOS	HUR0618_5	42.62317	-73.75558	:America/New_York	USA	knots	198	20	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.143	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of Albany	NY
98661	Port of Albany (depth 7 ft), Hudson River (midchannel), New York Current	NOS	HUR0618_8	42.62317	-73.75558	:America/New_York	USA	knots	198	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port of Albany	NY
98662	Mid-Hudson Suspension Bridge (depth 48 ft), Hudson River (midchannel), New York Current	NOS	HUR0620_1	41.70182	-73.94593	:America/New_York	USA	knots	185	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.162	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mid-Hudson Suspension Bridge	NY
98663	Mid-Hudson Suspension Bridge (depth 32 ft), Hudson River (midchannel), New York Current	NOS	HUR0620_6	41.70182	-73.94593	:America/New_York	USA	knots	186	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mid-Hudson Suspension Bridge	NY
98664	Mid-Hudson Suspension Bridge (depth 16 ft), Hudson River (midchannel), New York Current	NOS	HUR0620_11	41.70182	-73.94593	:America/New_York	USA	knots	188	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.166	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mid-Hudson Suspension Bridge	NY
98665	Johns Pass entrance (depth 8 ft), Florida Current	NOS	JOP1101_1	27.77815	-82.78722	:America/New_York	USA	knots	223	51	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.172	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johns Pass Entrance	FL
98666	Johns Pass entrance (depth 2 ft), Florida Current	NOS	JOP1101_5	27.77815	-82.78722	:America/New_York	USA	knots	222	53	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.246	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johns Pass Entrance	FL
98667	Johns Pass Bridge, north span (depth 16 ft), Florida Current	NOS	JOP1103_1	27.78331	-82.78216	:America/New_York	USA	knots	209	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johns Pass Bridge, north span	FL
98668	Johns Pass Bridge, north span (depth 3 ft), Florida Current	NOS	JOP1103_9	27.78331	-82.78216	:America/New_York	USA	knots	209	34	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johns Pass Bridge, north span	FL
98669	Johns Pass Bridge, 0.3 nmi north of (depth 11 ft), Florida Current	NOS	JOP1104_1	27.78499	-82.77988	:America/New_York	USA	knots	235	47	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.208	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johns Pass Bridge, 0.3nm north of	FL
98670	Johns Pass Bridge, 0.3 nmi north of (depth 3 ft), Florida Current	NOS	JOP1104_6	27.78499	-82.77988	:America/New_York	USA	knots	228	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.223	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johns Pass Bridge, 0.3nm north of	FL
98671	Cliff Point, 1.8 mi NE of (depth 208 ft), Chiniak Bay, Alaska Current	NOS	KOD0901_1	57.73559	-152.38463	:America/Anchorage	USA	knots	\N	289	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cliff Point, 1.8miles NE of	AK
98672	Cliff Point, 1.8 mi NE of (depth 25 ft), Chiniak Bay, Alaska Current	NOS	KOD0901_29	57.73559	-152.38463	:America/Anchorage	USA	knots	\N	241	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cliff Point, 1.8miles NE of	AK
98673	Kodiak Harbor Narrows (depth 33 ft), Chiniak Bay, Alaska Current	NOS	KOD0903_1	57.78918	-152.394	:America/Anchorage	USA	knots	220	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kodiak Harbor Narrows	AK
98674	Kodiak Harbor Narrows (depth 16 ft), Chiniak Bay, Alaska Current	NOS	KOD0903_6	57.78918	-152.394	:America/Anchorage	USA	knots	228	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kodiak Harbor Narrows	AK
98675	Kodiak Harbor Narrows (depth 6 ft), Chiniak Bay, Alaska Current	NOS	KOD0903_9	57.78918	-152.394	:America/Anchorage	USA	knots	228	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.163	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kodiak Harbor Narrows	AK
98676	Woody Island, north of (depth 99 ft), Chiniak Bay, Alaska Current	NOS	KOD0904_1	57.80578	-152.33434	:America/Anchorage	USA	knots	243	51	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woody Island, north of	AK
98677	Woody Island, north of (depth 59 ft), Chiniak Bay, Alaska Current	NOS	KOD0904_7	57.80578	-152.33434	:America/Anchorage	USA	knots	246	50	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woody Island, north of	AK
98678	Woody Island, north of (depth 14 ft), Chiniak Bay, Alaska Current	NOS	KOD0904_14	57.80578	-152.33434	:America/Anchorage	USA	knots	241	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woody Island, north of	AK
98679	Woody Channel (depth 85 ft), Chiniak Bay, Alaska Current	NOS	KOD0905_1	57.78043	-152.36638	:America/Anchorage	USA	knots	203	20	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woody Channel	AK
98680	Woody Channel (depth 49 ft), Chiniak Bay, Alaska Current	NOS	KOD0905_12	57.78043	-152.36638	:America/Anchorage	USA	knots	204	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woody Channel	AK
98681	Woody Channel (depth 16 ft), Chiniak Bay, Alaska Current	NOS	KOD0905_22	57.78043	-152.36638	:America/Anchorage	USA	knots	203	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Woody Channel	AK
98682	Cape Chiniak (depth 223 ft), Chiniak Bay, Alaska Current	NOS	KOD0906_1	57.60784	-152.08979	:America/Anchorage	USA	knots	200	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chiniak	AK
98683	Cape Chiniak (depth 125 ft), Chiniak Bay, Alaska Current	NOS	KOD0906_16	57.60784	-152.08979	:America/Anchorage	USA	knots	201	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chiniak	AK
98684	Cape Chiniak (depth 26 ft), Chiniak Bay, Alaska Current	NOS	KOD0906_31	57.60784	-152.08979	:America/Anchorage	USA	knots	189	12	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chiniak	AK
98685	Ugak Bay entrance (depth 112 ft), Alaska Current	NOS	KOD0907_15	57.3995	-152.53466	:America/Anchorage	USA	knots	\N	237.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ugak Bay Entrance	AK
98686	Ugak Bay entrance (depth 27 ft), Alaska Current	NOS	KOD0907_28	57.3995	-152.53466	:America/Anchorage	USA	knots	\N	292	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ugak Bay Entrance	AK
98687	Geese Island, south of (depth 79 ft), Sitkinak Strait, Alaska Current	NOS	KOD0915_1	56.68618	-153.92006	:America/Anchorage	USA	knots	110	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Geese Island, south of	AK
98688	Geese Island, south of (depth 46 ft), Sitkinak Strait, Alaska Current	NOS	KOD0915_6	56.68618	-153.92006	:America/Anchorage	USA	knots	112	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Geese Island, south of	AK
98689	Geese Island, south of (depth 13 ft), Sitkinak Strait, Alaska Current	NOS	KOD0915_11	56.68618	-153.92006	:America/Anchorage	USA	knots	111	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Geese Island, south of	AK
98690	Cape Sitkinak, east of (depth 169 ft), Sitkinak Strait, Alaska Current	NOS	KOD0916_1	56.57744	-153.79126	:America/Anchorage	USA	knots	151	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Sitkinak, east of	AK
98691	Cape Sitkinak, east of (depth 97 ft), Sitkinak Strait, Alaska Current	NOS	KOD0916_12	56.57744	-153.79126	:America/Anchorage	USA	knots	144	338	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.366	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Sitkinak, east of	AK
98692	Cape Sitkinak, east of (depth 25 ft), Sitkinak Strait, Alaska Current	NOS	KOD0916_23	56.57744	-153.79126	:America/Anchorage	USA	knots	139	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.462	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Sitkinak, east of	AK
98698	Cape Trinity (depth 27 ft), Sitkinak Strait, Alaska Current	NOS	KOD0918_25	56.74982	-154.201	:America/Anchorage	USA	knots	130	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Trinity	AK
98699	Russian Harbor (depth 93 ft), Sitkinak Strait, Alaska Current	NOS	KOD0919_1	56.73967	-154.03397	:America/Anchorage	USA	knots	137	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Russian Harbor	AK
98700	Russian Harbor (depth 54 ft), Sitkinak Strait, Alaska Current	NOS	KOD0919_7	56.73967	-154.03397	:America/Anchorage	USA	knots	128	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Russian Harbor	AK
98701	Russian Harbor (depth 14 ft), Sitkinak Strait, Alaska Current	NOS	KOD0919_13	56.73967	-154.03397	:America/Anchorage	USA	knots	120	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Russian Harbor	AK
98702	Approach to Alitak Bay (depth 89 ft), Alaska Current	NOS	KOD0920_1	56.78384	-154.64118	:America/Anchorage	USA	knots	236	67	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Approach to Alitak Bay	AK
98703	Approach to Alitak Bay (depth 56 ft), Alaska Current	NOS	KOD0920_6	56.78384	-154.64118	:America/Anchorage	USA	knots	225	70	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Approach to Alitak Bay	AK
98704	Approach to Alitak Bay (depth 17 ft), Alaska Current	NOS	KOD0920_12	56.78384	-154.64118	:America/Anchorage	USA	knots	210	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Approach to Alitak Bay	AK
98705	Cape Ikolik, Shelikof Strait (depth 197 ft), Alaska Current	NOS	KOD0921_1	57.28605	-154.82843	:America/Anchorage	USA	knots	200	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Ikolik, Shelikof Strait	AK
98706	Cape Ikolik, Shelikof Strait (depth 112 ft), Alaska Current	NOS	KOD0921_14	57.28605	-154.82843	:America/Anchorage	USA	knots	205	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Ikolik, Shelikof Strait	AK
98707	Cape Ikolik, Shelikof Strait (depth 27 ft), Alaska Current	NOS	KOD0921_27	57.28605	-154.82843	:America/Anchorage	USA	knots	228	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.211	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Ikolik, Shelikof Strait	AK
98708	Cape Grant, Shelikof Strait (depth 164 ft), Alaska Current	NOS	KOD0922_1	57.41718	-154.76648	:America/Anchorage	USA	knots	204	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Grant, Shelikof Strait	AK
98709	Cape Grant, Shelikof Strait (depth 98 ft), Alaska Current	NOS	KOD0922_11	57.41718	-154.76648	:America/Anchorage	USA	knots	207	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Grant, Shelikof Strait	AK
98710	Cape Grant, Shelikof Strait (depth 26 ft), Alaska Current	NOS	KOD0922_22	57.41718	-154.76648	:America/Anchorage	USA	knots	211	20	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Grant, Shelikof Strait	AK
98711	Uyak Anchorage, Uyak Bay (depth 56 ft), Alaska Current	NOS	KOD0923_1	57.63732	-153.99539	:America/Anchorage	USA	knots	\N	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uyak Anchorage, Uyak Bay	AK
98712	Uyak Anchorage, Uyak Bay (depth 33 ft), Alaska Current	NOS	KOD0923_8	57.63732	-153.99539	:America/Anchorage	USA	knots	\N	310	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uyak Anchorage, Uyak Bay	AK
98713	Uyak Anchorage, Uyak Bay (depth 14 ft), Alaska Current	NOS	KOD0923_14	57.63732	-153.99539	:America/Anchorage	USA	knots	\N	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Uyak Anchorage, Uyak Bay	AK
98714	Larsen Bay, Uyak Bay (depth 33 ft), Alaska Current	NOS	KOD0924_1	57.54221	-153.98831	:America/Anchorage	USA	knots	111	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Larsen Bay, Uyak Bay	AK
98715	Larsen Bay, Uyak Bay (depth 14 ft), Alaska Current	NOS	KOD0924_7	57.54221	-153.98831	:America/Anchorage	USA	knots	105	296	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Larsen Bay, Uyak Bay	AK
98716	Larsen Bay, Uyak Bay (depth 7 ft), Alaska Current	NOS	KOD0924_9	57.54221	-153.98831	:America/Anchorage	USA	knots	104	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Larsen Bay, Uyak Bay	AK
98717	Cape Kuliuk, Shelikof Strait (depth 169 ft), Alaska Current	NOS	KOD0925_1	57.79352	-154.03236	:America/Anchorage	USA	knots	226	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kuliuk, Shelikof Strait	AK
98718	Cape Kuliuk, Shelikof Strait (depth 97 ft), Alaska Current	NOS	KOD0925_12	57.79352	-154.03236	:America/Anchorage	USA	knots	234	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kuliuk, Shelikof Strait	AK
98719	Cape Kuliuk, Shelikof Strait (depth 25 ft), Alaska Current	NOS	KOD0925_23	57.79352	-154.03236	:America/Anchorage	USA	knots	274	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kuliuk, Shelikof Strait	AK
98720	Steep Cape, Shelikof Strait (depth 88 ft), Alaska Current	NOS	KOD0926_11	58.21452	-153.22028	:America/Anchorage	USA	knots	\N	57.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.105	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steep Cape, Shelikof Strait	AK
98721	Steep Cape, Shelikof Strait (depth 23 ft), Alaska Current	NOS	KOD0926_21	58.21452	-153.22028	:America/Anchorage	USA	knots	\N	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steep Cape, Shelikof Strait	AK
98722	2.5 nmi east of Outlet Cape (depth 156 ft), Kupreanof Strait, Alaska Current	NOS	KOD0928_1	57.99757	-153.15648	:America/Anchorage	USA	knots	88	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2.5nm east of Outlet Cape	AK
98723	2.5 nmi east of Outlet Cape (depth 91 ft), Kupreanof Strait, Alaska Current	NOS	KOD0928_11	57.99757	-153.15648	:America/Anchorage	USA	knots	111	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2.5nm east of Outlet Cape	AK
98724	2.5 nmi east of Outlet Cape (depth 19 ft), Kupreanof Strait, Alaska Current	NOS	KOD0928_22	57.99757	-153.15648	:America/Anchorage	USA	knots	125	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	2.5nm east of Outlet Cape	AK
98725	Chernof Point, 0.8 mi off (depth 71 ft), Kupreanof Strait, Alaska Current	NOS	KOD0929_1	57.96041	-152.90063	:America/Anchorage	USA	knots	85	278	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.105	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chernof Point, 0.8mile off	AK
98726	Chernof Point, 0.8 mi off (depth 41 ft), Kupreanof Strait, Alaska Current	NOS	KOD0929_10	57.96041	-152.90063	:America/Anchorage	USA	knots	88	276	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.184	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chernof Point, 0.8mile off	AK
98727	Chernof Point, 0.8 mi off (depth 15 ft), Kupreanof Strait, Alaska Current	NOS	KOD0929_18	57.96041	-152.90063	:America/Anchorage	USA	knots	90	276	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.221	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chernof Point, 0.8mile off	AK
98728	Whale Passage, northwest entrance (depth 83 ft), Alaska Current	NOS	KOD0930_1	57.93959	-152.86278	:America/Anchorage	USA	knots	111	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.396	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Passage, Northwest Entrance	AK
98729	Whale Passage, northwest entrance (depth 50 ft), Alaska Current	NOS	KOD0930_6	57.93959	-152.86278	:America/Anchorage	USA	knots	113	301	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.496	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Passage, Northwest Entrance	AK
98730	Whale Passage, northwest entrance (depth 18 ft), Alaska Current	NOS	KOD0930_11	57.93959	-152.86278	:America/Anchorage	USA	knots	112	301	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.454	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Passage, Northwest Entrance	AK
98731	Whale Passage, off Bird Point (depth 73 ft), Alaska Current	NOS	KOD0931_1	57.91885	-152.79529	:America/Anchorage	USA	knots	119	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Passage, off Bird Point	AK
98732	Whale Passage, off Bird Point (depth 43 ft), Alaska Current	NOS	KOD0931_10	57.91885	-152.79529	:America/Anchorage	USA	knots	119	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Passage, off Bird Point	AK
98733	Whale Passage, off Bird Point (depth 14 ft), Alaska Current	NOS	KOD0931_19	57.91885	-152.79529	:America/Anchorage	USA	knots	117	310	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Passage, off Bird Point	AK
98734	Shag Rocks (depth 169 ft), Whale Passage, Alaska Current	NOS	KOD0932_1	57.90752	-152.77663	:America/Anchorage	USA	knots	117	269	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shag Rocks	AK
98735	Shag Rocks (depth 97 ft), Whale Passage, Alaska Current	NOS	KOD0932_12	57.90752	-152.77663	:America/Anchorage	USA	knots	119	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.408	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shag Rocks	AK
98736	Shag Rocks (depth 24 ft), Whale Passage, Alaska Current	NOS	KOD0932_23	57.90752	-152.77663	:America/Anchorage	USA	knots	120	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shag Rocks	AK
98737	Narrow Strait, off Ouzinkie Point (depth 84 ft), Alaska Current	NOS	KOD0933_1	57.9121	-152.52407	:America/Anchorage	USA	knots	117	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Narrow Strait, off Ouzinkie Point	AK
98738	Narrow Strait, off Ouzinkie Point (depth 51 ft), Alaska Current	NOS	KOD0933_6	57.9121	-152.52407	:America/Anchorage	USA	knots	120	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Narrow Strait, off Ouzinkie Point	AK
98739	Narrow Strait, off Ouzinkie Point (depth 12 ft), Alaska Current	NOS	KOD0933_12	57.9121	-152.52407	:America/Anchorage	USA	knots	121	310	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Narrow Strait, off Ouzinkie Point	AK
98740	Afognak Strait, east entrance (depth 97 ft), Alaska Current	NOS	KOD0934_1	57.99474	-152.68417	:America/Anchorage	USA	knots	107	284.3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Afognak Strait, East Entrance	AK
98741	Afognak Strait, east entrance (depth 57 ft), Alaska Current	NOS	KOD0934_7	57.99474	-152.68417	:America/Anchorage	USA	knots	107	285	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.281	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Afognak Strait, East Entrance	AK
98742	Afognak Strait, east entrance (depth 11 ft), Alaska Current	NOS	KOD0934_14	57.99474	-152.68417	:America/Anchorage	USA	knots	105	251	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.245	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Afognak Strait, East Entrance	AK
98743	Raspberry Strait, south of Muskomee Bay (depth 169 ft), Alaska Current	NOS	KOD0935_1	58.07176	-153.06462	:America/Anchorage	USA	knots	348	163	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raspberry Strait, south of Muskomee Bay	AK
98744	Raspberry Strait, south of Muskomee Bay (depth 97 ft), Alaska Current	NOS	KOD0935_12	58.07176	-153.06462	:America/Anchorage	USA	knots	\N	157.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raspberry Strait, south of Muskomee Bay	AK
98745	Raspberry Strait, south of Muskomee Bay (depth 25 ft), Alaska Current	NOS	KOD0935_23	58.07176	-153.06462	:America/Anchorage	USA	knots	\N	157	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raspberry Strait, south of Muskomee Bay	AK
98746	Black Cape, Shelikof Strait (depth 95 ft), Alaska Current	NOS	KOD0936_1	58.40572	-152.90728	:America/Anchorage	USA	knots	\N	181.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Black Cape, Shelikof Strait	AK
98747	Black Cape, Shelikof Strait (depth 55 ft), Alaska Current	NOS	KOD0936_7	58.40572	-152.90728	:America/Anchorage	USA	knots	4	187.6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Black Cape, Shelikof Strait	AK
98748	Black Cape, Shelikof Strait (depth 16 ft), Alaska Current	NOS	KOD0936_13	58.40572	-152.90728	:America/Anchorage	USA	knots	20	196.1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Black Cape, Shelikof Strait	AK
98749	Alligator Island, Shelikof Strait (depth 61 ft), Alaska Current	NOS	KOD0937_7	58.46107	-152.82645	:America/Anchorage	USA	knots	\N	224.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alligator Island, Shelikof Strait	AK
98750	Alligator Island, Shelikof Strait (depth 15 ft), Alaska Current	NOS	KOD0937_14	58.46107	-152.82645	:America/Anchorage	USA	knots	35	236.2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alligator Island, Shelikof Strait	AK
98751	Lighthouse Point, Shuyak Island (depth 188 ft), Alaska Current	NOS	KOD0938_12	58.48523	-152.67029	:America/Anchorage	USA	knots	\N	252	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lighthouse Point, Shuyak Island	AK
98752	Lighthouse Point, Shuyak Island (depth 70 ft), Alaska Current	NOS	KOD0938_24	58.48523	-152.67029	:America/Anchorage	USA	knots	61	242	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lighthouse Point, Shuyak Island	AK
98753	Cape Current Narrows, Shuyak Strait (depth 99 ft), Alaska Current	NOS	KOD0939_1	58.46688	-152.49512	:America/Anchorage	USA	knots	102	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Current Narrows, Shuyak Strait	AK
98754	Cape Current Narrows, Shuyak Strait (depth 57 ft), Alaska Current	NOS	KOD0939_14	58.46688	-152.49512	:America/Anchorage	USA	knots	96	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Current Narrows, Shuyak Strait	AK
98755	Cape Current Narrows, Shuyak Strait (depth 14 ft), Alaska Current	NOS	KOD0939_27	58.46688	-152.49512	:America/Anchorage	USA	knots	93	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Current Narrows, Shuyak Strait	AK
98756	East Shuyak Strait entrance (depth 134 ft), Alaska Current	NOS	KOD0940_11	58.4579	-152.42785	:America/Anchorage	USA	knots	\N	197.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Shuyak Strait Entrance	AK
98757	East Shuyak Strait entrance (depth 25 ft), Alaska Current	NOS	KOD0940_22	58.4579	-152.42785	:America/Anchorage	USA	knots	110	140	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	East Shuyak Strait Entrance	AK
98758	Tonki Cape, east of (depth 138 ft), Marmot Strait, Alaska Current	NOS	KOD0941_1	58.34598	-151.91508	:America/Anchorage	USA	knots	164	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tonki Cape, east of	AK
98759	Tonki Cape, east of (depth 85 ft), Marmot Strait, Alaska Current	NOS	KOD0941_9	58.34598	-151.91508	:America/Anchorage	USA	knots	160	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tonki Cape, east of	AK
98760	Tonki Cape, east of (depth 26 ft), Marmot Strait, Alaska Current	NOS	KOD0941_18	58.34598	-151.91508	:America/Anchorage	USA	knots	156	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tonki Cape, east of	AK
98761	Marmot Island, west of (depth 169 ft), Marmot Strait, Alaska Current	NOS	KOD0942_1	58.24443	-151.93232	:America/Anchorage	USA	knots	186	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marmot Island, west of	AK
98762	Marmot Island, west of (depth 97 ft), Marmot Strait, Alaska Current	NOS	KOD0942_12	58.24443	-151.93232	:America/Anchorage	USA	knots	191	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marmot Island, west of	AK
98763	Marmot Island, west of (depth 24 ft), Marmot Strait, Alaska Current	NOS	KOD0942_23	58.24443	-151.93232	:America/Anchorage	USA	knots	194	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marmot Island, west of	AK
98764	Marmot Island, southwest of (depth 180 ft), Marmot Strait, Alaska Current	NOS	KOD0943_1	58.17085	-151.96862	:America/Anchorage	USA	knots	206	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marmot Island, southwest of	AK
98765	Marmot Island, southwest of (depth 101 ft), Marmot Strait, Alaska Current	NOS	KOD0943_13	58.17085	-151.96862	:America/Anchorage	USA	knots	207	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marmot Island, southwest of	AK
98766	Marmot Island, southwest of (depth 22 ft), Marmot Strait, Alaska Current	NOS	KOD0943_25	58.17085	-151.96862	:America/Anchorage	USA	knots	209	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marmot Island, southwest of	AK
98767	North of Perevalnie Island, Shuyak Island (depth 144 ft), Alaska Current	NOS	KOD0944_1	58.65111	-152.39663	:America/Anchorage	USA	knots	74	274	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North of Perevalnie Island, Shuyak Island	AK
98768	North of Perevalnie Island, Shuyak Island (depth 85 ft), Alaska Current	NOS	KOD0944_10	58.65111	-152.39663	:America/Anchorage	USA	knots	89	274	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North of Perevalnie Island, Shuyak Island	AK
98769	North of Perevalnie Island, Shuyak Island (depth 20 ft), Alaska Current	NOS	KOD0944_20	58.65111	-152.39663	:America/Anchorage	USA	knots	89	269	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.277	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North of Perevalnie Island, Shuyak Island	AK
98770	The Race (depth 45 ft), Long Island Sound, New York Current	NOS	LIS1001_1	41.22818	-72.06252	:America/New_York	USA	knots	105	295	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Race	NY
98771	The Race (depth 25 ft), Long Island Sound, New York Current	NOS	LIS1001_7	41.22818	-72.06252	:America/New_York	USA	knots	108	292	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Race	NY
98772	The Race (depth 6 ft), Long Island Sound, New York Current	NOS	LIS1001_13	41.22818	-72.06252	:America/New_York	USA	knots	106	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.39	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Race	NY
98773	Wicopesset island, NE of (depth 44 ft), Block Island Sound, Rhode Island Current	NOS	LIS1002_1	41.29841	-71.90096	:America/New_York	USA	knots	141	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wicopesset island, NE of	RI
98774	Wicopesset island, NE of (depth 25 ft), Block Island Sound, Rhode Island Current	NOS	LIS1002_7	41.29841	-71.90096	:America/New_York	USA	knots	132	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wicopesset island, NE of	RI
98775	Wicopesset island, NE of (depth 8 ft), Block Island Sound, Rhode Island Current	NOS	LIS1002_12	41.29841	-71.90096	:America/New_York	USA	knots	125	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.298	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wicopesset island, NE of	RI
98776	Thames River approach (depth 35 ft), Long Island Sound, Connecticut Current	NOS	LIS1003_1	41.29387	-72.07842	:America/New_York	USA	knots	51	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thames River Approach	CT
98777	Thames River approach (depth 15 ft), Long Island Sound, Connecticut Current	NOS	LIS1003_7	41.29387	-72.07842	:America/New_York	USA	knots	65	271	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thames River Approach	CT
98778	Thames River approach (depth 5 ft), Long Island Sound, Connecticut Current	NOS	LIS1003_10	41.29387	-72.07842	:America/New_York	USA	knots	71	268	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thames River Approach	CT
98779	New London Harbor entrance (depth 31 ft), Long Island Sound, Connecticut Current	NOS	LIS1004_1	41.31875	-72.08173	:America/New_York	USA	knots	\N	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London Harbor entrance	CT
98780	New London Harbor entrance (depth 15 ft), Long Island Sound, Connecticut Current	NOS	LIS1004_6	41.31875	-72.08173	:America/New_York	USA	knots	\N	335	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London Harbor entrance	CT
98781	New London Harbor entrance (depth 2 ft), Long Island Sound, Connecticut Current	NOS	LIS1004_10	41.31875	-72.08173	:America/New_York	USA	knots	167	316	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London Harbor entrance	CT
98782	Fort Trumbull State Park (depth 31 ft), Long Island Sound, Connecticut Current	NOS	LIS1005_1	41.34544	-72.08629	:America/New_York	USA	knots	\N	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.112	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Trumbull State Park	CT
98783	Fort Trumbull State Park (depth 14 ft), Long Island Sound, Connecticut Current	NOS	LIS1005_6	41.34544	-72.08629	:America/New_York	USA	knots	\N	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Trumbull State Park	CT
98784	Fort Trumbull State Park (depth 5 ft), Long Island Sound, Connecticut Current	NOS	LIS1005_9	41.34544	-72.08629	:America/New_York	USA	knots	169	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Trumbull State Park	CT
98785	New London State Pier (depth 57 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1006_1	41.35728	-72.08673	:America/New_York	USA	knots	164	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London State Pier	CT
98786	New London State Pier (depth 31 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1006_9	41.35728	-72.08673	:America/New_York	USA	knots	172	351	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London State Pier	CT
98787	New London State Pier (depth 14 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1006_14	41.35728	-72.08673	:America/New_York	USA	knots	178	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New London State Pier	CT
98788	US Coast Guard Academy (depth 32 ft), Long Island Sound, Connecticut Current	NOS	LIS1007_1	41.37373	-72.0895	:America/New_York	USA	knots	184	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	U.S. Coast Guard Academy	CT
98789	US Coast Guard Academy (depth 16 ft), Long Island Sound, Connecticut Current	NOS	LIS1007_6	41.37373	-72.0895	:America/New_York	USA	knots	179	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	U.S. Coast Guard Academy	CT
98790	US Coast Guard Academy (depth 9 ft), Long Island Sound, Connecticut Current	NOS	LIS1007_8	41.37373	-72.0895	:America/New_York	USA	knots	182	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	U.S. Coast Guard Academy	CT
98791	Smith Cove (depth 31 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1008_1	41.39658	-72.09592	:America/New_York	USA	knots	179	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Cove	CT
98792	Smith Cove (depth 14 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1008_6	41.39658	-72.09592	:America/New_York	USA	knots	184	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Cove	CT
98793	Smith Cove (depth 5 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1008_9	41.39658	-72.09592	:America/New_York	USA	knots	181	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.222	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Cove	CT
98794	Allyn Point (depth 19 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1009_1	41.44296	-72.0856	:America/New_York	USA	knots	184	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allyn Point	CT
98795	Allyn Point (depth 12 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1009_5	41.44296	-72.0856	:America/New_York	USA	knots	182	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allyn Point	CT
98796	Allyn Point (depth 4 ft), Thames River, Long Island Sound, Connecticut Current	NOS	LIS1009_10	41.44296	-72.0856	:America/New_York	USA	knots	195	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allyn Point	CT
98797	Great Gull Island, SW of (depth 29 ft), Long Island Sound, New York Current	NOS	LIS1010_1	41.19444	-72.13363	:America/New_York	USA	knots	164	332	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Gull Island, SW of	NY
98798	Great Gull Island, SW of (depth 16 ft), Long Island Sound, New York Current	NOS	LIS1010_9	41.19444	-72.13363	:America/New_York	USA	knots	157	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.144	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Gull Island, SW of	NY
98799	Great Gull Island, SW of (depth 3 ft), Long Island Sound, New York Current	NOS	LIS1010_17	41.19444	-72.13363	:America/New_York	USA	knots	147	320	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.294	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Great Gull Island, SW of	NY
98800	Plum Island, 3 nmi north of, Buoy PI (depth 131 ft), Long Island Sound, New York Current	NOS	LIS1011_1	41.22245	-72.17709	:America/New_York	USA	knots	82	253	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.167	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Island, 3nm. North of, Buoy PI	NY
98801	Plum Island, 3 nmi north of, Buoy PI (depth 79 ft), Long Island Sound, New York Current	NOS	LIS1011_9	41.22245	-72.17709	:America/New_York	USA	knots	79	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Island, 3nm. North of, Buoy PI	NY
98802	Plum Island, 3 nmi north of, Buoy PI (depth 20 ft), Long Island Sound, New York Current	NOS	LIS1011_18	41.22245	-72.17709	:America/New_York	USA	knots	81	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.303	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Island, 3nm. North of, Buoy PI	NY
98803	Plum Gut (depth 158 ft), Long Island Sound, New York Current	NOS	LIS1012_1	41.15917	-72.2075	:America/New_York	USA	knots	121	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Gut	NY
98804	Plum Gut (depth 99 ft), Long Island Sound, New York Current	NOS	LIS1012_10	41.15917	-72.2075	:America/New_York	USA	knots	124	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.177	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Gut	NY
98805	Plum Gut (depth 25 ft), Long Island Sound, New York Current	NOS	LIS1012_21	41.15917	-72.2075	:America/New_York	USA	knots	116	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 26.4 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.392	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Plum Gut	NY
98806	Saybrook Breakwater Light (depth 19 ft), Long Island Sound, Connecticut Current	NOS	LIS1013_1	41.2582	-72.34207	:America/New_York	USA	knots	104	287	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saybrook Breakwater Light	CT
98807	Saybrook Breakwater Light (depth 14 ft), Long Island Sound, Connecticut Current	NOS	LIS1013_4	41.2582	-72.34207	:America/New_York	USA	knots	105	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saybrook Breakwater Light	CT
98808	Saybrook Breakwater Light (depth 5 ft), Long Island Sound, Connecticut Current	NOS	LIS1013_10	41.2582	-72.34207	:America/New_York	USA	knots	103	249	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saybrook Breakwater Light	CT
98809	I-95 Bridge (depth 23 ft), Connecticut River, Long Island Sound, Connecticut Current	NOS	LIS1014_1	41.3182	-72.34583	:America/New_York	USA	knots	182	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-95 Bridge	CT
98810	I-95 Bridge (depth 14 ft), Connecticut River, Long Island Sound, Connecticut Current	NOS	LIS1014_6	41.3182	-72.34583	:America/New_York	USA	knots	169	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-95 Bridge	CT
98811	I-95 Bridge (depth 3 ft), Connecticut River, Long Island Sound, Connecticut Current	NOS	LIS1014_13	41.3182	-72.34583	:America/New_York	USA	knots	166	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.447	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-95 Bridge	CT
98812	Saybrook Channel (depth 13 ft), Connecticut River, Long Island Sound, Connecticut Current	NOS	LIS1015_1	41.2833	-72.34757	:America/New_York	USA	knots	186	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saybrook Channel	CT
98813	Saybrook Channel (depth 2 ft), Connecticut River, Long Island Sound, Connecticut Current	NOS	LIS1015_8	41.2833	-72.34757	:America/New_York	USA	knots	180	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.343	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saybrook Channel	CT
98814	Cornfield Point, 4 mi south of, Buoy CF (depth 124 ft), New York Current	NOS	LIS1016_1	41.18945	-72.3696	:America/New_York	USA	knots	69	240	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cornfield Point, 4 miles south of, Buoy CF	NY
98815	Cornfield Point, 4 mi south of, Buoy CF (depth 71 ft), New York Current	NOS	LIS1016_9	41.18945	-72.3696	:America/New_York	USA	knots	67	244	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cornfield Point, 4 miles south of, Buoy CF	NY
98816	Cornfield Point, 4 mi south of, Buoy CF (depth 19 ft), New York Current	NOS	LIS1016_17	41.18945	-72.3696	:America/New_York	USA	knots	65	245	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.193	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cornfield Point, 4 miles south of, Buoy CF	NY
98817	Six Mile Reef, 2 mi south of, Buoy TE (depth 88 ft), Long Island Sound, New York Current	NOS	LIS1017_1	41.1345	-72.48927	:America/New_York	USA	knots	82	247	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.172	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six Mile Reef, 2 miles south of, Buoy TE	NY
98818	Six Mile Reef, 2 mi south of, Buoy TE (depth 49 ft), Long Island Sound, New York Current	NOS	LIS1017_7	41.1345	-72.48927	:America/New_York	USA	knots	74	252	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six Mile Reef, 2 miles south of, Buoy TE	NY
98819	Six Mile Reef, 2 mi south of, Buoy TE (depth 16 ft), Long Island Sound, New York Current	NOS	LIS1017_12	41.1345	-72.48927	:America/New_York	USA	knots	73	255	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six Mile Reef, 2 miles south of, Buoy TE	NY
98820	Six Mile Reef, 1 mi south of (depth 58 ft), Long Island Sound, New York Current	NOS	LIS1018_1	41.16835	-72.4994	:America/New_York	USA	knots	73	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six mile Reef, 1 mile south of	NY
98821	Six Mile Reef, 1 mi south of (depth 35 ft), Long Island Sound, New York Current	NOS	LIS1018_8	41.16835	-72.4994	:America/New_York	USA	knots	75	257	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six mile Reef, 1 mile south of	NY
98822	Six Mile Reef, 1 mi south of (depth 15 ft), Long Island Sound, New York Current	NOS	LIS1018_14	41.16835	-72.4994	:America/New_York	USA	knots	77	250	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six mile Reef, 1 mile south of	NY
98823	Six Mile Reef, 1 mi west of (depth 36 ft), Long Island Sound, Connecticut Current	NOS	LIS1019_1	41.17973	-72.55177	:America/New_York	USA	knots	87	278	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six Mile Reef, 1 mile west of	CT
98824	Six Mile Reef, 1 mi west of (depth 26 ft), Long Island Sound, Connecticut Current	NOS	LIS1019_4	41.17973	-72.55177	:America/New_York	USA	knots	86	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six Mile Reef, 1 mile west of	CT
98825	Six Mile Reef, 1 mi west of (depth 13 ft), Long Island Sound, Connecticut Current	NOS	LIS1019_8	41.17973	-72.55177	:America/New_York	USA	knots	87	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Six Mile Reef, 1 mile west of	CT
98826	Roanoke Point, 2 mi NE of (depth 62 ft), Long Island Sound, New York Current	NOS	LIS1020_1	41.00697	-72.66322	:America/New_York	USA	knots	103	287	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roanoke Point, 2 miles NE of	NY
98827	Roanoke Point, 2 mi NE of (depth 39 ft), Long Island Sound, New York Current	NOS	LIS1020_8	41.00697	-72.66322	:America/New_York	USA	knots	106	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roanoke Point, 2 miles NE of	NY
98828	Roanoke Point, 2 mi NE of (depth 16 ft), Long Island Sound, New York Current	NOS	LIS1020_15	41.00697	-72.66322	:America/New_York	USA	knots	93	271	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roanoke Point, 2 miles NE of	NY
98829	Branford Reef, 5.0 mi south of (depth 69 ft), Long Island Sound, Connecticut Current	NOS	LIS1021_1	41.14443	-72.82798	:America/New_York	USA	knots	106	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Branford Reef, 5.0 miles south of	CT
98830	Branford Reef, 5.0 mi south of (depth 39 ft), Long Island Sound, Connecticut Current	NOS	LIS1021_10	41.14443	-72.82798	:America/New_York	USA	knots	96	273	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Branford Reef, 5.0 miles south of	CT
98831	Branford Reef, 5.0 mi south of (depth 6 ft), Long Island Sound, Connecticut Current	NOS	LIS1021_20	41.14443	-72.82798	:America/New_York	USA	knots	84	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Branford Reef, 5.0 miles south of	CT
98832	New Haven Harbor, Tanker Terminal (depth 30 ft), Long Island Sound, Connecticut Current	NOS	LIS1022_1	41.29507	-72.909	:America/New_York	USA	knots	\N	19	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor, Tanker Terminal	CT
98833	New Haven Harbor, Tanker Terminal (depth 21 ft), Long Island Sound, Connecticut Current	NOS	LIS1022_4	41.29507	-72.909	:America/New_York	USA	knots	209	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor, Tanker Terminal	CT
98834	New Haven Harbor, Tanker Terminal (depth 11 ft), Long Island Sound, Connecticut Current	NOS	LIS1022_7	41.29507	-72.909	:America/New_York	USA	knots	218	33.6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor, Tanker Terminal	CT
98835	New Haven Harbor entrance (depth 31 ft), Long Island Sound, Connecticut Current	NOS	LIS1023_1	41.22238	-72.90932	:America/New_York	USA	knots	106	295	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor entrance	CT
98836	New Haven Harbor entrance (depth 14 ft), Long Island Sound, Connecticut Current	NOS	LIS1023_6	41.22238	-72.90932	:America/New_York	USA	knots	117	288	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor entrance	CT
98837	New Haven Harbor entrance (depth 4 ft), Long Island Sound, Connecticut Current	NOS	LIS1023_9	41.22238	-72.90932	:America/New_York	USA	knots	122	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor entrance	CT
98838	New Haven Harbor, Gateway Terminal approach (depth 31 ft), Connecticut Current	NOS	LIS1024_1	41.28267	-72.91197	:America/New_York	USA	knots	\N	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor, Gateway Terminal Approach	CT
98839	New Haven Harbor, Gateway Terminal approach (depth 18 ft), Connecticut Current	NOS	LIS1024_5	41.28267	-72.91197	:America/New_York	USA	knots	\N	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor, Gateway Terminal Approach	CT
98840	New Haven Harbor, Gateway Terminal approach (depth 8 ft), Connecticut Current	NOS	LIS1024_8	41.28267	-72.91197	:America/New_York	USA	knots	\N	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Haven Harbor, Gateway Terminal Approach	CT
98841	Port Jefferson Harbor entrance (depth 31 ft), Long Island Sound, New York Current	NOS	LIS1025_1	40.9699	-73.09165	:America/New_York	USA	knots	1	154	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.144	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Jefferson Harbor entrance	NY
98842	Port Jefferson Harbor entrance (depth 15 ft), Long Island Sound, New York Current	NOS	LIS1025_11	40.9699	-73.09165	:America/New_York	USA	knots	342	149	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Jefferson Harbor entrance	NY
98843	Port Jefferson Harbor entrance (depth 3 ft), Long Island Sound, New York Current	NOS	LIS1025_18	40.9699	-73.09165	:America/New_York	USA	knots	336	150	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Jefferson Harbor entrance	NY
98844	Stratford Point, 3.5 mi south of (depth 43 ft), Long Island Sound, Connecticut Current	NOS	LIS1026_1	41.08998	-73.10452	:America/New_York	USA	knots	67	249	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stratford Point, 3.5 miles south of	CT
98845	Stratford Point, 3.5 mi south of (depth 16 ft), Long Island Sound, Connecticut Current	NOS	LIS1026_9	41.08998	-73.10452	:America/New_York	USA	knots	71	251	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stratford Point, 3.5 miles south of	CT
98846	Stratford Point, 3.5 mi south of (depth 6 ft), Long Island Sound, Connecticut Current	NOS	LIS1026_12	41.08998	-73.10452	:America/New_York	USA	knots	70	247	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stratford Point, 3.5 miles south of	CT
98847	Stratford Shoal, 2 mi south of (depth 114 ft), Long Island Sound, New York Current	NOS	LIS1027_1	41.02297	-73.10477	:America/New_York	USA	knots	99	261	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stratford Shoal, 2 miles south of	NY
98848	Stratford Shoal, 2 mi south of (depth 68 ft), Long Island Sound, New York Current	NOS	LIS1027_8	41.02297	-73.10477	:America/New_York	USA	knots	93	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stratford Shoal, 2 miles south of	NY
98849	Stratford Shoal, 2 mi south of (depth 22 ft), Long Island Sound, New York Current	NOS	LIS1027_15	41.02297	-73.10477	:America/New_York	USA	knots	79	272	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stratford Shoal, 2 miles south of	NY
98850	Bridgeport Harbor, Tongue Point (depth 30 ft), Long Island Sound, Connecticut Current	NOS	LIS1028_1	41.16668	-73.17533	:America/New_York	USA	knots	\N	40	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport Harbor, Tongue Point	CT
98851	Bridgeport Harbor, Tongue Point (depth 15 ft), Long Island Sound, Connecticut Current	NOS	LIS1028_10	41.16668	-73.17533	:America/New_York	USA	knots	\N	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport Harbor, Tongue Point	CT
98852	Bridgeport Harbor, Tongue Point (depth 4 ft), Long Island Sound, Connecticut Current	NOS	LIS1028_17	41.16668	-73.17533	:America/New_York	USA	knots	\N	44.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport Harbor, Tongue Point	CT
98853	Bridgeport Harbor entrance (depth 31 ft), Long Island Sound, Connecticut Current	NOS	LIS1029_1	41.12138	-73.18945	:America/New_York	USA	knots	62	254	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport Harbor Entrance	CT
98854	Bridgeport Harbor entrance (depth 15 ft), Long Island Sound, Connecticut Current	NOS	LIS1029_11	41.12138	-73.18945	:America/New_York	USA	knots	58	256	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport Harbor Entrance	CT
98855	Bridgeport Harbor entrance (depth 5 ft), Long Island Sound, Connecticut Current	NOS	LIS1029_17	41.12138	-73.18945	:America/New_York	USA	knots	58	256	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bridgeport Harbor Entrance	CT
98856	Eatons Neck, 2.5 mi east of (depth 41 ft), Long Island Sound, New York Current	NOS	LIS1030_1	40.95742	-73.34198	:America/New_York	USA	knots	122	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck, 2.5 miles east of	NY
98857	Eatons Neck, 2.5 mi east of (depth 18 ft), Long Island Sound, New York Current	NOS	LIS1030_8	40.95742	-73.34198	:America/New_York	USA	knots	128	279	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck, 2.5 miles east of	NY
98858	Eatons Neck, 2.5 mi east of (depth 5 ft), Long Island Sound, New York Current	NOS	LIS1030_12	40.95742	-73.34198	:America/New_York	USA	knots	125	276	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck, 2.5 miles east of	NY
98859	Norwalk Harbor (depth 11 ft), Long Island Sound, Connecticut Current	NOS	LIS1031_1	41.08535	-73.4024	:America/New_York	USA	knots	151	329	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Norwalk Harbor	CT
98860	Norwalk Harbor (depth 2 ft), Long Island Sound, Connecticut Current	NOS	LIS1031_6	41.08535	-73.4024	:America/New_York	USA	knots	148	339	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Norwalk Harbor	CT
98861	Eatons Neck, 3 mi north of (depth 92 ft), Long Island Sound, Connecticut Current	NOS	LIS1032_1	41.00505	-73.405	:America/New_York	USA	knots	83	249	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck, 3 miles north of	CT
98862	Eatons Neck, 3 mi north of (depth 49 ft), Long Island Sound, Connecticut Current	NOS	LIS1032_14	41.00505	-73.405	:America/New_York	USA	knots	80	264	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck, 3 miles north of	CT
98863	Eatons Neck, 3 mi north of (depth 10 ft), Long Island Sound, Connecticut Current	NOS	LIS1032_26	41.00505	-73.405	:America/New_York	USA	knots	76	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eatons Neck, 3 miles north of	CT
98864	The Cows, 2 mi SE of (depth 86 ft), Long Island Sound, Connecticut Current	NOS	LIS1033_1	40.98858	-73.49582	:America/New_York	USA	knots	81	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Cows, 2 miles SE of	CT
98865	The Cows, 2 mi SE of (depth 47 ft), Long Island Sound, Connecticut Current	NOS	LIS1033_7	40.98858	-73.49582	:America/New_York	USA	knots	80	253	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Cows, 2 miles SE of	CT
98866	The Cows, 2 mi SE of (depth 14 ft), Long Island Sound, Connecticut Current	NOS	LIS1033_12	40.98858	-73.49582	:America/New_York	USA	knots	72	243	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Cows, 2 miles SE of	CT
98867	Stamford Harbor entrance (depth 14 ft), Long Island Sound, Connecticut Current	NOS	LIS1034_1	41.01535	-73.53695	:America/New_York	USA	knots	174	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stamford Harbor entrance	CT
98868	Stamford Harbor entrance (depth 3 ft), Long Island Sound, Connecticut Current	NOS	LIS1034_8	41.01535	-73.53695	:America/New_York	USA	knots	175	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Stamford Harbor entrance	CT
98869	Matinecock Point, 1.7 mi northwest of (depth 46 ft), Long Island Sound, New York Current	NOS	LIS1035_1	40.92455	-73.65585	:America/New_York	USA	knots	72	251	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matinecock Point, 1.7 miles northwest of	NY
98870	Matinecock Point, 1.7 mi northwest of (depth 30 ft), Long Island Sound, New York Current	NOS	LIS1035_6	40.92455	-73.65585	:America/New_York	USA	knots	63	244	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matinecock Point, 1.7 miles northwest of	NY
98871	Matinecock Point, 1.7 mi northwest of (depth 10 ft), Long Island Sound, New York Current	NOS	LIS1035_12	40.92455	-73.65585	:America/New_York	USA	knots	55	233	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matinecock Point, 1.7 miles northwest of	NY
98872	Execution Rocks (depth 96 ft), Long Island Sound, New York Current	NOS	LIS1036_1	40.87325	-73.7334	:America/New_York	USA	knots	219	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Execution Rocks	NY
98873	Execution Rocks (depth 50 ft), Long Island Sound, New York Current	NOS	LIS1036_8	40.87325	-73.7334	:America/New_York	USA	knots	232	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Execution Rocks	NY
98874	Execution Rocks (depth 11 ft), Long Island Sound, New York Current	NOS	LIS1036_14	40.87325	-73.7334	:America/New_York	USA	knots	232	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Execution Rocks	NY
98875	Hart Island, southeast of (depth 98 ft), Long Island Sound, New York Current	NOS	LIS1037_1	40.8432	-73.76225	:America/New_York	USA	knots	189	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.126	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hart Island, southeast of	NY
98876	Hart Island, southeast of (depth 59 ft), Long Island Sound, New York Current	NOS	LIS1037_7	40.8432	-73.76225	:America/New_York	USA	knots	194	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hart Island, southeast of	NY
98877	Hart Island, southeast of (depth 13 ft), Long Island Sound, New York Current	NOS	LIS1037_14	40.8432	-73.76225	:America/New_York	USA	knots	201	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hart Island, southeast of	NY
98878	Throgs Neck Bridge (depth 59 ft), Long Island Sound, New York Current	NOS	LIS1038_1	40.80105	-73.7921	:America/New_York	USA	knots	289	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Throgs Neck Bridge	NY
98879	Throgs Neck Bridge (depth 36 ft), Long Island Sound, New York Current	NOS	LIS1038_8	40.80105	-73.7921	:America/New_York	USA	knots	268	105	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Throgs Neck Bridge	NY
98880	Throgs Neck Bridge (depth 14 ft), Long Island Sound, New York Current	NOS	LIS1038_15	40.80105	-73.7921	:America/New_York	USA	knots	262	106	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Throgs Neck Bridge	NY
98881	Lake Worth Inlet entrance (depth 28 ft), Florida Current	NOS	LWI0901_1	26.77298	-80.0362	:America/New_York	USA	knots	85	268	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth Inlet Entrance	FL
98882	Lake Worth Inlet entrance (depth 15 ft), Florida Current	NOS	LWI0901_5	26.77298	-80.0362	:America/New_York	USA	knots	86	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth Inlet Entrance	FL
98883	Lake Worth Inlet entrance (depth 5 ft), Florida Current	NOS	LWI0901_8	26.77298	-80.0362	:America/New_York	USA	knots	92	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.172	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Worth Inlet Entrance	FL
98884	North Turning Basin (depth 8 ft), Lake Worth Inlet, Florida Current	NOS	LWI0904_1	26.77126	-80.0504	:America/New_York	USA	knots	168	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Turning Basin	FL
98885	North Turning Basin (depth 3 ft), Lake Worth Inlet, Florida Current	NOS	LWI0904_4	26.77126	-80.0504	:America/New_York	USA	knots	170	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Turning Basin	FL
98886	South Jetty (depth 38 ft), Government Cut, Miami Harbor, Florida Current	NOS	MIH0802_1	25.760429	-80.126877	:America/New_York	USA	knots	115	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Jetty	FL
98887	South Jetty (depth 15 ft), Government Cut, Miami Harbor, Florida Current	NOS	MIH0802_8	25.760429	-80.126877	:America/New_York	USA	knots	117	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Jetty	FL
98888	South Jetty (depth 9 ft), Government Cut, Miami Harbor, Florida Current	NOS	MIH0802_10	25.760429	-80.126877	:America/New_York	USA	knots	118	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Jetty	FL
98889	West entrance, south side (depth 34 ft), Government Cut, Miami Harbor, Florida Current	NOS	MIH0804_1	25.7646	-80.137428	:America/New_York	USA	knots	90	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West entrance, south side	FL
98890	West entrance, south side (depth 14 ft), Government Cut, Miami Harbor, Florida Current	NOS	MIH0804_7	25.7646	-80.137428	:America/New_York	USA	knots	94	289	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.408	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West entrance, south side	FL
98891	West entrance, south side (depth 4 ft), Government Cut, Miami Harbor, Florida Current	NOS	MIH0804_10	25.7646	-80.137428	:America/New_York	USA	knots	97	290	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.385	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West entrance, south side	FL
98892	Fisher Island Turning Basin (depth 36 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0805_1	25.767771	-80.143417	:America/New_York	USA	knots	111	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fisher Island Turning Basin	FL
98893	Fisher Island Turning Basin (depth 16 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0805_7	25.767771	-80.143417	:America/New_York	USA	knots	119	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fisher Island Turning Basin	FL
98894	Fisher Island Turning Basin (depth 9 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0805_9	25.767771	-80.143417	:America/New_York	USA	knots	123	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.207	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fisher Island Turning Basin	FL
98895	Pilot House (depth 31 ft), Fishermans Channel, Miami Harbor, Florida Current	NOS	MIH0806_1	25.765779	-80.145821	:America/New_York	USA	knots	85	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilot House	FL
98896	Pilot House (depth 14 ft), Fishermans Channel, Miami Harbor, Florida Current	NOS	MIH0806_6	25.765779	-80.145821	:America/New_York	USA	knots	86	255	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilot House	FL
98897	Pilot House (depth 5 ft), Fishermans Channel, Miami Harbor, Florida Current	NOS	MIH0806_9	25.765779	-80.145821	:America/New_York	USA	knots	86	255	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.207	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pilot House	FL
98898	Norris Cut (depth 34 ft), Fishermans Channel, Miami Harbor, Florida Current	NOS	MIH0807_1	25.764971	-80.151131	:America/New_York	USA	knots	92	276	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Norris Cut	FL
98899	Norris Cut (depth 14 ft), Fishermans Channel, Miami Harbor, Florida Current	NOS	MIH0807_7	25.764971	-80.151131	:America/New_York	USA	knots	88	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Norris Cut	FL
98900	Norris Cut (depth 7 ft), Fishermans Channel, Miami Harbor, Florida Current	NOS	MIH0807_9	25.764971	-80.151131	:America/New_York	USA	knots	89	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Norris Cut	FL
98901	Main Ship Channel (depth 33 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0808_1	25.77335	-80.156921	:America/New_York	USA	knots	116	292	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Main Ship Channel	FL
98902	Main Ship Channel (depth 16 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0808_6	25.77335	-80.156921	:America/New_York	USA	knots	112	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Main Ship Channel	FL
98903	Main Ship Channel (depth 6 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0808_9	25.77335	-80.156921	:America/New_York	USA	knots	110	295	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Main Ship Channel	FL
98904	Lummus Island, SW corner (depth 14 ft), Fishermans Channel, Miami Harbor, Florida Current	NOS	MIH0809_2	25.765129	-80.161552	:America/New_York	USA	knots	89	269	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lummus Island, SW corner	FL
98905	Lummus Island, SW corner (depth 4 ft), Fishermans Channel, Miami Harbor, Florida Current	NOS	MIH0809_5	25.765129	-80.161552	:America/New_York	USA	knots	91	268	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lummus Island, SW corner	FL
98906	Lummus Island Turning Basin (depth 34 ft), Miami Harbor, Florida Current	NOS	MIH0810_1	25.767651	-80.167747	:America/New_York	USA	knots	60	260.1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lummus Island Turning Basin	FL
98907	Lummus Island Turning Basin (depth 14 ft), Miami Harbor, Florida Current	NOS	MIH0810_7	25.767651	-80.167747	:America/New_York	USA	knots	99	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lummus Island Turning Basin	FL
98908	Lummus Island Turning Basin (depth 7 ft), Miami Harbor, Florida Current	NOS	MIH0810_9	25.767651	-80.167747	:America/New_York	USA	knots	121	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lummus Island Turning Basin	FL
98909	Dodge Island Cut, west end (depth 28 ft), Miami Harbor, Florida Current	NOS	MIH0811_1	25.772949	-80.178497	:America/New_York	USA	knots	77	266	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island Cut, west end	FL
98910	Dodge Island Cut, west end (depth 15 ft), Miami Harbor, Florida Current	NOS	MIH0811_5	25.772949	-80.178497	:America/New_York	USA	knots	89	271	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island Cut, west end	FL
98911	Dodge Island Cut, west end (depth 5 ft), Miami Harbor, Florida Current	NOS	MIH0811_8	25.772949	-80.178497	:America/New_York	USA	knots	85	253	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island Cut, west end	FL
98912	Dodge Island, SE Turning Basin (depth 30 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0812_1	25.78178	-80.180603	:America/New_York	USA	knots	104	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island, SE Turning Basin	FL
98913	Dodge Island, SE Turning Basin (depth 14 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0812_6	25.78178	-80.180603	:America/New_York	USA	knots	119	307	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island, SE Turning Basin	FL
98914	Dodge Island, SE Turning Basin (depth 4 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0812_9	25.78178	-80.180603	:America/New_York	USA	knots	118	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island, SE Turning Basin	FL
98915	Dodge Island, NW Turning Basin (depth 30 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0813_1	25.7855	-80.183952	:America/New_York	USA	knots	\N	317.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island, NW Turning Basin	FL
98916	Dodge Island, NW Turning Basin (depth 17 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0813_5	25.7855	-80.183952	:America/New_York	USA	knots	163	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island, NW Turning Basin	FL
98917	Dodge Island, NW Turning Basin (depth 7 ft), Main Channel, Miami Harbor, Florida Current	NOS	MIH0813_8	25.7855	-80.183952	:America/New_York	USA	knots	173	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.098	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dodge Island, NW Turning Basin	FL
98918	Miami River entrance (depth 12 ft), Miami Harbor, Florida Current	NOS	MIH0814_1	25.77038	-80.187477	:America/New_York	USA	knots	51	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami River Entrance	FL
98919	Miami River entrance (depth 2 ft), Miami Harbor, Florida Current	NOS	MIH0814_7	25.77038	-80.187477	:America/New_York	USA	knots	90	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami River Entrance	FL
98920	Miami Harbor entrance (depth 35 ft), Government Cut, Florida Current	NOS	MIH0901_1	25.76405	-80.13394	:America/New_York	USA	knots	115	292	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami Harbor Entrance	FL
98921	Miami Harbor entrance (depth 22 ft), Government Cut, Florida Current	NOS	MIH0901_5	25.76405	-80.13394	:America/New_York	USA	knots	113	292	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami Harbor Entrance	FL
98922	Miami Harbor entrance (depth 15 ft), Government Cut, Florida Current	NOS	MIH0901_7	25.76405	-80.13394	:America/New_York	USA	knots	113	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami Harbor Entrance	FL
98923	Miami Harbor entrance (depth 8 ft), Government Cut, Florida Current	NOS	MIH0901_9	25.76405	-80.13394	:America/New_York	USA	knots	114	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Miami Harbor Entrance	FL
98924	Mobile Bay entrance, off Mobile Point (depth 11 ft), Alabama Current	NOS	MOB1101_2	30.22703	-88.03458	:America/Chicago	USA	knots	201	14	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mobile Bay Entrance, off Mobile Point	AL
98925	Mobile Bay entrance, off Mobile Point (depth 25 ft), Alabama Current	NOS	MOB1101_10	30.22703	-88.03458	:America/Chicago	USA	knots	198	7	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mobile Bay Entrance, off Mobile Point	AL
98926	Mobile Bay entrance, off Mobile Point (depth 41 ft), Alabama Current	NOS	MOB1101_20	30.22703	-88.03458	:America/Chicago	USA	knots	205	357	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mobile Bay Entrance, off Mobile Point	AL
98927	Petit Bois Island, Dauphin Island, between (depth 5 ft), Alabama Current	NOS	MOB1104_3	30.22178	-88.3708	:America/Chicago	USA	knots	172	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Petit Bois Island, Dauphin Island, between	AL
98928	Horn Island, Petit Bois Island, between (depth 7 ft), Mississippi Current	NOS	MOB1105_3	30.22569	-88.53994	:America/Chicago	USA	knots	172	48	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horn Island, Petit Bois Island, between	MS
98929	Dauphin Island Causeway (depth 7 ft), Mobile Bay, Alabama Current	NOS	MOB1106_4	30.28926	-88.1287	:America/Chicago	USA	knots	242	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dauphin Island Causeway	AL
98930	Sandy Hook Channel, Front Range Light (depth 31 ft), New York Harbor, New Jersey Current	NOS	NYH1901_1	40.48740005493164	-73.99330139160156	:America/New_York	USA	knots	138	303	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandy Hook Channel, Front Range Light	NJ
98931	Sandy Hook Channel, Front Range Light (depth 15 ft), New York Harbor, New Jersey Current	NOS	NYH1901_6	40.48740005493164	-73.99330139160156	:America/New_York	USA	knots	132	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandy Hook Channel, Front Range Light	NJ
98932	Sandy Hook Channel, Front Range Light (depth 5 ft), New York Harbor, New Jersey Current	NOS	NYH1901_9	40.48740005493164	-73.99330139160156	:America/New_York	USA	knots	122	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.348	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sandy Hook Channel, Front Range Light	NJ
98933	Chapel Hill Channel, south end (depth 7 ft), Sandy Hook Bay, New Jersey Current	NOS	NYH1902_1	40.475799560546875	-74.04969787597656	:America/New_York	USA	knots	57	254	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chapel Hill Channel, South End	NJ
98934	Chapel Hill Channel, south end (depth 18 ft), Sandy Hook Bay, New Jersey Current	NOS	NYH1902_4	40.475799560546875	-74.04969787597656	:America/New_York	USA	knots	49	257	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chapel Hill Channel, South End	NJ
98935	Chapel Hill Channel, south end (depth 21 ft), Sandy Hook Bay, New Jersey Current	NOS	NYH1902_5	40.475799560546875	-74.04969787597656	:America/New_York	USA	knots	48	262	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chapel Hill Channel, South End	NJ
98936	Ambrose Channel (depth 28 ft), New York Harbor entrance, New Jersey Current	NOS	NYH1903_1	40.516700744628906	-73.97470092773438	:America/New_York	USA	knots	119	290	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ambrose Channel	NJ
98937	Ambrose Channel (depth 15 ft), New York Harbor entrance, New Jersey Current	NOS	NYH1903_9	40.516700744628906	-73.97470092773438	:America/New_York	USA	knots	121	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.242	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ambrose Channel	NJ
98938	Ambrose Channel (depth 5 ft), New York Harbor entrance, New Jersey Current	NOS	NYH1903_15	40.516700744628906	-73.97470092773438	:America/New_York	USA	knots	118	299	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.364	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ambrose Channel	NJ
98939	Rockaway Inlet Jetty, 1 nmi SW of (depth 40 ft), Jamaica Bay, New York Current	NOS	NYH1904_1	40.53300094604492	-73.96080017089844	:America/New_York	USA	knots	120	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockaway Inlet Jetty, 1 nm SW of	NY
98940	Rockaway Inlet Jetty, 1 nmi SW of (depth 17 ft), Jamaica Bay, New York Current	NOS	NYH1904_8	40.53300094604492	-73.96080017089844	:America/New_York	USA	knots	144	307	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockaway Inlet Jetty, 1 nm SW of	NY
98941	Rockaway Inlet Jetty, 1 nmi SW of (depth 7 ft), Jamaica Bay, New York Current	NOS	NYH1904_11	40.53300094604492	-73.96080017089844	:America/New_York	USA	knots	139	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockaway Inlet Jetty, 1 nm SW of	NY
98942	Rockaway Inlet entrance (depth 23 ft), Jamaica Bay, New York Current	NOS	NYH1905_1	40.562198638916016	-73.9365005493164	:America/New_York	USA	knots	243	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockaway Inlet Entrance	NY
98943	Rockaway Inlet entrance (depth 14 ft), Jamaica Bay, New York Current	NOS	NYH1905_6	40.562198638916016	-73.9365005493164	:America/New_York	USA	knots	243	77	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.184	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockaway Inlet Entrance	NY
98944	Rockaway Inlet entrance (depth 5 ft), Jamaica Bay, New York Current	NOS	NYH1905_12	40.562198638916016	-73.9365005493164	:America/New_York	USA	knots	244	79	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rockaway Inlet Entrance	NY
98945	Ward Point Bend (depth 7 ft), Raritan Bay, New York Current	NOS	NYH1906_1	40.493099212646484	-74.25070190429688	:America/New_York	USA	knots	135	309	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ward Point Bend	NY
98946	Ward Point Bend (depth 15 ft), Raritan Bay, New York Current	NOS	NYH1906_3	40.493099212646484	-74.25070190429688	:America/New_York	USA	knots	141	307	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ward Point Bend	NY
98947	Ward Point Bend (depth 28 ft), Raritan Bay, New York Current	NOS	NYH1906_7	40.493099212646484	-74.25070190429688	:America/New_York	USA	knots	145	311	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ward Point Bend	NY
98948	Tremley Point (depth 27 ft), Arthur Kill, New York Current	NOS	NYH1908_2	40.58890151977539	-74.20600128173828	:America/New_York	USA	knots	205	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tremley Point	NY
98949	Tremley Point (depth 7 ft), Arthur Kill, New York Current	NOS	NYH1908_8	40.58890151977539	-74.20600128173828	:America/New_York	USA	knots	211	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tremley Point	NY
98950	Gulfport, Arthur Kill (depth 21 ft), New Jersey Current	NOS	NYH1909_6	40.62889862060547	-74.20320129394531	:America/New_York	USA	knots	202	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulfport, Arthur Kill	NJ
98951	Gulfport, Arthur Kill (depth 8 ft), New Jersey Current	NOS	NYH1909_10	40.62889862060547	-74.20320129394531	:America/New_York	USA	knots	197	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gulfport, Arthur Kill	NJ
98952	Middle Reach, Newark Bay (depth 30 ft), New Jersey Current	NOS	NYH1913_4	40.676300048828125	-74.13520050048828	:America/New_York	USA	knots	210	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Reach, Newark Bay	NJ
98953	Middle Reach, Newark Bay (depth 7 ft), New Jersey Current	NOS	NYH1913_11	40.676300048828125	-74.13520050048828	:America/New_York	USA	knots	197	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Reach, Newark Bay	NJ
98954	Constable Hook approach (depth 35 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1914_1	40.650699615478516	-74.06060028076172	:America/New_York	USA	knots	215	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Constable Hook Approach	NY
98955	Constable Hook approach (depth 15 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1914_7	40.650699615478516	-74.06060028076172	:America/New_York	USA	knots	213	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Constable Hook Approach	NY
98956	Constable Hook approach (depth 9 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1914_9	40.650699615478516	-74.06060028076172	:America/New_York	USA	knots	211	29	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.292	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Constable Hook Approach	NY
98957	Robbins Reef Light, 0.6 nmi E of (depth 11 ft), New York Harbor, New York Current	NOS	NYH1915_2	40.65520095825195	-74.05069732666016	:America/New_York	USA	knots	208	12	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.215	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robbins Reef Light, 0.6 nm E of	NY
98958	Robbins Reef Light, 0.6 nmi E of (depth 24 ft), New York Harbor, New York Current	NOS	NYH1915_6	40.65520095825195	-74.05069732666016	:America/New_York	USA	knots	205	9	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robbins Reef Light, 0.6 nm E of	NY
98959	Robbins Reef Light, 0.6 nmi E of (depth 37 ft), New York Harbor, New York Current	NOS	NYH1915_10	40.65520095825195	-74.05069732666016	:America/New_York	USA	knots	207	14	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.162	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Robbins Reef Light, 0.6 nm E of	NY
98960	Gowanus Bay entrance (depth 28 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1917_1	40.662498474121094	-74.01809692382812	:America/New_York	USA	knots	171	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gowanus Bay Entrance	NY
98961	Gowanus Bay entrance (depth 15 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1917_5	40.662498474121094	-74.01809692382812	:America/New_York	USA	knots	168	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gowanus Bay Entrance	NY
98962	Red Hook Channel (depth 3 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1918_1	40.672298431396484	-74.0239028930664	:America/New_York	USA	knots	167	16	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Hook Channel	NY
98963	Red Hook Channel (depth 21 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1918_6	40.672298431396484	-74.0239028930664	:America/New_York	USA	knots	141	333	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Hook Channel	NY
98964	Red Hook Channel (depth 31 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1918_9	40.672298431396484	-74.0239028930664	:America/New_York	USA	knots	138	326	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Hook Channel	NY
98965	Dimond Reef (depth 11 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1919_3	40.697898864746094	-74.02130126953125	:America/New_York	USA	knots	137	10	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.536	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dimond Reef	NY
98966	Dimond Reef (depth 18 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1919_5	40.697898864746094	-74.02130126953125	:America/New_York	USA	knots	159	11	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.514	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dimond Reef	NY
98967	Dimond Reef (depth 31 ft), Upper Bay, New York Harbor, New York Current	NOS	NYH1919_9	40.697898864746094	-74.02130126953125	:America/New_York	USA	knots	279	23	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.355	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dimond Reef	NY
98968	Brooklyn Bridge (depth 44 ft), East River, New York Current	NOS	NYH1920_1	40.70600128173828	-73.9977035522461	:America/New_York	USA	knots	225	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.105	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Bridge	NY
98969	Brooklyn Bridge (depth 14 ft), East River, New York Current	NOS	NYH1920_10	40.70600128173828	-73.9977035522461	:America/New_York	USA	knots	233	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.109	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Bridge	NY
98970	Brooklyn Bridge (depth 8 ft), East River, New York Current	NOS	NYH1920_12	40.70600128173828	-73.9977035522461	:America/New_York	USA	knots	234	47	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Bridge	NY
98971	Corlears Hook (depth 39 ft), East River, New York Current	NOS	NYH1921_1	40.70949935913086	-73.97640228271484	:America/New_York	USA	knots	250	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Corlears Hook	NY
98972	Corlears Hook (depth 16 ft), East River, New York Current	NOS	NYH1921_8	40.70949935913086	-73.97640228271484	:America/New_York	USA	knots	239	70	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Corlears Hook	NY
98973	Corlears Hook (depth 7 ft), East River, New York Current	NOS	NYH1921_11	40.70949935913086	-73.97640228271484	:America/New_York	USA	knots	237	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Corlears Hook	NY
98974	Newtown Creek (depth 28 ft), East River, New York Current	NOS	NYH1922_1	40.73469924926758	-73.9656982421875	:America/New_York	USA	knots	178	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newtown Creek	NY
98975	Newtown Creek (depth 15 ft), East River, New York Current	NOS	NYH1922_5	40.73469924926758	-73.9656982421875	:America/New_York	USA	knots	180	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newtown Creek	NY
98976	Newtown Creek (depth 5 ft), East River, New York Current	NOS	NYH1922_8	40.73469924926758	-73.9656982421875	:America/New_York	USA	knots	181	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.208	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newtown Creek	NY
98977	Hell Gate (depth 32 ft), East River, New York Current	NOS	NYH1924_1	40.77830123901367	-73.93830108642578	:America/New_York	USA	knots	232	50	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.356	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hell Gate	NY
98978	Hell Gate (depth 15 ft), East River, New York Current	NOS	NYH1924_6	40.77830123901367	-73.93830108642578	:America/New_York	USA	knots	239	46	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.393	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hell Gate	NY
98979	Hell Gate (depth 6 ft), East River, New York Current	NOS	NYH1924_9	40.77830123901367	-73.93830108642578	:America/New_York	USA	knots	241	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.417	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hell Gate	NY
98980	Harlem River, south end (depth 5 ft), New York Current	NOS	NYH1926_5	40.78609848022461	-73.93689727783203	:America/New_York	USA	knots	33	210	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harlem River, south end	NY
98981	Hudson River entrance (depth 43 ft), Hudson River (midchannel), New Jersey Current	NOS	NYH1927_2	40.70759963989258	-74.02529907226562	:America/New_York	USA	knots	184	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.249	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson River Entrance	NJ
98982	Hudson River entrance (depth 23 ft), Hudson River (midchannel), New Jersey Current	NOS	NYH1927_8	40.70759963989258	-74.02529907226562	:America/New_York	USA	knots	185	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson River Entrance	NJ
98983	Hudson River entrance (depth 7 ft), Hudson River (midchannel), New Jersey Current	NOS	NYH1927_13	40.70759963989258	-74.02529907226562	:America/New_York	USA	knots	183	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.396	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson River Entrance	NJ
98984	Hudson River, Pier 92 (depth 35 ft), Hudson River (midchannel), New York Current	NOS	NYH1928_3	40.77069854736328	-74.00279998779297	:America/New_York	USA	knots	209	34	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson River, Pier 92	NY
98985	Hudson River, Pier 92 (depth 19 ft), Hudson River (midchannel), New York Current	NOS	NYH1928_8	40.77069854736328	-74.00279998779297	:America/New_York	USA	knots	211	28	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson River, Pier 92	NY
98986	Hudson River, Pier 92 (depth 6 ft), Hudson River (midchannel), New York Current	NOS	NYH1928_12	40.77069854736328	-74.00279998779297	:America/New_York	USA	knots	212	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.453	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hudson River, Pier 92	NY
98987	Spuyten Duyvil (depth 45 ft), Hudson River (midchannel), New York Current	NOS	NYH1930_3	40.877899169921875	-73.92870330810547	:America/New_York	USA	knots	215	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spuyten Duyvil	NY
98988	Spuyten Duyvil (depth 29 ft), Hudson River (midchannel), New York Current	NOS	NYH1930_8	40.877899169921875	-73.92870330810547	:America/New_York	USA	knots	223	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spuyten Duyvil	NY
98989	Spuyten Duyvil (depth 9 ft), Hudson River (midchannel), New York Current	NOS	NYH1930_14	40.877899169921875	-73.92870330810547	:America/New_York	USA	knots	215	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.246	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spuyten Duyvil	NY
98990	Marine Parkway Bridge, Rockaway Inlet (depth 30 ft), Jamaica Bay, New York Current	NOS	NYH1931_6	40.57149887084961	-73.88369750976562	:America/New_York	USA	knots	266	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marine Parkway Bridge, Rockaway Inlet	NY
98991	Marine Parkway Bridge, Rockaway Inlet (depth 15 ft), Jamaica Bay, New York Current	NOS	NYH1931_15	40.57149887084961	-73.88369750976562	:America/New_York	USA	knots	265	76	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marine Parkway Bridge, Rockaway Inlet	NY
98992	Marine Parkway Bridge, Rockaway Inlet (depth 6 ft), Jamaica Bay, New York Current	NOS	NYH1931_21	40.57149887084961	-73.88369750976562	:America/New_York	USA	knots	257	77	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marine Parkway Bridge, Rockaway Inlet	NY
98993	Raritan River entrance, Victory Bridge (depth 14 ft), New Jersey Current	NOS	NYH1932_9	40.50920104980469	-74.29060363769531	:America/New_York	USA	knots	134	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raritan River Entrance, Victory Bridge	NJ
98994	Raritan River entrance, Victory Bridge (depth 3 ft), New Jersey Current	NOS	NYH1932_16	40.50920104980469	-74.29060363769531	:America/New_York	USA	knots	133	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raritan River Entrance, Victory Bridge	NJ
98995	Highlands Bridge, Shrewsbury River (depth 16 ft), New Jersey Current	NOS	NYH1933_5	40.396400451660156	-73.97979736328125	:America/New_York	USA	knots	357	178	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 67.3 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Highlands Bridge, Shrewsbury River	NJ
98996	Canarsie (midchannel), Jamaica Bay (depth 15 ft), New York Current	NOS	NYH1934_9	40.62699890136719	-73.88200378417969	:America/New_York	USA	knots	252	83	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Canarsie (midchannel), Jamaica Bay	NY
98997	Canarsie (midchannel), Jamaica Bay (depth 5 ft), New York Current	NOS	NYH1934_15	40.62699890136719	-73.88200378417969	:America/New_York	USA	knots	255	85	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Canarsie (midchannel), Jamaica Bay	NY
98998	San Diego Bay entrance (depth 33 ft), California Current	NOS	PCT0031_1	32.68170166015625	-117.2300033569336	:America/Los_Angeles	USA	knots	173	355	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Diego Bay Entrance	CA
98999	Oakland, Yerba Buena Island (depth 13 ft), San Francisco Bay, California Current	NOS	PCT0336_1	37.80979919433594	-122.35070037841797	:America/Los_Angeles	USA	knots	338	167	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.126	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland, Yerba Buena Island	CA
99000	Richmond (depth 14 ft), San Francisco Bay, California Current	NOS	PCT0666_2	37.929298400878906	-122.42500305175781	:America/Los_Angeles	USA	knots	147	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Richmond	CA
99001	Grays Harbor entrance (depth 12 ft), Washington Current	NOS	PCT1291_1	46.92250061035156	-124.13300323486328	:America/Los_Angeles	USA	knots	242	61	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grays Harbor Entrance	WA
99002	Kvichak Bay (off Naknek River entrance) (depth 10 ft), Alaska Current	NOS	PCT5776_1	58.70000076293945	-157.25	:America/Anchorage	USA	knots	239	53	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kvichak Bay (off Naknek River entrance)	AK
99003	Snub Point, Penobscot River (depth 26 ft), Maine Current	NOS	PEB0604_1	44.70945	-68.84107	:America/New_York	USA	knots	176	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snub Point, Penobscot River	ME
99004	Snub Point, Penobscot River (depth 17 ft), Maine Current	NOS	PEB0604_4	44.70945	-68.84107	:America/New_York	USA	knots	179	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snub Point, Penobscot River	ME
99005	Snub Point, Penobscot River (depth 7 ft), Maine Current	NOS	PEB0604_7	44.70945	-68.84107	:America/New_York	USA	knots	182	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.304	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snub Point, Penobscot River	ME
99006	Winterport, Penobscot River (depth 14 ft), Maine Current	NOS	PEB0605_1	44.63132	-68.8424	:America/New_York	USA	knots	210	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.241	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Winterport, Penobscot River	ME
99007	Winterport, Penobscot River (depth 7 ft), Maine Current	NOS	PEB0605_3	44.63132	-68.8424	:America/New_York	USA	knots	212	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Winterport, Penobscot River	ME
99008	Frankfort Flats at Marsh River, Penobscot River (depth 11 ft), Maine Current	NOS	PEB0606_1	44.6049	-68.84673	:America/New_York	USA	knots	109	273	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Frankfort Flats at Marsh River, Penobscot River	ME
99009	Bucksport, Penobscot River (depth 45 ft), Maine Current	NOS	PEB0607_2	44.57132	-68.8077	:America/New_York	USA	knots	123	300	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bucksport, Penobscot River	ME
99010	Bucksport, Penobscot River (depth 32 ft), Maine Current	NOS	PEB0607_4	44.57132	-68.8077	:America/New_York	USA	knots	118	290	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bucksport, Penobscot River	ME
99011	Bucksport, Penobscot River (depth 12 ft), Maine Current	NOS	PEB0607_7	44.57132	-68.8077	:America/New_York	USA	knots	113	292	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.115	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bucksport, Penobscot River	ME
99012	Penobscot Narrows Bridge (depth 36 ft), Maine Current	NOS	PEB0608_1	44.56227	-68.80053	:America/New_York	USA	knots	201	29	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.306	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Penobscot Narrows Bridge	ME
99013	Penobscot Narrows Bridge (depth 26 ft), Maine Current	NOS	PEB0608_4	44.56227	-68.80053	:America/New_York	USA	knots	201	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Penobscot Narrows Bridge	ME
99014	Penobscot Narrows Bridge (depth 13 ft), Maine Current	NOS	PEB0608_8	44.56227	-68.80053	:America/New_York	USA	knots	210	34	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Penobscot Narrows Bridge	ME
99015	Odom Ledge, Penobscot River (depth 29 ft), Maine Current	NOS	PEB0609_4	44.51673	-68.80317	:America/New_York	USA	knots	193	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.363	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Odom Ledge, Penobscot River	ME
99016	Odom Ledge, Penobscot River (depth 16 ft), Maine Current	NOS	PEB0609_6	44.51673	-68.80317	:America/New_York	USA	knots	177	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Odom Ledge, Penobscot River	ME
99017	Fort Point Ledge, Penobscot Bay (depth 71 ft), Maine Current	NOS	PEB0610_1	44.46425	-68.81155	:America/New_York	USA	knots	273	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.377	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point Ledge, Penobscot Bay	ME
99018	Fort Point Ledge, Penobscot Bay (depth 45 ft), Maine Current	NOS	PEB0610_5	44.46425	-68.81155	:America/New_York	USA	knots	258	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.242	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point Ledge, Penobscot Bay	ME
99019	Fort Point Ledge, Penobscot Bay (depth 25 ft), Maine Current	NOS	PEB0610_8	44.46425	-68.81155	:America/New_York	USA	knots	248	53	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point Ledge, Penobscot Bay	ME
99020	Hosmer Ledge, Castine Harbor (depth 52 ft), Maine Current	NOS	PEB0611_1	44.38345	-68.79	:America/New_York	USA	knots	245	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hosmer Ledge, Castine Harbor	ME
99021	Hosmer Ledge, Castine Harbor (depth 33 ft), Maine Current	NOS	PEB0611_4	44.38345	-68.79	:America/New_York	USA	knots	241	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hosmer Ledge, Castine Harbor	ME
99022	Hosmer Ledge, Castine Harbor (depth 13 ft), Maine Current	NOS	PEB0611_7	44.38345	-68.79	:America/New_York	USA	knots	240	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hosmer Ledge, Castine Harbor	ME
99023	Port Everglades entrance (depth 35 ft), Florida Current	NOS	PEV0901_1	26.09318	-80.10549	:America/New_York	USA	knots	77	251	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Everglades Entrance	FL
99024	Port Everglades entrance (depth 22 ft), Florida Current	NOS	PEV0901_5	26.09318	-80.10549	:America/New_York	USA	knots	75	255	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Everglades Entrance	FL
99025	Port Everglades entrance (depth 16 ft), Florida Current	NOS	PEV0901_7	26.09318	-80.10549	:America/New_York	USA	knots	75	257	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Everglades Entrance	FL
99026	Port Everglades entrance (depth 9 ft), Florida Current	NOS	PEV0901_9	26.09318	-80.10549	:America/New_York	USA	knots	77	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Everglades Entrance	FL
99027	Turning Basin (depth 34 ft), Port Everglades, Florida Current	NOS	PEV0902_1	26.09486	-80.11741	:America/New_York	USA	knots	\N	339.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turning Basin	FL
99028	Turning Basin (depth 14 ft), Port Everglades, Florida Current	NOS	PEV0902_7	26.09486	-80.11741	:America/New_York	USA	knots	\N	333.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turning Basin	FL
99029	Turning Basin (depth 4 ft), Port Everglades, Florida Current	NOS	PEV0902_10	26.09486	-80.11741	:America/New_York	USA	knots	173	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turning Basin	FL
99030	17th Street Bridge (depth 12 ft), Port Everglades, Florida Current	NOS	PEV0903_1	26.09973	-80.1191	:America/New_York	USA	knots	184	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	17th Street Bridge	FL
99031	17th Street Bridge (depth 9 ft), Port Everglades, Florida Current	NOS	PEV0903_2	26.09973	-80.1191	:America/New_York	USA	knots	184	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	17th Street Bridge	FL
99032	17th Street Bridge (depth 6 ft), Port Everglades, Florida Current	NOS	PEV0903_3	26.09973	-80.1191	:America/New_York	USA	knots	184	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	17th Street Bridge	FL
99033	South entrance (ICW) (depth 31 ft), Port Everglades, Florida Current	NOS	PEV0904_1	26.08733	-80.11312	:America/New_York	USA	knots	351	168	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Entrance (ICW)	FL
99034	South entrance (ICW) (depth 15 ft), Port Everglades, Florida Current	NOS	PEV0904_7	26.08733	-80.11312	:America/New_York	USA	knots	350	171	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 11.3 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Entrance (ICW)	FL
99035	South entrance (ICW) (depth 5 ft), Port Everglades, Florida Current	NOS	PEV0904_9	26.08733	-80.11312	:America/New_York	USA	knots	353	173	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Entrance (ICW)	FL
99036	South Port, at the terminals (depth 26 ft), Port Everglades, Florida Current	NOS	PEV0905_1	26.0744	-80.11385	:America/New_York	USA	knots	355	175	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Port, at the terminals	FL
99037	South Port, at the terminals (depth 16 ft), Port Everglades, Florida Current	NOS	PEV0905_4	26.0744	-80.11385	:America/New_York	USA	knots	356	175	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Port, at the terminals	FL
99038	South Port, at the terminals (depth 6 ft), Port Everglades, Florida Current	NOS	PEV0905_7	26.0744	-80.11385	:America/New_York	USA	knots	356	175	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Port, at the terminals	FL
99039	Portsmouth Harbor entrance (depth 44 ft), New Hampshire Current	NOS	PIR0701_1	43.06237	-70.70532	:America/New_York	USA	knots	178	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portsmouth Harbor Entrance	NH
99059	Schiller Station (depth 52 ft), New Hampshire Current	NOS	PIR0708_1	43.09738	-70.78108	:America/New_York	USA	knots	168	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Schiller Station	NH
99040	Portsmouth Harbor entrance (depth 25 ft), New Hampshire Current	NOS	PIR0701_7	43.06237	-70.70532	:America/New_York	USA	knots	196	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portsmouth Harbor Entrance	NH
99041	Portsmouth Harbor entrance (depth 8 ft), New Hampshire Current	NOS	PIR0701_12	43.06237	-70.70532	:America/New_York	USA	knots	194	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portsmouth Harbor Entrance	NH
99042	Fort Point (depth 39 ft), Portsmouth Harbor, Maine Current	NOS	PIR0702_1	43.0745	-70.70675	:America/New_York	USA	knots	138	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.341	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	ME
99043	Fort Point (depth 19 ft), Portsmouth Harbor, Maine Current	NOS	PIR0702_7	43.0745	-70.70675	:America/New_York	USA	knots	104	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	ME
99044	Fort Point (depth 6 ft), Portsmouth Harbor, Maine Current	NOS	PIR0702_11	43.0745	-70.70675	:America/New_York	USA	knots	98	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.211	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fort Point	ME
99045	Little Harbor entrance (depth 12 ft), Portsmouth Harbor, New Hampshire Current	NOS	PIR0703_1	43.0554	-70.71568	:America/New_York	USA	knots	122	316	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Little Harbor entrance	NH
99046	Little Harbor entrance (depth 3 ft), Portsmouth Harbor, New Hampshire Current	NOS	PIR0703_7	43.0554	-70.71568	:America/New_York	USA	knots	107	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Little Harbor entrance	NH
99047	Henderson Point, west of (depth 59 ft), Portsmouth Harbor, Maine Current	NOS	PIR0704_1	43.07488	-70.73838	:America/New_York	USA	knots	160	340	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Henderson Point, west of	ME
99048	Henderson Point, west of (depth 32 ft), Portsmouth Harbor, Maine Current	NOS	PIR0704_9	43.07488	-70.73838	:America/New_York	USA	knots	147	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Henderson Point, west of	ME
99049	Henderson Point, west of (depth 10 ft), Portsmouth Harbor, Maine Current	NOS	PIR0704_16	43.07488	-70.73838	:America/New_York	USA	knots	138	285	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Henderson Point, west of	ME
99050	Memorial Bridge (depth 58 ft), Maine Current	NOS	PIR0705_1	43.07938	-70.75208	:America/New_York	USA	knots	93	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Memorial Bridge	ME
99051	Memorial Bridge (depth 31 ft), Maine Current	NOS	PIR0705_9	43.07938	-70.75208	:America/New_York	USA	knots	101	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Memorial Bridge	ME
99052	Memorial Bridge (depth 8 ft), Maine Current	NOS	PIR0705_16	43.07938	-70.75208	:America/New_York	USA	knots	105	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Memorial Bridge	ME
99053	Sara Long Bridge (depth 33 ft), Maine Current	NOS	PIR0706_1	43.0887	-70.76198	:America/New_York	USA	knots	158	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sara Long Bridge	ME
99054	Sara Long Bridge (depth 19 ft), Maine Current	NOS	PIR0706_5	43.0887	-70.76198	:America/New_York	USA	knots	155	332	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.225	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sara Long Bridge	ME
99055	Sara Long Bridge (depth 6 ft), Maine Current	NOS	PIR0706_9	43.0887	-70.76198	:America/New_York	USA	knots	153	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.309	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sara Long Bridge	ME
99056	I-95 Bridge (depth 48 ft), New Hampshire Current	NOS	PIR0707_1	43.09282	-70.76708	:America/New_York	USA	knots	142	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-95 Bridge	NH
99057	I-95 Bridge (depth 29 ft), New Hampshire Current	NOS	PIR0707_7	43.09282	-70.76708	:America/New_York	USA	knots	129	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-95 Bridge	NH
99058	I-95 Bridge (depth 6 ft), New Hampshire Current	NOS	PIR0707_14	43.09282	-70.76708	:America/New_York	USA	knots	123	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.391	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	I-95 Bridge	NH
99060	Schiller Station (depth 29 ft), New Hampshire Current	NOS	PIR0708_8	43.09738	-70.78108	:America/New_York	USA	knots	162	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Schiller Station	NH
99061	Schiller Station (depth 9 ft), New Hampshire Current	NOS	PIR0708_14	43.09738	-70.78108	:America/New_York	USA	knots	157	329	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Schiller Station	NH
99062	Frankfort Island, south of (depth 37 ft), New Hampshire Current	NOS	PIR0709_1	43.11412	-70.80525	:America/New_York	USA	knots	129	303	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Frankfort Island, south of	NH
99063	Frankfort Island, south of (depth 24 ft), New Hampshire Current	NOS	PIR0709_5	43.11412	-70.80525	:America/New_York	USA	knots	130	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Frankfort Island, south of	NH
99064	Frankfort Island, south of (depth 7 ft), New Hampshire Current	NOS	PIR0709_10	43.11412	-70.80525	:America/New_York	USA	knots	130	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Frankfort Island, south of	NH
99065	General Sullivan Bridge (depth 15 ft), New Hampshire Current	NOS	PIR0710_1	43.11785	-70.82608	:America/New_York	USA	knots	71	243	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	General Sullivan Bridge	NH
99066	General Sullivan Bridge (depth 8 ft), New Hampshire Current	NOS	PIR0710_5	43.11785	-70.82608	:America/New_York	USA	knots	75	238	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	General Sullivan Bridge	NH
99067	General Sullivan Bridge (depth 3 ft), New Hampshire Current	NOS	PIR0710_8	43.11785	-70.82608	:America/New_York	USA	knots	78	238	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	General Sullivan Bridge	NH
99068	Furber Strait (depth 25 ft), New Hampshire Current	NOS	PIR0711_1	43.09112	-70.86135	:America/New_York	USA	knots	1	198	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Furber Strait	NH
99069	Furber Strait (depth 14 ft), New Hampshire Current	NOS	PIR0711_8	43.09112	-70.86135	:America/New_York	USA	knots	7	200	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Furber Strait	NH
99070	Furber Strait (depth 4 ft), New Hampshire Current	NOS	PIR0711_14	43.09112	-70.86135	:America/New_York	USA	knots	15	201	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Furber Strait	NH
99071	Agate Passage, south end (depth 25 ft), Puget Sound, Washington Current	NOS	PUG1501_1	47.711021423339844	-122.56714630126953	:America/Los_Angeles	USA	knots	21	200	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
99072	Agate Passage, south end (depth 22 ft), Puget Sound, Washington Current	NOS	PUG1501_2	47.711021423339844	-122.56714630126953	:America/Los_Angeles	USA	knots	\N	200.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
99073	Agate Passage, south end (depth 19 ft), Puget Sound, Washington Current	NOS	PUG1501_3	47.711021423339844	-122.56714630126953	:America/Los_Angeles	USA	knots	\N	200.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
99074	Agate Passage, south end (depth 15 ft), Puget Sound, Washington Current	NOS	PUG1501_4	47.711021423339844	-122.56714630126953	:America/Los_Angeles	USA	knots	\N	200	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
99075	Agate Passage, south end (depth 12 ft), Puget Sound, Washington Current	NOS	PUG1501_5	47.711021423339844	-122.56714630126953	:America/Los_Angeles	USA	knots	\N	199.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
99076	Agate Passage, south end (depth 9 ft), Puget Sound, Washington Current	NOS	PUG1501_6	47.711021423339844	-122.56714630126953	:America/Los_Angeles	USA	knots	16	203	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
99077	Agate Passage, south end (depth 5 ft), Puget Sound, Washington Current	NOS	PUG1501_7	47.711021423339844	-122.56714630126953	:America/Los_Angeles	USA	knots	\N	199.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
99078	Agate Passage, south end (depth 2 ft), Puget Sound, Washington Current	NOS	PUG1501_8	47.711021423339844	-122.56714630126953	:America/Los_Angeles	USA	knots	\N	198.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Agate Passage, south end	WA
99079	Alki Point, 1 mi west of (depth 641 ft), Puget Sound, Washington Current	NOS	PUG1502_1	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99080	Alki Point, 1 mi west of (depth 627 ft), Puget Sound, Washington Current	NOS	PUG1502_2	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99081	Alki Point, 1 mi west of (depth 614 ft), Puget Sound, Washington Current	NOS	PUG1502_3	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99082	Alki Point, 1 mi west of (depth 601 ft), Puget Sound, Washington Current	NOS	PUG1502_4	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	186.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99083	Alki Point, 1 mi west of (depth 588 ft), Puget Sound, Washington Current	NOS	PUG1502_5	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	186.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99084	Alki Point, 1 mi west of (depth 575 ft), Puget Sound, Washington Current	NOS	PUG1502_6	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	186.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.145	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99085	Alki Point, 1 mi west of (depth 562 ft), Puget Sound, Washington Current	NOS	PUG1502_7	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99086	Alki Point, 1 mi west of (depth 549 ft), Puget Sound, Washington Current	NOS	PUG1502_8	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99087	Alki Point, 1 mi west of (depth 536 ft), Puget Sound, Washington Current	NOS	PUG1502_9	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99088	Alki Point, 1 mi west of (depth 522 ft), Puget Sound, Washington Current	NOS	PUG1502_10	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99089	Alki Point, 1 mi west of (depth 509 ft), Puget Sound, Washington Current	NOS	PUG1502_11	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	188.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99090	Alki Point, 1 mi west of (depth 496 ft), Puget Sound, Washington Current	NOS	PUG1502_12	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	188.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99091	Alki Point, 1 mi west of (depth 483 ft), Puget Sound, Washington Current	NOS	PUG1502_13	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	8	189	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99092	Alki Point, 1 mi west of (depth 470 ft), Puget Sound, Washington Current	NOS	PUG1502_14	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	189.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99093	Alki Point, 1 mi west of (depth 457 ft), Puget Sound, Washington Current	NOS	PUG1502_15	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	190.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99094	Alki Point, 1 mi west of (depth 444 ft), Puget Sound, Washington Current	NOS	PUG1502_16	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	190.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99095	Alki Point, 1 mi west of (depth 431 ft), Puget Sound, Washington Current	NOS	PUG1502_17	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	190.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99096	Alki Point, 1 mi west of (depth 417 ft), Puget Sound, Washington Current	NOS	PUG1502_18	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	190.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99097	Alki Point, 1 mi west of (depth 404 ft), Puget Sound, Washington Current	NOS	PUG1502_19	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	191	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99098	Alki Point, 1 mi west of (depth 391 ft), Puget Sound, Washington Current	NOS	PUG1502_20	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	191	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99099	Alki Point, 1 mi west of (depth 378 ft), Puget Sound, Washington Current	NOS	PUG1502_21	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	190.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99100	Alki Point, 1 mi west of (depth 365 ft), Puget Sound, Washington Current	NOS	PUG1502_22	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	190.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99101	Alki Point, 1 mi west of (depth 352 ft), Puget Sound, Washington Current	NOS	PUG1502_23	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	190	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99102	Alki Point, 1 mi west of (depth 339 ft), Puget Sound, Washington Current	NOS	PUG1502_24	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	189.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99103	Alki Point, 1 mi west of (depth 326 ft), Puget Sound, Washington Current	NOS	PUG1502_25	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	189	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99104	Alki Point, 1 mi west of (depth 312 ft), Puget Sound, Washington Current	NOS	PUG1502_26	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	188.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99105	Alki Point, 1 mi west of (depth 299 ft), Puget Sound, Washington Current	NOS	PUG1502_27	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99106	Alki Point, 1 mi west of (depth 286 ft), Puget Sound, Washington Current	NOS	PUG1502_28	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	187	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99107	Alki Point, 1 mi west of (depth 273 ft), Puget Sound, Washington Current	NOS	PUG1502_29	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	186.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99108	Alki Point, 1 mi west of (depth 260 ft), Puget Sound, Washington Current	NOS	PUG1502_30	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	185.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99109	Alki Point, 1 mi west of (depth 247 ft), Puget Sound, Washington Current	NOS	PUG1502_31	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	184.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99110	Alki Point, 1 mi west of (depth 234 ft), Puget Sound, Washington Current	NOS	PUG1502_32	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	183.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99111	Alki Point, 1 mi west of (depth 221 ft), Puget Sound, Washington Current	NOS	PUG1502_33	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	182.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99112	Alki Point, 1 mi west of (depth 207 ft), Puget Sound, Washington Current	NOS	PUG1502_34	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	182.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99113	Alki Point, 1 mi west of (depth 194 ft), Puget Sound, Washington Current	NOS	PUG1502_35	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	359	187	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99114	Alki Point, 1 mi west of (depth 181 ft), Puget Sound, Washington Current	NOS	PUG1502_36	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	181.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99115	Alki Point, 1 mi west of (depth 168 ft), Puget Sound, Washington Current	NOS	PUG1502_37	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	182.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99116	Alki Point, 1 mi west of (depth 155 ft), Puget Sound, Washington Current	NOS	PUG1502_38	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	184.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99117	Alki Point, 1 mi west of (depth 142 ft), Puget Sound, Washington Current	NOS	PUG1502_39	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	188	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99118	Alki Point, 1 mi west of (depth 129 ft), Puget Sound, Washington Current	NOS	PUG1502_40	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	191.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99119	Alki Point, 1 mi west of (depth 116 ft), Puget Sound, Washington Current	NOS	PUG1502_41	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	195.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.247	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99120	Alki Point, 1 mi west of (depth 102 ft), Puget Sound, Washington Current	NOS	PUG1502_42	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	199.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.277	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99121	Alki Point, 1 mi west of (depth 89 ft), Puget Sound, Washington Current	NOS	PUG1502_43	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	205.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.305	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99122	Alki Point, 1 mi west of (depth 76 ft), Puget Sound, Washington Current	NOS	PUG1502_44	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	31	201	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.325	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99123	Alki Point, 1 mi west of (depth 63 ft), Puget Sound, Washington Current	NOS	PUG1502_45	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	216.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.337	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99124	Alki Point, 1 mi west of (depth 50 ft), Puget Sound, Washington Current	NOS	PUG1502_46	47.58367919921875	-122.45175170898438	:America/Los_Angeles	USA	knots	\N	221	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.335	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, 1 mile West of	WA
99125	Edmonds, 2.5 mi west of (depth 500 ft), Puget Sound, Washington Current	NOS	PUG1503_1	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	162.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99126	Edmonds, 2.5 mi west of (depth 487 ft), Puget Sound, Washington Current	NOS	PUG1503_2	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	162.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99127	Edmonds, 2.5 mi west of (depth 474 ft), Puget Sound, Washington Current	NOS	PUG1503_3	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.164	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99128	Edmonds, 2.5 mi west of (depth 461 ft), Puget Sound, Washington Current	NOS	PUG1503_4	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99129	Edmonds, 2.5 mi west of (depth 448 ft), Puget Sound, Washington Current	NOS	PUG1503_5	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99130	Edmonds, 2.5 mi west of (depth 435 ft), Puget Sound, Washington Current	NOS	PUG1503_6	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.145	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99131	Edmonds, 2.5 mi west of (depth 422 ft), Puget Sound, Washington Current	NOS	PUG1503_7	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99132	Edmonds, 2.5 mi west of (depth 409 ft), Puget Sound, Washington Current	NOS	PUG1503_8	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99133	Edmonds, 2.5 mi west of (depth 395 ft), Puget Sound, Washington Current	NOS	PUG1503_9	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99134	Edmonds, 2.5 mi west of (depth 382 ft), Puget Sound, Washington Current	NOS	PUG1503_10	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99135	Edmonds, 2.5 mi west of (depth 369 ft), Puget Sound, Washington Current	NOS	PUG1503_11	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99136	Edmonds, 2.5 mi west of (depth 356 ft), Puget Sound, Washington Current	NOS	PUG1503_12	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99137	Edmonds, 2.5 mi west of (depth 343 ft), Puget Sound, Washington Current	NOS	PUG1503_13	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99138	Edmonds, 2.5 mi west of (depth 330 ft), Puget Sound, Washington Current	NOS	PUG1503_14	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99139	Edmonds, 2.5 mi west of (depth 317 ft), Puget Sound, Washington Current	NOS	PUG1503_15	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	346	167	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99140	Edmonds, 2.5 mi west of (depth 304 ft), Puget Sound, Washington Current	NOS	PUG1503_16	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99141	Edmonds, 2.5 mi west of (depth 290 ft), Puget Sound, Washington Current	NOS	PUG1503_17	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99142	Edmonds, 2.5 mi west of (depth 277 ft), Puget Sound, Washington Current	NOS	PUG1503_18	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99143	Edmonds, 2.5 mi west of (depth 264 ft), Puget Sound, Washington Current	NOS	PUG1503_19	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	163.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99144	Edmonds, 2.5 mi west of (depth 251 ft), Puget Sound, Washington Current	NOS	PUG1503_20	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99145	Edmonds, 2.5 mi west of (depth 238 ft), Puget Sound, Washington Current	NOS	PUG1503_21	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	164.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99146	Edmonds, 2.5 mi west of (depth 225 ft), Puget Sound, Washington Current	NOS	PUG1503_22	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	165	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99147	Edmonds, 2.5 mi west of (depth 212 ft), Puget Sound, Washington Current	NOS	PUG1503_23	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	165.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99148	Edmonds, 2.5 mi west of (depth 199 ft), Puget Sound, Washington Current	NOS	PUG1503_24	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	166.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99149	Edmonds, 2.5 mi west of (depth 185 ft), Puget Sound, Washington Current	NOS	PUG1503_25	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	166.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99150	Edmonds, 2.5 mi west of (depth 172 ft), Puget Sound, Washington Current	NOS	PUG1503_26	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	167.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99151	Edmonds, 2.5 mi west of (depth 159 ft), Puget Sound, Washington Current	NOS	PUG1503_27	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	167.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99152	Edmonds, 2.5 mi west of (depth 146 ft), Puget Sound, Washington Current	NOS	PUG1503_28	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	168.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99153	Edmonds, 2.5 mi west of (depth 133 ft), Puget Sound, Washington Current	NOS	PUG1503_29	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	355	161	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99154	Edmonds, 2.5 mi west of (depth 120 ft), Puget Sound, Washington Current	NOS	PUG1503_30	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	169.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99155	Edmonds, 2.5 mi west of (depth 107 ft), Puget Sound, Washington Current	NOS	PUG1503_31	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	170.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99156	Edmonds, 2.5 mi west of (depth 94 ft), Puget Sound, Washington Current	NOS	PUG1503_32	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	171.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99157	Edmonds, 2.5 mi west of (depth 80 ft), Puget Sound, Washington Current	NOS	PUG1503_33	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	172.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99158	Edmonds, 2.5 mi west of (depth 67 ft), Puget Sound, Washington Current	NOS	PUG1503_34	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	358	161	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.226	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99159	Edmonds, 2.5 mi west of (depth 54 ft), Puget Sound, Washington Current	NOS	PUG1503_35	47.80712127685547	-122.44412994384766	:America/Los_Angeles	USA	knots	\N	173.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.248	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edmonds, 2.5 miles West of	WA
99160	Eagle Harbor entrance (depth 32 ft), Puget Sound, Washington Current	NOS	PUG1505_1	47.619571685791016	-122.49530029296875	:America/Los_Angeles	USA	knots	\N	328	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance to Eagle Harbor	WA
99161	Eagle Harbor entrance (depth 9 ft), Puget Sound, Washington Current	NOS	PUG1505_8	47.619571685791016	-122.49530029296875	:America/Los_Angeles	USA	knots	137	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance to Eagle Harbor	WA
99162	Harbor Island West (depth 48 ft), Puget Sound, Washington Current	NOS	PUG1507_1	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	189.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
99163	Harbor Island West (depth 45 ft), Puget Sound, Washington Current	NOS	PUG1507_2	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	187	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
99164	Harbor Island West (depth 41 ft), Puget Sound, Washington Current	NOS	PUG1507_3	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	185.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
101803	Range D, off Mosquito Creek, Winyah Bay, South Carolina Current	NOS	ACT6536_1	33.24417	-79.20583	:America/New_York	USA	knots	130	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:42:00	\N	1.1	01:57:00	\N	1.2	02:00:00	01:13:00	Range D, off Mosquito Creek	SC
99165	Harbor Island West (depth 38 ft), Puget Sound, Washington Current	NOS	PUG1507_4	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	183.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
99166	Harbor Island West (depth 35 ft), Puget Sound, Washington Current	NOS	PUG1507_5	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	182.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.112	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
99167	Harbor Island West (depth 31 ft), Puget Sound, Washington Current	NOS	PUG1507_6	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	181	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
99168	Harbor Island West (depth 28 ft), Puget Sound, Washington Current	NOS	PUG1507_7	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	179.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
99169	Harbor Island West (depth 25 ft), Puget Sound, Washington Current	NOS	PUG1507_8	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	178.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
99170	Harbor Island West (depth 22 ft), Puget Sound, Washington Current	NOS	PUG1507_9	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	356	177	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
99171	Harbor Island West (depth 18 ft), Puget Sound, Washington Current	NOS	PUG1507_10	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	178.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
99172	Harbor Island West (depth 15 ft), Puget Sound, Washington Current	NOS	PUG1507_11	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	180.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
99173	Harbor Island West (depth 12 ft), Puget Sound, Washington Current	NOS	PUG1507_12	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	\N	180.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
99174	Harbor Island West (depth 9 ft), Puget Sound, Washington Current	NOS	PUG1507_13	47.5831298828125	-122.36022186279297	:America/Los_Angeles	USA	knots	1	178	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island West	WA
99175	Liberty Bay (entrance), Port Orchard (depth 37 ft), Puget Sound, Washington Current	NOS	PUG1508_1	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	110	296	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
99176	Liberty Bay (entrance), Port Orchard (depth 33 ft), Puget Sound, Washington Current	NOS	PUG1508_2	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	\N	293	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
99177	Liberty Bay (entrance), Port Orchard (depth 30 ft), Puget Sound, Washington Current	NOS	PUG1508_3	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	\N	293.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
99178	Liberty Bay (entrance), Port Orchard (depth 27 ft), Puget Sound, Washington Current	NOS	PUG1508_4	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	\N	293.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
99179	Liberty Bay (entrance), Port Orchard (depth 24 ft), Puget Sound, Washington Current	NOS	PUG1508_5	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	124	288	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
99180	Liberty Bay (entrance), Port Orchard (depth 20 ft), Puget Sound, Washington Current	NOS	PUG1508_6	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	\N	295.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
99181	Liberty Bay (entrance), Port Orchard (depth 17 ft), Puget Sound, Washington Current	NOS	PUG1508_7	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	\N	295.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
99182	Liberty Bay (entrance), Port Orchard (depth 14 ft), Puget Sound, Washington Current	NOS	PUG1508_8	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	\N	296.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
99183	Liberty Bay (entrance), Port Orchard (depth 10 ft), Puget Sound, Washington Current	NOS	PUG1508_9	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	\N	297	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
99184	Liberty Bay (entrance), Port Orchard (depth 7 ft), Puget Sound, Washington Current	NOS	PUG1508_10	47.70682144165039	-122.62825012207031	:America/Los_Angeles	USA	knots	313	287	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Liberty Bay (entrance), Port Orchard	WA
99185	Point Jefferson, east of (depth 71 ft), Puget Sound, Washington Current	NOS	PUG1509_1	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	14	212	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
99186	Point Jefferson, east of (depth 65 ft), Puget Sound, Washington Current	NOS	PUG1509_2	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	\N	203.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
99187	Point Jefferson, east of (depth 58 ft), Puget Sound, Washington Current	NOS	PUG1509_3	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	\N	205.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
99188	Point Jefferson, east of (depth 51 ft), Puget Sound, Washington Current	NOS	PUG1509_4	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	\N	206.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
99189	Point Jefferson, east of (depth 45 ft), Puget Sound, Washington Current	NOS	PUG1509_5	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	21	214	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
99190	Point Jefferson, east of (depth 38 ft), Puget Sound, Washington Current	NOS	PUG1509_6	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	\N	209.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
99191	Point Jefferson, east of (depth 32 ft), Puget Sound, Washington Current	NOS	PUG1509_7	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	\N	211.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
99192	Point Jefferson, east of (depth 25 ft), Puget Sound, Washington Current	NOS	PUG1509_8	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	\N	212.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.176	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
99193	Point Jefferson, east of (depth 19 ft), Puget Sound, Washington Current	NOS	PUG1509_9	47.744468688964844	-122.468017578125	:America/Los_Angeles	USA	knots	31	217	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Jefferson, East of	WA
99194	Port Washington Narrows, Warren Ave. Bridge (depth 21 ft), Washington Current	NOS	PUG1510_1	47.57957077026367	-122.63065338134766	:America/Los_Angeles	USA	knots	102	279	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Washington Narrows, Warren Ave. Bridge	WA
99195	Port Washington Narrows, Warren Ave. Bridge (depth 4 ft), Washington Current	NOS	PUG1510_6	47.57957077026367	-122.63065338134766	:America/Los_Angeles	USA	knots	99	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Washington Narrows, Warren Ave. Bridge	WA
99196	President Point, 1.5 mi east of (depth 308 ft), Puget Sound, Washington Current	NOS	PUG1511_20	47.76712	-122.4319	:America/Los_Angeles	USA	knots	331	161	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Point, 1.5 miles east of	WA
99197	President Point, 1.5 mi east of (depth 176 ft), Puget Sound, Washington Current	NOS	PUG1511_30	47.76712	-122.4319	:America/Los_Angeles	USA	knots	341	158	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Point, 1.5 miles east of	WA
99198	President Point, 1.5 mi east of (depth 71 ft), Puget Sound, Washington Current	NOS	PUG1511_38	47.76712	-122.4319	:America/Los_Angeles	USA	knots	3	177	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Point, 1.5 miles east of	WA
99199	Restoration Point (depth 140 ft), Puget Sound, Washington Current	NOS	PUG1512_1	47.57884979248047	-122.46871948242188	:America/Los_Angeles	USA	knots	45	151	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Restoration Point	WA
99200	Restoration Point (depth 81 ft), Puget Sound, Washington Current	NOS	PUG1512_10	47.57884979248047	-122.46871948242188	:America/Los_Angeles	USA	knots	42	142	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.246	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Restoration Point	WA
99201	Restoration Point (depth 22 ft), Puget Sound, Washington Current	NOS	PUG1512_19	47.57884979248047	-122.46871948242188	:America/Los_Angeles	USA	knots	52	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.429	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Restoration Point	WA
99202	Rich Passage, east end (depth 70 ft), Puget Sound, Washington Current	NOS	PUG1513_1	47.57001876831055	-122.52980041503906	:America/Los_Angeles	USA	knots	108	314	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, East end	WA
99203	Rich Passage, east end (depth 38 ft), Puget Sound, Washington Current	NOS	PUG1513_6	47.57001876831055	-122.52980041503906	:America/Los_Angeles	USA	knots	127	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, East end	WA
99204	Rich Passage, east end (depth 11 ft), Puget Sound, Washington Current	NOS	PUG1513_10	47.57001876831055	-122.52980041503906	:America/Los_Angeles	USA	knots	139	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, East end	WA
99205	Rich Passage, west end (depth 57 ft), Puget Sound, Washington Current	NOS	PUG1514_1	47.58993148803711	-122.56233215332031	:America/Los_Angeles	USA	knots	53	235	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.112	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, West end	WA
99308	The Narrows, 0.3 mi north of bridge (depth 141 ft), Puget Sound, Washington Current	NOS	PUG1527_1	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	42	213	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99206	Rich Passage, west end (depth 51 ft), Puget Sound, Washington Current	NOS	PUG1514_2	47.58993148803711	-122.56233215332031	:America/Los_Angeles	USA	knots	\N	234.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, West end	WA
99207	Rich Passage, west end (depth 44 ft), Puget Sound, Washington Current	NOS	PUG1514_3	47.58993148803711	-122.56233215332031	:America/Los_Angeles	USA	knots	\N	235.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, West end	WA
99208	Rich Passage, west end (depth 38 ft), Puget Sound, Washington Current	NOS	PUG1514_4	47.58993148803711	-122.56233215332031	:America/Los_Angeles	USA	knots	\N	235.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, West end	WA
99209	Rich Passage, west end (depth 31 ft), Puget Sound, Washington Current	NOS	PUG1514_5	47.58993148803711	-122.56233215332031	:America/Los_Angeles	USA	knots	55	238	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, West end	WA
100784	Widow Island-Stimpson Island, between (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0171_1	44.1325	-68.825	:America/New_York	USA	knots	118	302	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:39:00	\N	0.5	-00:25:00	\N	0.9	-00:53:00	00:27:00	Widow Island-Stimpson Island, between	ME
99210	Rich Passage, west end (depth 25 ft), Puget Sound, Washington Current	NOS	PUG1514_6	47.58993148803711	-122.56233215332031	:America/Los_Angeles	USA	knots	\N	236.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, West end	WA
99211	Rich Passage, west end (depth 18 ft), Puget Sound, Washington Current	NOS	PUG1514_7	47.58993148803711	-122.56233215332031	:America/Los_Angeles	USA	knots	\N	236.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, West end	WA
99212	Rich Passage, west end (depth 12 ft), Puget Sound, Washington Current	NOS	PUG1514_8	47.58993148803711	-122.56233215332031	:America/Los_Angeles	USA	knots	55	239	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, West end	WA
99213	West Point, west of (depth 108 ft), Puget Sound, Washington Current	NOS	PUG1515_1	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	21	228	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
99214	West Point, west of (depth 101 ft), Puget Sound, Washington Current	NOS	PUG1515_2	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	218.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
99215	West Point, west of (depth 95 ft), Puget Sound, Washington Current	NOS	PUG1515_3	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	218.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.188	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
99216	West Point, west of (depth 88 ft), Puget Sound, Washington Current	NOS	PUG1515_4	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	217.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
99217	West Point, west of (depth 81 ft), Puget Sound, Washington Current	NOS	PUG1515_5	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	217.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.192	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
99218	West Point, west of (depth 75 ft), Puget Sound, Washington Current	NOS	PUG1515_6	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	217.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.193	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
99219	West Point, west of (depth 68 ft), Puget Sound, Washington Current	NOS	PUG1515_7	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	217.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
99220	West Point, west of (depth 62 ft), Puget Sound, Washington Current	NOS	PUG1515_8	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	217.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.193	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
99221	West Point, west of (depth 55 ft), Puget Sound, Washington Current	NOS	PUG1515_9	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	216.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
99222	West Point, west of (depth 49 ft), Puget Sound, Washington Current	NOS	PUG1515_10	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	357	230	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
99223	West Point, west of (depth 42 ft), Puget Sound, Washington Current	NOS	PUG1515_11	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	215.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.178	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
99224	West Point, west of (depth 35 ft), Puget Sound, Washington Current	NOS	PUG1515_12	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	214.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
99225	West Point, west of (depth 29 ft), Puget Sound, Washington Current	NOS	PUG1515_13	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	213.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
99226	West Point, west of (depth 22 ft), Puget Sound, Washington Current	NOS	PUG1515_14	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	\N	212.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
99227	West Point, west of (depth 16 ft), Puget Sound, Washington Current	NOS	PUG1515_15	47.662071228027344	-122.44168090820312	:America/Los_Angeles	USA	knots	341	234	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Point, West of	WA
99228	Alki Point, west of (depth 195 ft), Puget Sound, Washington Current	NOS	PUG1516_5	47.57606887817383	-122.4278335571289	:America/Los_Angeles	USA	knots	4	200	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, West of	WA
99229	Alki Point, west of (depth 103 ft), Puget Sound, Washington Current	NOS	PUG1516_12	47.57606887817383	-122.4278335571289	:America/Los_Angeles	USA	knots	6	213	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, West of	WA
99230	Alki Point, west of (depth 38 ft), Puget Sound, Washington Current	NOS	PUG1516_17	47.57606887817383	-122.4278335571289	:America/Los_Angeles	USA	knots	4	215	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alki Point, West of	WA
99231	Blake Island, S of (depth 241 ft), Puget Sound, Washington Current	NOS	PUG1517_1	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	161.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.372	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99232	Blake Island, S of (depth 231 ft), Puget Sound, Washington Current	NOS	PUG1517_2	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	164.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.392	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99233	Blake Island, S of (depth 221 ft), Puget Sound, Washington Current	NOS	PUG1517_3	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	166.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.407	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99234	Blake Island, S of (depth 211 ft), Puget Sound, Washington Current	NOS	PUG1517_4	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	168.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.42	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99235	Blake Island, S of (depth 201 ft), Puget Sound, Washington Current	NOS	PUG1517_5	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	170.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.432	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99236	Blake Island, S of (depth 191 ft), Puget Sound, Washington Current	NOS	PUG1517_6	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	172.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.444	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99237	Blake Island, S of (depth 182 ft), Puget Sound, Washington Current	NOS	PUG1517_7	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	173.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.454	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99238	Blake Island, S of (depth 172 ft), Puget Sound, Washington Current	NOS	PUG1517_8	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	350	218	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.465	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99239	Blake Island, S of (depth 162 ft), Puget Sound, Washington Current	NOS	PUG1517_9	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	176.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.476	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99240	Blake Island, S of (depth 152 ft), Puget Sound, Washington Current	NOS	PUG1517_10	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	177.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.488	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99241	Blake Island, S of (depth 142 ft), Puget Sound, Washington Current	NOS	PUG1517_11	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	177.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.5	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99242	Blake Island, S of (depth 132 ft), Puget Sound, Washington Current	NOS	PUG1517_12	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	178.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.512	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99243	Blake Island, S of (depth 122 ft), Puget Sound, Washington Current	NOS	PUG1517_13	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	179	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.524	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99244	Blake Island, S of (depth 113 ft), Puget Sound, Washington Current	NOS	PUG1517_14	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	179.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.538	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99245	Blake Island, S of (depth 103 ft), Puget Sound, Washington Current	NOS	PUG1517_15	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	179.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.551	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99246	Blake Island, S of (depth 93 ft), Puget Sound, Washington Current	NOS	PUG1517_16	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	349	237	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.564	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99247	Blake Island, S of (depth 83 ft), Puget Sound, Washington Current	NOS	PUG1517_17	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	179.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99248	Blake Island, S of (depth 73 ft), Puget Sound, Washington Current	NOS	PUG1517_18	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	179.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.588	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99249	Blake Island, S of (depth 63 ft), Puget Sound, Washington Current	NOS	PUG1517_19	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	180.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.599	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99351	Hale Passage, west end (depth 14 ft), Puget Sound, Washington Current	NOS	PUG1530_18	47.28137969970703	-122.66311645507812	:America/Los_Angeles	USA	knots	105	283	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.47	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, West end	WA
99250	Blake Island, S of (depth 54 ft), Puget Sound, Washington Current	NOS	PUG1517_20	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	180.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.607	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99251	Blake Island, S of (depth 44 ft), Puget Sound, Washington Current	NOS	PUG1517_21	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	350	244	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.612	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99252	Blake Island, S of (depth 34 ft), Puget Sound, Washington Current	NOS	PUG1517_22	47.52027893066406	-122.48792266845703	:America/Los_Angeles	USA	knots	\N	186.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.562	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blake Island, S of	WA
99253	Anderson Point, east of, Colvos Passage (depth 154 ft), Puget Sound, Washington Current	NOS	PUG1518_10	47.43943	-122.52578	:America/Los_Angeles	USA	knots	351	181	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.524	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anderson Point, East of, Colvos Passage	WA
99254	Anderson Point, east of, Colvos Passage (depth 62 ft), Puget Sound, Washington Current	NOS	PUG1518_17	47.43943	-122.52578	:America/Los_Angeles	USA	knots	353	185	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.548	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anderson Point, East of, Colvos Passage	WA
99255	Anderson Point, east of, Colvos Passage (depth 35 ft), Puget Sound, Washington Current	NOS	PUG1518_19	47.43943	-122.52578	:America/Los_Angeles	USA	knots	356	183	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.537	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Anderson Point, East of, Colvos Passage	WA
99256	Point Richmond, east of, Colvos Passage (depth 241 ft), Puget Sound, Washington Current	NOS	PUG1519_3	47.37662124633789	-122.52867126464844	:America/Los_Angeles	USA	knots	4	157	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.498	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, East of, Colvos Passage	WA
99257	Point Richmond, east of, Colvos Passage (depth 110 ft), Puget Sound, Washington Current	NOS	PUG1519_13	47.37662124633789	-122.52867126464844	:America/Los_Angeles	USA	knots	359	162	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.589	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, East of, Colvos Passage	WA
99258	Point Richmond, east of, Colvos Passage (depth 44 ft), Puget Sound, Washington Current	NOS	PUG1519_18	47.37662124633789	-122.52867126464844	:America/Los_Angeles	USA	knots	356	143	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.571	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Richmond, East of, Colvos Passage	WA
99259	Dolphin Point, 1.3 mi east of (depth 218 ft), Puget Sound, Washington Current	NOS	PUG1520_22	47.501548767089844	-122.42357635498047	:America/Los_Angeles	USA	knots	\N	178.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolphin Point, 1.3 miles East of	WA
99260	Dolphin Point, 1.3 mi east of (depth 139 ft), Puget Sound, Washington Current	NOS	PUG1520_28	47.501548767089844	-122.42357635498047	:America/Los_Angeles	USA	knots	343	184	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolphin Point, 1.3 miles East of	WA
99261	Dolphin Point, 1.3 mi east of (depth 48 ft), Puget Sound, Washington Current	NOS	PUG1520_35	47.501548767089844	-122.42357635498047	:America/Los_Angeles	USA	knots	343	186	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dolphin Point, 1.3 miles East of	WA
99262	Browns Point, 1.6 mi north of (depth 461 ft), Puget Sound, Washington Current	NOS	PUG1521_1	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	225	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.203	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99263	Browns Point, 1.6 mi north of (depth 448 ft), Puget Sound, Washington Current	NOS	PUG1521_2	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	224.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.208	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99264	Browns Point, 1.6 mi north of (depth 435 ft), Puget Sound, Washington Current	NOS	PUG1521_3	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	223.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.211	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99265	Browns Point, 1.6 mi north of (depth 422 ft), Puget Sound, Washington Current	NOS	PUG1521_4	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	223.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.208	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99266	Browns Point, 1.6 mi north of (depth 408 ft), Puget Sound, Washington Current	NOS	PUG1521_5	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	224	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99267	Browns Point, 1.6 mi north of (depth 395 ft), Puget Sound, Washington Current	NOS	PUG1521_6	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	224.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.214	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99268	Browns Point, 1.6 mi north of (depth 382 ft), Puget Sound, Washington Current	NOS	PUG1521_7	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	224.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.218	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99269	Browns Point, 1.6 mi north of (depth 369 ft), Puget Sound, Washington Current	NOS	PUG1521_8	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	225	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.221	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99270	Browns Point, 1.6 mi north of (depth 356 ft), Puget Sound, Washington Current	NOS	PUG1521_9	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	225.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.222	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99271	Browns Point, 1.6 mi north of (depth 343 ft), Puget Sound, Washington Current	NOS	PUG1521_10	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	225.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.221	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99272	Browns Point, 1.6 mi north of (depth 330 ft), Puget Sound, Washington Current	NOS	PUG1521_11	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	226.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.218	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99273	Browns Point, 1.6 mi north of (depth 317 ft), Puget Sound, Washington Current	NOS	PUG1521_12	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	227	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.212	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99274	Browns Point, 1.6 mi north of (depth 303 ft), Puget Sound, Washington Current	NOS	PUG1521_13	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	227.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.204	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99275	Browns Point, 1.6 mi north of (depth 290 ft), Puget Sound, Washington Current	NOS	PUG1521_14	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	47	228	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99276	Browns Point, 1.6 mi north of (depth 277 ft), Puget Sound, Washington Current	NOS	PUG1521_15	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	230.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.184	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99277	Browns Point, 1.6 mi north of (depth 264 ft), Puget Sound, Washington Current	NOS	PUG1521_16	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	232.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.174	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99278	Browns Point, 1.6 mi north of (depth 251 ft), Puget Sound, Washington Current	NOS	PUG1521_17	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	233.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99279	Browns Point, 1.6 mi north of (depth 238 ft), Puget Sound, Washington Current	NOS	PUG1521_18	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	234.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99280	Browns Point, 1.6 mi north of (depth 225 ft), Puget Sound, Washington Current	NOS	PUG1521_19	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	234.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99281	Browns Point, 1.6 mi north of (depth 212 ft), Puget Sound, Washington Current	NOS	PUG1521_20	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	235.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
100785	Eagle Island, 0.4 nmi S of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0176_1	44.19383	-68.78217	:America/New_York	USA	knots	147	336	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:17:00	\N	0.9	-00:31:00	\N	1.3	-00:28:00	-01:57:00	Eagle Island, 0.4 nautical mile S of	ME
99282	Browns Point, 1.6 mi north of (depth 199 ft), Puget Sound, Washington Current	NOS	PUG1521_21	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	235	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99283	Browns Point, 1.6 mi north of (depth 185 ft), Puget Sound, Washington Current	NOS	PUG1521_22	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	234.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99284	Browns Point, 1.6 mi north of (depth 172 ft), Puget Sound, Washington Current	NOS	PUG1521_23	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	234	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99285	Browns Point, 1.6 mi north of (depth 159 ft), Puget Sound, Washington Current	NOS	PUG1521_24	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	49	232	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99286	Browns Point, 1.6 mi north of (depth 146 ft), Puget Sound, Washington Current	NOS	PUG1521_25	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	230.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99287	Browns Point, 1.6 mi north of (depth 133 ft), Puget Sound, Washington Current	NOS	PUG1521_26	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	229	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99288	Browns Point, 1.6 mi north of (depth 120 ft), Puget Sound, Washington Current	NOS	PUG1521_27	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	227.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.145	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99289	Browns Point, 1.6 mi north of (depth 107 ft), Puget Sound, Washington Current	NOS	PUG1521_28	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	226.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99290	Browns Point, 1.6 mi north of (depth 94 ft), Puget Sound, Washington Current	NOS	PUG1521_29	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	227.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99291	Browns Point, 1.6 mi north of (depth 80 ft), Puget Sound, Washington Current	NOS	PUG1521_30	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	228.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99409	Balch Passage, NE of Eagle Island (depth 30 ft), Puget Sound, Washington Current	NOS	PUG1535_10	47.19062042236328	-122.6915512084961	:America/Los_Angeles	USA	knots	108	288	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.315	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Balch Passage, NE of Eagle Island	WA
99292	Browns Point, 1.6 mi north of (depth 67 ft), Puget Sound, Washington Current	NOS	PUG1521_31	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	229.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.191	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99293	Browns Point, 1.6 mi north of (depth 54 ft), Puget Sound, Washington Current	NOS	PUG1521_32	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	230.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99294	Browns Point, 1.6 mi north of (depth 41 ft), Puget Sound, Washington Current	NOS	PUG1521_33	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	\N	232.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.209	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99295	Browns Point, 1.6 mi north of (depth 28 ft), Puget Sound, Washington Current	NOS	PUG1521_34	47.32870101928711	-122.45404815673828	:America/Los_Angeles	USA	knots	42	234	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.205	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Browns Point, 1.6 miles North of	WA
99296	Dalco Passage (depth 187 ft), Puget Sound, Washington Current	NOS	PUG1522_3	47.32511901855469	-122.5246810913086	:America/Los_Angeles	USA	knots	124	288	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.278	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
99297	Dalco Passage (depth 128 ft), Puget Sound, Washington Current	NOS	PUG1522_12	47.32511901855469	-122.5246810913086	:America/Los_Angeles	USA	knots	130	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.408	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
99298	Dalco Passage (depth 23 ft), Puget Sound, Washington Current	NOS	PUG1522_28	47.32511901855469	-122.5246810913086	:America/Los_Angeles	USA	knots	\N	309.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.501	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dalco Passage	WA
99299	Gig Harbor entrance (depth 54 ft), Puget Sound, Washington Current	NOS	PUG1523_1	47.32415008544922	-122.57186889648438	:America/Los_Angeles	USA	knots	3	192	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor Entrance	WA
99300	Gig Harbor entrance (depth 31 ft), Puget Sound, Washington Current	NOS	PUG1523_8	47.32415008544922	-122.57186889648438	:America/Los_Angeles	USA	knots	357	198	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor Entrance	WA
99301	Gig Harbor entrance (depth 11 ft), Puget Sound, Washington Current	NOS	PUG1523_14	47.32415008544922	-122.57186889648438	:America/Los_Angeles	USA	knots	7	198	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gig Harbor Entrance	WA
99302	The Narrows, north end (midstream) (depth 139 ft), Puget Sound, Washington Current	NOS	PUG1524_1	47.305999755859375	-122.55003356933594	:America/Los_Angeles	USA	knots	331	132	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, North end - midstream	WA
99303	The Narrows, north end (midstream) (depth 87 ft), Puget Sound, Washington Current	NOS	PUG1524_9	47.305999755859375	-122.55003356933594	:America/Los_Angeles	USA	knots	335	141	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.224	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, North end - midstream	WA
99304	The Narrows, north end (midstream) (depth 40 ft), Puget Sound, Washington Current	NOS	PUG1524_16	47.305999755859375	-122.55003356933594	:America/Los_Angeles	USA	knots	337	145	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, North end - midstream	WA
99305	The Narrows, north end (west side) (depth 193 ft), Puget Sound, Washington Current	NOS	PUG1526_5	47.30400085449219	-122.55674743652344	:America/Los_Angeles	USA	knots	324	144	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.996	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, North End (west side)	WA
99306	The Narrows, north end (west side) (depth 95 ft), Puget Sound, Washington Current	NOS	PUG1526_20	47.30400085449219	-122.55674743652344	:America/Los_Angeles	USA	knots	326	148	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.933	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, North End (west side)	WA
99307	The Narrows, north end (west side) (depth 42 ft), Puget Sound, Washington Current	NOS	PUG1526_28	47.30400085449219	-122.55674743652344	:America/Los_Angeles	USA	knots	329	152	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.886	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, North End (west side)	WA
99309	The Narrows, 0.3 mi north of bridge (depth 134 ft), Puget Sound, Washington Current	NOS	PUG1527_2	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	216.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99310	The Narrows, 0.3 mi north of bridge (depth 128 ft), Puget Sound, Washington Current	NOS	PUG1527_3	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	216.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99311	The Narrows, 0.3 mi north of bridge (depth 121 ft), Puget Sound, Washington Current	NOS	PUG1527_4	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	216.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99312	The Narrows, 0.3 mi north of bridge (depth 115 ft), Puget Sound, Washington Current	NOS	PUG1527_5	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	216	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99313	The Narrows, 0.3 mi north of bridge (depth 108 ft), Puget Sound, Washington Current	NOS	PUG1527_6	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	215.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99314	The Narrows, 0.3 mi north of bridge (depth 102 ft), Puget Sound, Washington Current	NOS	PUG1527_7	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	215.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99315	The Narrows, 0.3 mi north of bridge (depth 95 ft), Puget Sound, Washington Current	NOS	PUG1527_8	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	214.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99316	The Narrows, 0.3 mi north of bridge (depth 88 ft), Puget Sound, Washington Current	NOS	PUG1527_9	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	214.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99317	The Narrows, 0.3 mi north of bridge (depth 82 ft), Puget Sound, Washington Current	NOS	PUG1527_10	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	214	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99318	The Narrows, 0.3 mi north of bridge (depth 75 ft), Puget Sound, Washington Current	NOS	PUG1527_11	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	213.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99319	The Narrows, 0.3 mi north of bridge (depth 69 ft), Puget Sound, Washington Current	NOS	PUG1527_12	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	42	204	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99320	The Narrows, 0.3 mi north of bridge (depth 62 ft), Puget Sound, Washington Current	NOS	PUG1527_13	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	212.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99321	The Narrows, 0.3 mi north of bridge (depth 56 ft), Puget Sound, Washington Current	NOS	PUG1527_14	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	211.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99975	Mud Bay (depth 40 ft), Prince William Sound, Alaska Current	NOS	PWS0735_1	60.54765	-145.84088	:America/Anchorage	USA	knots	63	256	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mud Bay	AK
99322	The Narrows, 0.3 mi north of bridge (depth 49 ft), Puget Sound, Washington Current	NOS	PUG1527_15	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	211.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99323	The Narrows, 0.3 mi north of bridge (depth 43 ft), Puget Sound, Washington Current	NOS	PUG1527_16	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	210.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99324	The Narrows, 0.3 mi north of bridge (depth 36 ft), Puget Sound, Washington Current	NOS	PUG1527_17	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	209.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99325	The Narrows, 0.3 mi north of bridge (depth 29 ft), Puget Sound, Washington Current	NOS	PUG1527_18	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	209.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99326	The Narrows, 0.3 mi north of bridge (depth 23 ft), Puget Sound, Washington Current	NOS	PUG1527_19	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	40	198	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99327	The Narrows, 0.3 mi north of bridge (depth 16 ft), Puget Sound, Washington Current	NOS	PUG1527_20	47.27431869506836	-122.54531860351562	:America/Los_Angeles	USA	knots	\N	206.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, 0.3 miles North of Bridge	WA
99328	The Narrows, south end (midstream) (depth 131 ft), Puget Sound, Washington Current	NOS	PUG1528_1	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	32	222	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99329	The Narrows, south end (midstream) (depth 125 ft), Puget Sound, Washington Current	NOS	PUG1528_2	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	217	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99330	The Narrows, south end (midstream) (depth 118 ft), Puget Sound, Washington Current	NOS	PUG1528_3	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	216.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99331	The Narrows, south end (midstream) (depth 112 ft), Puget Sound, Washington Current	NOS	PUG1528_4	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	216.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99332	The Narrows, south end (midstream) (depth 105 ft), Puget Sound, Washington Current	NOS	PUG1528_5	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	216.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99333	The Narrows, south end (midstream) (depth 98 ft), Puget Sound, Washington Current	NOS	PUG1528_6	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	216.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99334	The Narrows, south end (midstream) (depth 92 ft), Puget Sound, Washington Current	NOS	PUG1528_7	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	216.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99335	The Narrows, south end (midstream) (depth 85 ft), Puget Sound, Washington Current	NOS	PUG1528_8	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	216.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99336	The Narrows, south end (midstream) (depth 79 ft), Puget Sound, Washington Current	NOS	PUG1528_9	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	216	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99337	The Narrows, south end (midstream) (depth 72 ft), Puget Sound, Washington Current	NOS	PUG1528_10	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	215.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99338	The Narrows, south end (midstream) (depth 66 ft), Puget Sound, Washington Current	NOS	PUG1528_11	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	215.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99339	The Narrows, south end (midstream) (depth 59 ft), Puget Sound, Washington Current	NOS	PUG1528_12	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	215.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99340	The Narrows, south end (midstream) (depth 52 ft), Puget Sound, Washington Current	NOS	PUG1528_13	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	28	221	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99341	The Narrows, south end (midstream) (depth 46 ft), Puget Sound, Washington Current	NOS	PUG1528_14	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	214.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99342	The Narrows, south end (midstream) (depth 39 ft), Puget Sound, Washington Current	NOS	PUG1528_15	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	214.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99343	The Narrows, south end (midstream) (depth 33 ft), Puget Sound, Washington Current	NOS	PUG1528_16	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	213.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99344	The Narrows, south end (midstream) (depth 26 ft), Puget Sound, Washington Current	NOS	PUG1528_17	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	26	220	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99345	The Narrows, south end (midstream) (depth 20 ft), Puget Sound, Washington Current	NOS	PUG1528_18	47.26129913330078	-122.55828094482422	:America/Los_Angeles	USA	knots	\N	213.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows, South end (midstream)	WA
99346	Hale Passage, east end (depth 77 ft), Puget Sound, Washington Current	NOS	PUG1529_1	47.24789810180664	-122.59559631347656	:America/Los_Angeles	USA	knots	151	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.241	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, East end	WA
99347	Hale Passage, east end (depth 44 ft), Puget Sound, Washington Current	NOS	PUG1529_6	47.24789810180664	-122.59559631347656	:America/Los_Angeles	USA	knots	145	330	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, East end	WA
99348	Hale Passage, east end (depth 11 ft), Puget Sound, Washington Current	NOS	PUG1529_11	47.24789810180664	-122.59559631347656	:America/Los_Angeles	USA	knots	145	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, East end	WA
99349	Hale Passage, west end (depth 70 ft), Puget Sound, Washington Current	NOS	PUG1530_1	47.28137969970703	-122.66311645507812	:America/Los_Angeles	USA	knots	113	282	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.349	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, West end	WA
99350	Hale Passage, west end (depth 40 ft), Puget Sound, Washington Current	NOS	PUG1530_10	47.28137969970703	-122.66311645507812	:America/Los_Angeles	USA	knots	99	283	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.461	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, West end	WA
99352	Gibson Point, 0.8 mi east of (depth 199 ft), Puget Sound, Washington Current	NOS	PUG1531_1	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	204.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.141	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99353	Gibson Point, 0.8 mi east of (depth 189 ft), Puget Sound, Washington Current	NOS	PUG1531_2	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	205.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99354	Gibson Point, 0.8 mi east of (depth 179 ft), Puget Sound, Washington Current	NOS	PUG1531_3	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	205.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99355	Gibson Point, 0.8 mi east of (depth 169 ft), Puget Sound, Washington Current	NOS	PUG1531_4	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	205.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99356	Gibson Point, 0.8 mi east of (depth 159 ft), Puget Sound, Washington Current	NOS	PUG1531_5	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	206	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.166	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99357	Gibson Point, 0.8 mi east of (depth 149 ft), Puget Sound, Washington Current	NOS	PUG1531_6	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	29	205	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99358	Gibson Point, 0.8 mi east of (depth 140 ft), Puget Sound, Washington Current	NOS	PUG1531_7	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	206.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99359	Gibson Point, 0.8 mi east of (depth 130 ft), Puget Sound, Washington Current	NOS	PUG1531_8	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	206.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99360	Gibson Point, 0.8 mi east of (depth 120 ft), Puget Sound, Washington Current	NOS	PUG1531_9	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	206.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99361	Gibson Point, 0.8 mi east of (depth 110 ft), Puget Sound, Washington Current	NOS	PUG1531_10	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	207.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99362	Gibson Point, 0.8 mi east of (depth 100 ft), Puget Sound, Washington Current	NOS	PUG1531_11	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	207.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99363	Gibson Point, 0.8 mi east of (depth 90 ft), Puget Sound, Washington Current	NOS	PUG1531_12	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	207.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99364	Gibson Point, 0.8 mi east of (depth 81 ft), Puget Sound, Washington Current	NOS	PUG1531_13	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	34	204	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99365	Gibson Point, 0.8 mi east of (depth 71 ft), Puget Sound, Washington Current	NOS	PUG1531_14	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	208.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99366	Gibson Point, 0.8 mi east of (depth 61 ft), Puget Sound, Washington Current	NOS	PUG1531_15	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	208.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99367	Gibson Point, 0.8 mi east of (depth 51 ft), Puget Sound, Washington Current	NOS	PUG1531_16	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	209.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99368	Gibson Point, 0.8 mi east of (depth 41 ft), Puget Sound, Washington Current	NOS	PUG1531_17	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	\N	210.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99369	Gibson Point, 0.8 mi east of (depth 31 ft), Puget Sound, Washington Current	NOS	PUG1531_18	47.21913146972656	-122.58866882324219	:America/Los_Angeles	USA	knots	42	204	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gibson Point, 0.8 miles East of	WA
99370	Steilacoom, 0.8 mi north of (depth 242 ft), Puget Sound, Washington Current	NOS	PUG1532_1	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	210.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99371	Steilacoom, 0.8 mi north of (depth 229 ft), Puget Sound, Washington Current	NOS	PUG1532_2	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	211	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99372	Steilacoom, 0.8 mi north of (depth 216 ft), Puget Sound, Washington Current	NOS	PUG1532_3	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	211.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99373	Steilacoom, 0.8 mi north of (depth 203 ft), Puget Sound, Washington Current	NOS	PUG1532_4	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	212.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99374	Steilacoom, 0.8 mi north of (depth 190 ft), Puget Sound, Washington Current	NOS	PUG1532_5	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	212.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99375	Steilacoom, 0.8 mi north of (depth 177 ft), Puget Sound, Washington Current	NOS	PUG1532_6	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	37	205	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99376	Steilacoom, 0.8 mi north of (depth 164 ft), Puget Sound, Washington Current	NOS	PUG1532_7	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	214.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99377	Steilacoom, 0.8 mi north of (depth 151 ft), Puget Sound, Washington Current	NOS	PUG1532_8	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	215.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99378	Steilacoom, 0.8 mi north of (depth 137 ft), Puget Sound, Washington Current	NOS	PUG1532_9	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	216.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99379	Steilacoom, 0.8 mi north of (depth 124 ft), Puget Sound, Washington Current	NOS	PUG1532_10	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	218.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99380	Steilacoom, 0.8 mi north of (depth 111 ft), Puget Sound, Washington Current	NOS	PUG1532_11	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	220.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99381	Steilacoom, 0.8 mi north of (depth 98 ft), Puget Sound, Washington Current	NOS	PUG1532_12	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	221.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99382	Steilacoom, 0.8 mi north of (depth 85 ft), Puget Sound, Washington Current	NOS	PUG1532_13	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	55	213	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99383	Steilacoom, 0.8 mi north of (depth 72 ft), Puget Sound, Washington Current	NOS	PUG1532_14	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	224.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99384	Steilacoom, 0.8 mi north of (depth 59 ft), Puget Sound, Washington Current	NOS	PUG1532_15	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	224.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99385	Steilacoom, 0.8 mi north of (depth 45 ft), Puget Sound, Washington Current	NOS	PUG1532_16	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	51	215	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99386	Steilacoom, 0.8 mi north of (depth 32 ft), Puget Sound, Washington Current	NOS	PUG1532_17	47.18238067626953	-122.60559844970703	:America/Los_Angeles	USA	knots	\N	225.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Steilacoom, 0.8 miles North of	WA
99387	Ketron Island, west of (depth 261 ft), Puget Sound, Washington Current	NOS	PUG1533_1	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	194.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99388	Ketron Island, west of (depth 248 ft), Puget Sound, Washington Current	NOS	PUG1533_2	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	195.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99389	Ketron Island, west of (depth 235 ft), Puget Sound, Washington Current	NOS	PUG1533_3	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	195.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.162	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99390	Ketron Island, west of (depth 222 ft), Puget Sound, Washington Current	NOS	PUG1533_4	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	195.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99391	Ketron Island, west of (depth 208 ft), Puget Sound, Washington Current	NOS	PUG1533_5	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	194.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99392	Ketron Island, west of (depth 195 ft), Puget Sound, Washington Current	NOS	PUG1533_6	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	194.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99393	Ketron Island, west of (depth 182 ft), Puget Sound, Washington Current	NOS	PUG1533_7	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	194.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99394	Ketron Island, west of (depth 169 ft), Puget Sound, Washington Current	NOS	PUG1533_8	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	195.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99395	Ketron Island, west of (depth 156 ft), Puget Sound, Washington Current	NOS	PUG1533_9	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	196.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99396	Ketron Island, west of (depth 143 ft), Puget Sound, Washington Current	NOS	PUG1533_10	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	12	206	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99397	Ketron Island, west of (depth 130 ft), Puget Sound, Washington Current	NOS	PUG1533_11	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	200.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99398	Ketron Island, west of (depth 117 ft), Puget Sound, Washington Current	NOS	PUG1533_12	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	202.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99399	Ketron Island, west of (depth 103 ft), Puget Sound, Washington Current	NOS	PUG1533_13	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	203.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99400	Ketron Island, west of (depth 90 ft), Puget Sound, Washington Current	NOS	PUG1533_14	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	12	208	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99401	Ketron Island, west of (depth 77 ft), Puget Sound, Washington Current	NOS	PUG1533_15	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	200.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99402	Ketron Island, west of (depth 64 ft), Puget Sound, Washington Current	NOS	PUG1533_16	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	197.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99403	Ketron Island, west of (depth 51 ft), Puget Sound, Washington Current	NOS	PUG1533_17	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	\N	193.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99404	Ketron Island, west of (depth 38 ft), Puget Sound, Washington Current	NOS	PUG1533_18	47.14860153198242	-122.6594009399414	:America/Los_Angeles	USA	knots	10	193	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ketron Island, West of	WA
99405	Nisqually Reach, 0.5 mi south of Lyle Point (depth 177 ft), Washington Current	NOS	PUG1534_1	47.11692810058594	-122.6988525390625	:America/Los_Angeles	USA	knots	77	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nisqually Reach, 0.5 miles South of Lyle Point	WA
99406	Nisqually Reach, 0.5 mi south of Lyle Point (depth 68 ft), Washington Current	NOS	PUG1534_12	47.11692810058594	-122.6988525390625	:America/Los_Angeles	USA	knots	86	257	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nisqually Reach, 0.5 miles South of Lyle Point	WA
99407	Nisqually Reach, 0.5 mi south of Lyle Point (depth 29 ft), Washington Current	NOS	PUG1534_16	47.11692810058594	-122.6988525390625	:America/Los_Angeles	USA	knots	88	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nisqually Reach, 0.5 miles South of Lyle Point	WA
99408	Balch Passage, NE of Eagle Island (depth 60 ft), Puget Sound, Washington Current	NOS	PUG1535_1	47.19062042236328	-122.6915512084961	:America/Los_Angeles	USA	knots	108	288	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Balch Passage, NE of Eagle Island	WA
99410	Balch Passage, NE of Eagle Island (depth 11 ft), Puget Sound, Washington Current	NOS	PUG1535_16	47.19062042236328	-122.6915512084961	:America/Los_Angeles	USA	knots	104	287	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.311	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Balch Passage, NE of Eagle Island	WA
99411	Pitt Passage, NE of Pitt Island (depth 23 ft), Puget Sound, Washington Current	NOS	PUG1536_1	47.22383117675781	-122.71137237548828	:America/Los_Angeles	USA	knots	23	202	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.287	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pitt Passage, NE of Pitt Island	WA
99412	Pitt Passage, NE of Pitt Island (depth 7 ft), Puget Sound, Washington Current	NOS	PUG1536_6	47.22383117675781	-122.71137237548828	:America/Los_Angeles	USA	knots	29	196	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.318	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pitt Passage, NE of Pitt Island	WA
99413	Drayton Passage (depth 118 ft), Puget Sound, Washington Current	NOS	PUG1537_5	47.17258071899414	-122.7414779663086	:America/Los_Angeles	USA	knots	34	213	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drayton Passage	WA
99414	Drayton Passage (depth 52 ft), Puget Sound, Washington Current	NOS	PUG1537_15	47.17258071899414	-122.7414779663086	:America/Los_Angeles	USA	knots	23	210	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drayton Passage	WA
99415	Drayton Passage (depth 19 ft), Puget Sound, Washington Current	NOS	PUG1537_20	47.17258071899414	-122.7414779663086	:America/Los_Angeles	USA	knots	31	215	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Drayton Passage	WA
99416	Devils Head, west of (depth 191 ft), Puget Sound, Washington Current	NOS	PUG1538_5	47.16067123413086	-122.78936767578125	:America/Los_Angeles	USA	knots	159	324	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devils Head, West of	WA
99417	Devils Head, west of (depth 83 ft), Puget Sound, Washington Current	NOS	PUG1538_16	47.16067123413086	-122.78936767578125	:America/Los_Angeles	USA	knots	153	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devils Head, West of	WA
99418	Devils Head, west of (depth 24 ft), Puget Sound, Washington Current	NOS	PUG1538_22	47.16067123413086	-122.78936767578125	:America/Los_Angeles	USA	knots	156	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.227	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Devils Head, West of	WA
99419	Dana Passage (depth 88 ft), Puget Sound, Washington Current	NOS	PUG1539_1	47.16310119628906	-122.86810302734375	:America/Los_Angeles	USA	knots	43	232	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dana Passage	WA
99420	Dana Passage (depth 43 ft), Puget Sound, Washington Current	NOS	PUG1539_8	47.16310119628906	-122.86810302734375	:America/Los_Angeles	USA	knots	48	239	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.167	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dana Passage	WA
99421	Dana Passage (depth 16 ft), Puget Sound, Washington Current	NOS	PUG1539_12	47.16310119628906	-122.86810302734375	:America/Los_Angeles	USA	knots	49	242	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.176	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dana Passage	WA
99422	Budd Inlet entrance (depth 71 ft), Puget Sound, Washington Current	NOS	PUG1540_1	47.140159606933594	-122.92144775390625	:America/Los_Angeles	USA	knots	2	170	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Budd Inlet Entrance	WA
99423	Budd Inlet entrance (depth 32 ft), Puget Sound, Washington Current	NOS	PUG1540_7	47.140159606933594	-122.92144775390625	:America/Los_Angeles	USA	knots	4	172	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Budd Inlet Entrance	WA
99424	Budd Inlet entrance (depth 12 ft), Puget Sound, Washington Current	NOS	PUG1540_10	47.140159606933594	-122.92144775390625	:America/Los_Angeles	USA	knots	10	184	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Budd Inlet Entrance	WA
99425	Peale Passage, south end (depth 35 ft), Puget Sound, Washington Current	NOS	PUG1541_1	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	159	338	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
99426	Peale Passage, south end (depth 32 ft), Puget Sound, Washington Current	NOS	PUG1541_2	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	\N	338.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
99442	Squaxin Passage, north of Hunter Point (depth 18 ft), Puget Sound, Washington Current	NOS	PUG1543_5	47.17626953125	-122.91899871826172	:America/Los_Angeles	USA	knots	108	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Squaxin Passage, North of Hunter Point	WA
99427	Peale Passage, south end (depth 29 ft), Puget Sound, Washington Current	NOS	PUG1541_3	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	\N	338.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
99428	Peale Passage, south end (depth 26 ft), Puget Sound, Washington Current	NOS	PUG1541_4	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	\N	339.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
99429	Peale Passage, south end (depth 22 ft), Puget Sound, Washington Current	NOS	PUG1541_5	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	157	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
99430	Peale Passage, south end (depth 19 ft), Puget Sound, Washington Current	NOS	PUG1541_6	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	\N	341.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
99431	Peale Passage, south end (depth 16 ft), Puget Sound, Washington Current	NOS	PUG1541_7	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	\N	342.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
99432	Peale Passage, south end (depth 12 ft), Puget Sound, Washington Current	NOS	PUG1541_8	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	\N	343.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
99433	Peale Passage, south end (depth 9 ft), Puget Sound, Washington Current	NOS	PUG1541_9	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	16	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
99434	Peale Passage, south end (depth 6 ft), Puget Sound, Washington Current	NOS	PUG1541_10	47.174949645996094	-122.88697052001953	:America/Los_Angeles	USA	knots	\N	342.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, South end	WA
99435	Peale Passage, north end (depth 17 ft), Puget Sound, Washington Current	NOS	PUG1542_1	47.21752166748047	-122.9146499633789	:America/Los_Angeles	USA	knots	132	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, North end	WA
99436	Peale Passage, north end (depth 14 ft), Puget Sound, Washington Current	NOS	PUG1542_2	47.21752166748047	-122.9146499633789	:America/Los_Angeles	USA	knots	\N	314.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, North end	WA
99437	Peale Passage, north end (depth 11 ft), Puget Sound, Washington Current	NOS	PUG1542_3	47.21752166748047	-122.9146499633789	:America/Los_Angeles	USA	knots	\N	315.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, North end	WA
99438	Peale Passage, north end (depth 7 ft), Puget Sound, Washington Current	NOS	PUG1542_4	47.21752166748047	-122.9146499633789	:America/Los_Angeles	USA	knots	\N	316.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, North end	WA
99439	Peale Passage, north end (depth 4 ft), Puget Sound, Washington Current	NOS	PUG1542_5	47.21752166748047	-122.9146499633789	:America/Los_Angeles	USA	knots	135	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, North end	WA
99440	Peale Passage, north end (depth 1 ft), Puget Sound, Washington Current	NOS	PUG1542_6	47.21752166748047	-122.9146499633789	:America/Los_Angeles	USA	knots	\N	318.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peale Passage, North end	WA
99441	Squaxin Passage, north of Hunter Point (depth 32 ft), Puget Sound, Washington Current	NOS	PUG1543_1	47.17626953125	-122.91899871826172	:America/Los_Angeles	USA	knots	107	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Squaxin Passage, North of Hunter Point	WA
99443	Squaxin Passage, north of Hunter Point (depth 5 ft), Puget Sound, Washington Current	NOS	PUG1543_9	47.17626953125	-122.91899871826172	:America/Los_Angeles	USA	knots	110	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Squaxin Passage, North of Hunter Point	WA
99444	Totten Inlet entrance (depth 67 ft), Puget Sound, Washington Current	NOS	PUG1544_3	47.18825149536133	-122.94537353515625	:America/Los_Angeles	USA	knots	52	229	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.195	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Totten Inlet Entrance	WA
99445	Totten Inlet entrance (depth 41 ft), Puget Sound, Washington Current	NOS	PUG1544_7	47.18825149536133	-122.94537353515625	:America/Los_Angeles	USA	knots	39	227	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Totten Inlet Entrance	WA
99446	Totten Inlet entrance (depth 14 ft), Puget Sound, Washington Current	NOS	PUG1544_11	47.18825149536133	-122.94537353515625	:America/Los_Angeles	USA	knots	31	222	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Totten Inlet Entrance	WA
99447	Libby Point, Hammersley Inlet (depth 19 ft), Puget Sound, Washington Current	NOS	PUG1545_1	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	77	261	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
99448	Libby Point, Hammersley Inlet (depth 18 ft), Puget Sound, Washington Current	NOS	PUG1545_2	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	\N	259.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.301	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
99449	Libby Point, Hammersley Inlet (depth 16 ft), Puget Sound, Washington Current	NOS	PUG1545_3	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	\N	259.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
99450	Libby Point, Hammersley Inlet (depth 15 ft), Puget Sound, Washington Current	NOS	PUG1545_4	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	\N	259.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.352	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
99451	Libby Point, Hammersley Inlet (depth 13 ft), Puget Sound, Washington Current	NOS	PUG1545_5	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	\N	259.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.377	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
99452	Libby Point, Hammersley Inlet (depth 11 ft), Puget Sound, Washington Current	NOS	PUG1545_6	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	\N	259.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.399	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
99453	Libby Point, Hammersley Inlet (depth 10 ft), Puget Sound, Washington Current	NOS	PUG1545_7	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	\N	259.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.419	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
99454	Libby Point, Hammersley Inlet (depth 8 ft), Puget Sound, Washington Current	NOS	PUG1545_8	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	\N	259.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.437	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
99455	Libby Point, Hammersley Inlet (depth 6 ft), Puget Sound, Washington Current	NOS	PUG1545_9	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	\N	259.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.452	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
99456	Libby Point, Hammersley Inlet (depth 5 ft), Puget Sound, Washington Current	NOS	PUG1545_10	47.19892120361328	-122.98899841308594	:America/Los_Angeles	USA	knots	84	254	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.448	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Libby Point, Hammersley Inlet	WA
99457	Pickering Passage, west of Squaxin Island (depth 52 ft), Puget Sound, Washington Current	NOS	PUG1546_1	47.21928024291992	-122.93451690673828	:America/Los_Angeles	USA	knots	13	191	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, West of Squaxin Island	WA
99458	Pickering Passage, west of Squaxin Island (depth 29 ft), Puget Sound, Washington Current	NOS	PUG1546_8	47.21928024291992	-122.93451690673828	:America/Los_Angeles	USA	knots	6	194	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, West of Squaxin Island	WA
99459	Pickering Passage, west of Squaxin Island (depth 9 ft), Puget Sound, Washington Current	NOS	PUG1546_14	47.21928024291992	-122.93451690673828	:America/Los_Angeles	USA	knots	3	194	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, West of Squaxin Island	WA
99460	Pickering Passage, off Graham Point (depth 59 ft), Puget Sound, Washington Current	NOS	PUG1547_1	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	27	207	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
99461	Pickering Passage, off Graham Point (depth 56 ft), Puget Sound, Washington Current	NOS	PUG1547_2	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	206.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
99462	Pickering Passage, off Graham Point (depth 53 ft), Puget Sound, Washington Current	NOS	PUG1547_3	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	205.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
99463	Pickering Passage, off Graham Point (depth 49 ft), Puget Sound, Washington Current	NOS	PUG1547_4	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	204.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
99464	Pickering Passage, off Graham Point (depth 46 ft), Puget Sound, Washington Current	NOS	PUG1547_5	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	203.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
99465	Pickering Passage, off Graham Point (depth 43 ft), Puget Sound, Washington Current	NOS	PUG1547_6	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	202.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
99466	Pickering Passage, off Graham Point (depth 39 ft), Puget Sound, Washington Current	NOS	PUG1547_7	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	202	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
99467	Pickering Passage, off Graham Point (depth 36 ft), Puget Sound, Washington Current	NOS	PUG1547_8	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	201.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
99468	Pickering Passage, off Graham Point (depth 33 ft), Puget Sound, Washington Current	NOS	PUG1547_9	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	200.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
99469	Pickering Passage, off Graham Point (depth 30 ft), Puget Sound, Washington Current	NOS	PUG1547_10	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	22	198	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
99470	Pickering Passage, off Graham Point (depth 26 ft), Puget Sound, Washington Current	NOS	PUG1547_11	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	199.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
99471	Pickering Passage, off Graham Point (depth 23 ft), Puget Sound, Washington Current	NOS	PUG1547_12	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	199.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
99472	Pickering Passage, off Graham Point (depth 20 ft), Puget Sound, Washington Current	NOS	PUG1547_13	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	199.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
99473	Pickering Passage, off Graham Point (depth 16 ft), Puget Sound, Washington Current	NOS	PUG1547_14	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	198.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
100786	Burnt Island-Oak Island, between (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0181_1	44.19117	-68.81883	:America/New_York	USA	knots	98	290	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:28:00	\N	1.2	-00:55:00	\N	1	-00:28:00	-01:59:00	Burnt Island-Oak Island, between	ME
99474	Pickering Passage, off Graham Point (depth 13 ft), Puget Sound, Washington Current	NOS	PUG1547_15	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	198.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
99475	Pickering Passage, off Graham Point (depth 10 ft), Puget Sound, Washington Current	NOS	PUG1547_16	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	19	198	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
99476	Pickering Passage, off Graham Point (depth 7 ft), Puget Sound, Washington Current	NOS	PUG1547_17	47.247249603271484	-122.92591857910156	:America/Los_Angeles	USA	knots	\N	198.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, off Graham Point	WA
99477	Pickering Passage, north end (depth 78 ft), Puget Sound, Washington Current	NOS	PUG1548_1	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	69	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
99478	Pickering Passage, north end (depth 71 ft), Puget Sound, Washington Current	NOS	PUG1548_2	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	\N	255.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.098	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
99479	Pickering Passage, north end (depth 65 ft), Puget Sound, Washington Current	NOS	PUG1548_3	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	\N	255.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
99480	Pickering Passage, north end (depth 58 ft), Puget Sound, Washington Current	NOS	PUG1548_4	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	\N	255.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
99481	Pickering Passage, north end (depth 52 ft), Puget Sound, Washington Current	NOS	PUG1548_5	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	\N	254.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
99482	Pickering Passage, north end (depth 45 ft), Puget Sound, Washington Current	NOS	PUG1548_6	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	64	260	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
99483	Pickering Passage, north end (depth 39 ft), Puget Sound, Washington Current	NOS	PUG1548_7	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	\N	251.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
99484	Pickering Passage, north end (depth 32 ft), Puget Sound, Washington Current	NOS	PUG1548_8	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	\N	249.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
99485	Pickering Passage, north end (depth 25 ft), Puget Sound, Washington Current	NOS	PUG1548_9	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	\N	246.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
99486	Pickering Passage, north end (depth 19 ft), Puget Sound, Washington Current	NOS	PUG1548_10	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	52	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
99487	Pickering Passage, north end (depth 12 ft), Puget Sound, Washington Current	NOS	PUG1548_11	47.305721282958984	-122.85092163085938	:America/Los_Angeles	USA	knots	\N	244.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pickering Passage, North end	WA
99488	Hazel Point (depth 154 ft), Hood Canal, Washington Current	NOS	PUG1601_1	47.69123840332031	-122.76278686523438	:America/Los_Angeles	USA	knots	20	193	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hazel Point	WA
99489	Hazel Point (depth 88 ft), Hood Canal, Washington Current	NOS	PUG1601_11	47.69123840332031	-122.76278686523438	:America/Los_Angeles	USA	knots	23	200	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hazel Point	WA
99490	Hazel Point (depth 23 ft), Hood Canal, Washington Current	NOS	PUG1601_21	47.69123840332031	-122.76278686523438	:America/Los_Angeles	USA	knots	13	181	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hazel Point	WA
99491	South Point (depth 178 ft), Hood Canal, Washington Current	NOS	PUG1602_1	47.821659088134766	-122.67671966552734	:America/Los_Angeles	USA	knots	41	234	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Point	WA
99492	South Point (depth 43 ft), Hood Canal, Washington Current	NOS	PUG1602_42	47.821659088134766	-122.67671966552734	:America/Los_Angeles	USA	knots	42	231	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Point	WA
99493	South Point (depth 24 ft), Hood Canal, Washington Current	NOS	PUG1602_48	47.821659088134766	-122.67671966552734	:America/Los_Angeles	USA	knots	41	230	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.123	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Point	WA
99494	Hood Canal Bridge (depth 209 ft), Washington Current	NOS	PUG1603_1	47.854740142822266	-122.6294174194336	:America/Los_Angeles	USA	knots	37	223	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Bridge	WA
99495	Hood Canal Bridge (depth 111 ft), Washington Current	NOS	PUG1603_11	47.854740142822266	-122.6294174194336	:America/Los_Angeles	USA	knots	45	223	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Bridge	WA
99496	Hood Canal Bridge (depth 22 ft), Washington Current	NOS	PUG1603_20	47.854740142822266	-122.6294174194336	:America/Los_Angeles	USA	knots	46	219	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Bridge	WA
99497	Port Gamble Bay entrance (depth 32 ft), Hood Canal, Washington Current	NOS	PUG1604_1	47.85472106933594	-122.57817840576172	:America/Los_Angeles	USA	knots	20	204	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.133	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Gamble Bay Entrance	WA
99498	Port Gamble Bay entrance (depth 10 ft), Hood Canal, Washington Current	NOS	PUG1604_8	47.85472106933594	-122.57817840576172	:America/Los_Angeles	USA	knots	14	197	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Gamble Bay Entrance	WA
99499	Possession Sound entrance (depth 322 ft), Washington Current	NOS	PUG1605_20	47.89929962158203	-122.36009979248047	:America/Los_Angeles	USA	knots	199	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Possession Sound Entrance	WA
99500	Possession Sound entrance (depth 190 ft), Washington Current	NOS	PUG1605_30	47.89929962158203	-122.36009979248047	:America/Los_Angeles	USA	knots	198	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Possession Sound Entrance	WA
99501	Possession Sound entrance (depth 59 ft), Washington Current	NOS	PUG1605_40	47.89929962158203	-122.36009979248047	:America/Los_Angeles	USA	knots	204	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Possession Sound Entrance	WA
99502	Point No Point, 1.2 mi E of (depth 567 ft), Puget Sound, Washington Current	NOS	PUG1606_1	47.91249084472656	-122.50196838378906	:America/Los_Angeles	USA	knots	321	149	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.433	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 1.2 mi. E of	WA
99503	Point No Point, 1.2 mi E of (depth 108 ft), Puget Sound, Washington Current	NOS	PUG1606_36	47.91249084472656	-122.50196838378906	:America/Los_Angeles	USA	knots	338	164	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.285	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 1.2 mi. E of	WA
99504	Point No Point, 1.2 mi E of (depth 69 ft), Puget Sound, Washington Current	NOS	PUG1606_39	47.91249084472656	-122.50196838378906	:America/Los_Angeles	USA	knots	336	164	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.321	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 1.2 mi. E of	WA
99505	Point No Point, 2.1 mi E of (depth 240 ft), Puget Sound, Washington Current	NOS	PUG1607_1	47.918880462646484	-122.484130859375	:America/Los_Angeles	USA	knots	327	135	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.203	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 2.1 mi. E of	WA
99506	Point No Point, 2.1 mi E of (depth 57 ft), Puget Sound, Washington Current	NOS	PUG1607_29	47.918880462646484	-122.484130859375	:America/Los_Angeles	USA	knots	330	134	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.261	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 2.1 mi. E of	WA
99507	Point No Point, 2.1 mi E of (depth 31 ft), Puget Sound, Washington Current	NOS	PUG1607_33	47.918880462646484	-122.484130859375	:America/Los_Angeles	USA	knots	331	129	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.293	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point No Point, 2.1 mi. E of	WA
99508	Hood Canal entrance, Foulweather Bluff (depth 255 ft), Washington Current	NOS	PUG1608_1	47.92837905883789	-122.6388168334961	:America/Los_Angeles	USA	knots	0	173	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.19	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Entrance, Foulweather Bluff	WA
99509	Hood Canal entrance, Foulweather Bluff (depth 78 ft), Washington Current	NOS	PUG1608_28	47.92837905883789	-122.6388168334961	:America/Los_Angeles	USA	knots	352	164	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Entrance, Foulweather Bluff	WA
99510	Hood Canal entrance, Foulweather Bluff (depth 32 ft), Washington Current	NOS	PUG1608_35	47.92837905883789	-122.6388168334961	:America/Los_Angeles	USA	knots	340	153	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hood Canal Entrance, Foulweather Bluff	WA
99511	West of Mukilteo (depth 272 ft), Washington Current	NOS	PUG1609_20	47.948951721191406	-122.32846069335938	:America/Los_Angeles	USA	knots	205	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Mukilteo	WA
99512	West of Mukilteo (depth 140 ft), Washington Current	NOS	PUG1609_30	47.948951721191406	-122.32846069335938	:America/Los_Angeles	USA	knots	205	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Mukilteo	WA
99513	West of Mukilteo (depth 62 ft), Washington Current	NOS	PUG1609_36	47.948951721191406	-122.32846069335938	:America/Los_Angeles	USA	knots	198	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Mukilteo	WA
99514	Foulweather Bluff, 1.9 mi NE of (depth 125 ft), Puget Sound, Washington Current	NOS	PUG1610_17	47.95429992675781	-122.57859802246094	:America/Los_Angeles	USA	knots	305	141	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff, 1.9 mi. NE of	WA
99515	Foulweather Bluff, 1.9 mi NE of (depth 27 ft), Puget Sound, Washington Current	NOS	PUG1610_32	47.95429992675781	-122.57859802246094	:America/Los_Angeles	USA	knots	304	125	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.297	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff, 1.9 mi. NE of	WA
99516	Foulweather Bluff, 1.9 mi NE of (depth 20 ft), Puget Sound, Washington Current	NOS	PUG1610_33	47.95429992675781	-122.57859802246094	:America/Los_Angeles	USA	knots	302	125	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Foulweather Bluff, 1.9 mi. NE of	WA
99517	Olele Point, 1.8 mi ENE of (depth 148 ft), Admiralty Inlet, Washington Current	NOS	PUG1611_10	47.97880935668945	-122.64549255371094	:America/Los_Angeles	USA	knots	333	189	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olele Point, 1.8 mi. ENE of	WA
99518	Olele Point, 1.8 mi ENE of (depth 66 ft), Admiralty Inlet, Washington Current	NOS	PUG1611_35	47.97880935668945	-122.64549255371094	:America/Los_Angeles	USA	knots	340	169	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olele Point, 1.8 mi. ENE of	WA
99519	Olele Point, 1.8 mi ENE of (depth 20 ft), Admiralty Inlet, Washington Current	NOS	PUG1611_49	47.97880935668945	-122.64549255371094	:America/Los_Angeles	USA	knots	342	149	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Olele Point, 1.8 mi. ENE of	WA
99520	Clinton Ferry Terminal (depth 80 ft), Washington Current	NOS	PUG1612_1	47.96899	-122.34507	:America/Los_Angeles	USA	knots	184	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Ferry Terminal	WA
99521	Clinton Ferry Terminal (depth 47 ft), Washington Current	NOS	PUG1612_6	47.96899	-122.34507	:America/Los_Angeles	USA	knots	187	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Ferry Terminal	WA
99522	Clinton Ferry Terminal (depth 21 ft), Washington Current	NOS	PUG1612_10	47.96899	-122.34507	:America/Los_Angeles	USA	knots	178	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clinton Ferry Terminal	WA
99523	Port Townsend Canal (depth 15 ft), Admiralty Inlet, Washington Current	NOS	PUG1614_1	48.032470703125	-122.73261260986328	:America/Los_Angeles	USA	knots	323	145	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.619	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Townsend Canal	WA
99524	Port Townsend Canal (depth 5 ft), Admiralty Inlet, Washington Current	NOS	PUG1614_7	48.032470703125	-122.73261260986328	:America/Los_Angeles	USA	knots	323	140	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.836	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Townsend Canal	WA
99525	Nodule Point, 0.5 mi SE of (depth 65 ft), Admiralty Inlet, Washington Current	NOS	PUG1615_1	48.028709411621094	-122.660888671875	:America/Los_Angeles	USA	knots	347	162	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.214	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nodule Point, 0.5 mi. SE of	WA
99526	Nodule Point, 0.5 mi SE of (depth 25 ft), Admiralty Inlet, Washington Current	NOS	PUG1615_13	48.028709411621094	-122.660888671875	:America/Los_Angeles	USA	knots	353	162	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.573	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nodule Point, 0.5 mi. SE of	WA
99527	Nodule Point, 0.5 mi SE of (depth 9 ft), Admiralty Inlet, Washington Current	NOS	PUG1615_18	48.028709411621094	-122.660888671875	:America/Los_Angeles	USA	knots	357	162	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.589	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Nodule Point, 0.5 mi. SE of	WA
99528	Admiralty Inlet (off Bush Point) (depth 193 ft), Washington Current	NOS	PUG1616_6	48.03348159790039	-122.63764953613281	:America/Los_Angeles	USA	knots	0	176	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.199	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Admiralty Inlet (off Bush Point)	WA
99529	Admiralty Inlet (off Bush Point) (depth 68 ft), Washington Current	NOS	PUG1616_25	48.03348159790039	-122.63764953613281	:America/Los_Angeles	USA	knots	349	181	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.312	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Admiralty Inlet (off Bush Point)	WA
99530	Admiralty Inlet (off Bush Point) (depth 29 ft), Washington Current	NOS	PUG1616_31	48.03348159790039	-122.63764953613281	:America/Los_Angeles	USA	knots	347	180	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.529	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Admiralty Inlet (off Bush Point)	WA
99531	Bush Point Light, 0.5 mi NW of (depth 208 ft), Admiralty Inlet, Washington Current	NOS	PUG1617_14	48.03084182739258	-122.61334228515625	:America/Los_Angeles	USA	knots	348	187	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.294	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bush Point Light, 0.5 mile NW of	WA
99532	Bush Point Light, 0.5 mi NW of (depth 77 ft), Admiralty Inlet, Washington Current	NOS	PUG1617_34	48.03084182739258	-122.61334228515625	:America/Los_Angeles	USA	knots	338	189	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bush Point Light, 0.5 mile NW of	WA
99533	Bush Point Light, 0.5 mi NW of (depth 44 ft), Admiralty Inlet, Washington Current	NOS	PUG1617_39	48.03084182739258	-122.61334228515625	:America/Los_Angeles	USA	knots	336	189	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bush Point Light, 0.5 mile NW of	WA
99534	Camano Head-Sandy Point, passage (depth 209 ft), Washington Current	NOS	PUG1618_15	48.0478515625	-122.38896942138672	:America/Los_Angeles	USA	knots	119	303	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Camano Head-Sandy Point, passage	WA
99535	Camano Head-Sandy Point, passage (depth 78 ft), Washington Current	NOS	PUG1618_35	48.0478515625	-122.38896942138672	:America/Los_Angeles	USA	knots	117	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Camano Head-Sandy Point, passage	WA
99536	Camano Head-Sandy Point, passage (depth 32 ft), Washington Current	NOS	PUG1618_42	48.0478515625	-122.38896942138672	:America/Los_Angeles	USA	knots	117	303	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Camano Head-Sandy Point, passage	WA
99537	Marrowstone Point, 0.8 mi NE of (depth 151 ft), Admiralty Inlet, Washington Current	NOS	PUG1619_9	48.10633087158203	-122.67247009277344	:America/Los_Angeles	USA	knots	344	119	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.269	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 0.8 mi. NE of	WA
99538	Marrowstone Point, 0.8 mi NE of (depth 75 ft), Admiralty Inlet, Washington Current	NOS	PUG1619_32	48.10633087158203	-122.67247009277344	:America/Los_Angeles	USA	knots	346	124	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 0.8 mi. NE of	WA
99976	Mud Bay (depth 27 ft), Prince William Sound, Alaska Current	NOS	PWS0735_5	60.54765	-145.84088	:America/Anchorage	USA	knots	63	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mud Bay	AK
99539	Marrowstone Point, 0.8 mi NE of (depth 29 ft), Admiralty Inlet, Washington Current	NOS	PUG1619_46	48.10633087158203	-122.67247009277344	:America/Los_Angeles	USA	knots	349	129	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 0.8 mi. NE of	WA
99540	Marrowstone Point, 1.65 mi NE of (depth 144 ft), Admiralty Inlet, Washington Current	NOS	PUG1620_10	48.119300842285156	-122.66226959228516	:America/Los_Angeles	USA	knots	315	139	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.301	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 1.65 mi. NE of	WA
99541	Marrowstone Point, 1.65 mi NE of (depth 79 ft), Admiralty Inlet, Washington Current	NOS	PUG1620_20	48.119300842285156	-122.66226959228516	:America/Los_Angeles	USA	knots	326	142	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 1.65 mi. NE of	WA
99542	Marrowstone Point, 1.65 mi NE of (depth 26 ft), Admiralty Inlet, Washington Current	NOS	PUG1620_28	48.119300842285156	-122.66226959228516	:America/Los_Angeles	USA	knots	333	145	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Marrowstone Point, 1.65 mi. NE of	WA
99543	West of Camano Island (depth 180 ft), Washington Current	NOS	PUG1622_3	48.169681549072266	-122.5531997680664	:America/Los_Angeles	USA	knots	159	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Camano Island	WA
99544	West of Camano Island (depth 69 ft), Washington Current	NOS	PUG1622_20	48.169681549072266	-122.5531997680664	:America/Los_Angeles	USA	knots	151	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Camano Island	WA
99545	West of Camano Island (depth 23 ft), Washington Current	NOS	PUG1622_27	48.169681549072266	-122.5531997680664	:America/Los_Angeles	USA	knots	159	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West of Camano Island	WA
99546	Point Wilson, 0.6 mi NE of (depth 118 ft), Admiralty Inlet, Washington Current	NOS	PUG1623_14	48.150108337402344	-122.745361328125	:America/Los_Angeles	USA	knots	325	132	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 0.6 mi. NE of	WA
99547	Point Wilson, 0.6 mi NE of (depth 56 ft), Admiralty Inlet, Washington Current	NOS	PUG1623_33	48.150108337402344	-122.745361328125	:America/Los_Angeles	USA	knots	322	124	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 0.6 mi. NE of	WA
99548	Point Wilson, 0.6 mi NE of (depth 17 ft), Admiralty Inlet, Washington Current	NOS	PUG1623_45	48.150108337402344	-122.745361328125	:America/Los_Angeles	USA	knots	321	120	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.261	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 0.6 mi. NE of	WA
99549	Point Wilson, 1.6 mi NE of (depth 149 ft), Admiralty Inlet, Washington Current	NOS	PUG1624_8	48.156898498535156	-122.72599792480469	:America/Los_Angeles	USA	knots	316	116	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 1.6 mi. NE of	WA
99550	Point Wilson, 1.6 mi NE of (depth 87 ft), Admiralty Inlet, Washington Current	NOS	PUG1624_27	48.156898498535156	-122.72599792480469	:America/Los_Angeles	USA	knots	316	117	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 1.6 mi. NE of	WA
99551	Point Wilson, 1.6 mi NE of (depth 21 ft), Admiralty Inlet, Washington Current	NOS	PUG1624_47	48.156898498535156	-122.72599792480469	:America/Los_Angeles	USA	knots	319	126	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 1.6 mi. NE of	WA
99552	Point Wilson, 2.7 mi NE of (depth 118 ft), Admiralty Inlet, Washington Current	NOS	PUG1625_15	48.16706848144531	-122.70738983154297	:America/Los_Angeles	USA	knots	333	135	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 2.7 mi. NE of	WA
99553	Point Wilson, 2.7 mi NE of (depth 56 ft), Admiralty Inlet, Washington Current	NOS	PUG1625_34	48.16706848144531	-122.70738983154297	:America/Los_Angeles	USA	knots	333	137	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 2.7 mi. NE of	WA
99554	Point Wilson, 2.7 mi NE of (depth 20 ft), Admiralty Inlet, Washington Current	NOS	PUG1625_45	48.16706848144531	-122.70738983154297	:America/Los_Angeles	USA	knots	333	138	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Wilson, 2.7 mi. NE of	WA
99555	Skagit Bay, 1 mi north of Rocky Point (depth 54 ft), Washington Current	NOS	PUG1626_7	48.2671012878418	-122.52960205078125	:America/Los_Angeles	USA	knots	243	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. north of Rocky Point	WA
99556	Skagit Bay, 1 mi north of Rocky Point (depth 28 ft), Washington Current	NOS	PUG1626_15	48.2671012878418	-122.52960205078125	:America/Los_Angeles	USA	knots	246	51	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. north of Rocky Point	WA
99557	Skagit Bay, 1 mi north of Rocky Point (depth 12 ft), Washington Current	NOS	PUG1626_20	48.2671012878418	-122.52960205078125	:America/Los_Angeles	USA	knots	234	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. north of Rocky Point	WA
99558	Skagit Bay, 1 mi south of Goat Island (depth 52 ft), Washington Current	NOS	PUG1627_5	48.34477996826172	-122.54505157470703	:America/Los_Angeles	USA	knots	154	332	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. south of Goat Island	WA
99559	Skagit Bay, 1 mi south of Goat Island (depth 32 ft), Washington Current	NOS	PUG1627_11	48.34477996826172	-122.54505157470703	:America/Los_Angeles	USA	knots	149	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. south of Goat Island	WA
99560	Skagit Bay, 1 mi south of Goat Island (depth 12 ft), Washington Current	NOS	PUG1627_17	48.34477996826172	-122.54505157470703	:America/Los_Angeles	USA	knots	147	329	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay, 1 mi. south of Goat Island	WA
99561	Skagit Bay channel, SW of Hope Island (depth 39 ft), Washington Current	NOS	PUG1628_4	48.397830963134766	-122.57955169677734	:America/Los_Angeles	USA	knots	174	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay channel, SW of Hope Island	WA
99562	Skagit Bay channel, SW of Hope Island (depth 26 ft), Washington Current	NOS	PUG1628_8	48.397830963134766	-122.57955169677734	:America/Los_Angeles	USA	knots	168	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay channel, SW of Hope Island	WA
99563	Skagit Bay channel, SW of Hope Island (depth 10 ft), Washington Current	NOS	PUG1628_13	48.397830963134766	-122.57955169677734	:America/Los_Angeles	USA	knots	170	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Skagit Bay channel, SW of Hope Island	WA
99564	Yokeko Point, Deception Pass (depth 27 ft), Rosario Strait, Washington Current	NOS	PUG1629_3	48.4127197265625	-122.61316680908203	:America/Los_Angeles	USA	knots	226	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yokeko Point, Deception Pass	WA
99565	Yokeko Point, Deception Pass (depth 14 ft), Rosario Strait, Washington Current	NOS	PUG1629_7	48.4127197265625	-122.61316680908203	:America/Los_Angeles	USA	knots	228	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yokeko Point, Deception Pass	WA
99566	Yokeko Point, Deception Pass (depth 7 ft), Rosario Strait, Washington Current	NOS	PUG1629_9	48.4127197265625	-122.61316680908203	:America/Los_Angeles	USA	knots	230	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yokeko Point, Deception Pass	WA
99567	Kanem Point, 1.5 mi SW of Protection Island (depth 97 ft), Washington Current	NOS	PUG1630_30	48.10765075683594	-122.97364807128906	:America/Los_Angeles	USA	knots	289	121	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanem Point, 1.5 mi. SW of Protection Island	WA
99568	Kanem Point, 1.5 mi SW of Protection Island (depth 55 ft), Washington Current	NOS	PUG1630_43	48.10765075683594	-122.97364807128906	:America/Los_Angeles	USA	knots	284	125	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.188	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanem Point, 1.5 mi. SW of Protection Island	WA
99569	Kanem Point, 1.5 mi SW of Protection Island (depth 22 ft), Washington Current	NOS	PUG1630_53	48.10765075683594	-122.97364807128906	:America/Los_Angeles	USA	knots	279	117	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kanem Point, 1.5 mi. SW of Protection Island	WA
99570	Violet Point, 3.7 mi NW of Protection Island (depth 112 ft), Washington Current	NOS	PUG1631_4	48.161399841308594	-122.96810150146484	:America/Los_Angeles	USA	knots	304	107	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Violet Point, 3.7 mi. NW of Protection Island	WA
99571	Violet Point, 3.7 mi NW of Protection Island (depth 40 ft), Washington Current	NOS	PUG1631_26	48.161399841308594	-122.96810150146484	:America/Los_Angeles	USA	knots	297	103	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Violet Point, 3.7 mi. NW of Protection Island	WA
99572	Violet Point, 3.7 mi NW of Protection Island (depth 17 ft), Washington Current	NOS	PUG1631_33	48.161399841308594	-122.96810150146484	:America/Los_Angeles	USA	knots	290	102	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Violet Point, 3.7 mi. NW of Protection Island	WA
99573	Smith Island, 5.5 mi WNW of (depth 220 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1632_14	48.32455062866211	-122.96475219726562	:America/Los_Angeles	USA	knots	253	78	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 5.5 mi. WNW of	WA
99574	Smith Island, 5.5 mi WNW of (depth 141 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1632_26	48.32455062866211	-122.96475219726562	:America/Los_Angeles	USA	knots	253	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 5.5 mi. WNW of	WA
99575	Smith Island, 5.5 mi WNW of (depth 43 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1632_41	48.32455062866211	-122.96475219726562	:America/Los_Angeles	USA	knots	255	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 5.5 mi. WNW of	WA
99576	Smith Island, 3.4 mi ESE of (depth 134 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1634_1	48.29637908935547	-122.77632141113281	:America/Los_Angeles	USA	knots	230	102	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
99577	Smith Island, 3.4 mi ESE of (depth 56 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1634_25	48.29637908935547	-122.77632141113281	:America/Los_Angeles	USA	knots	218	109	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.617	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
99578	Smith Island, 3.4 mi ESE of (depth 20 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1634_36	48.29637908935547	-122.77632141113281	:America/Los_Angeles	USA	knots	218	114	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.663	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Smith Island, 3.4 mi. ESE of	WA
99579	New Dungeness Light, 2.8 mi NNW of (depth 360 ft), Washington Current	NOS	PUG1635_11	48.23347854614258	-123.13343048095703	:America/Los_Angeles	USA	knots	244	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Dungeness Light, 2.8 mi. NNW of	WA
99580	New Dungeness Light, 2.8 mi NNW of (depth 71 ft), Washington Current	NOS	PUG1635_55	48.23347854614258	-123.13343048095703	:America/Los_Angeles	USA	knots	273	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.346	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Dungeness Light, 2.8 mi. NNW of	WA
99581	New Dungeness Light, 2.8 mi NNW of (depth 52 ft), Washington Current	NOS	PUG1635_58	48.23347854614258	-123.13343048095703	:America/Los_Angeles	USA	knots	273	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.405	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New Dungeness Light, 2.8 mi. NNW of	WA
99582	Discovery Island, 7.6 mi SSE of (depth 244 ft), Washington Current	NOS	PUG1636_1	48.30015182495117	-123.16716003417969	:America/Los_Angeles	USA	knots	220	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 7.6 mi. SSE of	WA
99583	Discovery Island, 7.6 mi SSE of (depth 120 ft), Washington Current	NOS	PUG1636_20	48.30015182495117	-123.16716003417969	:America/Los_Angeles	USA	knots	245	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.213	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 7.6 mi. SSE of	WA
99584	Discovery Island, 7.6 mi SSE of (depth 28 ft), Washington Current	NOS	PUG1636_34	48.30015182495117	-123.16716003417969	:America/Los_Angeles	USA	knots	240	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.187	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 7.6 mi. SSE of	WA
99585	Ediz Hook Light, 5.3 mi ENE of (depth 179 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1637_5	48.18227005004883	-123.28150177001953	:America/Los_Angeles	USA	knots	260	78	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.385	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 5.3 mi. ENE of	WA
99586	Ediz Hook Light, 5.3 mi ENE of (depth 28 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1637_28	48.18227005004883	-123.28150177001953	:America/Los_Angeles	USA	knots	258	88	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.59	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 5.3 mi. ENE of	WA
99587	Ediz Hook Light, 5.3 mi ENE of (depth 22 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1637_29	48.18227005004883	-123.28150177001953	:America/Los_Angeles	USA	knots	257	88	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.517	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 5.3 mi. ENE of	WA
99588	Ediz Hook Light, 1.2 mi N of (depth 184 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1638_7	48.166690826416016	-123.41581726074219	:America/Los_Angeles	USA	knots	279	112	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 1.2 miles N of	WA
99589	Ediz Hook Light, 1.2 mi N of (depth 85 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1638_17	48.166690826416016	-123.41581726074219	:America/Los_Angeles	USA	knots	282	90	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.293	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 1.2 miles N of	WA
99590	Ediz Hook Light, 1.2 mi N of (depth 36 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1638_22	48.166690826416016	-123.41581726074219	:America/Los_Angeles	USA	knots	283	89	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.358	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ediz Hook Light, 1.2 miles N of	WA
99591	Angeles Pt., 2 mi NNE of (depth 61 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1639_1	48.176998138427734	-123.52694702148438	:America/Los_Angeles	USA	knots	304	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Angeles Pt., 2 mi. NNE of	WA
99592	Angeles Pt., 2 mi NNE of (depth 25 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1639_12	48.176998138427734	-123.52694702148438	:America/Los_Angeles	USA	knots	300	75	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.257	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Angeles Pt., 2 mi. NNE of	WA
99593	Angeles Pt., 2 mi NNE of (depth 12 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1639_16	48.176998138427734	-123.52694702148438	:America/Los_Angeles	USA	knots	300	75	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Angeles Pt., 2 mi. NNE of	WA
99594	Race Rocks, 4.5 mi S of (depth 394 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1640_1	48.223201751708984	-123.53230285644531	:America/Los_Angeles	USA	knots	\N	89.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.277	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Race Rocks, 4.5 mi. S of	WA
99595	Race Rocks, 4.5 mi S of (depth 237 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1640_9	48.223201751708984	-123.53230285644531	:America/Los_Angeles	USA	knots	274	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Race Rocks, 4.5 mi. S of	WA
99596	Race Rocks, 4.5 mi S of (depth 60 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1640_18	48.223201751708984	-123.53230285644531	:America/Los_Angeles	USA	knots	268	91	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.596	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Race Rocks, 4.5 mi. S of	WA
99597	Pillar Point, 6 mi NNE of (depth 297 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1641_36	48.29999923706055	-124.03739929199219	:America/Los_Angeles	USA	knots	273	93	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point, 6 mi. NNE of	WA
99598	Pillar Point, 6 mi NNE of (depth 74 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1641_70	48.29999923706055	-124.03739929199219	:America/Los_Angeles	USA	knots	293	114	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.417	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point, 6 mi. NNE of	WA
99599	Pillar Point, 6 mi NNE of (depth 41 ft), Strait of Juan de Fuca, Washington Current	NOS	PUG1641_75	48.29999923706055	-124.03739929199219	:America/Los_Angeles	USA	knots	290	115	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.288	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pillar Point, 6 mi. NNE of	WA
99600	Strait of Juan de Fuca entrance (depth 102 ft), Washington Current	NOS	PUG1642_49	48.449981689453125	-124.58380126953125	:America/Los_Angeles	USA	knots	306	113	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.564	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Juan de Fuca Entrance	WA
99601	Strait of Juan de Fuca entrance (depth 89 ft), Washington Current	NOS	PUG1642_50	48.449981689453125	-124.58380126953125	:America/Los_Angeles	USA	knots	\N	125.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.574	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Juan de Fuca Entrance	WA
99602	Deception Pass (Narrows) (depth 123 ft), Rosario Strait, Washington Current	NOS	PUG1701_1	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	102.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.338	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99603	Deception Pass (Narrows) (depth 119 ft), Rosario Strait, Washington Current	NOS	PUG1701_2	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	101.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.527	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99604	Deception Pass (Narrows) (depth 116 ft), Rosario Strait, Washington Current	NOS	PUG1701_3	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	100.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.618	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99605	Deception Pass (Narrows) (depth 113 ft), Rosario Strait, Washington Current	NOS	PUG1701_4	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	100	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99606	Deception Pass (Narrows) (depth 110 ft), Rosario Strait, Washington Current	NOS	PUG1701_5	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	99.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.685	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99607	Deception Pass (Narrows) (depth 106 ft), Rosario Strait, Washington Current	NOS	PUG1701_6	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	98.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.697	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99608	Deception Pass (Narrows) (depth 103 ft), Rosario Strait, Washington Current	NOS	PUG1701_7	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	97.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.704	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99609	Deception Pass (Narrows) (depth 100 ft), Rosario Strait, Washington Current	NOS	PUG1701_8	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	97.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.708	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99610	Deception Pass (Narrows) (depth 96 ft), Rosario Strait, Washington Current	NOS	PUG1701_9	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	96.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.708	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99611	Deception Pass (Narrows) (depth 93 ft), Rosario Strait, Washington Current	NOS	PUG1701_10	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	95.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.702	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99612	Deception Pass (Narrows) (depth 90 ft), Rosario Strait, Washington Current	NOS	PUG1701_11	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	94.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.691	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99613	Deception Pass (Narrows) (depth 87 ft), Rosario Strait, Washington Current	NOS	PUG1701_12	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	94.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.675	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99614	Deception Pass (Narrows) (depth 83 ft), Rosario Strait, Washington Current	NOS	PUG1701_13	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	93.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99615	Deception Pass (Narrows) (depth 80 ft), Rosario Strait, Washington Current	NOS	PUG1701_14	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	93.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.645	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99616	Deception Pass (Narrows) (depth 77 ft), Rosario Strait, Washington Current	NOS	PUG1701_15	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	93.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.633	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99617	Deception Pass (Narrows) (depth 73 ft), Rosario Strait, Washington Current	NOS	PUG1701_16	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	93	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.625	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99618	Deception Pass (Narrows) (depth 70 ft), Rosario Strait, Washington Current	NOS	PUG1701_17	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	92.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.62	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99619	Deception Pass (Narrows) (depth 67 ft), Rosario Strait, Washington Current	NOS	PUG1701_18	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	270	96	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.619	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99620	Deception Pass (Narrows) (depth 64 ft), Rosario Strait, Washington Current	NOS	PUG1701_19	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	92.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.619	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99621	Deception Pass (Narrows) (depth 60 ft), Rosario Strait, Washington Current	NOS	PUG1701_20	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	93	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.623	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99622	Deception Pass (Narrows) (depth 57 ft), Rosario Strait, Washington Current	NOS	PUG1701_21	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	93.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.628	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99623	Deception Pass (Narrows) (depth 54 ft), Rosario Strait, Washington Current	NOS	PUG1701_22	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	93.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.634	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99624	Deception Pass (Narrows) (depth 50 ft), Rosario Strait, Washington Current	NOS	PUG1701_23	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	93.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.641	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99625	Deception Pass (Narrows) (depth 47 ft), Rosario Strait, Washington Current	NOS	PUG1701_24	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	270	98	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.647	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99626	Deception Pass (Narrows) (depth 44 ft), Rosario Strait, Washington Current	NOS	PUG1701_25	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	94.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.653	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99627	Deception Pass (Narrows) (depth 41 ft), Rosario Strait, Washington Current	NOS	PUG1701_26	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	95.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.657	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99628	Deception Pass (Narrows) (depth 37 ft), Rosario Strait, Washington Current	NOS	PUG1701_27	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	95.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99629	Deception Pass (Narrows) (depth 34 ft), Rosario Strait, Washington Current	NOS	PUG1701_28	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	96.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99630	Deception Pass (Narrows) (depth 31 ft), Rosario Strait, Washington Current	NOS	PUG1701_29	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	97.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.656	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99631	Deception Pass (Narrows) (depth 28 ft), Rosario Strait, Washington Current	NOS	PUG1701_30	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	98.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.649	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99632	Deception Pass (Narrows) (depth 24 ft), Rosario Strait, Washington Current	NOS	PUG1701_31	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	99.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.638	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99633	Deception Pass (Narrows) (depth 21 ft), Rosario Strait, Washington Current	NOS	PUG1701_32	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	100.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.624	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99634	Deception Pass (Narrows) (depth 18 ft), Rosario Strait, Washington Current	NOS	PUG1701_33	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	277	108	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.618	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99635	Deception Pass (Narrows) (depth 14 ft), Rosario Strait, Washington Current	NOS	PUG1701_34	48.40618896484375	-122.64311981201172	:America/Los_Angeles	USA	knots	\N	102.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.652	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Deception Pass (Narrows)	WA
99636	Rosario Strait (depth 195 ft), Washington Current	NOS	PUG1702_1	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	340.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99637	Rosario Strait (depth 185 ft), Washington Current	NOS	PUG1702_2	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	345.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99638	Rosario Strait (depth 175 ft), Washington Current	NOS	PUG1702_3	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	349	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99639	Rosario Strait (depth 165 ft), Washington Current	NOS	PUG1702_4	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	352.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99640	Rosario Strait (depth 155 ft), Washington Current	NOS	PUG1702_5	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	354.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.201	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99641	Rosario Strait (depth 145 ft), Washington Current	NOS	PUG1702_6	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	357	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99642	Rosario Strait (depth 135 ft), Washington Current	NOS	PUG1702_7	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	358.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.276	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99643	Rosario Strait (depth 126 ft), Washington Current	NOS	PUG1702_8	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	0.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.311	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99644	Rosario Strait (depth 116 ft), Washington Current	NOS	PUG1702_9	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	183	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.345	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99645	Rosario Strait (depth 106 ft), Washington Current	NOS	PUG1702_10	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	2.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.376	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99646	Rosario Strait (depth 96 ft), Washington Current	NOS	PUG1702_11	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	3.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.406	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99647	Rosario Strait (depth 86 ft), Washington Current	NOS	PUG1702_12	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	3.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.433	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99648	Rosario Strait (depth 76 ft), Washington Current	NOS	PUG1702_13	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	187	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.458	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99649	Rosario Strait (depth 67 ft), Washington Current	NOS	PUG1702_14	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	4.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.478	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99650	Rosario Strait (depth 57 ft), Washington Current	NOS	PUG1702_15	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	4.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.493	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99651	Rosario Strait (depth 47 ft), Washington Current	NOS	PUG1702_16	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	190	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.501	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99652	Rosario Strait (depth 37 ft), Washington Current	NOS	PUG1702_17	48.458091735839844	-122.75006866455078	:America/Los_Angeles	USA	knots	\N	5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.501	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rosario Strait	WA
99653	San Juan Channel, south entrance (depth 114 ft), Washington Current	NOS	PUG1703_13	48.46100997924805	-122.9520263671875	:America/Los_Angeles	USA	knots	169	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 141.0 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.48	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan Channel, south entrance	WA
99654	San Juan Channel, south entrance (depth 92 ft), Washington Current	NOS	PUG1703_16	48.46100997924805	-122.9520263671875	:America/Los_Angeles	USA	knots	169	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.507	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan Channel, south entrance	WA
99655	San Juan Channel, south entrance (depth 75 ft), Washington Current	NOS	PUG1703_17	48.46100997924805	-122.9520263671875	:America/Los_Angeles	USA	knots	168	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.494	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Juan Channel, south entrance	WA
99656	Peavine Pass, west entrance (depth 48 ft), Rosario Strait, Washington Current	NOS	PUG1704_1	48.58707809448242	-122.81925964355469	:America/Los_Angeles	USA	knots	235	50	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.401	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peavine Pass, west entrance	WA
99657	Peavine Pass, west entrance (depth 19 ft), Rosario Strait, Washington Current	NOS	PUG1704_10	48.58707809448242	-122.81925964355469	:America/Los_Angeles	USA	knots	232	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.613	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peavine Pass, west entrance	WA
99658	Peavine Pass, west entrance (depth 9 ft), Rosario Strait, Washington Current	NOS	PUG1704_13	48.58707809448242	-122.81925964355469	:America/Los_Angeles	USA	knots	231	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.629	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peavine Pass, west entrance	WA
99659	Obstruction Pass, north of Obstruction Island (depth 54 ft), Washington Current	NOS	PUG1705_1	48.603271484375	-122.81272888183594	:America/Los_Angeles	USA	knots	274	100	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Obstruction Pass, north of Obstruction Island	WA
99660	Obstruction Pass, north of Obstruction Island (depth 15 ft), Washington Current	NOS	PUG1705_13	48.603271484375	-122.81272888183594	:America/Los_Angeles	USA	knots	286	88	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Obstruction Pass, north of Obstruction Island	WA
99661	Obstruction Pass, north of Obstruction Island (depth 8 ft), Washington Current	NOS	PUG1705_15	48.603271484375	-122.81272888183594	:America/Los_Angeles	USA	knots	286	87	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Obstruction Pass, north of Obstruction Island	WA
99662	Peapod Rocks Light, 1.2 nmi south of (depth 170 ft), Rosario Strait, Washington Current	NOS	PUG1706_1	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	218	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
99663	Peapod Rocks Light, 1.2 nmi south of (depth 157 ft), Rosario Strait, Washington Current	NOS	PUG1706_2	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	\N	36.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
99664	Peapod Rocks Light, 1.2 nmi south of (depth 144 ft), Rosario Strait, Washington Current	NOS	PUG1706_3	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	\N	35.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
99665	Peapod Rocks Light, 1.2 nmi south of (depth 131 ft), Rosario Strait, Washington Current	NOS	PUG1706_4	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	\N	34.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.225	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
99666	Peapod Rocks Light, 1.2 nmi south of (depth 118 ft), Rosario Strait, Washington Current	NOS	PUG1706_5	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	\N	33.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.246	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
99667	Peapod Rocks Light, 1.2 nmi south of (depth 104 ft), Rosario Strait, Washington Current	NOS	PUG1706_6	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	\N	32.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.264	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
99668	Peapod Rocks Light, 1.2 nmi south of (depth 91 ft), Rosario Strait, Washington Current	NOS	PUG1706_7	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	\N	31.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.28	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
99669	Peapod Rocks Light, 1.2 nmi south of (depth 78 ft), Rosario Strait, Washington Current	NOS	PUG1706_8	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	218	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.296	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
99670	Peapod Rocks Light, 1.2 nmi south of (depth 65 ft), Rosario Strait, Washington Current	NOS	PUG1706_9	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	\N	30.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
99671	Peapod Rocks Light, 1.2 nmi south of (depth 52 ft), Rosario Strait, Washington Current	NOS	PUG1706_10	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	\N	30.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.333	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
99672	Peapod Rocks Light, 1.2 nmi south of (depth 39 ft), Rosario Strait, Washington Current	NOS	PUG1706_11	48.62239074707031	-122.74761962890625	:America/Los_Angeles	USA	knots	220	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.358	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Peapod Rocks Light, 1.2 nm south of	WA
99673	Sinclair Island, 1.0 nmi NE of (depth 171 ft), Rosario Strait, Washington Current	NOS	PUG1707_6	48.64419937133789	-122.65872192382812	:America/Los_Angeles	USA	knots	131	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.309	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sinclair Island, 1.0 nm NE of	WA
99674	Sinclair Island, 1.0 nmi NE of (depth 99 ft), Rosario Strait, Washington Current	NOS	PUG1707_17	48.64419937133789	-122.65872192382812	:America/Los_Angeles	USA	knots	131	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.292	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sinclair Island, 1.0 nm NE of	WA
99675	Sinclair Island, 1.0 nmi NE of (depth 26 ft), Rosario Strait, Washington Current	NOS	PUG1707_28	48.64419937133789	-122.65872192382812	:America/Los_Angeles	USA	knots	131	324	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.305	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sinclair Island, 1.0 nm NE of	WA
99676	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 234 ft), Washington Current	NOS	PUG1708_1	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	332.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.059	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
99677	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 220 ft), Washington Current	NOS	PUG1708_2	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	334.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
99678	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 207 ft), Washington Current	NOS	PUG1708_3	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	335.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
99679	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 194 ft), Washington Current	NOS	PUG1708_4	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	337.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
99680	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 181 ft), Washington Current	NOS	PUG1708_5	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	338	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
99681	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 168 ft), Washington Current	NOS	PUG1708_6	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	338.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
99682	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 155 ft), Washington Current	NOS	PUG1708_7	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	339.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
99683	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 142 ft), Washington Current	NOS	PUG1708_8	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	340.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
99684	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 129 ft), Washington Current	NOS	PUG1708_9	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	340.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
99685	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 115 ft), Washington Current	NOS	PUG1708_10	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	152	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
99686	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 102 ft), Washington Current	NOS	PUG1708_11	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	341.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
99687	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 89 ft), Washington Current	NOS	PUG1708_12	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	341.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
99688	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 76 ft), Washington Current	NOS	PUG1708_13	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	341.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
99689	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 63 ft), Washington Current	NOS	PUG1708_14	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	152	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
99690	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 50 ft), Washington Current	NOS	PUG1708_15	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	\N	340.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
99691	Lawrence Point, Orcas Island, 1.3 nmi NE of (depth 37 ft), Washington Current	NOS	PUG1708_16	48.67940902709961	-122.71466827392578	:America/Los_Angeles	USA	knots	151	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lawrence Point, Orcas Island, 1.3 nm NE of	WA
99692	Clark Island, 1.6 nmi north of (depth 180 ft), Rosario Strait, Washington Current	NOS	PUG1709_10	48.731258392333984	-122.77337646484375	:America/Los_Angeles	USA	knots	150	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clark Island, 1.6 nm north of	WA
99693	Clark Island, 1.6 nmi north of (depth 48 ft), Rosario Strait, Washington Current	NOS	PUG1709_30	48.731258392333984	-122.77337646484375	:America/Los_Angeles	USA	knots	157	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clark Island, 1.6 nm north of	WA
99694	Clark Island, 1.6 nmi north of (depth 29 ft), Rosario Strait, Washington Current	NOS	PUG1709_33	48.731258392333984	-122.77337646484375	:America/Los_Angeles	USA	knots	159	335	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Clark Island, 1.6 nm north of	WA
99695	Hale Passage, east of Lummi Point (depth 44 ft), Rosario Strait, Washington Current	NOS	PUG1710_3	48.7348518371582	-122.68016815185547	:America/Los_Angeles	USA	knots	158	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east of Lummi Point	WA
99696	Hale Passage, east of Lummi Point (depth 27 ft), Rosario Strait, Washington Current	NOS	PUG1710_8	48.7348518371582	-122.68016815185547	:America/Los_Angeles	USA	knots	167	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east of Lummi Point	WA
99697	Hale Passage, east of Lummi Point (depth 8 ft), Rosario Strait, Washington Current	NOS	PUG1710_14	48.7348518371582	-122.68016815185547	:America/Los_Angeles	USA	knots	177	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hale Passage, east of Lummi Point	WA
99698	Matia Island, west of (depth 336 ft), Rosario Strait, Washington Current	NOS	PUG1711_4	48.774879455566406	-122.84097290039062	:America/Los_Angeles	USA	knots	135	299	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matia Island, west of	WA
99699	Matia Island, west of (depth 87 ft), Rosario Strait, Washington Current	NOS	PUG1711_23	48.774879455566406	-122.84097290039062	:America/Los_Angeles	USA	knots	149	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matia Island, west of	WA
99700	Matia Island, west of (depth 47 ft), Rosario Strait, Washington Current	NOS	PUG1711_26	48.774879455566406	-122.84097290039062	:America/Los_Angeles	USA	knots	153	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.144	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matia Island, west of	WA
99701	Parker Reef Light, north of (depth 189 ft), Rosario Strait, Washington Current	NOS	PUG1712_1	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	108.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99702	Parker Reef Light, north of (depth 182 ft), Rosario Strait, Washington Current	NOS	PUG1712_2	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	107.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99703	Parker Reef Light, north of (depth 176 ft), Rosario Strait, Washington Current	NOS	PUG1712_3	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	105.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99704	Parker Reef Light, north of (depth 169 ft), Rosario Strait, Washington Current	NOS	PUG1712_4	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	103.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99705	Parker Reef Light, north of (depth 163 ft), Rosario Strait, Washington Current	NOS	PUG1712_5	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	102.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99706	Parker Reef Light, north of (depth 156 ft), Rosario Strait, Washington Current	NOS	PUG1712_6	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	100.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99707	Parker Reef Light, north of (depth 150 ft), Rosario Strait, Washington Current	NOS	PUG1712_7	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	99.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99708	Parker Reef Light, north of (depth 143 ft), Rosario Strait, Washington Current	NOS	PUG1712_8	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	97.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.095	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99709	Parker Reef Light, north of (depth 136 ft), Rosario Strait, Washington Current	NOS	PUG1712_9	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	96.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99710	Parker Reef Light, north of (depth 130 ft), Rosario Strait, Washington Current	NOS	PUG1712_10	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	280	91	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99711	Parker Reef Light, north of (depth 123 ft), Rosario Strait, Washington Current	NOS	PUG1712_11	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	93.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99712	Parker Reef Light, north of (depth 117 ft), Rosario Strait, Washington Current	NOS	PUG1712_12	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	91.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99713	Parker Reef Light, north of (depth 110 ft), Rosario Strait, Washington Current	NOS	PUG1712_13	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	90.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99714	Parker Reef Light, north of (depth 104 ft), Rosario Strait, Washington Current	NOS	PUG1712_14	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	89	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99715	Parker Reef Light, north of (depth 97 ft), Rosario Strait, Washington Current	NOS	PUG1712_15	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	87.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99716	Parker Reef Light, north of (depth 90 ft), Rosario Strait, Washington Current	NOS	PUG1712_16	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	86.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99717	Parker Reef Light, north of (depth 84 ft), Rosario Strait, Washington Current	NOS	PUG1712_17	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	85.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99718	Parker Reef Light, north of (depth 77 ft), Rosario Strait, Washington Current	NOS	PUG1712_18	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	84.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99719	Parker Reef Light, north of (depth 71 ft), Rosario Strait, Washington Current	NOS	PUG1712_19	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	83.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99720	Parker Reef Light, north of (depth 64 ft), Rosario Strait, Washington Current	NOS	PUG1712_20	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	82.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99721	Parker Reef Light, north of (depth 58 ft), Rosario Strait, Washington Current	NOS	PUG1712_21	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	81.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99722	Parker Reef Light, north of (depth 51 ft), Rosario Strait, Washington Current	NOS	PUG1712_22	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	80.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.172	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99723	Parker Reef Light, north of (depth 45 ft), Rosario Strait, Washington Current	NOS	PUG1712_23	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	257	81	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.205	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99724	Parker Reef Light, north of (depth 38 ft), Rosario Strait, Washington Current	NOS	PUG1712_24	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	78.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.237	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99725	Parker Reef Light, north of (depth 31 ft), Rosario Strait, Washington Current	NOS	PUG1712_25	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	254	79	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.268	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99726	Parker Reef Light, north of (depth 25 ft), Rosario Strait, Washington Current	NOS	PUG1712_26	48.73263931274414	-122.88638305664062	:America/Los_Angeles	USA	knots	\N	75.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.272	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Parker Reef Light, north of	WA
99727	Patos Island, south of Toe Point (depth 63 ft), Rosario Strait, Washington Current	NOS	PUG1713_10	48.77206039428711	-122.93370056152344	:America/Los_Angeles	USA	knots	196	46	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.267	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island, south of Toe Point	WA
99728	Patos Island, south of Toe Point (depth 30 ft), Rosario Strait, Washington Current	NOS	PUG1713_20	48.77206039428711	-122.93370056152344	:America/Los_Angeles	USA	knots	191	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.356	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island, south of Toe Point	WA
99729	Patos Island, south of Toe Point (depth 14 ft), Rosario Strait, Washington Current	NOS	PUG1713_25	48.77206039428711	-122.93370056152344	:America/Los_Angeles	USA	knots	188	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.396	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island, south of Toe Point	WA
99730	Patos Island Light, 1.4 nmi west of (depth 191 ft), Rosario Strait, Washington Current	NOS	PUG1714_16	48.773128509521484	-123.00579071044922	:America/Los_Angeles	USA	knots	225	40	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.419	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island Light, 1.4 nm west of	WA
99731	Patos Island Light, 1.4 nmi west of (depth 99 ft), Rosario Strait, Washington Current	NOS	PUG1714_23	48.773128509521484	-123.00579071044922	:America/Los_Angeles	USA	knots	215	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.469	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island Light, 1.4 nm west of	WA
99732	Patos Island Light, 1.4 nmi west of (depth 46 ft), Rosario Strait, Washington Current	NOS	PUG1714_27	48.773128509521484	-123.00579071044922	:America/Los_Angeles	USA	knots	209	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.443	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Patos Island Light, 1.4 nm west of	WA
99733	President Channel, east of Point Disney (depth 200 ft), Washington Current	NOS	PUG1715_28	48.6733512878418	-123.00598907470703	:America/Los_Angeles	USA	knots	\N	41.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Channel, East of Point Disney	WA
99734	President Channel, east of Point Disney (depth 108 ft), Washington Current	NOS	PUG1715_35	48.6733512878418	-123.00598907470703	:America/Los_Angeles	USA	knots	219	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.369	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Channel, East of Point Disney	WA
99735	President Channel, east of Point Disney (depth 69 ft), Washington Current	NOS	PUG1715_38	48.6733512878418	-123.00598907470703	:America/Los_Angeles	USA	knots	218	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.502	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	President Channel, East of Point Disney	WA
99736	Turn Point, Boundary Pass (depth 208 ft), Washington Current	NOS	PUG1717_28	48.69121170043945	-123.24501037597656	:America/Los_Angeles	USA	knots	232	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.407	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point, Boundary Pass	WA
99737	Turn Point, Boundary Pass (depth 168 ft), Washington Current	NOS	PUG1717_31	48.69121170043945	-123.24501037597656	:America/Los_Angeles	USA	knots	235	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.393	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point, Boundary Pass	WA
99738	Turn Point, Boundary Pass (depth 116 ft), Washington Current	NOS	PUG1717_35	48.69121170043945	-123.24501037597656	:America/Los_Angeles	USA	knots	236	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.297	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turn Point, Boundary Pass	WA
99739	Haro Strait, 1.2 nmi west of Kellett Bluff (depth 204 ft), Washington Current	NOS	PUG1718_29	48.58871841430664	-123.225830078125	:America/Los_Angeles	USA	knots	178	340	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haro Strait, 1.2 nm west of Kellett Bluff	WA
99740	Haro Strait, 1.2 nmi west of Kellett Bluff (depth 106 ft), Washington Current	NOS	PUG1718_34	48.58871841430664	-123.225830078125	:America/Los_Angeles	USA	knots	179	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haro Strait, 1.2 nm west of Kellett Bluff	WA
99741	Haro Strait, 1.2 nmi west of Kellett Bluff (depth 66 ft), Washington Current	NOS	PUG1718_36	48.58871841430664	-123.225830078125	:America/Los_Angeles	USA	knots	179	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.384	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Haro Strait, 1.2 nm west of Kellett Bluff	WA
99742	Spieden Channel, north of Limestone Point (depth 205 ft), Washington Current	NOS	PUG1719_7	48.627830505371094	-123.11164855957031	:America/Los_Angeles	USA	knots	282	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.341	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spieden Channel, north of Limestone Point	WA
99743	Spieden Channel, north of Limestone Point (depth 60 ft), Washington Current	NOS	PUG1719_18	48.627830505371094	-123.11164855957031	:America/Los_Angeles	USA	knots	282	85	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.634	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spieden Channel, north of Limestone Point	WA
99744	Spieden Channel, north of Limestone Point (depth 47 ft), Washington Current	NOS	PUG1719_19	48.627830505371094	-123.11164855957031	:America/Los_Angeles	USA	knots	281	85	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.665	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spieden Channel, north of Limestone Point	WA
99745	Spring Passage, south entrance (depth 62 ft), San Juan Channel, Washington Current	NOS	PUG1720_11	48.611541748046875	-123.03410339355469	:America/Los_Angeles	USA	knots	151	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Passage, south entrance	WA
99746	Spring Passage, south entrance (depth 26 ft), San Juan Channel, Washington Current	NOS	PUG1720_22	48.611541748046875	-123.03410339355469	:America/Los_Angeles	USA	knots	149	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Passage, south entrance	WA
99747	Spring Passage, south entrance (depth 13 ft), San Juan Channel, Washington Current	NOS	PUG1720_26	48.611541748046875	-123.03410339355469	:America/Los_Angeles	USA	knots	148	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Spring Passage, south entrance	WA
99748	Wasp Passage narrows (depth 64 ft), San Juan Channel, Washington Current	NOS	PUG1721_1	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	256.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99749	Wasp Passage narrows (depth 60 ft), San Juan Channel, Washington Current	NOS	PUG1721_2	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	66	264	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99750	Wasp Passage narrows (depth 57 ft), San Juan Channel, Washington Current	NOS	PUG1721_3	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	255.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99751	Wasp Passage narrows (depth 54 ft), San Juan Channel, Washington Current	NOS	PUG1721_4	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	254.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99752	Wasp Passage narrows (depth 50 ft), San Juan Channel, Washington Current	NOS	PUG1721_5	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	254.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99753	Wasp Passage narrows (depth 47 ft), San Juan Channel, Washington Current	NOS	PUG1721_6	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	253.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99754	Wasp Passage narrows (depth 44 ft), San Juan Channel, Washington Current	NOS	PUG1721_7	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	253	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99755	Wasp Passage narrows (depth 41 ft), San Juan Channel, Washington Current	NOS	PUG1721_8	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	252.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99756	Wasp Passage narrows (depth 37 ft), San Juan Channel, Washington Current	NOS	PUG1721_9	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	251.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99757	Wasp Passage narrows (depth 34 ft), San Juan Channel, Washington Current	NOS	PUG1721_10	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	251.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99758	Wasp Passage narrows (depth 31 ft), San Juan Channel, Washington Current	NOS	PUG1721_11	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	62	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99759	Wasp Passage narrows (depth 27 ft), San Juan Channel, Washington Current	NOS	PUG1721_12	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	250.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99760	Wasp Passage narrows (depth 24 ft), San Juan Channel, Washington Current	NOS	PUG1721_13	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	249.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99761	Wasp Passage narrows (depth 21 ft), San Juan Channel, Washington Current	NOS	PUG1721_14	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	249.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99762	Wasp Passage narrows (depth 18 ft), San Juan Channel, Washington Current	NOS	PUG1721_15	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	248.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99763	Wasp Passage narrows (depth 14 ft), San Juan Channel, Washington Current	NOS	PUG1721_16	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	\N	248.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99764	Wasp Passage narrows (depth 11 ft), San Juan Channel, Washington Current	NOS	PUG1721_17	48.59246826171875	-122.98957061767578	:America/Los_Angeles	USA	knots	60	256	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wasp Passage narrows	WA
99765	Harney Channel, north of Point Hudson (depth 99 ft), San Juan Channel, Washington Current	NOS	PUG1722_1	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	257.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99766	Harney Channel, north of Point Hudson (depth 95 ft), San Juan Channel, Washington Current	NOS	PUG1722_2	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	257.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99767	Harney Channel, north of Point Hudson (depth 92 ft), San Juan Channel, Washington Current	NOS	PUG1722_3	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	258.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99768	Harney Channel, north of Point Hudson (depth 89 ft), San Juan Channel, Washington Current	NOS	PUG1722_4	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	259	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99769	Harney Channel, north of Point Hudson (depth 85 ft), San Juan Channel, Washington Current	NOS	PUG1722_5	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	259.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99770	Harney Channel, north of Point Hudson (depth 82 ft), San Juan Channel, Washington Current	NOS	PUG1722_6	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	72	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99771	Harney Channel, north of Point Hudson (depth 79 ft), San Juan Channel, Washington Current	NOS	PUG1722_7	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	260.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99772	Harney Channel, north of Point Hudson (depth 76 ft), San Juan Channel, Washington Current	NOS	PUG1722_8	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	260.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99773	Harney Channel, north of Point Hudson (depth 72 ft), San Juan Channel, Washington Current	NOS	PUG1722_9	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	260.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99774	Harney Channel, north of Point Hudson (depth 69 ft), San Juan Channel, Washington Current	NOS	PUG1722_10	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	260.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99775	Harney Channel, north of Point Hudson (depth 66 ft), San Juan Channel, Washington Current	NOS	PUG1722_11	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	260.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99776	Harney Channel, north of Point Hudson (depth 62 ft), San Juan Channel, Washington Current	NOS	PUG1722_12	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99777	Harney Channel, north of Point Hudson (depth 59 ft), San Juan Channel, Washington Current	NOS	PUG1722_13	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99778	Harney Channel, north of Point Hudson (depth 56 ft), San Juan Channel, Washington Current	NOS	PUG1722_14	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99779	Harney Channel, north of Point Hudson (depth 53 ft), San Juan Channel, Washington Current	NOS	PUG1722_15	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99780	Harney Channel, north of Point Hudson (depth 49 ft), San Juan Channel, Washington Current	NOS	PUG1722_16	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99781	Harney Channel, north of Point Hudson (depth 46 ft), San Juan Channel, Washington Current	NOS	PUG1722_17	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99782	Harney Channel, north of Point Hudson (depth 43 ft), San Juan Channel, Washington Current	NOS	PUG1722_18	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99783	Harney Channel, north of Point Hudson (depth 39 ft), San Juan Channel, Washington Current	NOS	PUG1722_19	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99784	Harney Channel, north of Point Hudson (depth 36 ft), San Juan Channel, Washington Current	NOS	PUG1722_20	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	78	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99785	Harney Channel, north of Point Hudson (depth 33 ft), San Juan Channel, Washington Current	NOS	PUG1722_21	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99786	Harney Channel, north of Point Hudson (depth 30 ft), San Juan Channel, Washington Current	NOS	PUG1722_22	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99787	Harney Channel, north of Point Hudson (depth 26 ft), San Juan Channel, Washington Current	NOS	PUG1722_23	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99788	Harney Channel, north of Point Hudson (depth 23 ft), San Juan Channel, Washington Current	NOS	PUG1722_24	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99789	Harney Channel, north of Point Hudson (depth 20 ft), San Juan Channel, Washington Current	NOS	PUG1722_25	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99790	Harney Channel, north of Point Hudson (depth 16 ft), San Juan Channel, Washington Current	NOS	PUG1722_26	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	261	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99791	Harney Channel, north of Point Hudson (depth 13 ft), San Juan Channel, Washington Current	NOS	PUG1722_27	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	78	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99792	Harney Channel, north of Point Hudson (depth 10 ft), San Juan Channel, Washington Current	NOS	PUG1722_28	48.5897216796875	-122.9217300415039	:America/Los_Angeles	USA	knots	\N	260.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harney Channel, north of Point Hudson	WA
99793	Upright Channel narrows (depth 136 ft), San Juan Channel, Washington Current	NOS	PUG1723_1	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	50.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.368	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99824	Point Colville, 1.4 nmi east of (depth 56 ft), Rosario Strait, Washington Current	NOS	PUG1728_22	48.41809844970703	-122.78119659423828	:America/Los_Angeles	USA	knots	207	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.244	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 1.4 nm east of	WA
99794	Upright Channel narrows (depth 129 ft), San Juan Channel, Washington Current	NOS	PUG1723_2	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	49.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99795	Upright Channel narrows (depth 123 ft), San Juan Channel, Washington Current	NOS	PUG1723_3	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	48.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.371	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99796	Upright Channel narrows (depth 116 ft), San Juan Channel, Washington Current	NOS	PUG1723_4	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	47.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.371	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99797	Upright Channel narrows (depth 110 ft), San Juan Channel, Washington Current	NOS	PUG1723_5	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	46.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.371	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99798	Upright Channel narrows (depth 103 ft), San Juan Channel, Washington Current	NOS	PUG1723_6	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	46.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.37	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99799	Upright Channel narrows (depth 97 ft), San Juan Channel, Washington Current	NOS	PUG1723_7	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	232	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.368	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99800	Upright Channel narrows (depth 90 ft), San Juan Channel, Washington Current	NOS	PUG1723_8	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	45.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.366	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99801	Upright Channel narrows (depth 84 ft), San Juan Channel, Washington Current	NOS	PUG1723_9	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	44.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.363	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99802	Upright Channel narrows (depth 77 ft), San Juan Channel, Washington Current	NOS	PUG1723_10	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	44.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.359	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99803	Upright Channel narrows (depth 70 ft), San Juan Channel, Washington Current	NOS	PUG1723_11	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	44.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.355	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99804	Upright Channel narrows (depth 64 ft), San Juan Channel, Washington Current	NOS	PUG1723_12	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	44.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99805	Upright Channel narrows (depth 57 ft), San Juan Channel, Washington Current	NOS	PUG1723_13	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	231	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.345	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99806	Upright Channel narrows (depth 51 ft), San Juan Channel, Washington Current	NOS	PUG1723_14	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	44.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.339	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99807	Upright Channel narrows (depth 44 ft), San Juan Channel, Washington Current	NOS	PUG1723_15	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	44.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.333	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99808	Upright Channel narrows (depth 38 ft), San Juan Channel, Washington Current	NOS	PUG1723_16	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	44	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99809	Upright Channel narrows (depth 31 ft), San Juan Channel, Washington Current	NOS	PUG1723_17	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	\N	43.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99810	Upright Channel narrows (depth 24 ft), San Juan Channel, Washington Current	NOS	PUG1723_18	48.55384063720703	-122.92262268066406	:America/Los_Angeles	USA	knots	230	40	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.311	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Upright Channel narrows	WA
99811	South Haro Strait, south of Lime Kiln Light (depth 212 ft), Washington Current	NOS	PUG1724_27	48.49797058105469	-123.15989685058594	:America/Los_Angeles	USA	knots	145	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Haro Strait, south of Lime Kiln Light	WA
99812	South Haro Strait, south of Lime Kiln Light (depth 159 ft), Washington Current	NOS	PUG1724_29	48.49797058105469	-123.15989685058594	:America/Los_Angeles	USA	knots	144	315	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Haro Strait, south of Lime Kiln Light	WA
99813	South Haro Strait, south of Lime Kiln Light (depth 107 ft), Washington Current	NOS	PUG1724_31	48.49797058105469	-123.15989685058594	:America/Los_Angeles	USA	knots	147	310	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.226	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Haro Strait, south of Lime Kiln Light	WA
99814	Cherry Point, 1.8 nmi southeast of (depth 41 ft), Rosario Strait, Washington Current	NOS	PUG1725_10	48.83378982543945	-122.7279281616211	:America/Los_Angeles	USA	knots	167	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point, 1.8 nm southeast of	WA
99815	Cherry Point, 1.8 nmi southeast of (depth 24 ft), Rosario Strait, Washington Current	NOS	PUG1725_20	48.83378982543945	-122.7279281616211	:America/Los_Angeles	USA	knots	161	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point, 1.8 nm southeast of	WA
99816	Cherry Point, 1.8 nmi southeast of (depth 8 ft), Rosario Strait, Washington Current	NOS	PUG1725_30	48.83378982543945	-122.7279281616211	:America/Los_Angeles	USA	knots	156	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point, 1.8 nm southeast of	WA
99817	Strait of Georgia, 4.5 nmi SW of Point Roberts (depth 189 ft), Washington Current	NOS	PUG1726_11	48.93888854980469	-123.16513061523438	:America/Los_Angeles	USA	knots	107	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Georgia, 4.5 nm SW of Point Roberts	WA
99818	Strait of Georgia, 4.5 nmi SW of Point Roberts (depth 70 ft), Washington Current	NOS	PUG1726_29	48.93888854980469	-123.16513061523438	:America/Los_Angeles	USA	knots	120	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Georgia, 4.5 nm SW of Point Roberts	WA
99819	Strait of Georgia, 4.5 nmi SW of Point Roberts (depth 31 ft), Washington Current	NOS	PUG1726_35	48.93888854980469	-123.16513061523438	:America/Los_Angeles	USA	knots	129	332	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strait of Georgia, 4.5 nm SW of Point Roberts	WA
99820	Point Colville, 3.0 nmi east of (depth 165 ft), Rosario Strait, Washington Current	NOS	PUG1727_10	48.41249084472656	-122.7402572631836	:America/Los_Angeles	USA	knots	174	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.207	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 3.0 nm east of (Lawson Reef, 1 nm	WA
99821	Point Colville, 3.0 nmi east of (depth 47 ft), Rosario Strait, Washington Current	NOS	PUG1727_28	48.41249084472656	-122.7402572631836	:America/Los_Angeles	USA	knots	186	20	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 3.0 nm east of (Lawson Reef, 1 nm	WA
99822	Point Colville, 3.0 nmi east of (depth 34 ft), Rosario Strait, Washington Current	NOS	PUG1727_30	48.41249084472656	-122.7402572631836	:America/Los_Angeles	USA	knots	186	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.51	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 3.0 nm east of (Lawson Reef, 1 nm	WA
99823	Point Colville, 1.4 nmi east of (depth 134 ft), Rosario Strait, Washington Current	NOS	PUG1728_10	48.41809844970703	-122.78119659423828	:America/Los_Angeles	USA	knots	205	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 1.4 nm east of	WA
99825	Point Colville, 1.4 nmi east of (depth 29 ft), Rosario Strait, Washington Current	NOS	PUG1728_26	48.41809844970703	-122.78119659423828	:America/Los_Angeles	USA	knots	207	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Colville, 1.4 nm east of	WA
99826	Belle Rock Light, east of (depth 115 ft), Rosario Strait, Washington Current	NOS	PUG1729_7	48.49679183959961	-122.73079681396484	:America/Los_Angeles	USA	knots	202	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Belle Rock Light, east of	WA
99827	Belle Rock Light, east of (depth 62 ft), Rosario Strait, Washington Current	NOS	PUG1729_15	48.49679183959961	-122.73079681396484	:America/Los_Angeles	USA	knots	211	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.331	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Belle Rock Light, east of	WA
99828	Belle Rock Light, east of (depth 23 ft), Rosario Strait, Washington Current	NOS	PUG1729_21	48.49679183959961	-122.73079681396484	:America/Los_Angeles	USA	knots	219	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.431	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Belle Rock Light, east of	WA
99829	Lopez Pass (depth 58 ft), Rosario Strait, Washington Current	NOS	PUG1730_4	48.479740142822266	-122.81890869140625	:America/Los_Angeles	USA	knots	92	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lopez Pass	WA
99830	Lopez Pass (depth 35 ft), Rosario Strait, Washington Current	NOS	PUG1730_11	48.479740142822266	-122.81890869140625	:America/Los_Angeles	USA	knots	91	276	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.368	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lopez Pass	WA
99831	Lopez Pass (depth 15 ft), Rosario Strait, Washington Current	NOS	PUG1730_17	48.479740142822266	-122.81890869140625	:America/Los_Angeles	USA	knots	90	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.385	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lopez Pass	WA
99832	Fauntleroy Point Light, east of (depth 93 ft), Rosario Strait, Washington Current	NOS	PUG1731_7	48.52158	-122.77066	:America/Los_Angeles	USA	knots	146	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fauntleroy Point Light, east of	WA
99833	Fauntleroy Point Light, east of (depth 54 ft), Rosario Strait, Washington Current	NOS	PUG1731_13	48.52158	-122.77066	:America/Los_Angeles	USA	knots	153	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.357	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fauntleroy Point Light, east of	WA
99834	Fauntleroy Point Light, east of (depth 21 ft), Rosario Strait, Washington Current	NOS	PUG1731_18	48.52158	-122.77066	:America/Los_Angeles	USA	knots	157	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.394	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fauntleroy Point Light, east of	WA
99835	Strawberry Island, west of (depth 164 ft), Rosario Strait, Washington Current	NOS	PUG1732_5	48.56095886230469	-122.75430297851562	:America/Los_Angeles	USA	knots	156	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.274	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strawberry Island, west of	WA
99836	Strawberry Island, west of (depth 46 ft), Rosario Strait, Washington Current	NOS	PUG1732_23	48.56095886230469	-122.75430297851562	:America/Los_Angeles	USA	knots	172	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.464	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strawberry Island, west of	WA
99837	Strawberry Island, west of (depth 33 ft), Rosario Strait, Washington Current	NOS	PUG1732_25	48.56095886230469	-122.75430297851562	:America/Los_Angeles	USA	knots	174	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.463	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Strawberry Island, west of	WA
99838	Thatcher Pass (depth 146 ft), Rosario Strait, Washington Current	NOS	PUG1733_4	48.52743148803711	-122.80397033691406	:America/Los_Angeles	USA	knots	84	256	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.238	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thatcher Pass	WA
99839	Thatcher Pass (depth 61 ft), Rosario Strait, Washington Current	NOS	PUG1733_17	48.52743148803711	-122.80397033691406	:America/Los_Angeles	USA	knots	90	255	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.386	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thatcher Pass	WA
99840	Thatcher Pass (depth 28 ft), Rosario Strait, Washington Current	NOS	PUG1733_22	48.52743148803711	-122.80397033691406	:America/Los_Angeles	USA	knots	93	256	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.417	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thatcher Pass	WA
99841	Guemes Channel, west entrance (depth 53 ft), Rosario Strait, Washington Current	NOS	PUG1734_1	48.521240234375	-122.65218353271484	:America/Los_Angeles	USA	knots	253	85	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.43	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, West Entrance	WA
99842	Guemes Channel, west entrance (depth 24 ft), Rosario Strait, Washington Current	NOS	PUG1734_10	48.521240234375	-122.65218353271484	:America/Los_Angeles	USA	knots	253	83	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.65	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, West Entrance	WA
99843	Guemes Channel, west entrance (depth 11 ft), Rosario Strait, Washington Current	NOS	PUG1734_14	48.521240234375	-122.65218353271484	:America/Los_Angeles	USA	knots	252	83	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.739	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, West Entrance	WA
99844	Guemes Channel, east entrance (depth 52 ft), Rosario Strait, Washington Current	NOS	PUG1735_1	48.52769088745117	-122.60601043701172	:America/Los_Angeles	USA	knots	253	75	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.2	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, East Entrance	WA
99845	Guemes Channel, east entrance (depth 25 ft), Rosario Strait, Washington Current	NOS	PUG1735_9	48.52769088745117	-122.60601043701172	:America/Los_Angeles	USA	knots	263	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, East Entrance	WA
99846	Guemes Channel, east entrance (depth 9 ft), Rosario Strait, Washington Current	NOS	PUG1735_14	48.52769088745117	-122.60601043701172	:America/Los_Angeles	USA	knots	268	75	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.31	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Guemes Channel, East Entrance	WA
99847	Saddle Bag Island Passage (depth 238 ft), Rosario Strait, Washington Current	NOS	PUG1736_1	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	7.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.333	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99848	Saddle Bag Island Passage (depth 232 ft), Rosario Strait, Washington Current	NOS	PUG1736_2	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	4.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.32	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99849	Saddle Bag Island Passage (depth 225 ft), Rosario Strait, Washington Current	NOS	PUG1736_3	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	1.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.308	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99850	Saddle Bag Island Passage (depth 218 ft), Rosario Strait, Washington Current	NOS	PUG1736_4	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	358.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.296	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99851	Saddle Bag Island Passage (depth 212 ft), Rosario Strait, Washington Current	NOS	PUG1736_5	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	356.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.283	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99852	Saddle Bag Island Passage (depth 205 ft), Rosario Strait, Washington Current	NOS	PUG1736_6	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	354.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.272	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99853	Saddle Bag Island Passage (depth 199 ft), Rosario Strait, Washington Current	NOS	PUG1736_7	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	353.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99854	Saddle Bag Island Passage (depth 192 ft), Rosario Strait, Washington Current	NOS	PUG1736_8	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	352.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.252	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99855	Saddle Bag Island Passage (depth 186 ft), Rosario Strait, Washington Current	NOS	PUG1736_9	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	351.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.244	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99856	Saddle Bag Island Passage (depth 179 ft), Rosario Strait, Washington Current	NOS	PUG1736_10	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	351.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.237	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99887	Bellingham Channel South (depth 118 ft), Rosario Strait, Washington Current	NOS	PUG1739_1	48.53963088989258	-122.68343353271484	:America/Los_Angeles	USA	knots	224	65	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel South	WA
99857	Saddle Bag Island Passage (depth 172 ft), Rosario Strait, Washington Current	NOS	PUG1736_11	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	351.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99858	Saddle Bag Island Passage (depth 166 ft), Rosario Strait, Washington Current	NOS	PUG1736_12	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	351.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.226	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99859	Saddle Bag Island Passage (depth 159 ft), Rosario Strait, Washington Current	NOS	PUG1736_13	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	351.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.221	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99860	Saddle Bag Island Passage (depth 153 ft), Rosario Strait, Washington Current	NOS	PUG1736_14	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	351.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.216	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99861	Saddle Bag Island Passage (depth 146 ft), Rosario Strait, Washington Current	NOS	PUG1736_15	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	352.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.211	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99862	Saddle Bag Island Passage (depth 140 ft), Rosario Strait, Washington Current	NOS	PUG1736_16	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	352.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.207	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99863	Saddle Bag Island Passage (depth 133 ft), Rosario Strait, Washington Current	NOS	PUG1736_17	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	353.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99864	Saddle Bag Island Passage (depth 127 ft), Rosario Strait, Washington Current	NOS	PUG1736_18	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	353.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99865	Saddle Bag Island Passage (depth 120 ft), Rosario Strait, Washington Current	NOS	PUG1736_19	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	353.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.191	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99866	Saddle Bag Island Passage (depth 113 ft), Rosario Strait, Washington Current	NOS	PUG1736_20	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	354.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99867	Saddle Bag Island Passage (depth 107 ft), Rosario Strait, Washington Current	NOS	PUG1736_21	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	354.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.18	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99868	Saddle Bag Island Passage (depth 100 ft), Rosario Strait, Washington Current	NOS	PUG1736_22	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	354.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.174	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99869	Saddle Bag Island Passage (depth 94 ft), Rosario Strait, Washington Current	NOS	PUG1736_23	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	354.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.167	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99870	Saddle Bag Island Passage (depth 87 ft), Rosario Strait, Washington Current	NOS	PUG1736_24	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	179	351	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99871	Saddle Bag Island Passage (depth 81 ft), Rosario Strait, Washington Current	NOS	PUG1736_25	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	353.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.154	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99872	Saddle Bag Island Passage (depth 74 ft), Rosario Strait, Washington Current	NOS	PUG1736_26	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	353.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.146	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99873	Saddle Bag Island Passage (depth 67 ft), Rosario Strait, Washington Current	NOS	PUG1736_27	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	352.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.138	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99874	Saddle Bag Island Passage (depth 61 ft), Rosario Strait, Washington Current	NOS	PUG1736_28	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	350.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99875	Saddle Bag Island Passage (depth 54 ft), Rosario Strait, Washington Current	NOS	PUG1736_29	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	349.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.125	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99876	Saddle Bag Island Passage (depth 48 ft), Rosario Strait, Washington Current	NOS	PUG1736_30	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	173	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99877	Saddle Bag Island Passage (depth 41 ft), Rosario Strait, Washington Current	NOS	PUG1736_31	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	346.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99878	Saddle Bag Island Passage (depth 35 ft), Rosario Strait, Washington Current	NOS	PUG1736_32	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	345.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.115	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99879	Saddle Bag Island Passage (depth 28 ft), Rosario Strait, Washington Current	NOS	PUG1736_33	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	\N	345.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99880	Saddle Bag Island Passage (depth 22 ft), Rosario Strait, Washington Current	NOS	PUG1736_34	48.535919189453125	-122.56391143798828	:America/Los_Angeles	USA	knots	166	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saddle Bag Island Passage	WA
99881	Allan Pass (depth 93 ft), Rosario Strait, Washington Current	NOS	PUG1737_1	48.471588134765625	-122.69982147216797	:America/Los_Angeles	USA	knots	85	283	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allan Pass	WA
99882	Allan Pass (depth 21 ft), Rosario Strait, Washington Current	NOS	PUG1737_23	48.471588134765625	-122.69982147216797	:America/Los_Angeles	USA	knots	77	289	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.495	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allan Pass	WA
99883	Allan Pass (depth 11 ft), Rosario Strait, Washington Current	NOS	PUG1737_26	48.471588134765625	-122.69982147216797	:America/Los_Angeles	USA	knots	75	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.475	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Allan Pass	WA
99884	Burrows Pass (depth 100 ft), Rosario Strait, Washington Current	NOS	PUG1738_1	48.48952102661133	-122.68672180175781	:America/Los_Angeles	USA	knots	95	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.465	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrows Pass	WA
99885	Burrows Pass (depth 28 ft), Rosario Strait, Washington Current	NOS	PUG1738_23	48.48952102661133	-122.68672180175781	:America/Los_Angeles	USA	knots	89	283	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.433	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrows Pass	WA
99886	Burrows Pass (depth 15 ft), Rosario Strait, Washington Current	NOS	PUG1738_27	48.48952102661133	-122.68672180175781	:America/Los_Angeles	USA	knots	87	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.423	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Burrows Pass	WA
99888	Bellingham Channel South (depth 33 ft), Rosario Strait, Washington Current	NOS	PUG1739_27	48.53963088989258	-122.68343353271484	:America/Los_Angeles	USA	knots	217	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel South	WA
99889	Bellingham Channel South (depth 19 ft), Rosario Strait, Washington Current	NOS	PUG1739_31	48.53963088989258	-122.68343353271484	:America/Los_Angeles	USA	knots	216	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.381	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel South	WA
99890	Bellingham Channel, off Cypress Head Light (depth 119 ft), Washington Current	NOS	PUG1740_10	48.55854034423828	-122.66175842285156	:America/Los_Angeles	USA	knots	194	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.302	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel, off Cypress Head Light	WA
99891	Bellingham Channel, off Cypress Head Light (depth 50 ft), Washington Current	NOS	PUG1740_17	48.55854034423828	-122.66175842285156	:America/Los_Angeles	USA	knots	191	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.457	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel, off Cypress Head Light	WA
99892	Bellingham Channel, off Cypress Head Light (depth 31 ft), Washington Current	NOS	PUG1740_19	48.55854034423828	-122.66175842285156	:America/Los_Angeles	USA	knots	190	20	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.484	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel, off Cypress Head Light	WA
99893	Bellingham Channel north entrance (depth 171 ft), Rosario Strait, Washington Current	NOS	PUG1741_5	48.592811584472656	-122.65767669677734	:America/Los_Angeles	USA	knots	212	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.341	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel North Entrance	WA
99894	Bellingham Channel north entrance (depth 47 ft), Rosario Strait, Washington Current	NOS	PUG1741_24	48.592811584472656	-122.65767669677734	:America/Los_Angeles	USA	knots	228	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.39	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel North Entrance	WA
99895	Bellingham Channel north entrance (depth 27 ft), Rosario Strait, Washington Current	NOS	PUG1741_27	48.592811584472656	-122.65767669677734	:America/Los_Angeles	USA	knots	230	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.377	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bellingham Channel North Entrance	WA
99896	Cattle Point, 1.2 nmi SE of (depth 117 ft), San Juan Channel, Washington Current	NOS	PUG1742_15	48.43436813354492	-122.94660949707031	:America/Los_Angeles	USA	knots	186	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.421	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 1.2 nm SE of	WA
99897	Cattle Point, 1.2 nmi SE of (depth 78 ft), San Juan Channel, Washington Current	NOS	PUG1742_18	48.43436813354492	-122.94660949707031	:America/Los_Angeles	USA	knots	183	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.52	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 1.2 nm SE of	WA
99898	Cattle Point, 1.2 nmi SE of (depth 39 ft), San Juan Channel, Washington Current	NOS	PUG1742_21	48.43436813354492	-122.94660949707031	:America/Los_Angeles	USA	knots	183	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 1.2 nm SE of	WA
99899	Cattle Point, 4.6 nmi SW of (depth 187 ft), San Juan Channel, Washington Current	NOS	PUG1743_14	48.384010314941406	-123.01567077636719	:America/Los_Angeles	USA	knots	179	47	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 4.6 nm SW of	WA
99900	Cattle Point, 4.6 nmi SW of (depth 105 ft), San Juan Channel, Washington Current	NOS	PUG1743_19	48.384010314941406	-123.01567077636719	:America/Los_Angeles	USA	knots	227	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 4.6 nm SW of	WA
99901	Cattle Point, 4.6 nmi SW of (depth 55 ft), San Juan Channel, Washington Current	NOS	PUG1743_22	48.384010314941406	-123.01567077636719	:America/Los_Angeles	USA	knots	228	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.143	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cattle Point, 4.6 nm SW of	WA
99902	Discovery Island, 3.0 nmi NE of (depth 160 ft), Washington Current	NOS	PUG1744_13	48.45206832885742	-123.15544128417969	:America/Los_Angeles	USA	knots	153	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.322	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 3.0 nm NE of	WA
99903	Discovery Island, 3.0 nmi NE of (depth 68 ft), Washington Current	NOS	PUG1744_20	48.45206832885742	-123.15544128417969	:America/Los_Angeles	USA	knots	157	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 3.0 nm NE of	WA
99904	Discovery Island, 3.0 nmi NE of (depth 41 ft), Washington Current	NOS	PUG1744_22	48.45206832885742	-123.15544128417969	:America/Los_Angeles	USA	knots	160	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Discovery Island, 3.0 nm NE of	WA
99905	Point George, west of (depth 283 ft), San Juan Channel, Washington Current	NOS	PUG1745_10	48.55670928955078	-122.99848175048828	:America/Los_Angeles	USA	knots	139	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point George, west of	WA
99906	Point George, west of (depth 119 ft), San Juan Channel, Washington Current	NOS	PUG1745_20	48.55670928955078	-122.99848175048828	:America/Los_Angeles	USA	knots	155	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point George, west of	WA
99907	Point George, west of (depth 53 ft), San Juan Channel, Washington Current	NOS	PUG1745_24	48.55670928955078	-122.99848175048828	:America/Los_Angeles	USA	knots	152	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point George, west of	WA
99908	Pear Point, east of (depth 112 ft), San Juan Channel, Washington Current	NOS	PUG1746_4	48.51139831542969	-122.9529037475586	:America/Los_Angeles	USA	knots	203	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pear Point, east of	WA
99909	Pear Point, east of (depth 59 ft), San Juan Channel, Washington Current	NOS	PUG1746_8	48.51139831542969	-122.9529037475586	:America/Los_Angeles	USA	knots	196	29	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.247	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pear Point, east of	WA
99910	Pear Point, east of (depth 32 ft), San Juan Channel, Washington Current	NOS	PUG1746_10	48.51139831542969	-122.9529037475586	:America/Los_Angeles	USA	knots	192	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.291	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pear Point, east of	WA
99911	College Fiord (depth 163 ft), Port Wells, Prince William Sound, Alaska Current	NOS	PWS0701_1	60.98983	-148.0467	:America/Anchorage	USA	knots	167	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.216	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	College Fiord	AK
99912	College Fiord (depth 98 ft), Port Wells, Prince William Sound, Alaska Current	NOS	PWS0701_6	60.98983	-148.0467	:America/Anchorage	USA	knots	175	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	College Fiord	AK
99913	College Fiord (depth 32 ft), Port Wells, Prince William Sound, Alaska Current	NOS	PWS0701_11	60.98983	-148.0467	:America/Anchorage	USA	knots	\N	28.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	College Fiord	AK
99914	Point Culross (depth 381 ft), Port Wells, Prince William Sound, Alaska Current	NOS	PWS0704_1	60.75442	-148.12186	:America/Anchorage	USA	knots	108	303	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Culross	AK
99915	Point Culross (depth 223 ft), Port Wells, Prince William Sound, Alaska Current	NOS	PWS0704_13	60.75442	-148.12186	:America/Anchorage	USA	knots	114	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Culross	AK
99916	Point Culross (depth 53 ft), Port Wells, Prince William Sound, Alaska Current	NOS	PWS0704_26	60.75442	-148.12186	:America/Anchorage	USA	knots	116	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Culross	AK
99917	Perry Passage (depth 225 ft), Port Wells, Prince William Sound, Alaska Current	NOS	PWS0706_9	60.67099	-148.01548	:America/Anchorage	USA	knots	\N	326	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Perry Passage	AK
99918	Perry Passage (depth 48 ft), Port Wells, Prince William Sound, Alaska Current	NOS	PWS0706_18	60.67099	-148.01548	:America/Anchorage	USA	knots	\N	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Perry Passage	AK
99919	Crafton Island - Knight Island Pass (depth 255 ft), Prince William Sound, Alaska Current	NOS	PWS0708_3	60.50249	-147.89787	:America/Anchorage	USA	knots	184	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crafton Island - Knight Island Pass	AK
99920	Crafton Island - Knight Island Pass (depth 176 ft), Prince William Sound, Alaska Current	NOS	PWS0708_9	60.50249	-147.89787	:America/Anchorage	USA	knots	177	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crafton Island - Knight Island Pass	AK
99921	Crafton Island - Knight Island Pass (depth 97 ft), Prince William Sound, Alaska Current	NOS	PWS0708_15	60.50249	-147.89787	:America/Anchorage	USA	knots	\N	354.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Crafton Island - Knight Island Pass	AK
99922	W. of Johnson Bay (depth 282 ft), Prince William Sound, Alaska Current	NOS	PWS0710_1	60.35899	-147.93291	:America/Anchorage	USA	knots	233	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	W. of Johnson Bay	AK
99923	W. of Johnson Bay (depth 164 ft), Prince William Sound, Alaska Current	NOS	PWS0710_10	60.35899	-147.93291	:America/Anchorage	USA	knots	189	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	W. of Johnson Bay	AK
99924	W. of Johnson Bay (depth 33 ft), Prince William Sound, Alaska Current	NOS	PWS0710_20	60.35899	-147.93291	:America/Anchorage	USA	knots	199	16.6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	W. of Johnson Bay	AK
99925	Bainbridge Pass (depth 131 ft), Prince William Sound, Alaska Current	NOS	PWS0713_1	60.1291	-148.20235	:America/Anchorage	USA	knots	234	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.256	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bainbridge Pass	AK
99926	Bainbridge Pass (depth 75 ft), Prince William Sound, Alaska Current	NOS	PWS0713_18	60.1291	-148.20235	:America/Anchorage	USA	knots	235	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.276	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bainbridge Pass	AK
99927	Bainbridge Pass (depth 16 ft), Prince William Sound, Alaska Current	NOS	PWS0713_36	60.1291	-148.20235	:America/Anchorage	USA	knots	235	34	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.337	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bainbridge Pass	AK
99928	Prince of Wales Pass (depth 237 ft), Prince William Sound, Alaska Current	NOS	PWS0714_1	60.0362	-148.13448	:America/Anchorage	USA	knots	203	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Prince of Wales Pass	AK
99929	Prince of Wales Pass (depth 138 ft), Prince William Sound, Alaska Current	NOS	PWS0714_11	60.0362	-148.13448	:America/Anchorage	USA	knots	202	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Prince of Wales Pass	AK
99930	Prince of Wales Pass (depth 30 ft), Prince William Sound, Alaska Current	NOS	PWS0714_22	60.0362	-148.13448	:America/Anchorage	USA	knots	202	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.207	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Prince of Wales Pass	AK
99931	Sawmill Bay ent., Evans Island (depth 158 ft), Prince William Sound, Alaska Current	NOS	PWS0715_1	60.0591	-147.97423	:America/Anchorage	USA	knots	243	50	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sawmill Bay Entr., Evans Island	AK
99932	Sawmill Bay ent., Evans Island (depth 79 ft), Prince William Sound, Alaska Current	NOS	PWS0715_7	60.0591	-147.97423	:America/Anchorage	USA	knots	235	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sawmill Bay Entr., Evans Island	AK
99933	Sawmill Bay ent., Evans Island (depth 14 ft), Prince William Sound, Alaska Current	NOS	PWS0715_12	60.0591	-147.97423	:America/Anchorage	USA	knots	234	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.192	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sawmill Bay Entr., Evans Island	AK
99934	Elrington Passage (depth 295 ft), Prince William Sound, Alaska Current	NOS	PWS0716_1	59.97951	-148.1167	:America/Anchorage	USA	knots	231	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elrington Passage	AK
99935	Elrington Passage (depth 180 ft), Prince William Sound, Alaska Current	NOS	PWS0716_8	59.97951	-148.1167	:America/Anchorage	USA	knots	229	51	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elrington Passage	AK
99936	Elrington Passage (depth 49 ft), Prince William Sound, Alaska Current	NOS	PWS0716_16	59.97951	-148.1167	:America/Anchorage	USA	knots	232	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elrington Passage	AK
99937	Latouche Pass (depth 108 ft), Prince William Sound, Alaska Current	NOS	PWS0717_1	59.97666	-148.04645	:America/Anchorage	USA	knots	223	27	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.234	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Latouche Pass	AK
99938	Latouche Pass (depth 62 ft), Prince William Sound, Alaska Current	NOS	PWS0717_8	59.97666	-148.04645	:America/Anchorage	USA	knots	220	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Latouche Pass	AK
99939	Latouche Pass (depth 23 ft), Prince William Sound, Alaska Current	NOS	PWS0717_14	59.97666	-148.04645	:America/Anchorage	USA	knots	217	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.367	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Latouche Pass	AK
99940	Montague Strait (depth 290 ft), Prince William Sound, Alaska Current	NOS	PWS0719_1	59.9146	-147.96072	:America/Anchorage	USA	knots	228	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Strait	AK
99941	Montague Strait (depth 172 ft), Prince William Sound, Alaska Current	NOS	PWS0719_7	59.9146	-147.96072	:America/Anchorage	USA	knots	236	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Strait	AK
99942	Montague Strait (depth 54 ft), Prince William Sound, Alaska Current	NOS	PWS0719_13	59.9146	-147.96072	:America/Anchorage	USA	knots	236	47	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Strait	AK
99943	Wooded Island (depth 156 ft), Hinchinbrook entrance, Prince William Sound, Alaska Current	NOS	PWS0721_1	59.86825	-147.28112	:America/Anchorage	USA	knots	231	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wooded Island	AK
99944	Wooded Island (depth 97 ft), Hinchinbrook entrance, Prince William Sound, Alaska Current	NOS	PWS0721_10	59.86825	-147.28112	:America/Anchorage	USA	knots	208	65	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.309	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wooded Island	AK
99945	Wooded Island (depth 25 ft), Hinchinbrook entrance, Prince William Sound, Alaska Current	NOS	PWS0721_21	59.86825	-147.28112	:America/Anchorage	USA	knots	204	81	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.692	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wooded Island	AK
99946	Snug Harbor (depth 280 ft), Prince William Sound, Alaska Current	NOS	PWS0723_1	60.2758	-147.63456	:America/Anchorage	USA	knots	\N	10.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snug Harbor	AK
99947	Snug Harbor (depth 162 ft), Prince William Sound, Alaska Current	NOS	PWS0723_10	60.2758	-147.63456	:America/Anchorage	USA	knots	291	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snug Harbor	AK
99948	Snug Harbor (depth 57 ft), Prince William Sound, Alaska Current	NOS	PWS0723_18	60.2758	-147.63456	:America/Anchorage	USA	knots	\N	19	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.259	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snug Harbor	AK
99949	Green Island Pass (depth 163 ft), Prince William Sound, Alaska Current	NOS	PWS0724_3	60.26732	-147.30157	:America/Anchorage	USA	knots	201	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Island Pass	AK
99950	Green Island Pass (depth 104 ft), Prince William Sound, Alaska Current	NOS	PWS0724_9	60.26732	-147.30157	:America/Anchorage	USA	knots	\N	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.191	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Island Pass	AK
99951	Green Island Pass (depth 35 ft), Prince William Sound, Alaska Current	NOS	PWS0724_16	60.26732	-147.30157	:America/Anchorage	USA	knots	214	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.22	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Green Island Pass	AK
99952	Montague Point (depth 277 ft), Prince William Sound, Alaska Current	NOS	PWS0725_1	60.39838	-147.09389	:America/Anchorage	USA	knots	261	88	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Point	AK
99953	Montague Point (depth 158 ft), Prince William Sound, Alaska Current	NOS	PWS0725_10	60.39838	-147.09389	:America/Anchorage	USA	knots	279	99	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Point	AK
99954	Montague Point (depth 40 ft), Prince William Sound, Alaska Current	NOS	PWS0725_19	60.39838	-147.09389	:America/Anchorage	USA	knots	323	92	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.386	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Montague Point	AK
99955	Bear Cape (depth 566 ft), Hinchinbrook entrance, Prince William Sound, Alaska Current	NOS	PWS0726_1	60.35199	-146.74626	:America/Anchorage	USA	knots	171	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Cape	AK
99956	Bear Cape (depth 251 ft), Hinchinbrook entrance, Prince William Sound, Alaska Current	NOS	PWS0726_13	60.35199	-146.74626	:America/Anchorage	USA	knots	176	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Cape	AK
99957	Johnstone Point (depth 231 ft), Prince William Sound, Alaska Current	NOS	PWS0727_1	60.48874	-146.61651	:America/Anchorage	USA	knots	241	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johnstone Point	AK
99958	Johnstone Point (depth 139 ft), Prince William Sound, Alaska Current	NOS	PWS0727_8	60.48874	-146.61651	:America/Anchorage	USA	knots	252	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johnstone Point	AK
99959	Johnstone Point (depth 34 ft), Prince William Sound, Alaska Current	NOS	PWS0727_16	60.48874	-146.61651	:America/Anchorage	USA	knots	250	65	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.206	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Johnstone Point	AK
99960	Cape Hinchinbrook approach (depth 181 ft), Prince William Sound, Alaska Current	NOS	PWS0729_1	60.22488	-146.22623	:America/Anchorage	USA	knots	84	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Hinchinbrook Approach	AK
99961	Cape Hinchinbrook approach (depth 115 ft), Prince William Sound, Alaska Current	NOS	PWS0729_6	60.22488	-146.22623	:America/Anchorage	USA	knots	\N	280	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Hinchinbrook Approach	AK
99962	Cape Hinchinbrook approach (depth 37 ft), Prince William Sound, Alaska Current	NOS	PWS0729_12	60.22488	-146.22623	:America/Anchorage	USA	knots	\N	291.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.294	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Hinchinbrook Approach	AK
99963	Middle Ground Shoal, north of (depth 185 ft), Prince William Sound, Alaska Current	NOS	PWS0731_1	60.55797	-146.36622	:America/Anchorage	USA	knots	270	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Ground Shoal, north of	AK
99964	Middle Ground Shoal, north of (depth 119 ft), Prince William Sound, Alaska Current	NOS	PWS0731_6	60.55797	-146.36622	:America/Anchorage	USA	knots	272	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Ground Shoal, north of	AK
99965	Middle Ground Shoal, north of (depth 41 ft), Prince William Sound, Alaska Current	NOS	PWS0731_12	60.55797	-146.36622	:America/Anchorage	USA	knots	283	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Ground Shoal, north of	AK
99966	Channel Island (depth 150 ft), Prince William Sound, Alaska Current	NOS	PWS0732_1	60.60438	-145.84024	:America/Anchorage	USA	knots	251	89	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Channel Island	AK
99967	Channel Island (depth 84 ft), Prince William Sound, Alaska Current	NOS	PWS0732_6	60.60438	-145.84024	:America/Anchorage	USA	knots	249	73.3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Channel Island	AK
99968	Channel Island (depth 32 ft), Prince William Sound, Alaska Current	NOS	PWS0732_10	60.60438	-145.84024	:America/Anchorage	USA	knots	247	83	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Channel Island	AK
99969	Salmo Point (depth 75 ft), Prince William Sound, Alaska Current	NOS	PWS0733_1	60.61672	-145.77075	:America/Anchorage	USA	knots	245	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Salmo Point	AK
99970	Salmo Point (depth 49 ft), Prince William Sound, Alaska Current	NOS	PWS0733_5	60.61672	-145.77075	:America/Anchorage	USA	knots	241	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.231	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Salmo Point	AK
99971	Salmo Point (depth 16 ft), Prince William Sound, Alaska Current	NOS	PWS0733_10	60.61672	-145.77075	:America/Anchorage	USA	knots	237	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.309	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Salmo Point	AK
99972	Old Log Boom (depth 44 ft), Prince William Sound, Alaska Current	NOS	PWS0734_1	60.5723	-145.74343	:America/Anchorage	USA	knots	35	218	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Log Boom	AK
99973	Old Log Boom (depth 31 ft), Prince William Sound, Alaska Current	NOS	PWS0734_3	60.5723	-145.74343	:America/Anchorage	USA	knots	34	221	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Log Boom	AK
99974	Old Log Boom (depth 12 ft), Prince William Sound, Alaska Current	NOS	PWS0734_6	60.5723	-145.74343	:America/Anchorage	USA	knots	36	221	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Log Boom	AK
99977	Mud Bay (depth 14 ft), Prince William Sound, Alaska Current	NOS	PWS0735_9	60.54765	-145.84088	:America/Anchorage	USA	knots	62	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mud Bay	AK
99978	Port Gravina (depth 312 ft), Prince William Sound, Alaska Current	NOS	PWS0736_1	60.60636	-146.38952	:America/Anchorage	USA	knots	\N	42.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Gravina	AK
99979	Port Gravina (depth 181 ft), Prince William Sound, Alaska Current	NOS	PWS0736_11	60.60636	-146.38952	:America/Anchorage	USA	knots	267	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Gravina	AK
99980	Port Gravina (depth 50 ft), Prince William Sound, Alaska Current	NOS	PWS0736_21	60.60636	-146.38952	:America/Anchorage	USA	knots	\N	86	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Gravina	AK
99981	Between Naked and Eleanor Islands (depth 244 ft), Prince William Sound, Alaska Current	NOS	PWS0739_1	60.607669830322266	-147.4893341064453	:America/Anchorage	USA	knots	149	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Between Naked and Eleanor Islands	AK
99982	Between Naked and Eleanor Islands (depth 139 ft), Prince William Sound, Alaska Current	NOS	PWS0739_9	60.607669830322266	-147.4893341064453	:America/Anchorage	USA	knots	132	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Between Naked and Eleanor Islands	AK
99983	Between Naked and Eleanor Islands (depth 34 ft), Prince William Sound, Alaska Current	NOS	PWS0739_17	60.607669830322266	-147.4893341064453	:America/Anchorage	USA	knots	137	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Between Naked and Eleanor Islands	AK
99984	Storey Island and Peak Island, between (depth 292 ft), Alaska Current	NOS	PWS0740_1	60.72666931152344	-147.30482482910156	:America/Anchorage	USA	knots	\N	2.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Storey Island and Peak Island, between	AK
99985	Storey Island and Peak Island, between (depth 177 ft), Alaska Current	NOS	PWS0740_8	60.72666931152344	-147.30482482910156	:America/Anchorage	USA	knots	\N	315.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Storey Island and Peak Island, between	AK
99986	Storey Island and Peak Island, between (depth 46 ft), Alaska Current	NOS	PWS0740_16	60.72666931152344	-147.30482482910156	:America/Anchorage	USA	knots	117	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Storey Island and Peak Island, between	AK
99987	Storey Island, north of (depth 261 ft), Prince William Sound, Alaska Current	NOS	PWS0741_2	60.75041	-147.40586	:America/Anchorage	USA	knots	86	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Storey Island, north of	AK
99988	Storey Island, north of (depth 179 ft), Prince William Sound, Alaska Current	NOS	PWS0741_7	60.75041	-147.40586	:America/Anchorage	USA	knots	90	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Storey Island, north of	AK
99989	Storey Island, north of (depth 48 ft), Prince William Sound, Alaska Current	NOS	PWS0741_15	60.75041	-147.40586	:America/Anchorage	USA	knots	92	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Storey Island, north of	AK
99990	Outpost Island (depth 319 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0742_1	60.83539	-147.44942	:America/Anchorage	USA	knots	\N	306.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Outpost Island	AK
99991	Outpost Island (depth 106 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0742_14	60.83539	-147.44942	:America/Anchorage	USA	knots	81	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Outpost Island	AK
99992	Outpost Island (depth 73 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0742_16	60.83539	-147.44942	:America/Anchorage	USA	knots	75	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Outpost Island	AK
99993	Slipper Point (depth 235 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0743_2	60.90998	-147.26555	:America/Anchorage	USA	knots	\N	42	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Slipper Point	AK
99994	Slipper Point (depth 143 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0743_9	60.90998	-147.26555	:America/Anchorage	USA	knots	233	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Slipper Point	AK
99995	Slipper Point (depth 25 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0743_18	60.90998	-147.26555	:America/Anchorage	USA	knots	244	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Slipper Point	AK
99996	Finski Point (depth 223 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0744_3	60.90195	-147.06415	:America/Anchorage	USA	knots	134	311.5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Finski Point	AK
99997	Finski Point (depth 131 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0744_10	60.90195	-147.06415	:America/Anchorage	USA	knots	143	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Finski Point	AK
99998	Finski Point (depth 13 ft), Central Sound, Prince William Sound, Alaska Current	NOS	PWS0744_19	60.90195	-147.06415	:America/Anchorage	USA	knots	140	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Finski Point	AK
99999	Valdez Narrows (depth 329 ft), Valdez Arm, Prince William Sound, Alaska Current	NOS	PWS0745_5	61.06976	-146.66077	:America/Anchorage	USA	knots	201	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valdez Narrows	AK
100000	Valdez Narrows (depth 231 ft), Valdez Arm, Prince William Sound, Alaska Current	NOS	PWS0745_10	61.06976	-146.66077	:America/Anchorage	USA	knots	209	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.011	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valdez Narrows	AK
100001	Valdez Narrows (depth 133 ft), Valdez Arm, Prince William Sound, Alaska Current	NOS	PWS0745_15	61.06976	-146.66077	:America/Anchorage	USA	knots	220	34	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Valdez Narrows	AK
100002	St. Andrew Bay entrance (depth 31 ft), Florida Current	NOS	SAB0803_1	30.121771	-85.729721	:America/Chicago	USA	knots	221	47	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Andrew Bay Entrance	FL
100003	St. Andrew Bay entrance (depth 18 ft), Florida Current	NOS	SAB0803_5	30.121771	-85.729721	:America/Chicago	USA	knots	225	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Andrew Bay Entrance	FL
100004	St. Andrew Bay entrance (depth 5 ft), Florida Current	NOS	SAB0803_9	30.121771	-85.729721	:America/Chicago	USA	knots	230	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Andrew Bay Entrance	FL
100005	Paper Mill (depth 27 ft), St. Andrew Bay, Florida Current	NOS	SAB0805_1	30.130449	-85.631622	:America/Chicago	USA	knots	238	60.2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Paper Mill	FL
100006	Paper Mill (depth 16 ft), St. Andrew Bay, Florida Current	NOS	SAB0805_8	30.130449	-85.631622	:America/Chicago	USA	knots	245	86	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Paper Mill	FL
100007	Paper Mill (depth 3 ft), St. Andrew Bay, Florida Current	NOS	SAB0805_16	30.130449	-85.631622	:America/Chicago	USA	knots	249	70.9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.236	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Paper Mill	FL
100008	Redfish Point (depth 32 ft), St. Andrew Bay, Florida Current	NOS	SAB0806_1	30.14402	-85.6668	:America/Chicago	USA	knots	303	129	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redfish Point	FL
100009	Redfish Point (depth 19 ft), St. Andrew Bay, Florida Current	NOS	SAB0806_5	30.14402	-85.6668	:America/Chicago	USA	knots	310	118	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redfish Point	FL
100010	Redfish Point (depth 5 ft), St. Andrew Bay, Florida Current	NOS	SAB0806_9	30.14402	-85.6668	:America/Chicago	USA	knots	319	101	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redfish Point	FL
100011	Courtney Point, 0.75 mi SE of (depth 30 ft), St. Andrew Bay, Florida Current	NOS	SAB0807_1	30.138729	-85.699181	:America/Chicago	USA	knots	273	68	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Courtney Point, 0.75mi. SE of	FL
100012	Courtney Point, 0.75 mi SE of (depth 20 ft), St. Andrew Bay, Florida Current	NOS	SAB0807_4	30.138729	-85.699181	:America/Chicago	USA	knots	256	65	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.115	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Courtney Point, 0.75mi. SE of	FL
100013	Courtney Point, 0.75 mi SE of (depth 7 ft), St. Andrew Bay, Florida Current	NOS	SAB0807_8	30.138729	-85.699181	:America/Chicago	USA	knots	210	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Courtney Point, 0.75mi. SE of	FL
100014	Courtney Point, 0.4 mi ESE of (depth 56 ft), St. Andrew Bay, Florida Current	NOS	SAB0808_1	30.14423	-85.703331	:America/Chicago	USA	knots	\N	41.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Courtney Point, 0.4mi. ESE of	FL
100015	Courtney Point, 0.4 mi ESE of (depth 11 ft), St. Andrew Bay, Florida Current	NOS	SAB0808_5	30.14423	-85.703331	:America/Chicago	USA	knots	190	22.5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 49.2 ft.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Courtney Point, 0.4mi. ESE of	FL
100016	Courtney Point, 0.4 mi ESE of (depth 4 ft), St. Andrew Bay, Florida Current	NOS	SAB0808_9	30.14423	-85.703331	:America/Chicago	USA	knots	174	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 42.6 ft.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.302	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Courtney Point, 0.4mi. ESE of	FL
100017	Bear Point, 0.6 nmi E of (depth 27 ft), St. Andrew Bay, Florida Current	NOS	SAB0809_1	30.164351	-85.713417	:America/Chicago	USA	knots	\N	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.226	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Point, 0.6nm E of	FL
100018	Bear Point, 0.6 nmi E of (depth 14 ft), St. Andrew Bay, Florida Current	NOS	SAB0809_5	30.164351	-85.713417	:America/Chicago	USA	knots	137	312	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Point, 0.6nm E of	FL
100019	Bear Point, 0.6 nmi E of (depth 4 ft), St. Andrew Bay, Florida Current	NOS	SAB0809_8	30.164351	-85.713417	:America/Chicago	USA	knots	120	297	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bear Point, 0.6nm E of	FL
100020	Long Point, West Bay (depth 4 ft), St. Andrew Bay, Florida Current	NOS	SAB0812_1	30.23925	-85.749832	:America/Chicago	USA	knots	173	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Long Point, West Bay	FL
100021	Wrangell Narrows (off Petersburg) (depth 25 ft), Alaska Current	NOS	SEA0103_2	56.815	-132.96278	:America/Juneau	USA	knots	51	247	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 23.7 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.12	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrangell Narrows (off Petersburg)	AK
100022	Wrangell Narrows (off Petersburg) (depth 15 ft), Alaska Current	NOS	SEA0103_5	56.815	-132.96278	:America/Juneau	USA	knots	56	247	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 13.8 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrangell Narrows (off Petersburg)	AK
100023	Wrangell Narrows (off Petersburg) (depth 4 ft), Alaska Current	NOS	SEA0103_8	56.815	-132.96278	:America/Juneau	USA	knots	62	246	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Wrangell Narrows (off Petersburg)	AK
100024	South Ledge (depth 23 ft), Wrangell Narrows, Alaska Current	NOS	SEA0104_2	56.62056	-132.96344	:America/Juneau	USA	knots	218	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.319	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Ledge	AK
100025	South Ledge (depth 16 ft), Wrangell Narrows, Alaska Current	NOS	SEA0104_4	56.62056	-132.96344	:America/Juneau	USA	knots	218	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.321	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Ledge	AK
100026	South Ledge (depth 7 ft), Wrangell Narrows, Alaska Current	NOS	SEA0104_7	56.62056	-132.96344	:America/Juneau	USA	knots	218	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.338	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Ledge	AK
100027	Sergius Narrows (depth 44 ft), Peril Strait, Alaska Current	NOS	SEA0202_5	57.40702	-135.63115	:America/Juneau	USA	knots	242	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.438	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sergius Narrows	AK
100028	Sergius Narrows (depth 31 ft), Peril Strait, Alaska Current	NOS	SEA0202_7	57.40702	-135.63115	:America/Juneau	USA	knots	241	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.436	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sergius Narrows	AK
100029	Sergius Narrows (depth 18 ft), Peril Strait, Alaska Current	NOS	SEA0202_9	57.40702	-135.63115	:America/Juneau	USA	knots	241	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.433	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sergius Narrows	AK
100030	Kakul Narrows (depth 58 ft), Peril Strait, Alaska Current	NOS	SEA0203_16	57.3699	-135.6925	:America/Juneau	USA	knots	209	27	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.211	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kakul Narrows	AK
100031	Kakul Narrows (depth 19 ft), Peril Strait, Alaska Current	NOS	SEA0203_19	57.3699	-135.6925	:America/Juneau	USA	knots	211	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.207	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kakul Narrows	AK
100032	Whitestone Narrows, S of Whitestone Point (depth 43 ft), Neva Strait, Alaska Current	NOS	SEA0204_2	57.24495	-135.5639	:America/Juneau	USA	knots	339	163	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whitestone Narrows, S of Whitestone Point	AK
100033	Whitestone Narrows, S of Whitestone Point (depth 16 ft), Neva Strait, Alaska Current	NOS	SEA0204_6	57.24495	-135.5639	:America/Juneau	USA	knots	338	161	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.098	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whitestone Narrows, S of Whitestone Point	AK
100034	Creek Point, 0.44 nmi SE of (depth 15 ft), Olga Strait, Alaska Current	NOS	SEA0205_5	57.21014	-135.49492	:America/Juneau	USA	knots	141	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Creek Point, 0.44 n.mi. SE of	AK
100035	Povorotni Island, 0.23 nmi WSW of (depth 89 ft), Peril Strait, Alaska Current	NOS	SEA0302_6	57.5105	-135.56167	:America/Juneau	USA	knots	156	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Povorotni Island, 0.23 n.mi. WSW of	AK
100036	Povorotni Island, 0.23 nmi WSW of (depth 50 ft), Peril Strait, Alaska Current	NOS	SEA0302_9	57.5105	-135.56167	:America/Juneau	USA	knots	158	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Povorotni Island, 0.23 n.mi. WSW of	AK
100037	Povorotni Island, 0.23 nmi WSW of (depth 10 ft), Peril Strait, Alaska Current	NOS	SEA0302_12	57.5105	-135.56167	:America/Juneau	USA	knots	159	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Povorotni Island, 0.23 n.mi. WSW of	AK
100038	Big Rose Island, 0.2 nmi SE of (depth 92 ft), Peril Strait, Alaska Current	NOS	SEA0303_3	57.45308	-135.5373	:America/Juneau	USA	knots	221	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Big Rose Island, 0.2 n.mi. SE of	AK
100039	Big Rose Island, 0.2 nmi SE of (depth 32 ft), Peril Strait, Alaska Current	NOS	SEA0303_12	57.45308	-135.5373	:America/Juneau	USA	knots	212	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Big Rose Island, 0.2 n.mi. SE of	AK
100040	Big Rose Island, 0.2 nmi SE of (depth 12 ft), Peril Strait, Alaska Current	NOS	SEA0303_15	57.45308	-135.5373	:America/Juneau	USA	knots	212	42	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 13.1 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Big Rose Island, 0.2 n.mi. SE of	AK
100041	Suloia Point, 0.32 nmi ENE of (depth 92 ft), Peril Strait, Alaska Current	NOS	SEA0304_12	57.39217	-135.64105	:America/Juneau	USA	knots	113	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.284	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Suloia Point, 0.32 n.mi. ENE of	AK
100042	Suloia Point, 0.32 nmi ENE of (depth 65 ft), Peril Strait, Alaska Current	NOS	SEA0304_14	57.39217	-135.64105	:America/Juneau	USA	knots	114	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.323	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Suloia Point, 0.32 n.mi. ENE of	AK
100043	Suloia Point, 0.32 nmi ENE of (depth 26 ft), Peril Strait, Alaska Current	NOS	SEA0304_17	57.39217	-135.64105	:America/Juneau	USA	knots	113	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.346	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Suloia Point, 0.32 n.mi. ENE of	AK
100044	Zeal Point, 0.34 nmi SSW of (depth 48 ft), Neva Strait, Alaska Current	NOS	SEA0306_7	57.2869	-135.6079	:America/Juneau	USA	knots	345	170	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Zeal Point, 0.34 n.mi. SSW of	AK
100045	Zeal Point, 0.34 nmi SSW of (depth 29 ft), Neva Strait, Alaska Current	NOS	SEA0306_10	57.2869	-135.6079	:America/Juneau	USA	knots	347	165	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Zeal Point, 0.34 n.mi. SSW of	AK
100046	Zeal Point, 0.34 nmi SSW of (depth 16 ft), Neva Strait, Alaska Current	NOS	SEA0306_12	57.2869	-135.6079	:America/Juneau	USA	knots	346	163	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.062	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Zeal Point, 0.34 n.mi. SSW of	AK
100047	Tracy Arm Bar (depth 32 ft), Stephens Passage, Alaska Current	NOS	SEA0307_18	57.77973	-133.63224	:America/Juneau	USA	knots	226	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 28.8 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.473	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tracy Arm Bar	AK
100048	Shrubby Island, east of (depth 308 ft), Clarence Strait, Alaska Current	NOS	SEA0401_1	56.22667	-132.90867	:America/Juneau	USA	knots	314	151	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.1	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shrubby Island, east of	AK
100049	Shrubby Island, east of (depth 72 ft), Clarence Strait, Alaska Current	NOS	SEA0401_25	56.22667	-132.90867	:America/Juneau	USA	knots	327	149	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shrubby Island, east of	AK
100050	Shrubby Island, east of (depth 61 ft), Clarence Strait, Alaska Current	NOS	SEA0401_26	56.22667	-132.90867	:America/Juneau	USA	knots	326	149	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shrubby Island, east of	AK
100051	Snow Passage, southern approach (depth 260 ft), Clarence Strait, Alaska Current	NOS	SEA0402_1	56.25633	-132.9405	:America/Juneau	USA	knots	336	159	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.459	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Passage, southern approach	AK
100052	Snow Passage, southern approach (depth 44 ft), Clarence Strait, Alaska Current	NOS	SEA0402_23	56.25633	-132.9405	:America/Juneau	USA	knots	329	162	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Passage, southern approach	AK
100053	Snow Passage, southern approach (depth 14 ft), Clarence Strait, Alaska Current	NOS	SEA0402_26	56.25633	-132.9405	:America/Juneau	USA	knots	328	163	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Passage, southern approach	AK
100054	Snow Passage Narrows (depth 299 ft), Clarence Strait, Alaska Current	NOS	SEA0403_1	56.279	-132.953	:America/Juneau	USA	knots	337	154	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.163	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Passage Narrows	AK
100055	Snow Passage Narrows (depth 43 ft), Clarence Strait, Alaska Current	NOS	SEA0403_27	56.279	-132.953	:America/Juneau	USA	knots	333	153	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Passage Narrows	AK
100056	Snow Passage Narrows (depth 23 ft), Clarence Strait, Alaska Current	NOS	SEA0403_29	56.279	-132.953	:America/Juneau	USA	knots	331	153	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.224	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Snow Passage Narrows	AK
100057	Round Island Light (depth 104 ft), Clarence Strait, Alaska Current	NOS	SEA0404_1	56.31417	-133.094	:America/Juneau	USA	knots	315	144	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Round Island Light	AK
100058	Round Island Light (depth 32 ft), Clarence Strait, Alaska Current	NOS	SEA0404_12	56.31417	-133.094	:America/Juneau	USA	knots	318	146	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Round Island Light	AK
100059	Round Island Light (depth 19 ft), Clarence Strait, Alaska Current	NOS	SEA0404_14	56.31417	-133.094	:America/Juneau	USA	knots	318	148	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Round Island Light	AK
100060	Vichnefski Rock Light (depth 289 ft), Sumner Strait, Alaska Current	NOS	SEA0405_1	56.446	-133.0195	:America/Juneau	USA	knots	237	29	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.159	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vichnefski Rock Light	AK
100061	Vichnefski Rock Light (depth 54 ft), Sumner Strait, Alaska Current	NOS	SEA0405_25	56.446	-133.0195	:America/Juneau	USA	knots	227	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 52.9 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vichnefski Rock Light	AK
100079	Kake Harbor (depth 19 ft), Keku Strait, Alaska Current	NOS	SEA0505_13	56.96571	-133.95223	:America/Juneau	USA	knots	304	122	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kake Harbor	AK
100062	Vichnefski Rock Light (depth 35 ft), Sumner Strait, Alaska Current	NOS	SEA0405_27	56.446	-133.0195	:America/Juneau	USA	knots	226	50	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 33.2 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.161	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vichnefski Rock Light	AK
100063	Killisnoo Harbor (depth 90 ft), Chatham Strait, Alaska Current	NOS	SEA0406_1	57.46322	-134.56463	:America/Juneau	USA	knots	321	152	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Killisnoo Harbor	AK
100064	Killisnoo Harbor (depth 12 ft), Chatham Strait, Alaska Current	NOS	SEA0406_25	57.46322	-134.56463	:America/Juneau	USA	knots	321	142	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Killisnoo Harbor	AK
100065	Western Channel (depth 110 ft), Sitka Sound, Alaska Current	NOS	SEA0409_1	57.0503	-135.39578	:America/Juneau	USA	knots	193	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Western Channel	AK
100066	Western Channel (depth 64 ft), Sitka Sound, Alaska Current	NOS	SEA0409_8	57.0503	-135.39578	:America/Juneau	USA	knots	193	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Western Channel	AK
100067	Western Channel (depth 18 ft), Sitka Sound, Alaska Current	NOS	SEA0409_15	57.0503	-135.39578	:America/Juneau	USA	knots	210	29	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Western Channel	AK
100068	The Brother, east of (depth 488 ft), Stephens Passage, Alaska Current	NOS	SEA0502_1	57.32245	-133.7334	:America/Juneau	USA	knots	164	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Brother, east of	AK
100069	The Brother, east of (depth 173 ft), Stephens Passage, Alaska Current	NOS	SEA0502_13	57.32245	-133.7334	:America/Juneau	USA	knots	207	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Brother, east of	AK
100070	The Brother, east of (depth 68 ft), Stephens Passage, Alaska Current	NOS	SEA0502_17	57.32245	-133.7334	:America/Juneau	USA	knots	\N	50.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Brother, east of	AK
100071	The Five Fingers (depth 250 ft), Stephens Passage, Alaska Current	NOS	SEA0503_1	57.26632	-133.60353	:America/Juneau	USA	knots	164	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Five Fingers	AK
100072	The Five Fingers (depth 158 ft), Stephens Passage, Alaska Current	NOS	SEA0503_8	57.26632	-133.60353	:America/Juneau	USA	knots	208	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Five Fingers	AK
100073	The Five Fingers (depth 40 ft), Stephens Passage, Alaska Current	NOS	SEA0503_17	57.26632	-133.60353	:America/Juneau	USA	knots	215	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Five Fingers	AK
100074	Turnabout Island (depth 261 ft), Frederick Sound, Alaska Current	NOS	SEA0504_1	57.11598	-133.92482	:America/Juneau	USA	knots	244	71	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turnabout Island	AK
100075	Turnabout Island (depth 156 ft), Frederick Sound, Alaska Current	NOS	SEA0504_9	57.11598	-133.92482	:America/Juneau	USA	knots	252	77	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turnabout Island	AK
100076	Turnabout Island (depth 51 ft), Frederick Sound, Alaska Current	NOS	SEA0504_17	57.11598	-133.92482	:America/Juneau	USA	knots	260	80	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.144	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Turnabout Island	AK
100077	Kake Harbor (depth 98 ft), Keku Strait, Alaska Current	NOS	SEA0505_1	56.96571	-133.95223	:America/Juneau	USA	knots	296	115	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kake Harbor	AK
100078	Kake Harbor (depth 45 ft), Keku Strait, Alaska Current	NOS	SEA0505_9	56.96571	-133.95223	:America/Juneau	USA	knots	300	110	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kake Harbor	AK
100080	Hawk Inlet, Hawk Point (depth 78 ft), Chatham Strait, Alaska Current	NOS	SEA0507_2	58.09733	-134.77512	:America/Juneau	USA	knots	182	335	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawk Inlet, Hawk Point	AK
100081	Hawk Inlet, Hawk Point (depth 59 ft), Chatham Strait, Alaska Current	NOS	SEA0507_5	58.09733	-134.77512	:America/Juneau	USA	knots	181	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.124	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawk Inlet, Hawk Point	AK
100082	Hawk Inlet, Hawk Point (depth 13 ft), Chatham Strait, Alaska Current	NOS	SEA0507_12	58.09733	-134.77512	:America/Juneau	USA	knots	178	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.342	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hawk Inlet, Hawk Point	AK
100083	The Eye Opener (depth 108 ft), Sumner Strait, Alaska Current	NOS	SEA0601_1	56.37623	-133.24576	:America/Juneau	USA	knots	283	89	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.146	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Eye Opener	AK
100084	The Eye Opener (depth 62 ft), Sumner Strait, Alaska Current	NOS	SEA0601_8	56.37623	-133.24576	:America/Juneau	USA	knots	276	100	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.29	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Eye Opener	AK
100085	The Eye Opener (depth 16 ft), Sumner Strait, Alaska Current	NOS	SEA0601_15	56.37623	-133.24576	:America/Juneau	USA	knots	272	103	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.66	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Eye Opener	AK
100086	Red Bay entrance (depth 95 ft), Sumner Strait, Alaska Current	NOS	SEA0602_1	56.32918	-133.30283	:America/Juneau	USA	knots	126	251	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bay Entrance	AK
100087	Red Bay entrance (depth 63 ft), Sumner Strait, Alaska Current	NOS	SEA0602_6	56.32918	-133.30283	:America/Juneau	USA	knots	100	238	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bay Entrance	AK
100088	Red Bay entrance (depth 17 ft), Sumner Strait, Alaska Current	NOS	SEA0602_13	56.32918	-133.30283	:America/Juneau	USA	knots	20	210	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Red Bay Entrance	AK
100089	Sumner Island, east of (depth 328 ft), Sumner Strait, Alaska Current	NOS	SEA0603_1	56.40549	-133.74774	:America/Juneau	USA	knots	191	330	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.224	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sumner Island, east of	AK
100090	Sumner Island, east of (depth 229 ft), Sumner Strait, Alaska Current	NOS	SEA0603_11	56.40549	-133.74774	:America/Juneau	USA	knots	213	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.343	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sumner Island, east of	AK
100091	Sumner Island, east of (depth 150 ft), Sumner Strait, Alaska Current	NOS	SEA0603_19	56.40549	-133.74774	:America/Juneau	USA	knots	226	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.277	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sumner Island, east of	AK
100092	Helm Rock (depth 128 ft), Sumner Strait, Alaska Current	NOS	SEA0604_2	56.37537	-133.66786	:America/Juneau	USA	knots	233	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Helm Rock	AK
100093	Helm Rock (depth 80 ft), Sumner Strait, Alaska Current	NOS	SEA0604_7	56.37537	-133.66786	:America/Juneau	USA	knots	234	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.34	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Helm Rock	AK
100094	Helm Rock (depth 30 ft), Sumner Strait, Alaska Current	NOS	SEA0604_12	56.37537	-133.66786	:America/Juneau	USA	knots	240	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.787	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Helm Rock	AK
100095	Mariposa Reef, 3 mi south of (depth 322 ft), Sumner Strait, Alaska Current	NOS	SEA0605_1	56.33161	-133.72589	:America/Juneau	USA	knots	229	42	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.307	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mariposa Reef, 3 miles south of	AK
100096	Mariposa Reef, 3 mi south of (depth 184 ft), Sumner Strait, Alaska Current	NOS	SEA0605_8	56.33161	-133.72589	:America/Juneau	USA	knots	222	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.527	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mariposa Reef, 3 miles south of	AK
100097	Mariposa Reef, 3 mi south of (depth 46 ft), Sumner Strait, Alaska Current	NOS	SEA0605_15	56.33161	-133.72589	:America/Juneau	USA	knots	\N	32.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.813	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mariposa Reef, 3 miles south of	AK
100098	Calder Rocks (depth 186 ft), Sumner Strait, Alaska Current	NOS	SEA0608_1	56.23982	-133.73993	:America/Juneau	USA	knots	176	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Calder Rocks	AK
100099	Calder Rocks (depth 107 ft), Sumner Strait, Alaska Current	NOS	SEA0608_9	56.23982	-133.73993	:America/Juneau	USA	knots	198	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Calder Rocks	AK
100100	Calder Rocks (depth 38 ft), Sumner Strait, Alaska Current	NOS	SEA0608_16	56.23982	-133.73993	:America/Juneau	USA	knots	\N	29.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Calder Rocks	AK
100101	Amelius Island, 1 mi east of (depth 105 ft), Sumner Strait, Alaska Current	NOS	SEA0609_1	56.17779	-133.84177	:America/Juneau	USA	knots	228	78	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.212	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Amelius Island, 1 mile east of	AK
100102	Amelius Island, 1 mi east of (depth 66 ft), Sumner Strait, Alaska Current	NOS	SEA0609_5	56.17779	-133.84177	:America/Juneau	USA	knots	\N	57.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.313	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Amelius Island, 1 mile east of	AK
100103	Amelius Island, 1 mi east of (depth 16 ft), Sumner Strait, Alaska Current	NOS	SEA0609_10	56.17779	-133.84177	:America/Juneau	USA	knots	\N	49.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.409	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Amelius Island, 1 mile east of	AK
100104	Shakan Light, 2.4 mi west of (depth 202 ft), Sumner Strait, Alaska Current	NOS	SEA0610_1	56.1455	-133.69709	:America/Juneau	USA	knots	\N	337.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Light, 2.4 miles west of	AK
100105	Shakan Light, 2.4 mi west of (depth 114 ft), Sumner Strait, Alaska Current	NOS	SEA0610_10	56.1455	-133.69709	:America/Juneau	USA	knots	256	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Light, 2.4 miles west of	AK
100106	Shakan Light, 2.4 mi west of (depth 25 ft), Sumner Strait, Alaska Current	NOS	SEA0610_19	56.1455	-133.69709	:America/Juneau	USA	knots	212	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Light, 2.4 miles west of	AK
100107	Shipley Bay entrance (depth 153 ft), Sumner Strait, Alaska Current	NOS	SEA0611_1	56.09037	-133.68957	:America/Juneau	USA	knots	235	79	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.101	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shipley Bay Entrance	AK
100108	Shipley Bay entrance (depth 94 ft), Sumner Strait, Alaska Current	NOS	SEA0611_7	56.09037	-133.68957	:America/Juneau	USA	knots	233	76	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shipley Bay Entrance	AK
100109	Shipley Bay entrance (depth 35 ft), Sumner Strait, Alaska Current	NOS	SEA0611_13	56.09037	-133.68957	:America/Juneau	USA	knots	238	71	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.109	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shipley Bay Entrance	AK
100110	Shakan Strait, west end (depth 41 ft), Sumner Strait, Alaska Current	NOS	SEA0612_1	56.12992	-133.57493	:America/Juneau	USA	knots	320	143	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Strait, west end	AK
100111	Shakan Strait, west end (depth 28 ft), Sumner Strait, Alaska Current	NOS	SEA0612_3	56.12992	-133.57493	:America/Juneau	USA	knots	316	146	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Strait, west end	AK
100112	Shakan Strait, west end (depth 15 ft), Sumner Strait, Alaska Current	NOS	SEA0612_5	56.12992	-133.57493	:America/Juneau	USA	knots	314	152	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Strait, west end	AK
100113	Shakan Strait Rock (depth 70 ft), Sumner Strait, Alaska Current	NOS	SEA0613_1	56.12743	-133.49875	:America/Juneau	USA	knots	233	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Strait Rock	AK
100114	Shakan Strait Rock (depth 44 ft), Sumner Strait, Alaska Current	NOS	SEA0613_5	56.12743	-133.49875	:America/Juneau	USA	knots	237	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Strait Rock	AK
100115	Shakan Strait Rock (depth 17 ft), Sumner Strait, Alaska Current	NOS	SEA0613_9	56.12743	-133.49875	:America/Juneau	USA	knots	241	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shakan Strait Rock	AK
100116	El Capitan Strait, northwest entrance (depth 20 ft), El Capitan Passage, Alaska Current	NOS	SEA0614_1	56.15352	-133.45707	:America/Juneau	USA	knots	246	75	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	El Capitan Strait, northwest entrance	AK
100117	El Capitan Strait, northwest entrance (depth 14 ft), El Capitan Passage, Alaska Current	NOS	SEA0614_2	56.15352	-133.45707	:America/Juneau	USA	knots	235	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	El Capitan Strait, northwest entrance	AK
100118	Dry Pass (depth 16 ft), Sumner Strait, Alaska Current	NOS	SEA0616_5	56.16123	-133.39945	:America/Juneau	USA	knots	286	120	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dry Pass	AK
100119	Dry Pass (depth 6 ft), Sumner Strait, Alaska Current	NOS	SEA0616_11	56.16123	-133.39945	:America/Juneau	USA	knots	275	115	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dry Pass	AK
100120	Affleck Canal (depth 229 ft), Sumner Strait, Alaska Current	NOS	SEA0617_8	56.10349	-134.06615	:America/Juneau	USA	knots	179	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Affleck Canal	AK
100121	Affleck Canal (depth 124 ft), Sumner Strait, Alaska Current	NOS	SEA0617_12	56.10349	-134.06615	:America/Juneau	USA	knots	175	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Affleck Canal	AK
100122	Fairway Island, 2 nmi east of (depth 110 ft), Sumner Strait, Alaska Current	NOS	SEA0618_1	56.04959	-133.98963	:America/Juneau	USA	knots	240	109	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fairway Island, 2nm east of	AK
100123	Fairway Island, 2 nmi east of (depth 64 ft), Sumner Strait, Alaska Current	NOS	SEA0618_8	56.04959	-133.98963	:America/Juneau	USA	knots	153	91	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fairway Island, 2nm east of	AK
100124	Fairway Island, 2 nmi east of (depth 25 ft), Sumner Strait, Alaska Current	NOS	SEA0618_14	56.04959	-133.98963	:America/Juneau	USA	knots	257	89	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fairway Island, 2nm east of	AK
100125	Fairway Island, SW of (depth 182 ft), Sumner Strait, Alaska Current	NOS	SEA0619_1	56.03688	-134.07526	:America/Juneau	USA	knots	206	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fairway Island, SW of	AK
100126	Fairway Island, SW of (depth 117 ft), Sumner Strait, Alaska Current	NOS	SEA0619_6	56.03688	-134.07526	:America/Juneau	USA	knots	189	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.25	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fairway Island, SW of	AK
100127	Fairway Island, SW of (depth 38 ft), Sumner Strait, Alaska Current	NOS	SEA0619_12	56.03688	-134.07526	:America/Juneau	USA	knots	197	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.233	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fairway Island, SW of	AK
100128	Coronation Island - Spanish Island, between (depth 129 ft), Sumner Strait, Alaska Current	NOS	SEA0621_1	55.92551	-134.12815	:America/Juneau	USA	knots	91	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coronation Island - Spanish Island, between	AK
100129	Coronation Island - Spanish Island, between (depth 83 ft), Sumner Strait, Alaska Current	NOS	SEA0621_8	55.92551	-134.12815	:America/Juneau	USA	knots	97	264	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coronation Island - Spanish Island, between	AK
100130	Coronation Island - Spanish Island, between (depth 37 ft), Sumner Strait, Alaska Current	NOS	SEA0621_15	55.92551	-134.12815	:America/Juneau	USA	knots	99	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coronation Island - Spanish Island, between	AK
100131	Warren Channel (depth 92 ft), Sumner Strait, Alaska Current	NOS	SEA0622_1	55.93346	-133.83525	:America/Juneau	USA	knots	160	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.222	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Warren Channel	AK
100132	Warren Channel (depth 52 ft), Sumner Strait, Alaska Current	NOS	SEA0622_5	55.93346	-133.83525	:America/Juneau	USA	knots	164	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Warren Channel	AK
100133	Warren Channel (depth 23 ft), Sumner Strait, Alaska Current	NOS	SEA0622_8	55.93346	-133.83525	:America/Juneau	USA	knots	171	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.171	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Warren Channel	AK
100134	Whale Rock, 1.0 nmi SE of (depth 252 ft), Alaska Current	NOS	SEA0624_1	55.83345	-133.67503	:America/Juneau	USA	knots	242	71	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Rock, 1.0 nm SE of	AK
100135	Whale Rock, 1.0 nmi SE of (depth 147 ft), Alaska Current	NOS	SEA0624_9	55.83345	-133.67503	:America/Juneau	USA	knots	234	81	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Rock, 1.0 nm SE of	AK
100136	Whale Rock, 1.0 nmi SE of (depth 42 ft), Alaska Current	NOS	SEA0624_17	55.83345	-133.67503	:America/Juneau	USA	knots	236	80	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Whale Rock, 1.0 nm SE of	AK
100137	Tokeen Bay (depth 58 ft), Alaska Current	NOS	SEA0625_1	56.00262	-133.45682	:America/Juneau	USA	knots	274	75	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tokeen Bay	AK
100138	Tokeen Bay (depth 38 ft), Alaska Current	NOS	SEA0625_4	56.00262	-133.45682	:America/Juneau	USA	knots	268	70	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tokeen Bay	AK
100139	Tokeen Bay (depth 12 ft), Alaska Current	NOS	SEA0625_8	56.00262	-133.45682	:America/Juneau	USA	knots	260	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tokeen Bay	AK
100140	South entrance (depth 278 ft), El Capitan Passage, Alaska Current	NOS	SEA0626_1	55.89663	-133.36525	:America/Juneau	USA	knots	194	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South entrance	AK
100141	South entrance (depth 159 ft), El Capitan Passage, Alaska Current	NOS	SEA0626_10	55.89663	-133.36525	:America/Juneau	USA	knots	187	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South entrance	AK
100142	South entrance (depth 41 ft), El Capitan Passage, Alaska Current	NOS	SEA0626_19	55.89663	-133.36525	:America/Juneau	USA	knots	204	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South entrance	AK
100143	Tuxekan Passage, north of Kutegi Point (depth 64 ft), Alaska Current	NOS	SEA0627_1	55.908	-133.27065	:America/Juneau	USA	knots	167	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tuxekan Passage, north of Kutegi Point	AK
100144	Tuxekan Passage, north of Kutegi Point (depth 38 ft), Alaska Current	NOS	SEA0627_5	55.908	-133.27065	:America/Juneau	USA	knots	163	324	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tuxekan Passage, north of Kutegi Point	AK
100145	Tuxekan Passage, north of Kutegi Point (depth 17 ft), Alaska Current	NOS	SEA0627_8	55.908	-133.27065	:America/Juneau	USA	knots	155	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tuxekan Passage, north of Kutegi Point	AK
100146	Sea Otter Sound (depth 266 ft), Alaska Current	NOS	SEA0628_1	55.84245	-133.51345	:America/Juneau	USA	knots	304	127	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Otter Sound	AK
100147	Sea Otter Sound (depth 147 ft), Alaska Current	NOS	SEA0628_10	55.84245	-133.51345	:America/Juneau	USA	knots	307	118	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Otter Sound	AK
100148	Sea Otter Sound (depth 82 ft), Alaska Current	NOS	SEA0628_15	55.84245	-133.51345	:America/Juneau	USA	knots	305	128	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sea Otter Sound	AK
100149	Karheen Passage, west of Cob Island (depth 76 ft), Alaska Current	NOS	SEA0629_1	55.79676	-133.30957	:America/Juneau	USA	knots	337	173	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Karheen Passage, west of Cob Island	AK
100150	Karheen Passage, west of Cob Island (depth 46 ft), Alaska Current	NOS	SEA0629_10	55.79676	-133.30957	:America/Juneau	USA	knots	335	166	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Karheen Passage, west of Cob Island	AK
100151	Karheen Passage, west of Cob Island (depth 14 ft), Alaska Current	NOS	SEA0629_20	55.79676	-133.30957	:America/Juneau	USA	knots	333	161	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Karheen Passage, west of Cob Island	AK
100152	Tonowek Narrows (depth 108 ft), Alaska Current	NOS	SEA0630_2	55.75918	-133.33546	:America/Juneau	USA	knots	214	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tonowek Narrows	AK
100153	Tonowek Narrows (depth 62 ft), Alaska Current	NOS	SEA0630_16	55.75918	-133.33546	:America/Juneau	USA	knots	219	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tonowek Narrows	AK
100154	Tonowek Narrows (depth 16 ft), Alaska Current	NOS	SEA0630_30	55.75918	-133.33546	:America/Juneau	USA	knots	224	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tonowek Narrows	AK
100155	Boca de Finas (depth 60 ft), Alaska Current	NOS	SEA0632_12	55.69768	-133.58734	:America/Juneau	USA	knots	315	125	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Boca de Finas	AK
100156	Dead Tree Point (depth 102 ft), Alaska Current	NOS	SEA0633_2	55.74561	-133.67059	:America/Juneau	USA	knots	332	156	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dead Tree Point	AK
100157	Dead Tree Point (depth 62 ft), Alaska Current	NOS	SEA0633_8	55.74561	-133.67059	:America/Juneau	USA	knots	352	154	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dead Tree Point	AK
100158	Dead Tree Point (depth 23 ft), Alaska Current	NOS	SEA0633_14	55.74561	-133.67059	:America/Juneau	USA	knots	347	154	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dead Tree Point	AK
100159	Timbered Island (depth 79 ft), Alaska Current	NOS	SEA0634_1	55.69388	-133.78426	:America/Juneau	USA	knots	202	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Timbered Island	AK
100160	Timbered Island (depth 53 ft), Alaska Current	NOS	SEA0634_5	55.69388	-133.78426	:America/Juneau	USA	knots	209	32	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Timbered Island	AK
100161	Timbered Island (depth 14 ft), Alaska Current	NOS	SEA0634_11	55.69388	-133.78426	:America/Juneau	USA	knots	203	28	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Timbered Island	AK
100162	Saint Nicholas Channel, north (depth 121 ft), Alaska Current	NOS	SEA0635_2	55.52955	-133.56271	:America/Juneau	USA	knots	196	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saint Nicholas Channel, north	AK
100163	Saint Nicholas Channel, north (depth 81 ft), Alaska Current	NOS	SEA0635_6	55.52955	-133.56271	:America/Juneau	USA	knots	198	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saint Nicholas Channel, north	AK
100164	Saint Nicholas Channel, north (depth 22 ft), Alaska Current	NOS	SEA0635_12	55.52955	-133.56271	:America/Juneau	USA	knots	184	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saint Nicholas Channel, north	AK
100165	Saint Nicholas Channel, south end (depth 146 ft), Alaska Current	NOS	SEA0636_2	55.45502	-133.63084	:America/Juneau	USA	knots	216	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saint Nicholas Channel, south end	AK
100166	Saint Nicholas Channel, south end (depth 87 ft), Alaska Current	NOS	SEA0636_8	55.45502	-133.63084	:America/Juneau	USA	knots	209	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saint Nicholas Channel, south end	AK
100167	Saint Nicholas Channel, south end (depth 28 ft), Alaska Current	NOS	SEA0636_14	55.45502	-133.63084	:America/Juneau	USA	knots	211	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saint Nicholas Channel, south end	AK
100168	Portillo Channel (depth 74 ft), Alaska Current	NOS	SEA0637_1	55.49249	-133.42566	:America/Juneau	USA	knots	159	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portillo Channel	AK
100169	Portillo Channel (depth 47 ft), Alaska Current	NOS	SEA0637_5	55.49249	-133.42566	:America/Juneau	USA	knots	155	338	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portillo Channel	AK
100170	Portillo Channel (depth 15 ft), Alaska Current	NOS	SEA0637_10	55.49249	-133.42566	:America/Juneau	USA	knots	170	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portillo Channel	AK
100171	San Christoval Chanel, Larz Lt., 0.25 nmi N of (depth 104 ft), Alaska Current	NOS	SEA0638_1	55.58824	-133.3305	:America/Juneau	USA	knots	100	307	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Christoval Chanel, Larz Lt., 0.25nm N of	AK
100172	San Christoval Chanel, Larz Lt., 0.25 nmi N of (depth 65 ft), Alaska Current	NOS	SEA0638_5	55.58824	-133.3305	:America/Juneau	USA	knots	107	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.065	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Christoval Chanel, Larz Lt., 0.25nm N of	AK
100173	San Christoval Chanel, Larz Lt., 0.25 nmi N of (depth 16 ft), Alaska Current	NOS	SEA0638_10	55.58824	-133.3305	:America/Juneau	USA	knots	106	315	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.107	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Christoval Chanel, Larz Lt., 0.25nm N of	AK
100174	San Christoval Rock (depth 42 ft), Alaska Current	NOS	SEA0639_1	55.562721	-133.29922	:America/Juneau	USA	knots	124	307	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Christoval Rock	AK
100175	San Christoval Rock (depth 29 ft), Alaska Current	NOS	SEA0639_3	55.562721	-133.29922	:America/Juneau	USA	knots	126	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Christoval Rock	AK
100176	San Christoval Rock (depth 15 ft), Alaska Current	NOS	SEA0639_5	55.562721	-133.29922	:America/Juneau	USA	knots	126	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Christoval Rock	AK
100177	Arriaga Passage, west end (depth 95 ft), Alaska Current	NOS	SEA0641_1	55.57189	-133.73307	:America/Juneau	USA	knots	274	68	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arriaga Passage, west end	AK
100178	Arriaga Passage, west end (depth 62 ft), Alaska Current	NOS	SEA0641_3	55.57189	-133.73307	:America/Juneau	USA	knots	267	65	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arriaga Passage, west end	AK
100179	Arriaga Passage, west end (depth 29 ft), Alaska Current	NOS	SEA0641_5	55.57189	-133.73307	:America/Juneau	USA	knots	265	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Arriaga Passage, west end	AK
100180	Point Rosary, west of (depth 327 ft), Alaska Current	NOS	SEA0703_1	55.27037	-133.5224	:America/Juneau	USA	knots	\N	27.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Rosary, west of	AK
100181	Point Rosary, west of (depth 196 ft), Alaska Current	NOS	SEA0703_9	55.27037	-133.5224	:America/Juneau	USA	knots	\N	9.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Rosary, west of	AK
100182	Point Rosary, west of (depth 48 ft), Alaska Current	NOS	SEA0703_18	55.27037	-133.5224	:America/Juneau	USA	knots	199	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Rosary, west of	AK
100183	Point Verde (depth 93 ft), Ulloa Channel, Alaska Current	NOS	SEA0704_1	55.29915	-133.26773	:America/Juneau	USA	knots	343	136.6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Verde	AK
100184	Point Verde (depth 54 ft), Ulloa Channel, Alaska Current	NOS	SEA0704_4	55.29915	-133.26773	:America/Juneau	USA	knots	\N	129	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Verde	AK
100185	Point Verde (depth 14 ft), Ulloa Channel, Alaska Current	NOS	SEA0704_7	55.29915	-133.26773	:America/Juneau	USA	knots	315	134	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Verde	AK
100186	Eagle Point (depth 246 ft), Meares Passage, Alaska Current	NOS	SEA0705_2	55.22023	-133.24109	:America/Juneau	USA	knots	\N	1.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Point	AK
100187	Eagle Point (depth 148 ft), Meares Passage, Alaska Current	NOS	SEA0705_7	55.22023	-133.24109	:America/Juneau	USA	knots	184	4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Point	AK
100188	Eagle Point (depth 30 ft), Meares Passage, Alaska Current	NOS	SEA0705_13	55.22023	-133.24109	:America/Juneau	USA	knots	283	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Eagle Point	AK
100189	Tlevak Narrows, Turn Point, east of (depth 77 ft), Tlevak Strait, Alaska Current	NOS	SEA0706_1	55.26486	-133.12236	:America/Juneau	USA	knots	327	127	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.242	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tlevak Narrows, Turn Point, east of	AK
100190	Tlevak Narrows, Turn Point, east of (depth 44 ft), Tlevak Strait, Alaska Current	NOS	SEA0706_11	55.26486	-133.12236	:America/Juneau	USA	knots	333	120	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.677	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tlevak Narrows, Turn Point, east of	AK
100191	Tlevak Narrows, Turn Point, east of (depth 14 ft), Tlevak Strait, Alaska Current	NOS	SEA0706_20	55.26486	-133.12236	:America/Juneau	USA	knots	330	120	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.72	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tlevak Narrows, Turn Point, east of	AK
100192	Cape Chacon, south of (depth 357 ft), Dixon Entrance, Alaska Current	NOS	SEA0708_1	54.62556	-132.05715	:America/Juneau	USA	knots	264	88	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chacon, south of	AK
100193	Cape Chacon, south of (depth 200 ft), Dixon Entrance, Alaska Current	NOS	SEA0708_7	54.62556	-132.05715	:America/Juneau	USA	knots	261	76	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.225	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chacon, south of	AK
100194	Cape Chacon, south of (depth 42 ft), Dixon Entrance, Alaska Current	NOS	SEA0708_13	54.62556	-132.05715	:America/Juneau	USA	knots	254	156	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.558	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Chacon, south of	AK
100195	Happy Harbor, Kasaan Island, Kasaan Bay (depth 295 ft), Clarence Strait, Alaska Current	NOS	SEA0709_1	55.50378	-132.3162	:America/Juneau	USA	knots	\N	292.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Happy Harbor, Kasaan Island, Kasaan Bay	AK
100196	Happy Harbor, Kasaan Island, Kasaan Bay (depth 176 ft), Clarence Strait, Alaska Current	NOS	SEA0709_7	55.50378	-132.3162	:America/Juneau	USA	knots	124	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Happy Harbor, Kasaan Island, Kasaan Bay	AK
100197	Happy Harbor, Kasaan Island, Kasaan Bay (depth 39 ft), Clarence Strait, Alaska Current	NOS	SEA0709_14	55.50378	-132.3162	:America/Juneau	USA	knots	118	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Happy Harbor, Kasaan Island, Kasaan Bay	AK
100198	Grindall Island, south of (depth 220 ft), Clarence Strait, Alaska Current	NOS	SEA0710_1	55.41102	-132.12643	:America/Juneau	USA	knots	75	280	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grindall Island, south of	AK
100199	Grindall Island, south of (depth 122 ft), Clarence Strait, Alaska Current	NOS	SEA0710_11	55.41102	-132.12643	:America/Juneau	USA	knots	108	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grindall Island, south of	AK
100200	Grindall Island, south of (depth 24 ft), Clarence Strait, Alaska Current	NOS	SEA0710_21	55.41102	-132.12643	:America/Juneau	USA	knots	183	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grindall Island, south of	AK
100201	East of the airport (depth 87 ft), Tongass Narrows, Alaska Current	NOS	SEA0711_1	55.35408	-131.69973	:America/Juneau	USA	knots	117	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.357	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	east of the airport	AK
100202	East of the airport (depth 55 ft), Tongass Narrows, Alaska Current	NOS	SEA0711_6	55.35408	-131.69973	:America/Juneau	USA	knots	128	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	east of the airport	AK
100203	East of the airport (depth 15 ft), Tongass Narrows, Alaska Current	NOS	SEA0711_12	55.35408	-131.69973	:America/Juneau	USA	knots	133	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.264	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	east of the airport	AK
100204	Pennock Island, east channel (depth 101 ft), Tongass Narrows, Alaska Current	NOS	SEA0712_1	55.31227	-131.59635	:America/Juneau	USA	knots	\N	310	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pennock Island, East Channel	AK
100205	Pennock Island, east channel (depth 62 ft), Tongass Narrows, Alaska Current	NOS	SEA0712_7	55.31227	-131.59635	:America/Juneau	USA	knots	132	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pennock Island, East Channel	AK
100206	Pennock Island, east channel (depth 16 ft), Tongass Narrows, Alaska Current	NOS	SEA0712_14	55.31227	-131.59635	:America/Juneau	USA	knots	139	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.146	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pennock Island, East Channel	AK
100207	Walden Rocks, 0.4 mi north of (depth 115 ft), Nichols Passage, Alaska Current	NOS	SEA0713_1	55.2785	-131.61152	:America/Juneau	USA	knots	231	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.227	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Walden Rocks, 0.4 mile north of	AK
100208	Walden Rocks, 0.4 mi north of (depth 76 ft), Nichols Passage, Alaska Current	NOS	SEA0713_4	55.2785	-131.61152	:America/Juneau	USA	knots	233	47	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Walden Rocks, 0.4 mile north of	AK
100209	Walden Rocks, 0.4 mi north of (depth 23 ft), Nichols Passage, Alaska Current	NOS	SEA0713_8	55.2785	-131.61152	:America/Juneau	USA	knots	207	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Walden Rocks, 0.4 mile north of	AK
100210	Pennock Island, west channel (depth 80 ft), Tongass Narrows, Alaska Current	NOS	SEA0714_1	55.30143	-131.61598	:America/Juneau	USA	knots	\N	335.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pennock Island, West Channel	AK
100211	Pennock Island, west channel (depth 41 ft), Tongass Narrows, Alaska Current	NOS	SEA0714_4	55.30143	-131.61598	:America/Juneau	USA	knots	145	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pennock Island, West Channel	AK
100212	Pennock Island, west channel (depth 14 ft), Tongass Narrows, Alaska Current	NOS	SEA0714_6	55.30143	-131.61598	:America/Juneau	USA	knots	149	296	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pennock Island, West Channel	AK
100213	Juneau Harbor, N of (depth 79 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0801_1	58.29641	-134.42468	:America/Juneau	USA	knots	\N	327.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau Harbor, N of	AK
100214	Juneau Harbor, N of (depth 50 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0801_4	58.29641	-134.42468	:America/Juneau	USA	knots	150	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau Harbor, N of	AK
100215	Juneau Harbor, N of (depth 10 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0801_8	58.29641	-134.42468	:America/Juneau	USA	knots	147	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau Harbor, N of	AK
100216	Juneau Harbor, S of (depth 53 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0803_1	58.284779	-134.39763	:America/Juneau	USA	knots	138	314	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau Harbor, S of	AK
100217	Juneau Harbor, S of (depth 33 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0803_4	58.284779	-134.39763	:America/Juneau	USA	knots	145	314	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau Harbor, S of	AK
100218	Juneau Harbor, S of (depth 13 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0803_7	58.284779	-134.39763	:America/Juneau	USA	knots	150	315	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.177	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Juneau Harbor, S of	AK
100219	N of Ship Creek (depth 81 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0804_1	58.257439	-134.33604	:America/Juneau	USA	knots	131	324	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	N of Ship Creek	AK
100220	N of Ship Creek (depth 54 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0804_3	58.257439	-134.33604	:America/Juneau	USA	knots	136	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	N of Ship Creek	AK
100221	N of Ship Creek (depth 15 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	SEA0804_6	58.257439	-134.33604	:America/Juneau	USA	knots	144	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	N of Ship Creek	AK
100222	Point Salisbury, west of (depth 67 ft), Stephens Passage, Alaska Current	NOS	SEA0805_9	58.209221	-134.24968	:America/Juneau	USA	knots	\N	318.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Salisbury, west of	AK
100223	Point Salisbury, west of (depth 21 ft), Stephens Passage, Alaska Current	NOS	SEA0805_16	58.209221	-134.24968	:America/Juneau	USA	knots	149	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Salisbury, west of	AK
100224	Point Coke, SE of, Tracy Arm (depth 289 ft), Stephens Passage, Alaska Current	NOS	SEA0810_1	57.776031	-133.64967	:America/Juneau	USA	knots	277	90	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Coke, SE of, Tracy Arm	AK
100225	Point Coke, SE of, Tracy Arm (depth 170 ft), Stephens Passage, Alaska Current	NOS	SEA0810_7	57.776031	-133.64967	:America/Juneau	USA	knots	260	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Coke, SE of, Tracy Arm	AK
100226	Point Coke, SE of, Tracy Arm (depth 33 ft), Stephens Passage, Alaska Current	NOS	SEA0810_14	57.776031	-133.64967	:America/Juneau	USA	knots	262	85	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.299	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Coke, SE of, Tracy Arm	AK
100227	Point Astley, NE of, Tracy Arm (depth 289 ft), Stephens Passage, Alaska Current	NOS	SEA0811_1	57.730019	-133.63124	:America/Juneau	USA	knots	291	106.5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Astley, NE of, Tracy Arm	AK
100228	Point Astley, NE of, Tracy Arm (depth 170 ft), Stephens Passage, Alaska Current	NOS	SEA0811_7	57.730019	-133.63124	:America/Juneau	USA	knots	209	55.8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Astley, NE of, Tracy Arm	AK
100229	Point Astley, NE of, Tracy Arm (depth 33 ft), Stephens Passage, Alaska Current	NOS	SEA0811_14	57.730019	-133.63124	:America/Juneau	USA	knots	218	115	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Astley, NE of, Tracy Arm	AK
100230	Tantallon Point, SW of (depth 184 ft), Stephens Passage, Alaska Current	NOS	SEA0812_1	58.172871	-134.2881	:America/Juneau	USA	knots	96	275.1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.179	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tantallon Point, SW of	AK
100231	Tantallon Point, SW of (depth 116 ft), Stephens Passage, Alaska Current	NOS	SEA0812_8	58.172871	-134.2881	:America/Juneau	USA	knots	95	274.6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.209	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tantallon Point, SW of	AK
100232	Tantallon Point, SW of (depth 37 ft), Stephens Passage, Alaska Current	NOS	SEA0812_16	58.172871	-134.2881	:America/Juneau	USA	knots	96	269	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Tantallon Point, SW of	AK
100233	Point Young (depth 81 ft), Stephens Passage, Alaska Current	NOS	SEA0813_1	58.20903	-134.55865	:America/Juneau	USA	knots	84	270.4	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.422	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Young	AK
100234	Point Young (depth 55 ft), Stephens Passage, Alaska Current	NOS	SEA0813_3	58.20903	-134.55865	:America/Juneau	USA	knots	89	275.9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.377	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Young	AK
100235	Point Young (depth 16 ft), Stephens Passage, Alaska Current	NOS	SEA0813_6	58.20903	-134.55865	:America/Juneau	USA	knots	80	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Young	AK
100236	Portland Island, SW of (depth 175 ft), Stephens Passage, Alaska Current	NOS	SEA0814_1	58.31937	-134.7119	:America/Juneau	USA	knots	15	212	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Island, SW of	AK
100237	Portland Island, SW of (depth 24 ft), Stephens Passage, Alaska Current	NOS	SEA0814_24	58.31937	-134.7119	:America/Juneau	USA	knots	\N	157.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portland Island, SW of	AK
100238	Piling Point, east of (depth 138 ft), Stephens Passage, Alaska Current	NOS	SEA0816_1	58.3281	-134.78336	:America/Juneau	USA	knots	326	147.1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.176	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piling Point, east of	AK
100239	Piling Point, east of (depth 79 ft), Stephens Passage, Alaska Current	NOS	SEA0816_10	58.3281	-134.78336	:America/Juneau	USA	knots	\N	151	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.265	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piling Point, east of	AK
100240	Piling Point, east of (depth 20 ft), Stephens Passage, Alaska Current	NOS	SEA0816_19	58.3281	-134.78336	:America/Juneau	USA	knots	321	140	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piling Point, east of	AK
100241	Saginaw Channel, 2 mi E of Point Retreat (depth 106 ft), Stephens Passage, Alaska Current	NOS	SEA0818_1	58.405	-134.885	:America/Juneau	USA	knots	355	151	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saginaw Channel, 2 miles E of Point Retreat	AK
100242	Saginaw Channel, 2 mi E of Point Retreat (depth 67 ft), Stephens Passage, Alaska Current	NOS	SEA0818_4	58.405	-134.885	:America/Juneau	USA	knots	347	146	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saginaw Channel, 2 miles E of Point Retreat	AK
100243	Saginaw Channel, 2 mi E of Point Retreat (depth 15 ft), Stephens Passage, Alaska Current	NOS	SEA0818_8	58.405	-134.885	:America/Juneau	USA	knots	345	148	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Saginaw Channel, 2 miles E of Point Retreat	AK
100244	North Pass, Lincoln Island (depth 230 ft), Lynn Canal, Alaska Current	NOS	SEA0819_1	58.474739	-134.9323	:America/Juneau	USA	knots	169	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Pass, Lincoln Island	AK
100245	North Pass, Lincoln Island (depth 131 ft), Lynn Canal, Alaska Current	NOS	SEA0819_11	58.474739	-134.9323	:America/Juneau	USA	knots	166	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Pass, Lincoln Island	AK
100246	North Pass, Lincoln Island (depth 33 ft), Lynn Canal, Alaska Current	NOS	SEA0819_21	58.474739	-134.9323	:America/Juneau	USA	knots	161	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Pass, Lincoln Island	AK
100247	Point Retreat, 1 mi west of (depth 413 ft), Lynn Canal, Alaska Current	NOS	SEA0820_1	58.416779	-134.9666	:America/Juneau	USA	knots	\N	354.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Retreat, 1 mile west of	AK
100248	Point Retreat, 1 mi west of (depth 232 ft), Lynn Canal, Alaska Current	NOS	SEA0820_12	58.416779	-134.9666	:America/Juneau	USA	knots	213	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.099	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Retreat, 1 mile west of	AK
100249	Point Retreat, 1 mi west of (depth 52 ft), Lynn Canal, Alaska Current	NOS	SEA0820_23	58.416779	-134.9666	:America/Juneau	USA	knots	243	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Retreat, 1 mile west of	AK
100250	Vanderbilt Reef, 2 mi west of (depth 534 ft), Lynn Canal, Alaska Current	NOS	SEA0822_1	58.603531	-135.04314	:America/Juneau	USA	knots	\N	31.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vanderbilt Reef, 2 miles west of	AK
100251	Vanderbilt Reef, 2 mi west of (depth 298 ft), Lynn Canal, Alaska Current	NOS	SEA0822_10	58.603531	-135.04314	:America/Juneau	USA	knots	\N	52.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vanderbilt Reef, 2 miles west of	AK
100252	Vanderbilt Reef, 2 mi west of (depth 88 ft), Lynn Canal, Alaska Current	NOS	SEA0822_18	58.603531	-135.04314	:America/Juneau	USA	knots	175	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Vanderbilt Reef, 2 miles west of	AK
100253	Low Point, Taiya Inlet entrance (depth 185 ft), Lynn Canal, Alaska Current	NOS	SEA0825_1	59.267231	-135.38091	:America/Juneau	USA	knots	\N	9.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Low Point, Taiya Inlet entrance	AK
100254	Low Point, Taiya Inlet entrance (depth 106 ft), Lynn Canal, Alaska Current	NOS	SEA0825_9	59.267231	-135.38091	:America/Juneau	USA	knots	\N	13	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Low Point, Taiya Inlet entrance	AK
100255	Low Point, Taiya Inlet entrance (depth 37 ft), Lynn Canal, Alaska Current	NOS	SEA0825_16	59.267231	-135.38091	:America/Juneau	USA	knots	186	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Low Point, Taiya Inlet entrance	AK
100256	Battery Point, Chilkoot Inlet (depth 241 ft), Lynn Canal, Alaska Current	NOS	SEA0826_1	59.216881	-135.35043	:America/Juneau	USA	knots	186	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.044	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Battery Point, Chilkoot Inlet	AK
100257	Battery Point, Chilkoot Inlet (depth 133 ft), Lynn Canal, Alaska Current	NOS	SEA0826_12	59.216881	-135.35043	:America/Juneau	USA	knots	181	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Battery Point, Chilkoot Inlet	AK
100258	Battery Point, Chilkoot Inlet (depth 35 ft), Lynn Canal, Alaska Current	NOS	SEA0826_22	59.216881	-135.35043	:America/Juneau	USA	knots	177	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Battery Point, Chilkoot Inlet	AK
100259	Glacier Point, Chilkat Inlet (depth 341 ft), Lynn Canal, Alaska Current	NOS	SEA0827_1	59.104671	-135.3732	:America/Juneau	USA	knots	153	329	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Point, Chilkat Inlet	AK
100260	Glacier Point, Chilkat Inlet (depth 194 ft), Lynn Canal, Alaska Current	NOS	SEA0827_10	59.104671	-135.3732	:America/Juneau	USA	knots	147	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.009	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Point, Chilkat Inlet	AK
100261	Glacier Point, Chilkat Inlet (depth 46 ft), Lynn Canal, Alaska Current	NOS	SEA0827_19	59.104671	-135.3732	:America/Juneau	USA	knots	146	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Point, Chilkat Inlet	AK
100262	South Inian Pass, west end (depth 139 ft), Cross Sound, Alaska Current	NOS	SEA0830_1	58.227909	-136.35449	:America/Juneau	USA	knots	266	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.179	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Inian Pass, west end	AK
100263	South Inian Pass, west end (depth 80 ft), Cross Sound, Alaska Current	NOS	SEA0830_10	58.227909	-136.35449	:America/Juneau	USA	knots	270	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.187	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Inian Pass, west end	AK
100264	South Inian Pass, west end (depth 21 ft), Cross Sound, Alaska Current	NOS	SEA0830_19	58.227909	-136.35449	:America/Juneau	USA	knots	270	68	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.185	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Inian Pass, west end	AK
100265	Port Althrop ent., east of George Island (depth 239 ft), Cross Sound, Alaska Current	NOS	SEA0831_1	58.201672	-136.36292	:America/Juneau	USA	knots	195	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.41	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Althrop entr, east of George Island	AK
100266	Port Althrop ent., east of George Island (depth 134 ft), Cross Sound, Alaska Current	NOS	SEA0831_17	58.201672	-136.36292	:America/Juneau	USA	knots	161	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.453	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Althrop entr, east of George Island	AK
100267	Port Althrop ent., east of George Island (depth 29 ft), Cross Sound, Alaska Current	NOS	SEA0831_33	58.201672	-136.36292	:America/Juneau	USA	knots	159	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.645	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Althrop entr, east of George Island	AK
100268	Cape Spencer, 3 mi south of (depth 236 ft), Cross Sound, Alaska Current	NOS	SEA0832_1	58.150318	-136.63261	:America/Juneau	USA	knots	227	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Spencer, 3 miles south of	AK
100269	Cape Spencer, 3 mi south of (depth 137 ft), Cross Sound, Alaska Current	NOS	SEA0832_11	58.150318	-136.63261	:America/Juneau	USA	knots	242	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.345	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Spencer, 3 miles south of	AK
100270	Cape Spencer, 3 mi south of (depth 39 ft), Cross Sound, Alaska Current	NOS	SEA0832_21	58.150318	-136.63261	:America/Juneau	USA	knots	228	88	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.498	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Spencer, 3 miles south of	AK
100271	Yakobi Rock, 1 mi west of (depth 419 ft), Cross Sound, Alaska Current	NOS	SEA0833_1	58.082668	-136.59917	:America/Juneau	USA	knots	\N	30.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yakobi Rock, 1 mile west of	AK
100272	Yakobi Rock, 1 mi west of (depth 235 ft), Cross Sound, Alaska Current	NOS	SEA0833_8	58.082668	-136.59917	:America/Juneau	USA	knots	217	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yakobi Rock, 1 mile west of	AK
100273	Yakobi Rock, 1 mi west of (depth 77 ft), Cross Sound, Alaska Current	NOS	SEA0833_14	58.082668	-136.59917	:America/Juneau	USA	knots	219	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yakobi Rock, 1 mile west of	AK
100274	Point Hogan, south passage (depth 138 ft), Alaska Current	NOS	SEA0835_1	57.68816	-136.256	:America/Juneau	USA	knots	\N	54.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Hogan, South Passage	AK
100275	Point Hogan, south passage (depth 79 ft), Alaska Current	NOS	SEA0835_10	57.68816	-136.256	:America/Juneau	USA	knots	243	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.062	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Hogan, South Passage	AK
100276	Point Hogan, south passage (depth 20 ft), Alaska Current	NOS	SEA0835_19	57.68816	-136.256	:America/Juneau	USA	knots	241	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Hogan, South Passage	AK
100277	Elbow Passage, south of Klag Island (depth 83 ft), Alaska Current	NOS	SEA0837_1	57.613762	-136.09943	:America/Juneau	USA	knots	223	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elbow Passage, south of Klag Island	AK
100278	Elbow Passage, south of Klag Island (depth 47 ft), Alaska Current	NOS	SEA0837_12	57.613762	-136.09943	:America/Juneau	USA	knots	263	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elbow Passage, south of Klag Island	AK
100279	Elbow Passage, south of Klag Island (depth 14 ft), Alaska Current	NOS	SEA0837_22	57.613762	-136.09943	:America/Juneau	USA	knots	269	42	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.272	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Elbow Passage, south of Klag Island	AK
100280	Lituya Bay entrance (depth 29 ft), Alaska Current	NOS	SEA0838_1	58.614288	-137.6601	:America/Yakutat	USA	knots	205	29	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.581	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lituya Bay Entrance	AK
100281	Lituya Bay entrance (depth 16 ft), Alaska Current	NOS	SEA0838_5	58.614288	-137.6601	:America/Yakutat	USA	knots	207	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.477	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lituya Bay Entrance	AK
100282	Lituya Bay entrance (depth 6 ft), Alaska Current	NOS	SEA0838_8	58.614288	-137.6601	:America/Yakutat	USA	knots	207	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.309	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lituya Bay Entrance	AK
100283	Sisters Reef (depth 326 ft), Alaska Current	NOS	SEA0839_1	58.184361	-135.32483	:America/Juneau	USA	knots	\N	150.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.06	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sisters Reef	AK
100284	Sisters Reef (depth 195 ft), Alaska Current	NOS	SEA0839_9	58.184361	-135.32483	:America/Juneau	USA	knots	331	158	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.005	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sisters Reef	AK
100285	Sisters Reef (depth 47 ft), Alaska Current	NOS	SEA0839_18	58.184361	-135.32483	:America/Juneau	USA	knots	296	130	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sisters Reef	AK
100286	South Passage (depth 229 ft), Alaska Current	NOS	SEA0843_1	58.235569	-136.09892	:America/Juneau	USA	knots	273	109	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Passage	AK
100287	South Passage (depth 131 ft), Alaska Current	NOS	SEA0843_16	58.235569	-136.09892	:America/Juneau	USA	knots	275	105	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.201	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Passage	AK
100288	South Passage (depth 32 ft), Alaska Current	NOS	SEA0843_31	58.235569	-136.09892	:America/Juneau	USA	knots	274	92	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.469	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Passage	AK
100289	North Passage (depth 238 ft), Alaska Current	NOS	SEA0845_1	58.318218	-136.11786	:America/Juneau	USA	knots	232	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.406	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Passage	AK
100290	North Passage (depth 133 ft), Alaska Current	NOS	SEA0845_17	58.318218	-136.11786	:America/Juneau	USA	knots	263	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Passage	AK
100291	North Passage (depth 34 ft), Alaska Current	NOS	SEA0845_32	58.318218	-136.11786	:America/Juneau	USA	knots	239	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.208	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Passage	AK
100292	Beardslee Island, west of, Glacier Bay (depth 158 ft), Alaska Current	NOS	SEA0847_1	58.467072	-136.03453	:America/Juneau	USA	knots	155	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beardslee Island, West of, Glacier Bay	AK
100293	Beardslee Island, west of, Glacier Bay (depth 86 ft), Alaska Current	NOS	SEA0847_12	58.467072	-136.03453	:America/Juneau	USA	knots	159	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beardslee Island, West of, Glacier Bay	AK
100294	Beardslee Island, west of, Glacier Bay (depth 20 ft), Alaska Current	NOS	SEA0847_22	58.467072	-136.03453	:America/Juneau	USA	knots	185	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Beardslee Island, West of, Glacier Bay	AK
100295	Hugh Miller Inlet, Glacier Bay (depth 209 ft), Alaska Current	NOS	SEA0850_1	58.7494	-136.37325	:America/Juneau	USA	knots	\N	347.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hugh Miller Inlet, Glacier Bay	AK
100296	Hugh Miller Inlet, Glacier Bay (depth 117 ft), Alaska Current	NOS	SEA0850_8	58.7494	-136.37325	:America/Juneau	USA	knots	\N	327.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hugh Miller Inlet, Glacier Bay	AK
100297	Hugh Miller Inlet, Glacier Bay (depth 25 ft), Alaska Current	NOS	SEA0850_15	58.7494	-136.37325	:America/Juneau	USA	knots	128	307	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hugh Miller Inlet, Glacier Bay	AK
100298	Lisianski Strait, north of Rock Point (depth 119 ft), Cross Sound, Alaska Current	NOS	SEA0851_1	58.005741	-136.35194	:America/Juneau	USA	knots	284	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lisianski Strait, north of Rock Point	AK
100299	Lisianski Strait, north of Rock Point (depth 67 ft), Cross Sound, Alaska Current	NOS	SEA0851_9	58.005741	-136.35194	:America/Juneau	USA	knots	275	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.216	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lisianski Strait, north of Rock Point	AK
100300	Lisianski Strait, north of Rock Point (depth 14 ft), Cross Sound, Alaska Current	NOS	SEA0851_17	58.005741	-136.35194	:America/Juneau	USA	knots	268	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.39	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lisianski Strait, north of Rock Point	AK
100301	Klawock Narrows, north of Fish Egg Island (depth 55 ft), Alaska Current	NOS	SEA0901_1	55.50733	-133.17993	:America/Juneau	USA	knots	281	102	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Klawock Narrows, north of Fish Egg Island	AK
100302	Klawock Narrows, north of Fish Egg Island (depth 35 ft), Alaska Current	NOS	SEA0901_3	55.50733	-133.17993	:America/Juneau	USA	knots	281	102	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Klawock Narrows, north of Fish Egg Island	AK
100303	Klawock Narrows, north of Fish Egg Island (depth 15 ft), Alaska Current	NOS	SEA0901_5	55.50733	-133.17993	:America/Juneau	USA	knots	269	100	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Klawock Narrows, north of Fish Egg Island	AK
100304	Pleasant Island, southwest of (depth 336 ft), Alaska Current	NOS	SEA1001_1	58.30968	-135.7382	:America/Juneau	USA	knots	318	87	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pleasant Island, southwest of	AK
100305	Pleasant Island, southwest of (depth 205 ft), Alaska Current	NOS	SEA1001_6	58.30968	-135.7382	:America/Juneau	USA	knots	309	92	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.189	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pleasant Island, southwest of	AK
100306	Pleasant Island, southwest of (depth 48 ft), Alaska Current	NOS	SEA1001_12	58.30968	-135.7382	:America/Juneau	USA	knots	323	93	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pleasant Island, southwest of	AK
100307	Glacier Bay entrance, off Point Gustavus (depth 174 ft), Alaska Current	NOS	SEA1002_1	58.38242	-135.94617	:America/Juneau	USA	knots	185	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.622	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, off Point Gustavus	AK
100308	Glacier Bay entrance, off Point Gustavus (depth 101 ft), Alaska Current	NOS	SEA1002_12	58.38242	-135.94617	:America/Juneau	USA	knots	187	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.623	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, off Point Gustavus	AK
100309	Glacier Bay entrance, off Point Gustavus (depth 23 ft), Alaska Current	NOS	SEA1002_24	58.38242	-135.94617	:America/Juneau	USA	knots	187	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.493	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, off Point Gustavus	AK
100310	Glacier Bay entrance, midchannel (depth 192 ft), Alaska Current	NOS	SEA1003_1	58.38213	-135.97673	:America/Juneau	USA	knots	159	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.6	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, midchannel	AK
100311	Glacier Bay entrance, midchannel (depth 113 ft), Alaska Current	NOS	SEA1003_13	58.38213	-135.97673	:America/Juneau	USA	knots	160	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.559	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, midchannel	AK
100312	Glacier Bay entrance, midchannel (depth 28 ft), Alaska Current	NOS	SEA1003_26	58.38213	-135.97673	:America/Juneau	USA	knots	158	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.497	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, midchannel	AK
100313	Glacier Bay entrance, off Point Carolus (depth 161 ft), Alaska Current	NOS	SEA1004_1	58.38275	-136.0155	:America/Juneau	USA	knots	166	312	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.756	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, off Point Carolus	AK
100314	Glacier Bay entrance, off Point Carolus (depth 89 ft), Alaska Current	NOS	SEA1004_12	58.38275	-136.0155	:America/Juneau	USA	knots	172	288	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-1.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, off Point Carolus	AK
100315	Glacier Bay entrance, off Point Carolus (depth 17 ft), Alaska Current	NOS	SEA1004_23	58.38275	-136.0155	:America/Juneau	USA	knots	174	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-1.244	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Glacier Bay entrance, off Point Carolus	AK
100316	South Inian Pass, east end (depth 199 ft), Cross Sound, Alaska Current	NOS	SEA1005_1	58.2241	-136.30842	:America/Juneau	USA	knots	229	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Inian Pass, east end	AK
100317	South Inian Pass, east end (depth 113 ft), Cross Sound, Alaska Current	NOS	SEA1005_14	58.2241	-136.30842	:America/Juneau	USA	knots	239	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.159	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Inian Pass, east end	AK
100318	South Inian Pass, east end (depth 28 ft), Cross Sound, Alaska Current	NOS	SEA1005_27	58.2241	-136.30842	:America/Juneau	USA	knots	246	76	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.236	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	South Inian Pass, east end	AK
100319	North Inian Pass, east end (depth 95 ft), Cross Sound, Alaska Current	NOS	SEA1006_30	58.28403	-136.36993	:America/Juneau	USA	knots	131	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Inian Pass, east end	AK
100320	North Inian Pass, west end (depth 843 ft), Cross Sound, Alaska Current	NOS	SEA1007_2	58.28328	-136.38465	:America/Juneau	USA	knots	\N	105.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.596	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Inian Pass, west end	AK
100321	North Inian Pass, west end (depth 502 ft), Cross Sound, Alaska Current	NOS	SEA1007_15	58.28328	-136.38465	:America/Juneau	USA	knots	\N	69.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.139	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Inian Pass, west end	AK
100322	North Inian Pass, west end (depth 135 ft), Cross Sound, Alaska Current	NOS	SEA1007_29	58.28328	-136.38465	:America/Juneau	USA	knots	232	78	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.577	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Inian Pass, west end	AK
100787	Butter I., 0.3 nmi SE of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0186_1	44.22217	-68.77783	:America/New_York	USA	knots	194	50	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:07:00	\N	0.6	-01:50:00	\N	0.4	-02:53:00	-00:02:00	Butter I., 0.3 nautical mile SE of	ME
100323	Cross Sound entrance, NW of Cape Bingham (depth 552 ft), Alaska Current	NOS	SEA1008_17	58.1225	-136.56735	:America/Juneau	USA	knots	\N	6.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Sound Entrance, NW of Cape Bingham	AK
100324	Cross Sound entrance, NW of Cape Bingham (depth 106 ft), Alaska Current	NOS	SEA1008_34	58.1225	-136.56735	:America/Juneau	USA	knots	218	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Sound Entrance, NW of Cape Bingham	AK
100325	Cross Sound entrance, midchannel (depth 696 ft), Alaska Current	NOS	SEA1009_11	58.1531	-136.58747	:America/Juneau	USA	knots	\N	5.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.217	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Sound Entrance, midchannel	AK
100326	Cross Sound entrance, midchannel (depth 408 ft), Alaska Current	NOS	SEA1009_22	58.1531	-136.58747	:America/Juneau	USA	knots	\N	40.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Sound Entrance, midchannel	AK
100327	Cross Sound entrance, midchannel (depth 119 ft), Alaska Current	NOS	SEA1009_33	58.1531	-136.58747	:America/Juneau	USA	knots	225	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.258	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Sound Entrance, midchannel	AK
100328	Cross Sound entrance, SE of Cape Spencer Lt. (depth 250 ft), Alaska Current	NOS	SEA1010_1	58.17712	-136.61642	:America/Juneau	USA	knots	219	53	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Sound Entrance, SE of Cape Spencer Lt.	AK
100329	Cross Sound entrance, SE of Cape Spencer Lt. (depth 142 ft), Alaska Current	NOS	SEA1010_12	58.17712	-136.61642	:America/Juneau	USA	knots	232	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.328	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Sound Entrance, SE of Cape Spencer Lt.	AK
100330	Cross Sound entrance, SE of Cape Spencer Lt. (depth 34 ft), Alaska Current	NOS	SEA1010_23	58.17712	-136.61642	:America/Juneau	USA	knots	231	89	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.436	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cross Sound Entrance, SE of Cape Spencer Lt.	AK
100331	San Francisco Bay entrance (outside) (depth 124 ft), California Current	NOS	SFB1201_10	37.8106	-122.502	:America/Los_Angeles	USA	knots	235	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco Bay Entrance (Outside)	CA
100332	San Francisco Bay entrance (outside) (depth 58 ft), California Current	NOS	SFB1201_20	37.8106	-122.502	:America/Los_Angeles	USA	knots	238	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.326	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco Bay Entrance (Outside)	CA
100333	San Francisco Bay entrance (outside) (depth 19 ft), California Current	NOS	SFB1201_26	37.8106	-122.502	:America/Los_Angeles	USA	knots	239	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.493	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco Bay Entrance (Outside)	CA
100334	Golden Gate Bridge, 0.88 nmi NE of (depth 126 ft), California Current	NOS	SFB1202_1	37.82922	-122.46202	:America/Los_Angeles	USA	knots	213	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.3	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golden Gate Bridge, 0.88 nm NE of	CA
100335	Golden Gate Bridge, 0.88 nmi NE of (depth 54 ft), California Current	NOS	SFB1202_12	37.82922	-122.46202	:America/Los_Angeles	USA	knots	231	48	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.33	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golden Gate Bridge, 0.88 nm NE of	CA
100336	Golden Gate Bridge, 0.88 nmi NE of (depth 21 ft), California Current	NOS	SFB1202_17	37.82922	-122.46202	:America/Los_Angeles	USA	knots	238	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.265	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golden Gate Bridge, 0.88 nm NE of	CA
100337	Golden Gate Bridge, 0.46 nmi E of (depth 200 ft), California Current	NOS	SFB1203_5	37.82007	-122.473	:America/Los_Angeles	USA	knots	235	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.495	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golden Gate Bridge, 0.46 nm E of	CA
100442	Carquinez Strait (depth 12 ft), California Current	NOS	SFB1319_10	38.06138	-122.21823	:America/Los_Angeles	USA	knots	289	98	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carquinez Strait	CA
100338	Golden Gate Bridge, 0.46 nmi E of (depth 69 ft), California Current	NOS	SFB1203_15	37.82007	-122.473	:America/Los_Angeles	USA	knots	253	71	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.188	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golden Gate Bridge, 0.46 nm E of	CA
100339	Golden Gate Bridge, 0.46 nmi E of (depth 30 ft), California Current	NOS	SFB1203_18	37.82007	-122.473	:America/Los_Angeles	USA	knots	257	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Golden Gate Bridge, 0.46 nm E of	CA
100340	Alcatraz Island, southwest of (depth 57 ft), San Francisco Bay, California Current	NOS	SFB1204_1	37.81425	-122.432	:America/Los_Angeles	USA	knots	260	88	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alcatraz Island, southwest of	CA
100341	Alcatraz Island, southwest of (depth 21 ft), San Francisco Bay, California Current	NOS	SFB1204_12	37.81425	-122.432	:America/Los_Angeles	USA	knots	264	89	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alcatraz Island, southwest of	CA
100342	Alcatraz Island, southwest of (depth 2 ft), San Francisco Bay, California Current	NOS	SFB1204_18	37.81425	-122.432	:America/Los_Angeles	USA	knots	271	86	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.171	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alcatraz Island, southwest of	CA
100343	North Point, Pier 35, north of (depth 57 ft), San Francisco Bay, California Current	NOS	SFB1205_1	37.81423	-122.407	:America/Los_Angeles	USA	knots	282	113	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Point, Pier 35, north of	CA
100344	North Point, Pier 35, north of (depth 28 ft), San Francisco Bay, California Current	NOS	SFB1205_10	37.81423	-122.407	:America/Los_Angeles	USA	knots	296	109	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Point, Pier 35, north of	CA
100345	North Point, Pier 35, north of (depth 12 ft), San Francisco Bay, California Current	NOS	SFB1205_15	37.81423	-122.407	:America/Los_Angeles	USA	knots	300	106	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.126	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Point, Pier 35, north of	CA
100346	Pier 23 (depth 37 ft), San Francisco Bay, California Current	NOS	SFB1206_1	37.8053	-122.39728	:America/Los_Angeles	USA	knots	320	146	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pier 23	CA
100347	Pier 23 (depth 17 ft), San Francisco Bay, California Current	NOS	SFB1206_7	37.8053	-122.39728	:America/Los_Angeles	USA	knots	322	144	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.248	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pier 23	CA
100348	Pier 23 (depth 4 ft), San Francisco Bay, California Current	NOS	SFB1206_11	37.8053	-122.39728	:America/Los_Angeles	USA	knots	323	143	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.441	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pier 23	CA
100349	Bay Bridge, Pier D (depth 65 ft), San Francisco Bay, California Current	NOS	SFB1207_1	37.80093	-122.37387	:America/Los_Angeles	USA	knots	324	124	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Bridge, Pier D	CA
100350	Bay Bridge, Pier D (depth 35 ft), San Francisco Bay, California Current	NOS	SFB1207_10	37.80093	-122.37387	:America/Los_Angeles	USA	knots	317	132	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Bridge, Pier D	CA
100351	Bay Bridge, Pier D (depth 9 ft), San Francisco Bay, California Current	NOS	SFB1207_18	37.80093	-122.37387	:America/Los_Angeles	USA	knots	305	144	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.159	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Bridge, Pier D	CA
100352	Bay Bridge, Span B-C (depth 87 ft), San Francisco Bay, California Current	NOS	SFB1208_1	37.79748	-122.37387	:America/Los_Angeles	USA	knots	355	148	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.226	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Bridge, Span B-C	CA
100353	Bay Bridge, Span B-C (depth 38 ft), San Francisco Bay, California Current	NOS	SFB1208_16	37.79748	-122.37387	:America/Los_Angeles	USA	knots	338	147	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.105	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Bridge, Span B-C	CA
100354	Bay Bridge, Span B-C (depth 11 ft), San Francisco Bay, California Current	NOS	SFB1208_24	37.79748	-122.37387	:America/Los_Angeles	USA	knots	320	158	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bay Bridge, Span B-C	CA
100355	Yerba Buena Island, west of (midchannel) (depth 84 ft), California Current	NOS	SFB1209_1	37.81003	-122.38307	:America/Los_Angeles	USA	knots	320	120	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yerba Buena Island, west of (midchannel)	CA
100356	Yerba Buena Island, west of (midchannel) (depth 39 ft), California Current	NOS	SFB1209_15	37.81003	-122.38307	:America/Los_Angeles	USA	knots	329	136	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yerba Buena Island, west of (midchannel)	CA
100357	Yerba Buena Island, west of (midchannel) (depth 12 ft), California Current	NOS	SFB1209_23	37.81003	-122.38307	:America/Los_Angeles	USA	knots	331	143	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.215	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Yerba Buena Island, west of (midchannel)	CA
100358	Treasure Island, 0.78 nmi NW of (depth 22 ft), San Francisco Bay, California Current	NOS	SFB1210_1	37.83733	-122.38717	:America/Los_Angeles	USA	knots	288	121	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.102	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Treasure Island, 0.78 NM NW of	CA
100359	Treasure Island, 0.78 nmi NW of (depth 14 ft), San Francisco Bay, California Current	NOS	SFB1210_6	37.83733	-122.38717	:America/Los_Angeles	USA	knots	294	122	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Treasure Island, 0.78 NM NW of	CA
100360	Treasure Island, 0.78 nmi NW of (depth 3 ft), San Francisco Bay, California Current	NOS	SFB1210_13	37.83733	-122.38717	:America/Los_Angeles	USA	knots	302	126	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.142	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Treasure Island, 0.78 NM NW of	CA
100361	Alcatraz Island, 0.5 mi north of (depth 74 ft), San Francisco Bay, California Current	NOS	SFB1211_1	37.83513	-122.42013	:America/Los_Angeles	USA	knots	237	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alcatraz Island, 0.5 mile north of	CA
100362	Alcatraz Island, 0.5 mi north of (depth 29 ft), San Francisco Bay, California Current	NOS	SFB1211_15	37.83513	-122.42013	:America/Los_Angeles	USA	knots	271	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alcatraz Island, 0.5 mile north of	CA
100363	Alcatraz Island, 0.5 mi north of (depth 6 ft), San Francisco Bay, California Current	NOS	SFB1211_22	37.83513	-122.42013	:America/Los_Angeles	USA	knots	293	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.085	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alcatraz Island, 0.5 mile north of	CA
100364	Raccoon Strait (depth 71 ft), San Francisco Bay, California Current	NOS	SFB1212_1	37.87192	-122.44197	:America/Los_Angeles	USA	knots	\N	62.2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raccoon Strait	CA
100365	Raccoon Strait (depth 38 ft), San Francisco Bay, California Current	NOS	SFB1212_6	37.87192	-122.44197	:America/Los_Angeles	USA	knots	\N	58.7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raccoon Strait	CA
100366	Raccoon Strait (depth 19 ft), San Francisco Bay, California Current	NOS	SFB1212_9	37.87192	-122.44197	:America/Los_Angeles	USA	knots	\N	56.6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Raccoon Strait	CA
100367	Oakland Inner Harbor Channel (depth 40 ft), San Francisco Bay, California Current	NOS	SFB1213_1	37.795	-122.3183	:America/Los_Angeles	USA	knots	287	105	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.121	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor Channel	CA
100368	Oakland Inner Harbor Channel (depth 17 ft), San Francisco Bay, California Current	NOS	SFB1213_8	37.795	-122.3183	:America/Los_Angeles	USA	knots	285	103	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor Channel	CA
100369	Oakland Inner Harbor Channel (depth 4 ft), San Francisco Bay, California Current	NOS	SFB1213_12	37.795	-122.3183	:America/Los_Angeles	USA	knots	286	108	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor Channel	CA
100370	Oakland Inner Harbor Reach (depth 45 ft), San Francisco Bay, California Current	NOS	SFB1214_1	37.7929	-122.28552	:America/Los_Angeles	USA	knots	\N	98.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor Reach	CA
100371	Oakland Inner Harbor Reach (depth 20 ft), San Francisco Bay, California Current	NOS	SFB1214_16	37.7929	-122.28552	:America/Los_Angeles	USA	knots	279	102	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor Reach	CA
100372	Oakland Inner Harbor Reach (depth 4 ft), San Francisco Bay, California Current	NOS	SFB1214_26	37.7929	-122.28552	:America/Los_Angeles	USA	knots	284	100	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.089	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor Reach	CA
100373	Brooklyn Basin (depth 28 ft), San Francisco Bay, California Current	NOS	SFB1215_1	37.78523	-122.26055	:America/Los_Angeles	USA	knots	293	111	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Basin	CA
100374	Brooklyn Basin (depth 15 ft), San Francisco Bay, California Current	NOS	SFB1215_5	37.78523	-122.26055	:America/Los_Angeles	USA	knots	289	113	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.052	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Basin	CA
100375	Brooklyn Basin (depth 5 ft), San Francisco Bay, California Current	NOS	SFB1215_8	37.78523	-122.26055	:America/Los_Angeles	USA	knots	290	114	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brooklyn Basin	CA
100376	Alameda Estuary, southeast end (depth 15 ft), San Francisco Bay, California Current	NOS	SFB1216_1	37.76146	-122.22391	:America/Los_Angeles	USA	knots	358	181	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alameda Estuary, southeast end	CA
100377	Alameda Estuary, southeast end (depth 2 ft), San Francisco Bay, California Current	NOS	SFB1216_9	37.76146	-122.22391	:America/Los_Angeles	USA	knots	1	178	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Alameda Estuary, southeast end	CA
100378	Rincon Point (depth 58 ft), San Francisco Bay, California Current	NOS	SFB1217_1	37.79027	-122.3734	:America/Los_Angeles	USA	knots	321	143	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.061	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rincon Point	CA
100379	Rincon Point (depth 22 ft), San Francisco Bay, California Current	NOS	SFB1217_12	37.79027	-122.3734	:America/Los_Angeles	USA	knots	330	148	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.078	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rincon Point	CA
100380	Rincon Point (depth 9 ft), San Francisco Bay, California Current	NOS	SFB1217_16	37.79027	-122.3734	:America/Los_Angeles	USA	knots	333	149	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rincon Point	CA
100381	Emeryville Marina (depth 5 ft), San Francisco Bay, California Current	NOS	SFB1218_1	37.84332	-122.32537	:America/Los_Angeles	USA	knots	\N	157	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Emeryville Marina	CA
100382	Point Bonita, 0.95 nmi SSE of (depth 96 ft), California Current	NOS	SFB1220_1	37.8011	-122.5184	:America/Los_Angeles	USA	knots	234	71	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.258	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Bonita, 0.95 nm SSE of	CA
100383	Point Bonita, 0.95 nmi SSE of (depth 44 ft), California Current	NOS	SFB1220_9	37.8011	-122.5184	:America/Los_Angeles	USA	knots	236	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Bonita, 0.95 nm SSE of	CA
100384	Point Bonita, 0.95 nmi SSE of (depth 17 ft), California Current	NOS	SFB1220_13	37.8011	-122.5184	:America/Los_Angeles	USA	knots	238	70	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Bonita, 0.95 nm SSE of	CA
100385	San Francisco Bar, north of ship channel (depth 25 ft), California Current	NOS	SFB1221_1	37.78529	-122.614	:America/Los_Angeles	USA	knots	260	84	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.132	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco Bar, north of ship channel	CA
100386	San Francisco Bar, north of ship channel (depth 15 ft), California Current	NOS	SFB1221_4	37.78529	-122.614	:America/Los_Angeles	USA	knots	260	75	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.172	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco Bar, north of ship channel	CA
100387	San Francisco Bar, north of ship channel (depth 5 ft), California Current	NOS	SFB1221_7	37.78529	-122.614	:America/Los_Angeles	USA	knots	260	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco Bar, north of ship channel	CA
100388	San Francisco traffic separation zone buoy (depth 84 ft), California Current	NOS	SFB1222_1	37.7505	-122.6996	:America/Los_Angeles	USA	knots	261	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco traffic separation zone buoy	CA
100389	San Francisco traffic separation zone buoy (depth 45 ft), California Current	NOS	SFB1222_7	37.7505	-122.6996	:America/Los_Angeles	USA	knots	258	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco traffic separation zone buoy	CA
100390	San Francisco traffic separation zone buoy (depth 12 ft), California Current	NOS	SFB1222_12	37.7505	-122.6996	:America/Los_Angeles	USA	knots	233	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco traffic separation zone buoy	CA
100391	San Francisco southern traffic lane, N end (depth 105 ft), California Current	NOS	SFB1223_1	37.64458	-122.6954	:America/Los_Angeles	USA	knots	\N	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco southern traffic lane, N end	CA
100392	San Francisco southern traffic lane, N end (depth 53 ft), California Current	NOS	SFB1223_9	37.64458	-122.6954	:America/Los_Angeles	USA	knots	\N	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.069	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco southern traffic lane, N end	CA
100393	San Francisco southern traffic lane, N end (depth 13 ft), California Current	NOS	SFB1223_15	37.64458	-122.6954	:America/Los_Angeles	USA	knots	192	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Francisco southern traffic lane, N end	CA
100394	Dumbarton Highway Bridge (depth 40 ft), San Francisco Bay, California Current	NOS	SFB1301_1	37.50175	-122.11598	:America/Los_Angeles	USA	knots	318	138	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dumbarton Highway Bridge	CA
100395	Dumbarton Highway Bridge (depth 17 ft), San Francisco Bay, California Current	NOS	SFB1301_8	37.50175	-122.11598	:America/Los_Angeles	USA	knots	319	140	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.023	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dumbarton Highway Bridge	CA
100396	Dumbarton Highway Bridge (depth 4 ft), San Francisco Bay, California Current	NOS	SFB1301_12	37.50175	-122.11598	:America/Los_Angeles	USA	knots	320	139	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dumbarton Highway Bridge	CA
100397	Redwood Point, 1.7 nmi east of (depth 30 ft), San Francisco Bay, California Current	NOS	SFB1302_1	37.53062	-122.1601	:America/Los_Angeles	USA	knots	305	121	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redwood Point, 1.7nm East of	CA
100398	Redwood Point, 1.7 nmi east of (depth 20 ft), San Francisco Bay, California Current	NOS	SFB1302_4	37.53062	-122.1601	:America/Los_Angeles	USA	knots	305	125	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redwood Point, 1.7nm East of	CA
100399	Redwood Point, 1.7 nmi east of (depth 7 ft), San Francisco Bay, California Current	NOS	SFB1302_8	37.53062	-122.1601	:America/Los_Angeles	USA	knots	305	127	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redwood Point, 1.7nm East of	CA
100400	Redwood Creek (depth 20 ft), San Francisco Bay, California Current	NOS	SFB1304_1	37.52575	-122.1991	:America/Los_Angeles	USA	knots	49	233	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redwood Creek	CA
100401	Redwood Creek (depth 4 ft), San Francisco Bay, California Current	NOS	SFB1304_6	37.52575	-122.1991	:America/Los_Angeles	USA	knots	51	234	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Redwood Creek	CA
100402	San Mateo Bridge (depth 30 ft), San Francisco Bay, California Current	NOS	SFB1305_1	37.58778	-122.25018	:America/Los_Angeles	USA	knots	300	135	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Mateo Bridge	CA
100403	San Mateo Bridge (depth 21 ft), San Francisco Bay, California Current	NOS	SFB1305_4	37.58778	-122.25018	:America/Los_Angeles	USA	knots	299	136	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Mateo Bridge	CA
100404	San Mateo Bridge (depth 11 ft), San Francisco Bay, California Current	NOS	SFB1305_7	37.58778	-122.25018	:America/Los_Angeles	USA	knots	298	136	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	San Mateo Bridge	CA
100405	Coyote Point, 2.3 nmi NNE of (depth 22 ft), San Francisco Bay, California Current	NOS	SFB1306_1	37.62555	-122.29607	:America/Los_Angeles	USA	knots	322	144	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.118	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coyote Point, 2.3 nmi. NNE of	CA
100406	Coyote Point, 2.3 nmi NNE of (depth 12 ft), San Francisco Bay, California Current	NOS	SFB1306_4	37.62555	-122.29607	:America/Los_Angeles	USA	knots	324	144	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.173	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coyote Point, 2.3 nmi. NNE of	CA
100407	Coyote Point, 2.3 nmi NNE of (depth 3 ft), San Francisco Bay, California Current	NOS	SFB1306_7	37.62555	-122.29607	:America/Los_Angeles	USA	knots	325	144	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Coyote Point, 2.3 nmi. NNE of	CA
100443	Dillon Point (depth 97 ft), Carquinez Strait, California Current	NOS	SFB1320_1	38.0589	-122.19305	:America/Los_Angeles	USA	knots	258	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dillon Point	CA
100408	Mulford Gardens Channel approach (depth 4 ft), San Francisco Bay, California Current	NOS	SFB1307_4	37.65008	-122.26282	:America/Los_Angeles	USA	knots	321	138	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mulford Gardens Channel Approach	CA
100409	Hunters Point, 1.6 nmi SE of (depth 24 ft), San Francisco Bay, California Current	NOS	SFB1308_1	37.69603	-122.33815	:America/Los_Angeles	USA	knots	22	201	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hunters Point, 1.6nm SE of	CA
100410	Hunters Point, 1.6 nmi SE of (depth 5 ft), San Francisco Bay, California Current	NOS	SFB1308_7	37.69603	-122.33815	:America/Los_Angeles	USA	knots	23	202	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hunters Point, 1.6nm SE of	CA
100411	Point Chauncey, 1.3 mi east of (depth 40 ft), San Francisco Bay, California Current	NOS	SFB1309_1	37.89082	-122.41878	:America/Los_Angeles	USA	knots	168	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Chauncey, 1.3 miles east of	CA
100412	Point Chauncey, 1.3 mi east of (depth 24 ft), San Francisco Bay, California Current	NOS	SFB1309_6	37.89082	-122.41878	:America/Los_Angeles	USA	knots	170	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Chauncey, 1.3 miles east of	CA
100413	Point Chauncey, 1.3 mi east of (depth 7 ft), San Francisco Bay, California Current	NOS	SFB1309_11	37.89082	-122.41878	:America/Los_Angeles	USA	knots	173	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Chauncey, 1.3 miles east of	CA
100414	Point Chauncey, 1.25 nmi north of (depth 31 ft), San Francisco Bay, California Current	NOS	SFB1310_1	37.9153	-122.44607	:America/Los_Angeles	USA	knots	168	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Chauncey, 1.25 nm north of	CA
100415	Point Chauncey, 1.25 nmi north of (depth 18 ft), San Francisco Bay, California Current	NOS	SFB1310_5	37.9153	-122.44607	:America/Los_Angeles	USA	knots	173	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Chauncey, 1.25 nm north of	CA
100416	Point Chauncey, 1.25 nmi north of (depth 5 ft), San Francisco Bay, California Current	NOS	SFB1310_9	37.9153	-122.44607	:America/Los_Angeles	USA	knots	177	351	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.315	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Chauncey, 1.25 nm north of	CA
100417	Point San Pablo, midchannel (depth 60 ft), San Pablo Bay, California Current	NOS	SFB1312_1	37.96888	-122.43913	:America/Los_Angeles	USA	knots	199	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.129	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point San Pablo, midchannel	CA
100418	Point San Pablo, midchannel (depth 30 ft), San Pablo Bay, California Current	NOS	SFB1312_10	37.96888	-122.43913	:America/Los_Angeles	USA	knots	203	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point San Pablo, midchannel	CA
100419	Point San Pablo, midchannel (depth 11 ft), San Pablo Bay, California Current	NOS	SFB1312_16	37.96888	-122.43913	:America/Los_Angeles	USA	knots	199	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point San Pablo, midchannel	CA
100420	Petaluma River approach (Buoys 3 and 4) (depth 2 ft), San Pablo Bay, California Current	NOS	SFB1313_4	38.04349899291992	-122.42633056640625	:America/Los_Angeles	USA	knots	179	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Petaluma River approach (Buoys 3 and 4)	CA
100421	Pinole Point, 1.27 nmi NNW of (depth 32 ft), San Pablo Bay, California Current	NOS	SFB1314_1	38.03083	-122.37715	:America/Los_Angeles	USA	knots	223	45	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Point, 1.27 nmi. NNW of	CA
100422	Pinole Point, 1.27 nmi NNW of (depth 19 ft), San Pablo Bay, California Current	NOS	SFB1314_5	38.03083	-122.37715	:America/Los_Angeles	USA	knots	228	47	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Point, 1.27 nmi. NNW of	CA
100423	Pinole Point, 1.27 nmi NNW of (depth 5 ft), San Pablo Bay, California Current	NOS	SFB1314_9	38.03083	-122.37715	:America/Los_Angeles	USA	knots	232	50	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Point, 1.27 nmi. NNW of	CA
100424	Pinole Shoal (depth 23 ft), San Pablo Bay, California Current	NOS	SFB1315_1	38.04757	-122.33413	:America/Los_Angeles	USA	knots	250	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.022	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Shoal	CA
100425	Pinole Shoal (depth 19 ft), San Pablo Bay, California Current	NOS	SFB1315_2	38.04757	-122.33413	:America/Los_Angeles	USA	knots	\N	71.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.003	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Shoal	CA
100426	Pinole Shoal (depth 16 ft), San Pablo Bay, California Current	NOS	SFB1315_3	38.04757	-122.33413	:America/Los_Angeles	USA	knots	\N	72.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.036	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Shoal	CA
100427	Pinole Shoal (depth 13 ft), San Pablo Bay, California Current	NOS	SFB1315_4	38.04757	-122.33413	:America/Los_Angeles	USA	knots	\N	73.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Shoal	CA
100428	Pinole Shoal (depth 10 ft), San Pablo Bay, California Current	NOS	SFB1315_5	38.04757	-122.33413	:America/Los_Angeles	USA	knots	\N	73.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Shoal	CA
100429	Pinole Shoal (depth 6 ft), San Pablo Bay, California Current	NOS	SFB1315_6	38.04757	-122.33413	:America/Los_Angeles	USA	knots	255	75	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Shoal	CA
100430	Pinole Shoal (depth 3 ft), San Pablo Bay, California Current	NOS	SFB1315_7	38.04757	-122.33413	:America/Los_Angeles	USA	knots	\N	76	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.256	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Pinole Shoal	CA
100431	Davis Point, 1.0 nmi NW of (depth 33 ft), San Pablo Bay, California Current	NOS	SFB1316_1	38.0619	-122.27668	:America/Los_Angeles	USA	knots	267	78	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Davis Point, 1.0 nmi. NW of	CA
100432	Davis Point, 1.0 nmi NW of (depth 17 ft), San Pablo Bay, California Current	NOS	SFB1316_6	38.0619	-122.27668	:America/Los_Angeles	USA	knots	266	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.188	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Davis Point, 1.0 nmi. NW of	CA
100433	Davis Point, 1.0 nmi NW of (depth 7 ft), San Pablo Bay, California Current	NOS	SFB1316_9	38.0619	-122.27668	:America/Los_Angeles	USA	knots	266	87	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.35	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Davis Point, 1.0 nmi. NW of	CA
100434	Mare Island Strait, NE of Pier 34 (depth 29 ft), Carquinez Strait, California Current	NOS	SFB1317_1	38.07725	-122.24565	:America/Los_Angeles	USA	knots	175	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.068	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mare Island Strait, NE of Pier 34	CA
100435	Mare Island Strait, NE of Pier 34 (depth 15 ft), Carquinez Strait, California Current	NOS	SFB1317_5	38.07725	-122.24565	:America/Los_Angeles	USA	knots	169	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.054	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mare Island Strait, NE of Pier 34	CA
100436	Mare Island Strait, NE of Pier 34 (depth 6 ft), Carquinez Strait, California Current	NOS	SFB1317_8	38.07725	-122.24565	:America/Los_Angeles	USA	knots	167	351	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.169	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mare Island Strait, NE of Pier 34	CA
100437	Carquinez Bridge, I-80 (depth 72 ft), Carquinez Strait, California Current	NOS	SFB1318_1	38.06237	-122.22753	:America/Los_Angeles	USA	knots	280	94	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.234	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carquinez Bridge, I-80	CA
100438	Carquinez Bridge, I-80 (depth 39 ft), Carquinez Strait, California Current	NOS	SFB1318_6	38.06237	-122.22753	:America/Los_Angeles	USA	knots	270	93	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carquinez Bridge, I-80	CA
100439	Carquinez Bridge, I-80 (depth 20 ft), Carquinez Strait, California Current	NOS	SFB1318_9	38.06237	-122.22753	:America/Los_Angeles	USA	knots	269	92	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.282	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carquinez Bridge, I-80	CA
100440	Carquinez Strait (depth 42 ft), California Current	NOS	SFB1319_1	38.06138	-122.21823	:America/Los_Angeles	USA	knots	282	94	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.164	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carquinez Strait	CA
100441	Carquinez Strait (depth 25 ft), California Current	NOS	SFB1319_6	38.06138	-122.21823	:America/Los_Angeles	USA	knots	290	95	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Carquinez Strait	CA
100444	Dillon Point (depth 45 ft), Carquinez Strait, California Current	NOS	SFB1320_9	38.0589	-122.19305	:America/Los_Angeles	USA	knots	264	98	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.317	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dillon Point	CA
100445	Dillon Point (depth 19 ft), Carquinez Strait, California Current	NOS	SFB1320_13	38.0589	-122.19305	:America/Los_Angeles	USA	knots	275	92	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.319	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dillon Point	CA
100446	Grizzly Bay entrance (depth 2 ft), Suisun Bay, California Current	NOS	SFB1322_4	38.10318	-122.05248	:America/Los_Angeles	USA	knots	228	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Grizzly Bay entrance	CA
100447	Roe Island Channel (depth 29 ft), Suisun Bay, California Current	NOS	SFB1323_1	38.06507	-122.03445	:America/Los_Angeles	USA	knots	269	96	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.111	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roe Island Channel	CA
100448	Roe Island Channel (depth 16 ft), Suisun Bay, California Current	NOS	SFB1323_5	38.06507	-122.03445	:America/Los_Angeles	USA	knots	272	99	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.057	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roe Island Channel	CA
100449	Roe Island Channel (depth 6 ft), Suisun Bay, California Current	NOS	SFB1323_8	38.06507	-122.03445	:America/Los_Angeles	USA	knots	276	93	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.248	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Roe Island Channel	CA
100450	Middle Point Lt., 0.18 nmi NNW of (depth 30 ft), Suisun Bay, California Current	NOS	SFB1324_1	38.05752	-121.99303	:America/Los_Angeles	USA	knots	274	103	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Point Lt., 0.18 nmi. NNW of	CA
100451	Middle Point Lt., 0.18 nmi NNW of (depth 17 ft), Suisun Bay, California Current	NOS	SFB1324_5	38.05752	-121.99303	:America/Los_Angeles	USA	knots	277	103	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Point Lt., 0.18 nmi. NNW of	CA
100452	Middle Point Lt., 0.18 nmi NNW of (depth 7 ft), Suisun Bay, California Current	NOS	SFB1324_8	38.05752	-121.99303	:America/Los_Angeles	USA	knots	279	101	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.064	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Middle Point Lt., 0.18 nmi. NNW of	CA
100453	Simmons Point, 0.6 nmi ESE of (depth 32 ft), Suisun Bay, California Current	NOS	SFB1325_1	38.04812	-121.9225	:America/Los_Angeles	USA	knots	281	98	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Simmons Point, 0.6nm ESE of	CA
100454	Simmons Point, 0.6 nmi ESE of (depth 19 ft), Suisun Bay, California Current	NOS	SFB1325_5	38.04812	-121.9225	:America/Los_Angeles	USA	knots	280	98	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.131	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Simmons Point, 0.6nm ESE of	CA
100455	Simmons Point, 0.6 nmi ESE of (depth 6 ft), Suisun Bay, California Current	NOS	SFB1325_9	38.04812	-121.9225	:America/Los_Angeles	USA	knots	281	102	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.175	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Simmons Point, 0.6nm ESE of	CA
100456	New York Slough, 0.6 mi E of Pt. Emmet (depth 32 ft), Suisun Bay, California Current	NOS	SFB1326_1	38.0325	-121.86908	:America/Los_Angeles	USA	knots	291	109	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.058	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New York Slough, 0.6miles E of Pt. Emmet	CA
100457	New York Slough, 0.6 mi E of Pt. Emmet (depth 19 ft), Suisun Bay, California Current	NOS	SFB1326_5	38.0325	-121.86908	:America/Los_Angeles	USA	knots	286	109	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.11	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New York Slough, 0.6miles E of Pt. Emmet	CA
100458	New York Slough, 0.6 mi E of Pt. Emmet (depth 5 ft), Suisun Bay, California Current	NOS	SFB1326_9	38.0325	-121.86908	:America/Los_Angeles	USA	knots	283	109	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	New York Slough, 0.6miles E of Pt. Emmet	CA
100459	Antioch Point (depth 48 ft), San Joaquin River, California Current	NOS	SFB1327_1	38.02395	-121.82258	:America/Los_Angeles	USA	knots	329	142	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Antioch Point	CA
100460	Antioch Point (depth 22 ft), San Joaquin River, California Current	NOS	SFB1327_9	38.02395	-121.82258	:America/Los_Angeles	USA	knots	321	138	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Antioch Point	CA
100461	Antioch Point (depth 9 ft), San Joaquin River, California Current	NOS	SFB1327_13	38.02395	-121.82258	:America/Los_Angeles	USA	knots	314	141	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Antioch Point	CA
100462	West Island, north of (depth 26 ft), San Joaquin River, California Current	NOS	SFB1328_1	38.02485	-121.79005	:America/Los_Angeles	USA	knots	256	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Island, north of	CA
100463	West Island, north of (depth 13 ft), San Joaquin River, California Current	NOS	SFB1328_5	38.02485	-121.79005	:America/Los_Angeles	USA	knots	255	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Island, north of	CA
100464	West Island, north of (depth 3 ft), San Joaquin River, California Current	NOS	SFB1328_8	38.02485	-121.79005	:America/Los_Angeles	USA	knots	255	76	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.232	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	West Island, north of	CA
100465	Antioch, Route 160 bridge (depth 30 ft), San Joaquin River, California Current	NOS	SFB1329_1	38.02697	-121.75307	:America/Los_Angeles	USA	knots	276	93	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.056	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Antioch, Route 160 bridge	CA
100466	Antioch, Route 160 bridge (depth 17 ft), San Joaquin River, California Current	NOS	SFB1329_5	38.02697	-121.75307	:America/Los_Angeles	USA	knots	277	95	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Antioch, Route 160 bridge	CA
100467	Antioch, Route 160 bridge (depth 7 ft), San Joaquin River, California Current	NOS	SFB1329_8	38.02697	-121.75307	:America/Los_Angeles	USA	knots	277	96	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Antioch, Route 160 bridge	CA
100468	Entrance, 0.7 nmi SW of Chain Island (depth 48 ft), Sacramento River, California Current	NOS	SFB1330_1	38.05847	-121.8712	:America/Los_Angeles	USA	knots	226	39	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance, 0.7nm SW of Chain Island	CA
100469	Entrance, 0.7 nmi SW of Chain Island (depth 22 ft), Sacramento River, California Current	NOS	SFB1330_9	38.05847	-121.8712	:America/Los_Angeles	USA	knots	225	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance, 0.7nm SW of Chain Island	CA
100470	Entrance, 0.7 nmi SW of Chain Island (depth 9 ft), Sacramento River, California Current	NOS	SFB1330_13	38.05847	-121.8712	:America/Los_Angeles	USA	knots	226	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Entrance, 0.7nm SW of Chain Island	CA
100471	Point Sacramento, 0.2 nmi NE of (depth 32 ft), Sacramento River, California Current	NOS	SFB1331_1	38.0643	-121.83372	:America/Los_Angeles	USA	knots	275	101	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Sacramento, 0.2nm NE of	CA
100472	Point Sacramento, 0.2 nmi NE of (depth 15 ft), Sacramento River, California Current	NOS	SFB1331_11	38.0643	-121.83372	:America/Los_Angeles	USA	knots	281	98	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Sacramento, 0.2nm NE of	CA
100473	Point Sacramento, 0.2 nmi NE of (depth 4 ft), Sacramento River, California Current	NOS	SFB1331_18	38.0643	-121.83372	:America/Los_Angeles	USA	knots	283	98	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Point Sacramento, 0.2nm NE of	CA
100474	Sacramento River Light 14 (depth 26 ft), California Current	NOS	SFB1332_1	38.07715	-121.76393	:America/Los_Angeles	USA	knots	234	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sacramento River Light 14	CA
100475	Sacramento River Light 14 (depth 14 ft), California Current	NOS	SFB1332_8	38.07715	-121.76393	:America/Los_Angeles	USA	knots	236	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.071	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sacramento River Light 14	CA
100476	Sacramento River Light 14 (depth 3 ft), California Current	NOS	SFB1332_15	38.07715	-121.76393	:America/Los_Angeles	USA	knots	235	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sacramento River Light 14	CA
100477	Shark River entrance (depth 15 ft), New Jersey Current	NOS	SHR9901_2	40.1873	-74.0126	:America/New_York	USA	knots	97	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.086	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shark River Entrance	NJ
100478	Shark River entrance (depth 5 ft), New Jersey Current	NOS	SHR9901_14	40.1873	-74.0126	:America/New_York	USA	knots	98	273	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Shark River Entrance	NJ
100531	Akun Strait (depth 47 ft), Aleutian Islands, Alaska Current	NOS	UNI1007_10	54.1337	-165.65111	:America/Nome	USA	knots	148	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.084	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akun Strait	AK
100479	Dames Point, 0.23 nmi ESE of (depth 31 ft), St. Johns River, Florida Current	NOS	SJR0301_2	30.3865	-81.55383	:America/New_York	USA	knots	69	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point, 0.23 n.mi. ESE of	FL
100480	Dames Point, 0.23 nmi ESE of (depth 14 ft), St. Johns River, Florida Current	NOS	SJR0301_7	30.3865	-81.55383	:America/New_York	USA	knots	68	256	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.308	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point, 0.23 n.mi. ESE of	FL
100481	Dames Point, 0.23 nmi ESE of (depth 5 ft), St. Johns River, Florida Current	NOS	SJR0301_10	30.3865	-81.55383	:America/New_York	USA	knots	66	244	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.368	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point, 0.23 n.mi. ESE of	FL
100482	Chaseville Turn (depth 30 ft), St. Johns River, Florida Current	NOS	SJR0302_2	30.37833	-81.62833	:America/New_York	USA	knots	17	186	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.17	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chaseville Turn	FL
100483	Chaseville Turn (depth 14 ft), St. Johns River, Florida Current	NOS	SJR0302_7	30.37833	-81.62833	:America/New_York	USA	knots	3	166	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.026	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chaseville Turn	FL
100484	Chaseville Turn (depth 4 ft), St. Johns River, Florida Current	NOS	SJR0302_10	30.37833	-81.62833	:America/New_York	USA	knots	339	165	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.035	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chaseville Turn	FL
100485	St. Johns Bar Cut, 0.7 nmi east of jetties (depth 31 ft), Florida Current	NOS	SJR0304_2	30.398	-81.39717	:America/New_York	USA	knots	122	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns Bar Cut, 0.7 n.mi. east of jetties	FL
100486	St. Johns Bar Cut, 0.7 nmi east of jetties (depth 14 ft), Florida Current	NOS	SJR0304_7	30.398	-81.39717	:America/New_York	USA	knots	95	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns Bar Cut, 0.7 n.mi. east of jetties	FL
100487	St. Johns Bar Cut, 0.7 nmi east of jetties (depth 5 ft), Florida Current	NOS	SJR0304_10	30.398	-81.39717	:America/New_York	USA	knots	91	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.613	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns Bar Cut, 0.7 n.mi. east of jetties	FL
100488	St. Johns River ent. (between jetties) (depth 30 ft), Florida Current	NOS	SJR9801_4	30.40067	-81.386	:America/New_York	USA	knots	80	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.047	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns River Ent. (between jetties)	FL
100489	St. Johns River ent. (between jetties) (depth 16 ft), Florida Current	NOS	SJR9801_8	30.40067	-81.386	:America/New_York	USA	knots	81	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns River Ent. (between jetties)	FL
100490	St. Johns River ent. (between jetties) (depth 10 ft), Florida Current	NOS	SJR9801_10	30.40067	-81.386	:America/New_York	USA	knots	81	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.178	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns River Ent. (between jetties)	FL
100491	Trout River Cut (depth 32 ft), St. Johns River, Florida Current	NOS	SJR9806_1	30.38358	-81.62785	:America/New_York	USA	knots	23	205	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.135	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trout River Cut	FL
100492	Trout River Cut (depth 15 ft), St. Johns River, Florida Current	NOS	SJR9806_6	30.38358	-81.62785	:America/New_York	USA	knots	25	191	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 16.4 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trout River Cut	FL
100493	Trout River Cut (depth 6 ft), St. Johns River, Florida Current	NOS	SJR9806_9	30.38358	-81.62785	:America/New_York	USA	knots	5	193	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Trout River Cut	FL
100494	Blount Island, east of (depth 30 ft), St. Johns River, Florida Current	NOS	SJR9807_2	30.39228	-81.50872	:America/New_York	USA	knots	99	264	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 39.4 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blount Island, East of	FL
100495	Blount Island, east of (depth 16 ft), St. Johns River, Florida Current	NOS	SJR9807_6	30.39228	-81.50872	:America/New_York	USA	knots	90	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 26.2 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.109	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blount Island, East of	FL
100496	Blount Island, east of (depth 7 ft), St. Johns River, Florida Current	NOS	SJR9807_9	30.39228	-81.50872	:America/New_York	USA	knots	79	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 16.4 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.399	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Blount Island, East of	FL
100497	Lydia Ann Channel, S end (depth 3 ft), Texas Current	NOS	STX1801_5	27.85260009765625	-97.05480194091797	:America/Chicago	USA	knots	201	26	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.416	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lydia Ann Channel, S end	TX
100498	Murray Shoal (depth 4 ft), Texas Current	NOS	STX1802_5	27.89929962158203	-97.05139923095703	:America/Chicago	USA	knots	175	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.092	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Murray Shoal	TX
100499	ICW Laguna Madre, 2.25 nmi S of Arroyo Colorado Cut (depth 3 ft), Texas Current	NOS	STX1812_2	26.327899932861328	-97.30970001220703	:America/Chicago	USA	knots	164	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICW Laguna Madre, 2.25 nm S of Arroyo Colorado Cut	TX
100500	ICW Laguna Madre, Light 69 (depth 4 ft), Texas Current	NOS	STX1813_3	26.107500076293945	-97.21160125732422	:America/Chicago	USA	knots	147	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICW Laguna Madre, Light 69	TX
100501	Queen Isabella Causeway Bridge (depth 17 ft), Laguna Madre, Texas Current	NOS	STX1814_14	26.082399368286133	-97.19779968261719	:America/Chicago	USA	knots	136	312	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 93.5 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.006	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Queen Isabella Causeway Bridge	TX
100502	Port Isabel, Pontoon Swing Bridge (depth 8 ft), Texas Current	NOS	STX1815_4	26.071800231933594	-97.19950103759766	:America/Chicago	USA	knots	219	41	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.083	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Isabel, Pontoon Swing Bridge	TX
100503	Brownsville Ship Channel, east end (depth 18 ft), Texas Current	NOS	STX1817_2	26.03499984741211	-97.2197036743164	:America/Chicago	USA	knots	62	241	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brownsville Ship Channel, east end	TX
100504	Laguna Madre Channel, SW end (depth 3 ft), Texas Current	NOS	STX1818_4	26.046600341796875	-97.1980972290039	:America/Chicago	USA	knots	86	266	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Laguna Madre Channel, SW end	TX
100505	Laguna Madre Channel, NE end (depth 8 ft), Texas Current	NOS	STX1819_2	26.066499710083008	-97.1675033569336	:America/Chicago	USA	knots	99	277	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.191	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Laguna Madre Channel, NE end	TX
100506	Laguna Madre Channel, NE end (depth 15 ft), Texas Current	NOS	STX1819_6	26.066499710083008	-97.1675033569336	:America/Chicago	USA	knots	97	277	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Laguna Madre Channel, NE end	TX
100507	Brazos Santiago Pass entrance (depth 32 ft), Texas Current	NOS	STX1820_1	26.065200805664062	-97.14939880371094	:America/Chicago	USA	knots	95	282	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brazos Santiago Pass Entrance	TX
100508	Brazos Santiago Pass entrance (depth 16 ft), Texas Current	NOS	STX1820_6	26.065200805664062	-97.14939880371094	:America/Chicago	USA	knots	92	278	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brazos Santiago Pass Entrance	TX
100509	Brazos Santiago Pass entrance (depth 6 ft), Texas Current	NOS	STX1820_9	26.065200805664062	-97.14939880371094	:America/Chicago	USA	knots	94	276	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brazos Santiago Pass Entrance	TX
100510	Brazos Santiago Pass (SPIP) (depth 17 ft), Texas Current	NOS	STX1821_29	26.0674991607666	-97.15480041503906	:America/Chicago	USA	knots	90	276	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 383.9 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Brazos Santiago Pass (SPIP)	TX
100511	Port Isabel Channel, north end (depth 28 ft), Texas Current	NOS	STX1822_13	26.05419921875	-97.21150207519531	:America/Chicago	USA	knots	167	358	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 86.9 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.091	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Isabel Channel, North End	TX
100512	Unimak Pass, east entrance (depth 236 ft), Aleutian Islands, Alaska Current	NOS	UNI1001_1	54.29981	-164.51693	:America/Nome	USA	knots	98	292	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, East Entrance	AK
100513	Unimak Pass, east entrance (depth 131 ft), Aleutian Islands, Alaska Current	NOS	UNI1001_9	54.29981	-164.51693	:America/Nome	USA	knots	89	280	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, East Entrance	AK
100514	Unimak Pass, east entrance (depth 26 ft), Aleutian Islands, Alaska Current	NOS	UNI1001_17	54.29981	-164.51693	:America/Nome	USA	knots	90	279	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.271	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, East Entrance	AK
100515	Unimak Pass (depth 213 ft), Aleutian Islands, Alaska Current	NOS	UNI1002_1	54.30863	-164.74683	:America/Nome	USA	knots	114	285	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass	AK
100516	Unimak Pass (depth 121 ft), Aleutian Islands, Alaska Current	NOS	UNI1002_15	54.30863	-164.74683	:America/Nome	USA	knots	116	285	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass	AK
100517	Unimak Pass (depth 29 ft), Aleutian Islands, Alaska Current	NOS	UNI1002_29	54.30863	-164.74683	:America/Nome	USA	knots	118	280	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.208	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass	AK
100518	Ugamak Strait, off Kaligagan Island (depth 126 ft), Aleutian Islands, Alaska Current	NOS	UNI1003_1	54.15457	-164.87092	:America/Nome	USA	knots	132	329	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.385	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ugamak Strait, off Kaligagan Island	AK
100519	Ugamak Strait, off Kaligagan Island (depth 60 ft), Aleutian Islands, Alaska Current	NOS	UNI1003_11	54.15457	-164.87092	:America/Nome	USA	knots	131	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.389	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ugamak Strait, off Kaligagan Island	AK
100520	Ugamak Strait, off Kaligagan Island (depth 27 ft), Aleutian Islands, Alaska Current	NOS	UNI1003_16	54.15457	-164.87092	:America/Nome	USA	knots	132	340	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.327	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ugamak Strait, off Kaligagan Island	AK
100521	Unimak Pass, north approach (depth 216 ft), Aleutian Islands, Alaska Current	NOS	UNI1004_1	54.44831	-165.09124	:America/Nome	USA	knots	154	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.279	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, North Approach	AK
100522	Unimak Pass, north approach (depth 133 ft), Aleutian Islands, Alaska Current	NOS	UNI1004_6	54.44831	-165.09124	:America/Nome	USA	knots	144	339	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.524	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, North Approach	AK
100523	Unimak Pass, north approach (depth 35 ft), Aleutian Islands, Alaska Current	NOS	UNI1004_12	54.44831	-165.09124	:America/Nome	USA	knots	132	330	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.902	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, North Approach	AK
100524	Unimak Pass, west approach (depth 245 ft), Aleutian Islands, Alaska Current	NOS	UNI1005_1	54.36695	-165.36433	:America/Nome	USA	knots	130	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.183	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, West Approach	AK
100525	Unimak Pass, west approach (depth 137 ft), Aleutian Islands, Alaska Current	NOS	UNI1005_12	54.36695	-165.36433	:America/Nome	USA	knots	131	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.191	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, West Approach	AK
100526	Unimak Pass, west approach (depth 28 ft), Aleutian Islands, Alaska Current	NOS	UNI1005_23	54.36695	-165.36433	:America/Nome	USA	knots	130	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unimak Pass, West Approach	AK
100527	Avatanak Strait (depth 247 ft), Aleutian Islands, Alaska Current	NOS	UNI1006_1	54.11279	-165.47573	:America/Nome	USA	knots	229	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.21	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Avatanak Strait	AK
100528	Avatanak Strait (depth 159 ft), Aleutian Islands, Alaska Current	NOS	UNI1006_10	54.11279	-165.47573	:America/Nome	USA	knots	233	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.345	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Avatanak Strait	AK
100529	Avatanak Strait (depth 40 ft), Aleutian Islands, Alaska Current	NOS	UNI1006_22	54.11279	-165.47573	:America/Nome	USA	knots	237	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.558	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Avatanak Strait	AK
100530	Akun Strait (depth 76 ft), Aleutian Islands, Alaska Current	NOS	UNI1007_1	54.1337	-165.65111	:America/Nome	USA	knots	159	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akun Strait	AK
100532	Akun Strait (depth 14 ft), Aleutian Islands, Alaska Current	NOS	UNI1007_20	54.1337	-165.65111	:America/Nome	USA	knots	141	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.222	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akun Strait	AK
100533	Akutan Bay (depth 248 ft), Aleutian Islands, Alaska Current	NOS	UNI1008_1	54.18252	-165.72444	:America/Nome	USA	knots	120	305.1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan Bay	AK
100534	Akutan Bay (depth 140 ft), Aleutian Islands, Alaska Current	NOS	UNI1008_12	54.18252	-165.72444	:America/Nome	USA	knots	117	300.8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.098	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan Bay	AK
100535	Akutan Bay (depth 32 ft), Aleutian Islands, Alaska Current	NOS	UNI1008_23	54.18252	-165.72444	:America/Nome	USA	knots	114	295.5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.094	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan Bay	AK
100536	Baby Pass (depth 133 ft), Aleutian Islands, Alaska Current	NOS	UNI1009_1	53.9812	-166.07178	:America/Nome	USA	knots	126	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.108	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baby Pass	AK
100537	Baby Pass (depth 87 ft), Aleutian Islands, Alaska Current	NOS	UNI1009_8	53.9812	-166.07178	:America/Nome	USA	knots	128	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.174	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baby Pass	AK
100538	Baby Pass (depth 22 ft), Aleutian Islands, Alaska Current	NOS	UNI1009_18	53.9812	-166.07178	:America/Nome	USA	knots	129	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.386	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baby Pass	AK
100539	Akutan Pass (depth 207 ft), Aleutian Islands, Alaska Current	NOS	UNI1010_1	54.02455	-166.09753	:America/Nome	USA	knots	98	295	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.494	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan Pass	AK
100540	Akutan Pass (depth 128 ft), Aleutian Islands, Alaska Current	NOS	UNI1010_13	54.02455	-166.09753	:America/Nome	USA	knots	102	299	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.757	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan Pass	AK
100541	Akutan Pass (depth 30 ft), Aleutian Islands, Alaska Current	NOS	UNI1010_28	54.02455	-166.09753	:America/Nome	USA	knots	103	301	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.915	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Akutan Pass	AK
100542	Unalga Pass (depth 157 ft), Aleutian Islands, Alaska Current	NOS	UNI1011_1	53.95372	-166.21471	:America/Nome	USA	knots	138	316	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.423	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalga Pass	AK
100543	Unalga Pass (depth 98 ft), Aleutian Islands, Alaska Current	NOS	UNI1011_10	53.95372	-166.21471	:America/Nome	USA	knots	144	314	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.493	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalga Pass	AK
100544	Unalga Pass (depth 26 ft), Aleutian Islands, Alaska Current	NOS	UNI1011_21	53.95372	-166.21471	:America/Nome	USA	knots	147	315	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.642	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Unalga Pass	AK
100545	Udagak Strait (narrows) (depth 108 ft), Aleutian Islands, Alaska Current	NOS	UNI1012_2	53.73414	-166.28904	:America/Nome	USA	knots	88	268	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.27	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Udagak Strait (narrows)	AK
100546	Udagak Strait (narrows) (depth 65 ft), Aleutian Islands, Alaska Current	NOS	UNI1012_15	53.73414	-166.28904	:America/Nome	USA	knots	95	272	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.288	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Udagak Strait (narrows)	AK
100547	Udagak Strait (narrows) (depth 19 ft), Aleutian Islands, Alaska Current	NOS	UNI1012_29	53.73414	-166.28904	:America/Nome	USA	knots	94	273	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.291	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Udagak Strait (narrows)	AK
100548	Priest Rock (depth 139 ft), Aleutian Islands, Alaska Current	NOS	UNI1013_1	54.01858	-166.37567	:America/Nome	USA	knots	69	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.315	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Priest Rock	AK
100549	Priest Rock (depth 73 ft), Aleutian Islands, Alaska Current	NOS	UNI1013_11	54.01858	-166.37567	:America/Nome	USA	knots	72	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.401	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Priest Rock	AK
100550	Priest Rock (depth 14 ft), Aleutian Islands, Alaska Current	NOS	UNI1013_20	54.01858	-166.37567	:America/Nome	USA	knots	71	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.461	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Priest Rock	AK
100551	Captains Bay (depth 61 ft), Aleutian Islands, Alaska Current	NOS	UNI1016_1	53.87716	-166.56829	:America/Nome	USA	knots	\N	196	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Captains Bay	AK
100552	Captains Bay (depth 41 ft), Aleutian Islands, Alaska Current	NOS	UNI1016_4	53.87716	-166.56829	:America/Nome	USA	knots	\N	200	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.127	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Captains Bay	AK
100553	Captains Bay (depth 15 ft), Aleutian Islands, Alaska Current	NOS	UNI1016_8	53.87716	-166.56829	:America/Nome	USA	knots	\N	189.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Captains Bay	AK
100554	Cape Kovrizhka (depth 192 ft), Aleutian Islands, Alaska Current	NOS	UNI1017_1	53.84524	-167.18199	:America/Nome	USA	knots	\N	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.163	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kovrizhka	AK
100555	Cape Kovrizhka (depth 103 ft), Aleutian Islands, Alaska Current	NOS	UNI1017_10	53.84524	-167.18199	:America/Nome	USA	knots	\N	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.429	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kovrizhka	AK
100556	Cape Kovrizhka (depth 25 ft), Aleutian Islands, Alaska Current	NOS	UNI1017_18	53.84524	-167.18199	:America/Nome	USA	knots	\N	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.53	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Kovrizhka	AK
100557	Paso Point (depth 266 ft), Aleutian Islands, Alaska Current	NOS	UNI1018_1	53.41249	-167.69747	:America/Nome	USA	knots	227	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.153	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Paso Point	AK
100558	Paso Point (depth 167 ft), Aleutian Islands, Alaska Current	NOS	UNI1018_7	53.41249	-167.69747	:America/Nome	USA	knots	227	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Paso Point	AK
100559	Paso Point (depth 36 ft), Aleutian Islands, Alaska Current	NOS	UNI1018_15	53.41249	-167.69747	:America/Nome	USA	knots	218	48	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.369	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Paso Point	AK
100560	Umnak Pass (depth 254 ft), Aleutian Islands, Alaska Current	NOS	UNI1019_1	53.36238	-167.81982	:America/Nome	USA	knots	228	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.371	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Umnak Pass	AK
100561	Umnak Pass (depth 146 ft), Aleutian Islands, Alaska Current	NOS	UNI1019_12	53.36238	-167.81982	:America/Nome	USA	knots	228	72	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.569	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Umnak Pass	AK
100562	Umnak Pass (depth 38 ft), Aleutian Islands, Alaska Current	NOS	UNI1019_23	53.36238	-167.81982	:America/Nome	USA	knots	227	66	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.69	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Umnak Pass	AK
100563	Konets Head (depth 176 ft), Aleutian Islands, Alaska Current	NOS	UNI1020_1	53.32598	-167.90066	:America/Nome	USA	knots	288	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Konets Head	AK
100564	Konets Head (depth 104 ft), Aleutian Islands, Alaska Current	NOS	UNI1020_12	53.32598	-167.90066	:America/Nome	USA	knots	232	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.253	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Konets Head	AK
100565	Konets Head (depth 32 ft), Aleutian Islands, Alaska Current	NOS	UNI1020_23	53.32598	-167.90066	:America/Nome	USA	knots	235	36	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.219	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Konets Head	AK
100566	Sedanka Pass (depth 197 ft), Aleutian Islands, Alaska Current	NOS	UNI1021_1	53.85121	-166.07639	:America/Nome	USA	knots	138	330	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sedanka Pass	AK
100567	Sedanka Pass (depth 111 ft), Aleutian Islands, Alaska Current	NOS	UNI1021_14	53.85121	-166.07639	:America/Nome	USA	knots	141	338	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.046	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sedanka Pass	AK
100568	Sedanka Pass (depth 26 ft), Aleutian Islands, Alaska Current	NOS	UNI1021_27	53.85121	-166.07639	:America/Nome	USA	knots	132	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.007	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sedanka Pass	AK
100569	Derbin Strait (depth 220 ft), Aleutian Islands, Alaska Current	NOS	UNI1022_1	54.08391	-165.22707	:America/Nome	USA	knots	125	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.262	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Derbin Strait	AK
100570	Derbin Strait (depth 132 ft), Aleutian Islands, Alaska Current	NOS	UNI1022_10	54.08391	-165.22707	:America/Nome	USA	knots	133	314	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Derbin Strait	AK
100571	Derbin Strait (depth 33 ft), Aleutian Islands, Alaska Current	NOS	UNI1022_20	54.08391	-165.22707	:America/Nome	USA	knots	139	318	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.458	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Derbin Strait	AK
100572	Bishop Point, Unalaska Island (depth 114 ft), Aleutian Islands, Alaska Current	NOS	UNI1023_1	53.97871	-166.95646	:America/Nome	USA	knots	248	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.04	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bishop Point, Unalaska Island	AK
100573	Bishop Point, Unalaska Island (depth 68 ft), Aleutian Islands, Alaska Current	NOS	UNI1023_8	53.97871	-166.95646	:America/Nome	USA	knots	255	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bishop Point, Unalaska Island	AK
100574	Bishop Point, Unalaska Island (depth 16 ft), Aleutian Islands, Alaska Current	NOS	UNI1023_16	53.97871	-166.95646	:America/Nome	USA	knots	261	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bishop Point, Unalaska Island	AK
100575	Cape Cheerful, Unalaska Island (depth 151 ft), Aleutian Islands, Alaska Current	NOS	UNI1024_1	54.02659	-166.6724	:America/Nome	USA	knots	83	269	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cheerful, Unalaska Island	AK
100576	Cape Cheerful, Unalaska Island (depth 92 ft), Aleutian Islands, Alaska Current	NOS	UNI1024_10	54.02659	-166.6724	:America/Nome	USA	knots	87	279	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.165	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cheerful, Unalaska Island	AK
100577	Cape Cheerful, Unalaska Island (depth 20 ft), Aleutian Islands, Alaska Current	NOS	UNI1024_21	54.02659	-166.6724	:America/Nome	USA	knots	88	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.205	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cheerful, Unalaska Island	AK
100578	Isanotski Strait (False Pass Cnry) (depth 15 ft), Alaska Current	NOS	UNI1901_1	54.86669921875	-163.39999389648438	:America/Nome	USA	knots	178	358	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 4.9 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.419	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Isanotski Strait (False Pass Cnry)	AK
100579	Cape Cod Canal, west end (depth 110 ft), Massachusetts Current	NOS	ca0101_8	41.73749923706055	-70.6249008178711	:America/New_York	USA	knots	\N	45	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, West End	MA
100580	Cape Cod Canal, west end (depth 189 ft), Massachusetts Current	NOS	ca0101_14	41.73749923706055	-70.6249008178711	:America/New_York	USA	knots	\N	40	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.209	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, West End	MA
100581	Cape Cod Canal, west end (depth 13 ft), Massachusetts Current	NOS	ca0101_20	41.73749923706055	-70.6249008178711	:America/New_York	USA	knots	217	41	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 267.4 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.38	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cape Cod Canal, West End	MA
100582	Chesapeake Bay ent., 2.0 nmi N of Cape Henry Lt. (depth 22 ft), Virginia Current	NOS	cb0102_4	36.9594	-76.0128	:America/New_York	USA	knots	112	297	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.045	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Ent., 2.0 n.mi. N of Cape Henry Lt.	VA
100583	Chesapeake Bay ent., 2.0 nmi N of Cape Henry Lt. (depth 38 ft), Virginia Current	NOS	cb0102_9	36.9594	-76.0128	:America/New_York	USA	knots	105	293	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.223	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Ent., 2.0 n.mi. N of Cape Henry Lt.	VA
100584	Chesapeake Bay ent., 2.0 nmi N of Cape Henry Lt. (depth 55 ft), Virginia Current	NOS	cb0102_14	36.9594	-76.0128	:America/New_York	USA	knots	101	281	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.192	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Ent., 2.0 n.mi. N of Cape Henry Lt.	VA
100585	York River entrance channel (SE end) (depth 14 ft), Virginia Current	NOS	cb0201_2	37.14	-76.13383	:America/New_York	USA	knots	168	347	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	York River Entrance Channel (SE end)	VA
100586	York River entrance channel (SE end) (depth 32 ft), Virginia Current	NOS	cb0201_7	37.14	-76.13383	:America/New_York	USA	knots	175	346	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 30.8 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.229	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	York River Entrance Channel (SE end)	VA
100587	York River entrance channel (SE end) (depth 41 ft), Virginia Current	NOS	cb0201_10	37.14	-76.13383	:America/New_York	USA	knots	158	339	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	York River Entrance Channel (SE end)	VA
100588	Thimble Shoal Channel, 2.4 nmi east of Ft. Monroe (depth 12 ft), Virginia Current	NOS	cb0301_1	37.0112	-76.2495	:America/New_York	USA	knots	\N	266.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.258	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thimble Shoal Channel, 2.4 n.mi east of Ft. Monroe	VA
100589	Thimble Shoal Channel, 2.4 nmi east of Ft. Monroe (depth 15 ft), Virginia Current	NOS	cb0301_2	37.0112	-76.2495	:America/New_York	USA	knots	85	286	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.196	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thimble Shoal Channel, 2.4 n.mi east of Ft. Monroe	VA
100590	Thimble Shoal Channel, 2.4 nmi east of Ft. Monroe (depth 35 ft), Virginia Current	NOS	cb0301_8	37.0112	-76.2495	:America/New_York	USA	knots	76	280	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Thimble Shoal Channel, 2.4 n.mi east of Ft. Monroe	VA
100591	Sewells Point (Naval Station Norfolk) (depth 21 ft), Hampton Roads, Virginia Current	NOS	cb0402_4	36.96295	-76.33388	:America/New_York	USA	knots	10	202	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.398	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sewells Point (Naval Station Norfolk)	VA
100592	Sewells Point (Naval Station Norfolk) (depth 34 ft), Hampton Roads, Virginia Current	NOS	cb0402_8	36.96295	-76.33388	:America/New_York	USA	knots	8	198	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.289	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sewells Point (Naval Station Norfolk)	VA
100593	Sewells Point (Naval Station Norfolk) (depth 44 ft), Hampton Roads, Virginia Current	NOS	cb0402_11	36.96295	-76.33388	:America/New_York	USA	knots	6	190	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.186	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sewells Point (Naval Station Norfolk)	VA
100594	Newport News Channel, west end (depth 15 ft), Hampton Roads, Virginia Current	NOS	cb0601_2	36.95602	-76.41448	:America/New_York	USA	knots	100	285	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.221	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newport News Channel, west end	VA
100595	Newport News Channel, west end (depth 21 ft), Hampton Roads, Virginia Current	NOS	cb0601_4	36.95602	-76.41448	:America/New_York	USA	knots	98	284	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.07	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newport News Channel, west end	VA
100596	Newport News Channel, west end (depth 31 ft), Hampton Roads, Virginia Current	NOS	cb0601_7	36.95602	-76.41448	:America/New_York	USA	knots	98	287	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newport News Channel, west end	VA
100597	James River entrance (depth 11 ft), Virginia Current	NOS	cb0701_25	36.96233	-76.42417	:America/New_York	USA	knots	118	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 169.0 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.158	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	James River Entrance	VA
100598	Bluff Point, 7.2 nmi east of (depth 22 ft), Chesapeake Bay, Virginia Current	NOS	cb0801_4	37.67442	-76.15462	:America/New_York	USA	knots	175	337	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bluff Point, 7.2 n.mi. east of	VA
100599	Bluff Point, 7.2 nmi east of (depth 32 ft), Chesapeake Bay, Virginia Current	NOS	cb0801_7	37.67442	-76.15462	:America/New_York	USA	knots	176	343	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bluff Point, 7.2 n.mi. east of	VA
100600	Bluff Point, 7.2 nmi east of (depth 42 ft), Chesapeake Bay, Virginia Current	NOS	cb0801_10	37.67442	-76.15462	:America/New_York	USA	knots	210	345	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bluff Point, 7.2 n.mi. east of	VA
100601	Piney Point, 1.1 nmi south of (depth 22 ft), Potomac River, Maryland Current	NOS	cb0901_4	38.09098	-76.52975	:America/New_York	USA	knots	124	314	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piney Point, 1.1 n.mi. south of	MD
100602	Piney Point, 1.1 nmi south of (depth 32 ft), Potomac River, Maryland Current	NOS	cb0901_7	38.09098	-76.52975	:America/New_York	USA	knots	121	317	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.033	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piney Point, 1.1 n.mi. south of	MD
100603	Piney Point, 1.1 nmi south of (depth 55 ft), Potomac River, Maryland Current	NOS	cb0901_14	38.09098	-76.52975	:America/New_York	USA	knots	112	329	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Piney Point, 1.1 n.mi. south of	MD
100604	Cove Point, 1.0 nmi N of (depth 10 ft), Chesapeake Bay, Maryland Current	NOS	cb1001_20	38.4026985168457	-76.38390350341797	:America/New_York	USA	knots	138	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 265.7 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.128	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cove Point, 1.0 n.mi. N of	MD
100605	Chesapeake Bay Bridge, 0.6 nmi S of (depth 22 ft), Maryland Current	NOS	cb1101_4	38.98215	-76.38467	:America/New_York	USA	knots	226	23	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Bridge, 0.6 n.mi S of.	MD
100606	Chesapeake Bay Bridge, 0.6 nmi S of (depth 35 ft), Maryland Current	NOS	cb1101_8	38.98215	-76.38467	:America/New_York	USA	knots	215	23	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.024	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Bridge, 0.6 n.mi S of.	MD
100607	Chesapeake Bay Bridge, 0.6 nmi S of (depth 42 ft), Maryland Current	NOS	cb1101_10	38.98215	-76.38467	:America/New_York	USA	knots	209	21	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.018	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake Bay Bridge, 0.6 n.mi S of.	MD
100608	Swan Point, 2.6 nmi west of (depth 26 ft), Chesapeake Bay, Maryland Current	NOS	cb1201_1	39.14083	-76.32947	:America/New_York	USA	knots	162	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Swan Point, 2.6 n.mi. west of	MD
100609	Swan Point, 2.6 nmi west of (depth 16 ft), Chesapeake Bay, Maryland Current	NOS	cb1201_4	39.14083	-76.32947	:America/New_York	USA	knots	196	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Swan Point, 2.6 n.mi. west of	MD
100610	Swan Point, 2.6 nmi west of (depth 7 ft), Chesapeake Bay, Maryland Current	NOS	cb1201_7	39.14083	-76.32947	:America/New_York	USA	knots	192	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.126	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Swan Point, 2.6 n.mi. west of	MD
100611	Chesapeake and Delaware Canal, Chesapeake City (depth 59 ft), Maryland Current	NOS	cb1301_4	39.53053	-75.82762	:America/New_York	USA	knots	\N	86.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.168	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake and Delaware Canal, Chesapeake City	MD
100612	Chesapeake and Delaware Canal, Chesapeake City (depth 164 ft), Maryland Current	NOS	cb1301_12	39.53053	-75.82762	:America/New_York	USA	knots	\N	88	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake and Delaware Canal, Chesapeake City	MD
100613	Chesapeake and Delaware Canal, Chesapeake City (depth 8 ft), Maryland Current	NOS	cb1301_20	39.53053	-75.82762	:America/New_York	USA	knots	278	97	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 269.0 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.039	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Chesapeake and Delaware Canal, Chesapeake City	MD
100614	Newport News Shipbuilding (depth 22 ft), Hampton Roads, Virginia Current	NOS	cb1401_40	36.98379898071289	-76.443603515625	:America/New_York	USA	knots	159	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 528.2 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.008	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newport News Shipbuilding	VA
100615	Port Aransas, Channel View (depth 16 ft), Texas Current	NOS	cc0301_30	27.83981	-97.05314	:America/Chicago	USA	knots	128	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 398.6 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.019	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Aransas, Channel View	TX
100617	Harbor Island, Aransas Channel (depth 11 ft), Texas Current	NOS	cc0501_12	27.84673	-97.06076	:America/Chicago	USA	knots	160	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 162.1 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.333	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island, Aransas Channel	TX
100618	Harbor Island, Aransas Channel (depth 398 ft), Texas Current	NOS	cc0501_30	27.84673	-97.06076	:America/Chicago	USA	knots	\N	330.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.198	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Harbor Island, Aransas Channel	TX
100619	Corpus Christi Channel UT Marine Science (depth 15 ft), Texas Current	NOS	cc0601_32	27.83977	-97.07275	:America/Chicago	USA	knots	69	246	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 424.9 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Corpus Christi Channel UT Marine Science	TX
100620	Cherry Point (depth 47 ft), Rosario Strait, Washington Current	NOS	cp0101_20	48.86275	-122.76098	:America/Los_Angeles	USA	knots	179	7	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 267.4 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Cherry Point	WA
100621	Reedy Point (depth 35 ft), Delaware Current	NOS	db0201_1	39.55860137939453	-75.55149841308594	:America/New_York	USA	knots	168	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.148	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Point	DE
100622	Reedy Point (depth 15 ft), Delaware Current	NOS	db0201_7	39.55860137939453	-75.55149841308594	:America/New_York	USA	knots	162	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.222	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Point	DE
100623	Reedy Point (depth 6 ft), Delaware Current	NOS	db0201_10	39.55860137939453	-75.55149841308594	:America/New_York	USA	knots	160	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.266	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reedy Point	DE
100624	Philadelphia, Penns Landing (depth 39 ft), Pennsylvania Current	NOS	db0301_22	39.94620132446289	-75.13960266113281	:America/New_York	USA	knots	187	4	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 295.3 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.388	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Philadelphia, Penns Landing	PA
100625	Delaware Bay Channel LB 10 (depth 12 ft), Delaware Current	NOS	db0502_1	38.94013	-75.10486	:America/New_York	USA	knots	157	341	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.076	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Delaware Bay Channel LB 10	DE
100626	Petty Island, Delaware River (depth 10 ft), Pennsylvania Current	NOS	db1935_3	39.96730041503906	-75.11720275878906	:America/New_York	USA	knots	238	59	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Petty Island, Delaware River	PA
100627	Petty Island, Delaware River (depth 16 ft), Pennsylvania Current	NOS	db1935_5	39.96730041503906	-75.11720275878906	:America/New_York	USA	knots	237	59	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Petty Island, Delaware River	PA
100628	Petty Island, Delaware River (depth 30 ft), Pennsylvania Current	NOS	db1935_9	39.96730041503906	-75.11720275878906	:America/New_York	USA	knots	235	59	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.087	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Petty Island, Delaware River	PA
100629	Surfside Bridge (depth 30 ft), Freeport, Texas Current	NOS	fr0201_2	28.954999923706055	-95.29389953613281	:America/Chicago	USA	knots	\N	42.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.016	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Surfside Bridge	TX
100630	Surfside Bridge (depth 15 ft), Freeport, Texas Current	NOS	fr0201_6	28.954999923706055	-95.29389953613281	:America/Chicago	USA	knots	222	42	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 82.0 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.034	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Surfside Bridge	TX
100631	Surfside Bridge (depth 135 ft), Freeport, Texas Current	NOS	fr0201_10	28.954999923706055	-95.29389953613281	:America/Chicago	USA	knots	\N	46.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Surfside Bridge	TX
100632	Morgans Point (depth 19 ft), Galveston Bay, Texas Current	NOS	g02010_1	29.68160057067871	-94.9822998046875	:America/Chicago	USA	knots	169	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.081	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Morgans Point	TX
100633	Morgans Point (depth 9 ft), Galveston Bay, Texas Current	NOS	g02010_4	29.68160057067871	-94.9822998046875	:America/Chicago	USA	knots	172	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.179	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Morgans Point	TX
100634	Galveston Causeway RR. bridge (depth 10 ft), Galveston Bay, Texas Current	NOS	g05010_26	29.29747	-94.885818	:America/Chicago	USA	knots	99	266	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 177.2 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.205	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Causeway RR. bridge	TX
100635	Galveston Bay entrance channel, LB 11 (depth 13 ft), Texas Current	NOS	g06010_1	29.34222	-94.74083	:America/Chicago	USA	knots	77	282	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.236	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Bay Entrance Channel, LB 11	TX
100636	Fred Hartman Br., Houston Ship Channel (depth 25 ft), Galveston Bay, Texas Current	NOS	g08010_30	29.7035	-95.01892	:America/Chicago	USA	knots	136	314	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 398.6 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.205	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fred Hartman Br., Houston Ship Channel	TX
100637	Galveston Channel, west end (depth 30 ft), Galveston Bay, Texas Current	NOS	g09010_10	29.30940055847168	-94.82060241699219	:America/Chicago	USA	knots	107	287	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 269.0 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Galveston Channel, west end	TX
100638	Ship Island, 1.0 nmi S of, LB 22 (depth 11 ft), Mississippi Sound, Mississippi Current	NOS	gp0101_1	30.19406	-88.98917	:America/Chicago	USA	knots	114	308	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 1.0 nm S of, LB 22	MS
100639	Ship Island, 1.0 nmi S of, LB 22 (depth 18 ft), Mississippi Sound, Mississippi Current	NOS	gp0101_3	30.19406	-88.98917	:America/Chicago	USA	knots	\N	298.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.05	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 1.0 nm S of, LB 22	MS
100640	Ship Island, 1.0 nmi S of, LB 22 (depth 24 ft), Mississippi Sound, Mississippi Current	NOS	gp0101_5	30.19406	-88.98917	:America/Chicago	USA	knots	\N	314.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.051	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 1.0 nm S of, LB 22	MS
100641	Ship Island, 0.5 nmi NW of, LB 26 (depth 11 ft), Mississippi Sound, Mississippi Current	NOS	gp0201_1	30.2162	-88.99442	:America/Chicago	USA	knots	\N	33.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.012	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 0.5 nm NW of, LB 26	MS
100642	Ship Island, 0.5 nmi NW of, LB 26 (depth 15 ft), Mississippi Sound, Mississippi Current	NOS	gp0201_2	30.2162	-88.99442	:America/Chicago	USA	knots	216	9	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.038	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 0.5 nm NW of, LB 26	MS
100643	Ship Island, 0.5 nmi NW of, LB 26 (depth 18 ft), Mississippi Sound, Mississippi Current	NOS	gp0201_3	30.2162	-88.99442	:America/Chicago	USA	knots	\N	26.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 0.5 nm NW of, LB 26	MS
100644	Ship Island, 1.8 nmi NNW of, DM 32 (depth 10 ft), Mississippi Sound, Mississippi Current	NOS	gp0301_5	30.23917	-89	:America/Chicago	USA	knots	184	26	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 70.5 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.067	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 1.8 nm NNW of, DM 32	MS
100645	Ship Island, 1.8 nmi NNW of, DM 32 (depth 202 ft), Mississippi Sound, Mississippi Current	NOS	gp0301_15	30.23917	-89	:America/Chicago	USA	knots	\N	20.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.004	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 1.8 nm NNW of, DM 32	MS
100646	Ship Island, 1.8 nmi NNW of, DM 32 (depth 399 ft), Mississippi Sound, Mississippi Current	NOS	gp0301_30	30.23917	-89	:America/Chicago	USA	knots	\N	20.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.01	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Ship Island, 1.8 nm NNW of, DM 32	MS
100647	Humboldt Bay entrance channel LB 9 (depth 11 ft), California Current	NOS	hb0201_1	40.75699996948242	-124.22339630126953	:America/Los_Angeles	USA	knots	232	111	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.246	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldt Bay Entrance Channel LB 9	CA
100648	Humboldt Bay entrance channel LB 9 (depth 21 ft), California Current	NOS	hb0201_4	40.75699996948242	-124.22339630126953	:America/Los_Angeles	USA	knots	247	106	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.224	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldt Bay Entrance Channel LB 9	CA
100649	Humboldt Bay entrance channel LB 9 (depth 37 ft), California Current	NOS	hb0201_9	40.75699996948242	-124.22339630126953	:America/Los_Angeles	USA	knots	259	98	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.152	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Humboldt Bay Entrance Channel LB 9	CA
100650	Hookton Channel Day Marker 3 (depth 59 ft), Humboldt Bay, California Current	NOS	hb0302_2	40.74399948120117	-124.22450256347656	:America/Los_Angeles	USA	knots	\N	191.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.08	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hookton Channel Day Marker 3	CA
100651	Hookton Channel Day Marker 3 (depth 16 ft), Humboldt Bay, California Current	NOS	hb0302_5	40.74399948120117	-124.22450256347656	:America/Los_Angeles	USA	knots	9	195	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 137.8 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hookton Channel Day Marker 3	CA
100652	Hookton Channel Day Marker 3 (depth 217 ft), Humboldt Bay, California Current	NOS	hb0302_8	40.74399948120117	-124.22450256347656	:America/Los_Angeles	USA	knots	\N	191.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.149	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Hookton Channel Day Marker 3	CA
100653	North Bay Channel, Chevron Pier (depth 15 ft), Humboldt Bay, California Current	NOS	hb0401_15	40.7775	-124.19661	:America/Los_Angeles	USA	knots	206	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 400.3 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.14	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	North Bay Channel, Chevron Pier	CA
100654	Bar Cut, 0.6 nmi ENE of St. Johns Point (depth 12 ft), St. Johns River, Florida Current	NOS	jx0101_1	30.39994	-81.37367	:America/New_York	USA	knots	58	275	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.448	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bar Cut, 0.6 n.mi. ENE of St. John's Point	FL
100655	Bar Cut, 0.6 nmi ENE of St. Johns Point (depth 25 ft), St. Johns River, Florida Current	NOS	jx0101_5	30.39994	-81.37367	:America/New_York	USA	knots	61	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.119	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bar Cut, 0.6 n.mi. ENE of St. John's Point	FL
100656	Bar Cut, 0.6 nmi ENE of St. Johns Point (depth 35 ft), St. Johns River, Florida Current	NOS	jx0101_8	30.39994	-81.37367	:America/New_York	USA	knots	72	247	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bar Cut, 0.6 n.mi. ENE of St. John's Point	FL
100657	Mayport Basin entrance (depth 12 ft), St. Johns River, Florida Current	NOS	jx0201_1	30.39889	-81.39469	:America/New_York	USA	knots	93	280	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.114	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport Basin Entrance	FL
100658	Mayport Basin entrance (depth 22 ft), St. Johns River, Florida Current	NOS	jx0201_4	30.39889	-81.39469	:America/New_York	USA	knots	84	276	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.136	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport Basin Entrance	FL
100659	Mayport Basin entrance (depth 35 ft), St. Johns River, Florida Current	NOS	jx0201_8	30.39889	-81.39469	:America/New_York	USA	knots	73	276	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.204	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mayport Basin Entrance	FL
100660	ICW Intersection (depth 12 ft), St. Johns River, Florida Current	NOS	jx0301_1	30.38275	-81.45556	:America/New_York	USA	knots	102	292	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.389	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICW Intersection	FL
100661	ICW Intersection (depth 22 ft), St. Johns River, Florida Current	NOS	jx0301_4	30.38275	-81.45556	:America/New_York	USA	knots	94	291	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.326	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICW Intersection	FL
100662	ICW Intersection (depth 35 ft), St. Johns River, Florida Current	NOS	jx0301_8	30.38275	-81.45556	:America/New_York	USA	knots	89	296	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.103	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	ICW Intersection	FL
100663	Mile Point LB 20 (depth 11 ft), St. Johns River, Florida Current	NOS	jx0302_1	30.38433	-81.44217	:America/New_York	USA	knots	36	203	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.293	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mile Point LB 20	FL
100664	Mile Point LB 20 (depth 17 ft), St. Johns River, Florida Current	NOS	jx0302_3	30.38433	-81.44217	:America/New_York	USA	knots	38	203	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.178	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mile Point LB 20	FL
100665	Mile Point LB 20 (depth 27 ft), St. Johns River, Florida Current	NOS	jx0302_6	30.38433	-81.44217	:America/New_York	USA	knots	35	213	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mile Point LB 20	FL
100666	St. Johns Bluff (depth 12 ft), St. Johns River, Florida Current	NOS	jx0401_1	30.39037	-81.49678	:America/New_York	USA	knots	82	269	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.293	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns Bluff	FL
100667	St. Johns Bluff (depth 22 ft), St. Johns River, Florida Current	NOS	jx0401_4	30.39037	-81.49678	:America/New_York	USA	knots	72	267	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.088	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns Bluff	FL
100668	St. Johns Bluff (depth 32 ft), St. Johns River, Florida Current	NOS	jx0401_7	30.39037	-81.49678	:America/New_York	USA	knots	71	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 30.8 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.251	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St. Johns Bluff	FL
102472	Mill Creek, Alaska Current	NOS	PCT3091_1	56.45	-132.21667	:America/Juneau	USA	knots	330	150	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:44:00	\N	0.9	00:23:00	\N	0.6	00:31:00	00:13:00	Mill Creek	AK
100669	Dames Point Bridge (depth 57 ft), St. Johns River, Florida Current	NOS	jx0501_4	30.38599	-81.55706	:America/New_York	USA	knots	\N	259.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point Bridge	FL
100670	Dames Point Bridge (depth 15 ft), St. Johns River, Florida Current	NOS	jx0501_13	30.38599	-81.55706	:America/New_York	USA	knots	87	257	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 175.5 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.072	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point Bridge	FL
100671	Dames Point Bridge (depth 241 ft), St. Johns River, Florida Current	NOS	jx0501_18	30.38599	-81.55706	:America/New_York	USA	knots	\N	264.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Dames Point Bridge	FL
100672	Reddie Point (depth 12 ft), St. Johns River, Florida Current	NOS	jx0601_1	30.39853	-81.62594	:America/New_York	USA	knots	36	176	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.063	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reddie Point	FL
100673	Reddie Point (depth 16 ft), St. Johns River, Florida Current	NOS	jx0601_2	30.39853	-81.62594	:America/New_York	USA	knots	\N	204.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.077	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reddie Point	FL
100674	Reddie Point (depth 19 ft), St. Johns River, Florida Current	NOS	jx0601_3	30.39853	-81.62594	:America/New_York	USA	knots	\N	205.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.147	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reddie Point	FL
100675	Reddie Point (depth 22 ft), St. Johns River, Florida Current	NOS	jx0601_4	30.39853	-81.62594	:America/New_York	USA	knots	40	170	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.181	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reddie Point	FL
100676	Reddie Point (depth 25 ft), St. Johns River, Florida Current	NOS	jx0601_5	30.39853	-81.62594	:America/New_York	USA	knots	\N	200.8	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.171	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reddie Point	FL
100677	Reddie Point (depth 29 ft), St. Johns River, Florida Current	NOS	jx0601_6	30.39853	-81.62594	:America/New_York	USA	knots	\N	197.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.13	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reddie Point	FL
100678	Reddie Point (depth 32 ft), St. Johns River, Florida Current	NOS	jx0601_7	30.39853	-81.62594	:America/New_York	USA	knots	\N	195.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.122	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reddie Point	FL
100679	Reddie Point (depth 35 ft), St. Johns River, Florida Current	NOS	jx0601_8	30.39853	-81.62594	:America/New_York	USA	knots	29	164	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.134	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Reddie Point	FL
100680	Acosta Bridge (depth 15 ft), St. Johns River, Florida Current	NOS	jx0701_20	30.32266	-81.66461	:America/New_York	USA	knots	77	259	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 267.4 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.041	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Acosta Bridge	FL
100681	St. Marys entrance, LB 13 (depth 14 ft), Cumberland Sound, Florida Current	NOS	kb0101_2	30.7103	-81.3731	:America/New_York	USA	knots	95	320	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.234	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Marys Entrance, LB 13	FL
100682	St. Marys entrance, LB 13 (depth 21 ft), Cumberland Sound, Florida Current	NOS	kb0101_4	30.7103	-81.3731	:America/New_York	USA	knots	94	317	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.195	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Marys Entrance, LB 13	FL
100683	St. Marys entrance, LB 13 (depth 31 ft), Cumberland Sound, Florida Current	NOS	kb0101_7	30.7103	-81.3731	:America/New_York	USA	knots	92	317	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.156	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Marys Entrance, LB 13	FL
100687	Range A, LB 23, St. Marys River (depth 11 ft), Cumberland Sound, Georgia Current	NOS	kb0201_1	30.71049	-81.45926	:America/New_York	USA	knots	98	295	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A, LB 23, St Marys River	GA
100688	Range A, LB 23, St. Marys River (depth 14 ft), Cumberland Sound, Georgia Current	NOS	kb0201_2	30.71049	-81.45926	:America/New_York	USA	knots	97	296	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.09	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A, LB 23, St Marys River	GA
100689	Range A, LB 23, St. Marys River (depth 24 ft), Cumberland Sound, Georgia Current	NOS	kb0201_5	30.71049	-81.45926	:America/New_York	USA	knots	90	299	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A, LB 23, St Marys River	GA
100690	Range A2, LB 29, Cumberland Sound (depth 11 ft), Georgia Current	NOS	kb0301_1	30.72482	-81.48445	:America/New_York	USA	knots	182	341	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.144	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A2, LB 29, Cumberland Sound	GA
100691	Range A2, LB 29, Cumberland Sound (depth 18 ft), Georgia Current	NOS	kb0301_3	30.72482	-81.48445	:America/New_York	USA	knots	167	340	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.027	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A2, LB 29, Cumberland Sound	GA
100692	Range A2, LB 29, Cumberland Sound (depth 24 ft), Georgia Current	NOS	kb0301_5	30.72482	-81.48445	:America/New_York	USA	knots	149	339	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range A2, LB 29, Cumberland Sound	GA
100693	Range E, LB 43, Cumberland Sound (depth 11 ft), East River, Georgia Current	NOS	kb0401_1	30.77505	-81.48902	:America/New_York	USA	knots	156	2	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range E, LB 43, Cumberland Sound	GA
100694	Range E, LB 43, Cumberland Sound (depth 21 ft), East River, Georgia Current	NOS	kb0401_4	30.77505	-81.48902	:America/New_York	USA	knots	160	9	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.028	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Range E, LB 43, Cumberland Sound	GA
100695	Kings Bay, Site VI (depth 28 ft), Cumberland Sound, Georgia Current	NOS	kb0501_15	30.788299560546875	-81.49669647216797	:America/New_York	USA	knots	144	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 200.1 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.02	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kings Bay, Site VI	GA
100696	Kings Bay, North Turning Basin (depth 10 ft), Cumberland Sound, Georgia Current	NOS	kb0601_2	30.809999465942383	-81.52030181884766	:America/New_York	USA	knots	174	355	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kings Bay, North Turning Basin	GA
100697	Kings Bay, North Turning Basin (depth 16 ft), Cumberland Sound, Georgia Current	NOS	kb0601_4	30.809999465942383	-81.52030181884766	:America/New_York	USA	knots	173	352	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kings Bay, North Turning Basin	GA
100698	Kings Bay, North Turning Basin (depth 26 ft), Cumberland Sound, Georgia Current	NOS	kb0601_7	30.809999465942383	-81.52030181884766	:America/New_York	USA	knots	169	349	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.014	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kings Bay, North Turning Basin	GA
100699	Rich Passage, LB 8 (depth 11 ft), Puget Sound, Washington Current	NOS	ks0101_1	47.5933	-122.5426	:America/Los_Angeles	USA	knots	103	318	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.26	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, LB 8	WA
100700	Rich Passage, LB 8 (depth 14 ft), Puget Sound, Washington Current	NOS	ks0101_2	47.5933	-122.5426	:America/Los_Angeles	USA	knots	105	318	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.23	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, LB 8	WA
100701	Rich Passage, LB 8 (depth 31 ft), Puget Sound, Washington Current	NOS	ks0101_7	47.5933	-122.5426	:America/Los_Angeles	USA	knots	109	313	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.157	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rich Passage, LB 8	WA
100702	Bangor, Hood Canal LB B (depth 14 ft), Washington Current	NOS	ks0201_2	47.75782	-122.73057	:America/Los_Angeles	USA	knots	358	181	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 12.8 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.228	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor, Hood Canal LB B	WA
100686	St. Marys entrance, LB 19 (depth 34 ft), Florida Current	NOS	kb0102_8	30.708900451660156	-81.41480255126953	:America/New_York	USA	knots	75	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.062	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Marys Entrance, LB 19	FL
100703	Bangor, Hood Canal LB B (depth 28 ft), Washington Current	NOS	ks0201_6	47.75782	-122.73057	:America/Los_Angeles	USA	knots	354	179	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 25.9 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.073	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor, Hood Canal LB B	WA
100704	Bangor, Hood Canal LB B (depth 41 ft), Washington Current	NOS	ks0201_10	47.75782	-122.73057	:America/Los_Angeles	USA	knots	352	179	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 39.0 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bangor, Hood Canal LB B	WA
100705	Queens Gate (depth 35 ft), California Current	NOS	lb0101_6	33.717	-118.1879	:America/Los_Angeles	USA	knots	257	48	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.062	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Queens Gate	CA
101804	Frazier Point, south of, Winyah Bay, South Carolina Current	NOS	ACT6541_1	33.295	-79.27283	:America/New_York	USA	knots	115	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:59:00	\N	0.5	01:52:00	\N	1.1	01:52:00	02:20:00	Frazier Point, south of	SC
100706	Calcasieu Pass, Cameron Fishing Pier (depth 136 ft), Louisiana Current	NOS	lc0201_10	29.76513	-93.34293	:America/Chicago	USA	knots	\N	353.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.303	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Calcasieu Pass, Cameron Fishing Pier	LA
100707	Calcasieu Pass, Cameron Fishing Pier (depth 17 ft), Louisiana Current	NOS	lc0201_20	29.76513	-93.34293	:America/Chicago	USA	knots	173	353	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 267.4 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.324	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Calcasieu Pass, Cameron Fishing Pier	LA
100708	Calcasieu Pass, Cameron Fishing Pier (depth 399 ft), Louisiana Current	NOS	lc0201_30	29.76513	-93.34293	:America/Chicago	USA	knots	\N	351.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.289	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Calcasieu Pass, Cameron Fishing Pier	LA
100709	Lake Charles City Docks (depth 21 ft), Louisiana Current	NOS	lc0301_20	30.2178	-93.2495	:America/Chicago	USA	knots	289	115	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 267.4 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.393	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Lake Charles City Docks	LA
100710	Matagorda Ship Channel Marker 19 (depth 15 ft), Matagorda Bay, Texas Current	NOS	mg0101_17	28.44769	-96.35619	:America/Chicago	USA	knots	163	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 226.4 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.172	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matagorda Ship Channel Marker 19	TX
100711	Matagorda entrance channel (depth 15 ft), Matagorda Bay, Texas Current	NOS	mg0201_20	28.42667	-96.33	:America/Chicago	USA	knots	124	306	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 264.1 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.137	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Matagorda Entrance Channel	TX
100712	Bergen Point (depth 37 ft), Kill Van Kull, New York Current	NOS	n01010_1	40.6422004699707	-74.15129852294922	:America/New_York	USA	knots	110	299	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.252	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bergen Point	NY
100713	Bergen Point (depth 14 ft), Kill Van Kull, New York Current	NOS	n01010_8	40.6422004699707	-74.15129852294922	:America/New_York	USA	knots	133	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.24	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bergen Point	NY
100714	Bayonne Bridge (depth 16 ft), Kill Van Kull, New York Current	NOS	n02010_8	40.641700744628906	-74.14330291748047	:America/New_York	USA	knots	78	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Bayonne Bridge	NY
100715	The Narrows (depth 29 ft), New York Harbor entrance, New York Current	NOS	n03020_2	40.60639953613281	-74.03800201416016	:America/New_York	USA	knots	134	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.021	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows	NY
100716	The Narrows (depth 13 ft), New York Harbor entrance, New York Current	NOS	n03020_7	40.60639953613281	-74.03800201416016	:America/New_York	USA	knots	143	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.299	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows	NY
100717	The Narrows (depth 6 ft), New York Harbor entrance, New York Current	NOS	n03020_9	40.60639953613281	-74.03800201416016	:America/New_York	USA	knots	144	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.407	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	The Narrows	NY
100718	Gowanus Flats LBB 32 (depth 11 ft), Upper Bay, New York Harbor, New York Current	NOS	n05010_1	40.67210006713867	-74.03990173339844	:America/New_York	USA	knots	197	29	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.462	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gowanus Flats LBB 32	NY
100719	Gowanus Flats LBB 32 (depth 28 ft), Upper Bay, New York Harbor, New York Current	NOS	n05010_6	40.67210006713867	-74.03990173339844	:America/New_York	USA	knots	191	26	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.151	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gowanus Flats LBB 32	NY
100720	Gowanus Flats LBB 32 (depth 44 ft), Upper Bay, New York Harbor, New York Current	NOS	n05010_11	40.67210006713867	-74.03990173339844	:America/New_York	USA	knots	194	25	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.175	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Gowanus Flats LBB 32	NY
100721	Kill Van Kull LB 14, east of Bayonne Bridge (depth 11 ft), New Jersey Current	NOS	n06010_1	40.64358	-74.13889	:America/New_York	USA	knots	75	248	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.075	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kill Van Kull LB 14, east of Bayonne Bridge	NJ
100722	Kill Van Kull LB 14, east of Bayonne Bridge (depth 25 ft), New Jersey Current	NOS	n06010_4	40.64358	-74.13889	:America/New_York	USA	knots	78	247	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 21.5 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.104	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kill Van Kull LB 14, east of Bayonne Bridge	NJ
100723	Kill Van Kull LB 14, east of Bayonne Bridge (depth 41 ft), New Jersey Current	NOS	n06010_10	40.64358	-74.13889	:America/New_York	USA	knots	82	248	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.159	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Kill Van Kull LB 14, east of Bayonne Bridge	NJ
100724	Newark Bay entrance LB 18 (depth 15 ft), New Jersey Current	NOS	n07010_2	40.64708	-74.1555	:America/New_York	USA	knots	155	0	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.201	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newark Bay Entrance LB 18	NJ
100725	Newark Bay entrance LB 18 (depth 22 ft), New Jersey Current	NOS	n07010_4	40.64708	-74.1555	:America/New_York	USA	knots	149	357	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.236	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newark Bay Entrance LB 18	NJ
100726	Newark Bay entrance LB 18 (depth 32 ft), New Jersey Current	NOS	n07010_7	40.64708	-74.1555	:America/New_York	USA	knots	119	4	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.218	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Newark Bay Entrance LB 18	NJ
100727	Providence River, Fox Point Reach (depth 31 ft), Narragansett Bay, Rhode Island Current	NOS	nb0101_2	41.8087	-71.39747	:America/New_York	USA	knots	\N	341.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.001	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Providence River, Fox Point Reach	RI
100728	Providence River, Fox Point Reach (depth 11 ft), Narragansett Bay, Rhode Island Current	NOS	nb0101_8	41.8087	-71.39747	:America/New_York	USA	knots	141	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.015	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Providence River, Fox Point Reach	RI
100729	Fall River entrance (depth 30 ft), Narragansett Bay, Massachusetts Current	NOS	nb0201_1	41.6999	-71.17842	:America/New_York	USA	knots	239	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.194	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fall River entrance	MA
100730	Fall River entrance (depth 23 ft), Narragansett Bay, Massachusetts Current	NOS	nb0201_3	41.6999	-71.17842	:America/New_York	USA	knots	\N	59.5	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.198	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fall River entrance	MA
100731	Fall River entrance (depth 13 ft), Narragansett Bay, Massachusetts Current	NOS	nb0201_6	41.6999	-71.17842	:America/New_York	USA	knots	242	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.074	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Fall River entrance	MA
100732	Quonset Point (depth 8 ft), Narragansett Bay, Rhode Island Current	NOS	nb0301_7	41.5834	-71.3957	:America/New_York	USA	knots	194	27	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.097	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Quonset Point	RI
100733	Groton, Thames River, Pier 6 (depth 42 ft), Long Island Sound, Connecticut Current	NOS	nl0101_9	41.39175	-72.0923	:America/New_York	USA	knots	132	311	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 124.7 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.082	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Groton, Thames River, Pier 6	CT
100734	Portsmouth Harbor, Gangway Rocks LB13 (depth 14 ft), New Hampshire Current	NOS	pm0101_2	43.078399658203125	-70.74669647216797	:America/New_York	USA	knots	121	289	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.237	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portsmouth Harbor, Gangway Rocks LB13	NH
100735	Portsmouth Harbor, Gangway Rocks LB13 (depth 21 ft), New Hampshire Current	NOS	pm0101_4	43.078399658203125	-70.74669647216797	:America/New_York	USA	knots	121	287	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.202	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portsmouth Harbor, Gangway Rocks LB13	NH
100736	Portsmouth Harbor, Gangway Rocks LB13 (depth 28 ft), New Hampshire Current	NOS	pm0101_6	43.078399658203125	-70.74669647216797	:America/New_York	USA	knots	120	284	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.175	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Portsmouth Harbor, Gangway Rocks LB13	NH
100737	Horn Island Pass, LB 17 (depth 12 ft), Mississippi Sound, Mississippi Current	NOS	ps0201_1	30.21503	-88.51089	:America/Chicago	USA	knots	228	23	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.157	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horn Island Pass, LB 17	MS
100738	Horn Island Pass, LB 17 (depth 25 ft), Mississippi Sound, Mississippi Current	NOS	ps0201_5	30.21503	-88.51089	:America/Chicago	USA	knots	221	25	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Horn Island Pass, LB 17	MS
100739	Benicia Bridge (depth 15 ft), Suisun Bay, California Current	NOS	s06010_16	38.03463	-122.12525	:America/Los_Angeles	USA	knots	242	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 213.3 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.055	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Benicia Bridge	CA
100740	Southampton Shoal Channel, LB 6 (depth 15 ft), San Francisco Bay, California Current	NOS	s08010_2	37.91625	-122.42233	:America/Los_Angeles	USA	knots	169	359	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.066	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southampton Shoal Channel, LB 6	CA
100741	Southampton Shoal Channel, LB 6 (depth 22 ft), San Francisco Bay, California Current	NOS	s08010_4	37.91625	-122.42233	:America/Los_Angeles	USA	knots	168	358	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.115	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southampton Shoal Channel, LB 6	CA
100742	Southampton Shoal Channel, LB 6 (depth 35 ft), San Francisco Bay, California Current	NOS	s08010_8	37.91625	-122.42233	:America/Los_Angeles	USA	knots	170	356	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.197	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Southampton Shoal Channel, LB 6	CA
100743	Oakland Outer Harbor entrance, LB 3 (depth 14 ft), San Francisco Bay, California Current	NOS	s09010_2	37.8082	-122.34434	:America/Los_Angeles	USA	knots	359	191	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Outer Harbor Entrance, LB 3	CA
100744	Oakland Outer Harbor entrance, LB 3 (depth 24 ft), San Francisco Bay, California Current	NOS	s09010_4	37.8082	-122.34434	:America/Los_Angeles	USA	knots	1	194	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.\n** Depth specified in the harcon record is 20.7 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.043	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Outer Harbor Entrance, LB 3	CA
100745	Oakland Outer Harbor entrance, LB 3 (depth 37 ft), San Francisco Bay, California Current	NOS	s09010_9	37.8082	-122.34434	:America/Los_Angeles	USA	knots	16	203	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.025	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Outer Harbor Entrance, LB 3	CA
100746	Oakland Inner Harbor LB4 (depth 14 ft), San Francisco Bay, California Current	NOS	s10010_2	37.80097	-122.34775	:America/Los_Angeles	USA	knots	348	165	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.106	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor LB4	CA
100747	Oakland Inner Harbor LB4 (depth 21 ft), San Francisco Bay, California Current	NOS	s10010_4	37.80097	-122.34775	:America/Los_Angeles	USA	knots	348	161	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.117	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor LB4	CA
100748	Oakland Inner Harbor LB4 (depth 27 ft), San Francisco Bay, California Current	NOS	s10010_6	37.80097	-122.34775	:America/Los_Angeles	USA	knots	347	157	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.126	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Oakland Inner Harbor LB4	CA
100752	Sabine Front Range, Point Hunt, NW of (depth 7 ft), Sabine Pass, Louisiana Current	NOS	sn0301_5	29.75806	-93.89	:America/Chicago	USA	knots	166	335	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 70.5 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.042	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Front Range, Point Hunt, NW of	LA
100769	Port Manatee Channel entrance (depth 17 ft), Tampa Bay, Florida Current	NOS	t03010_7	27.66395	-82.59877	:America/New_York	USA	knots	218	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.053	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Manatee Channel Entrance	FL
100750	Sabine Pass, USCG base (depth 4 ft), Texas Current	NOS	sn0201_30	29.7286	-93.87	:America/Chicago	USA	knots	146	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 398.6 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.031	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass, USCG Base	TX
100751	Sabine Pass, USCG base (depth 530 ft), Texas Current	NOS	sn0201_40	29.7286	-93.87	:America/Chicago	USA	knots	\N	323.7	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass, USCG Base	TX
100753	Sabine Front Range, Point Hunt, NW of (depth 136 ft), Sabine Pass, Louisiana Current	NOS	sn0301_10	29.75806	-93.89	:America/Chicago	USA	knots	\N	334.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.048	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Front Range, Point Hunt, NW of	LA
100754	Sabine Front Range, Point Hunt, NW of (depth 202 ft), Sabine Pass, Louisiana Current	NOS	sn0301_15	29.75806	-93.89	:America/Chicago	USA	knots	\N	328.6	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.062	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Front Range, Point Hunt, NW of	LA
100755	Rainbow Bridge (depth 71 ft), Sabine Pass, Texas Current	NOS	sn0501_5	29.98111	-93.87111	:America/Chicago	USA	knots	\N	281.9	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.15	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rainbow Bridge	TX
100756	Rainbow Bridge (depth 12 ft), Sabine Pass, Texas Current	NOS	sn0501_17	29.98111	-93.87111	:America/Chicago	USA	knots	108	285	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 228.0 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.16	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rainbow Bridge	TX
100757	Rainbow Bridge (depth 307 ft), Sabine Pass, Texas Current	NOS	sn0501_23	29.98111	-93.87111	:America/Chicago	USA	knots	\N	287.3	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.192	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Rainbow Bridge	TX
100758	Port Arthur (depth 16 ft), Sabine Pass, Texas Current	NOS	sn0701_20	29.86671	-93.93111	:America/Chicago	USA	knots	210	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 267.4 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.113	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Arthur	TX
100759	Sabine Pass, Cheniere LNG (depth 412 ft), Louisiana Current	NOS	sn0801_31	29.742399215698242	-93.87370300292969	:America/Chicago	USA	knots	\N	332.1	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.273	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass, Cheniere LNG	LA
100760	Sabine Pass, Cheniere LNG (depth 504 ft), Louisiana Current	NOS	sn0801_38	29.742399215698242	-93.87370300292969	:America/Chicago	USA	knots	\N	335.2	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.403	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass, Cheniere LNG	LA
100761	Sabine Pass, Cheniere LNG (depth 8 ft), Louisiana Current	NOS	sn0801_45	29.742399215698242	-93.87370300292969	:America/Chicago	USA	knots	155	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 595.5 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.491	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass, Cheniere LNG	LA
100762	Sunshine Skyway Bridge (depth 36 ft), Tampa Bay, Florida Current	NOS	t01010_3	27.62065	-82.65525	:America/New_York	USA	knots	236	58	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.079	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunshine Skyway Bridge	FL
100763	Sunshine Skyway Bridge (depth 16 ft), Tampa Bay, Florida Current	NOS	t01010_9	27.62065	-82.65525	:America/New_York	USA	knots	238	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.037	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunshine Skyway Bridge	FL
100764	Sunshine Skyway Bridge (depth 10 ft), Tampa Bay, Florida Current	NOS	t01010_11	27.62065	-82.65525	:America/New_York	USA	knots	239	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.017	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sunshine Skyway Bridge	FL
100765	Old Tampa Bay entrance (Port Tampa) (depth 32 ft), Florida Current	NOS	t02010_2	27.86287	-82.55373	:America/New_York	USA	knots	210	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.013	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Tampa Bay Entrance (Port Tampa)	FL
100766	Old Tampa Bay entrance (Port Tampa) (depth 16 ft), Florida Current	NOS	t02010_7	27.86287	-82.55373	:America/New_York	USA	knots	211	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.03	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Tampa Bay Entrance (Port Tampa)	FL
100767	Old Tampa Bay entrance (Port Tampa) (depth 9 ft), Florida Current	NOS	t02010_9	27.86287	-82.55373	:America/New_York	USA	knots	212	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.032	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Old Tampa Bay Entrance (Port Tampa)	FL
100768	Port Manatee Channel entrance (depth 26 ft), Tampa Bay, Florida Current	NOS	t03010_4	27.66395	-82.59877	:America/New_York	USA	knots	217	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.096	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Manatee Channel Entrance	FL
100770	Port Manatee Channel entrance (depth 7 ft), Tampa Bay, Florida Current	NOS	t03010_10	27.66395	-82.59877	:America/New_York	USA	knots	219	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.029	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Port Manatee Channel Entrance	FL
98428	Big Stone Beach Anchorage, Buoy G (depth 41 ft), Delaware Current	NOS	DEB2106_2	38.963199615478516	-75.17939758300781	:America/New_York	USA	knots	146	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.116	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Big Stone Beach Anchorage, buoy "G"	DE
98443	Baker Range Channel (depth 11 ft), New Jersey Current	NOS	DEB2111_1	39.469398498535156	-75.55999755859375	:America/New_York	USA	knots	184	331	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.155	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Baker Range Channel	NJ
98476	Mantua Creek, US 44 Bridge, Paulsboro (depth 13 ft), New Jersey Current	NOS	DEB2123_16	39.83150100708008	-75.23600006103516	:America/New_York	USA	knots	21	193	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.\n** Depth specified in the harcon record is 54.1 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.297	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Mantua Creek US 44 Bridge Paulsboro	NJ
98493	Edgewater Range at Devlin Range (depth 32 ft), Pennsylvania Current	NOS	DEB2132_1	40.077598571777344	-74.8865966796875	:America/New_York	USA	knots	250	70	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.268	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Edgewater Range at Devlin Range	PA
100616	Enbridge (depth 44 ft), Corpus Christi Channel, Texas Current	NOS	cc0401_10	27.817699432373047	-97.20929718017578	:America/Chicago	USA	knots	65	246	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.\n** Depth specified in the harcon record is 136.2 ft.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.002	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Enbridge	TX
100684	St. Marys entrance, LB 19 (depth 11 ft), Florida Current	NOS	kb0102_1	30.708900451660156	-81.41480255126953	:America/New_York	USA	knots	71	276	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.307	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Marys Entrance, LB 19	FL
100685	St. Marys entrance, LB 19 (depth 21 ft), Florida Current	NOS	kb0102_4	30.708900451660156	-81.41480255126953	:America/New_York	USA	knots	77	272	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	-0.093	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	St Marys Entrance, LB 19	FL
100771	Eastport, Friar Roads, Maine Current	NOS	ACT0091_1	44.9	-66.98333	:America/New_York	USA	knots	40	210	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98504	00:00:00	\N	1.2	00:00:00	\N	1.2	00:00:00	00:00:00	Eastport, Friar Roads	ME
100772	Western Passage, off Kendall Head, Maine Current	NOS	ACT0101_1	44.93167	-67	:America/New_York	USA	knots	142	319	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98504	00:40:00	\N	1.3	00:11:00	\N	1.4	00:27:00	00:13:00	Western Passage, off Kendall Head	ME
100773	Western Passage, off Frost Ledge, Maine Current	NOS	ACT0106_1	44.965	-67.03167	:America/New_York	USA	knots	150	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98504	00:15:00	\N	0.7	00:04:00	\N	0.9	00:33:00	-00:16:00	Western Passage, off Frost Ledge	ME
100774	Pond Point, 7.6 mi SSE of, Maine Current	NOS	ACT0111_1	44.335	-67.50333	:America/New_York	USA	knots	215	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	00:24:00	\N	1.1	00:04:00	\N	0.7	00:03:00	-01:10:00	Pond Point, 7.6 miles SSE of	ME
100775	Moosabec Reach, east end, Maine Current	NOS	ACT0116_1	44.5285	-67.57267	:America/New_York	USA	knots	258	110	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-03:10:00	\N	0.9	-02:44:00	\N	1.5	-02:55:00	-02:50:00	Moosabec Reach, east end	ME
100776	Moosabec Reach, west end, Maine Current	NOS	ACT0121_1	44.52083	-67.65	:America/New_York	USA	knots	253	92	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:15:00	\N	1.1	-01:19:00	\N	1.5	-01:53:00	-01:37:00	Moosabec Reach, west end	ME
100777	Casco Passage, east end, Blue Hill Bay, Maine Current	NOS	ACT0131_1	44.195	-68.465	:America/New_York	USA	knots	284	86	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:29:00	\N	0.6	-01:20:00	\N	1	-01:57:00	-00:39:00	Casco Passage, east end, Blue Hill Bay	ME
100778	Hat Island, SE of, Jericho Bay, Maine Current	NOS	ACT0136_1	44.13333	-68.495	:America/New_York	USA	knots	124	318	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:51:00	\N	1.2	-00:11:00	\N	1.3	-01:12:00	-00:27:00	Hat Island, SE of, Jericho Bay	ME
100779	Clam I., NW of, Deer I. Thorofare (depth 14 ft), Maine Current	NOS	ACT0141_1	44.1645	-68.60383	:America/New_York	USA	knots	199	4	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-02:17:00	\N	0.2	00:09:00	\N	0.3	-02:24:00	-00:34:00	Clam I., NW of, Deer I. Thorofare	ME
100780	Grog Island, E of, Deer Island Thorofare (depth 14 ft), Maine Current	NOS	ACT0146_1	44.162	-68.6205	:America/New_York	USA	knots	235	20	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-03:02:00	\N	0.3	-01:58:00	\N	0.3	-02:26:00	-02:04:00	Grog Island, E of, Deer Island Thorofare	ME
100781	Russ Island, N of, Deer Island Thorofare (depth 14 ft), Maine Current	NOS	ACT0151_1	44.153	-68.64633	:America/New_York	USA	knots	265	74	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-02:47:00	\N	0.6	-01:46:00	\N	0.6	-02:22:00	-02:06:00	Russ Island, N of, Deer Island Thorofare	ME
100782	Isle au Haut, 0.8 mi E of Rich's Pt (depth 11 ft), Maine Current	NOS	ACT0161_1	44.08333	-68.58333	:America/New_York	USA	knots	139	336	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:50:00	\N	1.4	-00:43:00	\N	2.1	-01:03:00	-00:44:00	Isle au Haut, 0.8 mile E of Rich's Pt	ME
100783	Mark Island, north of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0166_1	44.13667	-68.70283	:America/New_York	USA	knots	164	13	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	00:07:00	\N	0.4	-00:37:00	\N	0.4	-00:28:00	-02:04:00	Mark Island, north of	ME
100788	Bradbury Island, ESE of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0191_1	44.23383	-68.7345	:America/New_York	USA	knots	225	25	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:27:00	\N	0.6	00:07:00	\N	0.7	00:01:00	-00:30:00	Bradbury Island, ESE of	ME
100789	Compass Island, 0.4 nmi ENE of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0196_1	44.21667	-68.8555	:America/New_York	USA	knots	175	15	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:32:00	\N	0.3	-00:58:00	\N	0.4	-01:54:00	-01:02:00	Compass Island, 0.4 nmi. ENE of	ME
100790	Scrag Island, 0.3 nmi SW of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0201_1	44.22217	-68.84367	:America/New_York	USA	knots	197	10	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:26:00	\N	0.3	-00:03:00	\N	0.6	-00:55:00	-00:32:00	Scrag Island, 0.3 nautical mile SW of	ME
100791	Great Spruce Head Island, west of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0206_1	44.23833	-68.83633	:America/New_York	USA	knots	174	3	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:50:00	\N	0.3	-00:30:00	\N	0.4	-01:24:00	-00:03:00	Great Spruce Head Island, west of	ME
100792	Pickering Island, south of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0216_1	44.2605	-68.75633	:America/New_York	USA	knots	150	300	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-02:08:00	\N	0.6	-01:13:00	\N	0.9	-02:55:00	-01:33:00	Pickering Island, south of	ME
100793	Little Eaton Island, NNE of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0221_1	44.27417	-68.73117	:America/New_York	USA	knots	106	300	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	00:10:00	\N	0.3	00:36:00	\N	0.6	-00:53:00	00:25:00	Little Eaton Island, NNE of	ME
100794	Hog Island, ESE of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0231_1	44.27533	-68.78117	:America/New_York	USA	knots	180	24	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:22:00	\N	0.5	00:22:00	\N	0.4	-00:23:00	-00:10:00	Hog Island, ESE of	ME
96358	Ape Hole Creek, Pocomoke Sound, Chesapeake Bay, Maryland	NOS	8571072	37.961700439453125	-75.82170104980469	:America/New_York	USA	feet	\N	\N	\N	\N	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94971	04:58:00	\N	0.83	04:27:00	\N	0.9	\N	\N	Ape Hole Creek, Pocomoke Sound	MD
100795	Little Deer I.-Sheep I., between (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0236_1	44.27967	-68.72383	:America/New_York	USA	knots	124	310	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:23:00	\N	0.6	-00:13:00	\N	0.9	-00:23:00	00:56:00	Little Deer I.-Sheep I., between	ME
100796	Swains Ledge, 0.3 nmi SW of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0246_1	44.2855	-68.73117	:America/New_York	USA	knots	170	358	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:38:00	\N	0.4	00:02:00	\N	0.7	-00:56:00	-00:32:00	Swains Ledge, 0.3 nautical mile SW of	ME
100797	Pond Island-Western Island, between (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0251_1	44.293	-68.81667	:America/New_York	USA	knots	172	356	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:05:00	\N	0.6	-00:49:00	\N	0.6	-01:54:00	-01:33:00	Pond Island-Western Island, between	ME
100798	Birch Island, northwest of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0256_1	44.30283	-68.75583	:America/New_York	USA	knots	200	22	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:01:00	\N	0.2	-01:07:00	\N	0.4	-01:54:00	-00:33:00	Birch Island, northwest of	ME
100799	Pumpkin Island, north of (depth 14 ft), East Penobscot Bay, Maine Current	NOS	ACT0281_1	44.31333	-68.74033	:America/New_York	USA	knots	90	290	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-02:14:00	\N	0.3	-01:46:00	\N	0.4	-03:24:00	-01:31:00	Pumpkin Island, north of	ME
100800	Islesboro Harbor, NE of, Penobscot Bay (depth 75 ft), Maine Current	NOS	ACT0291_1	44.31617	-68.87967	:America/New_York	USA	knots	166	4	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:56:00	\N	0.3	-00:36:00	\N	0.4	-01:14:00	-01:13:00	Islesboro Harbor, NE of, Penobscot Bay	ME
100801	Islesboro Harbor, NE of, Penobscot Bay (depth 15 ft), Maine Current	NOS	ACT0296_1	44.31717	-68.87783	:America/New_York	USA	knots	154	334	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:54:00	\N	0.3	-00:30:00	\N	0.1	00:16:00	-00:59:00	Islesboro Harbor, NE of, Penobscot Bay	ME
100802	Turtle Head Pt., ESE of, Penobscot Bay (depth 15 ft), Maine Current	NOS	ACT0311_1	44.37617	-68.85467	:America/New_York	USA	knots	171	338	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99011	-01:02:00	\N	0.4	-01:10:00	\N	0.3	-00:36:00	00:24:00	Turtle Head Pt., ESE of, Penobscot Bay	ME
100803	Turtle Head Pt., ESE of, Penobscot Bay (depth 40 ft), Maine Current	NOS	ACT0311_2	44.37617	-68.85467	:America/New_York	USA	knots	155	319	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99011	-00:32:00	\N	0.4	-01:18:00	\N	0.2	-00:55:00	-00:31:00	Turtle Head Pt., ESE of, Penobscot Bay	ME
100804	Dice Head, west of, Penobscot Bay (depth 15 ft), Maine Current	NOS	ACT0321_1	44.3795	-68.84533	:America/New_York	USA	knots	198	28	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99011	-00:48:00	\N	0.3	-01:23:00	\N	0.2	-01:52:00	-00:27:00	Dice Head, west of, Penobscot Bay	ME
100805	Dice Head, west of, Penobscot Bay (depth 58 ft), Maine Current	NOS	ACT0321_2	44.3795	-68.84533	:America/New_York	USA	knots	178	334	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99011	00:34:00	\N	0.3	-00:39:00	\N	0.2	-00:09:00	00:25:00	Dice Head, west of, Penobscot Bay	ME
100806	Dice Head, west of, Penobscot Bay (depth 96 ft), Maine Current	NOS	ACT0321_3	44.3795	-68.84533	:America/New_York	USA	knots	135	312	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99011	00:24:00	\N	0.3	-00:32:00	\N	0.3	00:37:00	00:34:00	Dice Head, west of, Penobscot Bay	ME
100807	Jones Point, Bagaduce River (depth 15 ft), Maine Current	NOS	ACT0331_1	44.42583	-68.75833	:America/New_York	USA	knots	237	53	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99011	00:21:00	\N	2.1	-00:03:00	\N	1.8	-00:13:00	00:21:00	Jones Point, Bagaduce River	ME
100808	Verona I., N of, Easter Ch., Penobscot R (depth 10 ft), Maine Current	NOS	ACT0346_1	44.56783	-68.78117	:America/New_York	USA	knots	116	273	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99011	00:18:00	\N	0.9	00:07:00	\N	0.3	02:18:00	-00:54:00	Verona I., N of, Easter Ch., Penobscot R	ME
100809	Oak Point, Penobscot River (depth 15 ft), Maine Current	NOS	ACT0371_1	44.66833	-68.813	:America/New_York	USA	knots	219	26	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99011	01:09:00	\N	0.9	00:16:00	\N	0.6	00:05:00	00:21:00	Oak Point, Penobscot River	ME
100810	Oak Point, Penobscot River (depth 35 ft), Maine Current	NOS	ACT0371_2	44.66833	-68.813	:America/New_York	USA	knots	258	337	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99011	-00:50:00	\N	0.9	00:10:00	\N	0.7	-00:53:00	00:01:00	Oak Point, Penobscot River	ME
100811	Andrews Island, ESE of (depth 15 ft), West Penobscot Bay, Maine Current	NOS	ACT0381_1	43.99417	-69.013	:America/New_York	USA	knots	155	11	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:45:00	\N	0.6	-00:20:00	\N	0.6	-00:30:00	-00:32:00	Andrews Island, ESE of	ME
100812	Andrews Island, ESE of (depth 75 ft), West Penobscot Bay, Maine Current	NOS	ACT0381_2	43.99417	-69.013	:America/New_York	USA	knots	188	342	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:38:00	\N	0.6	-00:32:00	\N	1.2	-01:25:00	00:03:00	Andrews Island, ESE of	ME
100813	Little Hurricane Island, southwest of (depth 15 ft), West Penobscot Bay, Maine Current	NOS	ACT0386_1	44.023	-68.91783	:America/New_York	USA	knots	157	331	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	00:16:00	\N	0.7	-00:26:00	\N	0.7	-00:15:00	00:05:00	Little Hurricane Island, southwest of	ME
100814	Little Hurricane Island, southwest of (depth 40 ft), West Penobscot Bay, Maine Current	NOS	ACT0386_2	44.023	-68.91783	:America/New_York	USA	knots	125	300	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:06:00	\N	0.6	-00:11:00	\N	0.9	-00:28:00	-00:04:00	Little Hurricane Island, southwest of	ME
100815	Heron Neck, Green Island (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0391_1	44.02967	-68.873	:America/New_York	USA	knots	165	344	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:14:00	\N	0.6	-00:35:00	\N	1.5	-01:57:00	-00:35:00	Heron Neck, Green Island	ME
100816	Triangle Ledge, SSE of (depth 15 ft), Isle au Haut Bay, Maine Current	NOS	ACT0401_1	44.04117	-68.758	:America/New_York	USA	knots	197	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	00:12:00	\N	0.9	00:07:00	\N	1	00:04:00	-00:03:00	Triangle Ledge, SSE of	ME
100817	Triangle Ledge, SSE of (depth 40 ft), Isle au Haut Bay, Maine Current	NOS	ACT0401_2	44.04117	-68.758	:America/New_York	USA	knots	180	317	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:46:00	\N	0.6	-00:15:00	\N	0.9	-01:30:00	-00:09:00	Triangle Ledge, SSE of	ME
100818	Moore Harbor, W of (depth 15 ft), Isle au Haut Bay, Maine Current	NOS	ACT0406_1	44.04217	-68.6925	:America/New_York	USA	knots	135	344	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:09:00	\N	1	00:44:00	\N	0.6	-00:10:00	00:07:00	Moore Harbor, W of	ME
100819	Moore Harbor, W of (depth 75 ft), Isle au Haut Bay, Maine Current	NOS	ACT0406_2	44.04217	-68.6925	:America/New_York	USA	knots	165	337	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:25:00	\N	0.5	-00:31:00	\N	0.9	-01:43:00	-00:17:00	Moore Harbor, W of	ME
100820	Moore Harbor, W of (depth 120 ft), Isle au Haut Bay, Maine Current	NOS	ACT0406_3	44.04217	-68.6925	:America/New_York	USA	knots	215	345	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:50:00	\N	0.3	-00:19:00	\N	1	-02:44:00	-01:02:00	Moore Harbor, W of	ME
100821	The Reach, NNE of, Green Island (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0411_1	44.04283	-68.85967	:America/New_York	USA	knots	111	284	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-02:26:00	\N	0.4	-00:46:00	\N	0.6	-03:33:00	-01:32:00	The Reach, NNE of, Green Island	ME
100822	White Islands, northeast of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0416_1	44.05	-68.90667	:America/New_York	USA	knots	165	322	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:39:00	\N	0.6	-01:54:00	\N	0.6	-01:58:00	-01:32:00	White Islands, northeast of	ME
100823	Fisherman Island Passage (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0421_1	44.052	-69.045	:America/New_York	USA	knots	240	53	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:59:00	\N	0.6	-02:13:00	\N	0.9	-02:54:00	-02:03:00	Fisherman Island Passage	ME
100824	Crotch Island, east of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0426_1	44.06033	-68.90717	:America/New_York	USA	knots	163	343	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:40:00	\N	1.8	-00:31:00	\N	2.8	-00:59:00	-00:58:00	Crotch Island, east of	ME
100825	Laireys Island, south of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0431_1	44.06033	-68.89633	:America/New_York	USA	knots	155	335	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:22:00	\N	0.8	00:06:00	\N	0.6	-00:58:00	-00:28:00	Laireys Island, south of	ME
100826	Sheep Island (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0436_1	44.06467	-69.05783	:America/New_York	USA	knots	220	23	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:47:00	\N	0.7	-00:55:00	\N	0.7	-02:54:00	-01:34:00	Sheep Island	ME
100827	Leadbetter I., SSW of southern tip (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0441_1	44.06783	-68.89833	:America/New_York	USA	knots	126	320	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:03:00	\N	1.2	-00:15:00	\N	2.1	-00:53:00	-00:05:00	Leadbetter I., SSW of southern tip	ME
100828	Leadbetter Island, E of southern tip (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0446_1	44.06917	-68.89367	:America/New_York	USA	knots	175	0	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	00:16:00	\N	0.6	-00:19:00	\N	0.6	-00:28:00	01:00:00	Leadbetter Island, E of southern tip	ME
100829	Leadbetter Island, northwest tip of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0451_1	44.08383	-68.91117	:America/New_York	USA	knots	214	16	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:43:00	\N	0.9	-00:17:00	\N	1.2	-00:58:00	-00:30:00	Leadbetter Island, northwest tip of	ME
100830	Dodge Point-Monroe Island, between (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0456_1	44.08533	-69.04367	:America/New_York	USA	knots	205	15	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-02:38:00	\N	0.5	-01:19:00	\N	0.6	-03:53:00	-02:32:00	Dodge Point-Monroe Island, between	ME
100831	Dogfish Island, NNE of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0461_1	44.092	-68.91333	:America/New_York	USA	knots	147	325	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:37:00	\N	0.4	-02:03:00	\N	0.7	-02:24:00	-02:32:00	Dogfish Island, NNE of	ME
100832	Rockland Harbor Breakwater (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0466_1	44.10217	-69.07783	:America/New_York	USA	knots	97	315	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:10:00	\N	0.4	-00:06:00	\N	0.4	-01:28:00	-00:41:00	Rockland Harbor Breakwater	ME
100833	Browns Head, Vinalhaven Island, NNW of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0471_1	44.112998962402344	-68.91217041015625	:America/New_York	USA	knots	221	16	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:27:00	\N	0.2	-00:58:00	\N	0.3	-01:58:00	-00:32:00	Browns Head, Vinalhaven Island, NNW of	ME
101805	Frazier Point, west of, Winyah Bay, South Carolina Current	NOS	ACT6546_1	33.30967	-79.28667	:America/New_York	USA	knots	170	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:41:00	\N	1	02:19:00	\N	0.9	02:23:00	02:01:00	Frazier Point, west of	SC
100834	Crabtree Pt., North Haven I., NNE of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0476_1	44.115	-68.92367	:America/New_York	USA	knots	228	3	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:32:00	\N	0.2	-00:54:00	\N	0.4	-00:53:00	-00:32:00	Crabtree Pt., North Haven I., NNE of	ME
100835	Fox Island Thorofare (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0481_1	44.127	-68.893	:America/New_York	USA	knots	278	70	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-02:56:00	\N	0.4	-02:17:00	\N	0.3	-03:23:00	-03:02:00	Fox Island Thorofare	ME
100836	Mark Island, 0.3 nmi SSE of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0486_1	44.16667	-68.9805	:America/New_York	USA	knots	246	44	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:57:00	\N	0.5	-01:07:00	\N	0.6	-01:51:00	-01:36:00	Mark Island, 0.3 nmi., SSE of	ME
100837	Saddle Island, northwest of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0491_1	44.18083	-68.955	:America/New_York	USA	knots	225	10	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:44:00	\N	0.4	-02:07:00	\N	0.4	-03:53:00	-03:33:00	Saddle Island, northwest of	ME
100838	Lasell Island, SSW of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0501_1	44.18667	-68.947	:America/New_York	USA	knots	217	22	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:17:00	\N	0.4	-01:07:00	\N	0.6	-01:57:00	-02:31:00	Lasell Island, SSW of	ME
100839	East Goose Rock, NNE of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0506_1	44.1895	-68.968	:America/New_York	USA	knots	210	0	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-02:44:00	\N	0.4	-02:19:00	\N	0.6	-03:55:00	-03:34:00	East Goose Rock, NNE of	ME
100840	Camden Harbor entrance (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0511_1	44.20283	-69.04667	:America/New_York	USA	knots	190	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:27:00	\N	0.3	-03:42:00	\N	0.3	-02:54:00	-02:03:00	Camden Harbor Entrance	ME
100841	Ensign Island, SSE of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0516_1	44.22333	-68.95867	:America/New_York	USA	knots	220	22	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:56:00	\N	0.3	-00:36:00	\N	0.4	-01:40:00	00:55:00	Ensign Island, SSE of	ME
97848	Ngulu Atoll, Caroline Islands, FSM	NOS	TPT2639	8.300000190734863	137.48330688476562	:Pacific/Chuuk	FSM	feet	\N	\N	\N	Reference is in time zone :Pacific/Palau; offsets not adjusted	\N	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	94668	00:19:00	\N	0.77	00:40:00	\N	0.77	\N	\N	Ngulu Islands	FM
100842	Warren Island, northwest of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0521_1	44.27583	-68.95367	:America/New_York	USA	knots	248	36	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:44:00	\N	0.3	-00:28:00	\N	0.7	-02:27:00	-01:00:00	Warren Island, northwest of	ME
100843	Ducktrap Harbor, northeast of (depth 15 ft), West Penobscot Bay, Maine Current	NOS	ACT0526_1	44.3	-68.93967	:America/New_York	USA	knots	185	355	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:12:00	\N	0.4	-00:34:00	\N	0.7	-01:17:00	-01:00:00	Ducktrap Harbor, northeast of	ME
100844	Ducktrap Harbor, northeast of (depth 40 ft), West Penobscot Bay, Maine Current	NOS	ACT0526_2	44.3	-68.93967	:America/New_York	USA	knots	237	14	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:20:00	\N	0.3	-00:56:00	\N	0.6	-02:39:00	-01:24:00	Ducktrap Harbor, northeast of	ME
100845	Ducktrap Harbor, NNE of (depth 90 ft), West Penobscot Bay, Maine Current	NOS	ACT0531_1	44.3045	-68.95583	:America/New_York	USA	knots	203	14	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:04:00	\N	0.3	-00:04:00	\N	0.6	-01:09:00	00:04:00	Ducktrap Harbor, NNE of	ME
100846	Ducktrap Harbor, NNE of (depth 160 ft), West Penobscot Bay, Maine Current	NOS	ACT0531_2	44.3045	-68.95583	:America/New_York	USA	knots	233	38	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	00:02:00	\N	0.3	-00:05:00	\N	0.7	-01:12:00	00:13:00	Ducktrap Harbor, NNE of	ME
100847	Ducktrap Harbor, NNE of (depth 15 ft), West Penobscot Bay, Maine Current	NOS	ACT0536_1	44.305	-68.95917	:America/New_York	USA	knots	202	58	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:06:00	\N	0.5	00:11:00	\N	0.6	00:23:00	-00:33:00	Ducktrap Harbor, NNE of	ME
100848	Ducktrap Harbor, NNE of (depth 130 ft), West Penobscot Bay, Maine Current	NOS	ACT0536_2	44.305	-68.95917	:America/New_York	USA	knots	193	13	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:42:00	\N	0.5	-00:28:00	\N	0.9	-01:24:00	-00:25:00	Ducktrap Harbor, NNE of	ME
100849	Flat Island, SSW of (depth 14 ft), West Penobscot Bay, Maine Current	NOS	ACT0541_1	44.31383	-68.92417	:America/New_York	USA	knots	230	45	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:38:00	\N	0.4	00:01:00	\N	0.6	-01:23:00	-00:32:00	Flat Island, SSW of	ME
100850	Head of the Cape, 0.8 nmi W, of Penobscot Bay (depth 15 ft), Maine Current	NOS	ACT0546_1	44.32083	-68.84667	:America/New_York	USA	knots	125	325	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	00:01:00	\N	0.4	00:10:00	\N	0.6	-00:34:00	-00:01:00	Head of the Cape, 0.8 nmi. W, of Penobscot Bay	ME
100851	Head of the Cape, 0.8 nmi W, of Penobscot Bay (depth 130 ft), Maine Current	NOS	ACT0546_2	44.32083	-68.84667	:America/New_York	USA	knots	166	15	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:22:00	\N	0.3	-00:35:00	\N	0.6	-01:24:00	-00:18:00	Head of the Cape, 0.8 nmi. W, of Penobscot Bay	ME
100852	Head of the Cape, NNW of, Penobscot Bay (depth 15 ft), Maine Current	NOS	ACT0551_1	44.31783	-68.83617	:America/New_York	USA	knots	163	332	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:24:00	\N	0.4	-00:15:00	\N	0.9	-00:56:00	00:05:00	Head of the Cape, NNW of, Penobscot Bay	ME
100853	Head of the Cape, NNW of, Penobscot Bay (depth 30 ft), Maine Current	NOS	ACT0551_2	44.31783	-68.83617	:America/New_York	USA	knots	176	356	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:30:00	\N	0.3	-00:23:00	\N	0.7	-01:32:00	-00:01:00	Head of the Cape, NNW of, Penobscot Bay	ME
100854	Head of the Cape, NNW of, Penobscot Bay (depth 130 ft), Maine Current	NOS	ACT0551_3	44.31783	-68.83617	:America/New_York	USA	knots	172	353	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:30:00	\N	0.4	-00:56:00	\N	0.4	-01:09:00	-00:48:00	Head of the Cape, NNW of, Penobscot Bay	ME
100855	Ram Island, west of, West Penobscot Bay (depth 14 ft), Maine Current	NOS	ACT0556_1	44.35467	-68.91583	:America/New_York	USA	knots	189	4	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:47:00	\N	0.3	-01:31:00	\N	0.6	-03:53:00	-02:30:00	Ram Island, west of, West Penobscot Bay	ME
100856	Temple Heights, NE of, W Penobscot Bay (depth 15 ft), Maine Current	NOS	ACT0561_1	44.35633	-68.92217	:America/New_York	USA	knots	189	0	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:49:00	\N	0.4	-00:59:00	\N	0.6	-01:12:00	-01:40:00	Temple Heights, NE of, W Penobscot Bay	ME
100857	Temple Heights, NE of, W Penobscot Bay (depth 65 ft), Maine Current	NOS	ACT0561_2	44.35633	-68.92217	:America/New_York	USA	knots	175	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-01:04:00	\N	0.3	-00:48:00	\N	0.6	-01:56:00	-01:13:00	Temple Heights, NE of, W Penobscot Bay	ME
100858	Temple Heights, NNE of, W Penobscot Bay (depth 15 ft), Maine Current	NOS	ACT0566_1	44.3575	-68.94367	:America/New_York	USA	knots	175	5	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:36:00	\N	0.6	00:03:00	\N	0.9	-00:44:00	-00:12:00	Temple Heights, NNE of, W Penobscot Bay	ME
100859	Temple Heights, NNE of, W Penobscot Bay (depth 30 ft), Maine Current	NOS	ACT0566_2	44.3575	-68.94367	:America/New_York	USA	knots	188	344	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:14:00	\N	0.4	-00:02:00	\N	0.9	-01:01:00	00:08:00	Temple Heights, NNE of, W Penobscot Bay	ME
100860	Temple Heights, NNE of, W Penobscot Bay (depth 50 ft), Maine Current	NOS	ACT0566_3	44.3575	-68.94367	:America/New_York	USA	knots	164	333	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	-00:10:00	\N	0.5	-00:06:00	\N	0.7	-00:38:00	-00:24:00	Temple Heights, NNE of, W Penobscot Bay	ME
100861	Damariscotta River, off Cavis Point, Maine Current	NOS	ACT0576_1	43.875	-69.58332824707031	:America/New_York	USA	knots	215	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98132	-01:58:00	\N	0.49	-01:45:00	\N	0.31	-01:27:00	-02:10:00	Damariscotta River, off Cavis Point	ME
100862	Sheepscot River, off Barter Island, Maine Current	NOS	ACT0581_1	43.900001525878906	-69.6916732788086	:America/New_York	USA	knots	200	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98132	-01:13:00	\N	0.54	-02:13:00	\N	0.42	-01:26:00	-02:01:00	Sheepscot River, off Barter Island	ME
100863	Lowe Point, NE of, Sasanoa River, Maine Current	NOS	ACT0586_1	43.85166931152344	-69.72167205810547	:America/New_York	USA	knots	152	327	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98132	-01:07:00	\N	0.87	-01:02:00	\N	0.88	-01:26:00	-01:32:00	Lowe Point, NE of, Sasanoa River	ME
100864	Lower Hell Gate, Knubble Bay, Maine Current	NOS	ACT0591_1	43.876670837402344	-69.7300033569336	:America/New_York	USA	knots	155	290	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98132	-00:34:00	\N	1.7	-00:34:00	\N	1.56	-01:01:00	-01:32:00	Lower Hell Gate, Knubble Bay	ME
100865	Upper Hell Gate, Sasanoa River, Maine Current	NOS	ACT0596_1	43.89500045776367	-69.77166748046875	:America/New_York	USA	knots	142	307	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98132	01:23:00	\N	0.4	01:37:00	\N	0.52	02:53:00	00:34:00	Upper Hell Gate, Sasanoa River	ME
100866	Hunniwell Point, northeast of, Kennebec River, Maine Current	NOS	ACT0601_1	43.75667190551758	-69.78166961669922	:America/New_York	USA	knots	151	332	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98132	-00:16:00	\N	1.41	-00:59:00	\N	1.25	-00:33:00	-00:41:00	Hunniwell Point, northeast of	ME
100867	Bald Head, 0.3 mi southwest of, Kennebec River, Maine Current	NOS	ACT0606_1	43.80167007446289	-69.79332733154297	:America/New_York	USA	knots	153	321	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98132	-00:17:00	\N	1.12	-00:43:00	\N	0.83	-00:15:00	-00:50:00	Bald Head, 0.3 mile southwest of	ME
100868	Bluff Head, west of, Kennebec River, Maine Current	NOS	ACT0611_1	43.85499954223633	-69.79666900634766	:America/New_York	USA	knots	184	14	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98132	-00:16:00	\N	1.65	-00:18:00	\N	1.2	-00:05:00	-00:20:00	Bluff Head, west of	ME
100869	Fiddler Ledge, north of, Kennebec River, Maine Current	NOS	ACT0616_1	43.880001068115234	-69.79666900634766	:America/New_York	USA	knots	113	267	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98132	00:08:00	\N	1.26	00:01:00	\N	0.99	00:09:00	-00:24:00	Fiddler Ledge, north of	ME
100870	Doubling Point, south of, Kennebec River, Maine Current	NOS	ACT0621_1	43.880001068115234	-69.80667114257812	:America/New_York	USA	knots	127	300	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98132	00:13:00	\N	1.46	-00:22:00	\N	1.35	-00:10:00	-00:23:00	Doubling Point, south of	ME
100871	Lincoln Ledge, east of, Kennebec River, Maine Current	NOS	ACT0626_1	43.89667	-69.81	:America/New_York	USA	knots	174	359	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98084	01:31:00	\N	2.6	01:49:00	\N	2.8	01:42:00	01:48:00	Lincoln Ledge, east of	ME
100872	Odiornes Point, NNE of (depth 15 ft), Portsmouth Harbor, New Hampshire Current	NOS	ACT0686_1	43.04333	-70.705	:America/New_York	USA	knots	183	339	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99041	02:13:00	\N	0.6	01:54:00	\N	0.4	01:23:00	00:41:00	Odiornes Point, NNE of	NH
100889	Annisquam Harbor Light, Massachusetts Current	NOS	ACT0831_1	42.66833	-70.685	:America/New_York	USA	knots	13	200	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:09:00	\N	1.1	00:54:00	\N	0.8	00:33:00	00:53:00	Annisquam Harbor Light	MA
100873	Odiornes Point, northeast of (depth 15 ft), Portsmouth Harbor, New Hampshire Current	NOS	ACT0691_1	43.05	-70.70167	:America/New_York	USA	knots	156	320	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99041	01:03:00	\N	0.7	00:14:00	\N	0.5	00:09:00	00:29:00	Odiornes Point, northeast of	NH
100874	Whaleback Reef, west of (depth 15 ft), Portsmouth Harbor, New Hampshire Current	NOS	ACT0706_1	43.05833	-70.7045	:America/New_York	USA	knots	144	340	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99041	00:10:00	\N	1	00:27:00	\N	0.6	00:09:00	00:03:00	Whaleback Reef, west of	NH
100875	Wood Island, northwest of (depth 15 ft), Portsmouth Harbor, New Hampshire Current	NOS	ACT0716_1	43.06583	-70.705	:America/New_York	USA	knots	199	358	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99041	-00:44:00	\N	0.8	00:09:00	\N	1	00:12:00	00:23:00	Wood Island, northwest of	NH
100876	Salamander Point, north of (depth 15 ft), Portsmouth Harbor, Maine Current	NOS	ACT0726_1	43.07633	-70.717	:America/New_York	USA	knots	91	257	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99041	00:45:00	\N	0.6	00:44:00	\N	1.2	00:24:00	00:26:00	Salamander Point, north of	ME
100877	Clark Island, south of (depth 15 ft), Portsmouth Harbor, New Hampshire Current	NOS	ACT0731_1	43.07383	-70.72467	:America/New_York	USA	knots	85	270	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99041	00:31:00	\N	1.5	00:31:00	\N	1.4	00:33:00	00:28:00	Clark Island, south of	NH
100878	Clark Island, southwest of (depth 15 ft), Portsmouth Harbor, Maine Current	NOS	ACT0736_1	43.075	-70.72783	:America/New_York	USA	knots	70	263	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99041	-00:06:00	\N	0.6	-00:05:00	\N	0.6	00:31:00	00:26:00	Clark Island, southwest of	ME
100879	Henderson Point, SSW of (depth 15 ft), Portsmouth Harbor, New Hampshire Current	NOS	ACT0741_1	43.07333	-70.73867	:America/New_York	USA	knots	133	306	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99041	00:36:00	\N	1.2	01:20:00	\N	1.4	00:14:00	00:07:00	Henderson Point, SSW of	NH
100880	Shapleigh Island Bridge, south of, Portsmouth Harbor, New Hampshire Current	NOS	ACT0751_1	43.06967	-70.73833	:America/New_York	USA	knots	348	178	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99041	-00:37:00	\N	0.4	-00:18:00	\N	0.7	-00:40:00	-01:01:00	Shapleigh Island Bridge, south of	NH
100881	Pierces Island, northeast of (depth 15 ft), Portsmouth Harbor, New Hampshire Current	NOS	ACT0756_1	43.07583	-70.74133	:America/New_York	USA	knots	144	325	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99041	-00:21:00	\N	0.8	00:34:00	\N	2.4	-00:08:00	00:31:00	Pierces Island, northeast of	NH
100882	Dover Point, west of (depth 15 ft), New Hampshire Current	NOS	ACT0791_1	43.11917	-70.83717	:America/New_York	USA	knots	119	283	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99041	-00:02:00	\N	0.4	00:18:00	\N	1.2	00:07:00	00:23:00	Dover Point, west of	NH
100883	Goat Island, north of (depth 15 ft), New Hampshire Current	NOS	ACT0796_1	43.127	-70.85617	:America/New_York	USA	knots	77	272	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99041	00:49:00	\N	0.8	01:05:00	\N	1	00:52:00	00:20:00	Goat Island, north of	NH
100884	Goat Island and Fox Point, between (depth 15 ft), New Hampshire Current	NOS	ACT0801_1	43.12283	-70.857	:America/New_York	USA	knots	142	303	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99041	02:30:00	\N	0.4	01:39:00	\N	1	00:34:00	00:51:00	Goat Island and Fox Point, between	NH
100885	Knight Hill Township, west of (depth 15 ft), New Hampshire Current	NOS	ACT0806_1	43.10783	-70.85833	:America/New_York	USA	knots	15	205	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99041	00:21:00	\N	0.5	00:41:00	\N	0.6	00:39:00	00:54:00	Knight Hill Township, west of	NH
100886	Merrimack River entrance, Massachusetts Current	NOS	ACT0816_1	42.81833	-70.81	:America/New_York	USA	knots	105	285	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:46:00	\N	1.1	01:20:00	\N	1.7	00:55:00	01:08:00	Merrimack River entrance	MA
100887	Newburyport, Merrimack River, Massachusetts Current	NOS	ACT0821_1	42.81333	-70.86833	:America/New_York	USA	knots	98	288	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:23:00	\N	1.1	01:53:00	\N	1.2	01:19:00	01:42:00	Newburyport, Merrimack River	MA
100888	Plum Island Sound entrance, Massachusetts Current	NOS	ACT0826_1	42.705	-70.78833	:America/New_York	USA	knots	184	316	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:19:00	\N	1.2	00:55:00	\N	1.2	00:27:00	00:43:00	Plum Island Sound entrance	MA
100890	Gloucester Harbor entrance, Massachusetts Current	NOS	ACT0836_1	42.58167	-70.675	:America/New_York	USA	knots	195	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:48:00	\N	0.2	00:06:00	\N	0.2	-00:37:00	-00:34:00	Gloucester Harbor entrance	MA
100891	Blynman Canal ent., Gloucester Harbor, Massachusetts Current	NOS	ACT0841_1	42.61	-70.67333	:America/New_York	USA	knots	130	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:51:00	\N	2.7	00:10:00	\N	2.3	-00:15:00	-00:20:00	Blynman Canal ent., Gloucester Harbor	MA
100892	Nahant, 1.8 nmi NE of East Point (depth 10 ft), Massachusetts Current	NOS	ACT0906_1	42.43333	-70.867	:America/New_York	USA	knots	144	252	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:48:00	\N	0.1	00:54:00	\N	0.5	00:23:00	00:10:00	Nahant, 1.8 n.mi. NE of East Point	MA
100893	Nahant, 1.8 nmi NE of East Point (depth 45 ft), Massachusetts Current	NOS	ACT0906_2	42.43333	-70.867	:America/New_York	USA	knots	70	250	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:43:00	\N	0.2	01:09:00	\N	0.2	-00:30:00	01:09:00	Nahant, 1.8 n.mi. NE of East Point	MA
100894	Nahant, 1.8 nmi NE of East Point (depth 80 ft), Massachusetts Current	NOS	ACT0906_3	42.43333	-70.867	:America/New_York	USA	knots	77	238	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:43:00	\N	0.2	01:09:00	\N	0.2	-00:34:00	01:10:00	Nahant, 1.8 n.mi. NE of East Point	MA
100895	Nahant, 0.4 nmi east of East Point (depth 15 ft), Massachusetts Current	NOS	ACT0911_1	42.4205	-70.89383	:America/New_York	USA	knots	45	205	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:10:00	\N	0.5	-00:36:00	\N	0.4	-00:05:00	00:10:00	Nahant, 0.4 n.mi. east of East Point	MA
100896	Nahant, 0.4 nmi east of East Point (depth 25 ft), Massachusetts Current	NOS	ACT0911_2	42.4205	-70.89383	:America/New_York	USA	knots	27	198	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:17:00	\N	0.4	-00:21:00	\N	0.3	-00:06:00	00:03:00	Nahant, 0.4 n.mi. east of East Point	MA
100897	Nahant, 1 nmi SE of East Point (depth 45 ft), Massachusetts Current	NOS	ACT0916_1	42.39717	-70.85283	:America/New_York	USA	knots	74	253	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:13:00	\N	0.2	00:01:00	\N	0.2	-00:31:00	00:14:00	Nahant, 1 n.mi. SE of East Point	MA
100898	Nahant, 1 nmi SE of East Point (depth 70 ft), Massachusetts Current	NOS	ACT0916_2	42.39717	-70.85283	:America/New_York	USA	knots	90	261	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:02:00	\N	0.2	01:09:00	\N	0.2	-00:05:00	01:08:00	Nahant, 1 n.mi. SE of East Point	MA
100899	Pea Island, 0.4 nmi southeast of (depth 15 ft), Massachusetts Current	NOS	ACT0921_1	42.4105	-70.90217	:America/New_York	USA	knots	63	239	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:13:00	\N	0.4	01:00:00	\N	0.4	00:44:00	00:37:00	Pea Island, 0.4 n.mi. southeast of	MA
100900	Pea Island, 0.4 nmi southeast of (depth 25 ft), Massachusetts Current	NOS	ACT0921_2	42.4105	-70.90217	:America/New_York	USA	knots	48	224	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:17:00	\N	0.3	00:39:00	\N	0.4	00:25:00	00:52:00	Pea Island, 0.4 n.mi. southeast of	MA
100901	Pea Island, 0.4 nmi southeast of (depth 65 ft), Massachusetts Current	NOS	ACT0921_3	42.4105	-70.90217	:America/New_York	USA	knots	35	271	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:43:00	\N	0.3	-00:54:00	\N	0.3	-00:46:00	00:09:00	Pea Island, 0.4 n.mi. southeast of	MA
100902	Bass Point, 1.2 nmi southeast of (depth 10 ft), Massachusetts Current	NOS	ACT0926_1	42.402	-70.91783	:America/New_York	USA	knots	66	259	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:26:00	\N	0.6	01:25:00	\N	0.6	-00:31:00	00:53:00	Bass Point, 1.2 n.mi. southeast of	MA
100903	Bass Point, 1.2 nmi southeast of (depth 45 ft), Massachusetts Current	NOS	ACT0926_2	42.402	-70.91783	:America/New_York	USA	knots	86	251	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:41:00	\N	0.2	-00:05:00	\N	0.3	-00:38:00	00:47:00	Bass Point, 1.2 n.mi. southeast of	MA
100904	Bass Point, 1.2 nmi southeast of (depth 60 ft), Massachusetts Current	NOS	ACT0926_3	42.402	-70.91783	:America/New_York	USA	knots	91	250	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:11:00	\N	0.2	-00:05:00	\N	0.2	-00:38:00	00:26:00	Bass Point, 1.2 n.mi. southeast of	MA
100905	Little Nahant Cupola, 0.6 nmi west of (depth 10 ft), Massachusetts Current	NOS	ACT0941_1	42.43117	-70.94717	:America/New_York	USA	knots	219	33	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:34:00	\N	0.4	-00:21:00	\N	0.3	-00:11:00	01:27:00	Little Nahant Cupola, 0.6 n.mi. west of	MA
100906	Sand Point, Black Marsh Channel (depth 10 ft), Massachusetts Current	NOS	ACT0946_1	42.443	-70.942	:America/New_York	USA	knots	203	13	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:15:00	\N	0.4	-00:12:00	\N	0.4	-00:05:00	01:15:00	Sand Point, Black Marsh Channel	MA
100907	Lynn Harbor (depth 10 ft), Massachusetts Current	NOS	ACT0951_1	42.4545	-70.94633	:America/New_York	USA	knots	90	274	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	01:12:00	\N	0.2	-00:21:00	\N	0.2	00:20:00	02:30:00	Lynn Harbor	MA
100908	Point of Pines, 0.5 nmi south of (depth 6 ft), Massachusetts Current	NOS	ACT0956_1	42.43283	-70.95883	:America/New_York	USA	knots	198	9	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:29:00	\N	0.5	00:24:00	\N	0.4	-00:04:00	01:03:00	Point of Pines, 0.5 n.mi. south of	MA
100909	Point of Pines, 0.1 nmi northeast of (depth 6 ft), Massachusetts Current	NOS	ACT0961_1	42.442	-70.96033	:America/New_York	USA	knots	131	296	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:22:00	\N	1	00:24:00	\N	0.7	00:34:00	00:45:00	Point of Pines, 0.1 n.mi. northeast of	MA
100910	Finn's Ledge Bell, 0.2 nmi west of (depth 10 ft), Massachusetts Current	NOS	ACT0966_1	42.3695	-70.92367	:America/New_York	USA	knots	35	226	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:14:00	\N	0.6	01:10:00	\N	0.4	-00:10:00	00:21:00	Finn's Ledge Bell, 0.2 n.mi. west of	MA
100911	Finn's Ledge Bell, 0.2 nmi west of (depth 25 ft), Massachusetts Current	NOS	ACT0966_2	42.3695	-70.92367	:America/New_York	USA	knots	33	229	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:16:00	\N	0.4	00:55:00	\N	0.3	-00:20:00	00:31:00	Finn's Ledge Bell, 0.2 n.mi. west of	MA
100912	Winthrop Head, 1.1 nmi east of (depth 10 ft), Massachusetts Current	NOS	ACT0971_1	42.3655	-70.942	:America/New_York	USA	knots	19	205	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:58:00	\N	0.3	00:24:00	\N	0.4	-01:21:00	00:26:00	Winthrop Head, 1.1 n.mi. east of	MA
100913	The Graves, 0.3 nmi SSE of (depth 10 ft), Massachusetts Current	NOS	ACT1026_1	42.36	-70.86667	:America/New_York	USA	knots	103	227	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:07:00	\N	0.5	01:13:00	\N	0.5	00:07:00	01:16:00	The Graves, 0.3 n.mi. SSE of	MA
100914	The Graves, 0.3 nmi SSE of (depth 45 ft), Massachusetts Current	NOS	ACT1026_2	42.36	-70.86667	:America/New_York	USA	knots	85	262	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:10:00	\N	0.4	-00:47:00	\N	0.3	-00:46:00	-00:15:00	The Graves, 0.3 n.mi. SSE of	MA
100915	The Graves, 0.3 nmi SSE of (depth 60 ft), Massachusetts Current	NOS	ACT1026_3	42.36	-70.86667	:America/New_York	USA	knots	70	252	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:35:00	\N	0.3	-00:47:00	\N	0.2	-00:58:00	-00:21:00	The Graves, 0.3 n.mi. SSE of	MA
100916	Thieves Ledge (depth 45 ft), Massachusetts Current	NOS	ACT1031_1	42.32133	-70.838	:America/New_York	USA	knots	128	304	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:49:00	\N	0.2	-00:01:00	\N	0.2	-00:24:00	-00:45:00	Thieves Ledge	MA
100917	Little Brewster Island, 1.5 nmi E of (depth 10 ft), Massachusetts Current	NOS	ACT1036_1	42.328	-70.85717	:America/New_York	USA	knots	80	285	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:43:00	\N	0.9	00:46:00	\N	0.5	02:10:00	-00:45:00	Little Brewster Island, 1.5 n.mi. E of	MA
100918	Little Brewster Island, 1.5 nmi E of (depth 35 ft), Massachusetts Current	NOS	ACT1036_2	42.328	-70.85717	:America/New_York	USA	knots	76	236	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	01:15:00	\N	0.4	-00:44:00	\N	0.3	00:44:00	-00:02:00	Little Brewster Island, 1.5 n.mi. E of	MA
100919	Little Brewster Island, 1.5 nmi E of (depth 60 ft), Massachusetts Current	NOS	ACT1036_3	42.328	-70.85717	:America/New_York	USA	knots	47	225	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:57:00	\N	0.2	-01:18:00	\N	0.2	-01:23:00	01:26:00	Little Brewster Island, 1.5 n.mi. E of	MA
100920	Hypocrite Channel (depth 10 ft), Massachusetts Current	NOS	ACT1041_1	42.34917	-70.89383	:America/New_York	USA	knots	70	262	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:43:00	\N	0.8	00:24:00	\N	0.7	00:04:00	00:44:00	Hypocrite Channel	MA
100921	Little Calf Island, 0.4 nmi NW of (depth 10 ft), Massachusetts Current	NOS	ACT1046_1	42.35083	-70.9	:America/New_York	USA	knots	48	220	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:30:00	\N	0.6	00:09:00	\N	0.4	00:14:00	-00:20:00	Little Calf Island, 0.4 n.mi. NW of	MA
100922	Boston Light, 0.2 nmi south of (depth 10 ft), Massachusetts Current	NOS	ACT1051_1	42.32533	-70.89	:America/New_York	USA	knots	100	267	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:28:00	\N	1.1	00:24:00	\N	0.8	00:05:00	00:36:00	Boston Light, 0.2 n.mi. south of	MA
100923	Point Allerton, 0.4 nmi northwest of (depth 10 ft), Massachusetts Current	NOS	ACT1061_1	42.31467	-70.88717	:America/New_York	USA	knots	80	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:23:00	\N	0.7	00:58:00	\N	0.5	-00:18:00	00:12:00	Point Allerton, 0.4 n.mi. northwest of	MA
100924	Calf Island, 0.4 nmi west of (depth 10 ft), Massachusetts Current	NOS	ACT1066_1	42.33883	-70.90633	:America/New_York	USA	knots	37	198	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:01:00	\N	0.5	00:28:00	\N	0.4	00:07:00	00:05:00	Calf Island, 0.4 n.mi. west of	MA
100925	Calf Island, 0.4 nmi west of (depth 25 ft), Massachusetts Current	NOS	ACT1066_2	42.33883	-70.90633	:America/New_York	USA	knots	52	203	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:48:00	\N	0.3	00:05:00	\N	0.4	-00:37:00	00:11:00	Calf Island, 0.4 n.mi. west of	MA
100926	Calf Island, 0.4 nmi west of (depth 45 ft), Massachusetts Current	NOS	ACT1066_3	42.33883	-70.90633	:America/New_York	USA	knots	20	209	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-02:27:00	\N	0.3	00:09:00	\N	0.3	-01:37:00	00:00:00	Calf Island, 0.4 n.mi. west of	MA
100927	Black Rock Channel (depth 10 ft), Massachusetts Current	NOS	ACT1081_1	42.32883	-70.9155	:America/New_York	USA	knots	46	247	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:13:00	\N	0.8	-00:06:00	\N	0.5	-00:17:00	00:19:00	Black Rock Channel	MA
100928	Deer Island Light, 0.4 nmi NW of (depth 35 ft), Massachusetts Current	NOS	ACT1086_1	42.343	-70.92833	:America/New_York	USA	knots	116	307	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:58:00	\N	0.5	-02:05:00	\N	0.2	-00:24:00	-04:16:00	Deer Island Light, 0.4 n.mi. NW of	MA
100929	Lovell Island, 0.4 nmi north of (depth 10 ft), Massachusetts Current	NOS	ACT1091_1	42.34083	-70.93	:America/New_York	USA	knots	64	259	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:41:00	\N	1	-00:06:00	\N	0.9	00:00:00	00:17:00	Lovell Island, 0.4 n.mi. north of	MA
100930	Lovell Island, 0.4 nmi north of (depth 25 ft), Massachusetts Current	NOS	ACT1091_2	42.34083	-70.93	:America/New_York	USA	knots	74	264	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:23:00	\N	0.8	-00:09:00	\N	0.9	-00:17:00	00:21:00	Lovell Island, 0.4 n.mi. north of	MA
100931	Deer Island Light, 0.8 nmi ESE of (depth 10 ft), Massachusetts Current	NOS	ACT1101_1	42.337	-70.938	:America/New_York	USA	knots	66	233	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:35:00	\N	0.8	-00:15:00	\N	0.7	-00:13:00	00:15:00	Deer Island Light, 0.8 n.mi. ESE of	MA
100932	Deer Island Light, 0.4 nmi east of (depth 10 ft), Massachusetts Current	NOS	ACT1106_1	42.34083	-70.94617	:America/New_York	USA	knots	57	240	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:28:00	\N	0.8	-01:08:00	\N	0.7	-00:01:00	00:12:00	Deer Island Light, 0.4 n.mi. east of	MA
100933	Deer Island Light, 0.4 nmi east of (depth 35 ft), Massachusetts Current	NOS	ACT1106_2	42.34083	-70.94617	:America/New_York	USA	knots	53	264	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:04:00	\N	0.6	00:57:00	\N	0.9	-00:41:00	00:39:00	Deer Island Light, 0.4 n.mi. east of	MA
100934	Deer Island Light, 0.7 nmi ESE of (depth 35 ft), Massachusetts Current	NOS	ACT1111_1	42.3375	-70.93967	:America/New_York	USA	knots	62	233	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:13:00	\N	0.5	-00:05:00	\N	0.7	-00:32:00	00:20:00	Deer Island Light, 0.7 n.mi. ESE of	MA
100935	Deer Island Light, 0.3 nmi SSE of (depth 10 ft), Massachusetts Current	NOS	ACT1121_1	42.33533	-70.957	:America/New_York	USA	knots	82	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:16:00	\N	0.9	00:49:00	\N	1.1	-00:07:00	00:10:00	Deer Island Light, 0.3 n.mi. SSE of	MA
100936	Deer Island Light, 0.3 nmi SSE of (depth 35 ft), Massachusetts Current	NOS	ACT1121_2	42.33533	-70.957	:America/New_York	USA	knots	90	261	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:16:00	\N	0.8	00:51:00	\N	1.1	-00:20:00	00:44:00	Deer Island Light, 0.3 n.mi. SSE of	MA
101081	Weepecket Island, south of, Buzzards Bay, Massachusetts Current	NOS	ACT1951_1	41.50667	-70.73833	:America/New_York	USA	knots	255	69	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98261	-03:03:00	\N	0.2	-02:25:00	\N	0.4	-04:40:00	-02:28:00	Weepecket Island, south of	MA
100937	Deer Island Light, 0.4 nmi SSE of (depth 10 ft), Massachusetts Current	NOS	ACT1126_1	42.33283	-70.957	:America/New_York	USA	knots	73	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:18:00	\N	0.9	00:58:00	\N	1.2	-00:03:00	00:38:00	Deer Island Light, 0.4 n.mi. SSE of	MA
100938	Deer Island Light, 0.4 nmi SSE of (depth 25 ft), Massachusetts Current	NOS	ACT1126_2	42.33283	-70.957	:America/New_York	USA	knots	81	269	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:21:00	\N	0.9	00:52:00	\N	1.1	-00:11:00	00:47:00	Deer Island Light, 0.4 n.mi. SSE of	MA
100939	Deer Island, southwest of (depth 10 ft), Massachusetts Current	NOS	ACT1131_1	42.34383	-70.963	:America/New_York	USA	knots	137	351	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:20:00	\N	0.5	-00:21:00	\N	0.3	-00:05:00	-02:03:00	Deer Island, southwest of	MA
100940	Long Island Head, 0.9 nmi NW of (depth 10 ft), Massachusetts Current	NOS	ACT1136_1	42.34	-70.97383	:America/New_York	USA	knots	103	302	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:56:00	\N	0.5	00:35:00	\N	0.5	-00:17:00	-00:04:00	Long Island Head, 0.9 n.mi. NW of	MA
100941	Long Island Head, 0.9 nmi NW of (depth 35 ft), Massachusetts Current	NOS	ACT1136_2	42.34	-70.97383	:America/New_York	USA	knots	79	304	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:21:00	\N	0.3	01:26:00	\N	0.4	-00:10:00	00:45:00	Long Island Head, 0.9 n.mi. NW of	MA
100942	Deer Island Flats (depth 10 ft), Massachusetts Current	NOS	ACT1141_1	42.34717	-70.9775	:America/New_York	USA	knots	107	327	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-03:16:00	\N	0.4	-01:06:00	\N	0.4	-00:36:00	-01:37:00	Deer Island Flats	MA
100943	Snake Island, southwest of (depth 10 ft), Massachusetts Current	NOS	ACT1151_1	42.36283	-70.987	:America/New_York	USA	knots	134	312	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:01:00	\N	0.4	00:24:00	\N	0.3	-00:14:00	00:26:00	Snake Island, southwest of	MA
100944	Deer Island Light, 1.0 nmi WSW of (depth 10 ft), Massachusetts Current	NOS	ACT1156_1	42.33283	-70.97383	:America/New_York	USA	knots	86	254	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:53:00	\N	0.7	01:13:00	\N	1	00:43:00	02:05:00	Deer Island Light, 1.0 n.mi. WSW of	MA
100945	Deer Island Light, 1.0 nmi WSW of (depth 35 ft), Massachusetts Current	NOS	ACT1156_2	42.33283	-70.97383	:America/New_York	USA	knots	82	273	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:11:00	\N	0.3	01:38:00	\N	1	-00:05:00	01:41:00	Deer Island Light, 1.0 n.mi. WSW of	MA
100946	Spectacle I. and Long I., between (depth 10 ft), Massachusetts Current	NOS	ACT1161_1	42.3225	-70.97417	:America/New_York	USA	knots	38	217	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:34:00	\N	0.5	00:09:00	\N	0.4	-00:13:00	-00:39:00	Spectacle I. and Long I., between	MA
100947	Spectacle Island, 0.2 nmi south of (depth 10 ft), Massachusetts Current	NOS	ACT1166_1	42.31633	-70.98583	:America/New_York	USA	knots	98	244	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:58:00	\N	0.4	-01:00:00	\N	0.4	-00:22:00	-00:57:00	Spectacle Island, 0.2 n.mi. south of	MA
100948	Spectacle I. and Thompson I., between (depth 10 ft), Massachusetts Current	NOS	ACT1176_1	42.32083	-70.99283	:America/New_York	USA	knots	127	306	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-03:08:00	\N	0.3	-03:49:00	\N	0.2	-01:49:00	-02:35:00	Spectacle I. and Thompson I., between	MA
100949	Thompson Island, 0.7 nmi NNE of (depth 10 ft), Massachusetts Current	NOS	ACT1181_1	42.33283	-70.99833	:America/New_York	USA	knots	86	281	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:32:00	\N	0.5	01:36:00	\N	0.6	-00:37:00	01:05:00	Thompson Island, 0.7 n.mi. NNE of	MA
100950	Thompson Island, 0.7 nmi NNE of (depth 35 ft), Massachusetts Current	NOS	ACT1181_2	42.33283	-70.99833	:America/New_York	USA	knots	91	277	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:52:00	\N	0.2	01:36:00	\N	0.4	-01:13:00	00:43:00	Thompson Island, 0.7 n.mi. NNE of	MA
100951	Fort Independence, 0.3 nmi east of (depth 10 ft), Massachusetts Current	NOS	ACT1191_1	42.33883	-71.00367	:America/New_York	USA	knots	125	303	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	01:00:00	\N	0.5	01:36:00	\N	0.5	00:27:00	01:25:00	Fort Independence, 0.3 n.mi. east of	MA
100967	Georges Island, north of (depth 25 ft), Massachusetts Current	NOS	ACT1281_1	42.32367	-70.92783	:America/New_York	USA	knots	112	298	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:58:00	\N	0.8	-01:36:00	\N	0.6	-01:34:00	-00:06:00	Georges Island, north of	MA
100952	South Boston, Pier 4, 0.2 nmi NNE of (depth 10 ft), Massachusetts Current	NOS	ACT1206_1	42.35217	-71.03083	:America/New_York	USA	knots	118	299	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	01:01:00	\N	0.3	01:01:00	\N	0.2	00:29:00	00:11:00	South Boston, Pier 4, 0.2 n.mi. NNE of	MA
100953	South Boston, Pier 4, 0.2 nmi NNE of (depth 25 ft), Massachusetts Current	NOS	ACT1206_2	42.35217	-71.03083	:America/New_York	USA	knots	120	30	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:03:00	\N	0.1	00:24:00	\N	0.3	-00:23:00	01:37:00	South Boston, Pier 4, 0.2 n.mi. NNE of	MA
100954	East Boston, Pier 10, southeast of (depth 10 ft), Massachusetts Current	NOS	ACT1216_1	42.37583	-71.04667	:America/New_York	USA	knots	194	17	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:04:00	\N	0.3	00:55:00	\N	0.2	01:26:00	00:23:00	East Boston, Pier 10, southeast of	MA
100955	East Boston, Pier 10, southeast of (depth 25 ft), Massachusetts Current	NOS	ACT1216_2	42.37583	-71.04667	:America/New_York	USA	knots	193	30	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:39:00	\N	0.2	01:10:00	\N	0.3	-00:08:00	01:18:00	East Boston, Pier 10, southeast of	MA
100956	Chelsea River, west of bascule bridge (depth 10 ft), Massachusetts Current	NOS	ACT1226_1	42.3845	-71.04217	:America/New_York	USA	knots	240	48	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:58:00	\N	0.2	-00:21:00	\N	0.2	-00:07:00	00:38:00	Chelsea River, west of bascule bridge	MA
100957	Chelsea River, below bascule bridge (depth 10 ft), Massachusetts Current	NOS	ACT1231_1	42.38383	-71.02833	:America/New_York	USA	knots	272	88	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:16:00	\N	0.2	-00:10:00	\N	0.2	00:20:00	00:32:00	Chelsea River, below bascule bridge	MA
100958	Mystic River Bridge, 0.1 nmi west of (depth 10 ft), Massachusetts Current	NOS	ACT1236_1	42.38583	-71.05033	:America/New_York	USA	knots	93	267	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:28:00	\N	0.1	-00:05:00	\N	0.1	00:22:00	-00:51:00	Mystic River Bridge, 0.1 n.mi. west of	MA
100959	Mystic River Bridge, northwest of (depth 10 ft), Massachusetts Current	NOS	ACT1241_1	42.38583	-71.04917	:America/New_York	USA	knots	98	300	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:56:00	\N	0.1	01:09:00	\N	0.1	-00:29:00	00:17:00	Mystic River Bridge, northwest of	MA
100960	City Point, 0.8 nmi SSE of (depth 10 ft), Massachusetts Current	NOS	ACT1246_1	42.32033	-71.01467	:America/New_York	USA	knots	69	248	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:51:00	\N	0.5	00:39:00	\N	0.5	00:04:00	01:14:00	City Point, 0.8 n.mi. SSE of	MA
100961	Squantum Point, 0.8 nmi northeast of (depth 10 ft), Massachusetts Current	NOS	ACT1251_1	42.3105	-71.02833	:America/New_York	USA	knots	36	216	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:39:00	\N	0.4	00:40:00	\N	0.3	00:09:00	01:11:00	Squantum Point, 0.8 n.mi. northeast of	MA
100962	Squantum Point, 0.4 nmi NNE of (depth 10 ft), Massachusetts Current	NOS	ACT1256_1	42.30633	-71.03717	:America/New_York	USA	knots	91	266	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:40:00	\N	0.4	-00:01:00	\N	0.3	00:05:00	00:36:00	Squantum Point, 0.4 n.mi. NNE of	MA
100963	Neponset River (depth 10 ft), Massachusetts Current	NOS	ACT1261_1	42.30417	-71.043	:America/New_York	USA	knots	25	218	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:23:00	\N	0.4	-00:27:00	\N	0.3	-00:34:00	00:40:00	Neponset River	MA
100964	Lovell Island, 0.1 nmi south of (depth 10 ft), Massachusetts Current	NOS	ACT1271_1	42.32333	-70.92467	:America/New_York	USA	knots	92	275	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:05:00	\N	0.9	-01:49:00	\N	0.6	-00:01:00	-00:35:00	Lovell Island, 0.1 n.mi. south of	MA
100965	Lovell Island, 0.1 nmi south of (depth 24 ft), Massachusetts Current	NOS	ACT1271_2	42.32333	-70.92467	:America/New_York	USA	knots	95	294	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:13:00	\N	0.7	-02:12:00	\N	0.6	-00:34:00	-00:25:00	Lovell Island, 0.1 n.mi. south of	MA
100966	Georges Island, northeast of (depth 10 ft), Massachusetts Current	NOS	ACT1276_1	42.32283	-70.9255	:America/New_York	USA	knots	100	279	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-02:22:00	\N	0.6	-01:42:00	\N	0.6	-00:22:00	-00:34:00	Georges Island, northeast of	MA
101031	Tuckernuck Island, 4.2 mi SSW of, Massachusetts Current	NOS	ACT1601_1	41.22617	-70.28167	:America/New_York	USA	knots	280	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	03:56:00	\N	0.6	03:13:00	\N	0.3	04:08:00	02:17:00	Tuckernuck Island, 4.2 miles SSW of	MA
100968	Gallops Island, 0.2 nmi SSE of (depth 10 ft), Massachusetts Current	NOS	ACT1286_1	42.323	-70.93217	:America/New_York	USA	knots	62	243	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:09:00	\N	0.8	00:21:00	\N	0.9	-00:08:00	-00:04:00	Gallops Island, 0.2 n.mi. SSE of	MA
100969	Gallops Island, 0.1 nmi southeast of (depth 10 ft), Massachusetts Current	NOS	ACT1291_1	42.32417	-70.93167	:America/New_York	USA	knots	63	225	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:15:00	\N	0.9	-00:33:00	\N	0.7	-00:10:00	-00:01:00	Gallops Island, 0.1 n.mi. southeast of	MA
100970	Gallops Island, 0.1 nmi southeast of (depth 35 ft), Massachusetts Current	NOS	ACT1291_2	42.32417	-70.93167	:America/New_York	USA	knots	52	255	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:15:00	\N	0.7	-00:38:00	\N	0.8	-00:07:00	00:17:00	Gallops Island, 0.1 n.mi. southeast of	MA
100971	Gallops Island, The Narrows (depth 20 ft), Massachusetts Current	NOS	ACT1296_1	42.327	-70.93383	:America/New_York	USA	knots	262	135	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:58:00	\N	0.1	-00:06:00	\N	0.4	-01:34:00	01:08:00	Gallops Island, The Narrows	MA
100972	Lovell Island, west of (depth 10 ft), Massachusetts Current	NOS	ACT1306_1	42.32867	-70.93283	:America/New_York	USA	knots	299	134	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:17:00	\N	1	-00:21:00	\N	0.4	00:07:00	00:44:00	Lovell Island, west of	MA
100973	Lovell Island, west of (depth 24 ft), Massachusetts Current	NOS	ACT1306_2	42.32867	-70.93283	:America/New_York	USA	knots	313	136	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:10:00	\N	1	00:19:00	\N	0.3	-00:13:00	01:17:00	Lovell Island, west of	MA
100974	Georges Island, 0.5 nmi ESE of (depth 10 ft), Massachusetts Current	NOS	ACT1316_1	42.3195	-70.91617	:America/New_York	USA	knots	65	244	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:01:00	\N	1	00:51:00	\N	0.8	00:23:00	00:55:00	Georges Island, 0.5 n.mi. ESE of	MA
100975	Georges Island, 0.4 nmi east of (depth 10 ft), Massachusetts Current	NOS	ACT1321_1	42.31867	-70.91617	:America/New_York	USA	knots	57	248	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:23:00	\N	0.9	00:09:00	\N	0.8	-00:26:00	00:03:00	Georges Island, 0.4 n.mi. east of	MA
100976	Georges Island, 0.3 nmi SSE of (depth 10 ft), Massachusetts Current	NOS	ACT1331_1	42.313	-70.92583	:America/New_York	USA	knots	69	234	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:29:00	\N	1	00:29:00	\N	0.9	00:12:00	00:29:00	Georges Island, 0.3 n.mi. SSE of	MA
100977	Georges Island, 0.3 nmi SSE of (depth 35 ft), Massachusetts Current	NOS	ACT1331_2	42.313	-70.92583	:America/New_York	USA	knots	73	237	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:10:00	\N	0.7	00:40:00	\N	0.8	-00:01:00	00:53:00	Georges Island, 0.3 n.mi. SSE of	MA
100978	Georges Island, 0.4 nmi SSE of (depth 10 ft), Massachusetts Current	NOS	ACT1336_1	42.31117	-70.9255	:America/New_York	USA	knots	46	236	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-02:15:00	\N	0.8	00:58:00	\N	1	00:07:00	00:27:00	Georges Island, 0.4 n.mi. SSE of	MA
100979	Georges Island, 0.4 nmi SSE of (depth 35 ft), Massachusetts Current	NOS	ACT1336_2	42.31117	-70.9255	:America/New_York	USA	knots	65	240	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:12:00	\N	0.8	01:01:00	\N	1	00:05:00	00:51:00	Georges Island, 0.4 n.mi. SSE of	MA
100980	Nubble Channel (depth 10 ft), Massachusetts Current	NOS	ACT1341_1	42.32883	-70.94883	:America/New_York	USA	knots	6	187	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:31:00	\N	0.6	00:50:00	\N	0.6	-00:21:00	00:40:00	Nubble Channel	MA
100981	Peddocks Island, 0.2 nmi north of (depth 10 ft), Massachusetts Current	NOS	ACT1356_1	42.30533	-70.93333	:America/New_York	USA	knots	257	246	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:41:00	\N	0.6	01:27:00	\N	0.8	00:28:00	01:15:00	Peddocks Island, 0.2 n.mi. north of	MA
100982	Peddocks Island, 0.2 nmi north of (depth 25 ft), Massachusetts Current	NOS	ACT1356_2	42.30533	-70.93333	:America/New_York	USA	knots	60	255	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:05:00	\N	0.5	01:09:00	\N	0.8	-00:02:00	01:25:00	Peddocks Island, 0.2 n.mi. north of	MA
100983	Peddocks Island, 0.3 nmi northwest of (depth 10 ft), Massachusetts Current	NOS	ACT1361_1	42.30667	-70.9355	:America/New_York	USA	knots	60	245	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:44:00	\N	0.8	01:30:00	\N	0.9	00:42:00	01:20:00	Peddocks Island, 0.3 n.mi. northwest of	MA
100984	Peddocks Island, 0.3 nmi northwest of (depth 25 ft), Massachusetts Current	NOS	ACT1361_2	42.30667	-70.9355	:America/New_York	USA	knots	55	250	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:03:00	\N	0.5	01:14:00	\N	0.8	00:12:00	01:27:00	Peddocks Island, 0.3 n.mi. northwest of	MA
100985	Peddocks Island, 0.3 nmi northwest of (depth 40 ft), Massachusetts Current	NOS	ACT1361_3	42.30667	-70.9355	:America/New_York	USA	knots	60	261	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:59:00	\N	0.4	01:11:00	\N	0.8	-00:17:00	01:40:00	Peddocks Island, 0.3 n.mi. northwest of	MA
100986	Rainsford I. and Windmill Pt., between (depth 10 ft), Massachusetts Current	NOS	ACT1366_1	42.30867	-70.93867	:America/New_York	USA	knots	56	251	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:34:00	\N	0.8	00:59:00	\N	0.6	00:28:00	00:29:00	Rainsford I. and Windmill Pt., between	MA
100987	Rainsford I. and Windmill Pt., between (depth 25 ft), Massachusetts Current	NOS	ACT1366_2	42.30867	-70.93867	:America/New_York	USA	knots	53	256	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:07:00	\N	0.4	01:24:00	\N	0.6	00:13:00	01:31:00	Rainsford I. and Windmill Pt., between	MA
100988	Gallops Island, 0.5 nmi southwest of (depth 10 ft), Massachusetts Current	NOS	ACT1371_1	42.31883	-70.947	:America/New_York	USA	knots	74	238	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:35:00	\N	0.6	00:19:00	\N	0.5	00:41:00	-01:02:00	Gallops Island, 0.5 n.mi. southwest of	MA
100989	Gallops Island, 0.5 nmi southwest of (depth 25 ft), Massachusetts Current	NOS	ACT1371_2	42.31883	-70.947	:America/New_York	USA	knots	72	237	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:58:00	\N	0.3	00:22:00	\N	0.4	00:08:00	-00:33:00	Gallops Island, 0.5 n.mi. southwest of	MA
100990	Rainsford Island, 0.2 nmi NE of (depth 10 ft), Massachusetts Current	NOS	ACT1376_1	42.315	-70.94917	:America/New_York	USA	knots	84	239	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:13:00	\N	0.4	00:23:00	\N	0.4	-00:26:00	00:14:00	Rainsford Island, 0.2 n.mi. NE of	MA
100991	Rainsford Island, 0.2 nmi NE of (depth 20 ft), Massachusetts Current	NOS	ACT1376_2	42.315	-70.94917	:America/New_York	USA	knots	86	237	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:24:00	\N	0.2	00:46:00	\N	0.4	-02:01:00	00:12:00	Rainsford Island, 0.2 n.mi. NE of	MA
100992	Rainsford Island, 0.4 nmi SE of (depth 10 ft), Massachusetts Current	NOS	ACT1381_1	42.30833	-70.94367	:America/New_York	USA	knots	55	225	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:11:00	\N	0.6	-00:44:00	\N	0.5	-00:08:00	00:57:00	Rainsford Island, 0.4 n.mi. SE of	MA
100993	Long I. and Rainsford I., between (depth 10 ft), Massachusetts Current	NOS	ACT1386_1	42.31167	-70.963	:America/New_York	USA	knots	49	226	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:43:00	\N	0.7	00:18:00	\N	0.6	00:22:00	00:34:00	Long I. and Rainsford I., between	MA
100994	Long I. and Rainsford I., between (depth 25 ft), Massachusetts Current	NOS	ACT1386_2	42.31167	-70.963	:America/New_York	USA	knots	33	229	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:13:00	\N	0.6	00:43:00	\N	0.5	00:13:00	00:38:00	Long I. and Rainsford I., between	MA
100995	West Head, Peddocks I., 0.1 nmi W of (depth 10 ft), Massachusetts Current	NOS	ACT1391_1	42.29083	-70.95367	:America/New_York	USA	knots	18	208	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:16:00	\N	0.7	01:02:00	\N	0.8	-01:30:00	01:24:00	West Head, Peddocks I., 0.1 n.mi. W of	MA
100996	West Head, Peddocks I., 0.1 nmi W of (depth 30 ft), Massachusetts Current	NOS	ACT1391_2	42.29083	-70.95367	:America/New_York	USA	knots	38	198	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:00:00	\N	0.5	01:08:00	\N	0.7	-01:35:00	01:15:00	West Head, Peddocks I., 0.1 n.mi. W of	MA
100997	Sunken Ledge, 0.2 nmi northwest of (depth 10 ft), Massachusetts Current	NOS	ACT1396_1	42.29783	-70.9645	:America/New_York	USA	knots	16	223	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:44:00	\N	0.5	-00:31:00	\N	0.3	00:17:00	00:28:00	Sunken Ledge, 0.2 n.mi. northwest of	MA
100998	Sunken Ledge, 0.2 nmi northwest of (depth 20 ft), Massachusetts Current	NOS	ACT1396_2	42.29783	-70.9645	:America/New_York	USA	knots	30	236	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:14:00	\N	0.4	00:29:00	\N	0.3	00:19:00	00:33:00	Sunken Ledge, 0.2 n.mi. northwest of	MA
100999	West Head, Long I., 0.4 nmi south of (depth 10 ft), Massachusetts Current	NOS	ACT1401_1	42.30533	-70.97133	:America/New_York	USA	knots	60	231	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:17:00	\N	0.5	00:51:00	\N	0.5	00:24:00	01:00:00	West Head, Long I., 0.4 n.mi. south of	MA
101000	West Head, Long I., 0.4 nmi south of (depth 20 ft), Massachusetts Current	NOS	ACT1401_2	42.30533	-70.97133	:America/New_York	USA	knots	43	231	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:13:00	\N	0.4	01:05:00	\N	0.4	00:06:00	00:55:00	West Head, Long I., 0.4 n.mi. south of	MA
101001	Moon Head, 0.4 nmi east of (depth 10 ft), Massachusetts Current	NOS	ACT1406_1	42.30633	-70.97883	:America/New_York	USA	knots	80	259	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:43:00	\N	0.3	-01:49:00	\N	0.3	-00:18:00	-00:30:00	Moon Head, 0.4 n.mi. east of	MA
101002	West Head, 0.2 nmi southwest of (depth 10 ft), Massachusetts Current	NOS	ACT1411_1	42.28583	-70.953	:America/New_York	USA	knots	322	167	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:03:00	\N	1.2	00:26:00	\N	1.1	-00:13:00	01:00:00	West Head, 0.2 n.mi. southwest of	MA
101003	Nut Island, 0.4 nmi NNE of (depth 10 ft), Massachusetts Current	NOS	ACT1416_1	42.28467	-70.95367	:America/New_York	USA	knots	312	158	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:31:00	\N	1.2	00:30:00	\N	1	00:11:00	01:01:00	Nut Island, 0.4 n.mi. NNE of	MA
101004	Nut Island, 0.4 nmi NNE of (depth 20 ft), Massachusetts Current	NOS	ACT1416_2	42.28467	-70.95367	:America/New_York	USA	knots	321	155	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:29:00	\N	1.2	00:34:00	\N	0.9	00:11:00	01:08:00	Nut Island, 0.4 n.mi. NNE of	MA
101005	Nut Island, 0.2 nmi NNE of (depth 10 ft), Massachusetts Current	NOS	ACT1421_1	42.283	-70.95533	:America/New_York	USA	knots	309	146	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:31:00	\N	1	00:40:00	\N	0.9	00:31:00	01:15:00	Nut Island, 0.2 n.mi. NNE of	MA
101006	Nut Island, 0.2 nmi NNE of (depth 20 ft), Massachusetts Current	NOS	ACT1421_2	42.283	-70.95533	:America/New_York	USA	knots	303	131	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:16:00	\N	0.8	00:43:00	\N	0.8	00:30:00	01:25:00	Nut Island, 0.2 n.mi. NNE of	MA
101007	Peddocks Island, west of (depth 10 ft), Massachusetts Current	NOS	ACT1426_1	42.28717	-70.96533	:America/New_York	USA	knots	358	187	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:43:00	\N	0.3	00:20:00	\N	0.4	-00:42:00	-00:04:00	Peddocks Island, west of	MA
101008	Moon Head, 0.9 nmi southeast of (depth 10 ft), Massachusetts Current	NOS	ACT1431_1	42.29167	-70.98217	:America/New_York	USA	knots	33	227	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:32:00	\N	0.3	01:09:00	\N	0.3	00:30:00	01:27:00	Moon Head, 0.9 n.mi. southeast of	MA
101009	Weir River entrance (depth 10 ft), Massachusetts Current	NOS	ACT1441_1	42.2755	-70.8805	:America/New_York	USA	knots	272	76	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:30:00	\N	0.6	00:39:00	\N	0.6	00:09:00	00:42:00	Weir River entrance	MA
101010	Crow Point, 0.2 nmi north of (depth 10 ft), Massachusetts Current	NOS	ACT1451_1	42.26617	-70.895	:America/New_York	USA	knots	319	146	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	01:30:00	\N	0.2	-00:36:00	\N	0.2	00:05:00	00:04:00	Crow Point, 0.2 n.mi. north of	MA
101011	Bumkin Island, 0.1 nmi west of (depth 10 ft), Massachusetts Current	NOS	ACT1456_1	42.28083	-70.90617	:America/New_York	USA	knots	320	166	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:52:00	\N	0.6	01:18:00	\N	0.5	-00:02:00	00:37:00	Bumkin Island, 0.1 n.mi. west of	MA
101012	Bumkin Island, 0.1 nmi west of (depth 20 ft), Massachusetts Current	NOS	ACT1456_2	42.28083	-70.90617	:America/New_York	USA	knots	316	161	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:41:00	\N	0.5	01:16:00	\N	0.4	-00:23:00	00:57:00	Bumkin Island, 0.1 n.mi. west of	MA
101013	Windmill Point, 0.7 nmi SSE of (depth 10 ft), Massachusetts Current	NOS	ACT1461_1	42.2925	-70.91617	:America/New_York	USA	knots	350	128	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-01:41:00	\N	0.4	00:40:00	\N	0.8	-00:02:00	00:11:00	Windmill Point, 0.7 n.mi. SSE of	MA
101014	Windmill Point, 0.7 nmi SSE of (depth 25 ft), Massachusetts Current	NOS	ACT1461_2	42.2925	-70.91617	:America/New_York	USA	knots	315	136	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:49:00	\N	0.2	00:55:00	\N	0.8	-00:07:00	01:41:00	Windmill Point, 0.7 n.mi. SSE of	MA
101015	Bumkin Island, 0.4 nmi west of (depth 10 ft), Massachusetts Current	NOS	ACT1466_1	42.2805	-70.9125	:America/New_York	USA	knots	303	195	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-02:58:00	\N	0.2	00:51:00	\N	0.4	-00:23:00	00:23:00	Bumkin Island, 0.4 n.mi. west of	MA
101016	Sheep Island, 0.3 nmi west of (depth 10 ft), Massachusetts Current	NOS	ACT1476_1	42.28117	-70.933	:America/New_York	USA	knots	305	75	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:49:00	\N	0.4	01:14:00	\N	0.8	00:11:00	01:15:00	Sheep Island, 0.3 n.mi. west of	MA
101017	Sheep Island, 0.3 nmi west of (depth 25 ft), Massachusetts Current	NOS	ACT1476_2	42.28117	-70.933	:America/New_York	USA	knots	300	82	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:22:00	\N	0.3	01:14:00	\N	0.7	01:10:00	01:32:00	Sheep Island, 0.3 n.mi. west of	MA
101018	Pig Rock, north of (depth 10 ft), Massachusetts Current	NOS	ACT1486_1	42.28217	-70.94083	:America/New_York	USA	knots	290	78	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:47:00	\N	0.8	-00:36:00	\N	0.5	00:40:00	-00:15:00	Pig Rock, north of	MA
101019	Pig Rock, north of (depth 25 ft), Massachusetts Current	NOS	ACT1486_2	42.28217	-70.94083	:America/New_York	USA	knots	293	82	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:22:00	\N	0.6	00:24:00	\N	0.5	00:35:00	01:21:00	Pig Rock, north of	MA
101020	Pig Rock, northwest of (depth 20 ft), Massachusetts Current	NOS	ACT1491_1	42.28133	-70.9425	:America/New_York	USA	knots	283	85	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	01:00:00	\N	0.7	00:52:00	\N	0.8	01:04:00	01:53:00	Pig Rock, northwest of	MA
101021	Grape Island and Lower Neck, between (depth 10 ft), Massachusetts Current	NOS	ACT1496_1	42.2645	-70.925	:America/New_York	USA	knots	281	94	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:11:00	\N	0.7	-01:16:00	\N	0.6	-00:23:00	00:06:00	Grape Island and Lower Neck, between	MA
101022	Grape Island (depth 10 ft), Massachusetts Current	NOS	ACT1501_1	42.268	-70.93133	:America/New_York	USA	knots	345	203	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:18:00	\N	0.3	00:13:00	\N	0.4	-00:47:00	00:38:00	Grape Island	MA
101023	Stodders Neck, Weymouth Back River (depth 10 ft), Massachusetts Current	NOS	ACT1506_1	42.25333	-70.9275	:America/New_York	USA	knots	93	268	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:43:00	\N	0.2	00:54:00	\N	0.4	-00:32:00	00:34:00	Stodders Neck, Weymouth Back River	MA
101024	Gull Point, 0.4 nmi ESE of (depth 10 ft), Massachusetts Current	NOS	ACT1516_1	42.253	-70.947	:America/New_York	USA	knots	69	229	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	-00:05:00	\N	0.4	-00:32:00	\N	0.3	-00:19:00	00:08:00	Gull Point, 0.4 n.mi. ESE of	MA
101025	Gull Point, 0.4 nmi ESE of (depth 25 ft), Massachusetts Current	NOS	ACT1516_2	42.253	-70.947	:America/New_York	USA	knots	42	235	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:07:00	\N	0.2	-00:42:00	\N	0.3	-00:49:00	00:42:00	Gull Point, 0.4 n.mi. ESE of	MA
101026	Germantown Point (depth 20 ft), Massachusetts Current	NOS	ACT1526_1	42.24633	-70.96467	:America/New_York	USA	knots	70	269	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:01:00	\N	0.3	00:54:00	\N	0.3	00:05:00	00:49:00	Germantown Point	MA
101027	Philip Head, Town River Bay (depth 10 ft), Massachusetts Current	NOS	ACT1536_1	42.25	-70.97033	:America/New_York	USA	knots	95	289	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:17:00	\N	0.2	01:33:00	\N	0.3	00:11:00	01:11:00	Philip Head, Town River Bay	MA
101028	Barnstable Harbor (depth 7 ft), Cape Cod Bay, Massachusetts Current	NOS	ACT1546_1	41.72667	-70.27333	:America/New_York	USA	knots	4	192	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98024	00:17:00	\N	1.1	01:03:00	\N	0.9	00:10:00	00:17:00	Barnstable Harbor	MA
101029	Old Man Shoal, Nantucket Shoals, Massachusetts Current	NOS	ACT1591_1	41.22667	-69.98333	:America/New_York	USA	knots	225	80	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:14:00	\N	0.9	01:03:00	\N	0.9	01:23:00	01:17:00	Old Man Shoal, Nantucket Shoals	MA
101030	Miacomet Pond, 3.0 mi SSE of, Massachusetts Current	NOS	ACT1596_1	41.19	-70.09667	:America/New_York	USA	knots	280	80	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	02:16:00	\N	0.8	02:03:00	\N	0.6	02:19:00	02:22:00	Miacomet Pond, 3.0 miles SSE of	MA
101032	Pollock Rip Channel, east end, Nantucket Sound entrance, Massachusetts Current	NOS	ACT1611_1	41.565	-69.92333	:America/New_York	USA	knots	212	53	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-00:38:00	\N	1.1	-00:39:00	\N	1	-00:14:00	-00:23:00	Pollock Rip Channel, east end	MA
101033	Monomoy Pt., channel 0.2 mi west of, Nantucket Sound, Massachusetts Current	NOS	ACT1626_1	41.55	-70.02167	:America/New_York	USA	knots	346	170	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-00:23:00	\N	1.2	00:39:00	\N	0.8	00:00:00	00:18:00	Monomoy Pt., channel 0.2 mile west of	MA
101034	Stage Harbor, west of Morris Island, Nantucket Sound, Massachusetts Current	NOS	ACT1636_1	41.65667	-69.975	:America/New_York	USA	knots	144	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	04:28:00	\N	0.6	01:29:00	\N	0.3	03:07:00	02:24:00	Stage Harbor, west of Morris Island	MA
101035	Dennis Port, 2.2 mi south of, Nantucket Sound, Massachusetts Current	NOS	ACT1641_1	41.61667	-70.115	:America/New_York	USA	knots	269	77	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:04:00	\N	0.2	00:52:00	\N	0.2	01:28:00	00:27:00	Dennis Port, 2.2 miles south of	MA
101036	Monomoy Point, 6 mi west of, Nantucket Sound, Massachusetts Current	NOS	ACT1646_1	41.55833	-70.15	:America/New_York	USA	knots	275	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:22:00	\N	0.3	01:52:00	\N	0.2	01:22:00	01:09:00	Monomoy Point, 6 miles west of	MA
101037	Handkerchief Lighted Whistle Buoy H, Nantucket Sound, Massachusetts Current	NOS	ACT1651_1	41.48833	-70.06667	:America/New_York	USA	knots	251	80	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	00:59:00	\N	0.8	01:10:00	\N	0.6	01:08:00	00:49:00	Handkerchief Lighted Whistle Buoy 'H'	MA
101038	Halfmoon Shoal, 1.9 mi northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1656_1	41.48417	-70.1925	:America/New_York	USA	knots	265	110	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:44:00	\N	0.3	01:49:00	\N	0.4	01:42:00	01:24:00	Halfmoon Shoal, 1.9 miles northeast of	MA
101039	Halfmoon Shoal, 3.5 mi east of, Nantucket Sound, Massachusetts Current	NOS	ACT1661_1	41.46833	-70.15333	:America/New_York	USA	knots	295	88	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:11:00	\N	0.6	01:23:00	\N	0.5	01:13:00	01:06:00	Halfmoon Shoal, 3.5 miles east of	MA
101040	Great Point, 0.5 mi west of, Nantucket Sound, Massachusetts Current	NOS	ACT1666_1	41.39333	-70.06167	:America/New_York	USA	knots	195	29	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	00:33:00	\N	0.7	01:37:00	\N	0.6	00:25:00	01:13:00	Great Point, 0.5 mile west of	MA
101041	Great Point, 3 mi west of, Nantucket Sound, Massachusetts Current	NOS	ACT1671_1	41.39	-70.11333	:America/New_York	USA	knots	248	66	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:08:00	\N	0.5	01:23:00	\N	0.4	01:15:00	00:51:00	Great Point, 3 miles west of	MA
101042	Tuckernuck Shoal, off east end, Nantucket Sound, Massachusetts Current	NOS	ACT1676_1	41.405	-70.17333	:America/New_York	USA	knots	287	113	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:10:00	\N	0.5	01:34:00	\N	0.5	01:22:00	01:09:00	Tuckernuck Shoal, off east end	MA
101043	Nantucket Harbor entrance channel, Nantucket Sound, Massachusetts Current	NOS	ACT1686_1	41.30667	-70.1	:America/New_York	USA	knots	350	171	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	03:58:00	\N	0.9	01:55:00	\N	0.6	03:22:00	02:44:00	Nantucket Harbor entrance channel	MA
101044	Eel Pt., Nantucket I. 2.5 mi NE of, Nantucket Sound, Massachusetts Current	NOS	ACT1691_1	41.32167	-70.17	:America/New_York	USA	knots	284	94	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:15:00	\N	0.2	01:12:00	\N	0.3	01:13:00	01:02:00	Eel Pt., Nantucket I. 2.5 miles NE of	MA
101045	Muskeget I., channel 1 mi northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1696_1	41.35	-70.285	:America/New_York	USA	knots	295	108	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	00:56:00	\N	0.9	00:45:00	\N	0.6	01:29:00	00:57:00	Muskeget I., channel 1 mile northeast of	MA
101046	Muskeget Rock, 1.3 mi southwest of, Nantucket Sound, Massachusetts Current	NOS	ACT1701_1	41.32	-70.39333	:America/New_York	USA	knots	192	24	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	00:18:00	\N	0.6	00:23:00	\N	0.6	01:10:00	00:57:00	Muskeget Rock, 1.3 miles southwest of	MA
101047	Muskeget Channel, Nantucket Sound, Massachusetts Current	NOS	ACT1706_1	41.34833	-70.42	:America/New_York	USA	knots	200	21	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:02:00	\N	1.9	00:38:00	\N	1.9	01:40:00	01:29:00	Muskeget Channel	MA
101048	Long Shoal-Norton Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1716_1	41.40833	-70.33333	:America/New_York	USA	knots	260	100	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:13:00	\N	0.6	01:12:00	\N	0.7	01:31:00	01:26:00	Long Shoal-Norton Shoal, between	MA
101049	Cape Poge Lt., 1.7 mi SSE of, Nantucket Sound, Massachusetts Current	NOS	ACT1721_1	41.4	-70.42667	:America/New_York	USA	knots	215	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	00:48:00	\N	0.7	-00:07:00	\N	0.8	00:58:00	00:49:00	Cape Poge Lt., 1.7 miles SSE of	MA
101050	Cross Rip Channel, Nantucket Sound, Massachusetts Current	NOS	ACT1726_1	41.44833	-70.29167	:America/New_York	USA	knots	272	91	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:59:00	\N	0.5	01:48:00	\N	0.6	01:48:00	01:55:00	Cross Rip Channel	MA
101051	Cape Poge Lt., 3.2 mi northeast of, Nantucket Sound, Massachusetts Current	NOS	ACT1731_1	41.45833	-70.4	:America/New_York	USA	knots	300	95	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	02:37:00	\N	0.7	02:03:00	\N	0.8	02:42:00	02:33:00	Cape Poge Lt., 3.2 miles northeast of	MA
101052	Broken Ground-Horseshoe Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1736_1	41.55	-70.285	:America/New_York	USA	knots	276	107	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:20:00	\N	0.5	01:55:00	\N	0.5	01:46:00	01:15:00	Broken Ground-Horseshoe Shoal, between	MA
101053	Point Gammon, 1.2 mi south of, Nantucket Sound, Massachusetts Current	NOS	ACT1741_1	41.58833	-70.25667	:America/New_York	USA	knots	260	105	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:02:00	\N	0.6	01:03:00	\N	0.5	01:15:00	01:06:00	Point Gammon, 1.2 miles south of	MA
101054	Lewis Bay entrance channel, Nantucket Sound, Massachusetts Current	NOS	ACT1751_1	41.63167	-70.27333	:America/New_York	USA	knots	184	4	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	04:22:00	\N	0.8	00:53:00	\N	0.5	02:46:00	02:44:00	Lewis Bay entrance channel	MA
101055	Cotuit Bay entrance (Bluff Point), Nantucket Sound, Massachusetts Current	NOS	ACT1756_1	41.61	-70.43	:America/New_York	USA	knots	218	35	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	03:35:00	\N	0.4	02:33:00	\N	0.3	02:44:00	02:51:00	Cotuit Bay entrance (Bluff Point)	MA
101056	Wreck Shoal-Eldridge Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1761_1	41.53333	-70.42833	:America/New_York	USA	knots	245	62	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:45:00	\N	0.8	01:32:00	\N	0.8	01:47:00	01:44:00	Wreck Shoal-Eldridge Shoal, between	MA
101057	Hedge Fence Lighted Gong Buoy 22, Nantucket Sound, Massachusetts Current	NOS	ACT1766_1	41.47167	-70.48333	:America/New_York	USA	knots	268	108	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	02:44:00	\N	0.7	02:34:00	\N	0.7	02:48:00	02:38:00	Hedge Fence Lighted Gong Buoy 22	MA
101058	Cape Poge Light, 1.4 mi west of, Nantucket Sound, Massachusetts Current	NOS	ACT1771_1	41.42417	-70.48333	:America/New_York	USA	knots	250	95	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:39:00	\N	0.1	01:54:00	\N	0.2	02:13:00	01:26:00	Cape Poge Light, 1.4 miles west of	MA
101059	East Chop-Squash Meadow, between, Nantucket Sound, Massachusetts Current	NOS	ACT1786_1	41.465	-70.53667	:America/New_York	USA	knots	329	131	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	02:04:00	\N	1.1	00:55:00	\N	0.7	02:07:00	01:43:00	East Chop-Squash Meadow, between	MA
101060	East Chop, 1 mi north of, Nantucket Sound, Massachusetts Current	NOS	ACT1791_1	41.485	-70.55833	:America/New_York	USA	knots	297	116	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	02:11:00	\N	1.3	01:52:00	\N	1.1	02:40:00	02:17:00	East Chop, 1 mile north of	MA
101061	West Chop, 0.8 mi north of, Nantucket Sound, Massachusetts Current	NOS	ACT1801_1	41.49333	-70.595	:America/New_York	USA	knots	282	96	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	02:35:00	\N	1.8	01:58:00	\N	1.6	02:49:00	02:20:00	West Chop, 0.8 mile north of	MA
101062	Hedge Fence-L'Hommedieu Shoal, between, Nantucket Sound, Massachusetts Current	NOS	ACT1806_1	41.505	-70.53667	:America/New_York	USA	knots	276	106	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:52:00	\N	1.3	01:38:00	\N	1	02:27:00	02:01:00	Hedge Fence-L'Hommedieu Shoal, between	MA
101063	Waquoit Bay entrance, Nantucket Sound, Massachusetts Current	NOS	ACT1811_1	41.54833	-70.53	:America/New_York	USA	knots	203	348	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	04:01:00	\N	0.8	02:14:00	\N	0.8	03:21:00	03:40:00	Waquoit Bay entrance	MA
101064	L'Hommedieu Shoal, north of west end, Nantucket Sound, Massachusetts Current	NOS	ACT1816_1	41.52667	-70.57667	:America/New_York	USA	knots	268	80	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	02:11:00	\N	1.4	02:03:00	\N	1.2	02:30:00	02:12:00	L'Hommedieu Shoal, north of west end	MA
101065	Nobska Point, 1.8 mi east of, Nantucket Sound, Massachusetts Current	NOS	ACT1821_1	41.51833	-70.61833	:America/New_York	USA	knots	240	63	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:49:00	\N	1	01:45:00	\N	1.2	02:13:00	01:55:00	Nobska Point, 1.8 miles east of	MA
101066	West Chop, 0.2 mi west of, Vineyard Sound, Massachusetts Current	NOS	ACT1826_1	41.48333	-70.61	:America/New_York	USA	knots	241	59	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:16:00	\N	0.8	01:34:00	\N	1.3	01:19:00	01:50:00	West Chop, 0.2 mile west of	MA
101067	Nobska Point, 1 mi southeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1831_1	41.50167	-70.64333	:America/New_York	USA	knots	259	71	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	02:19:00	\N	1.4	02:15:00	\N	1.3	02:33:00	02:25:00	Nobska Point, 1 mile southeast of	MA
101068	Norton Point, 0.5 mi north of, Vineyard Sound, Massachusetts Current	NOS	ACT1836_1	41.46833	-70.665	:America/New_York	USA	knots	240	50	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:12:00	\N	1.4	01:44:00	\N	1.7	01:55:00	02:01:00	Norton Point, 0.5 mile north of	MA
101069	Tarpaulin Cove, 1.5 mi east of, Vineyard Sound, Massachusetts Current	NOS	ACT1841_1	41.47167	-70.725	:America/New_York	USA	knots	232	55	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	02:33:00	\N	1.4	02:07:00	\N	1	02:49:00	02:12:00	Tarpaulin Cove, 1.5 miles east of	MA
101070	Robinsons Hole, 1.2 mi southeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1846_1	41.435	-70.78	:America/New_York	USA	knots	240	60	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	02:02:00	\N	1.2	01:51:00	\N	1	02:30:00	02:11:00	Robinsons Hole, 1.2 miles southeast of	MA
101071	Gay Head, 3 mi northeast of, Vineyard Sound, Massachusetts Current	NOS	ACT1851_1	41.385	-70.78333	:America/New_York	USA	knots	238	81	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	02:11:00	\N	0.8	01:50:00	\N	0.5	02:25:00	01:42:00	Gay Head, 3 miles northeast of	MA
101072	Gay Head, 3 mi north of, Vineyard Sound, Massachusetts Current	NOS	ACT1861_1	41.40167	-70.85333	:America/New_York	USA	knots	255	74	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:17:00	\N	0.7	01:24:00	\N	0.6	02:13:00	01:55:00	Gay Head, 3 miles north of	MA
101073	Gay Head, 1.5 mi northwest of, Vineyard Sound, Massachusetts Current	NOS	ACT1866_1	41.36333	-70.86333	:America/New_York	USA	knots	249	12	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	01:16:00	\N	1.2	00:54:00	\N	1	01:30:00	01:42:00	Gay Head, 1.5 miles northwest of	MA
101074	South end, Quicks Hole, Massachusetts Current	NOS	ACT1901_1	41.43833	-70.84167	:America/New_York	USA	knots	300	140	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98261	00:09:00	\N	0.7	00:12:00	\N	0.9	01:17:00	00:29:00	South end	MA
101075	North end, Quicks Hole, Massachusetts Current	NOS	ACT1911_1	41.45167	-70.85	:America/New_York	USA	knots	2	165	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98261	-00:21:00	\N	0.9	00:36:00	\N	0.9	01:41:00	00:56:00	North end	MA
101076	Westport River entrance, Buzzards Bay, Massachusetts Current	NOS	ACT1921_1	41.50833	-71.08833	:America/New_York	USA	knots	108	290	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98261	-01:49:00	\N	0.9	-01:23:00	\N	1	-01:15:00	-01:26:00	Westport River entrance	MA
101077	Ribbon Reef-Sow & Pigs Reef, between, Buzzards Bay, Massachusetts Current	NOS	ACT1931_1	41.42167	-70.97	:America/New_York	USA	knots	237	62	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98261	-02:30:00	\N	0.4	-02:49:00	\N	0.4	-01:43:00	-03:44:00	Ribbon Reef-Sow & Pigs Reef, between	MA
101078	Penikese Island, 0.8 mi northwest of, Buzzards Bay, Massachusetts Current	NOS	ACT1936_1	41.465	-70.93667	:America/New_York	USA	knots	254	50	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98261	-01:33:00	\N	0.4	-01:43:00	\N	0.6	-03:01:00	-01:55:00	Penikese Island, 0.8 mile northwest of	MA
101079	Penikese Island, 0.2 mi south of, Buzzards Bay, Massachusetts Current	NOS	ACT1941_1	41.44333	-70.925	:America/New_York	USA	knots	287	93	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98261	-03:15:00	\N	0.3	-01:33:00	\N	0.3	-03:07:00	-02:30:00	Penikese Island, 0.2 mile south of	MA
101080	Gull I. and Nashawena I., between, Buzzards Bay, Massachusetts Current	NOS	ACT1946_1	41.43667	-70.90333	:America/New_York	USA	knots	247	91	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98261	-03:17:00	\N	0.4	-02:15:00	\N	0.4	-03:39:00	-03:01:00	Gull I. and Nashawena I., between	MA
101082	Dumpling Rocks, 0.2 mi southeast of, Buzzards Bay, Massachusetts Current	NOS	ACT1966_1	41.53333	-70.91833	:America/New_York	USA	knots	190	66	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98261	-02:45:00	\N	0.4	-02:21:00	\N	0.4	-03:07:00	-02:32:00	Dumpling Rocks, 0.2 mile southeast of	MA
101083	Wareham River, off Long Beach Point, Buzzards Bay, Massachusetts Current	NOS	ACT2026_1	41.73333	-70.71667	:America/New_York	USA	knots	202	22	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98241	-01:24:00	\N	0.1	-00:33:00	\N	0.1	-02:09:00	-01:38:00	Wareham River, off Long Beach Point	MA
101084	Wareham River, off Barneys Point, Buzzards Bay, Massachusetts Current	NOS	ACT2031_1	41.745	-70.70667	:America/New_York	USA	knots	185	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98241	-01:32:00	\N	0.1	-00:29:00	\N	0.2	-02:17:00	-01:38:00	Wareham River, off Barneys Point	MA
101085	Bourne Highway bridge, Cape Cod Canal, Massachusetts Current	NOS	ACT2046_1	41.75	-70.58333	:America/New_York	USA	knots	245	65	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98241	-00:13:00	\N	0.8	-00:15:00	\N	0.8	-00:08:00	-00:07:00	Bourne Highway bridge	MA
101806	Rabbit Island, northwest of, Winyah Bay, South Carolina Current	NOS	ACT6551_1	33.3395	-79.28133	:America/New_York	USA	knots	215	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	02:25:00	\N	0.9	02:46:00	\N	1.2	02:39:00	02:14:00	Rabbit Island, northwest of	SC
101086	Black Point, SW of, Sakonnet River (depth 15 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2071_1	41.50667	-71.22	:America/New_York	USA	knots	194	12	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-02:26:00	\N	0.2	-01:55:00	\N	0.2	-02:54:00	-02:13:00	Black Point, SW of, Sakonnet River	RI
101087	Almy Point Bridge, south of, Sakonnet River (depth 15 ft), Rhode Island Current	NOS	ACT2076_1	41.62167	-71.22	:America/New_York	USA	knots	180	34	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-03:13:00	\N	0.8	-02:10:00	\N	0.2	-03:00:00	-02:30:00	Almy Point Bridge, south of, Sakonnet River	RI
101088	Brenton Point, 1.4 nmi southwest of (depth 7 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2096_1	41.43167	-71.37667	:America/New_York	USA	knots	170	347	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-01:04:00	\N	0.4	-00:38:00	\N	0.2	-01:03:00	-01:20:00	Brenton Point, 1.4 n.mi. southwest of	RI
101089	Castle Hill, west of, east passage (depth 15 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2101_1	41.45667	-71.37833	:America/New_York	USA	knots	237	13	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-00:29:00	\N	0.7	-00:42:00	\N	0.4	-00:06:00	-01:07:00	Castle Hill, west of, East Passage	RI
101090	Bull Point, east of (depth 10 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2106_1	41.48	-71.35	:America/New_York	USA	knots	206	1	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-01:33:00	\N	0.8	-00:47:00	\N	0.6	-01:10:00	-01:10:00	Bull Point, east of	RI
101091	Rose Island, northeast of (depth 15 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2121_1	41.50333	-71.33167	:America/New_York	USA	knots	124	310	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-02:08:00	\N	0.5	-00:07:00	\N	0.4	-01:57:00	-01:17:00	Rose Island, northeast of	RI
101092	Rose Island, northwest of (depth 15 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2126_1	41.50667	-71.35167	:America/New_York	USA	knots	190	7	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-01:39:00	\N	0.5	-00:26:00	\N	0.4	-01:38:00	-01:38:00	Rose Island, northwest of	RI
101093	Rose Island, west of, Narragansett Bay, Rhode Island Current	NOS	ACT2131_1	41.49667	-71.35	:America/New_York	USA	knots	172	1	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-01:28:00	\N	0.6	-00:34:00	\N	0.4	-00:42:00	-01:20:00	Rose Island, west of	RI
101094	Gould Island, southeast of (depth 7 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2136_1	41.525	-71.33667	:America/New_York	USA	knots	217	33	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-01:16:00	\N	0.4	-01:28:00	\N	0.3	-01:40:00	-01:14:00	Gould Island, southeast of	RI
101095	Gould Island, west of (depth 15 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2141_1	41.53167	-71.35833	:America/New_York	USA	knots	193	351	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-01:07:00	\N	0.4	-00:32:00	\N	0.3	-00:16:00	-01:13:00	Gould Island, west of	RI
101096	Dyer Island-Carrs Point (between), Narragansett Bay, Rhode Island Current	NOS	ACT2146_1	41.575	-71.29667	:America/New_York	USA	knots	236	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-01:37:00	\N	0.4	-01:13:00	\N	0.4	-01:56:00	-00:50:00	Dyer Island-Carrs Point (between)	RI
101097	Conanicut Point, ENE of (depth 15 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2151_1	41.575	-71.34167	:America/New_York	USA	knots	183	18	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-01:13:00	\N	0.2	-00:24:00	\N	0.2	-02:05:00	-01:18:00	Conanicut Point, ENE of	RI
101098	Dyer Island, west of (depth 7 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2156_1	41.58667	-71.30833	:America/New_York	USA	knots	216	23	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-01:34:00	\N	0.6	-00:46:00	\N	0.4	-01:04:00	-00:53:00	Dyer Island, west of	RI
101099	Mount Hope Bridge (depth 7 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2166_1	41.64	-71.25833	:America/New_York	USA	knots	230	47	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-00:58:00	\N	0.8	-01:34:00	\N	0.6	-01:22:00	-01:08:00	Mount Hope Bridge	RI
101100	Hog Island, northwest of (depth 10 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2171_1	41.64667	-71.295	:America/New_York	USA	knots	199	11	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-01:04:00	\N	0.2	-00:04:00	\N	0.2	-02:16:00	-00:30:00	Hog Island, northwest of	RI
101807	Sampit River entrance, Winyah Bay, South Carolina Current	NOS	ACT6556_1	33.35133	-79.28033	:America/New_York	USA	knots	135	345	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:53:00	\N	0.7	01:20:00	\N	0.6	01:33:00	01:39:00	Sampit River entrance	SC
101101	Common Fence Point, west of (depth 10 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2176_1	41.65	-71.245	:America/New_York	USA	knots	224	50	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-00:37:00	\N	0.4	00:08:00	\N	0.2	-01:13:00	-01:00:00	Common Fence Point, west of	RI
101102	Mount Hope Point, northeast of (depth 10 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2181_1	41.68	-71.21167	:America/New_York	USA	knots	217	38	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-00:57:00	\N	0.2	-00:20:00	\N	0.2	-02:01:00	-01:03:00	Mount Hope Point, northeast of	RI
101103	Warren, Warren River, Narragansett Bay, Rhode Island Current	NOS	ACT2196_1	41.72833	-71.28833	:America/New_York	USA	knots	171	358	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-01:05:00	\N	0.5	00:11:00	\N	0.5	-00:14:00	-00:22:00	Warren, Warren River	RI
101104	Beavertail Point, 0.8 mi northwest of, Narragansett Bay, Rhode Island Current	NOS	ACT2201_1	41.45833	-71.41167	:America/New_York	USA	knots	188	3	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-00:19:00	\N	0.6	-00:54:00	\N	0.3	-00:11:00	-01:31:00	Beavertail Point, 0.8 mile northwest of	RI
101105	Dutch Island and Beaver Head, between, Narragansett Bay, Rhode Island Current	NOS	ACT2211_1	41.49667	-71.40333	:America/New_York	USA	knots	233	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-01:47:00	\N	0.6	-01:32:00	\N	0.5	-01:56:00	-01:58:00	Dutch Island and Beaver Head, between	RI
101106	Dutch Island, west of (depth 7 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2216_1	41.505	-71.41	:America/New_York	USA	knots	206	14	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-01:16:00	\N	0.7	-01:49:00	\N	0.7	-01:33:00	-01:21:00	Dutch Island, west of	RI
101107	Patience Island, narrows east of, Narragansett Bay, Rhode Island Current	NOS	ACT2236_1	41.65833	-71.35333	:America/New_York	USA	knots	157	354	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-02:37:00	\N	0.5	-02:29:00	\N	0.4	-02:41:00	-02:44:00	Patience Island, narrows east of	RI
101108	Patience I. and Warwick Neck, between, Narragansett Bay, Rhode Island Current	NOS	ACT2241_1	41.66333	-71.37333	:America/New_York	USA	knots	224	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-01:13:00	\N	0.5	-01:21:00	\N	0.3	-01:40:00	-01:18:00	Patience I. and Warwick Neck, between	RI
101109	Nayatt Point, WNW of (depth 10 ft), Narragansett Bay, Rhode Island Current	NOS	ACT2246_1	41.72833	-71.36	:America/New_York	USA	knots	128	325	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97989	-01:11:00	\N	0.1	00:47:00	\N	0.1	-02:24:00	-01:00:00	Nayatt Point, WNW of	RI
101110	Harbor of Refuge, south entrance, Point Judith, Block Island Sound, Rhode Island Current	NOS	ACT2266_1	41.358	-71.49583	:America/New_York	USA	knots	181	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-03:02:00	\N	0.2	-02:53:00	\N	0.2	-02:25:00	-02:47:00	Harbor of Refuge, south entrance	RI
101111	Pond entrance - Point Judith, Block Island Sound, Rhode Island Current	NOS	ACT2276_1	41.38333	-71.51667	:America/New_York	USA	knots	186	351	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-04:04:00	\N	0.4	-03:06:00	\N	0.6	-03:15:00	-03:06:00	Pond entrance - Point Judith	RI
101112	2.4 mi southwest of, Point Judith, Block Island Sound, Rhode Island Current	NOS	ACT2281_1	41.33117	-71.51083	:America/New_York	USA	knots	90	258	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:36:00	\N	0.1	00:06:00	\N	0.2	-00:40:00	00:28:00	2.4 miles southwest of	RI
101113	4 mi north of, Block Island, Block Island Sound, Rhode Island Current	NOS	ACT2291_1	41.3	-71.53333	:America/New_York	USA	knots	76	285	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:06:00	\N	0.2	-00:05:00	\N	0.2	-00:32:00	00:31:00	4 miles north of	RI
101114	Sandy Point, 2.1 mi NNE of (depth 15 ft), Block Island Sound, Rhode Island Current	NOS	ACT2296_1	41.26417	-71.56667	:America/New_York	USA	knots	66	296	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:55:00	\N	0.4	-00:58:00	\N	0.3	00:17:00	-00:20:00	Sandy Point, 2.1 miles NNE of	RI
101115	Sandy Pt., 1.5 mi north of (depth 7 ft), Block Island Sound, Rhode Island Current	NOS	ACT2301_1	41.25	-71.56667	:America/New_York	USA	knots	63	315	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:05:00	\N	0.5	-00:38:00	\N	0.6	-00:24:00	-01:07:00	Sandy Pt., 1.5 miles north of	RI
101116	Clay Head, 1.2 mi ENE of (depth 15 ft), Block Island Sound, Rhode Island Current	NOS	ACT2306_1	41.2225	-71.53083	:America/New_York	USA	knots	164	298	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:07:00	\N	0.1	-01:37:00	\N	0.2	-02:20:00	00:49:00	Clay Head, 1.2 miles ENE of	RI
101117	Old Harbor Pt., 0.5 mi southeast of, Block Island Sound, Rhode Island Current	NOS	ACT2311_1	41.15	-71.53333	:America/New_York	USA	knots	175	336	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:06:00	\N	0.1	-00:37:00	\N	0.1	-00:12:00	-00:38:00	Old Harbor Pt., 0.5 mile southeast of	RI
101118	Lewis Pt., 1.0 mi southwest of, Block Island, Block Island Sound, Rhode Island Current	NOS	ACT2316_1	41.13667	-71.62167	:America/New_York	USA	knots	136	298	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:25:00	\N	0.4	-01:13:00	\N	0.6	-01:29:00	-00:24:00	Lewis Pt., 1.0 mile southwest of	RI
101119	Lewis Pt., 1.5 mi west of, Block Island, Block Island Sound, Rhode Island Current	NOS	ACT2321_1	41.15	-71.63333	:America/New_York	USA	knots	170	318	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:12:00	\N	0.4	-01:23:00	\N	0.4	-01:33:00	-00:48:00	Lewis Pt., 1.5 miles west of	RI
101120	Great Salt Pond entrance, Block Island, Block Island Sound, Rhode Island Current	NOS	ACT2326_1	41.1995	-71.59167	:America/New_York	USA	knots	326	165	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-04:34:00	\N	0.1	-03:40:00	\N	0.1	-04:10:00	-03:24:00	Great Salt Pond entrance	RI
101121	Great Salt Pond ent., 1 mi NW of (depth 7 ft), Block Island Sound, Rhode Island Current	NOS	ACT2331_1	41.2	-71.6	:America/New_York	USA	knots	35	158	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:47:00	\N	0.1	-01:06:00	\N	0.1	-00:54:00	-01:54:00	Great Salt Pond ent., 1 mile NW of	RI
101122	Green Hill Point, 1.1 mi south of, Block Island Sound, Rhode Island Current	NOS	ACT2341_1	41.34833	-71.59617	:America/New_York	USA	knots	70	258	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:07:00	\N	0.1	-00:52:00	\N	0.2	-00:58:00	-00:24:00	Green Hill Point, 1.1 miles south of	RI
101123	Sandy Point, 4.1 mi northwest of (depth 15 ft), Block Island Sound, Rhode Island Current	NOS	ACT2346_1	41.29333	-71.63333	:America/New_York	USA	knots	84	270	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:08:00	\N	0.2	00:06:00	\N	0.2	00:04:00	00:32:00	Sandy Point, 4.1 miles northwest of	RI
101124	Quonochontaug Beach, 1.1 mi S of, Block Island Sound, Rhode Island Current	NOS	ACT2356_1	41.31333	-71.71367	:America/New_York	USA	knots	78	248	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:32:00	\N	0.1	00:01:00	\N	0.3	-00:43:00	00:47:00	Quonochontaug Beach, 1.1 miles S of	RI
101125	Quonochontaug Beach, 3.8 mi S of (depth 15 ft), Block Island Sound, Rhode Island Current	NOS	ACT2361_1	41.2725	-71.71667	:America/New_York	USA	knots	58	243	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:04:00	\N	0.2	-00:11:00	\N	0.2	00:03:00	00:39:00	Quonochontaug Beach, 3.8 miles S of	RI
101126	Lewis Point, 6.0 mi WNW of (depth 15 ft), Block Island Sound, Rhode Island Current	NOS	ACT2366_1	41.19333	-71.73667	:America/New_York	USA	knots	97	286	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:23:00	\N	0.3	00:35:00	\N	0.2	00:59:00	00:16:00	Lewis Point, 6.0 miles WNW of	RI
101127	Southwest Ledge, Block Island Sound, Rhode Island Current	NOS	ACT2371_1	41.11667	-71.7	:America/New_York	USA	knots	141	321	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:23:00	\N	0.5	-00:41:00	\N	0.5	-00:35:00	-00:14:00	Southwest Ledge	RI
101128	Southwest Ledge, 2.0 mi west of (depth 15 ft), Block Island Sound, Rhode Island Current	NOS	ACT2376_1	41.11333	-71.71667	:America/New_York	USA	knots	168	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:53:00	\N	0.5	00:05:00	\N	0.4	00:10:00	00:11:00	Southwest Ledge, 2.0 miles west of	RI
101129	Watch Hill Point, 2.2 mi east of, Block Island Sound, Rhode Island Current	NOS	ACT2381_1	41.30267	-71.81	:America/New_York	USA	knots	86	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:33:00	\N	0.2	-00:13:00	\N	0.4	-00:29:00	00:45:00	Watch Hill Point, 2.2 miles east of	RI
101130	Watch Hill Point, 5.2 mi SSE of (depth 15 ft), Block Island Sound, Rhode Island Current	NOS	ACT2386_1	41.22	-71.81667	:America/New_York	USA	knots	64	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:00:00	\N	0.3	00:13:00	\N	0.4	00:35:00	00:39:00	Watch Hill Point, 5.2 miles SSE of	RI
101131	Watch Hill Point, 5.3 nmi SE of (depth 15 ft), Block Island Sound, Rhode Island Current	NOS	ACT2391_1	41.24417	-71.77383	:America/New_York	USA	knots	92	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:03:00	\N	0.2	-00:11:00	\N	0.2	-00:08:00	-00:17:00	Watch Hill Point, 5.3 n.mi. SE of	RI
101132	Montauk Point, 5.4 mi NNE of (depth 15 ft), Block Island Sound, New York Current	NOS	ACT2396_1	41.15917	-71.82467	:America/New_York	USA	knots	79	279	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:04:00	\N	0.4	-00:08:00	\N	0.3	00:33:00	-00:38:00	Montauk Point, 5.4 miles NNE of	NY
101133	Montauk Point, 1.2 mi east of, Block Island Sound, New York Current	NOS	ACT2401_1	41.075	-71.83	:America/New_York	USA	knots	162	346	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-02:05:00	\N	0.7	-01:14:00	\N	0.8	-01:22:00	-00:38:00	Montauk Point, 1.2 miles east of	NY
101134	Montauk Point, 1 mi northeast of, Block Island Sound, New York Current	NOS	ACT2406_1	41.08333	-71.85	:America/New_York	USA	knots	145	356	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:56:00	\N	0.5	-01:37:00	\N	0.7	-02:04:00	-01:14:00	Montauk Point, 1 mile northeast of	NY
101135	East Pt., 4.1 mi S of Fishers Island (depth 15 ft), New York Current	NOS	ACT2416_1	41.22333	-71.925	:America/New_York	USA	knots	73	236	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:00:00	\N	0.4	00:27:00	\N	0.3	00:50:00	00:19:00	East Pt., 4.1 miles S of Fishers Island	NY
101136	Cerberus Shoal, 1.5 mi east of (depth 15 ft), Block Island Sound, New York Current	NOS	ACT2421_1	41.17417	-71.9195	:America/New_York	USA	knots	92	256	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:04:00	\N	0.4	00:20:00	\N	0.3	-00:15:00	-00:23:00	Cerberus Shoal, 1.5 miles east of	NY
101137	Shagwong Reef & Cerberus Shoal, between, Block Island Sound, New York Current	NOS	ACT2426_1	41.13167	-71.925	:America/New_York	USA	knots	56	241	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:10:00	\N	0.4	-00:52:00	\N	0.6	-00:30:00	-00:25:00	Shagwong Reef & Cerberus Shoal, between	NY
101138	Mt. Prospect, 0.6 mi SSE of (depth 15 ft), Block Island Sound, New York Current	NOS	ACT2436_1	41.24583	-71.99667	:America/New_York	USA	knots	54	275	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:11:00	\N	0.4	-00:11:00	\N	0.5	-00:34:00	00:10:00	Mt. Prospect, 0.6 mile SSE of	NY
101139	Cerberus Shoal and Fishers I., between (depth 7 ft), Block Island Sound, New York Current	NOS	ACT2441_1	41.21667	-71.96667	:America/New_York	USA	knots	96	264	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:21:00	\N	0.3	-00:13:00	\N	0.4	-00:59:00	00:07:00	Cerberus Shoal and Fishers I., between	NY
101140	Gardiners Island, 3 mi northeast of (depth 10 ft), Block Island Sound, New York Current	NOS	ACT2451_1	41.13167	-72.03333	:America/New_York	USA	knots	138	305	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:41:00	\N	0.2	-01:04:00	\N	0.3	-00:47:00	-00:25:00	Gardiners Island, 3 miles northeast of	NY
101141	Eastern Plain Pt., 3.9 mi ENE of, Block Island Sound, New York Current	NOS	ACT2456_1	41.1175	-71.99667	:America/New_York	USA	knots	96	246	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:13:00	\N	0.2	-01:30:00	\N	0.3	-01:01:00	-00:22:00	Eastern Plain Pt., 3.9 miles ENE of	NY
101142	Rocky Point, 2 mi WNW of (depth 15 ft), Block Island Sound, New York Current	NOS	ACT2466_1	41.05917	-72.03	:America/New_York	USA	knots	65	255	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:11:00	\N	0.1	-01:06:00	\N	0.1	-01:22:00	-00:49:00	Rocky Point, 2 miles WNW of	NY
101143	Goff Point, 0.4 mi northwest of, New York Current	NOS	ACT2471_1	41.02483	-72.0625	:America/New_York	USA	knots	10	225	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-02:43:00	\N	0.4	-02:30:00	\N	0.4	-01:46:00	-01:25:00	Goff Point, 0.4 mile northwest of	NY
101144	Acabonack Hbr. ent., 0.6 mi ESE of, New York Current	NOS	ACT2476_1	41.02167	-72.12333	:America/New_York	USA	knots	140	345	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-02:42:00	\N	0.3	-02:15:00	\N	0.4	-01:34:00	-01:05:00	Acabonack Hbr. ent., 0.6 mile ESE of	NY
101145	Hog Creek Point, north of, New York Current	NOS	ACT2481_1	41.06833	-72.16167	:America/New_York	USA	knots	67	281	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-02:04:00	\N	0.1	-00:54:00	\N	0.1	-00:56:00	-01:21:00	Hog Creek Point, north of	NY
101146	Ram Island, 2.2 mi east of, New York Current	NOS	ACT2486_1	41.07833	-72.23	:America/New_York	USA	knots	90	250	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:24:00	\N	0.1	-00:29:00	\N	0.1	-00:19:00	-00:14:00	Ram Island, 2.2 miles east of	NY
101147	Orient Point, 2.4 mi SSE of, New York Current	NOS	ACT2491_1	41.125	-72.205	:America/New_York	USA	knots	25	250	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:43:00	\N	0.1	-00:39:00	\N	0.1	00:19:00	01:11:00	Orient Point, 2.4 miles SSE of	NY
101148	Gardiners Pt. Ruins, 1.1 mi N of, New York Current	NOS	ACT2496_1	41.15833	-72.14717	:America/New_York	USA	knots	66	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:09:00	\N	0.4	-00:22:00	\N	0.4	-00:12:00	-00:09:00	Gardiners Pt. Ruins, 1.1 miles N of	NY
101149	Gardiners Point & Plum Island, between (depth 15 ft), New York Current	NOS	ACT2501_1	41.1555	-72.15867	:America/New_York	USA	knots	100	288	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:42:00	\N	0.4	-00:36:00	\N	0.4	-00:18:00	-00:32:00	Gardiners Point & Plum Island, between	NY
101150	Ram Island, 1.4 mi NNE of, New York Current	NOS	ACT2506_1	41.09667	-72.26333	:America/New_York	USA	knots	75	240	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:05:00	\N	0.1	-00:07:00	\N	0.1	00:01:00	00:07:00	Ram Island, 1.4 miles NNE of	NY
101151	Long Beach Pt., 0.7 mi southwest of (depth 15 ft), New York Current	NOS	ACT2511_1	41.10417	-72.30667	:America/New_York	USA	knots	101	307	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:12:00	\N	0.4	-00:16:00	\N	0.4	00:33:00	00:44:00	Long Beach Pt., 0.7 mile southwest of	NY
101152	Jennings Point, 0.2 mi NNW of (depth 13 ft), New York Current	NOS	ACT2521_1	41.07467	-72.3825	:America/New_York	USA	knots	55	290	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:09:00	\N	0.4	00:04:00	\N	0.5	00:32:00	00:37:00	Jennings Point, 0.2 mile NNW of	NY
101153	Cedar Point, 0.2 mi west of, New York Current	NOS	ACT2526_1	41.03967	-72.26783	:America/New_York	USA	knots	5	195	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:53:00	\N	0.5	-00:21:00	\N	0.7	-00:11:00	00:29:00	Cedar Point, 0.2 mile west of	NY
101154	North Haven Peninsula, north of, New York Current	NOS	ACT2531_1	41.04117	-72.32083	:America/New_York	USA	knots	35	230	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:46:00	\N	0.5	-00:35:00	\N	0.7	00:12:00	00:39:00	North Haven Peninsula, north of	NY
101155	Paradise Point, 0.4 mi east of (depth 13 ft), New York Current	NOS	ACT2536_1	41.048	-72.37617	:America/New_York	USA	knots	345	145	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:06:00	\N	0.4	-00:02:00	\N	0.5	00:26:00	00:45:00	Paradise Point, 0.4 mile east of	NY
101156	Little Peconic Bay entrance (depth 19 ft), New York Current	NOS	ACT2541_1	41.02633	-72.38467	:America/New_York	USA	knots	15	240	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:09:00	\N	0.4	-00:04:00	\N	0.5	00:35:00	00:53:00	Little Peconic Bay entrance	NY
101157	Robins Island, 0.5 mi south of, New York Current	NOS	ACT2546_1	40.94967	-72.453	:America/New_York	USA	knots	65	245	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:23:00	\N	0.1	-00:17:00	\N	0.3	00:32:00	00:56:00	Robins Island, 0.5 mile south of	NY
101158	Napatree Point, 0.7 mi southwest of, Fishers Island Sound, Rhode Island Current	NOS	ACT2556_1	41.29867	-71.9	:America/New_York	USA	knots	113	284	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:30:00	\N	0.5	-01:12:00	\N	0.5	-00:48:00	-00:47:00	Napatree Point, 0.7 mile southwest of	RI
101159	Little Narragansett Bay entrance, Fishers Island Sound, Connecticut Current	NOS	ACT2561_1	41.33333	-71.88333	:America/New_York	USA	knots	268	92	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-02:50:00	\N	0.3	-02:07:00	\N	0.4	-01:58:00	-02:13:00	Little Narragansett Bay entrance	CT
101160	Ram Island Reef, south of (depth 7 ft), Fishers Island Sound, Connecticut Current	NOS	ACT2571_1	41.30167	-71.975	:America/New_York	USA	knots	88	255	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:05:00	\N	0.4	-00:55:00	\N	0.4	-00:54:00	-00:45:00	Ram Island Reef, south of	CT
101161	Clay Point, 1.3 mi NNE of (depth 15 ft), Fishers Island Sound, New York Current	NOS	ACT2586_1	41.298	-71.9755	:America/New_York	USA	knots	35	264	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:27:00	\N	0.4	-00:54:00	\N	0.4	-00:34:00	-00:30:00	Clay Point, 1.3 miles NNE of	NY
101162	North Hill Point, 1.1 mi NNW of, Fishers Island Sound, Connecticut Current	NOS	ACT2591_1	41.29283	-72.028	:America/New_York	USA	knots	82	258	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:49:00	\N	0.3	-00:31:00	\N	0.5	-00:57:00	-00:08:00	North Hill Point, 1.1 miles NNW of	CT
101163	Race Point, 0.4 mi southwest of, The Race, Long Island Sound, New York Current	NOS	ACT2596_1	41.245	-72.04333	:America/New_York	USA	knots	135	288	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:57:00	\N	0.8	-00:40:00	\N	0.8	-00:16:00	-00:33:00	Race Point, 0.4 mile southwest of	NY
101164	Little Gull Island, 1.4 nmi NNE of (depth 45 ft), Long Island Sound, New York Current	NOS	ACT2606_1	41.2255	-72.092	:America/New_York	USA	knots	100	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:34:00	\N	0.4	00:12:00	\N	0.4	00:02:00	00:08:00	Little Gull Island, 1.4 n.mi. NNE of	NY
101165	Little Gull Island, 1.1 mi ENE of, The Race, Long Island Sound, New York Current	NOS	ACT2611_1	41.21833	-72.085	:America/New_York	USA	knots	130	301	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:57:00	\N	1.1	-00:16:00	\N	1.2	00:01:00	00:11:00	Little Gull Island, 1.1 miles ENE of	NY
101166	Little Gull Island, 0.8 mi NNW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2616_1	41.21833	-72.1155	:America/New_York	USA	knots	43	258	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:58:00	\N	0.7	-01:24:00	\N	0.6	00:25:00	-02:19:00	Little Gull Island, 0.8 mile NNW of	NY
101167	Goshen Point, 1.9 mi SSE of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2666_1	41.26667	-72.105	:America/New_York	USA	knots	62	285	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-02:01:00	\N	0.4	-01:05:00	\N	0.4	-00:57:00	-00:53:00	Goshen Point, 1.9 miles SSE of	CT
101168	Bartlett Reef, 0.2 mi south of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2671_1	41.26667	-72.13333	:America/New_York	USA	knots	90	255	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:46:00	\N	0.3	-00:58:00	\N	0.4	-02:03:00	-01:04:00	Bartlett Reef, 0.2 mile south of	CT
101169	Twotree Island Channel (depth 11 ft), Long Island Sound, Connecticut Current	NOS	ACT2676_1	41.29833	-72.14167	:America/New_York	USA	knots	99	267	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:54:00	\N	0.4	-01:32:00	\N	0.4	-00:58:00	-00:33:00	Twotree Island Channel	CT
101170	Niantic (Railroad Bridge) (depth 5 ft), Long Island Sound, Connecticut Current	NOS	ACT2681_1	41.32667	-72.17667	:America/New_York	USA	knots	178	352	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:52:00	\N	0.2	-01:08:00	\N	0.5	-00:45:00	-00:43:00	Niantic (Railroad Bridge)	CT
101171	Black Point, 0.8 mi south of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2686_1	41.27333	-72.20833	:America/New_York	USA	knots	73	260	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:22:00	\N	0.3	-01:16:00	\N	0.4	-00:42:00	-00:15:00	Black Point, 0.8 mile south of	CT
101172	Black Point and Plum Island, between (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2691_1	41.23333	-72.205	:America/New_York	USA	knots	76	236	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:14:00	\N	0.6	-00:01:00	\N	0.7	00:33:00	00:39:00	Black Point and Plum Island, between	NY
101173	Plum Island, 0.8 mi NNW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2701_1	41.19833	-72.19833	:America/New_York	USA	knots	65	247	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:53:00	\N	0.6	-00:21:00	\N	0.5	00:12:00	-01:03:00	Plum Island, 0.8 mile NNW of	NY
101174	Hatchett Point, 1.6 nmi S of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2711_1	41.25667	-72.25617	:America/New_York	USA	knots	75	255	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:04:00	\N	0.4	-01:07:00	\N	0.5	-00:59:00	-00:27:00	Hatchett Point, 1.6 n.mi. S of	CT
101175	Hatchett Point, 1.1 mi WSW of, Long Island Sound, Connecticut Current	NOS	ACT2716_1	41.2725	-72.282	:America/New_York	USA	knots	45	240	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-02:49:00	\N	0.3	-01:16:00	\N	0.4	-02:29:00	-00:42:00	Hatchett Point, 1.1 miles WSW of	CT
101176	Orient Point, 1 mi WNW of, Long Island Sound, New York Current	NOS	ACT2721_1	41.16667	-72.25167	:America/New_York	USA	knots	55	245	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:27:00	\N	0.7	-02:07:00	\N	0.4	-01:01:00	-00:23:00	Orient Point, 1 mile WNW of	NY
101177	Saybrook Breakwater, 1.5 mi SE of, Long Island Sound, Connecticut Current	NOS	ACT2726_1	41.24633	-72.3175	:America/New_York	USA	knots	70	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-02:09:00	\N	0.5	-01:16:00	\N	0.6	-01:22:00	-00:45:00	Saybrook Breakwater, 1.5 miles SE of	CT
101178	Eustasia Island, 0.6 mi ESE of, Connecticut River, Long Island Sound, Connecticut Current	NOS	ACT2746_1	41.38833	-72.40383	:America/New_York	USA	knots	70	290	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	01:14:00	\N	0.3	01:33:00	\N	0.3	02:01:00	01:33:00	Eustasia Island, 0.6 mile ESE of	CT
101179	Eddy Rock Shoal, west of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2751_1	41.44283	-72.463	:America/New_York	USA	knots	155	350	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	01:08:00	\N	0.1	02:11:00	\N	0.2	01:49:00	02:11:00	Eddy Rock Shoal, west of	CT
101180	Higganum Creek, 0.5 mi ESE of, Connecticut River, Long Island Sound, Connecticut Current	NOS	ACT2756_1	41.50033	-72.54367	:America/New_York	USA	knots	80	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	02:49:00	\N	0.2	02:47:00	\N	0.2	03:14:00	02:45:00	Higganum Creek, 0.5 mile ESE of	CT
101181	Wilcox Island Park, east of, Connecticut River, Long Island Sound, Connecticut Current	NOS	ACT2761_1	41.57217	-72.648	:America/New_York	USA	knots	160	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	03:23:00	\N	0.2	03:31:00	\N	0.3	04:14:00	03:17:00	Wilcox Island Park, east of	CT
101182	Rocky Hill (depth 9 ft), Connecticut River, Long Island Sound, Connecticut Current	NOS	ACT2766_1	41.66367	-72.62883	:America/New_York	USA	knots	135	335	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	03:18:00	\N	0.2	03:32:00	\N	0.2	04:51:00	03:31:00	Rocky Hill	CT
101183	Hartford Jetty (depth 9 ft), Connecticut River, Long Island Sound, Connecticut Current	NOS	ACT2771_1	41.75117	-72.65033	:America/New_York	USA	knots	95	290	IGNORE VELOCITIES	Velocities for this station should be disregarded--use times only.	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	04:17:00	\N	0.2	04:34:00	\N	0.001	05:53:00	03:32:00	Hartford Jetty	CT
101184	Mulford Point, 3.1 mi northwest of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2776_1	41.2	-72.31833	:America/New_York	USA	knots	66	269	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:36:00	\N	0.5	-01:10:00	\N	0.6	00:02:00	00:05:00	Mulford Point, 3.1 miles northwest of	NY
101185	Rocky Point, 0.3 mi north of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2781_1	41.14383	-72.357	:America/New_York	USA	knots	41	279	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:40:00	\N	0.5	-01:07:00	\N	0.5	-00:19:00	-00:51:00	Rocky Point, 0.3 mile north of	NY
101186	Cornfield Point, 2.8 nmi SE of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2786_1	41.2325	-72.33883	:America/New_York	USA	knots	85	249	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:44:00	\N	0.3	-01:02:00	\N	0.6	-01:27:00	-00:32:00	Cornfield Point, 2.8 n.mi. SE of	CT
101187	Cornfield Point, 1.1 mi south of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2796_1	41.24417	-72.39	:America/New_York	USA	knots	108	293	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-02:15:00	\N	0.4	-01:39:00	\N	0.4	-00:53:00	-00:52:00	Cornfield Point, 1.1 miles south of	CT
101188	Cornfield Point, 1.9 nmi SW of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2801_1	41.24133	-72.42167	:America/New_York	USA	knots	91	272	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:23:00	\N	0.4	-01:40:00	\N	0.4	-01:09:00	-01:24:00	Cornfield Point, 1.9 n.mi. SW of	CT
101189	Kelsey Point, 2.1 mi southeast of, Long Island Sound, Connecticut Current	NOS	ACT2806_1	41.235	-72.4655	:America/New_York	USA	knots	70	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:12:00	\N	0.4	-01:07:00	\N	0.5	-00:27:00	-00:44:00	Kelsey Point, 2.1 miles southeast of	CT
101190	Kelsey Point, 1 mi south of, Long Island Sound, Connecticut Current	NOS	ACT2811_1	41.23333	-72.5	:America/New_York	USA	knots	118	249	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-02:06:00	\N	0.4	-01:08:00	\N	0.6	-01:34:00	-01:07:00	Kelsey Point, 1 mile south of	CT
101191	Six Mile Reef, 1.5 mi north of, Long Island Sound, Connecticut Current	NOS	ACT2816_1	41.21117	-72.48117	:America/New_York	USA	knots	95	290	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:53:00	\N	0.3	-00:17:00	\N	0.3	-00:09:00	-00:13:00	Six Mile Reef, 1.5 miles north of	CT
101192	Six Mile Reef, 2 mi east of, Long Island Sound, New York Current	NOS	ACT2821_1	41.1805	-72.44833	:America/New_York	USA	knots	40	235	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:47:00	\N	0.5	-00:17:00	\N	0.5	-00:28:00	00:03:00	Six Mile Reef, 2 miles east of	NY
101319	Catskill, Hudson River (midchannel), New York Current	NOS	ACT3781_1	42.21667	-73.85	:America/New_York	USA	knots	\N	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98642	00:36:00	\N	1.5	01:30:00	\N	1.5	01:11:00	00:54:00	Catskill	NY
101193	Horton Point, 1.4 mi NNW of, Long Island Sound, New York Current	NOS	ACT2841_1	41.105	-72.45667	:America/New_York	USA	knots	40	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:30:00	\N	0.5	00:03:00	\N	0.4	00:12:00	00:07:00	Horton Point, 1.4 miles NNW of	NY
101194	Hammonasset Point, 1.2 mi SW of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2846_1	41.237	-72.56667	:America/New_York	USA	knots	106	287	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:43:00	\N	0.2	-01:20:00	\N	0.3	-00:51:00	-00:34:00	Hammonasset Point, 1.2 miles SW of	CT
101195	Hammonasset Point, 5 mi south of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2851_1	41.16333	-72.5695	:America/New_York	USA	knots	90	284	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:18:00	\N	0.4	-00:08:00	\N	0.4	00:05:00	-00:14:00	Hammonasset Point, 5 miles south of	NY
101196	Duck Pond Point, 3.2 nmi NW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2856_1	41.07883	-72.56517	:America/New_York	USA	knots	71	253	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:15:00	\N	0.3	-00:14:00	\N	0.4	-00:25:00	-00:06:00	Duck Pond Point, 3.2 n.mi. NW of	NY
101197	Mattituck Inlet, 1 mi northwest of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2861_1	41.028	-72.57033	:America/New_York	USA	knots	53	241	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:38:00	\N	0.2	-00:20:00	\N	0.3	-00:13:00	00:02:00	Mattituck Inlet, 1 mile northwest of	NY
101198	Sachem Head, 1 mi SSE of, Long Island Sound, Connecticut Current	NOS	ACT2866_1	41.2275	-72.705	:America/New_York	USA	knots	65	255	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:14:00	\N	0.2	-00:41:00	\N	0.3	-00:30:00	-00:25:00	Sachem Head, 1 mile SSE of	CT
101199	Sachem Head 6.2 mi south of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2871_1	41.1455	-72.705	:America/New_York	USA	knots	65	260	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:16:00	\N	0.2	00:19:00	\N	0.2	00:37:00	-00:02:00	Sachem Head  6.2 miles south of	CT
101200	Roanoke Point, 5.6 mi north of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2876_1	41.07283	-72.70883	:America/New_York	USA	knots	50	255	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:36:00	\N	0.2	-00:07:00	\N	0.2	00:06:00	-00:05:00	Roanoke Point, 5.6 miles north of	NY
101201	Roanoke Point, 2.3 mi NNW of, Long Island Sound, New York Current	NOS	ACT2886_1	41.01533	-72.71617	:America/New_York	USA	knots	70	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:41:00	\N	0.2	-00:27:00	\N	0.3	-01:11:00	00:00:00	Roanoke Point, 2.3 miles NNW of	NY
101202	Branford Reef, 1.5 mi southwest of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2891_1	41.2095	-72.8305	:America/New_York	USA	knots	68	272	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:30:00	\N	0.2	-00:19:00	\N	0.2	-00:05:00	00:01:00	Branford Reef, 1.5 miles southwest of	CT
101203	Herod Point, 6.5 mi north of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2901_1	41.0775	-72.83	:America/New_York	USA	knots	70	254	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:19:00	\N	0.2	00:01:00	\N	0.3	-00:19:00	00:22:00	Herod Point, 6.5 miles north of	NY
101204	Herod Point, 2.8 mi north of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2906_1	41.01617	-72.83217	:America/New_York	USA	knots	90	290	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:18:00	\N	0.1	-00:22:00	\N	0.1	-00:21:00	-00:17:00	Herod Point, 2.8 miles north of	NY
101205	Herod Point, 5.0 nmi NW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2911_1	41.02733	-72.91217	:America/New_York	USA	knots	89	271	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:01:00	\N	0.2	-00:22:00	\N	0.2	-00:09:00	-00:27:00	Herod Point, 5.0 n.mi. NW of	NY
101206	Pond Point, 4.2 mi SSE of, Long Island Sound, Connecticut Current	NOS	ACT2936_1	41.14333	-72.968	:America/New_York	USA	knots	65	265	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:26:00	\N	0.1	-00:01:00	\N	0.2	-00:12:00	00:06:00	Pond Point, 4.2 miles SSE of	CT
101207	Sound Beach, 2.2 mi north of, Long Island Sound, New York Current	NOS	ACT2941_1	41.0055	-72.97417	:America/New_York	USA	knots	75	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:37:00	\N	0.2	-00:11:00	\N	0.3	00:05:00	-00:05:00	Sound Beach, 2.2 miles north of	NY
101208	Charles Island, 0.8 mi SSE of, Long Island Sound, Connecticut Current	NOS	ACT2946_1	41.1795	-73.04383	:America/New_York	USA	knots	70	250	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:06:00	\N	0.1	-00:41:00	\N	0.1	-00:43:00	-00:20:00	Charles Island, 0.8 mile SSE of	CT
101209	Milford Point, 0.2 mi west of (depth 10 ft), Long Island Sound, Connecticut Current	NOS	ACT2951_1	41.1725	-73.11367	:America/New_York	USA	knots	135	330	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:07:00	\N	0.3	-00:04:00	\N	0.4	00:02:00	00:25:00	Milford Point, 0.2 mile west of	CT
101210	Railroad drawbridge, above (depth 5 ft), Long Island Sound, Connecticut Current	NOS	ACT2956_1	41.20883	-73.11117	:America/New_York	USA	knots	185	350	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:07:00	\N	0.3	00:08:00	\N	0.3	00:42:00	00:39:00	Railroad drawbridge, above	CT
101211	Fowler Island, 0.1 mi NNW of (depth 5 ft), Long Island Sound, Connecticut Current	NOS	ACT2961_1	41.24	-73.10383	:America/New_York	USA	knots	270	40	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:36:00	\N	0.3	00:05:00	\N	0.3	00:56:00	00:40:00	Fowler Island, 0.1 mile NNW of	CT
101212	Wooster Island, 0.1 mi southwest of (depth 5 ft), Long Island Sound, Connecticut Current	NOS	ACT2966_1	41.27783	-73.08667	:America/New_York	USA	knots	220	20	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:10:00	\N	0.2	00:28:00	\N	0.2	01:27:00	00:30:00	Wooster Island, 0.1 mile southwest of	CT
101213	Point No Point, 2.1 mi south of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2976_1	41.1125	-73.11883	:America/New_York	USA	knots	74	251	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:13:00	\N	0.3	-00:11:00	\N	0.4	-00:22:00	00:02:00	Point No Point, 2.1 miles south of	CT
101214	Stratford Point, 4.3 mi south of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT2986_1	41.0795	-73.11117	:America/New_York	USA	knots	75	254	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:02:00	\N	0.2	00:14:00	\N	0.3	00:20:00	00:15:00	Stratford Point, 4.3 miles south of	CT
101215	Stratford Point, 4.3 mi south of (depth 60 ft), Long Island Sound, Connecticut Current	NOS	ACT2986_2	41.0795	-73.11117	:America/New_York	USA	knots	78	291	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:03:00	\N	0.2	-00:14:00	\N	0.2	-00:28:00	-00:13:00	Stratford Point, 4.3 miles south of	CT
101216	Stratford Point, 6.1 mi south of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT2991_1	41.0495	-73.09667	:America/New_York	USA	knots	80	267	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:18:00	\N	0.2	-00:02:00	\N	0.3	-00:10:00	00:26:00	Stratford Point, 6.1 miles south of	NY
101217	Stratford Point, 6.1 mi south of (depth 51 ft), Long Island Sound, New York Current	NOS	ACT2991_2	41.0495	-73.09667	:America/New_York	USA	knots	87	279	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:24:00	\N	0.2	-00:36:00	\N	0.3	-00:35:00	-00:24:00	Stratford Point, 6.1 miles south of	NY
101218	Stratford Shoal, 6 mi east of, Long Island Sound, New York Current	NOS	ACT2996_1	41.07533	-72.97383	:America/New_York	USA	knots	60	265	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:21:00	\N	0.1	-00:07:00	\N	0.2	00:09:00	00:03:00	Stratford Shoal, 6 miles east of	NY
101219	Old Field Point, 2.9 nmi NNW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3006_1	41.022	-73.1395	:America/New_York	USA	knots	76	254	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:15:00	\N	0.2	-00:16:00	\N	0.2	00:27:00	-00:35:00	Old Field Point, 2.9 n.mi. NNW of	NY
101220	Old Field Point, 2 mi northeast of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3011_1	41.00383	-73.095	:America/New_York	USA	knots	92	266	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:46:00	\N	0.3	00:08:00	\N	0.3	00:41:00	-00:01:00	Old Field Point, 2 miles northeast of	NY
101221	Old Field Point, 2 mi northeast of (depth 40 ft), Long Island Sound, New York Current	NOS	ACT3011_2	41.00383	-73.095	:America/New_York	USA	knots	81	236	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:29:00	\N	0.2	00:03:00	\N	0.2	00:30:00	-00:02:00	Old Field Point, 2 miles northeast of	NY
101222	Old Field Point, 1 mi east of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3016_1	40.9745	-73.09667	:America/New_York	USA	knots	308	105	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	01:44:00	\N	0.2	02:26:00	\N	0.1	03:34:00	02:35:00	Old Field Point, 1 mile east of	NY
101223	Old Field Point, 1 mi east of (depth 22 ft), Long Island Sound, New York Current	NOS	ACT3016_2	40.9745	-73.09667	:America/New_York	USA	knots	297	110	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	01:32:00	\N	0.1	01:49:00	\N	0.1	02:38:00	02:27:00	Old Field Point, 1 mile east of	NY
101224	Crane Neck Point, 0.5 mi northwest of, Long Island Sound, New York Current	NOS	ACT3026_1	40.96667	-73.16667	:America/New_York	USA	knots	16	256	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-01:49:00	\N	0.4	-01:32:00	\N	0.4	-00:47:00	-01:42:00	Crane Neck Point, 0.5 mile northwest of	NY
101225	Pine Creek Point, 2.3 mi SSE of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT3041_1	41.08417	-73.24	:America/New_York	USA	knots	84	272	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:11:00	\N	0.1	00:01:00	\N	0.2	-00:12:00	00:31:00	Pine Creek Point, 2.3 miles SSE of	CT
101226	Shoal Point, 6 mi south of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3046_1	41.02833	-73.23383	:America/New_York	USA	knots	47	232	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:43:00	\N	0.1	00:23:00	\N	0.1	00:30:00	00:52:00	Shoal Point, 6 miles south of	NY
101227	Crane Neck Point, 3.4 mi WNW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3051_1	40.98333	-73.23117	:America/New_York	USA	knots	79	261	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:03:00	\N	0.1	-00:03:00	\N	0.2	-00:04:00	-00:15:00	Crane Neck Point, 3.4 miles WNW of	NY
101228	Crane Neck Point, 3.7 mi WSW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3056_1	40.93833	-73.23117	:America/New_York	USA	knots	232	66	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:30:00	\N	0.1	-00:36:00	\N	0.1	-01:24:00	-00:14:00	Crane Neck Point, 3.7 miles WSW of	NY
101229	Saugatuck River, 0.3 mi NW of Bluff Pt (depth 15 ft), Connecticut Current	NOS	ACT3061_1	41.1045	-73.36533	:America/New_York	USA	knots	80	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:02:00	\N	0.1	-00:46:00	\N	0.2	-00:04:00	00:30:00	Saugatuck River, 0.3 mi. NW of Bluff Pt	CT
101230	Sheffield I. Hbr., 0.5 mi southeast of (depth 12 ft), Connecticut Current	NOS	ACT3076_1	41.05533	-73.42083	:America/New_York	USA	knots	42	229	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-02:24:00	\N	0.1	-03:59:00	\N	0.1	-02:33:00	-03:26:00	Sheffield I. Hbr., 0.5 mile southeast of	CT
101231	Sheffield I. Tower, 1.1 mi SE of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT3081_1	41.03283	-73.4055	:America/New_York	USA	knots	81	283	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:21:00	\N	0.2	00:34:00	\N	0.3	00:41:00	01:09:00	Sheffield I. Tower, 1.1 miles SE of	CT
101232	Sheffield I. Tower, 1.1 mi SE of (depth 60 ft), Long Island Sound, Connecticut Current	NOS	ACT3081_2	41.03283	-73.4055	:America/New_York	USA	knots	76	269	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:24:00	\N	0.1	00:19:00	\N	0.2	-00:19:00	01:10:00	Sheffield I. Tower, 1.1 miles SE of	CT
101233	Eatons Neck Pt., 2.5 nmi NNW of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT3091_1	40.9955	-73.41	:America/New_York	USA	knots	73	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-02:21:00	\N	0.2	-02:02:00	\N	0.2	-01:51:00	-02:06:00	Eatons Neck Pt., 2.5 n.mi. NNW of	CT
101234	Eatons Neck Pt., 1.3 mi north of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3096_1	40.97667	-73.39617	:America/New_York	USA	knots	75	283	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:09:00	\N	0.3	00:16:00	\N	0.4	00:29:00	00:13:00	Eatons Neck Pt., 1.3 miles north of	NY
101235	Eatons Neck Pt., 1.8 mi west of, Long Island Sound, New York Current	NOS	ACT3106_1	40.95	-73.43333	:America/New_York	USA	knots	68	199	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:44:00	\N	0.1	-01:09:00	\N	0.2	-01:11:00	-00:32:00	Eatons Neck Pt., 1.8 miles west of	NY
101236	Huntington Bay, off East Fort Point (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3111_1	40.92667	-73.4175	:America/New_York	USA	knots	14	190	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:39:00	\N	0.1	00:09:00	\N	0.2	00:02:00	00:24:00	Huntington Bay, off East Fort Point	NY
101237	Huntington Bay, off East Fort Point (depth 30 ft), Long Island Sound, New York Current	NOS	ACT3111_2	40.92667	-73.4175	:America/New_York	USA	knots	7	179	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:28:00	\N	0.1	00:05:00	\N	0.1	-00:46:00	00:15:00	Huntington Bay, off East Fort Point	NY
101238	Northport Bay entrance (in channel) (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3116_1	40.90883	-73.4075	:America/New_York	USA	knots	267	100	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:18:00	\N	0.1	00:09:00	\N	0.1	-00:03:00	00:22:00	Northport Bay entrance (in channel)	NY
101239	Northport Bay, south of Duck I. Bluff, Long Island Sound, New York Current	NOS	ACT3121_1	40.91667	-73.38333	:America/New_York	USA	knots	286	7	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:20:00	\N	0.1	00:46:00	\N	0.1	00:29:00	00:08:00	Northport Bay, south of Duck I. Bluff	NY
101240	Long Neck Point, 0.6 mi south of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT3126_1	41.02633	-73.478	:America/New_York	USA	knots	73	252	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:01:00	\N	0.1	-00:10:00	\N	0.3	-01:12:00	01:24:00	Long Neck Point, 0.6 mile south of	CT
101241	Long Neck Point, 0.6 mi south of (depth 27 ft), Long Island Sound, Connecticut Current	NOS	ACT3126_2	41.02633	-73.478	:America/New_York	USA	knots	80	257	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:03:00	\N	0.1	-00:13:00	\N	0.2	-00:57:00	01:22:00	Long Neck Point, 0.6 mile south of	CT
101242	Lloyd Point, 1.3 mi NNW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3131_1	40.96583	-73.495	:America/New_York	USA	knots	55	255	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:53:00	\N	0.2	00:49:00	\N	0.3	01:24:00	01:30:00	Lloyd Point, 1.3 miles NNW of	NY
101243	Lloyd Point, 1.3 mi NNW of (depth 40 ft), Long Island Sound, New York Current	NOS	ACT3131_2	40.96583	-73.495	:America/New_York	USA	knots	53	269	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:25:00	\N	0.2	00:08:00	\N	0.3	00:00:00	01:17:00	Lloyd Point, 1.3 miles NNW of	NY
101244	Shippan Point, 1.3 mi SSE of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT3136_1	40.99967	-73.51717	:America/New_York	USA	knots	55	239	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:04:00	\N	0.1	00:02:00	\N	0.3	00:36:00	00:23:00	Shippan Point, 1.3 miles SSE of	CT
101245	Shippan Point, 1.3 mi SSE of (depth 40 ft), Long Island Sound, Connecticut Current	NOS	ACT3136_2	40.99967	-73.51717	:America/New_York	USA	knots	71	247	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:22:00	\N	0.2	00:06:00	\N	0.2	00:18:00	00:56:00	Shippan Point, 1.3 miles SSE of	CT
101246	Rocky Point, 1 mi east of (depth 15 ft), Oyster Bay, Long Island Sound, New York Current	NOS	ACT3151_1	40.91917	-73.5005	:America/New_York	USA	knots	306	117	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:30:00	\N	0.1	00:15:00	\N	0.2	00:19:00	00:24:00	Rocky Point, 1 mile east of	NY
101247	Harbor ent., south of Plum Point (depth 7 ft), Long Island Sound, New York Current	NOS	ACT3156_1	40.9	-73.51667	:America/New_York	USA	knots	54	244	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:11:00	\N	0.2	-00:01:00	\N	0.2	-00:06:00	00:00:00	Harbor ent., south of Plum Point	NY
101248	Harbor, west of Soper Point (depth 7 ft), Oyster Bay, Long Island Sound, New York Current	NOS	ACT3161_1	40.88333	-73.53333	:America/New_York	USA	knots	140	333	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:11:00	\N	0.1	00:20:00	\N	0.2	00:24:00	-00:03:00	Harbor, west of Soper Point	NY
101249	Greenwich Point, 1.1 mi south of (depth 15 ft), Long Island Sound, Connecticut Current	NOS	ACT3171_1	40.98367	-73.567	:America/New_York	USA	knots	73	258	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	01:01:00	\N	0.2	00:58:00	\N	0.2	01:21:00	01:49:00	Greenwich Point, 1.1 miles south of	CT
101250	Greenwich Point, 1.1 mi south of (depth 55 ft), Long Island Sound, Connecticut Current	NOS	ACT3171_2	40.98367	-73.567	:America/New_York	USA	knots	69	265	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	01:03:00	\N	0.1	00:51:00	\N	0.2	01:24:00	00:51:00	Greenwich Point, 1.1 miles south of	CT
101251	Greenwich Point, 2.5 mi south of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3176_1	40.96	-73.56133	:America/New_York	USA	knots	52	242	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:29:00	\N	0.2	00:10:00	\N	0.2	00:47:00	00:57:00	Greenwich Point, 2.5 miles south of	NY
101252	Greenwich Point, 2.5 mi south of (depth 55 ft), Long Island Sound, New York Current	NOS	ACT3176_2	40.96	-73.56133	:America/New_York	USA	knots	79	256	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:17:00	\N	0.1	-00:04:00	\N	0.2	-01:07:00	-00:27:00	Greenwich Point, 2.5 miles south of	NY
101253	Oak Neck Point, 0.6 mi north of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3181_1	40.925	-73.567	:America/New_York	USA	knots	72	260	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	02:11:00	\N	0.2	01:58:00	\N	0.2	02:51:00	02:25:00	Oak Neck Point, 0.6 mile north of	NY
101254	Oak Neck Point, 0.6 mi north of (depth 30 ft), Long Island Sound, New York Current	NOS	ACT3181_2	40.925	-73.567	:America/New_York	USA	knots	90	300	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	01:51:00	\N	0.1	01:35:00	\N	0.2	00:54:00	01:41:00	Oak Neck Point, 0.6 mile north of	NY
101255	Cos Cob Harbor, off Goose Island, Long Island Sound, Connecticut Current	NOS	ACT3186_1	41.01667022705078	-73.5999984741211	:America/New_York	USA	knots	188	13	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:55:00	\N	0.1	-00:15:00	\N	0.2	00:11:00	00:00:00	Cos Cob Harbor, off Goose Island	CT
101256	Captain Hbr. ent., 0.6 mi southwest of (depth 15 ft), Connecticut Current	NOS	ACT3191_1	40.99417	-73.5945	:America/New_York	USA	knots	118	312	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	02:00:00	\N	0.2	01:44:00	\N	0.2	01:32:00	01:49:00	Captain Hbr. Ent., 0.6 mile southwest of	CT
101257	Captain Hbr. ent., 0.6 mi southwest of (depth 30 ft), Connecticut Current	NOS	ACT3191_2	40.99417	-73.5945	:America/New_York	USA	knots	142	319	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	01:58:00	\N	0.2	01:14:00	\N	0.2	01:22:00	00:58:00	Captain Hbr. Ent., 0.6 mile southwest of	CT
101258	Parsonage Point, 1.3 nmi ESE of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3196_1	40.9375	-73.65817	:America/New_York	USA	knots	51	230	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	01:00:00	\N	0.1	00:24:00	\N	0.2	00:47:00	01:10:00	Parsonage Point, 1.3 n.mi. ESE of	NY
101259	Peningo Neck, 0.6 mi off Parsonage Pt (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3201_1	40.93867	-73.675	:America/New_York	USA	knots	35	226	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:27:00	\N	0.2	00:23:00	\N	0.2	01:09:00	01:16:00	Peningo Neck, 0.6 mi. off Parsonage Pt	NY
101260	Matinecock Point, 0.7 mi NNW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3211_1	40.91333	-73.64	:America/New_York	USA	knots	46	233	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:36:00	\N	0.1	00:27:00	\N	0.2	01:14:00	01:34:00	Matinecock Point, 0.7 mile NNW of	NY
101261	Matinecock Point, 0.7 mi NNW of (depth 40 ft), Long Island Sound, New York Current	NOS	ACT3211_2	40.91333	-73.64	:America/New_York	USA	knots	53	262	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	00:20:00	\N	0.1	00:07:00	\N	0.2	00:35:00	01:33:00	Matinecock Point, 0.7 mile NNW of	NY
101262	Hempstead Harbor, off Glenwood Landing (depth 10 ft), Long Island Sound, New York Current	NOS	ACT3226_1	40.828	-73.65	:America/New_York	USA	knots	320	138	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:59:00	\N	0.2	-00:19:00	\N	0.3	-00:38:00	00:03:00	Hempstead Harbor, off Glenwood Landing	NY
101263	Delancey Point, 1 mi southeast of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3236_1	40.91667	-73.71217	:America/New_York	USA	knots	59	244	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98772	-00:05:00	\N	0.1	00:09:00	\N	0.2	00:45:00	01:14:00	Delancey Point, 1 mile southeast of	NY
101264	Huckleberry Island, 0.2 mi NW of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3256_1	40.8905	-73.75717	:America/New_York	USA	knots	234	69	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98880	-03:40:00	\N	0.2	-04:16:00	\N	0.1	-03:25:00	-03:21:00	Huckleberry Island, 0.2 mile NW of	NY
101265	Huckleberry Island, 0.6 mi SE of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3261_1	40.88	-73.74583	:America/New_York	USA	knots	226	25	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98880	-02:24:00	\N	0.3	-00:33:00	\N	0.2	-02:35:00	-01:53:00	Huckleberry Island, 0.6 mile SE of	NY
101266	Manhasset Bay entrance (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3271_1	40.82917	-73.72967	:America/New_York	USA	knots	307	115	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98880	03:04:00	\N	0.3	02:18:00	\N	0.2	02:48:00	02:48:00	Manhasset Bay entrance	NY
101267	Hart Island, 0.3 nmi SSE of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3286_1	40.8405	-73.76567	:America/New_York	USA	knots	201	40	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98880	-01:10:00	\N	0.5	-01:28:00	\N	0.3	-01:37:00	-01:46:00	Hart Island, 0.3 n.mi. SSE of	NY
101268	City Island Bridge (depth 10 ft), Long Island Sound, New York Current	NOS	ACT3296_1	40.85783	-73.79333	:America/New_York	USA	knots	198	352	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98880	-04:13:00	\N	0.4	-05:01:00	\N	0.1	-03:09:00	-04:06:00	City Island Bridge	NY
101269	Eastchester Bay, near Big Tom (depth 5 ft), Long Island Sound, New York Current	NOS	ACT3301_1	40.83667	-73.79533	:America/New_York	USA	knots	294	97	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98880	-03:14:00	\N	0.4	-04:00:00	\N	0.2	-03:15:00	-03:46:00	Eastchester Bay, near Big Tom	NY
101270	Hutchinson R., Pelham Highway Bridge (depth 5 ft), Long Island Sound, New York Current	NOS	ACT3306_1	40.86167	-73.81667	:America/New_York	USA	knots	78	305	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98880	02:13:00	\N	0.4	02:28:00	\N	0.5	02:31:00	02:12:00	Hutchinson R., Pelham Highway Bridge	NY
101271	Throgs Neck, 0.3 nmi NE of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3321_1	40.81067	-73.7855	:America/New_York	USA	knots	193	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98880	00:08:00	\N	0.6	-00:40:00	\N	0.6	-00:31:00	-00:52:00	Throgs Neck, 0.3 n.mi. NE of	NY
101272	Throgs Neck, 0.4 mi south of (depth 15 ft), Long Island Sound, New York Current	NOS	ACT3326_1	40.79833	-73.79083	:America/New_York	USA	knots	278	90	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98880	00:19:00	\N	0.6	00:09:00	\N	0.5	00:26:00	00:41:00	Throgs Neck, 0.4 mile south of	NY
101273	Throgs Neck, 0.2 mi S of (Willets Point) (depth 15 ft), New York Current	NOS	ACT3331_1	40.802	-73.79133	:America/New_York	USA	knots	289	90	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98880	00:13:00	\N	0.7	-00:09:00	\N	0.4	-00:10:00	00:21:00	Throgs Neck, 0.2 mile S of (Willets Point)	NY
101274	Cryders Point, 0.4 mi NNW of, East River, New York Current	NOS	ACT3341_1	40.80030059814453	-73.79869842529297	:America/New_York	USA	knots	285	110	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	-00:59:00	\N	0.26	-00:45:00	\N	0.39	-00:26:00	-00:20:00	Cryders Point, 0.4 mile NNW of	NY
101275	Bronx-Whitestone Bridge, east of (depth 14 ft), East River, New York Current	NOS	ACT3346_1	40.801700592041016	-73.82669830322266	:America/New_York	USA	knots	247	76	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	-01:26:00	\N	0.23	-00:48:00	\N	0.5	-00:31:00	00:00:00	Bronx-Whitestone Bridge, East of	NY
101276	College Point Reef, 0.25 nmi NW of (depth 15 ft), East River, New York Current	NOS	ACT3356_1	40.80099868774414	-73.85469818115234	:America/New_York	USA	knots	261	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	-00:56:00	\N	0.3	-00:51:00	\N	0.45	-00:30:00	00:09:00	College Point Reef, 0.25 n.mi. NW of	NY
101277	Rikers I. chan., off La Guardia Field, East River, New York Current	NOS	ACT3366_1	40.78329849243164	-73.88330078125	:America/New_York	USA	knots	261	88	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	-00:07:00	\N	0.31	-00:06:00	\N	0.33	00:07:00	00:14:00	Rikers I. chan., off La Guardia Field	NY
101278	Hunts Point, southwest of, East River, New York Current	NOS	ACT3376_1	40.79999923706055	-73.88330078125	:America/New_York	USA	knots	280	108	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	-00:04:00	\N	0.31	-00:12:00	\N	0.51	00:04:00	00:11:00	Hunts Point, southwest of	NY
101279	South Brother Island, NW of (depth 15 ft), East River, New York Current	NOS	ACT3381_1	40.79669952392578	-73.90170288085938	:America/New_York	USA	knots	252	54	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	-00:11:00	\N	0.29	00:02:00	\N	0.45	-00:14:00	00:04:00	South Brother Island, NW of	NY
101280	Off Winthrop Ave., Astoria, East River, New York Current	NOS	ACT3386_1	40.78670120239258	-73.91670227050781	:America/New_York	USA	knots	220	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	-00:10:00	\N	0.6	00:00:00	\N	1.02	00:07:00	00:09:00	Off Winthrop Ave., Astoria	NY
101281	Roosevelt Is., west of, off 75th Street, East River, New York Current	NOS	ACT3406_1	40.766700744628906	-73.94999694824219	:America/New_York	USA	knots	215	37	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	00:08:00	\N	1.12	-00:06:00	\N	0.6	00:01:00	-00:02:00	Roosevelt Is., west of, off 75th Street	NY
101282	Roosevelt Is., east of, off 36th Avenue, East River, New York Current	NOS	ACT3411_1	40.76359939575195	-73.94550323486328	:America/New_York	USA	knots	210	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	-00:10:00	\N	0.81	-00:06:00	\N	1.05	-00:05:00	00:02:00	Roosevelt Island, east of, off 36th Avenue	NY
101283	Roosevelt Is., west of, off 67th Street, East River, New York Current	NOS	ACT3416_1	40.762298583984375	-73.9540023803711	:America/New_York	USA	knots	230	11	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	00:12:00	\N	0.95	-00:10:00	\N	1.08	00:16:00	00:16:00	Roosevelt Is., west of, off 67th Street	NY
101284	Roosevelt Is., west of, off 63rd Street, East River, New York Current	NOS	ACT3421_1	40.759700775146484	-73.95449829101562	:America/New_York	USA	knots	223	36	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	00:04:00	\N	0.69	-00:10:00	\N	0.84	-00:07:00	00:10:00	Roosevelt Is., west of, off 63rd Street	NY
101285	Roosevelt Island, east of, East River, New York Current	NOS	ACT3426_1	40.758201599121094	-73.95130157470703	:America/New_York	USA	knots	200	28	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	00:08:00	\N	0.62	-00:08:00	\N	0.84	00:03:00	00:12:00	Roosevelt Island, east of	NY
101286	Manhattan, off 31st Street, East River, New York Current	NOS	ACT3431_1	40.73970031738281	-73.96949768066406	:America/New_York	USA	knots	175	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	00:37:00	\N	0.5	-00:13:00	\N	0.45	00:12:00	00:08:00	Manhattan, off 31st Street	NY
101287	Willis Ave. Bridge, 0.1 mi NW of, Harlem River, New York Current	NOS	ACT3481_1	40.805	-73.93	:America/New_York	USA	knots	330	140	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	-00:12:00	\N	0.31	-00:02:00	\N	0.36	-00:27:00	-00:02:00	Willis Ave. Bridge, 0.1 mile NW of	NY
101288	Madison Ave. Bridge, Harlem River, New York Current	NOS	ACT3486_1	40.81330108642578	-73.93499755859375	:America/New_York	USA	knots	0	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	-00:13:00	\N	0.41	00:16:00	\N	0.54	-00:17:00	-00:11:00	Madison Ave. Bridge	NY
101289	Macombs Dam Bridge, Harlem River, New York Current	NOS	ACT3491_1	40.82830047607422	-73.93499755859375	:America/New_York	USA	knots	0	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	-00:10:00	\N	0.33	00:12:00	\N	0.51	-00:17:00	-00:12:00	Macombs Dam Bridge	NY
101290	High Bridge, Harlem River, New York Current	NOS	ACT3496_1	40.84170150756836	-73.93170166015625	:America/New_York	USA	knots	15	189	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	-00:07:00	\N	0.48	00:06:00	\N	0.6	-00:17:00	-00:13:00	High Bridge	NY
101291	West 207th Street Bridge, Harlem River, New York Current	NOS	ACT3501_1	40.86330032348633	-73.91500091552734	:America/New_York	USA	knots	35	215	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	-00:01:00	\N	0.48	00:03:00	\N	0.6	-00:19:00	-00:12:00	West 207th Street Bridge	NY
101292	Broadway Bridge, Harlem River, New York Current	NOS	ACT3506_1	40.87329864501953	-73.91169738769531	:America/New_York	USA	knots	299	116	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	00:05:00	\N	0.55	00:06:00	\N	0.63	-00:20:00	-00:10:00	Broadway Bridge	NY
101293	Henry Hudson Bridge, 0.7 nmi SE of (depth 16 ft), Harlem River, New York Current	NOS	ACT3511_1	40.87670135498047	-73.92169952392578	:America/New_York	USA	knots	326	137	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98978	00:42:00	\N	0.3	00:29:00	\N	0.23	00:15:00	-00:21:00	Henry Hudson Bridge, 0.7 nmi. SE of	NY
101294	Ponquogue bridge, Shinnecock Bay, Long Island, New York Current	NOS	ACT3531_1	40.845001220703125	-72.50170135498047	:America/New_York	USA	knots	90	250	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	00:38:00	\N	0.4	00:35:00	\N	0.6	01:17:00	00:24:00	Ponquogue bridge, Shinnecock Bay	NY
101295	Shinnecock Inlet, Long Island, New York Current	NOS	ACT3536_1	40.843299865722656	-72.47830200195312	:America/New_York	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-01:02:00	\N	1.44	-00:21:00	\N	1.88	00:17:00	-00:33:00	Shinnecock Inlet	NY
101296	Fire I. Inlet, 0.5 mi S of Oak Beach, Long Island, New York Current	NOS	ACT3541_1	40.62969970703125	-73.30670166015625	:America/New_York	USA	knots	244	82	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	00:00:00	\N	1.5	-00:01:00	\N	1.81	00:20:00	00:26:00	Fire I. Inlet, 0.5 mi. S of Oak Beach	NY
101297	Jones Inlet, Long Island, New York Current	NOS	ACT3546_1	40.59170150756836	-73.56670379638672	:America/New_York	USA	knots	217	35	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-01:04:00	\N	1.63	-00:49:00	\N	2.33	-00:52:00	-00:51:00	Jones Inlet	NY
101298	Long Beach, inside, between bridges, Long Island, New York Current	NOS	ACT3551_1	40.595001220703125	-73.66000366210938	:America/New_York	USA	knots	277	76	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	00:01:00	\N	0.38	00:23:00	\N	0.38	00:31:00	00:29:00	Long Beach, inside, between bridges	NY
101299	East Rockaway Inlet, Long Island, New York Current	NOS	ACT3556_1	40.59000015258789	-73.75499725341797	:America/New_York	USA	knots	227	42	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-01:37:00	\N	1.44	-01:35:00	\N	1.66	-01:23:00	-01:06:00	East Rockaway Inlet	NY
101300	Rockaway Point (depth 15 ft), Jamaica Bay, New York Current	NOS	ACT3571_1	40.53630065917969	-73.94129943847656	:America/New_York	USA	knots	140	301	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-03:01:00	\N	0.68	-02:34:00	\N	1.43	-02:13:00	-01:41:00	Rockaway Point	NY
101301	Beach Channel (bridge), Jamaica Bay, New York Current	NOS	ACT3596_1	40.58330154418945	-73.81670379638672	:America/New_York	USA	knots	225	62	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-01:19:00	\N	1.23	-01:13:00	\N	1.43	-01:25:00	-01:00:00	Beach Channel (bridge)	NY
101302	Grass Hassock Channel, Jamaica Bay, New York Current	NOS	ACT3601_1	40.61000061035156	-73.78500366210938	:America/New_York	USA	knots	228	52	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-00:53:00	\N	0.63	-01:02:00	\N	0.75	-00:58:00	-01:00:00	Grass Hassock Channel	NY
101303	Norton Point, WSW of (depth 16 ft), New York Harbor entrance, New York Current	NOS	ACT3611_1	40.55500030517578	-74.02169799804688	:America/New_York	USA	knots	166	341	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	00:28:00	\N	0.77	-01:01:00	\N	0.75	00:10:00	00:23:00	Norton Point, WSW of	NY
101304	Bay Ridge, west of (depth 22 ft), Upper Bay, New York Harbor, New York Current	NOS	ACT3621_1	40.625701904296875	-74.05400085449219	:America/New_York	USA	knots	185	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	01:00:00	\N	0.93	00:20:00	\N	1.04	00:12:00	00:39:00	Bay Ridge, west of	NY
101305	Statue of Liberty, east of, Upper Bay, New York Harbor, New York Current	NOS	ACT3646_1	40.689998626708984	-74.02999877929688	:America/New_York	USA	knots	205	31	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	01:00:00	\N	1.19	00:58:00	\N	1.05	01:20:00	00:53:00	Statue of Liberty, east of	NY
101306	Grants Tomb (depth 18 ft), Hudson River (midchannel), New York Current	NOS	ACT3656_1	40.808	-73.96767	:America/New_York	USA	knots	208	25	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98640	-00:33:00	\N	0.7	-00:22:00	\N	1	-00:13:00	00:11:00	Grants Tomb	NY
101307	Riverdale, Hudson River (midchannel), New York Current	NOS	ACT3671_1	40.9	-73.91667	:America/New_York	USA	knots	200	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98640	00:32:00	\N	0.8	00:27:00	\N	0.8	00:54:00	00:15:00	Riverdale	NY
101308	Mount St. Vincent College, SW of (depth 15 ft), New York Current	NOS	ACT3676_1	40.907	-73.908	:America/New_York	USA	knots	190	7	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98640	00:29:00	\N	0.5	00:20:00	\N	0.8	00:09:00	00:27:00	Mount St. Vincent College, SW of	NY
101309	Dobbs Ferry, Hudson River (midchannel), New York Current	NOS	ACT3681_1	41.01667	-73.88333	:America/New_York	USA	knots	\N	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98640	00:49:00	\N	0.7	00:53:00	\N	0.7	01:13:00	00:37:00	Dobbs Ferry	NY
101310	Tarrytown, Hudson River (midchannel), New York Current	NOS	ACT3691_1	41.08333	-73.88333	:America/New_York	USA	knots	\N	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98640	01:02:00	\N	0.6	01:06:00	\N	0.6	01:20:00	00:53:00	Tarrytown	NY
101311	Ossining, Hudson River (midchannel), New York Current	NOS	ACT3696_1	41.16667	-73.9	:America/New_York	USA	knots	\N	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98640	01:19:00	\N	0.5	01:22:00	\N	0.5	01:33:00	01:16:00	Ossining	NY
101312	Peekskill, Hudson River (midchannel), New York Current	NOS	ACT3711_1	41.28333	-73.95	:America/New_York	USA	knots	\N	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98640	01:42:00	\N	0.5	01:44:00	\N	0.5	01:53:00	01:46:00	Peekskill	NY
101313	Highland Falls, Hudson River (midchannel), New York Current	NOS	ACT3721_1	41.36667	-73.96667	:America/New_York	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98640	02:02:00	\N	0.5	01:57:00	\N	0.6	02:07:00	01:57:00	Highland Falls	NY
101314	West Point, off Duck Island, Hudson River (midchannel), New York Current	NOS	ACT3726_1	41.4	-73.95	:America/New_York	USA	knots	\N	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98640	02:04:00	\N	0.4	02:07:00	\N	0.6	02:15:00	02:04:00	West Point, off Duck Island	NY
101315	New Hamburg, Hudson River (midchannel), New York Current	NOS	ACT3741_1	41.58333	-73.95	:America/New_York	USA	knots	\N	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98640	02:33:00	\N	0.4	02:40:00	\N	0.6	02:48:00	02:24:00	New Hamburg	NY
101316	Hyde Park, Hudson River (midchannel), New York Current	NOS	ACT3751_1	41.78333	-73.95	:America/New_York	USA	knots	\N	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98640	03:00:00	\N	0.5	03:08:00	\N	0.7	03:25:00	02:43:00	Hyde Park	NY
101317	Barrytown, Hudson River (midchannel), New York Current	NOS	ACT3766_1	42	-73.93333	:America/New_York	USA	knots	\N	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98642	-00:04:00	\N	1.3	00:24:00	\N	1.3	00:21:00	-00:05:00	Barrytown	NY
101318	Saugerties, Hudson River (midchannel), New York Current	NOS	ACT3771_1	42.06667	-73.93333	:America/New_York	USA	knots	\N	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98642	00:06:00	\N	1.5	00:45:00	\N	1.4	00:38:00	00:14:00	Saugerties	NY
101320	New Baltimore, Hudson River (midchannel), New York Current	NOS	ACT3801_1	42.45	-73.78333	:America/New_York	USA	knots	\N	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98642	01:58:00	\N	1.1	02:07:00	\N	1.2	02:07:00	01:58:00	New Baltimore	NY
101321	Sandy Hook Chan., 0.4 mi W of N. Tip, Lower Bay, New York Harbor, New Jersey Current	NOS	ACT3826_1	40.479801177978516	-74.02169799804688	:America/New_York	USA	knots	50	235	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-01:49:00	\N	1	-01:55:00	\N	1.51	-01:28:00	-01:33:00	Sandy Hook Chan., 0.4 mi. W of N. Tip	NJ
101322	New Dorp Beach, 1.2 mi south of, Lower Bay, New York Harbor, New York Current	NOS	ACT3841_1	40.540000915527344	-74.0967025756836	:America/New_York	USA	knots	30	225	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-04:15:00	\N	0.31	-03:36:00	\N	0.3	-03:56:00	-04:38:00	New Dorp Beach, 1.2 miles south of	NY
101323	Old Orchard Shoal Lt., 1.2 mi ENE of, Lower Bay, New York Harbor, New York Current	NOS	ACT3846_1	40.5182991027832	-74.07330322265625	:America/New_York	USA	knots	85	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-02:01:00	\N	0.25	-02:07:00	\N	0.53	-01:56:00	-01:26:00	Old Orchard Shoal Lt., 1.2 mi. ENE of	NY
101324	Coney Island Lt., 1.5 mi SSE of, Lower Bay, New York Harbor, New York Current	NOS	ACT3861_1	40.551700592041016	-74.00499725341797	:America/New_York	USA	knots	125	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-00:52:00	\N	0.81	-01:56:00	\N	0.83	-01:04:00	-01:01:00	Coney Island Lt., 1.5 miles SSE of	NY
101325	Hoffman Island, 0.2 mi west of, Lower Bay, New York Harbor, New York Current	NOS	ACT3866_1	40.58330154418945	-74.06670379638672	:America/New_York	USA	knots	210	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-00:49:00	\N	0.5	-01:48:00	\N	0.68	-01:20:00	-00:20:00	Hoffman Island, 0.2 mile west of	NY
101326	Coney Island Channel, west end, Lower Bay, New York Harbor, New York Current	NOS	ACT3876_1	40.56999969482422	-74.00830078125	:America/New_York	USA	knots	102	293	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-00:47:00	\N	0.75	-00:44:00	\N	0.83	-00:58:00	-00:27:00	Coney Island Channel, west end	NY
101327	Seabright Bridge, Shrewsbury River, New Jersey Current	NOS	ACT3886_1	40.3650016784668	-73.9749984741211	:America/New_York	USA	knots	0	185	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	00:52:00	\N	1.06	01:06:00	\N	1.05	01:18:00	00:49:00	Seabright Bridge, Shrewsbury River	NJ
101328	Raritan Bay Reach Channel (depth 15 ft), New Jersey Current	NOS	ACT3891_1	40.48929977416992	-74.1176986694336	:America/New_York	USA	knots	94	285	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-00:50:00	\N	0.22	-02:40:00	\N	0.44	-01:42:00	-00:41:00	Raritan Bay Reach Channel	NJ
101329	Red Bank, 1.4 mi south of, Raritan Bay, New York Current	NOS	ACT3901_1	40.4817008972168	-74.20999908447266	:America/New_York	USA	knots	79	278	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-01:43:00	\N	0.31	-02:12:00	\N	0.45	-01:22:00	-01:25:00	Red Bank, 1.4 miles south of	NY
101330	Seguine Point (depth 14 ft), Raritan Bay, New York Current	NOS	ACT3906_1	40.50400161743164	-74.185302734375	:America/New_York	USA	knots	79	281	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-02:07:00	\N	0.19	-02:50:00	\N	0.53	-01:39:00	-00:51:00	Seguine Point	NY
101331	Seguine Point (depth 34 ft), Raritan Bay, New York Current	NOS	ACT3906_2	40.50400161743164	-74.185302734375	:America/New_York	USA	knots	105	285	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-02:07:00	\N	0.19	-02:50:00	\N	0.53	-01:39:00	-00:51:00	Seguine Point	NY
101332	Ward Point, ESE (depth 14 ft), Raritan Bay, New York Current	NOS	ACT3911_1	40.48830032348633	-74.22470092773438	:America/New_York	USA	knots	48	244	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-00:53:00	\N	0.34	-01:58:00	\N	0.56	-01:32:00	-00:14:00	Ward Point, ESE	NY
101333	Washington Canal, north entrance, Raritan River, New Jersey Current	NOS	ACT3921_1	40.47169876098633	-74.36830139160156	:America/New_York	USA	knots	60	240	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-02:50:00	\N	0.94	-01:25:00	\N	1.13	-00:49:00	-01:33:00	Washington Canal, north entrance	NJ
101334	South River entrance, Raritan River, New Jersey Current	NOS	ACT3926_1	40.47829818725586	-74.37830352783203	:America/New_York	USA	knots	0	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-01:43:00	\N	0.63	-02:14:00	\N	0.83	-01:32:00	-00:30:00	South River entrance	NJ
101335	Tottenville, Arthur Kill River (depth 15 ft), New York Current	NOS	ACT3931_1	40.513301849365234	-74.25499725341797	:America/New_York	USA	knots	211	23	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-01:22:00	\N	0.68	-01:25:00	\N	0.79	-00:51:00	-00:36:00	Tottenville, Arthur Kill River	NY
101336	Tottenville, Arthur Kill River (depth 32 ft), New York Current	NOS	ACT3931_2	40.513301849365234	-74.25499725341797	:America/New_York	USA	knots	207	26	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-01:02:00	\N	0.29	-01:05:00	\N	0.46	-01:10:00	-00:51:00	Tottenville, Arthur Kill River	NY
101337	Tufts Point-Smoking Point, Arthur Kill, New York Current	NOS	ACT3936_1	40.55670166015625	-74.22329711914062	:America/New_York	USA	knots	267	109	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-01:07:00	\N	0.75	-00:44:00	\N	0.9	-00:25:00	-00:27:00	Tufts Point-Smoking Point	NY
101338	Elizabethport, Arthur Kill, New Jersey Current	NOS	ACT3946_1	40.64670181274414	-74.18170166015625	:America/New_York	USA	knots	262	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	00:05:00	\N	0.69	-00:09:00	\N	1.05	00:28:00	00:29:00	Elizabethport	NJ
101339	Bergen Point, East Reach (depth 15 ft), Kill Van Kull, New York Current	NOS	ACT3956_1	40.64030075073242	-74.12470245361328	:America/New_York	USA	knots	94	274	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-01:43:00	\N	0.73	-02:13:00	\N	0.81	-01:11:00	-01:37:00	Bergen Point, East Reach	NY
101340	South Reach, Newark Bay (depth 15 ft), New Jersey Current	NOS	ACT3966_1	40.65599822998047	-74.13729858398438	:America/New_York	USA	knots	218	31	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-01:05:00	\N	0.46	-01:45:00	\N	0.51	-00:33:00	-00:54:00	South Reach, Newark Bay	NJ
101341	Lincoln Highway Bridge, Hackensack River, Newark Bay, New Jersey Current	NOS	ACT3971_1	40.733299255371094	-74.0999984741211	:America/New_York	USA	knots	181	17	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-00:13:00	\N	0.5	00:12:00	\N	0.68	00:17:00	00:44:00	Lincoln Highway Bridge, Hackensack River	NJ
101342	Lincoln Highway Bridge, Passaic River, Newark Bay, New Jersey Current	NOS	ACT3976_1	40.733299255371094	-74.11669921875	:America/New_York	USA	knots	180	9	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100716	-00:26:00	\N	0.31	-00:19:00	\N	0.45	-00:08:00	-00:15:00	Lincoln Highway Bridge, Passaic River	NJ
101343	Manasquan Inlet, New Jersey Current	NOS	ACT3986_1	40.1	-74.03333	:America/New_York	USA	knots	120	300	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-01:53:00	\N	1.1	-01:09:00	\N	1	-01:03:00	-01:39:00	Manasquan Inlet	NJ
101344	Manasquan R., hwy. bridge, main chan, New Jersey Current	NOS	ACT3991_1	40.1	-74.05	:America/New_York	USA	knots	50	230	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-00:46:00	\N	1.2	-01:29:00	\N	1.3	-01:01:00	-01:42:00	Manasquan R., hwy. bridge, main chan	NJ
101345	Point Pleasant Canal, north bridge, New Jersey Current	NOS	ACT3996_1	40.08333	-74.06667	:America/New_York	USA	knots	350	170	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	01:14:00	\N	1.2	00:49:00	\N	1	01:26:00	00:21:00	Point Pleasant Canal, north bridge	NJ
101346	Barnegat Inlet, New Jersey Current	NOS	ACT4001_1	39.76667	-74.11667	:America/New_York	USA	knots	90	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-00:08:00	\N	1.5	-00:27:00	\N	1.3	00:41:00	-00:12:00	Barnegat Inlet	NJ
101347	Manahawkin Drawbridge, New Jersey Current	NOS	ACT4006_1	39.65	-74.18333	:America/New_York	USA	knots	210	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	03:25:00	\N	0.5	02:04:00	\N	0.6	02:13:00	01:58:00	Manahawkin Drawbridge	NJ
101348	Absecon Inlet (depth 9 ft), New Jersey Current	NOS	ACT4011_1	39.3765	-74.4145	:America/New_York	USA	knots	147	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-02:14:00	\N	1.2	-01:30:00	\N	1.3	-01:27:00	-01:21:00	Absecon Inlet	NJ
101349	Absecon Inlet (depth 42 ft), New Jersey Current	NOS	ACT4011_2	39.3765	-74.4145	:America/New_York	USA	knots	144	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-02:04:00	\N	1.1	-01:45:00	\N	1.1	-01:22:00	-01:23:00	Absecon Inlet	NJ
101350	Five Fathom Bank Traffic Lane (depth 35 ft), New Jersey Current	NOS	ACT4031_1	38.78833	-74.71133	:America/New_York	USA	knots	121	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-01:36:00	\N	0.2	-02:21:00	\N	0.3	-02:10:00	-01:29:00	Five Fathom Bank Traffic Lane	NJ
101351	Five Fathom Bank Traffic Lane (depth 50 ft), New Jersey Current	NOS	ACT4031_2	38.78833	-74.71133	:America/New_York	USA	knots	128	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-02:16:00	\N	0.2	-01:57:00	\N	0.2	-02:44:00	-01:48:00	Five Fathom Bank Traffic Lane	NJ
101352	McCrie Shoal, New Jersey Current	NOS	ACT4036_1	38.85	-74.85	:America/New_York	USA	knots	100	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-01:00:00	\N	0.8	-01:05:00	\N	0.7	-00:54:00	-01:10:00	McCrie Shoal	NJ
101353	Cape May Canal, east end, New Jersey Current	NOS	ACT4046_1	38.95	-74.9	:America/New_York	USA	knots	130	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-02:01:00	\N	1.1	-02:27:00	\N	1.1	-02:07:00	-02:20:00	Cape May Canal, east end	NJ
101354	Cape May Channel, New Jersey Current	NOS	ACT4056_1	38.9	-74.96667	:America/New_York	USA	knots	150	306	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-01:41:00	\N	1.4	-02:09:00	\N	0.9	-01:34:00	-01:38:00	Cape May Channel	NJ
101355	Cape May Point, 1.4 nmi SSW of (depth 15 ft), New Jersey Current	NOS	ACT4061_1	38.90617	-74.978	:America/New_York	USA	knots	130	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-01:43:00	\N	1.1	-01:57:00	\N	0.9	-01:23:00	-01:29:00	Cape May Point, 1.4 n.mi. SSW of	NJ
101356	Cape May Point, 1.4 nmi SSW of (depth 25 ft), New Jersey Current	NOS	ACT4061_2	38.90617	-74.978	:America/New_York	USA	knots	139	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-01:37:00	\N	0.7	-01:44:00	\N	0.6	-01:16:00	-01:27:00	Cape May Point, 1.4 n.mi. SSW of	NJ
101357	Cape May Point, 2.7 nmi SSW of (depth 15 ft), New Jersey Current	NOS	ACT4066_1	38.89	-74.9855	:America/New_York	USA	knots	146	299	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-01:32:00	\N	0.5	-01:47:00	\N	0.7	-01:50:00	-01:14:00	Cape May Point, 2.7 n.mi. SSW of	NJ
101358	Cape Henlopen, 0.7 nmi ESE of (depth 12 ft), Delaware Current	NOS	ACT4076_1	38.7995	-75.08167	:America/New_York	USA	knots	139	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-00:59:00	\N	1.4	-00:32:00	\N	1	-00:25:00	-01:07:00	Cape Henlopen, 0.7 n.mi. ESE of	DE
101359	Cape Henlopen, 0.7 nmi ESE of (depth 70 ft), Delaware Current	NOS	ACT4076_2	38.7995	-75.08167	:America/New_York	USA	knots	150	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-00:40:00	\N	0.4	-00:35:00	\N	0.7	-01:46:00	-00:51:00	Cape Henlopen, 0.7 n.mi. ESE of	DE
101360	Cape Henlopen, 4.8 nmi northeast of (depth 18 ft), New Jersey Current	NOS	ACT4091_1	38.85917	-75.0245	:America/New_York	USA	knots	150	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-00:59:00	\N	1.1	-01:50:00	\N	0.9	-00:43:00	-01:09:00	Cape Henlopen, 4.8 n.mi. northeast of	NJ
101361	Cape Henlopen, 4.8 nmi northeast of (depth 28 ft), New Jersey Current	NOS	ACT4091_2	38.85917	-75.0245	:America/New_York	USA	knots	154	301	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-00:51:00	\N	0.7	-01:39:00	\N	0.6	-01:04:00	-01:11:00	Cape Henlopen, 4.8 n.mi. northeast of	NJ
101362	Breakwater Harbor, Delaware Current	NOS	ACT4101_1	38.79333	-75.10833	:America/New_York	USA	knots	78	266	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-01:10:00	\N	0.5	-01:29:00	\N	0.5	-01:15:00	-01:41:00	Breakwater Harbor	DE
101363	Broadkill Slough (depth 14 ft), Delaware Current	NOS	ACT4111_1	38.89633	-75.2105	:America/New_York	USA	knots	132	314	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-00:55:00	\N	0.4	-00:31:00	\N	0.5	-00:56:00	-00:30:00	Broadkill Slough	DE
101364	Mispillion River mouth, Delaware Current	NOS	ACT4116_1	38.94667	-75.315	:America/New_York	USA	knots	190	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	01:18:00	\N	0.6	01:50:00	\N	0.9	02:14:00	01:22:00	Mispillion River mouth	DE
101365	Bay Shore Channel (north) (depth 13 ft), New Jersey Current	NOS	ACT4121_1	39.078	-74.98133	:America/New_York	USA	knots	183	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-00:04:00	\N	0.4	-00:34:00	\N	0.5	-00:49:00	-00:24:00	Bay Shore Channel (north)	NJ
101366	Big Stone Beach, 2.8 mi southeast of, Delaware Current	NOS	ACT4141_1	38.97833	-75.27667	:America/New_York	USA	knots	145	326	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-01:07:00	\N	0.5	-01:30:00	\N	0.4	-01:04:00	-01:08:00	Big Stone Beach, 2.8 miles southeast of	DE
101367	Big Stone Beach, 2.2 nmi ENE of (depth 15 ft), Delaware Current	NOS	ACT4146_1	39.008	-75.28417	:America/New_York	USA	knots	135	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	00:04:00	\N	0.4	-00:26:00	\N	0.3	-00:13:00	-00:23:00	Big Stone Beach, 2.2 n.mi. ENE of	DE
101368	Fourteen Ft. Bank Lt., 1.4 nmi SSE of (depth 12 ft), New Jersey Current	NOS	ACT4151_1	39.03867	-75.158	:America/New_York	USA	knots	160	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	00:10:00	\N	0.7	-00:36:00	\N	0.7	-00:10:00	-00:14:00	Fourteen Ft. Bank Lt., 1.4 n.mi. SSE of	NJ
101369	Fourteen Ft. Bank Lt., 1.4 nmi SSE of (depth 30 ft), New Jersey Current	NOS	ACT4151_2	39.03867	-75.158	:America/New_York	USA	knots	155	343	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-00:05:00	\N	0.4	-00:32:00	\N	0.5	-00:40:00	-00:17:00	Fourteen Ft. Bank Lt., 1.4 n.mi. SSE of	NJ
101370	Fourteen Ft. Bank Lt., 1.2 mi east of, New Jersey Current	NOS	ACT4156_1	39.055	-75.15833	:America/New_York	USA	knots	174	339	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	00:05:00	\N	0.9	-00:26:00	\N	0.7	-00:10:00	00:02:00	Fourteen Ft. Bank Lt., 1.2 mi. east of	NJ
101371	Deadman Shoal, 3.1 nmi SW of (depth 13 ft), New Jersey Current	NOS	ACT4161_1	39.06667	-75.07033	:America/New_York	USA	knots	173	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-00:19:00	\N	0.4	-00:35:00	\N	0.5	-00:43:00	-00:35:00	Deadman Shoal, 3.1 n.mi. SW of	NJ
101372	Egg Island Flats, New Jersey Current	NOS	ACT4166_1	39.10667	-75.11833	:America/New_York	USA	knots	150	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-01:26:00	\N	0.4	-01:05:00	\N	0.4	-01:13:00	-00:58:00	Egg Island Flats	NJ
101373	Maurice River entrance, New Jersey Current	NOS	ACT4176_1	39.21667	-75.045	:America/New_York	USA	knots	192	12	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	00:39:00	\N	0.6	00:06:00	\N	0.6	00:31:00	00:37:00	Maurice River entrance	NJ
101374	Mauricetown Bridge, Maurice River, New Jersey Current	NOS	ACT4181_1	39.28667	-74.99333	:America/New_York	USA	knots	180	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	00:33:00	\N	1.3	00:48:00	\N	1.4	00:41:00	00:57:00	Mauricetown Bridge, Maurice River	NJ
101375	St. Jones River ent., 1 mi east of, Delaware Current	NOS	ACT4191_1	39.06667	-75.38333	:America/New_York	USA	knots	122	334	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-00:09:00	\N	0.4	-00:40:00	\N	0.3	-00:21:00	-00:16:00	St. Jones River ent., 1 mile east of	DE
101376	Kelly Island, 1.5 mi east of, Delaware Current	NOS	ACT4196_1	39.21333	-75.36167	:America/New_York	USA	knots	164	348	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	00:16:00	\N	0.7	00:11:00	\N	0.5	00:31:00	00:17:00	Kelly Island, 1.5 miles east of	DE
101377	False Egg Island Point, 2 mi off, New Jersey Current	NOS	ACT4206_1	39.19	-75.2	:America/New_York	USA	knots	158	342	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	00:06:00	\N	0.8	-00:35:00	\N	0.6	00:07:00	-00:14:00	False Egg Island Point, 2 miles off	NJ
101378	Ben Davis Pt. Shoal, southwest of (depth 15 ft), New Jersey Current	NOS	ACT4211_1	39.24783	-75.3155	:America/New_York	USA	knots	147	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	01:41:00	\N	1.1	00:51:00	\N	1	01:28:00	01:03:00	Ben Davis Pt. Shoal, southwest of	NJ
101379	Ben Davis Point, 0.8 mi southwest of, New Jersey Current	NOS	ACT4221_1	39.28167	-75.30333	:America/New_York	USA	knots	122	308	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	00:25:00	\N	0.5	00:19:00	\N	0.7	00:37:00	00:46:00	Ben Davis Point, 0.8 mile southwest of	NJ
101380	Cohansey River, 0.5 mi above entrance, New Jersey Current	NOS	ACT4226_1	39.34833	-75.36	:America/New_York	USA	knots	254	74	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	00:53:00	\N	0.8	00:41:00	\N	0.7	01:10:00	01:04:00	Cohansey River, 0.5 mile above entrance	NJ
101381	Smyrna River entrance, Delaware Current	NOS	ACT4241_1	39.365	-75.51333	:America/New_York	USA	knots	70	250	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	01:32:00	\N	0.9	01:02:00	\N	0.7	01:29:00	01:30:00	Smyrna River entrance	DE
101382	Stony Point, channel west of, Delaware Current	NOS	ACT4246_1	39.451698303222656	-75.56330108642578	:America/New_York	USA	knots	151	324	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100622	-01:09:00	\N	0.9	00:00:00	\N	0.8	00:03:00	-00:25:00	Stony Point, channel west of	DE
101383	Appoquinimink River entrance, Delaware Current	NOS	ACT4251_1	39.44670104980469	-75.58170318603516	:America/New_York	USA	knots	48	231	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100622	-01:41:00	\N	0.5	00:05:00	\N	0.6	-00:47:00	-00:41:00	Appoquinimink River entrance	DE
101384	Reedy Island (off end of pier), Delaware Current	NOS	ACT4261_1	39.51169967651367	-75.55670166015625	:America/New_York	USA	knots	194	27	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100622	-00:52:00	\N	1.2	00:11:00	\N	1.3	-00:19:00	-00:09:00	Reedy Island (off end of pier)	DE
101385	Alloway Creek ent., 0.2 mi above, New Jersey Current	NOS	ACT4266_1	39.49829864501953	-75.5250015258789	:America/New_York	USA	knots	325	129	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100622	-02:19:00	\N	0.9	-00:08:00	\N	1.2	-00:59:00	-00:44:00	Alloway Creek ent., 0.2 mile above	NJ
101386	New Bridge, Alloway Creek, New Jersey Current	NOS	ACT4271_1	39.52669906616211	-75.45169830322266	:America/New_York	USA	knots	270	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100622	-00:39:00	\N	0.6	01:07:00	\N	0.7	-00:17:00	00:33:00	New Bridge, Alloway Creek	NJ
101387	Salem River entrance, New Jersey Current	NOS	ACT4296_1	39.56999969482422	-75.50170135498047	:America/New_York	USA	knots	245	62	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100622	-00:06:00	\N	0.7	00:43:00	\N	0.8	00:26:00	00:34:00	Salem River entrance	NJ
101388	Bulkhead Shoal Channel, SE, Del. City (depth 14 ft), Delaware Current	NOS	ACT4301_1	39.57630157470703	-75.57530212402344	:America/New_York	USA	knots	118	299	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100622	-00:33:00	\N	0.9	-00:05:00	\N	1	00:04:00	00:06:00	Bulkhead Shoal Channel, SE, Del. City	DE
101389	Bulkhead Shoal Channel, off Del. City, Delaware Current	NOS	ACT4306_1	39.58330154418945	-75.58670043945312	:America/New_York	USA	knots	138	308	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100622	-00:31:00	\N	0.9	00:08:00	\N	1.2	-00:04:00	00:00:00	Bulkhead Shoal Channel, off Del. City	DE
101390	Finns Point, 0.60 nmi northwest of (depth 16 ft), Delaware Current	NOS	ACT4316_1	39.606201171875	-75.57450103759766	:America/New_York	USA	knots	152	332	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100622	-00:22:00	\N	1	00:18:00	\N	1.2	00:14:00	00:22:00	Finns Point, 0.60 n.mi. Northwest of	DE
101391	Penns Neck, 0.6 mi west of, Delaware Current	NOS	ACT4321_1	39.61750030517578	-75.58200073242188	:America/New_York	USA	knots	167	2	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100622	-00:44:00	\N	0.8	00:48:00	\N	0.9	00:18:00	00:11:00	Penns Neck, 0.6 mile west of	DE
101392	Penns Neck, 0.3 mi west of, Delaware Current	NOS	ACT4326_1	39.617801666259766	-75.57630157470703	:America/New_York	USA	knots	152	339	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100622	-00:38:00	\N	0.8	00:17:00	\N	1	00:02:00	00:05:00	Penns Neck, 0.3 mile west of	DE
101393	Christina River, 0.9 nmi above ent. (depth 15 ft), Delaware Current	NOS	ACT4351_1	39.72169876098633	-75.52950286865234	:America/New_York	USA	knots	137	303	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100622	-00:46:00	\N	0.4	00:26:00	\N	0.1	00:32:00	-00:22:00	Christina River, 0.9 n.mi. above ent	DE
101394	Hog Island, channel southeast of, Pennsylvania Current	NOS	ACT4391_1	39.86669921875	-75.21499633789062	:America/New_York	USA	knots	231	54	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100624	-00:13:00	\N	1.09	-00:03:00	\N	1.27	-00:49:00	00:15:00	Hog Island, channel southeast of	PA
101395	Eagle Point, 0.2 nmi northwest of (depth 17 ft), New Jersey Current	NOS	ACT4406_1	39.88029861450195	-75.1729965209961	:America/New_York	USA	knots	271	91	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100624	-00:29:00	\N	0.87	-00:56:00	\N	1.05	-00:27:00	00:08:00	Eagle Point, 0.2 n.mi. northwest of	NJ
101396	Eagle Point, 0.2 nmi northwest of (depth 40 ft), New Jersey Current	NOS	ACT4406_2	39.88029861450195	-75.1729965209961	:America/New_York	USA	knots	274	90	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100624	-00:29:00	\N	0.64	-01:11:00	\N	0.71	-00:33:00	00:03:00	Eagle Point, 0.2 n.mi. northwest of	NJ
101397	Smith Island Shoal, southeast of (depth 7 ft), Virginia Current	NOS	ACT4496_1	37.08833	-75.725	:America/New_York	USA	knots	68	298	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:41:00	\N	0.4	-01:56:00	\N	0.3	-01:41:00	-02:15:00	Smith Island Shoal, southeast of	VA
101398	Cape Henry Light, 2.2 mi southeast of, Virginia Current	NOS	ACT4501_1	36.89833	-75.97833	:America/New_York	USA	knots	165	346	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:17:00	\N	0.8	-01:02:00	\N	0.9	-01:21:00	-00:50:00	Cape Henry Light, 2.2 miles southeast of	VA
101399	Cape Henry Light, 3.4 nmi NNE of (depth 7 ft), Chesapeake Bay, Virginia Current	NOS	ACT4506_1	36.97983	-75.98083	:America/New_York	USA	knots	116	287	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:08:00	\N	1.5	-00:39:00	\N	0.9	-00:08:00	-00:31:00	Cape Henry Light, 3.4nm NNE of	VA
101400	Cape Henry Light, 3.4 nmi NNE of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4506_2	36.97983	-75.98083	:America/New_York	USA	knots	112	284	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:12:00	\N	1.1	-00:43:00	\N	0.9	-00:19:00	-00:29:00	Cape Henry Light, 3.4nm NNE of	VA
101401	Cape Henry Light, 3.4 nmi NNE of (depth 30 ft), Chesapeake Bay, Virginia Current	NOS	ACT4506_3	36.97983	-75.98083	:America/New_York	USA	knots	104	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:45:00	\N	0.6	-00:38:00	\N	0.5	-00:54:00	-00:43:00	Cape Henry Light, 3.4nm NNE of	VA
101402	Cape Henry Light, 2.35 nmi NNE of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4511_1	36.96233	-75.98567	:America/New_York	USA	knots	116	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:00:00	\N	1.1	-00:06:00	\N	0.9	00:12:00	-00:22:00	Cape Henry Light, 2.35nm NNE of	VA
101403	Cape Henry Light, 2.35 nmi NNE of (depth 30 ft), Chesapeake Bay, Virginia Current	NOS	ACT4511_2	36.96233	-75.98567	:America/New_York	USA	knots	123	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:32:00	\N	0.9	-00:39:00	\N	1.1	-00:41:00	-00:33:00	Cape Henry Light, 2.35nm NNE of	VA
101404	Cape Henry Light, 2.35 nmi NNE of (depth 45 ft), Chesapeake Bay, Virginia Current	NOS	ACT4511_3	36.96233	-75.98567	:America/New_York	USA	knots	125	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:48:00	\N	0.8	-00:47:00	\N	1.3	-01:10:00	-00:30:00	Cape Henry Light, 2.35nm NNE of	VA
101405	Cape Henry Light, 2.35 nmi NNE of (depth 60 ft), Chesapeake Bay, Virginia Current	NOS	ACT4511_4	36.96233	-75.98567	:America/New_York	USA	knots	124	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:03:00	\N	0.7	-00:57:00	\N	1.1	-01:27:00	-00:36:00	Cape Henry Light, 2.35nm NNE of	VA
101406	Cape Henry Light, 1.4 nmi NE of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4516_1	36.9455	-75.98967	:America/New_York	USA	knots	117	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:14:00	\N	1.4	00:05:00	\N	0.8	00:38:00	-00:23:00	Cape Henry Light, 1.4nm NE of	VA
101407	Cape Henry Light, 1.4 nmi NE of (depth 30 ft), Chesapeake Bay, Virginia Current	NOS	ACT4516_2	36.9455	-75.98967	:America/New_York	USA	knots	118	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:03:00	\N	1.1	-00:20:00	\N	1.1	-00:05:00	-00:15:00	Cape Henry Light, 1.4nm NE of	VA
101408	Cape Henry Light, 1.4 nmi NE of (depth 45 ft), Chesapeake Bay, Virginia Current	NOS	ACT4516_3	36.9455	-75.98967	:America/New_York	USA	knots	114	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:08:00	\N	1	-00:30:00	\N	1.1	-00:23:00	-00:10:00	Cape Henry Light, 1.4nm NE of	VA
101409	Cape Henry Light, 1.4 nmi NE of (depth 60 ft), Chesapeake Bay, Virginia Current	NOS	ACT4516_4	36.9455	-75.98967	:America/New_York	USA	knots	107	282	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:18:00	\N	0.9	-00:32:00	\N	0.9	-00:37:00	-00:10:00	Cape Henry Light, 1.4nm NE of	VA
101410	Cape Henry Light, 0.8 nmi NNE of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4521_1	36.93883	-75.99967	:America/New_York	USA	knots	113	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:03:00	\N	1.6	-00:36:00	\N	0.9	00:21:00	-00:44:00	Cape Henry Light, 0.8 n.mi. NNE of	VA
101411	Cape Henry Light, 0.8 nmi NNE of (depth 38 ft), Chesapeake Bay, Virginia Current	NOS	ACT4521_2	36.93883	-75.99967	:America/New_York	USA	knots	106	275	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:59:00	\N	1.1	-02:20:00	\N	1	-01:47:00	-02:16:00	Cape Henry Light, 0.8 n.mi. NNE of	VA
101412	Cape Henry Light, 3.2 mi north of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4531_1	36.98	-75.998	:America/New_York	USA	knots	129	300	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:07:00	\N	1.1	-00:39:00	\N	0.7	-00:05:00	-00:40:00	Cape Henry Light, 3.2 miles north of	VA
101413	Cape Henry Light, 4.6 mi north of, Chesapeake Bay, Virginia Current	NOS	ACT4536_1	37.00167	-75.98833	:America/New_York	USA	knots	104	294	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:16:00	\N	1.2	-00:30:00	\N	1.2	-00:32:00	-00:21:00	Cape Henry Light, 4.6 miles north of	VA
101414	Cape Henry Light, 5.9 nmi north of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4541_1	37.02333	-75.9925	:America/New_York	USA	knots	140	307	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:43:00	\N	0.7	-00:48:00	\N	0.5	-01:04:00	-01:06:00	Cape Henry Light, 5.9 n.mi. north of	VA
101415	Cape Henry Light, 8.3 mi NW of (depth 12 ft), Chesapeake Bay, Virginia Current	NOS	ACT4546_1	37.03667	-76.11	:America/New_York	USA	knots	133	329	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:19:00	\N	1	00:04:00	\N	0.9	00:11:00	00:05:00	Cape Henry Light, 8.3 mi. NW of	VA
101416	Lynnhaven Roads, Chesapeake Bay, Virginia Current	NOS	ACT4551_1	36.91833	-76.08167	:America/New_York	USA	knots	70	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:17:00	\N	0.8	-00:21:00	\N	0.7	-00:25:00	-00:25:00	Lynnhaven Roads	VA
101417	Lynnhaven Inlet bridge, Chesapeake Bay, Virginia Current	NOS	ACT4556_1	36.90667	-76.09333	:America/New_York	USA	knots	0	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-02:37:00	\N	1.3	-01:49:00	\N	0.5	-01:23:00	-02:23:00	Lynnhaven Inlet bridge	VA
101418	Chesapeake Beach, 1.5 mi north of, Chesapeake Bay Bridge Tunnel, Virginia Current	NOS	ACT4561_1	36.94483	-76.12217	:America/New_York	USA	knots	100	305	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:07:00	\N	0.8	00:09:00	\N	0.7	00:24:00	-00:34:00	Chesapeake Beach, 1.5 miles north of	VA
101419	Tail of the Horseshoe, Chesapeake Bay Bridge Tunnel, Virginia Current	NOS	ACT4571_1	36.99283	-76.10333	:America/New_York	USA	knots	110	300	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:21:00	\N	0.9	-00:09:00	\N	0.8	00:00:00	-00:24:00	Tail of the Horseshoe	VA
101420	Chesapeake Channel (bridge tunnel), Chesapeake Bay Bridge Tunnel, Virginia Current	NOS	ACT4576_1	37.04167	-76.07217	:America/New_York	USA	knots	145	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:12:00	\N	1.4	-00:01:00	\N	1.6	00:00:00	-00:08:00	Chesapeake Channel (bridge tunnel)	VA
101421	Chesapeake Channel (Buoy 15) (depth 13 ft), Chesapeake Bay, Virginia Current	NOS	ACT4581_1	37.05667	-76.093	:America/New_York	USA	knots	125	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:31:00	\N	0.4	-00:06:00	\N	0.5	-00:35:00	00:10:00	Chesapeake Channel (Buoy '15')	VA
101422	Chesapeake Channel (Buoy 15) (depth 34 ft), Chesapeake Bay, Virginia Current	NOS	ACT4581_2	37.05667	-76.093	:America/New_York	USA	knots	139	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:14:00	\N	0.4	-00:12:00	\N	0.5	-00:26:00	00:17:00	Chesapeake Channel (Buoy '15')	VA
101423	Fishermans Island, 3.2 mi WSW of, Chesapeake Bay Bridge Tunnel, Virginia Current	NOS	ACT4586_1	37.06667	-76.0375	:America/New_York	USA	knots	135	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:43:00	\N	1.5	-00:51:00	\N	1.1	-00:27:00	-00:57:00	Fishermans Island, 3.2 miles WSW of	VA
101424	Fishermans Island, 1.4 mi WSW of, Chesapeake Bay Bridge Tunnel, Virginia Current	NOS	ACT4591_1	37.07967	-76.00417	:America/New_York	USA	knots	140	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:09:00	\N	1	-00:41:00	\N	1.6	-01:14:00	-00:52:00	Fishermans Island, 1.4 miles WSW of	VA
101425	Fishermans Island, 2.45 nmi south of (depth 6 ft), Chesapeake Bay, Virginia Current	NOS	ACT4596_1	37.044	-75.96283	:America/New_York	USA	knots	126	301	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:38:00	\N	1.7	-00:59:00	\N	1.1	-00:22:00	-00:57:00	Fishermans Island, 2.45nm south of	VA
101426	Fishermans Island, 2.45 nmi south of (depth 16 ft), Chesapeake Bay, Virginia Current	NOS	ACT4596_2	37.044	-75.96283	:America/New_York	USA	knots	127	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:40:00	\N	1.5	-01:07:00	\N	1.1	-00:39:00	-00:54:00	Fishermans Island, 2.45nm south of	VA
101427	Fishermans Island, 2.45 nmi south of (depth 31 ft), Chesapeake Bay, Virginia Current	NOS	ACT4596_3	37.044	-75.96283	:America/New_York	USA	knots	123	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:53:00	\N	1	-01:11:00	\N	0.9	-01:06:00	-00:53:00	Fishermans Island, 2.45nm south of	VA
101428	Fishermans Island, 1.7 nmi south of (depth 16 ft), Chesapeake Bay, Virginia Current	NOS	ACT4601_1	37.05617	-75.97217	:America/New_York	USA	knots	126	297	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:33:00	\N	1.3	-01:08:00	\N	0.9	-00:24:00	-00:55:00	Fishermans Island, 1.7 n.mi. south of	VA
101429	Fishermans Island, 1.7 nmi south of (depth 26 ft), Chesapeake Bay, Virginia Current	NOS	ACT4601_2	37.05617	-75.97217	:America/New_York	USA	knots	120	290	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:41:00	\N	0.9	-00:58:00	\N	0.7	-00:42:00	-00:56:00	Fishermans Island, 1.7 n.mi. south of	VA
101430	Fishermans Island, 0.5 nmi SW of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4606_1	37.08083	-75.9805	:America/New_York	USA	knots	140	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:42:00	\N	1.8	-00:54:00	\N	1.3	-01:02:00	-01:04:00	Fishermans Island, 0.5 n.mi. SW of	VA
101431	Fishermans I., 0.4 mi west of, Chesapeake Bay Bridge Tunnel, Virginia Current	NOS	ACT4611_1	37.09283	-75.98883	:America/New_York	USA	knots	175	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:49:00	\N	1.9	-00:47:00	\N	1.8	-00:26:00	-00:46:00	Fishermans I., 0.4 mile west of	VA
101432	Fishermans I., 1.4 nmi WNW of (depth 16 ft), Chesapeake Bay, Virginia Current	NOS	ACT4616_1	37.10167	-76.0055	:America/New_York	USA	knots	155	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:34:00	\N	1.1	-00:53:00	\N	1.1	-00:33:00	-00:28:00	Fishermans I., 1.4 n.mi. WNW of	VA
101433	Fishermans I., 1.1 mi northwest of, Chesapeake Bay Bridge Tunnel, Virginia Current	NOS	ACT4621_1	37.10833	-76	:America/New_York	USA	knots	165	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:26:00	\N	1.5	-00:19:00	\N	1.6	-00:44:00	-00:17:00	Fishermans I., 1.1 miles northwest of	VA
101434	Cape Charles, off Wise Point (depth 5 ft), Chesapeake Bay Bridge Tunnel, Virginia Current	NOS	ACT4626_1	37.11467	-75.97167	:America/New_York	USA	knots	75	305	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:13:00	\N	0.2	-00:02:00	\N	0.6	00:04:00	00:16:00	Cape Charles, off Wise Point	VA
101435	Little Creek, 0.2 nmi N of east jetty (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4631_1	36.93417	-76.17667	:America/New_York	USA	knots	92	278	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:08:00	\N	0.3	-01:57:00	\N	0.3	-01:06:00	-01:19:00	Little Creek, 0.2 n.mi. N of east jetty	VA
101436	Butler Bluff, 2.1 nmi WSW of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4636_1	37.15617	-76.02667	:America/New_York	USA	knots	164	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:05:00	\N	0.8	-00:25:00	\N	0.7	-00:03:00	00:17:00	Butler Bluff, 2.1 n.mi. WSW of	VA
101437	York Spit Channel, N of Buoy 26 (depth 7 ft), Chesapeake Bay, Virginia Current	NOS	ACT4641_1	37.215	-76.14167	:America/New_York	USA	knots	195	10	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:19:00	\N	1	01:11:00	\N	0.7	01:28:00	00:44:00	York Spit Channel, N of Buoy '26'	VA
101438	Old Plantation Flats Lt., 0.5 mi W of, Chesapeake Bay, Virginia Current	NOS	ACT4646_1	37.23333	-76.06833	:America/New_York	USA	knots	175	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:59:00	\N	1.2	01:22:00	\N	1.1	01:26:00	01:15:00	Old Plantation Flats Lt., 0.5 mi. W of	VA
101439	Cape Charles City, 3.3 nmi west of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4651_1	37.2645	-76.09367	:America/New_York	USA	knots	187	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:54:00	\N	0.9	00:39:00	\N	0.9	00:33:00	00:23:00	Cape Charles City, 3.3 n.mi. west of	VA
101440	Cape Charles City, 3.3 nmi west of (depth 40 ft), Chesapeake Bay, Virginia Current	NOS	ACT4651_2	37.2645	-76.09367	:America/New_York	USA	knots	182	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:23:00	\N	0.8	00:04:00	\N	0.8	00:11:00	00:30:00	Cape Charles City, 3.3 n.mi. west of	VA
101441	Cape Charles City, 3.3 nmi west of (depth 95 ft), Chesapeake Bay, Virginia Current	NOS	ACT4651_3	37.2645	-76.09367	:America/New_York	USA	knots	138	322	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:17:00	\N	0.8	00:21:00	\N	0.9	00:24:00	00:57:00	Cape Charles City, 3.3 n.mi. west of	VA
101442	New Point Comfort, 4.1 nmi ESE of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4656_1	37.29	-76.19083	:America/New_York	USA	knots	202	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:39:00	\N	0.9	00:43:00	\N	0.7	01:02:00	00:06:00	New Point Comfort, 4.1 n.mi. ESE of	VA
101443	Wolf Trap Light, 0.5 mi west of, Chesapeake Bay, Virginia Current	NOS	ACT4661_1	37.39	-76.19833	:America/New_York	USA	knots	190	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:29:00	\N	1.1	01:21:00	\N	0.9	01:38:00	00:54:00	Wolf Trap Light, 0.5 mile west of	VA
101444	Wolf Trap Light, 5.8 mi east of, Chesapeake Bay, Virginia Current	NOS	ACT4666_1	37.385	-76.07167	:America/New_York	USA	knots	175	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:09:00	\N	1.2	02:01:00	\N	0.8	02:18:00	01:34:00	Wolf Trap Light, 5.8 miles east of	VA
101445	Church Neck Point, 1.9 nmi W of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4671_1	37.40333	-76.013	:America/New_York	USA	knots	177	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:43:00	\N	0.4	00:58:00	\N	0.4	00:41:00	00:56:00	Church Neck Point, 1.9 n.mi. W of	VA
101446	Wolf Trap Light, 6.1 nmi ENE of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4676_1	37.40833	-76.06383	:America/New_York	USA	knots	191	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:04:00	\N	1	01:19:00	\N	1.2	01:35:00	01:48:00	Wolf Trap Light, 6.1 n.mi. ENE of	VA
101447	Wolf Trap Light, 6.1 nmi ENE of (depth 29 ft), Chesapeake Bay, Virginia Current	NOS	ACT4676_2	37.40833	-76.06383	:America/New_York	USA	knots	173	12	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:00:00	\N	0.7	00:16:00	\N	0.6	00:21:00	00:47:00	Wolf Trap Light, 6.1 n.mi. ENE of	VA
101448	Wolf Trap Light, 5.2 nmi ENE of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4681_1	37.40833	-76.08333	:America/New_York	USA	knots	187	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:02:00	\N	1	01:55:00	\N	1.2	01:38:00	02:01:00	Wolf Trap Light, 5.2 n.mi. ENE of	VA
101449	Wolf Trap Light, 5.2 nmi ENE of (depth 40 ft), Chesapeake Bay, Virginia Current	NOS	ACT4681_2	37.40833	-76.08333	:America/New_York	USA	knots	183	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:12:00	\N	0.7	01:45:00	\N	0.9	01:02:00	02:03:00	Wolf Trap Light, 5.2 n.mi. ENE of	VA
101450	Wolf Trap Light, 5.2 nmi ENE of (depth 63 ft), Chesapeake Bay, Virginia Current	NOS	ACT4681_3	37.40833	-76.08333	:America/New_York	USA	knots	158	343	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:04:00	\N	0.6	00:43:00	\N	0.7	00:19:00	01:25:00	Wolf Trap Light, 5.2 n.mi. ENE of	VA
101451	Wolf Trap Light, 1.4 nmi NNE of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4686_1	37.41117	-76.17617	:America/New_York	USA	knots	175	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:12:00	\N	1.1	01:37:00	\N	1	01:33:00	01:12:00	Wolf Trap Light, 1.4 n.mi. NNE of	VA
101452	Wolf Trap Light, 2.0 nmi NW of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4691_1	37.41667	-76.215	:America/New_York	USA	knots	166	345	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:01:00	\N	0.6	-00:06:00	\N	0.5	-00:02:00	00:25:00	Wolf Trap Light, 2.0 n.mi. NW of	VA
101453	Nassawadox Point, 1.9 nmi NW of (depth 13 ft), Chesapeake Bay, Virginia Current	NOS	ACT4696_1	37.4995	-75.9895	:America/New_York	USA	knots	178	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:29:00	\N	0.6	01:04:00	\N	0.5	01:11:00	01:16:00	Nassawadox Point, 1.9 n.mi. NW of	VA
101454	Gwynn Island, 8.0 nmi east of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4701_1	37.495	-76.10833	:America/New_York	USA	knots	175	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:26:00	\N	1	02:24:00	\N	0.9	01:58:00	02:08:00	Gwynn Island, 8.0 n.mi. east of	VA
101455	Gwynn Island, 8.0 nmi east of (depth 28 ft), Chesapeake Bay, Virginia Current	NOS	ACT4701_2	37.495	-76.10833	:America/New_York	USA	knots	209	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:16:00	\N	0.5	00:28:00	\N	0.5	00:28:00	01:06:00	Gwynn Island, 8.0 n.mi. east of	VA
101456	Gwynn Island, 1.5 nmi east of (depth 16 ft), Chesapeake Bay, Virginia Current	NOS	ACT4706_1	37.5005	-76.245	:America/New_York	USA	knots	159	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:15:00	\N	0.5	00:15:00	\N	0.4	00:54:00	00:14:00	Gwynn Island, 1.5 n.mi. east of	VA
101457	Stingray Point, 5.5 mi east of, Chesapeake Bay, Virginia Current	NOS	ACT4711_1	37.58333	-76.17333	:America/New_York	USA	knots	179	343	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:25:00	\N	0.8	02:57:00	\N	0.9	02:23:00	02:41:00	Stingray Point, 5.5 miles east of	VA
101458	Stingray Point, 12.5 mi east of, Chesapeake Bay, Virginia Current	NOS	ACT4716_1	37.56333	-76.03833	:America/New_York	USA	knots	175	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:29:00	\N	0.8	02:21:00	\N	0.9	02:13:00	01:29:00	Stingray Point, 12.5 miles east of	VA
101459	Powells Bluff, 2.2 nmi NW of (depth 17 ft), Chesapeake Bay, Virginia Current	NOS	ACT4721_1	37.59083	-76.96833	:America/New_York	USA	knots	201	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:16:00	\N	0.6	00:50:00	\N	0.5	01:16:00	01:14:00	Powells Bluff, 2.2 n.mi. NW of	VA
101460	Windmill Point Light, 8.3 nmi ESE of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4726_1	37.57667	-76.06333	:America/New_York	USA	knots	182	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:39:00	\N	0.8	02:18:00	\N	0.8	02:13:00	02:24:00	Windmill Point Light, 8.3 n.mi. ESE of	VA
101461	Windmill Point Light, 8.3 nmi ESE of (depth 33 ft), Chesapeake Bay, Virginia Current	NOS	ACT4726_2	37.57667	-76.06333	:America/New_York	USA	knots	172	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:07:00	\N	0.4	00:43:00	\N	0.4	01:01:00	02:27:00	Windmill Point Light, 8.3 n.mi. ESE of	VA
101462	Windmill Point Light, 2.2 nmi ESE of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4731_1	37.58833	-76.19167	:America/New_York	USA	knots	169	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:22:00	\N	0.8	01:59:00	\N	0.5	02:44:00	01:41:00	Windmill Point Light, 2.2 n.mi. ESE of	VA
101463	Windmill Point Light, 2.2 nmi ESE of (depth 35 ft), Chesapeake Bay, Virginia Current	NOS	ACT4731_2	37.58833	-76.19167	:America/New_York	USA	knots	175	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:37:00	\N	0.4	00:56:00	\N	0.5	01:03:00	01:21:00	Windmill Point Light, 2.2 n.mi. ESE of	VA
101464	Milby Point, 5.3 nmi WNW of (depth 13 ft), Chesapeake Bay, Virginia Current	NOS	ACT4736_1	37.66417	-76.00867	:America/New_York	USA	knots	210	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:25:00	\N	0.7	01:51:00	\N	0.5	02:08:00	01:48:00	Milby Point, 5.3 n.mi. WNW of	VA
101465	Milby Point, 5.3 nmi WNW of (depth 38 ft), Chesapeake Bay, Virginia Current	NOS	ACT4736_2	37.66417	-76.00867	:America/New_York	USA	knots	197	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:33:00	\N	0.4	-00:27:00	\N	0.4	00:28:00	00:32:00	Milby Point, 5.3 n.mi. WNW of	VA
101466	Bluff Point, 4.6 nmi east of (depth 13 ft), Chesapeake Bay, Virginia Current	NOS	ACT4741_1	37.67833	-76.20417	:America/New_York	USA	knots	178	3	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:39:00	\N	0.7	02:46:00	\N	0.4	03:05:00	01:45:00	Bluff Point, 4.6 n.mi. east of	VA
101467	Bluff Point, 4.6 nmi east of (depth 33 ft), Chesapeake Bay, Virginia Current	NOS	ACT4741_2	37.67833	-76.20417	:America/New_York	USA	knots	185	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:54:00	\N	0.2	01:22:00	\N	0.4	01:25:00	01:52:00	Bluff Point, 4.6 n.mi. east of	VA
101468	Tangier Sound Light, 5.8 nmi west of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4746_1	37.78383	-76.09467	:America/New_York	USA	knots	185	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:19:00	\N	0.7	03:30:00	\N	0.4	03:29:00	03:16:00	Tangier Sound Light, 5.8 n.mi. west of	VA
101469	Great Wicomico R. Lt., 3.8 nmi ESE of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4751_1	37.78333	-76.19167	:America/New_York	USA	knots	196	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:45:00	\N	0.5	03:38:00	\N	0.4	03:15:00	03:14:00	Great Wicomico R. Lt., 3.8 n.mi. ESE of	VA
101470	Great Wicomico R. Lt., 3.8 nmi ESE of (depth 39 ft), Chesapeake Bay, Virginia Current	NOS	ACT4751_2	37.78333	-76.19167	:America/New_York	USA	knots	196	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:15:00	\N	0.3	02:48:00	\N	0.5	02:06:00	04:10:00	Great Wicomico R. Lt., 3.8 n.mi. ESE of	VA
101471	Smith Point Light, 6.7 nmi east of (depth 9 ft), Chesapeake Bay, Virginia Current	NOS	ACT4756_1	37.8805	-76.04417	:America/New_York	USA	knots	178	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:52:00	\N	0.4	02:18:00	\N	0.4	02:24:00	02:05:00	Smith Point Light, 6.7 n.mi. east of	VA
101472	Smith Point Light, 4.5 nmi east of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4761_1	37.87783	-76.08833	:America/New_York	USA	knots	171	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:28:00	\N	0.7	03:25:00	\N	0.4	03:22:00	03:09:00	Smith Point Light, 4.5 n.mi. east of	VA
101473	Smith Point Light, 4.5 nmi east of (depth 24 ft), Chesapeake Bay, Virginia Current	NOS	ACT4761_2	37.87783	-76.08833	:America/New_York	USA	knots	168	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:59:00	\N	0.5	02:48:00	\N	0.4	03:13:00	02:29:00	Smith Point Light, 4.5 n.mi. east of	VA
101474	Smith Point Light, 3.0 nmi east of (depth 15 ft), Chesapeake Bay, Virginia Current	NOS	ACT4766_1	37.8775	-76.118	:America/New_York	USA	knots	167	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:25:00	\N	0.7	04:16:00	\N	0.4	04:25:00	03:02:00	Smith Point Light, 3.0 n.mi. east of	VA
101475	Smith Point Light, 3.0 nmi east of (depth 34 ft), Chesapeake Bay, Virginia Current	NOS	ACT4766_2	37.8775	-76.118	:America/New_York	USA	knots	149	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:27:00	\N	0.3	01:43:00	\N	0.4	02:10:00	02:36:00	Smith Point Light, 3.0 n.mi. east of	VA
101476	Smith Point Light, 1.5 nmi east of (depth 14 ft), Chesapeake Bay, Virginia Current	NOS	ACT4771_1	37.87917	-76.152	:America/New_York	USA	knots	159	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:16:00	\N	0.7	03:54:00	\N	0.4	04:22:00	03:04:00	Smith Point Light, 1.5 n.mi. east of	VA
101477	Smith Point Light, 1.5 nmi east of (depth 39 ft), Chesapeake Bay, Virginia Current	NOS	ACT4771_2	37.87917	-76.152	:America/New_York	USA	knots	176	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:27:00	\N	0.5	03:42:00	\N	0.7	02:44:00	03:49:00	Smith Point Light, 1.5 n.mi. east of	VA
101478	Smith Point Light, 1.5 nmi east of (depth 68 ft), Chesapeake Bay, Virginia Current	NOS	ACT4771_3	37.87917	-76.152	:America/New_York	USA	knots	160	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:30:00	\N	0.3	02:03:00	\N	0.4	02:05:00	03:29:00	Smith Point Light, 1.5 n.mi. east of	VA
101479	Smith Point Light, 0.8 nmi NW of (depth 8 ft), Chesapeake Bay, Virginia Current	NOS	ACT4776_1	37.88717	-76.19833	:America/New_York	USA	knots	150	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:20:00	\N	0.8	02:06:00	\N	0.8	02:23:00	02:33:00	Smith Point Light, 0.8 n.mi. NW of	VA
101480	Smith Point Light, 6 mi north of, Chesapeake Bay, Maryland Current	NOS	ACT4786_1	37.98167	-76.19	:America/New_York	USA	knots	135	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:59:00	\N	0.9	03:51:00	\N	0.4	04:23:00	03:39:00	Smith Point Light, 6 miles north of	MD
101481	Smith Island, 3.6 nmi northwest of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4791_1	38.0075	-76.12133	:America/New_York	USA	knots	187	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:11:00	\N	0.4	02:33:00	\N	0.4	02:43:00	02:59:00	Smith Island, 3.6 n.mi. northwest of	MD
101482	Point Lookout, 5.9 nmi ESE of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4796_1	38.01467	-76.202	:America/New_York	USA	knots	161	340	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:08:00	\N	0.4	04:14:00	\N	0.4	03:40:00	04:17:00	Point Lookout, 5.9 n.mi. ESE of	MD
101483	Point Lookout, 5.9 nmi ESE of (depth 51 ft), Chesapeake Bay, Maryland Current	NOS	ACT4796_2	38.01467	-76.202	:America/New_York	USA	knots	167	330	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:25:00	\N	0.2	03:51:00	\N	0.4	02:40:00	03:56:00	Point Lookout, 5.9 n.mi. ESE of	MD
101484	Point Lookin, Chesapeake Bay, Maryland Current	NOS	ACT4806_1	38.11	-76.21833	:America/New_York	USA	knots	160	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:39:00	\N	0.5	05:31:00	\N	0.4	05:08:00	04:24:00	Point Lookin	MD
101485	Adams Island, 1.1 nmi west of (depth 12 ft), Chesapeake Bay, Maryland Current	NOS	ACT4811_1	38.1445	-76.1145	:America/New_York	USA	knots	191	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:19:00	\N	0.3	03:09:00	\N	0.1	04:30:00	02:17:00	Adams Island, 1.1 n.mi. west of	MD
101486	Adams Island, 3.4 nmi west of (depth 16 ft), Chesapeake Bay, Maryland Current	NOS	ACT4816_1	38.13967	-76.16333	:America/New_York	USA	knots	167	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:31:00	\N	0.4	04:31:00	\N	0.2	04:53:00	03:23:00	Adams Island, 3.4 n.mi west of	MD
101487	Point No Point, 4.3 nmi east of (depth 17 ft), Chesapeake Bay, Maryland Current	NOS	ACT4821_1	38.1355	-76.22917	:America/New_York	USA	knots	170	340	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	05:38:00	\N	0.2	04:54:00	\N	0.3	04:44:00	05:24:00	Point No Point, 4.3 n.mi. east of	MD
101488	Point No Point, 2.8 nmi east of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4826_1	38.13967	-76.26117	:America/New_York	USA	knots	172	340	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:59:00	\N	0.5	04:53:00	\N	0.2	05:16:00	04:04:00	Point No Point, 2.8 n.mi. east of	MD
101489	Point No Point, 2.8 nmi east of (depth 39 ft), Chesapeake Bay, Maryland Current	NOS	ACT4826_2	38.13967	-76.26117	:America/New_York	USA	knots	162	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:47:00	\N	0.2	04:21:00	\N	0.4	03:32:00	05:02:00	Point No Point, 2.8 n.mi. east of	MD
101490	Point No Point, 1.0 nmi east of (depth 17 ft), Chesapeake Bay, Maryland Current	NOS	ACT4831_1	38.1405	-76.30217	:America/New_York	USA	knots	172	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:27:00	\N	0.5	04:27:00	\N	0.3	04:37:00	03:51:00	Point No Point, 1.0 n.mi. east of	MD
101491	Hooper Strait (west), at Buoy 2 (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4836_1	38.22083	-76.10333	:America/New_York	USA	knots	233	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:33:00	\N	0.6	01:49:00	\N	0.5	02:00:00	01:53:00	Hooper Strait (west), at buoy '2'	MD
101492	Cedar Point, 2.9 nmi ENE of (depth 16 ft), Chesapeake Bay, Maryland Current	NOS	ACT4846_1	38.31083	-76.31333	:America/New_York	USA	knots	164	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:55:00	\N	0.8	-02:34:00	\N	0.5	-02:35:00	-03:16:00	Cedar Point, 2.9 n.mi. ENE of	MD
101620	Allmondsville, York River, Virginia Current	NOS	ACT5466_1	37.4	-76.66667	:America/New_York	USA	knots	105	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:13:00	\N	1	00:05:00	\N	1.1	00:43:00	-00:01:00	Allmondsville	VA
101493	Cedar Point, 2.9 nmi ENE of (depth 50 ft), Chesapeake Bay, Maryland Current	NOS	ACT4846_2	38.31083	-76.31333	:America/New_York	USA	knots	141	326	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-03:15:00	\N	0.3	-03:30:00	\N	0.5	-04:08:00	-03:05:00	Cedar Point, 2.9 n.mi. ENE of	MD
101494	Cedar Point, 1.1 mi ENE of, Chesapeake Bay, Maryland Current	NOS	ACT4851_1	38.3045	-76.35167	:America/New_York	USA	knots	185	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-03:42:00	\N	0.8	-02:50:00	\N	0.5	-03:23:00	-02:36:00	Cedar Point, 1.1 miles ENE of	MD
101495	Cove Point, 1.1 nmi east of (depth 17 ft), Chesapeake Bay, Maryland Current	NOS	ACT4861_1	38.38133	-76.36033	:America/New_York	USA	knots	165	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:14:00	\N	0.9	-02:42:00	\N	0.9	-02:57:00	-02:40:00	Cove Point, 1.1 n.mi. east of	MD
101496	Cove Point, 1.1 nmi east of (depth 40 ft), Chesapeake Bay, Maryland Current	NOS	ACT4861_2	38.38133	-76.36033	:America/New_York	USA	knots	165	343	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-03:26:00	\N	0.7	-03:19:00	\N	0.8	-03:22:00	-02:38:00	Cove Point, 1.1 n.mi. east of	MD
101497	Cove Point, 2.7 nmi east of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_1	38.38	-76.32533	:America/New_York	USA	knots	169	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:40:00	\N	0.9	-02:41:00	\N	0.5	-02:23:00	-02:59:00	Cove Point, 2.7 n.mi. east of	MD
101498	Cove Point, 2.7 nmi east of (depth 40 ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_2	38.38	-76.32533	:America/New_York	USA	knots	170	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:40:00	\N	0.6	-02:39:00	\N	0.9	-03:15:00	-01:53:00	Cove Point, 2.7 n.mi. east of	MD
101499	Cove Point, 2.7 nmi east of (depth 98 ft), Chesapeake Bay, Maryland Current	NOS	ACT4866_3	38.38	-76.32533	:America/New_York	USA	knots	165	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-03:36:00	\N	0.5	-04:02:00	\N	0.7	-03:49:00	-03:13:00	Cove Point, 2.7 n.mi. east of	MD
101500	Cove Point, 3.9 nmi east of (depth 11 ft), Chesapeake Bay, Maryland Current	NOS	ACT4871_1	38.37533	-76.29867	:America/New_York	USA	knots	171	346	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-03:44:00	\N	0.6	-03:36:00	\N	0.4	-03:29:00	-04:08:00	Cove Point, 3.9 n.mi. east of	MD
101501	Cove Point, 4.9 nmi NNE of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_1	38.46717	-76.37667	:America/New_York	USA	knots	159	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:26:00	\N	0.7	-02:29:00	\N	0.7	-02:57:00	-02:24:00	Cove Point, 4.9 n.mi. NNE of	MD
101502	Cove Point, 4.9 nmi NNE of (depth 40 ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_2	38.46717	-76.37667	:America/New_York	USA	knots	149	332	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:17:00	\N	0.4	-02:47:00	\N	1	-03:23:00	-01:58:00	Cove Point, 4.9 n.mi. NNE of	MD
101503	Cove Point, 4.9 nmi NNE of (depth 67 ft), Chesapeake Bay, Maryland Current	NOS	ACT4876_3	38.46717	-76.37667	:America/New_York	USA	knots	135	321	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:58:00	\N	0.4	-03:38:00	\N	0.6	-03:55:00	-02:14:00	Cove Point, 4.9 n.mi. NNE of	MD
101504	Kenwood Beach, 1.5 mi northeast of, Chesapeake Bay, Maryland Current	NOS	ACT4881_1	38.51833	-76.48167	:America/New_York	USA	knots	160	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:37:00	\N	0.4	-02:41:00	\N	0.2	-01:56:00	-02:46:00	Kenwood Beach, 1.5 miles northeast of	MD
101505	James Island, 3.4 mi west of, Chesapeake Bay, Maryland Current	NOS	ACT4891_1	38.525	-76.42	:America/New_York	USA	knots	175	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:02:00	\N	0.4	-02:39:00	\N	0.5	-02:16:00	-03:01:00	James Island, 3.4 miles west of	MD
101506	James Island, 2.5 mi WNW of, Chesapeake Bay, Maryland Current	NOS	ACT4896_1	38.53333	-76.39333	:America/New_York	USA	knots	175	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:36:00	\N	0.6	-02:42:00	\N	0.5	-02:31:00	-02:18:00	James Island, 2.5 miles WNW of	MD
101507	Plum Point, 1.4 mi ESE of, Chesapeake Bay, Maryland Current	NOS	ACT4901_1	38.6125	-76.4775	:America/New_York	USA	knots	155	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:04:00	\N	0.7	-01:37:00	\N	0.2	-01:31:00	-02:20:00	Plum Point, 1.4 miles ESE of	MD
101508	Sharp Island Lt., 2.3 nmi SE of (depth 20 ft), Chesapeake Bay, Maryland Current	NOS	ACT4906_1	38.60717	-76.348	:America/New_York	USA	knots	203	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:54:00	\N	0.7	-03:34:00	\N	0.8	-03:15:00	-03:07:00	Sharp Island Lt., 2.3 n.mi. SE of	MD
101509	Sharp Island Lt., 2.1 nmi west of (depth 18 ft), Chesapeake Bay, Maryland Current	NOS	ACT4911_1	38.64333	-76.42033	:America/New_York	USA	knots	183	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-01:33:00	\N	0.5	-01:36:00	\N	0.4	-01:49:00	-01:33:00	Sharp Island Lt., 2.1 n.mi. west of	MD
101510	Sharp Island Lt., 3.4 nmi west of (depth 18 ft), Chesapeake Bay, Maryland Current	NOS	ACT4916_1	38.64383	-76.448	:America/New_York	USA	knots	186	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-01:43:00	\N	0.5	-01:41:00	\N	0.4	-01:39:00	-01:57:00	Sharp Island Lt., 3.4 n.mi. west of	MD
101511	Sharp Island Lt., 3.4 nmi west of (depth 35 ft), Chesapeake Bay, Maryland Current	NOS	ACT4916_2	38.64383	-76.448	:America/New_York	USA	knots	183	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:24:00	\N	0.4	-02:23:00	\N	0.4	-02:34:00	-02:23:00	Sharp Island Lt., 3.4 n.mi. west of	MD
101512	Plum Point, 2.1 nmi NNE of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4921_1	38.645	-76.48717	:America/New_York	USA	knots	174	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:01:00	\N	0.5	-01:51:00	\N	0.4	-01:50:00	-01:51:00	Plum Point, 2.1 n.mi. NNE of	MD
101513	Poplar Island, 2.2 nmi WSW of (depth 14 ft), Chesapeake Bay, Maryland Current	NOS	ACT4926_1	38.75617	-76.4295	:America/New_York	USA	knots	185	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:49:00	\N	0.8	-01:26:00	\N	0.6	-00:44:00	-00:57:00	Poplar Island, 2.2 n.mi. WSW of	MD
101514	Poplar Island, 3.0 nmi WSW of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4931_1	38.74967	-76.4455	:America/New_York	USA	knots	189	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-01:08:00	\N	0.5	-01:22:00	\N	0.6	-01:08:00	-00:59:00	Poplar Island, 3.0 n.mi. WSW of	MD
101515	Poplar Island, 3.0 nmi WSW of (depth 48 ft), Chesapeake Bay, Maryland Current	NOS	ACT4931_2	38.74967	-76.4455	:America/New_York	USA	knots	172	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:13:00	\N	0.4	01:21:00	\N	0.5	00:58:00	02:01:00	Poplar Island, 3.0 n.mi. WSW of	MD
101516	Holland Point, 2.0 nmi east of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4936_1	38.75167	-76.49883	:America/New_York	USA	knots	180	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-01:39:00	\N	0.4	-01:24:00	\N	0.2	-01:20:00	-01:45:00	Holland Point, 2.0 n.mi east of	MD
101517	Kent Point, 4 mi southwest of, Chesapeake Bay, Maryland Current	NOS	ACT4941_1	38.79167	-76.43333	:America/New_York	USA	knots	210	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-01:05:00	\N	0.6	-01:04:00	\N	0.6	-01:03:00	-01:11:00	Kent Point, 4 miles southwest of	MD
101518	Kent Point, 1.3 mi south of, Chesapeake Bay, Maryland Current	NOS	ACT4946_1	38.81667	-76.36417	:America/New_York	USA	knots	235	55	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-03:47:00	\N	0.5	-03:38:00	\N	0.6	-03:27:00	-03:53:00	Kent Point, 1.3 miles south of	MD
101519	Horseshoe Point, 1.7 mi east of, Chesapeake Bay, Maryland Current	NOS	ACT4951_1	38.83833	-76.45333	:America/New_York	USA	knots	200	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-01:10:00	\N	0.6	-00:39:00	\N	0.6	-00:52:00	-00:49:00	Horseshoe Point, 1.7 miles east of	MD
101520	Bloody Point Bar Light, 0.6 mi NW of (depth 19 ft), Chesapeake Bay, Maryland Current	NOS	ACT4956_1	38.8395	-76.40283	:America/New_York	USA	knots	190	35	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:05:00	\N	0.6	-00:23:00	\N	0.9	-00:08:00	00:02:00	Bloody Point Bar Light, 0.6 mi. NW of	MD
101521	Thomas Pt. Shoal Lt., 1.8 mi SW of, Chesapeake Bay, Maryland Current	NOS	ACT4961_1	38.875	-76.46167	:America/New_York	USA	knots	190	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:17:00	\N	0.4	-02:27:00	\N	0.5	-02:24:00	-01:43:00	Thomas Pt. Shoal Lt., 1.8 mi. SW of	MD
101522	Thomas Pt. Shoal Lt., 2.0 nmi east of (depth 22 ft), Chesapeake Bay, Maryland Current	NOS	ACT4966_1	38.89583	-76.38683	:America/New_York	USA	knots	186	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:20:00	\N	0.6	-00:14:00	\N	0.6	-01:05:00	-00:22:00	Thomas Pt. Shoal Lt., 2.0 n.mi. east of	MD
101523	Thomas Pt. Shoal Lt., 0.5 nmi SE of (depth 16 ft), Chesapeake Bay, Maryland Current	NOS	ACT4971_1	38.891	-76.427	:America/New_York	USA	knots	191	33	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:41:00	\N	1.3	-00:09:00	\N	1	-00:25:00	-00:43:00	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of	MD
101621	Purtan Island, 0.2 mi southwest of, York River, Virginia Current	NOS	ACT5471_1	37.41467	-76.687	:America/New_York	USA	knots	104	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:46:00	\N	1	00:26:00	\N	1.2	00:44:00	00:18:00	Purtan Island, 0.2 mile southwest of	VA
101524	Thomas Pt. Shoal Lt., 0.5 nmi SE of (depth 33 ft), Chesapeake Bay, Maryland Current	NOS	ACT4971_2	38.891	-76.427	:America/New_York	USA	knots	196	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-01:20:00	\N	0.7	-01:18:00	\N	0.7	-00:54:00	-01:25:00	Thomas Pt. Shoal Lt., 0.5 n.mi. SE of	MD
101525	Tolly Point, 1.6 mi east of, Chesapeake Bay, Maryland Current	NOS	ACT4976_1	38.9345	-76.417	:America/New_York	USA	knots	190	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:24:00	\N	0.9	-00:19:00	\N	0.6	-00:03:00	-00:32:00	Tolly Point, 1.6 miles east of	MD
101526	Chesapeake Bay Bridge, main channel, Maryland Current	NOS	ACT4981_1	38.99167	-76.385	:America/New_York	USA	knots	230	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:13:00	\N	1.1	00:08:00	\N	0.9	00:16:00	-00:17:00	Chesapeake Bay Bridge, main channel	MD
101527	Sandy Point, 2.3 nmi east of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4986_1	39.00267	-76.34883	:America/New_York	USA	knots	199	20	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:29:00	\N	0.9	00:15:00	\N	1.1	00:19:00	00:13:00	Sandy Point, 2.3 n.mi. east of	MD
101528	Sandy Point, 2.3 nmi east of (depth 41 ft), Chesapeake Bay, Maryland Current	NOS	ACT4986_2	39.00267	-76.34883	:America/New_York	USA	knots	210	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:39:00	\N	0.6	-01:14:00	\N	0.8	-01:33:00	-00:48:00	Sandy Point, 2.3 n.mi. east of	MD
101529	Sandy Point, 0.8 nmi ESE of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT4991_1	39.004	-76.38	:America/New_York	USA	knots	199	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:05:00	\N	1.5	00:24:00	\N	1.2	-00:11:00	-00:15:00	Sandy Point, 0.8 n.mi. ESE of	MD
101530	Sandy Point, 0.8 nmi ESE of (depth 43 ft), Chesapeake Bay, Maryland Current	NOS	ACT4991_2	39.004	-76.38	:America/New_York	USA	knots	197	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-01:02:00	\N	1	-01:10:00	\N	1	-00:59:00	-00:59:00	Sandy Point, 0.8 n.mi. ESE of	MD
101531	Craighill Channel entrance, Buoy 2C (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT5001_1	39.04033	-76.37783	:America/New_York	USA	knots	182	353	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:09:00	\N	0.9	00:26:00	\N	1	-00:04:00	00:01:00	Craighill Channel entrance, Buoy '2C'	MD
101532	Craighill Channel entrance, Buoy 2C (depth 38 ft), Chesapeake Bay, Maryland Current	NOS	ACT5001_2	39.04033	-76.37783	:America/New_York	USA	knots	147	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:18:00	\N	0.6	00:01:00	\N	0.5	00:00:00	-00:06:00	Craighill Channel entrance, Buoy '2C'	MD
101533	Love Point, 2.5 mi north of, Chesapeake Bay, Maryland Current	NOS	ACT5011_1	39.07967	-76.31217	:America/New_York	USA	knots	240	55	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:07:00	\N	0.5	00:19:00	\N	0.8	-00:48:00	00:27:00	Love Point, 2.5 miles north of	MD
101534	Craighill Channel, NE of Mountain Pt, Chesapeake Bay, Maryland Current	NOS	ACT5021_1	39.08133	-76.3945	:America/New_York	USA	knots	175	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:34:00	\N	0.9	00:40:00	\N	0.8	00:28:00	00:25:00	Craighill Channel, NE of Mountain Pt	MD
101535	Craighill Channel, Belvidere Shoal (depth 18 ft), Chesapeake Bay, Maryland Current	NOS	ACT5026_1	39.09467	-76.393	:America/New_York	USA	knots	186	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:19:00	\N	0.6	00:46:00	\N	0.7	00:10:00	00:33:00	Craighill Channel, Belvidere Shoal	MD
101536	Craighill Angle, right outside quarter, Chesapeake Bay, Maryland Current	NOS	ACT5031_1	39.12833	-76.38783	:America/New_York	USA	knots	170	345	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:23:00	\N	0.6	00:27:00	\N	0.6	00:12:00	00:34:00	Craighill Angle, right outside quarter	MD
101537	Swan Point, 2.7 nmi SW of (depth 14 ft), Chesapeake Bay, Maryland Current	NOS	ACT5036_1	39.108	-76.30533	:America/New_York	USA	knots	170	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:25:00	\N	0.5	00:42:00	\N	0.6	00:18:00	00:38:00	Swan Point, 2.7 n.mi. SW of	MD
101538	Swan Point, 2.7 nmi SW of (depth 27 ft), Chesapeake Bay, Maryland Current	NOS	ACT5036_2	39.108	-76.30533	:America/New_York	USA	knots	142	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:25:00	\N	0.4	00:30:00	\N	0.6	-00:27:00	01:17:00	Swan Point, 2.7 n.mi. SW of	MD
101539	Swan Point, 1.6 mi northwest of, Chesapeake Bay, Maryland Current	NOS	ACT5046_1	39.1625	-76.30467	:America/New_York	USA	knots	215	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:57:00	\N	0.9	00:44:00	\N	0.8	00:53:00	00:38:00	Swan Point, 1.6 miles northwest of	MD
101540	Brewerton Channel Eastern Ext., Buoy 7 (depth 14 ft), Chesapeake Bay, Maryland Current	NOS	ACT5051_1	39.163	-76.38967	:America/New_York	USA	knots	175	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:05:00	\N	0.4	-00:02:00	\N	0.5	00:16:00	-00:14:00	Brewerton Channel Eastern Ext., Buoy '7'	MD
101541	Tolchester Channel, SW of Buoy 58B (depth 17 ft), Chesapeake Bay, Maryland Current	NOS	ACT5056_1	39.1825	-76.28117	:America/New_York	USA	knots	229	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:54:00	\N	1.1	00:20:00	\N	1.1	00:44:00	00:48:00	Tolchester Channel, SW of Bouy '58B'	MD
101808	Georgetown, Sampit River, Winyah Bay, South Carolina Current	NOS	ACT6561_1	33.35917	-79.2875	:America/New_York	USA	knots	80	275	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:52:00	\N	0.6	01:18:00	\N	0.5	02:00:00	00:56:00	Georgetown, Sampit River	SC
101542	Tolchester Channel, SW of Buoy 58B (depth 25 ft), Chesapeake Bay, Maryland Current	NOS	ACT5056_2	39.1825	-76.28117	:America/New_York	USA	knots	217	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:48:00	\N	0.7	00:02:00	\N	0.9	-00:09:00	00:38:00	Tolchester Channel, SW of Bouy '58B'	MD
101543	Tolchester Channel, Buoy 22 (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT5061_1	39.19117	-76.26583	:America/New_York	USA	knots	231	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:23:00	\N	0.8	01:10:00	\N	0.9	01:43:00	00:59:00	Tolchester Channel, Buoy '22'	MD
101544	Tolchester Channel, south of Buoy 38B (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT5066_1	39.19283	-76.28783	:America/New_York	USA	knots	208	28	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:50:00	\N	0.8	01:08:00	\N	0.7	00:51:00	00:59:00	Tolchester Channel, south of Buoy '38B'	MD
101545	North Point, 2.5 mi northeast of (depth 7 ft), Chesapeake Bay, Maryland Current	NOS	ACT5071_1	39.2145	-76.39533	:America/New_York	USA	knots	225	35	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:06:00	\N	0.5	01:00:00	\N	0.4	01:25:00	00:53:00	North Point, 2.5 miles northeast of	MD
101546	Tolchester Beach, 0.33 nmi west of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT5076_1	39.21717	-76.24833	:America/New_York	USA	knots	201	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:24:00	\N	1.1	01:20:00	\N	1.2	00:49:00	01:22:00	Tolchester Beach, 0.33 n.mi. west of	MD
101547	Pooles Island, 4 mi southwest of, Chesapeake Bay, Maryland Current	NOS	ACT5081_1	39.22667	-76.33133	:America/New_York	USA	knots	210	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:12:00	\N	0.8	00:48:00	\N	0.6	00:59:00	00:56:00	Pooles Island, 4 miles southwest of	MD
101548	Pooles Island 2.0 nmi SSW of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT5086_1	39.24633	-76.29667	:America/New_York	USA	knots	238	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:29:00	\N	0.7	00:58:00	\N	0.7	01:01:00	01:03:00	Pooles Island 2.0 n.mi. SSW of	MD
101549	Pooles Island, 0.8 mi south of, Chesapeake Bay, Maryland Current	NOS	ACT5091_1	39.26167	-76.27333	:America/New_York	USA	knots	255	60	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:20:00	\N	1.2	01:24:00	\N	0.9	01:29:00	01:12:00	Pooles Island, 0.8 mile south of	MD
101550	Miller Island, 1.5 mi ENE of (depth 7 ft), Chesapeake Bay, Maryland Current	NOS	ACT5096_1	39.275	-76.33167	:America/New_York	USA	knots	185	0	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:25:00	\N	0.3	00:15:00	\N	0.6	00:11:00	00:37:00	Miller Island, 1.5 miles ENE of	MD
101551	Pooles Island, 1.6 nmi east of (depth 16 ft), Chesapeake Bay, Maryland Current	NOS	ACT5101_1	39.2745	-76.22617	:America/New_York	USA	knots	208	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:03:00	\N	1.1	01:34:00	\N	1.1	01:28:00	01:45:00	Pooles Island, 1.6 n.mi. east of	MD
101552	Robins Point, 0.7 mi ESE of (depth 5 ft), Chesapeake Bay, Maryland Current	NOS	ACT5106_1	39.29583	-76.26833	:America/New_York	USA	knots	210	25	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:13:00	\N	1	-00:14:00	\N	1.4	-00:03:00	00:37:00	Robins Point, 0.7 mile ESE of	MD
101553	Worton Point, 1.5 nmi WSW of (depth 17 ft), Chesapeake Bay, Maryland Current	NOS	ACT5111_1	39.31167	-76.21717	:America/New_York	USA	knots	211	23	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:36:00	\N	1.1	01:45:00	\N	1	02:04:00	01:27:00	Worton Point, 1.5 n.mi. WSW of	MD
101554	Worton Point, 1.1 mi northwest of, Chesapeake Bay, Maryland Current	NOS	ACT5116_1	39.33167	-76.2	:America/New_York	USA	knots	245	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:32:00	\N	1.5	01:43:00	\N	1.4	01:43:00	01:38:00	Worton Point, 1.1 miles northwest of	MD
101555	Howell Point, 0.8 nmi west of (depth 15 ft), Chesapeake Bay, Maryland Current	NOS	ACT5121_1	39.3705	-76.13	:America/New_York	USA	knots	235	51	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:33:00	\N	1.3	01:48:00	\N	1	02:30:00	01:19:00	Howell Point, 0.8 n.mi. west of	MD
101556	Howell Point, 0.4 mi NNW of, Chesapeake Bay, Maryland Current	NOS	ACT5126_1	39.37667	-76.115	:America/New_York	USA	knots	245	80	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:18:00	\N	1.1	01:24:00	\N	1.1	01:28:00	01:20:00	Howell Point, 0.4 mile NNW of	MD
101557	Grove Point, 0.7 nmiNW of (depth 14 ft), Chesapeake Bay, Maryland Current	NOS	ACT5131_1	39.39633	-76.05033	:America/New_York	USA	knots	211	34	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	02:03:00	\N	1	02:01:00	\N	0.6	02:40:00	01:31:00	Grove Point, 0.7 n.mi.NW of	MD
101558	Turkey Point, 1.2 nmi SW of (depth 9 ft), Chesapeake Bay, Maryland Current	NOS	ACT5136_1	39.44333	-76.03383	:America/New_York	USA	knots	193	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:00:00	\N	0.8	01:30:00	\N	0.6	02:39:00	00:58:00	Turkey Point, 1.2 n.mi. SW of	MD
101559	Spesutie Island, channel north of (depth 7 ft), Chesapeake Bay, Maryland Current	NOS	ACT5141_1	39.4805	-76.08167	:America/New_York	USA	knots	100	285	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:40:00	\N	0.6	01:20:00	\N	0.8	01:42:00	01:49:00	Spesutie Island, channel north of	MD
101560	Rocky Pt. (Elk Neck), 0.25 nmi SW of (depth 9 ft), Chesapeake Bay, Maryland Current	NOS	ACT5146_1	39.48833	-75.9975	:America/New_York	USA	knots	196	9	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:49:00	\N	0.7	01:28:00	\N	0.6	02:42:00	01:14:00	Rocky Pt. (Elk Neck), 0.25 n.mi. SW of	MD
101561	Red Point, 0.2 mi W of, Northeast River (depth 7 ft), Chesapeake Bay, Maryland Current	NOS	ACT5151_1	39.52917	-75.98467	:America/New_York	USA	knots	\N	\N	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:47:00	\N	0.6	01:28:00	\N	0.9	01:42:00	01:57:00	Red Point, 0.2 mile W of, Northeast River	MD
101562	Thimble Shoal Channel (west end) (depth 15 ft), Hampton Roads, Virginia Current	NOS	ACT5161_1	37.00533	-76.22667	:America/New_York	USA	knots	116	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:24:00	\N	1.1	-00:27:00	\N	0.8	-00:20:00	-00:42:00	Thimble Shoal Channel (west end)	VA
101563	0.55 nmi east of (depth 48 ft), Old Point Comfort, Hampton Roads, Virginia Current	NOS	ACT5171_1	37.002	-76.29533	:America/New_York	USA	knots	60	251	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-02:18:00	\N	0.6	-01:11:00	\N	1.3	-03:07:00	-00:23:00	0.55 n.mi. east of	VA
101564	0.2 mi south of, Old Point Comfort, Hampton Roads, Virginia Current	NOS	ACT5176_1	36.99617	-76.31467	:America/New_York	USA	knots	75	240	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:32:00	\N	1.3	-01:04:00	\N	1.5	-00:42:00	-01:33:00	0.2 mile south of	VA
101565	0.9 mi southwest of, Old Point Comfort, Hampton Roads, Virginia Current	NOS	ACT5181_1	36.98883	-76.32617	:America/New_York	USA	knots	50	240	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:18:00	\N	1.4	-00:53:00	\N	1.5	-00:58:00	-00:41:00	0.9 mile southwest of	VA
101566	Willoughby Spit, 0.8 mi northwest of, Hampton Roads, Virginia Current	NOS	ACT5186_1	36.97667	-76.30667	:America/New_York	USA	knots	40	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-02:01:00	\N	0.9	-02:09:00	\N	0.6	-01:37:00	-02:21:00	Willoughby Spit, 0.8 mile northwest of	VA
101567	Willoughby Bay entrance, Hampton Roads, Virginia Current	NOS	ACT5191_1	36.96167	-76.29833	:America/New_York	USA	knots	330	135	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-02:26:00	\N	0.4	-02:34:00	\N	0.3	-02:17:00	-03:01:00	Willoughby Bay entrance	VA
101568	Norfolk Harbor Reach (Buoy R8) (depth 13 ft), Hampton Roads, Virginia Current	NOS	ACT5201_1	36.95	-76.3395	:America/New_York	USA	knots	11	183	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:23:00	\N	0.8	-01:21:00	\N	0.5	-00:23:00	-02:16:00	Norfolk Harbor Reach (Buoy R '8')	VA
101569	Norfolk Harbor Reach (Buoy R8) (depth 42 ft), Hampton Roads, Virginia Current	NOS	ACT5201_2	36.95	-76.3395	:America/New_York	USA	knots	0	152	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:57:00	\N	0.3	-01:39:00	\N	0.4	-00:38:00	-01:02:00	Norfolk Harbor Reach (Buoy R '8')	VA
101570	Sewells Point, pierhead (depth 7 ft), Hampton Roads, Virginia Current	NOS	ACT5206_1	36.94667	-76.335	:America/New_York	USA	knots	10	195	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:11:00	\N	0.8	-01:19:00	\N	0.5	-00:57:00	-01:41:00	Sewells Point, pierhead	VA
101571	Channel, middle (depth 15 ft), Newport News, Hampton Roads, Virginia Current	NOS	ACT5211_1	36.95633	-76.38167	:America/New_York	USA	knots	76	244	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:08:00	\N	1	-01:02:00	\N	1	-00:48:00	-00:52:00	Channel, middle	VA
101572	Middle Ground, 1 mi south of (depth 7 ft), Newport News, Hampton Roads, Virginia Current	NOS	ACT5221_1	36.93333	-76.38667	:America/New_York	USA	knots	100	270	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:19:00	\N	1.1	00:11:00	\N	1	00:28:00	-00:16:00	Middle Ground, 1 mile south of	VA
101573	Craney Island (depth 15 ft), Elizabeth River, Virginia Current	NOS	ACT5226_1	36.89467	-76.33583	:America/New_York	USA	knots	1	177	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:55:00	\N	0.8	-01:54:00	\N	0.6	-01:22:00	-02:33:00	Craney Island	VA
101574	Lamberts Point (depth 15 ft), Elizabeth River, Virginia Current	NOS	ACT5236_1	36.875	-76.3325	:America/New_York	USA	knots	328	143	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:57:00	\N	0.7	-02:00:00	\N	0.4	-02:08:00	-02:34:00	Lamberts Point	VA
101575	West Norfolk Bridge, Western Branch, Elizabeth River, Virginia Current	NOS	ACT5241_1	36.85833	-76.34333	:America/New_York	USA	knots	80	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-02:11:00	\N	0.7	-02:19:00	\N	0.5	-02:06:00	-02:46:00	West Norfolk Bridge, Western Branch	VA
101576	Seaboard Coast Line RR, Pinner Point, Elizabeth River, Virginia Current	NOS	ACT5246_1	36.86	-76.31667	:America/New_York	USA	knots	290	140	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-02:16:00	\N	0.4	-02:14:00	\N	0.4	-02:13:00	-02:11:00	Seaboard Coast Line RR, Pinner Point	VA
101577	Berkley Bridge, Eastern Branch, Elizabeth River, Virginia Current	NOS	ACT5251_1	36.84167	-76.28333	:America/New_York	USA	knots	295	120	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-02:56:00	\N	0.4	-02:10:00	\N	0.3	-02:30:00	-02:16:00	Berkley Bridge, Eastern Branch	VA
101578	Norfolk and Western RR. Bridge, E Branch, Elizabeth River, Virginia Current	NOS	ACT5256_1	36.83667	-76.245	:America/New_York	USA	knots	280	100	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:46:00	\N	0.6	-01:54:00	\N	0.4	-01:37:00	-02:21:00	Norfolk and Western RR. Bridge, E Branch	VA
101579	Berkley, Southern Branch, Elizabeth River, Virginia Current	NOS	ACT5261_1	36.83333	-76.29667	:America/New_York	USA	knots	330	215	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-02:34:00	\N	0.3	-01:56:00	\N	0.3	-02:28:00	-02:08:00	Berkley, Southern Branch	VA
101580	Chesapeake, Southern Branch, Elizabeth River, Virginia Current	NOS	ACT5266_1	36.80833	-76.29	:America/New_York	USA	knots	0	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-02:00:00	\N	0.6	-01:55:00	\N	0.6	-02:03:00	-02:10:00	Chesapeake, Southern Branch	VA
101581	Gilmerton Hwy. bridge, Southern Branch, Elizabeth River, Virginia Current	NOS	ACT5271_1	36.775	-76.295	:America/New_York	USA	knots	0	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-02:10:00	\N	0.7	-01:58:00	\N	0.5	-02:13:00	-02:23:00	Gilmerton Hwy. bridge, Southern Branch	VA
101582	Money Point, Southern Branch (depth 15 ft), Elizabeth River, Virginia Current	NOS	ACT5276_1	36.777000427246094	-76.30216979980469	:America/New_York	USA	knots	276	88	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:48:00	\N	0.9	-00:46:00	\N	0.7	-00:53:00	-00:35:00	Money Point, Southern Branch	VA
101583	Pig Point, 1.8 mi northeast of, Nansemond River, Virginia Current	NOS	ACT5281_1	36.92333	-76.41833	:America/New_York	USA	knots	70	285	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:48:00	\N	0.9	-00:46:00	\N	0.7	-00:53:00	-00:35:00	Pig Point, 1.8 miles northeast of	VA
101584	Town Point Bridge, 0.5 mi east of, Nansemond River, Virginia Current	NOS	ACT5286_1	36.88833	-76.48333	:America/New_York	USA	knots	70	265	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:14:00	\N	0.8	-01:38:00	\N	0.8	-01:30:00	-01:31:00	Town Point Bridge, 0.5 mile east of	VA
101585	Dumpling Island, Nansemond River, Virginia Current	NOS	ACT5291_1	36.80833	-76.55833	:America/New_York	USA	knots	345	175	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:31:00	\N	0.9	-01:39:00	\N	0.9	-01:22:00	-02:06:00	Dumpling Island	VA
101586	0.8 mi SW of shipbuilding plant, Newport News, Hampton Roads, Virginia Current	NOS	ACT5301_1	36.975	-76.455	:America/New_York	USA	knots	140	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:03:00	\N	1.1	-00:21:00	\N	0.9	-00:02:00	-00:27:00	0.8 mile SW of shipbuilding plant	VA
101587	1.5 mi SW of shipbuilding plant (depth 6 ft), Hampton Roads, Virginia Current	NOS	ACT5306_1	36.96833	-76.47	:America/New_York	USA	knots	140	350	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:50:00	\N	1	-00:39:00	\N	0.9	-00:41:00	-00:43:00	1.5 miles SW of shipbuilding plant	VA
101588	South end, Rocklanding Shoal Channel, James River, Virginia Current	NOS	ACT5311_1	37.05833	-76.59383	:America/New_York	USA	knots	165	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:07:00	\N	1	00:22:00	\N	0.7	00:34:00	00:20:00	South end	VA
101589	Middle, Rocklanding Shoal Channel, James River, Virginia Current	NOS	ACT5316_1	37.08667	-76.61383	:America/New_York	USA	knots	155	345	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:02:00	\N	0.9	00:57:00	\N	1	00:44:00	01:03:00	Middle	VA
101590	North end, Rocklanding Shoal Channel, James River, Virginia Current	NOS	ACT5321_1	37.11	-76.6325	:America/New_York	USA	knots	145	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:15:00	\N	0.9	01:01:00	\N	1.2	00:55:00	01:07:00	North end	VA
101591	Point of Shoals, west of, James River, Virginia Current	NOS	ACT5326_1	37.065	-76.66	:America/New_York	USA	knots	195	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:14:00	\N	0.8	02:06:00	\N	0.3	02:23:00	01:39:00	Point of Shoals, west of	VA
101592	Deepwater Shoals, James River, Virginia Current	NOS	ACT5331_1	37.14333	-76.63667	:America/New_York	USA	knots	166	353	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:50:00	\N	0.8	01:33:00	\N	1.1	01:37:00	00:59:00	Deepwater Shoals	VA
101593	Hog Point, James River, Virginia Current	NOS	ACT5336_1	37.2	-76.69167	:America/New_York	USA	knots	70	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:04:00	\N	1.2	01:56:00	\N	0.9	02:23:00	01:39:00	Hog Point	VA
101594	Jamestown Island, Church Point, James River, Virginia Current	NOS	ACT5341_1	37.20333	-76.78333	:America/New_York	USA	knots	145	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:08:00	\N	1.2	01:55:00	\N	1	02:19:00	02:03:00	Jamestown Island, Church Point	VA
101595	Chickahominy River Bridge, James River, Virginia Current	NOS	ACT5346_1	37.26167	-76.875	:America/New_York	USA	knots	154	332	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:52:00	\N	1.1	01:50:00	\N	1.2	02:00:00	02:02:00	Chickahominy River Bridge	VA
101596	Caremont Landing, James River, Virginia Current	NOS	ACT5351_1	37.23333	-76.95333	:America/New_York	USA	knots	125	290	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:19:00	\N	1.4	03:11:00	\N	1.3	03:38:00	02:54:00	Caremont Landing	VA
101597	Brandon Point, 0.3 mi northeast of, James River, Virginia Current	NOS	ACT5356_1	37.275	-76.98667	:America/New_York	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:20:00	\N	1.2	03:17:00	\N	1.1	03:51:00	02:57:00	Brandon Point, 0.3 mile northeast of	VA
101598	Windmill Point, James River, Virginia Current	NOS	ACT5361_1	37.31167	-77.095	:America/New_York	USA	knots	65	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:29:00	\N	0.9	03:21:00	\N	1.2	04:25:00	03:24:00	Windmill Point	VA
101599	Coggins Point, 0.5 mi north of, James River, Virginia Current	NOS	ACT5366_1	37.30667	-77.16667	:America/New_York	USA	knots	88	273	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:00:00	\N	0.8	03:39:00	\N	0.5	04:40:00	03:27:00	Coggins Point, 0.5 mile north of	VA
101600	City Point, James River, Virginia Current	NOS	ACT5371_1	37.31667	-77.27167	:America/New_York	USA	knots	135	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:04:00	\N	1.1	03:56:00	\N	1.2	04:43:00	03:59:00	City Point	VA
101601	Appomattox River entrance, James River, Virginia Current	NOS	ACT5376_1	37.31167	-77.295	:America/New_York	USA	knots	80	271	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:51:00	\N	0.8	04:20:00	\N	0.9	05:19:00	03:57:00	Appomattox River entrance	VA
101602	Bermuda Hundred, James River, Virginia Current	NOS	ACT5381_1	37.33667	-77.27	:America/New_York	USA	knots	199	19	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:19:00	\N	1.2	04:13:00	\N	0.8	05:40:00	03:21:00	Bermuda Hundred	VA
101603	Dutch Gap Canal, 0.5 mi east of, James River, Virginia Current	NOS	ACT5386_1	37.38	-77.34667	:America/New_York	USA	knots	90	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:49:00	\N	0.8	04:41:00	\N	0.7	05:23:00	04:39:00	Dutch Gap Canal, 0.5 mile east of	VA
101604	York Spit Light, 0.8 mi southwest of, York River, Virginia Current	NOS	ACT5401_1	37.2	-76.26667	:America/New_York	USA	knots	145	323	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:20:00	\N	0.8	-00:33:00	\N	0.7	-00:42:00	-00:16:00	York Spit Light, 0.8 mile southwest of	VA
101605	York River ent. Channel (NW end) (depth 15 ft), Virginia Current	NOS	ACT5406_1	37.22583	-76.30783	:America/New_York	USA	knots	128	298	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:26:00	\N	0.5	-00:45:00	\N	0.6	-01:52:00	00:03:00	York River Ent. Channel (NW end)	VA
101606	Tue Marshes Light, 0.7 nmi north of (depth 14 ft), York River, Virginia Current	NOS	ACT5411_1	37.24667	-76.388	:America/New_York	USA	knots	78	265	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:18:00	\N	0.8	01:26:00	\N	0.9	01:27:00	01:18:00	Tue Marshes Light, 0.7 n.mi. north of	VA
101607	Tue Marshes Light, 0.7 nmi north of (depth 39 ft), York River, Virginia Current	NOS	ACT5411_2	37.24667	-76.388	:America/New_York	USA	knots	70	247	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:55:00	\N	0.6	00:24:00	\N	0.8	00:27:00	01:15:00	Tue Marshes Light, 0.7 n.mi. north of	VA
101608	Tue Marshes Light, 0.7 nmi north of (depth 49 ft), York River, Virginia Current	NOS	ACT5411_3	37.24667	-76.388	:America/New_York	USA	knots	68	249	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:48:00	\N	0.3	-02:11:00	\N	0.4	-02:56:00	-01:11:00	Tue Marshes Light, 0.7 n.mi. north of	VA
101609	Tue Marshes Light, 0.9 nmi WNW of (depth 14 ft), York River, Virginia Current	NOS	ACT5416_1	37.238	-76.40217	:America/New_York	USA	knots	69	249	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:32:00	\N	0.7	-00:30:00	\N	0.7	-00:21:00	-00:30:00	Tue Marshes Light, 0.9 n.mi. WNW of	VA
101610	Tue Marshes Light, 0.9 nmi WNW of (depth 28 ft), York River, Virginia Current	NOS	ACT5416_2	37.238	-76.40217	:America/New_York	USA	knots	64	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:41:00	\N	0.6	-01:15:00	\N	0.5	-01:20:00	-00:46:00	Tue Marshes Light, 0.9 n.mi. WNW of	VA
101611	Midchannel, Tue Marshes Light, 2.7 mi west of, York River, Virginia Current	NOS	ACT5421_1	37.23333	-76.44333	:America/New_York	USA	knots	72	258	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:30:00	\N	0.6	-00:17:00	\N	0.5	-00:18:00	-00:22:00	Midchannel	VA
101612	North edge of channel, Tue Marshes Light, 2.7 mi west of, York River, Virginia Current	NOS	ACT5426_1	37.23667	-76.44333	:America/New_York	USA	knots	74	251	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:08:00	\N	0.7	-00:56:00	\N	0.4	-00:53:00	-01:16:00	North edge of channel	VA
101613	South edge of channel, Tue Marshes Light, 2.7 mi west of, York River, Virginia Current	NOS	ACT5431_1	37.22667	-76.44167	:America/New_York	USA	knots	95	257	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:31:00	\N	0.5	-00:49:00	\N	0.4	-00:31:00	-01:02:00	South edge of channel	VA
101614	Yorktown, York River, Virginia Current	NOS	ACT5436_1	37.24167	-76.50833	:America/New_York	USA	knots	124	302	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:24:00	\N	1.5	-01:07:00	\N	1.1	-00:35:00	-00:59:00	Yorktown	VA
101615	Gloucester Point, 150 yd southeast of, York River, Virginia Current	NOS	ACT5441_1	37.2425	-76.50167	:America/New_York	USA	knots	90	267	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-01:28:00	\N	1	-00:40:00	\N	0.8	-00:40:00	-01:07:00	Gloucester Point, 150 yds. southeast of	VA
101616	Gloucester Point, 0.4 mi southwest of, York River, Virginia Current	NOS	ACT5446_1	37.24033	-76.51083	:America/New_York	USA	knots	108	294	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:51:00	\N	0.9	-00:39:00	\N	1	-00:30:00	-00:24:00	Gloucester Point, 0.4 mile southwest of	VA
101617	Pages Rock, 1 mi SSE of, York River, Virginia Current	NOS	ACT5451_1	37.29333	-76.58	:America/New_York	USA	knots	125	303	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:29:00	\N	0.9	-00:15:00	\N	0.9	-00:15:00	-00:27:00	Pages Rock, 1 mile SSE of	VA
101618	Blundering Point, 0.9 mi SSW of, York River, Virginia Current	NOS	ACT5456_1	37.30217	-76.58467	:America/New_York	USA	knots	138	293	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:23:00	\N	1	-00:26:00	\N	1	-00:27:00	-00:03:00	Blundering Point, 0.9 mile SSW of	VA
101619	Clay Bank Pier, 100 yd southwest of, York River, Virginia Current	NOS	ACT5461_1	37.34633	-76.61333	:America/New_York	USA	knots	123	311	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:12:00	\N	1	-00:25:00	\N	1	-00:07:00	00:37:00	Clay Bank Pier, 100 yds. southwest of	VA
101622	Goff Point, 0.8 mi SSW of, York River, Virginia Current	NOS	ACT5476_1	37.4995	-76.78383	:America/New_York	USA	knots	123	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:47:00	\N	0.9	00:57:00	\N	0.8	01:32:00	01:14:00	Goff Point, 0.8 mile SSW of	VA
101623	West Point, 0.8 mi below, York River, Virginia Current	NOS	ACT5481_1	37.515	-76.79167	:America/New_York	USA	knots	150	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:59:00	\N	1.4	00:41:00	\N	1	01:18:00	00:34:00	West Point, 0.8 mile below	VA
101624	Lord Delaware Bridge, 100 yd S of, York River, Virginia Current	NOS	ACT5486_1	37.537	-76.79083	:America/New_York	USA	knots	210	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:39:00	\N	0.5	00:51:00	\N	0.7	01:32:00	01:08:00	Lord Delaware Bridge, 100 yds. S of	VA
101625	Wakema, Mattaponi River, York River, Virginia Current	NOS	ACT5491_1	37.65333	-76.9	:America/New_York	USA	knots	280	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:34:00	\N	1.6	01:26:00	\N	1.3	02:03:00	01:19:00	Wakema, Mattaponi River	VA
101626	Walkerton, Mattaponi River, York River, Virginia Current	NOS	ACT5496_1	37.72333	-77.025	:America/New_York	USA	knots	95	275	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:18:00	\N	0.8	02:25:00	\N	0.8	03:24:00	02:10:00	Walkerton, Mattaponi River	VA
101627	Eltham Bridge, 100 yd north of, York River, Virginia Current	NOS	ACT5501_1	37.535	-76.807	:America/New_York	USA	knots	124	327	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:07:00	\N	0.8	01:54:00	\N	0.5	02:01:00	01:37:00	Eltham Bridge, 100 yds. north of	VA
101628	Lester Manor, Pamunkey River, York River, Virginia Current	NOS	ACT5506_1	37.58167	-76.99	:America/New_York	USA	knots	55	235	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:59:00	\N	0.9	02:51:00	\N	1.1	03:13:00	02:39:00	Lester Manor, Pamunkey River	VA
101629	Northbury, Pamunkey River, York River, Virginia Current	NOS	ACT5511_1	37.625	-77.12167	:America/New_York	USA	knots	100	290	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:19:00	\N	1.2	04:11:00	\N	0.4	04:28:00	03:44:00	Northbury, Pamunkey River	VA
101630	New Point Comfort, 2.0 nmi WSW of (depth 16 ft), Virginia Current	NOS	ACT5516_1	37.295	-76.32083	:America/New_York	USA	knots	129	315	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:56:00	\N	0.4	01:39:00	\N	0.5	00:58:00	01:12:00	New Point Comfort, 2.0 n.mi. WSW of	VA
101631	Bland Point, Piankatank River, Virginia Current	NOS	ACT5521_1	37.53	-76.365	:America/New_York	USA	knots	125	300	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:06:00	\N	0.2	-00:14:00	\N	0.4	00:03:00	-00:41:00	Bland Point, Piankatank River	VA
101632	Doctor Point, 0.4 mi west of, Virginia Current	NOS	ACT5526_1	37.51833	-76.45	:America/New_York	USA	knots	142	311	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:13:00	\N	0.4	-00:42:00	\N	0.4	00:05:00	-01:28:00	Doctor Point, 0.4 mile west of	VA
101633	Stingray Point, 1.2 nmi NE of (depth 28 ft), Rappahannock River, Virginia Current	NOS	ACT5531_1	37.5755	-76.28467	:America/New_York	USA	knots	121	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:54:00	\N	0.5	-00:04:00	\N	0.4	01:01:00	-00:51:00	Stingray Point, 1.2 n.mi. NE of	VA
101634	Windmill Point, 1.0 nmi SSW of (depth 15 ft), Rappahannock River, Virginia Current	NOS	ACT5536_1	37.6	-76.29167	:America/New_York	USA	knots	103	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:24:00	\N	0.5	01:14:00	\N	0.6	01:08:00	01:49:00	Windmill Point, 1.0 n.mi SSW of	VA
101635	Windmill Point, 1.0 nmi SSW of (depth 38 ft), Rappahannock River, Virginia Current	NOS	ACT5536_2	37.6	-76.29167	:America/New_York	USA	knots	90	269	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:46:00	\N	0.3	01:18:00	\N	0.5	00:33:00	01:50:00	Windmill Point, 1.0 n.mi SSW of	VA
101636	Mosquito Point, 0.9 mi SSE of, Rappahannock River, Virginia Current	NOS	ACT5541_1	37.59533	-76.35133	:America/New_York	USA	knots	90	265	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:05:00	\N	0.8	01:47:00	\N	0.6	01:29:00	01:27:00	Mosquito Point, 0.9 mile SSE of	VA
101637	Orchard Point, 1.0 mi south of, Rappahannock River, Virginia Current	NOS	ACT5551_1	37.63283	-76.4575	:America/New_York	USA	knots	85	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:16:00	\N	0.6	01:51:00	\N	0.4	01:22:00	01:39:00	Orchard Point, 1.0 mile south of	VA
101638	Towles Point, Rappahannock River, Virginia Current	NOS	ACT5556_1	37.63	-76.50667	:America/New_York	USA	knots	103	274	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:49:00	\N	0.5	01:23:00	\N	0.5	01:39:00	01:59:00	Towles Point	VA
101639	Waterview, 1.3 mi NNE of, Rappahannock River, Virginia Current	NOS	ACT5566_1	37.74917	-76.59867	:America/New_York	USA	knots	155	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:34:00	\N	0.6	02:15:00	\N	0.6	02:14:00	02:35:00	Waterview, 1.3 miles NNE of	VA
101640	Tarpley Point, 1.5 mi south of, Rappahannock River, Virginia Current	NOS	ACT5571_1	37.76917	-76.652	:America/New_York	USA	knots	105	300	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:03:00	\N	0.7	02:53:00	\N	0.6	02:49:00	03:09:00	Tarpley Point, 1.5 miles south of	VA
101641	Jones Point, 1.4 mi NNW of, Rappahannock River, Virginia Current	NOS	ACT5576_1	37.8005	-76.693	:America/New_York	USA	knots	105	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:51:00	\N	0.8	02:39:00	\N	1	02:37:00	03:08:00	Jones Point, 1.4 miles NNW of	VA
101642	Sharps, 1.2 mi south of, Rappahannock River, Virginia Current	NOS	ACT5581_1	37.803	-76.69867	:America/New_York	USA	knots	95	290	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:25:00	\N	0.8	03:02:00	\N	0.8	02:52:00	03:41:00	Sharps, 1.2 miles south of	VA
101643	Bowlers Rock, 0.2 mi north of, Rappahannock River, Virginia Current	NOS	ACT5586_1	37.82633	-76.73333	:America/New_York	USA	knots	135	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:14:00	\N	1	02:57:00	\N	0.9	03:00:00	03:26:00	Bowlers Rock, 0.2 mile north of	VA
101644	Accaceek Point, 0.3 mi southwest of, Rappahannock River, Virginia Current	NOS	ACT5591_1	37.87533	-76.77333	:America/New_York	USA	knots	150	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:37:00	\N	0.9	03:04:00	\N	1.1	03:13:00	03:16:00	Accaceek Point, 0.3 mile southwest of	VA
101645	Tappahannock Bridge, 1.8 mi SE of, Rappahannock River, Virginia Current	NOS	ACT5596_1	37.91833	-76.82117	:America/New_York	USA	knots	105	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:52:00	\N	1.2	03:23:00	\N	1.3	03:51:00	03:45:00	Tappahannock Bridge, 1.8 miles SE of	VA
101646	Port Royal, Rappahannock River, Virginia Current	NOS	ACT5606_1	38.175	-77.19	:America/New_York	USA	knots	130	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	06:34:00	\N	0.7	06:26:00	\N	0.6	06:43:00	05:59:00	Port Royal	VA
101647	Pocomoke Sound approach, Virginia Current	NOS	ACT5611_1	37.63333	-75.965	:America/New_York	USA	knots	196	9	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:55:00	\N	0.7	01:28:00	\N	0.6	01:09:00	02:00:00	Pocomoke Sound Approach	VA
101648	Watts Island, 4 mi south of (depth 7 ft), Pocomoke Sound, Virginia Current	NOS	ACT5621_1	37.72	-75.9	:America/New_York	USA	knots	247	27	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:20:00	\N	0.6	00:17:00	\N	0.5	00:50:00	00:16:00	Watts Island, 4 miles south of	VA
101649	Watts Island, 2.3 nmi east of (depth 13 ft), Pocomoke Sound, Virginia Current	NOS	ACT5626_1	37.79367	-75.84717	:America/New_York	USA	knots	208	32	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:50:00	\N	1	01:24:00	\N	0.9	01:53:00	01:20:00	Watts Island, 2.3 n.mi. east of	VA
101650	Watts Island, 2.3 nmi east of (depth 48 ft), Pocomoke Sound, Virginia Current	NOS	ACT5626_2	37.79367	-75.84717	:America/New_York	USA	knots	209	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:10:00	\N	0.8	01:13:00	\N	0.9	01:26:00	01:30:00	Watts Island, 2.3 n.mi. east of	VA
101651	Long Point, 2.0 nmi northeast of (depth 9 ft), Pocomoke Sound, Maryland Current	NOS	ACT5631_1	37.915	-75.79833	:America/New_York	USA	knots	211	24	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:23:00	\N	0.3	00:57:00	\N	0.4	01:24:00	01:03:00	Long Point, 2.0 n.mi. northeast of	MD
101652	Pocomoke R., 0.5 mi below Shelltown, Pocomoke Sound, Maryland Current	NOS	ACT5636_1	37.97167	-75.645	:America/New_York	USA	knots	170	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:24:00	\N	0.8	03:16:00	\N	1	04:03:00	03:19:00	Pocomoke R., 0.5 mile below Shelltown	MD
101653	Tangier Sound Light, 0.5 nmi east of (depth 16 ft), Virginia Current	NOS	ACT5641_1	37.7875	-75.96383	:America/New_York	USA	knots	195	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:28:00	\N	0.8	01:59:00	\N	0.8	02:21:00	02:07:00	Tangier Sound Light, 0.5 n.mi. east of	VA
101654	Tangier Sound Light, 0.5 nmi east of (depth 41 ft), Virginia Current	NOS	ACT5641_2	37.7875	-75.96383	:America/New_York	USA	knots	189	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:17:00	\N	0.8	01:57:00	\N	0.9	02:20:00	02:14:00	Tangier Sound Light, 0.5 n.mi. east of	VA
101655	Tangier Sound Light, 1.5 mi NE of, Virginia Current	NOS	ACT5646_1	37.80833	-75.95667	:America/New_York	USA	knots	220	14	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:03:00	\N	1	02:18:00	\N	1.1	02:03:00	02:04:00	Tangier Sound Light, 1.5 miles NE of	VA
101656	Clump Island, 2.5 nmi west of (depth 15 ft), Tangier Sound, Virginia Current	NOS	ACT5651_1	37.90833	-75.957	:America/New_York	USA	knots	168	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:16:00	\N	0.6	03:04:00	\N	0.7	03:05:00	03:06:00	Clump Island, 2.5 n.mi. west of	VA
101657	Clump Island, 2.5 nmi west of (depth 40 ft), Tangier Sound, Virginia Current	NOS	ACT5651_2	37.90833	-75.957	:America/New_York	USA	knots	166	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:09:00	\N	0.6	02:45:00	\N	0.7	02:56:00	02:53:00	Clump Island, 2.5 n.mi. west of	VA
101658	Janes Island Light, 2.3 nmi NNE of (depth 14 ft), Tangier Sound, Maryland Current	NOS	ACT5656_1	38.00083	-75.90867	:America/New_York	USA	knots	188	1	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:09:00	\N	0.7	03:14:00	\N	0.6	03:17:00	03:23:00	Janes Island Light, 2.3 n.mi. NNE OF	MD
101659	Janes Island Light, 2.3 nmi NNE of (depth 39 ft), Tangier Sound, Maryland Current	NOS	ACT5656_2	38.00083	-75.90867	:America/New_York	USA	knots	174	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:02:00	\N	0.7	03:33:00	\N	0.6	03:28:00	03:40:00	Janes Island Light, 2.3 n.mi. NNE OF	MD
101660	Janes Island Light, 2.3 nmi NNE of (depth 92 ft), Tangier Sound, Maryland Current	NOS	ACT5656_3	38.00083	-75.90867	:America/New_York	USA	knots	181	348	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:28:00	\N	0.4	03:39:00	\N	0.5	02:58:00	03:33:00	Janes Island Light, 2.3 n.mi. NNE OF	MD
101661	Big Annemessex River entrance (depth 12 ft), Tangier Sound, Maryland Current	NOS	ACT5661_1	38.04883	-75.8575	:America/New_York	USA	knots	258	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:36:00	\N	0.2	01:35:00	\N	0.3	02:07:00	01:36:00	Big Annemessex River Entrance	MD
101662	Kedges Strait Buoy 4 (depth 12 ft), Tangier Sound, Maryland Current	NOS	ACT5666_1	38.0575	-76.03217	:America/New_York	USA	knots	276	91	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:57:00	\N	0.7	00:49:00	\N	0.7	00:46:00	00:47:00	Kedges Strait Buoy '4'	MD
101663	Manokin R. ent., 1.1 nmi E of Drum Pt (depth 20 ft), Tangier Sound, Maryland Current	NOS	ACT5671_1	38.097	-75.89133	:America/New_York	USA	knots	197	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:32:00	\N	0.3	02:16:00	\N	0.4	02:18:00	02:32:00	Manokin R. Ent., 1.1 n.mi. E of Drum Pt	MD
101664	Deal Is., 0.6 nmi W. of, at Buoy 14 (depth 14 ft), Tangier Sound, Maryland Current	NOS	ACT5676_1	38.14083	-75.97217	:America/New_York	USA	knots	181	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:03:00	\N	0.6	03:13:00	\N	0.6	03:18:00	03:14:00	Deal Is., 0.6 n.mi. W. of, at Bouy '14'	MD
101665	Deal Is., 0.6 nmi W. of, at Buoy 14 (depth 41 ft), Tangier Sound, Maryland Current	NOS	ACT5676_2	38.14083	-75.97217	:America/New_York	USA	knots	175	355	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:29:00	\N	0.4	02:21:00	\N	0.5	02:51:00	03:24:00	Deal Is., 0.6 n.mi. W. of, at Bouy '14'	MD
101666	Frog Point, 1.6 mi south of, Tangier Sound, Maryland Current	NOS	ACT5681_1	38.21	-75.955	:America/New_York	USA	knots	240	48	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:55:00	\N	1	03:16:00	\N	0.9	03:52:00	03:30:00	Frog Point, 1.6 miles south of	MD
101667	Long Point and Nanticoke Point, between (depth 9 ft), Tangier Sound, Maryland Current	NOS	ACT5686_1	38.21333	-75.9	:America/New_York	USA	knots	263	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:36:00	\N	0.7	02:53:00	\N	0.4	03:24:00	02:56:00	Long Point and Nanticoke Point, between	MD
101668	Victor Point, 0.8 mi southwest of, Wicomico River, Tangier Sound, Maryland Current	NOS	ACT5691_1	38.23833	-75.86333	:America/New_York	USA	knots	242	34	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:58:00	\N	0.8	03:10:00	\N	0.5	03:43:00	03:38:00	Victor Point, 0.8 mile southwest of	MD
101669	Whitehaven, Wicomico River, Tangier Sound, Maryland Current	NOS	ACT5696_1	38.265	-75.79167	:America/New_York	USA	knots	284	89	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:25:00	\N	1	04:01:00	\N	1	03:29:00	03:51:00	Whitehaven	MD
101670	Whitehaven, 2.5 mi above (depth 4 ft), Wicomico River, Tangier Sound, Maryland Current	NOS	ACT5701_1	38.29667	-75.75833	:America/New_York	USA	knots	188	6	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:19:00	\N	1	03:29:00	\N	0.9	03:33:00	03:34:00	Whitehaven, 2.5 miles above	MD
101671	Salisbury, 2 mi below (depth 4 ft), Wicomico River, Tangier Sound, Maryland Current	NOS	ACT5706_1	38.34	-75.63833	:America/New_York	USA	knots	258	85	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:52:00	\N	0.8	03:47:00	\N	0.5	03:56:00	03:52:00	Salisbury, 2 miles below	MD
101672	Sandy Point, Nanticoke River, Tangier Sound, Maryland Current	NOS	ACT5711_1	38.24667	-75.92833	:America/New_York	USA	knots	182	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:03:00	\N	1	03:52:00	\N	1.1	03:47:00	04:10:00	Sandy Point, Nanticoke River	MD
101673	Roaring Point, WSW of Nanticoke River (depth 18 ft), Tangier Sound, Maryland Current	NOS	ACT5716_1	38.26333	-75.92333	:America/New_York	USA	knots	181	356	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:34:00	\N	0.8	03:17:00	\N	0.8	03:50:00	04:06:00	Roaring Point, WSW of Nanticoke River	MD
101674	Roaring Point, WSW of Nanticoke River (depth 37 ft), Tangier Sound, Maryland Current	NOS	ACT5716_2	38.26333	-75.92333	:America/New_York	USA	knots	150	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:36:00	\N	0.5	03:15:00	\N	0.5	03:38:00	04:34:00	Roaring Point, WSW of Nanticoke River	MD
101675	Chapter Point, Nanticoke River, Tangier Sound, Maryland Current	NOS	ACT5721_1	38.37667	-75.86667	:America/New_York	USA	knots	204	14	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	05:42:00	\N	1.1	03:59:00	\N	1.3	05:10:00	04:41:00	Chapter Point, Nanticoke River	MD
101676	Fishing Bay entrance, at Buoy 2 (depth 15 ft), Tangier Sound, Maryland Current	NOS	ACT5726_1	38.22467	-75.9895	:America/New_York	USA	knots	139	311	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:45:00	\N	0.3	04:16:00	\N	0.4	03:47:00	04:02:00	Fishing Bay Entrance, at Buoy '2'	MD
101677	Hooper Strait, at Buoy 4 (depth 14 ft), Tangier Sound, Maryland Current	NOS	ACT5731_1	38.2175	-76.06383	:America/New_York	USA	knots	287	97	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:07:00	\N	0.7	00:48:00	\N	0.7	00:51:00	01:16:00	Hooper Strait, at Buoy '4'	MD
101678	Honga River entrance, at Buoy 1A (depth 26 ft), Tangier Sound, Maryland Current	NOS	ACT5741_1	38.24667	-76.11667	:America/New_York	USA	knots	152	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:03:00	\N	0.4	02:22:00	\N	0.4	02:52:00	03:17:00	Honga River Entrance, at Buoy '1A'	MD
101679	Sandy Point, east of, Great Wicomico River, Virginia Current	NOS	ACT5746_1	37.82167	-76.3	:America/New_York	USA	knots	140	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	00:49:00	\N	0.3	00:41:00	\N	0.3	00:58:00	00:14:00	Sandy Point, east of	VA
101680	Point Lookout, 5.2 nmi SW of (depth 13 ft), Potomac River, Maryland Current	NOS	ACT5751_1	37.96867	-76.39167	:America/New_York	USA	knots	113	294	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	01:16:00	\N	0.1	01:37:00	\N	0.1	02:34:00	01:38:00	Point Lookout, 5.2 n.mi. SW of	MD
101681	Point Lookout, 3.1 nmi SW of (depth 15 ft), Potomac River, Maryland Current	NOS	ACT5756_1	37.99783	-76.3625	:America/New_York	USA	knots	116	295	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:19:00	\N	0.4	03:23:00	\N	0.3	03:34:00	03:20:00	Point Lookout, 3.1 n.mi. SW of	MD
101682	Point Lookout, 3.1 nmi SW of (depth 34 ft), Potomac River, Maryland Current	NOS	ACT5756_2	37.99783	-76.3625	:America/New_York	USA	knots	126	303	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:40:00	\N	0.2	02:20:00	\N	0.2	02:44:00	02:50:00	Point Lookout, 3.1 n.mi. SW of	MD
101683	Point Lookout, 1.8 nmi SW of (depth 14 ft), Potomac River, Maryland Current	NOS	ACT5761_1	38.01333	-76.34367	:America/New_York	USA	knots	122	297	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:31:00	\N	0.4	03:01:00	\N	0.4	03:01:00	03:48:00	Point Lookout, 1.8 n.mi. SW of	MD
101684	Point Lookout, 1.8 nmi SW of (depth 47 ft), Potomac River, Maryland Current	NOS	ACT5761_2	38.01333	-76.34367	:America/New_York	USA	knots	102	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:13:00	\N	0.1	02:31:00	\N	0.3	02:08:00	03:16:00	Point Lookout, 1.8 n.mi. SW of	MD
101702	Freestone Point, 2.3 mi east of, Potomac River, Maryland Current	NOS	ACT5891_1	38.59633	-77.198	:America/New_York	USA	knots	229	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:06:00	\N	0.9	-00:01:00	\N	0.9	-00:03:00	-00:28:00	Freestone Point, 2.3 miles east of	MD
101685	Point Lookout, 1.0 nmi south of (depth 15 ft), Potomac River, Maryland Current	NOS	ACT5766_1	38.02083	-76.32417	:America/New_York	USA	knots	117	270	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:48:00	\N	0.5	02:48:00	\N	0.6	02:25:00	03:14:00	Point Lookout, 1.0 n.mi. south of	MD
101686	Point Lookout, 1.0 nmi south of (depth 43 ft), Potomac River, Maryland Current	NOS	ACT5766_2	38.02083	-76.32417	:America/New_York	USA	knots	86	271	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:04:00	\N	0.3	02:31:00	\N	0.5	02:00:00	03:58:00	Point Lookout, 1.0 n.mi. south of	MD
101687	Cornfield Point, midchannel, Potomac River, Maryland Current	NOS	ACT5776_1	38.01832962036133	-76.3550033569336	:America/New_York	USA	knots	110	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:24:00	\N	0.6	04:16:00	\N	0.4	04:33:00	03:49:00	Cornfield Point, midchannel	MD
101688	Cornfield Point, 3.8 mi south of, Potomac River, Maryland Current	NOS	ACT5781_1	37.9900016784668	-76.35832977294922	:America/New_York	USA	knots	100	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:09:00	\N	0.6	04:01:00	\N	0.6	04:18:00	03:34:00	Cornfield Point, 3.8 miles south of	MD
101689	Piney Point, 0.2 mi south of, Potomac River, Maryland Current	NOS	ACT5796_1	38.130001068115234	-76.53333282470703	:America/New_York	USA	knots	145	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:24:00	\N	0.6	03:16:00	\N	1.2	03:33:00	02:49:00	Piney Point, 0.2 mile south of	MD
101690	Piney Point, 2.2 mi south of, Potomac River, Maryland Current	NOS	ACT5806_1	38.098331451416016	-76.55166625976562	:America/New_York	USA	knots	130	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:24:00	\N	0.5	03:16:00	\N	0.4	03:33:00	02:49:00	Piney Point, 2.2 miles south of	MD
101691	White Point, Nomini Creek entrance, Potomac River, Virginia Current	NOS	ACT5816_1	38.135	-76.72167	:America/New_York	USA	knots	335	155	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:59:00	\N	1.1	03:51:00	\N	1.1	04:08:00	03:24:00	White Point, Nomini Creek entrance	VA
101692	Breton Bay entrance, Potomac River, Maryland Current	NOS	ACT5821_1	38.24167	-76.695	:America/New_York	USA	knots	200	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	02:44:00	\N	0.4	02:36:00	\N	0.5	02:53:00	02:09:00	Breton Bay entrance	MD
101693	St. Clements I., 1.8 mi southeast of, Potomac River, Maryland Current	NOS	ACT5831_1	38.195	-76.70833	:America/New_York	USA	knots	85	250	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	05:09:00	\N	0.8	05:01:00	\N	0.4	05:18:00	04:34:00	St. Clements I., 1.8 miles southeast of	MD
101694	St. Clements I., 1.1 mi southwest of, Potomac River, Maryland Current	NOS	ACT5836_1	38.19283	-76.76117	:America/New_York	USA	knots	99	281	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	04:58:00	\N	0.8	05:10:00	\N	0.5	05:04:00	04:33:00	St. Clements I., 1.1 miles southwest of	MD
101695	Rock Point, Wicomico River entrance, Potomac River, Maryland Current	NOS	ACT5841_1	38.27333	-76.82167	:America/New_York	USA	knots	174	19	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	03:46:00	\N	0.6	03:57:00	\N	0.4	03:42:00	03:42:00	Rock Point, Wicomico River entrance	MD
101696	Swan Point, Potomac River, Maryland Current	NOS	ACT5846_1	38.27333	-76.945	:America/New_York	USA	knots	140	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:09:00	\N	1	-02:04:00	\N	0.4	-01:54:00	-02:32:00	Swan Point	MD
101697	Persimmon Point, Potomac River, Maryland Current	NOS	ACT5861_1	38.36833	-76.99	:America/New_York	USA	knots	175	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-01:24:00	\N	1.8	-01:19:00	\N	1.5	-01:09:00	-01:47:00	Persimmon Point	MD
101698	Potomac River Bridge, 0.4 mi south of, Maryland Current	NOS	ACT5866_1	38.35633	-76.98667	:America/New_York	USA	knots	165	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-01:17:00	\N	1.8	-01:28:00	\N	1.1	-01:25:00	-01:38:00	Potomac River Bridge, 0.4 mile south of	MD
101699	Maryland Point, Potomac River, Maryland Current	NOS	ACT5876_1	38.34667	-77.19667	:America/New_York	USA	knots	80	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-01:19:00	\N	1.8	-01:14:00	\N	1.4	-01:04:00	-01:42:00	Maryland Point	MD
101700	Quantico, Potomac River, Maryland Current	NOS	ACT5881_1	38.52167	-77.27667	:America/New_York	USA	knots	200	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-01:09:00	\N	1.1	-01:04:00	\N	0.9	-00:54:00	-01:32:00	Quantico	MD
101701	Quantico Creek entrance, Potomac River, Virginia Current	NOS	ACT5886_1	38.52833	-77.28833	:America/New_York	USA	knots	115	305	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-01:34:00	\N	0.6	-01:29:00	\N	0.6	-01:19:00	-01:57:00	Quantico Creek entrance	VA
101703	Hallowing Point, Potomac River, Maryland Current	NOS	ACT5896_1	38.645	-77.1275	:America/New_York	USA	knots	149	345	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:15:00	\N	1.4	-00:05:00	\N	1.4	00:12:00	-00:24:00	Hallowing Point	MD
101704	Jones Point, Alexandria, Potomac River, DC Current	NOS	ACT5901_1	38.79367	-77.03717	:America/New_York	USA	knots	171	352	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:07:00	\N	1.1	00:01:00	\N	1.2	00:36:00	00:09:00	Jones Point, Alexandria	DC
101705	Hains Point, Potomac River, DC Current	NOS	ACT5906_1	38.85133	-77.022	:America/New_York	USA	knots	176	359	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:18:00	\N	0.4	00:31:00	\N	0.8	00:20:00	00:04:00	Hains Point	DC
101706	Hog Point, 0.6 nmi north of (depth 13 ft), Patuxent River, Maryland Current	NOS	ACT5931_1	38.318	-76.40117	:America/New_York	USA	knots	70	258	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-06:00:00	\N	0.6	-05:29:00	\N	0.5	-04:45:00	-05:59:00	Hog Point, 0.6 n.mi. north of	MD
101707	Hog Point, 0.6 nmi north of (depth 41 ft), Patuxent River, Maryland Current	NOS	ACT5931_2	38.318	-76.40117	:America/New_York	USA	knots	61	263	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-06:38:00	\N	0.3	-05:38:00	\N	0.5	-06:24:00	-05:36:00	Hog Point, 0.6 n.mi. north of	MD
101708	Drum Point, 0.3 mi SSE of, Patuxent River, Maryland Current	NOS	ACT5936_1	38.3155	-76.41917	:America/New_York	USA	knots	65	245	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-05:16:00	\N	0.5	-05:20:00	\N	0.5	-05:19:00	-05:25:00	Drum Point, 0.3 mile SSE of	MD
101709	Sandy Point, 0.5 mi south of, Patuxent River, Maryland Current	NOS	ACT5941_1	38.30833	-76.455	:America/New_York	USA	knots	125	300	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-04:55:00	\N	0.6	-05:49:00	\N	0.5	-05:08:00	-05:53:00	Sandy Point, 0.5 mile south of	MD
101710	Point Patience, 0.1 mi southwest of (depth 15 ft), Patuxent River, Maryland Current	NOS	ACT5946_1	38.32833	-76.48667	:America/New_York	USA	knots	145	315	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-06:01:00	\N	1	-06:12:00	\N	0.6	-05:07:00	-06:46:00	Point Patience, 0.1 mile southwest of	MD
101711	Broomes Island, 0.4 mi south of, Patuxent River, Maryland Current	NOS	ACT5951_1	38.395	-76.55417	:America/New_York	USA	knots	110	290	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-05:02:00	\N	0.6	-05:16:00	\N	0.5	-05:01:00	-05:02:00	Broomes Island, 0.4 mile south of	MD
101712	Sheridan Point, 0.1 mi southwest of, Patuxent River, Maryland Current	NOS	ACT5956_1	38.46617	-76.648	:America/New_York	USA	knots	135	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-04:16:00	\N	0.8	-04:54:00	\N	0.8	-04:33:00	-04:38:00	Sheridan Point, 0.1 mile southwest of	MD
101713	Benedict, highway bridge, Patuxent River, Maryland Current	NOS	ACT5961_1	38.51167	-76.67217	:America/New_York	USA	knots	190	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-04:35:00	\N	0.6	-04:38:00	\N	1	-04:45:00	-04:09:00	Benedict, highway bridge	MD
101714	Lyons Creek Wharf, Patuxent River, Maryland Current	NOS	ACT5966_1	38.74667	-76.685	:America/New_York	USA	knots	140	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-03:29:00	\N	1.1	-03:24:00	\N	1.4	-03:14:00	-03:52:00	Lyons Creek Wharf	MD
101715	Ragged Point, 1.5 mi east of, Little Choptank River, Maryland Current	NOS	ACT5976_1	38.53	-76.24417	:America/New_York	USA	knots	235	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-04:57:00	\N	0.2	-05:15:00	\N	0.5	-04:53:00	-04:29:00	Ragged Point, 1.5 miles east of	MD
101716	Cook Point, 1.4 nmi NNW of (depth 15 ft), Choptank River, Maryland Current	NOS	ACT5981_1	38.64717	-76.30667	:America/New_York	USA	knots	241	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-04:24:00	\N	0.7	-04:06:00	\N	0.8	-03:52:00	-04:06:00	Cook Point, 1.4 n.mi. NNW of	MD
101717	Cook Point, 1.4 nmi NNW of (depth 45 ft), Choptank River, Maryland Current	NOS	ACT5981_2	38.64717	-76.30667	:America/New_York	USA	knots	232	68	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-04:12:00	\N	0.6	-04:05:00	\N	0.6	-04:09:00	-04:03:00	Cook Point, 1.4 n.mi. NNW of	MD
101718	Holland Point, 2.0 nmi SSW of (depth 14 ft), Choptank River, Maryland Current	NOS	ACT5986_1	38.67383	-76.2575	:America/New_York	USA	knots	262	89	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-04:00:00	\N	0.2	-04:21:00	\N	0.3	-03:54:00	-03:26:00	Holland Point, 2.0 n.mi. SSW of	MD
101719	Chlora Point, 0.5 nmi SSW of (depth 17 ft), Choptank River, Maryland Current	NOS	ACT5991_1	38.62833	-76.15167	:America/New_York	USA	knots	332	139	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-03:58:00	\N	0.5	-03:32:00	\N	0.6	-03:45:00	-03:22:00	Chlora Point, 0.5 n.mi. SSW of	MD
101720	Chlora Point, 0.5 nmi SSW of (depth 24 ft), Choptank River, Maryland Current	NOS	ACT5991_2	38.62833	-76.15167	:America/New_York	USA	knots	323	143	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-03:42:00	\N	0.4	-03:33:00	\N	0.4	-03:48:00	-03:13:00	Chlora Point, 0.5 n.mi. SSW of	MD
101721	Martin Point, 0.6 nmi west of (depth 18 ft), Choptank River, Maryland Current	NOS	ACT5996_1	38.62717	-76.13583	:America/New_York	USA	knots	341	155	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-03:34:00	\N	0.2	-03:42:00	\N	0.3	-03:18:00	-03:22:00	Martin Point, 0.6 n.mi. west of	MD
101722	Howell Point, 0.5 nmi south of (depth 7 ft), Choptank River, Maryland Current	NOS	ACT6001_1	38.60383	-76.1145	:America/New_York	USA	knots	274	122	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-03:42:00	\N	0.5	-04:04:00	\N	0.4	-03:17:00	-03:52:00	Howell Point, 0.5 n.mi. south of	MD
101723	Cambridge hwy. bridge, W. of Swing Span (depth 18 ft), Choptank River, Maryland Current	NOS	ACT6006_1	38.57967	-76.06117	:America/New_York	USA	knots	316	132	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:13:00	\N	0.3	-03:05:00	\N	0.6	-02:48:00	-01:07:00	Cambridge hwy. bridge, W. of Swing Span	MD
101724	Off Jamaica Point, Choptank River, Maryland Current	NOS	ACT6011_1	38.60967	-75.98283	:America/New_York	USA	knots	205	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:26:00	\N	0.8	-02:32:00	\N	0.6	-02:13:00	-02:44:00	Off Jamaica Point	MD
101725	Poplar Point, south of, Choptank River, Maryland Current	NOS	ACT6016_1	38.67533	-75.96633	:America/New_York	USA	knots	100	305	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:15:00	\N	1	-02:05:00	\N	1	-01:52:00	-01:56:00	Poplar Point, south of	MD
101726	Dover Bridge, Choptank River, Maryland Current	NOS	ACT6021_1	38.75667	-75.99867	:America/New_York	USA	knots	235	50	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-01:47:00	\N	1	-01:50:00	\N	1.1	-01:19:00	-01:25:00	Dover Bridge	MD
101727	Bald Eagle Pt., east of, Harris Creek, Choptank River, Maryland Current	NOS	ACT6041_1	38.72917	-76.305	:America/New_York	USA	knots	175	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-04:14:00	\N	0.5	-04:27:00	\N	0.5	-04:07:00	-04:07:00	Bald Eagle Pt., east of, Harris Creek	MD
101728	Poplar Island, east of south end, Eastern Bay, Maryland Current	NOS	ACT6046_1	38.74833	-76.35333	:America/New_York	USA	knots	170	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:20:00	\N	0.8	-02:20:00	\N	1.2	-02:20:00	-02:20:00	Poplar Island, east of south end	MD
101729	Kent Point, 1.4 nmi east of (depth 15 ft), Eastern Bay, Maryland Current	NOS	ACT6051_1	38.83883	-76.3375	:America/New_York	USA	knots	233	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-03:12:00	\N	0.4	-03:18:00	\N	0.5	-03:04:00	-03:49:00	Kent Point, 1.4 n.mi. east of	MD
101730	Long Point, 1 mi southeast of, Eastern Bay, Maryland Current	NOS	ACT6056_1	38.84333	-76.32667	:America/New_York	USA	knots	235	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-03:40:00	\N	0.5	-03:40:00	\N	0.6	-03:40:00	-03:40:00	Long Point, 1 mile southeast of	MD
101731	Wye River, west of Bruffs Island (depth 9 ft), Eastern Bay, Maryland Current	NOS	ACT6081_1	38.85467	-76.198	:America/New_York	USA	knots	190	30	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-03:00:00	\N	0.9	-03:18:00	\N	0.8	-02:33:00	-03:17:00	Wye River, west of Bruffs Island	MD
101732	Deepwater Point, Miles River, Eastern Bay, Maryland Current	NOS	ACT6086_1	38.8055	-76.20917	:America/New_York	USA	knots	25	215	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-04:14:00	\N	0.6	-03:52:00	\N	0.6	-03:48:00	-03:43:00	Deepwater Point, Miles River	MD
101733	Greenbury Point, 1.8 mi east of (depth 8 ft), Maryland Current	NOS	ACT6106_1	38.97333	-76.41667	:America/New_York	USA	knots	245	70	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:47:00	\N	0.8	-01:05:00	\N	0.8	-00:57:00	-00:51:00	Greenbury Point, 1.8 miles east of	MD
101734	Mountain Point, Magothy River entrance, Maryland Current	NOS	ACT6121_1	39.05783	-76.43717	:America/New_York	USA	knots	125	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:04:00	\N	0.4	-02:00:00	\N	0.8	-02:20:00	-01:29:00	Mountain Point, Magothy River entrance	MD
101735	Love Point, 1.6 nmi east of (depth 16 ft), Chester River, Maryland Current	NOS	ACT6126_1	39.03417	-76.26783	:America/New_York	USA	knots	341	202	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-01:15:00	\N	0.4	-01:15:00	\N	0.6	-01:42:00	-00:47:00	Love Point, 1.6 n.mi. east of	MD
101736	Kent Island Narrows (highway bridge) (depth 4 ft), Chester River, Maryland Current	NOS	ACT6131_1	38.9705	-76.24717	:America/New_York	USA	knots	190	5	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-02:56:00	\N	1.1	-02:25:00	\N	1.2	-02:07:00	-02:11:00	Kent Island Narrows (highway bridge)	MD
101737	Hail Point, 0.7 nmieast of (depth 16 ft), Chester River, Maryland Current	NOS	ACT6136_1	39.0105	-76.1825	:America/New_York	USA	knots	168	2	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:37:00	\N	0.6	-01:08:00	\N	0.5	-00:51:00	-01:12:00	Hail Point, 0.7 n.mi.east of	MD
101738	Deep Point, Chester River, Maryland Current	NOS	ACT6141_1	39.10633	-76.1205	:America/New_York	USA	knots	260	65	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:18:00	\N	0.9	-00:33:00	\N	0.6	-00:31:00	-00:32:00	Deep Point	MD
101739	Chestertown, Chester River, Maryland Current	NOS	ACT6146_1	39.20717	-76.06117	:America/New_York	USA	knots	220	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:17:00	\N	0.6	00:05:00	\N	0.8	-00:21:00	-00:02:00	Chestertown	MD
101740	Lynch Point, Back River, Maryland Current	NOS	ACT6186_1	39.25	-76.43833	:America/New_York	USA	knots	130	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	-00:10:00	\N	0.5	-00:10:00	\N	0.7	00:00:00	00:00:00	Lynch Point, Back River	MD
101741	Gunpowder River entrance, Maryland Current	NOS	ACT6191_1	39.31167	-76.30833	:America/New_York	USA	knots	205	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:05:00	\N	0.4	-00:41:00	\N	0.5	-00:24:00	00:25:00	Gunpowder River entrance	MD
101742	Bush River, 0.4 mi SW of Bush Point, Maryland Current	NOS	ACT6196_1	39.35667	-76.25667	:America/New_York	USA	knots	165	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:20:00	\N	0.6	-00:24:00	\N	0.8	00:07:00	00:21:00	Bush River, 0.4 mi. SW of Bush Point	MD
101743	Grove Point, Sassafrass River, Maryland Current	NOS	ACT6201_1	39.37833	-76.04333	:America/New_York	USA	knots	288	95	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:44:00	\N	0.4	00:46:00	\N	0.5	00:46:00	00:51:00	Grove Point	MD
101744	Ordinary Point, 0.4 mi west of, Sassafrass River, Maryland Current	NOS	ACT6206_1	39.37417	-75.9875	:America/New_York	USA	knots	345	165	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	00:58:00	\N	0.5	00:37:00	\N	0.6	00:50:00	01:17:00	Ordinary Point, 0.4 mile west of	MD
101745	Georgetown, Sassafrass River, Maryland Current	NOS	ACT6211_1	39.36117	-75.88617	:America/New_York	USA	knots	200	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:25:00	\N	0.5	00:25:00	\N	0.4	01:00:00	00:56:00	Georgetown	MD
101746	Arnold Point, 0.4 mi west of, Elk River, Maryland Current	NOS	ACT6216_1	39.46383	-75.97417	:America/New_York	USA	knots	215	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:32:00	\N	1	01:45:00	\N	1	01:39:00	01:24:00	Arnold Point, 0.4 mile west of	MD
101747	Old Town Point Wharf, northwest of (depth 17 ft), Elk River, Maryland Current	NOS	ACT6221_1	39.50383	-75.91867	:America/New_York	USA	knots	242	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:45:00	\N	1.6	01:53:00	\N	1.3	02:00:00	01:49:00	Old Town Point Wharf, northwest of	MD
101748	Old Town Point Wharf, northwest of (depth 29 ft), Elk River, Maryland Current	NOS	ACT6221_2	39.50383	-75.91867	:America/New_York	USA	knots	237	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	01:45:00	\N	1.4	02:04:00	\N	1.2	02:07:00	01:47:00	Old Town Point Wharf, northwest of	MD
101749	Hendersons Point, Elk River, Maryland Current	NOS	ACT6226_1	39.55333	-75.86	:America/New_York	USA	knots	210	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97990	02:05:00	\N	0.9	02:05:00	\N	0.6	02:05:00	02:05:00	Hendersons Point	MD
101750	Back Creek, 0.3 nmi W of Sandy Pt (depth 14 ft), Maryland Current	NOS	ACT6231_1	39.52783	-75.86617	:America/New_York	USA	knots	244	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100613	00:06:00	\N	0.7	00:00:00	\N	0.6	-00:01:00	-00:15:00	Back Creek, 0.3 n.mi. W of Sandy Pt	MD
101751	Back Creek, 0.3 nmi W of Sandy Pt (depth 31 ft), Maryland Current	NOS	ACT6231_2	39.52783	-75.86617	:America/New_York	USA	knots	240	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100613	00:08:00	\N	0.6	-00:13:00	\N	0.6	00:01:00	-00:05:00	Back Creek, 0.3 n.mi. W of Sandy Pt	MD
101752	Chesapeake City Bridge, 0.45 nmi E of (depth 26 ft), Maryland Current	NOS	ACT6241_1	39.52783	-75.80717	:America/New_York	USA	knots	273	92	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100613	00:00:00	\N	0.7	00:01:00	\N	1	-00:22:00	00:03:00	Chesapeake City Bridge, 0.45 n.mi. E of	MD
101753	Chesapeake City Bridge, 0.45 nmi E of (depth 37 ft), Maryland Current	NOS	ACT6241_2	39.52783	-75.80717	:America/New_York	USA	knots	275	83	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100613	-00:07:00	\N	0.5	-00:04:00	\N	0.8	-00:26:00	00:06:00	Chesapeake City Bridge, 0.45 n.mi. E of	MD
101754	Conrail Bridge, east of (depth 17 ft), Chesapeake and Delaware Canal, Delaware Current	NOS	ACT6246_1	39.5425	-75.7025	:America/New_York	USA	knots	278	99	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100613	-00:01:00	\N	0.7	-00:13:00	\N	1	-00:30:00	-00:03:00	Conrail Bridge, east of	DE
101755	Conrail Bridge, east of (depth 34 ft), Chesapeake and Delaware Canal, Delaware Current	NOS	ACT6246_2	39.5425	-75.7025	:America/New_York	USA	knots	281	96	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100613	-00:24:00	\N	0.5	-00:11:00	\N	0.7	-00:35:00	-00:06:00	Conrail Bridge, east of	DE
101756	St. George Bridge, 0.1 nmi ENE of (depth 18 ft), Delaware Current	NOS	ACT6251_1	39.55283	-75.65	:America/New_York	USA	knots	247	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100613	-01:01:00	\N	0.7	-00:56:00	\N	0.9	-00:52:00	-00:53:00	St. George Bridge, 0.1 n.mi. ENE of	DE
101757	Reedy Point Radio Tower, south of (depth 19 ft), Delaware Current	NOS	ACT6256_1	39.56033	-75.57	:America/New_York	USA	knots	263	78	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100613	-00:09:00	\N	0.7	-00:43:00	\N	1	-01:00:00	-00:15:00	Reedy Point Radio Tower, south of	DE
101758	Cape Henry Light, 0.7 mi east of, Virginia Current	NOS	ACT6261_1	36.92833	-75.99333	:America/New_York	USA	knots	105	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:06:00	\N	1.8	-00:23:00	\N	0.9	-00:06:00	-01:07:00	Cape Henry Light, 0.7 mile east of	VA
101759	Carova Beach, north end, North Carolina Current	NOS	ACT6266_1	36.55	-75.86833	:America/New_York	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100582	-00:09:00	\N	0.4	-00:20:00	\N	0.4	-00:53:00	-00:21:00	Virginia Beach, south end	NC
101760	Bodie Island-Pea Island, between (depth 6 ft), Pamlico Sound, North Carolina Current	NOS	ACT6271_1	35.77667	-75.535	:America/New_York	USA	knots	28	202	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:52:00	\N	0.6	02:20:00	\N	1.2	02:38:00	02:03:00	Bodie Island-Pea Island, between	NC
101761	Bodie Island-Pea Island, between (depth 12 ft), Pamlico Sound, North Carolina Current	NOS	ACT6271_2	35.77667	-75.535	:America/New_York	USA	knots	36	204	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:48:00	\N	0.6	02:36:00	\N	1.2	02:49:00	02:02:00	Bodie Island-Pea Island, between	NC
101762	Coast Guard Tower, southwest of (depth 6 ft), Pamlico Sound, North Carolina Current	NOS	ACT6276_1	35.76167	-75.53167	:America/New_York	USA	knots	28	205	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	02:18:00	\N	0.8	02:30:00	\N	0.8	03:04:00	01:53:00	Coast Guard Tower, southwest of	NC
101763	Coast Guard Tower, southwest of (depth 12 ft), Pamlico Sound, North Carolina Current	NOS	ACT6276_2	35.76167	-75.53167	:America/New_York	USA	knots	33	212	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:33:00	\N	0.7	02:33:00	\N	0.8	03:01:00	01:57:00	Coast Guard Tower, southwest of	NC
101764	Herbert C. Bonner Bridge, WSW of (depth 6 ft), Pamlico Sound, North Carolina Current	NOS	ACT6281_1	35.77	-75.54667	:America/New_York	USA	knots	87	280	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:46:00	\N	0.9	02:55:00	\N	0.6	03:32:00	01:30:00	Herbert C. Bonner Bridge, WSW of	NC
101765	Hatteras Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6286_1	35.2	-75.75	:America/New_York	USA	knots	148	307	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:38:00	\N	1	02:42:00	\N	1.2	02:42:00	02:18:00	Hatteras Inlet	NC
101766	Ocracoke Inlet, channel entrance, Pamlico Sound, North Carolina Current	NOS	ACT6296_1	35.06529998779297	-76.018798828125	:America/New_York	USA	knots	145	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:40:00	\N	1.2	02:24:00	\N	1	02:48:00	01:43:00	Ocracoke Inlet, channel entrance	NC
101767	Teaches Hole Channel (depth 10 ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6301_1	35.07917	-76.00467	:America/New_York	USA	knots	195	50	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:47:00	\N	0.8	02:27:00	\N	0.6	02:49:00	01:42:00	Teaches Hole Channel	NC
101768	Blair Channel (depth 10 ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6306_1	35.08133	-76.03383	:America/New_York	USA	knots	140	355	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	02:03:00	\N	0.9	02:33:00	\N	0.6	02:52:00	01:48:00	Blair Channel	NC
101769	Wallace Channel (depth 9 ft), Ocracoke Inlet, Pamlico Sound, North Carolina Current	NOS	ACT6311_1	35.07967	-76.052	:America/New_York	USA	knots	140	305	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	02:13:00	\N	0.9	02:57:00	\N	0.9	02:51:00	02:03:00	Wallace Channel	NC
101770	Sheep Island Slue, Pamlico Sound, North Carolina Current	NOS	ACT6316_1	35.06667	-76.1	:America/New_York	USA	knots	95	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:56:00	\N	0.2	03:18:00	\N	0.1	02:33:00	01:35:00	Sheep Island Slue	NC
101771	Shackleford Banks, 0.8 mi S of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6326_1	34.66633	-76.6555	:America/New_York	USA	knots	145	314	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:31:00	\N	0.7	01:16:00	\N	0.8	01:19:00	00:30:00	Shackleford Banks, 0.8 mile S of	NC
101772	Beaufort Inlet approach, North Carolina Current	NOS	ACT6331_1	34.67169952392578	-76.66999816894531	:America/New_York	USA	knots	161	358	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:57:00	\N	0.7	01:19:00	\N	0.2	02:03:00	00:37:00	Beaufort Inlet Approach	NC
101773	Fort Macon, 0.6 mi SE of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6336_1	34.68579864501953	-76.66829681396484	:America/New_York	USA	knots	154	332	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:38:00	\N	0.9	01:47:00	\N	0.7	01:42:00	00:51:00	Fort Macon, 0.6 mile SE of	NC
101774	Fort Macon, 0.2 mi NE of (depth 10 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6341_1	34.69967	-76.67533	:America/New_York	USA	knots	151	307	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:21:00	\N	0.9	01:20:00	\N	1.1	01:12:00	00:36:00	Fort Macon, 0.2 mile NE of	NC
101775	Fort Macon, 0.2 mi NE of (depth 20 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6341_2	34.69967	-76.67533	:America/New_York	USA	knots	153	320	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:39:00	\N	0.9	01:18:00	\N	1.1	01:12:00	00:36:00	Fort Macon, 0.2 mile NE of	NC
101776	Tombstone Point, 0.1 mi E of (depth 15 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6346_1	34.70383	-76.68617	:America/New_York	USA	knots	128	305	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:27:00	\N	0.8	01:25:00	\N	0.9	01:13:00	00:34:00	Tombstone Point, 0.1 mile E of	NC
101777	Turning Basin (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6351_1	34.713	-76.69417	:America/New_York	USA	knots	144	327	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:32:00	\N	0.5	01:34:00	\N	0.8	01:11:00	00:50:00	Turning Basin	NC
101778	Turning Basin (depth 15 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6351_2	34.713	-76.69417	:America/New_York	USA	knots	138	334	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:32:00	\N	0.5	01:34:00	\N	0.7	01:09:00	00:59:00	Turning Basin	NC
101779	Sugarloaf Island, 0.2 mi S of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6356_1	34.7125	-76.71383	:America/New_York	USA	knots	94	266	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:14:00	\N	0.8	01:39:00	\N	0.7	01:58:00	01:22:00	Sugarloaf Island, 0.2 mile S of	NC
101780	Morehead City, S of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6361_1	34.71667	-76.73283	:America/New_York	USA	knots	110	293	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:42:00	\N	0.7	01:47:00	\N	0.8	02:12:00	01:29:00	Morehead City, S of	NC
101781	Morehead City, RR. bridge, N of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6366_1	34.72283	-76.69383	:America/New_York	USA	knots	185	54	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-01:03:00	\N	0.5	01:01:00	\N	0.6	00:44:00	00:09:00	Morehead City, RR. bridge, N of	NC
101782	Newport Marshes, SE of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6371_1	34.73133	-76.68333	:America/New_York	USA	knots	215	44	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:08:00	\N	0.6	01:02:00	\N	0.8	00:57:00	00:18:00	Newport Marshes, SE of	NC
101783	Newport Marshes, SE of (depth 15 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6371_2	34.73133	-76.68333	:America/New_York	USA	knots	226	44	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:08:00	\N	0.6	01:15:00	\N	0.8	00:53:00	00:21:00	Newport Marshes, SE of	NC
101784	Newport Marshes, E of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6376_1	34.73783	-76.6805	:America/New_York	USA	knots	224	40	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:09:00	\N	0.5	00:11:00	\N	0.6	00:07:00	-00:37:00	Newport Marshes, E of	NC
101785	Radio Island, E of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6381_1	34.71167	-76.67967	:America/New_York	USA	knots	202	22	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:16:00	\N	0.6	00:55:00	\N	0.7	00:55:00	00:20:00	Radio Island, E of	NC
101786	Bird Shoal, SE of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6391_1	34.7005	-76.65383	:America/New_York	USA	knots	304	126	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:16:00	\N	0.4	01:34:00	\N	0.5	01:40:00	01:10:00	Bird Shoal, SE of	NC
101787	Shackleford Point, NE of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6396_1	34.69217	-76.65217	:America/New_York	USA	knots	305	135	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:46:00	\N	0.6	01:28:00	\N	0.8	01:32:00	01:10:00	Shackleford Point, NE of	NC
101788	Carrot Island (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6401_1	34.70217	-76.6175	:America/New_York	USA	knots	262	80	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:49:00	\N	0.7	01:34:00	\N	0.5	01:49:00	01:15:00	Carrot Island	NC
101789	Middle Marshes, S of (depth 6 ft), Beaufort Inlet, North Carolina Current	NOS	ACT6406_1	34.67833	-76.61383	:America/New_York	USA	knots	275	123	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:18:00	\N	0.5	01:04:00	\N	0.8	00:59:00	01:03:00	Middle Marshes, S of	NC
101790	Reaves Point, 0.3 mi east of (depth 6 ft), Cape Fear River, North Carolina Current	NOS	ACT6446_1	33.9986686706543	-77.94950103759766	:America/New_York	USA	knots	181	351	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98200	-01:58:00	\N	0.1	-01:01:00	\N	0.2	-00:29:00	00:23:00	Reaves Point, 0.3 mile east of	NC
101791	Reaves Point, 0.3 mi east of (depth 16 ft), Cape Fear River, North Carolina Current	NOS	ACT6446_2	33.9986686706543	-77.94950103759766	:America/New_York	USA	knots	159	332	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98200	-00:56:00	\N	0.1	00:37:00	\N	0.4	-00:06:00	01:00:00	Reaves Point, 0.3 mile east of	NC
101792	Reaves Point, 0.3 mi east of (depth 26 ft), Cape Fear River, North Carolina Current	NOS	ACT6446_3	33.9986686706543	-77.94950103759766	:America/New_York	USA	knots	160	331	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98200	00:28:00	\N	0.1	00:40:00	\N	0.6	-00:39:00	02:05:00	Reaves Point, 0.3 mile east of	NC
101793	Reaves Point Channel (depth 6 ft), Cape Fear River, North Carolina Current	NOS	ACT6451_1	33.98466873168945	-77.93083190917969	:America/New_York	USA	knots	195	9	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98200	01:08:00	\N	0.5	00:27:00	\N	0.8	00:57:00	01:02:00	Reaves Point Channel	NC
101794	Reaves Point Channel (depth 16 ft), Cape Fear River, North Carolina Current	NOS	ACT6451_2	33.98466873168945	-77.93083190917969	:America/New_York	USA	knots	192	13	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98200	01:10:00	\N	0.5	00:04:00	\N	0.9	00:34:00	00:56:00	Reaves Point Channel	NC
101795	Reaves Point Channel (depth 26 ft), Cape Fear River, North Carolina Current	NOS	ACT6451_3	33.98466873168945	-77.93083190917969	:America/New_York	USA	knots	194	17	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98200	00:43:00	\N	0.3	01:42:00	\N	0.6	00:20:00	01:42:00	Reaves Point Channel	NC
101796	Reaves Point, 0.4 mi north of (depth 6 ft), Cape Fear River, North Carolina Current	NOS	ACT6461_1	34.006168365478516	-77.95249938964844	:America/New_York	USA	knots	198	27	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98200	01:10:00	\N	0.3	00:42:00	\N	0.5	01:11:00	01:05:00	Reaves Point, 0.4 mile north of	NC
101797	Reaves Point, 0.4 mi north of (depth 16 ft), Cape Fear River, North Carolina Current	NOS	ACT6461_2	34.006168365478516	-77.95249938964844	:America/New_York	USA	knots	191	11	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98200	00:58:00	\N	0.2	01:34:00	\N	0.5	00:51:00	01:18:00	Reaves Point, 0.4 mile north of	NC
101798	Reaves Point, 0.4 mi north of (depth 26 ft), Cape Fear River, North Carolina Current	NOS	ACT6461_3	34.006168365478516	-77.95249938964844	:America/New_York	USA	knots	183	50	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98200	00:17:00	\N	0.2	01:00:00	\N	0.5	-00:05:00	01:37:00	Reaves Point, 0.4 mile north of	NC
101799	0.4 mi north of (depth 6 ft), Brunswick River, Cape Fear River, North Carolina Current	NOS	ACT6496_1	34.18117141723633	-77.96582794189453	:America/New_York	USA	knots	118	290	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98200	00:13:00	\N	0.4	00:26:00	\N	0.5	01:42:00	01:12:00	0.4 mile north of	NC
101800	0.4 mi north of (depth 16 ft), Brunswick River, Cape Fear River, North Carolina Current	NOS	ACT6496_2	34.18117141723633	-77.96582794189453	:America/New_York	USA	knots	127	301	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98200	00:13:00	\N	0.3	00:48:00	\N	0.5	01:34:00	01:14:00	0.4 mile north of	NC
101801	1.8 mi north of mouth (depth 6 ft), Cape Fear River, North Carolina Current	NOS	ACT6501_1	34.205501556396484	-77.97450256347656	:America/New_York	USA	knots	170	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98200	01:43:00	\N	0.3	01:30:00	\N	0.3	01:48:00	01:20:00	1.8 miles north of mouth	NC
101802	Winyah Bay entrance, South Carolina Current	NOS	ACT6531_1	33.20717	-79.1845	:America/New_York	USA	knots	140	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:20:00	\N	1	01:35:00	\N	1.1	01:47:00	01:05:00	Winyah Bay entrance	SC
101809	Pee Dee River, swing bridge, Winyah Bay, South Carolina Current	NOS	ACT6566_1	33.3705	-79.26383	:America/New_York	USA	knots	210	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	02:43:00	\N	0.5	03:13:00	\N	0.4	03:03:00	01:57:00	Pee Dee River, swing bridge	SC
101810	Lafayette swing bridge, Waccamaw River, Winyah Bay, South Carolina Current	NOS	ACT6571_1	33.36867	-79.252	:America/New_York	USA	knots	200	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	02:31:00	\N	0.6	03:04:00	\N	0.4	03:23:00	01:56:00	Lafayette swing bridge, Waccamaw River	SC
101811	Butler Island, 0.3 mi south of, Winyah Bay, South Carolina Current	NOS	ACT6576_1	33.41667	-79.212	:America/New_York	USA	knots	205	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	02:55:00	\N	0.5	03:34:00	\N	0.4	03:36:00	02:11:00	Butler Island, 0.3 mile south of	SC
101812	North Santee River entrance (depth 6 ft), Santee Rivers, South Carolina Current	NOS	ACT6581_1	33.13583	-79.24083	:America/New_York	USA	knots	165	10	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:01:00	\N	0.9	00:33:00	\N	0.9	01:00:00	00:03:00	North Santee River entrance	SC
101813	South Santee River entrance (depth 5 ft), Santee Rivers, South Carolina Current	NOS	ACT6586_1	33.12	-79.275	:America/New_York	USA	knots	240	45	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:15:00	\N	0.8	00:38:00	\N	0.9	00:20:00	00:27:00	South Santee River entrance	SC
101814	Fort Sumter Range, Buoy 10, Charleston Harbor, South Carolina Current	NOS	ACT6611_1	32.68299865722656	-79.72599792480469	:America/New_York	USA	knots	104	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-01:03:00	\N	0.2	-00:51:00	\N	0.2	-01:05:00	-01:11:00	Fort Sumter Range, Buoy 10	SC
101815	Fort Sumter Range, Buoy 14, Charleston Harbor, South Carolina Current	NOS	ACT6616_1	32.69770050048828	-79.75569915771484	:America/New_York	USA	knots	117	289	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:38:00	\N	0.2	-00:59:00	\N	0.3	-00:49:00	-01:10:00	Fort Sumter Range, Buoy 14	SC
101816	Fort Sumter Range, Buoy 16, Charleston Harbor, South Carolina Current	NOS	ACT6621_1	32.71500015258789	-79.79229736328125	:America/New_York	USA	knots	128	299	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:24:00	\N	0.5	-00:16:00	\N	0.4	-00:15:00	00:17:00	Fort Sumter Range, Buoy 16	SC
101817	Fort Sumter Range, Buoy 18, Charleston Harbor, South Carolina Current	NOS	ACT6626_1	32.724300384521484	-79.80999755859375	:America/New_York	USA	knots	116	287	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:01:00	\N	0.8	-00:04:00	\N	0.6	-00:10:00	00:16:00	Fort Sumter Range, Buoy 18	SC
101818	North Jetty, 0.8 mi southeast of, Charleston Harbor, South Carolina Current	NOS	ACT6631_1	32.7175	-79.8	:America/New_York	USA	knots	110	295	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:16:00	\N	0.6	-00:48:00	\N	0.2	-00:06:00	-01:09:00	North Jetty, 0.8 mile southeast of	SC
101819	Charleston Hbr. ent. (between jetties), Charleston Harbor, South Carolina Current	NOS	ACT6636_1	32.73333	-79.83333	:America/New_York	USA	knots	121	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:09:00	\N	0.9	00:04:00	\N	1.1	-00:01:00	00:05:00	Charleston Hbr. ent. (between jetties)	SC
101820	Fort Sumter Range, Buoy 22, Charleston Harbor, South Carolina Current	NOS	ACT6641_1	32.740501403808594	-79.84449768066406	:America/New_York	USA	knots	128	305	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:51:00	\N	0.9	-00:15:00	\N	0.9	-00:33:00	-00:33:00	Fort Sumter Range, Buoy 22	SC
101821	South Jetty, break in, Charleston Harbor, South Carolina Current	NOS	ACT6646_1	32.73117	-79.85033	:America/New_York	USA	knots	204	2	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:22:00	\N	1.4	00:31:00	\N	0.7	00:38:00	00:06:00	South Jetty, break in	SC
101822	Ft. Sumter, 0.6 nmi NW of, Charleston Harbor, South Carolina Current	NOS	ACT6656_1	32.76117	-79.86717	:America/New_York	USA	knots	138	322	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:24:00	\N	0.9	-00:03:00	\N	0.9	-00:05:00	00:01:00	Ft. Sumter, 0.6 n.mi. NW of	SC
101823	South Chan., 0.8 mi ENE of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6661_1	32.75867	-79.88467	:America/New_York	USA	knots	115	275	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:13:00	\N	1.3	00:11:00	\N	0.5	00:43:00	-00:12:00	South Chan., 0.8 mi. ENE of Ft. Johnson	SC
101824	South Chan., 0.4 mi NW of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6666_1	32.758	-79.90633	:America/New_York	USA	knots	104	282	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:43:00	\N	1	00:58:00	\N	0.4	01:10:00	00:16:00	South Chan., 0.4 mi. NW of Ft. Johnson	SC
101825	Castle Pinckney, 0.4 mi south of, Charleston Harbor, South Carolina Current	NOS	ACT6676_1	32.767	-79.91167	:America/New_York	USA	knots	98	304	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:58:00	\N	0.9	01:00:00	\N	0.5	00:40:00	00:14:00	Castle Pinckney, 0.4 mile south of	SC
101826	South Channel, Buoy 4, Charleston Harbor, South Carolina Current	NOS	ACT6681_1	32.76219940185547	-79.91100311279297	:America/New_York	USA	knots	125	305	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:02:00	\N	0.5	-00:04:00	\N	0.5	-00:01:00	00:18:00	South Channel, Buoy 4	SC
101827	Castle Pinckney, 0.6 mi southwest of, Charleston Harbor, South Carolina Current	NOS	ACT6686_1	32.76633	-79.9195	:America/New_York	USA	knots	156	318	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:40:00	\N	0.7	01:20:00	\N	0.4	01:21:00	00:24:00	Castle Pinckney, 0.6 mile southwest of	SC
101828	Shutes Folly Island, 0.4 mi west of, Charleston Harbor, South Carolina Current	NOS	ACT6691_1	32.77633	-79.92083	:America/New_York	USA	knots	164	28	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:08:00	\N	1.1	00:59:00	\N	0.5	00:53:00	00:20:00	Shutes Folly Island, 0.4 mile west of	SC
101829	Customhouse Reach, off Customhouse, Charleston Harbor, South Carolina Current	NOS	ACT6696_1	32.77949905395508	-79.92250061035156	:America/New_York	USA	knots	190	9	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:23:00	\N	0.7	01:03:00	\N	0.6	00:49:00	00:59:00	Customhouse Reach, off Customhouse	SC
101830	Customhouse Reach, Charleston Harbor, South Carolina Current	NOS	ACT6701_1	32.7825	-79.92	:America/New_York	USA	knots	153	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:15:00	\N	0.9	00:37:00	\N	0.6	00:46:00	00:37:00	Customhouse Reach	SC
101831	Lower Town Creek Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6706_1	32.7925	-79.9245	:America/New_York	USA	knots	172	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:07:00	\N	1.1	00:24:00	\N	0.6	00:34:00	00:02:00	Lower Town Creek Reach	SC
101832	Town Creek, 0.2 mi above bridge, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6711_1	32.80533	-79.93167	:America/New_York	USA	knots	166	2	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:03:00	\N	1.3	00:54:00	\N	0.5	01:06:00	00:03:00	Town Creek, 0.2 mile above bridge	SC
101833	Rebellion Reach, 0.8 nmi N. of Ft. Sumter, Charleston Harbor, South Carolina Current	NOS	ACT6716_1	32.76633	-79.87333	:America/New_York	USA	knots	143	329	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:48:00	\N	0.4	00:27:00	\N	0.4	-00:06:00	-00:25:00	Rebellion Reach, 0.8 n.mi. N. of Ft. Sumter	SC
101834	The Cove, entrance on the Cove Range, Charleston Harbor, South Carolina Current	NOS	ACT6721_1	32.7675	-79.872	:America/New_York	USA	knots	151	346	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:10:00	\N	0.5	01:14:00	\N	0.7	00:28:00	00:06:00	The Cove, entrance on the Cove Range	SC
101835	Hog Island Channel, Charleston Harbor, South Carolina Current	NOS	ACT6726_1	32.78117	-79.87633	:America/New_York	USA	knots	125	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:20:00	\N	0.4	00:03:00	\N	0.5	-00:39:00	-00:29:00	Hog Island Channel	SC
101836	Folly I. Channel, N of Ft. Johnson, Charleston Harbor, South Carolina Current	NOS	ACT6731_1	32.76967	-79.90117	:America/New_York	USA	knots	104	301	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:59:00	\N	0.6	-00:03:00	\N	0.7	-01:09:00	-00:04:00	Folly I. Channel, N of Ft. Johnson	SC
101837	Bennis Range, Buoy 31, Charleston Harbor, South Carolina Current	NOS	ACT6736_1	32.77629852294922	-79.89920043945312	:America/New_York	USA	knots	110	292	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:13:00	\N	0.8	00:35:00	\N	0.7	00:02:00	00:18:00	Bennis Range, Buoy 31	SC
101838	Bennis Range, Buoy 34, Charleston Harbor, South Carolina Current	NOS	ACT6741_1	32.78219985961914	-79.91079711914062	:America/New_York	USA	knots	136	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:25:00	\N	0.8	00:22:00	\N	0.7	00:18:00	00:15:00	Bennis Range, Buoy 34	SC
101839	Horse Reach, Charleston Harbor, South Carolina Current	NOS	ACT6746_1	32.78617	-79.915	:America/New_York	USA	knots	146	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:09:00	\N	1	00:23:00	\N	0.8	00:36:00	-00:12:00	Horse Reach	SC
101840	Hog Island Reach, Buoy 38, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6751_1	32.794498443603516	-79.91500091552734	:America/New_York	USA	knots	193	12	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:12:00	\N	0.7	00:28:00	\N	0.7	00:13:00	00:14:00	Hog Island Reach, Buoy 38	SC
101841	Drum Island, 0.4 mi SSE of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6756_1	32.7945	-79.92083	:America/New_York	USA	knots	155	11	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:02:00	\N	0.9	00:53:00	\N	0.8	00:34:00	00:11:00	Drum Island, 0.4 mile SSE of	SC
101842	Drum Island, east of (bridge), Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6761_1	32.8045	-79.91533	:America/New_York	USA	knots	183	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:06:00	\N	1	00:42:00	\N	0.7	00:30:00	00:15:00	Drum Island, east of (bridge)	SC
101843	Hog Island Reach, SW of Remley Point, Charleston Harbor, South Carolina Current	NOS	ACT6766_1	32.81183	-79.912	:America/New_York	USA	knots	210	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:51:00	\N	0.7	00:44:00	\N	0.7	00:30:00	00:43:00	Hog Island Reach, SW of Remley Point	SC
101844	Drum Island Reach, marker 45, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6771_1	32.816200256347656	-79.92279815673828	:America/New_York	USA	knots	133	312	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:00:00	\N	0.5	01:00:00	\N	0.4	00:26:00	01:06:00	Drum Island Reach, marker 45	SC
101845	Drum Island, 0.2 mi above, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6776_1	32.81967	-79.92917	:America/New_York	USA	knots	152	332	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:37:00	\N	1.2	01:09:00	\N	0.6	01:12:00	00:01:00	Drum Island, 0.2 mile above	SC
101846	Daniel Island Reach, Buoy 48, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6781_1	32.82720184326172	-79.92880249023438	:America/New_York	USA	knots	182	6	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:55:00	\N	0.7	01:29:00	\N	0.7	01:01:00	00:53:00	Daniel Island Reach, Buoy 48	SC
101847	Shipyard Creek entrance, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6786_1	32.83000183105469	-79.93499755859375	:America/New_York	USA	knots	197	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:09:00	\N	0.8	01:06:00	\N	0.3	00:41:00	-00:29:00	Shipyard Creek entrance	SC
101848	Daniel Island Reach, Buoy 47A, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6791_1	32.832801818847656	-79.93000030517578	:America/New_York	USA	knots	190	352	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:51:00	\N	1.2	01:49:00	\N	0.8	01:29:00	00:42:00	Daniel Island Reach, Buoy 47A	SC
101849	Daniel Island Bend, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6796_1	32.84833	-79.92917	:America/New_York	USA	knots	153	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:39:00	\N	1.1	01:29:00	\N	0.7	00:55:00	00:55:00	Daniel Island Bend	SC
101850	North Charleston, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6806_1	32.86367	-79.95883	:America/New_York	USA	knots	142	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:17:00	\N	0.9	02:28:00	\N	0.6	01:26:00	01:04:00	North Charleston	SC
101851	Filbin Creek Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6811_1	32.88867	-79.96533	:America/New_York	USA	knots	180	6	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:27:00	\N	0.9	02:06:00	\N	0.7	01:31:00	01:08:00	Filbin Creek Reach	SC
101852	Filbin Creek Reach, 0.2 mi east of, Charleston Harbor, South Carolina Current	NOS	ACT6816_1	32.888	-79.9605	:America/New_York	USA	knots	197	2	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:29:00	\N	0.7	01:47:00	\N	0.4	01:16:00	00:32:00	Filbin Creek Reach, 0.2 mile east of	SC
101853	Filbin Creek Reach, Buoy 58, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6821_1	32.89630126953125	-79.96119689941406	:America/New_York	USA	knots	214	31	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:09:00	\N	0.7	02:04:00	\N	0.6	01:18:00	01:24:00	Filbin Creek Reach, Buoy 58	SC
101854	Ordnance Reach, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6826_1	32.90633	-79.95283	:America/New_York	USA	knots	242	62	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:07:00	\N	0.6	02:34:00	\N	0.6	01:35:00	01:05:00	Ordnance Reach	SC
101855	Yellow House Creek, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6831_1	32.90883	-79.93633	:America/New_York	USA	knots	270	88	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:12:00	\N	0.7	02:41:00	\N	0.4	02:06:00	00:57:00	Yellow House Creek	SC
101856	Yellow House Landing, 1 mi NW of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6836_1	32.91967	-79.9305	:America/New_York	USA	knots	170	334	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:06:00	\N	0.9	02:43:00	\N	0.4	02:26:00	00:58:00	Yellow House Landing, 1 mile NW of	SC
101857	Woods Point, SE of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6841_1	32.92583084106445	-79.93283081054688	:America/New_York	USA	knots	157	334	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	02:09:00	\N	0.5	01:55:00	\N	0.5	01:48:00	01:55:00	Woods Point, SE of	SC
101858	Woods Point, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6846_1	32.93167	-79.93833	:America/New_York	USA	knots	201	2	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:43:00	\N	0.7	03:02:00	\N	0.5	02:41:00	01:11:00	Woods Point	SC
101859	Snow Point, 0.5 mi north of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6851_1	32.95167	-79.93	:America/New_York	USA	knots	210	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:33:00	\N	0.7	02:36:00	\N	0.6	02:15:00	01:48:00	Snow Point, 0.5 mile north of	SC
101860	Back River entrance, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6856_1	32.96833	-79.93333	:America/New_York	USA	knots	67	252	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:34:00	\N	0.6	00:45:00	\N	0.6	00:46:00	00:48:00	Back River entrance	SC
101861	Off Amoco Pier, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6861_1	32.95920181274414	-79.91799926757812	:America/New_York	USA	knots	191	24	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:48:00	\N	0.5	02:49:00	\N	0.4	02:09:00	02:10:00	off Amoco Pier	SC
101862	Moreland, 0.5 nmi below, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6866_1	33.0005	-79.90467	:America/New_York	USA	knots	216	36	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	02:19:00	\N	1	02:58:00	\N	1.1	02:39:00	02:28:00	Moreland, 0.5 n.mi. below	SC
101863	Hagan Island, 1 nmi below, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6871_1	33.03333	-79.91333	:America/New_York	USA	knots	134	308	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:37:00	\N	0.7	03:52:00	\N	0.8	02:39:00	02:27:00	Hagan Island, 1 n.mi. below	SC
101864	The Tee, 0.4 mi southwest of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6876_1	33.06333	-79.92967	:America/New_York	USA	knots	98	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	03:20:00	\N	0.9	04:20:00	\N	0.6	04:22:00	02:29:00	The Tee, 0.4 mile southwest of	SC
101865	The Tee, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6881_1	33.06583	-79.923	:America/New_York	USA	knots	161	339	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:43:00	\N	0.5	03:09:00	\N	0.6	03:00:00	02:36:00	The Tee	SC
101866	Childsbury, S.A.L. RR. bridge, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6886_1	33.09383	-79.9425	:America/New_York	USA	knots	141	309	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	03:34:00	\N	0.9	04:27:00	\N	0.4	04:43:00	02:15:00	Childsbury, S.A.L. RR. bridge	SC
101867	East Branch, 0.2 mi above entrance, Charleston Harbor, South Carolina Current	NOS	ACT6891_1	33.06833	-79.92	:America/New_York	USA	knots	262	84	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	03:06:00	\N	0.9	03:07:00	\N	1.1	03:01:00	02:59:00	East Branch, 0.2 mile above entrance	SC
101868	Bonneau Ferry, east of, Cooper River, Charleston Harbor, South Carolina Current	NOS	ACT6896_1	33.07167	-79.88333	:America/New_York	USA	knots	197	22	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	03:36:00	\N	0.4	03:10:00	\N	0.4	03:27:00	02:44:00	Bonneau Ferry, east of	SC
101869	Remley Point, 0.2 mi northwest of, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6901_1	32.81617	-79.9095	:America/New_York	USA	knots	191	28	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:04:00	\N	0.9	00:36:00	\N	0.8	-00:14:00	00:20:00	Remley Point, 0.2 mile northwest of	SC
101870	Wando River Upper Reach, Turning Basin, Charleston Harbor, South Carolina Current	NOS	ACT6906_1	32.83333	-79.89667	:America/New_York	USA	knots	192	12	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:09:00	\N	0.6	-00:12:00	\N	0.6	-00:14:00	-00:09:00	Wando River Upper Reach, Turning Basin	SC
101871	Rathall Creek entrance, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6911_1	32.8595	-79.89617	:America/New_York	USA	knots	216	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:18:00	\N	0.9	00:35:00	\N	0.8	00:25:00	00:18:00	Rathall Creek entrance	SC
101872	Horlbeck Creek, 0.2 mi above entrance, Charleston Harbor, South Carolina Current	NOS	ACT6916_1	32.885	-79.845	:America/New_York	USA	knots	218	26	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:24:00	\N	0.5	00:29:00	\N	0.6	00:28:00	00:31:00	Horlbeck Creek, 0.2 mile above entrance	SC
101873	Nowell Creek entrance, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6921_1	32.87833	-79.875	:America/New_York	USA	knots	171	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:39:00	\N	0.6	00:42:00	\N	0.4	-00:02:00	-00:12:00	Nowell Creek entrance	SC
101874	Nowell Creek, southeast of, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6926_1	32.87200164794922	-79.8655014038086	:America/New_York	USA	knots	261	80	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:19:00	\N	0.5	-00:06:00	\N	0.5	-00:08:00	00:04:00	Nowell Creek, Southeast of	SC
101875	Anneville, marker 36, Wando River, Charleston Harbor, South Carolina Current	NOS	ACT6931_1	32.91830062866211	-79.83830261230469	:America/New_York	USA	knots	207	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:28:00	\N	0.7	00:41:00	\N	0.5	00:30:00	00:26:00	Anneville, marker 36	SC
101876	Battery, southwest of, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6936_1	32.76717	-79.93383	:America/New_York	USA	knots	114	303	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:03:00	\N	0.9	00:09:00	\N	0.7	00:16:00	-00:24:00	Battery, southwest of	SC
101877	Wappoo Creek entrance, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6941_1	32.77299880981445	-79.94999694824219	:America/New_York	USA	knots	136	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:41:00	\N	0.6	-00:05:00	\N	0.7	00:07:00	-00:06:00	Wappoo Creek entrance	SC
101878	Ashley River Memorial Bridge, Highway 17, Charleston Harbor, South Carolina Current	NOS	ACT6946_1	32.78200149536133	-79.95999908447266	:America/New_York	USA	knots	138	321	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:18:00	\N	0.6	00:30:00	\N	0.7	-00:09:00	-00:03:00	Ashley River Memorial Bridge, Highway 17	SC
101879	Trestle Ruins, marker 6A, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6951_1	32.795501708984375	-79.97329711914062	:America/New_York	USA	knots	150	353	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:28:00	\N	0.6	00:44:00	\N	0.6	-00:06:00	-00:12:00	Trestle Ruins, marker 6A	SC
101880	Duck Island, Marker 15, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6956_1	32.81999969482422	-79.96499633789062	:America/New_York	USA	knots	178	351	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:09:00	\N	0.8	00:19:00	\N	0.7	00:22:00	00:17:00	Duck Island, Marker 15	SC
101881	State Hwy. 7 bridge, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6961_1	32.83717	-79.982	:America/New_York	USA	knots	114	293	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:05:00	\N	0.5	-00:04:00	\N	0.6	00:06:00	00:05:00	State Hwy. 7 bridge	SC
101882	West Marsh Island, 0.1 mi east of, Charleston Harbor, South Carolina Current	NOS	ACT6966_1	32.82833	-80.00833	:America/New_York	USA	knots	86	250	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:25:00	\N	0.5	00:30:00	\N	0.4	00:23:00	00:14:00	West Marsh Island, 0.1 mile east of	SC
101883	Drayton, Railroad Bridge, Ashley River, Charleston Harbor, South Carolina Current	NOS	ACT6971_1	32.84669876098633	-80.05000305175781	:America/New_York	USA	knots	130	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:21:00	\N	1.2	00:30:00	\N	1.1	00:22:00	00:44:00	Drayton, Railroad Bridge	SC
101884	Stono Inlet, Stono River, South Carolina Current	NOS	ACT6976_1	32.62667	-79.99333	:America/New_York	USA	knots	136	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:45:00	\N	1.4	00:44:00	\N	1.1	-00:14:00	-00:09:00	Stono Inlet	SC
101885	Snake Island (depth 12 ft), Stono River, South Carolina Current	NOS	ACT6981_1	32.64	-80.02	:America/New_York	USA	knots	179	347	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:38:00	\N	0.5	-00:42:00	\N	0.7	-00:44:00	-00:30:00	Snake Island	SC
101886	Johns Island Airport, south of (depth 12 ft), Stono River, South Carolina Current	NOS	ACT6986_1	32.68333	-80.00333	:America/New_York	USA	knots	192	7	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:34:00	\N	0.8	-00:46:00	\N	0.9	-00:15:00	-00:13:00	Johns Island Airport, south of	SC
101887	Johns Island Bridge (depth 14 ft), Stono River, South Carolina Current	NOS	ACT6991_1	32.75333	-80.01	:America/New_York	USA	knots	182	358	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:10:00	\N	0.5	00:21:00	\N	0.5	00:40:00	00:33:00	Johns Island Bridge	SC
101888	Elliott Cut, west end, Stono River, South Carolina Current	NOS	ACT6996_1	32.76667	-80	:America/New_York	USA	knots	80	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:18:00	\N	1	-01:00:00	\N	0.9	00:10:00	-00:46:00	Elliott Cut, west end	SC
101889	Johns Island, main road bridge (depth 12 ft), Stono River, South Carolina Current	NOS	ACT7001_1	32.78670120239258	-80.10669708251953	:America/New_York	USA	knots	68	249	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:32:00	\N	0.4	01:48:00	\N	0.4	-00:24:00	00:29:00	Johns Island. Main Road Bridge	SC
101890	Pleasant Point (depth 12 ft), Stono River, South Carolina Current	NOS	ACT7006_1	32.75	-80.13333	:America/New_York	USA	knots	196	8	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	03:37:00	\N	0.4	00:34:00	\N	0.3	02:04:00	03:54:00	Pleasant Point	SC
101891	Deveaux Banks, off North Edisto River entrance (depth 12 ft), South Carolina Current	NOS	ACT7021_1	32.545	-80.15667	:America/New_York	USA	knots	126	306	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:26:00	\N	1	-00:01:00	\N	0.8	-00:16:00	-00:04:00	Deveaux Banks, off North Edisto River entrance	SC
101892	North Edisto River entrance, South Carolina Current	NOS	ACT7026_1	32.56167	-80.18667	:America/New_York	USA	knots	142	332	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:43:00	\N	1.9	01:10:00	\N	1.7	00:56:00	01:11:00	North Edisto River entrance	SC
101893	Wadmalaw Island, Wadmalaw River entrance (depth 12 ft), South Carolina Current	NOS	ACT7031_1	32.665	-80.235	:America/New_York	USA	knots	165	355	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-01:29:00	\N	0.4	00:11:00	\N	0.7	-01:02:00	00:06:00	Wadmalaw Island, Wadmalaw River entrance	SC
101894	Goshen Point, SE of, Wadmalaw River (depth 12 ft), South Carolina Current	NOS	ACT7036_1	32.71	-80.17167	:America/New_York	USA	knots	249	59	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:48:00	\N	0.4	02:18:00	\N	0.5	00:51:00	01:47:00	Goshen Point, SE of, Wadmalaw River	SC
101895	Goshen Point, south of, Wadmalaw River (depth 12 ft), South Carolina Current	NOS	ACT7041_1	32.71333	-80.18667	:America/New_York	USA	knots	235	48	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:53:00	\N	0.5	02:03:00	\N	0.4	01:24:00	01:35:00	Goshen Point, south of, Wadmalaw River	SC
101896	White Point, south of, Dawho River (depth 12 ft), South Carolina Current	NOS	ACT7046_1	32.625	-80.28167	:America/New_York	USA	knots	44	234	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:15:00	\N	0.4	00:02:00	\N	0.4	00:31:00	00:29:00	White Point, south of, Dawho River	SC
101897	Whooping Island, Dawho River (depth 12 ft), North Edisto River, South Carolina Current	NOS	ACT7051_1	32.63667	-80.34	:America/New_York	USA	knots	70	246	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:37:00	\N	0.3	00:36:00	\N	0.5	01:36:00	01:35:00	Whooping Island, Dawho River	SC
101898	South Edisto River entrance, South Carolina Current	NOS	ACT7056_1	32.48833	-80.34833	:America/New_York	USA	knots	146	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:24:00	\N	1.1	-00:14:00	\N	1.1	00:19:00	-00:09:00	South Edisto River entrance	SC
101899	Pine Island, South Edisto River (depth 15 ft), South Carolina Current	NOS	ACT7061_1	32.50667	-80.36167	:America/New_York	USA	knots	163	345	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:37:00	\N	0.5	-00:09:00	\N	0.7	00:00:00	00:12:00	Pine Island, South Edisto River	SC
101900	Fenwick Island Cut, South Edisto River (depth 15 ft), South Carolina Current	NOS	ACT7066_1	32.535	-80.41333	:America/New_York	USA	knots	23	220	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-01:26:00	\N	0.4	-00:55:00	\N	0.4	-02:43:00	-03:20:00	Fenwick Island Cut, South Edisto River	SC
101901	Sampson Island, S end, South Edisto Riv. (depth 15 ft), South Carolina Current	NOS	ACT7071_1	32.56330108642578	-80.3917007446289	:America/New_York	USA	knots	244	37	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:52:00	\N	0.8	00:34:00	\N	0.8	00:59:00	00:59:00	Sampson Island, S end, South Edisto Riv.	SC
101902	Sampson Island, NE end, South Edisto Riv. (depth 15 ft), South Carolina Current	NOS	ACT7076_1	32.61669921875	-80.38670349121094	:America/New_York	USA	knots	156	334	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:52:00	\N	0.8	01:15:00	\N	0.8	01:35:00	01:02:00	Sampson Island, NE end, South Edisto Riv.	SC
101903	Jehossee Island, S tip, South Edisto River (depth 15 ft), South Carolina Current	NOS	ACT7081_1	32.60333	-80.42	:America/New_York	USA	knots	69	275	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:05:00	\N	0.7	00:48:00	\N	0.7	01:44:00	00:53:00	Jehossee Island, S tip, South Edisto River	SC
101904	Smuggedy Swamp, South Edisto River (depth 6 ft), South Carolina Current	NOS	ACT7086_1	32.66	-80.41167	:America/New_York	USA	knots	166	349	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	02:25:00	\N	0.7	01:14:00	\N	0.5	02:26:00	01:01:00	Smuggedy Swamp, South Edisto River	SC
101905	Hutchinson Island, N. of, Ashepoo River (depth 10 ft), South Carolina Current	NOS	ACT7091_1	32.531700134277344	-80.43499755859375	:America/New_York	USA	knots	68	278	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:56:00	\N	0.7	01:14:00	\N	0.6	01:21:00	00:54:00	Hutchinson Island, N. of, Ashepoo River	SC
101906	Ashepoo Coosaw Cutoff, ICW marker 169 (depth 6 ft), South Carolina Current	NOS	ACT7096_1	32.525001525878906	-80.45330047607422	:America/New_York	USA	knots	265	65	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:12:00	\N	0.6	00:36:00	\N	0.5	01:22:00	00:56:00	Ashepoo Coosaw Cutoff, ICW marker 169	SC
101907	Pelican Bank, St. Helena Sound (depth 15 ft), South Carolina Current	NOS	ACT7101_1	32.455	-80.42833	:America/New_York	USA	knots	118	300	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:35:00	\N	0.8	-00:33:00	\N	0.9	00:05:00	00:17:00	Pelican Bank, St. Helena Sound	SC
101908	Ashepoo River, off Jefford Creek, St. Helena Sound, South Carolina Current	NOS	ACT7106_1	32.50669860839844	-80.41000366210938	:America/New_York	USA	knots	197	16	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:43:00	\N	0.8	00:46:00	\N	0.9	01:04:00	01:00:00	Ashepoo River, off Jefford Creek	SC
101909	Egg Bank, St. Helena Sound (depth 10 ft), South Carolina Current	NOS	ACT7111_1	32.435	-80.44333	:America/New_York	USA	knots	128	329	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:20:00	\N	0.8	-01:24:00	\N	0.8	-00:12:00	-00:06:00	Egg Bank, St. Helena Sound	SC
101910	Morgan Island, NE of, Coosaw River (depth 15 ft), South Carolina Current	NOS	ACT7116_1	32.48833	-80.47333	:America/New_York	USA	knots	125	303	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:19:00	\N	1	00:27:00	\N	0.8	00:28:00	00:36:00	Morgan Island, NE of, Coosaw River	SC
101926	Hilton Head, Port Royal Sound, South Carolina Current	NOS	ACT7201_1	32.25	-80.66667	:America/New_York	USA	knots	146	324	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:01:00	\N	0.9	00:49:00	\N	1.1	00:16:00	00:32:00	Hilton Head	SC
101911	Ashepoo Coosaw Cutoff, south end (depth 15 ft), St. Helena Sound, South Carolina Current	NOS	ACT7121_1	32.5099983215332	-80.50499725341797	:America/New_York	USA	knots	134	325	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:31:00	\N	0.6	-00:09:00	\N	0.6	00:32:00	00:43:00	Ashepoo Coosaw Cutoff, south end	SC
101912	Ashepoo Coosaw Cutoff, ICW marker 181 (depth 6 ft), South Carolina Current	NOS	ACT7126_1	32.52000045776367	-80.48829650878906	:America/New_York	USA	knots	34	232	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:13:00	\N	0.4	01:41:00	\N	0.5	00:31:00	01:01:00	Ashepoo Coosaw Cutoff, ICW marker 181	SC
101913	Combahee River entrance (depth 8 ft), St. Helena Sound, South Carolina Current	NOS	ACT7131_1	32.52669906616211	-80.53669738769531	:America/New_York	USA	knots	147	335	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:53:00	\N	0.8	00:59:00	\N	0.6	00:55:00	01:04:00	Combahee River entrance	SC
101914	Combahee River, S. of Fields Point (depth 15 ft), South Carolina Current	NOS	ACT7136_1	32.54999923706055	-80.56330108642578	:America/New_York	USA	knots	73	280	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:03:00	\N	1	01:35:00	\N	0.8	01:36:00	01:33:00	Combahee River, S. of Fields Point	SC
101915	Parrot Creek, Coosaw Island (depth 15 ft), St. Helena Sound, South Carolina Current	NOS	ACT7141_1	32.47333	-80.545	:America/New_York	USA	knots	175	355	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:54:00	\N	0.6	-00:48:00	\N	0.7	00:12:00	00:24:00	Parrot Creek, Coosaw Island	SC
101916	Morgan Island, north end, Coosaw River (depth 15 ft), South Carolina Current	NOS	ACT7146_1	32.50333	-80.53667	:America/New_York	USA	knots	85	271	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:30:00	\N	0.9	00:41:00	\N	0.8	00:34:00	00:27:00	Morgan Island, North end, Coosaw River	SC
101917	Williman Creek (depth 10 ft), St. Helena Sound, South Carolina Current	NOS	ACT7151_1	32.56167	-80.59167	:America/New_York	USA	knots	160	343	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:04:00	\N	0.8	01:27:00	\N	0.6	00:40:00	01:02:00	Williman Creek	SC
101918	Coosaw Island, south of, Morgan River (depth 10 ft), South Carolina Current	NOS	ACT7156_1	32.45167	-80.58333	:America/New_York	USA	knots	58	252	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:03:00	\N	0.7	00:55:00	\N	0.7	00:09:00	00:15:00	Coosaw Island, South of, Morgan River	SC
101919	Sams Point, northeast of, Coosaw River (depth 10 ft), South Carolina Current	NOS	ACT7161_1	32.49330139160156	-80.59329986572266	:America/New_York	USA	knots	117	292	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:24:00	\N	0.6	00:36:00	\N	0.5	00:34:00	00:31:00	Sams Point, Northeast of, Coosaw River	SC
101920	Whale Branch River (depth 10 ft), St. Helena Sound, South Carolina Current	NOS	ACT7166_1	32.52667	-80.69167	:America/New_York	USA	knots	111	295	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:09:00	\N	0.7	-00:09:00	\N	0.5	01:12:00	00:51:00	Whale Branch River	SC
101921	Fripps Inlet, Fripps Island (depth 15 ft), St. Helena Sound, South Carolina Current	NOS	ACT7171_1	32.34	-80.465	:America/New_York	USA	knots	104	299	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-01:29:00	\N	0.6	01:12:00	\N	0.7	-00:29:00	-00:22:00	Fripps Inlet, Fripps Island	SC
101922	Southeast Channel, Buoy 8, Port Royal Sound, South Carolina Current	NOS	ACT7181_1	32.13330078125	-80.58329772949219	:America/New_York	USA	knots	150	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:12:00	\N	0.8	-00:38:00	\N	0.8	-00:30:00	-00:09:00	Southeast Channel, Buoy 8	SC
101923	Port Royal Plantation Tower, east of (depth 15 ft), South Carolina Current	NOS	ACT7186_1	32.22333	-80.65667	:America/New_York	USA	knots	147	347	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:16:00	\N	1	-00:16:00	\N	0.9	00:33:00	00:19:00	Port Royal Plantation Tower, east of	SC
101924	Bay Point Island, S of, Broad River entrance (depth 15 ft), South Carolina Current	NOS	ACT7191_1	32.23333	-80.63	:America/New_York	USA	knots	128	320	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:46:00	\N	0.9	-01:09:00	\N	0.7	00:39:00	00:06:00	Bay Point Island, S of, Broad River entrance	SC
101925	Broad River entrance, Point Royal Sound (depth 15 ft), South Carolina Current	NOS	ACT7196_1	32.23167	-80.64	:America/New_York	USA	knots	138	324	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:25:00	\N	0.9	00:21:00	\N	1	00:36:00	00:32:00	Broad River Entrance, Point Royal Sound	SC
101927	Beaufort River entrance (depth 15 ft), Port Royal Sound, South Carolina Current	NOS	ACT7206_1	32.28833	-80.65167	:America/New_York	USA	knots	195	10	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:03:00	\N	0.7	01:11:00	\N	0.7	00:19:00	00:20:00	Beaufort River Entrance	SC
101928	Parris Island, east of, Beaufort River (depth 10 ft), South Carolina Current	NOS	ACT7211_1	32.326698303222656	-80.65670013427734	:America/New_York	USA	knots	175	356	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:12:00	\N	0.8	01:12:00	\N	0.7	00:29:00	00:11:00	Parris Island, east of, Beaufort River	SC
101929	Chowan Creek (depth 15 ft), Port Royal Sound, South Carolina Current	NOS	ACT7216_1	32.37	-80.63833	:America/New_York	USA	knots	246	39	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:34:00	\N	0.6	01:53:00	\N	0.6	00:24:00	00:23:00	Chowan Creek	SC
101930	Parris Island, north of, Beaufort River (depth 15 ft), South Carolina Current	NOS	ACT7221_1	32.36000061035156	-80.67500305175781	:America/New_York	USA	knots	149	341	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:22:00	\N	0.7	01:19:00	\N	0.7	00:56:00	00:51:00	Parris Island, north of, Beaufort River	SC
101931	Burkmeyer Bech, Beaufort River (depth 15 ft), Port Royal Sound, South Carolina Current	NOS	ACT7226_1	32.40330123901367	-80.67169952392578	:America/New_York	USA	knots	200	12	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:33:00	\N	0.5	01:19:00	\N	0.5	01:04:00	01:01:00	Burkmeyer Bech, Beaufort River	SC
101932	Beaufort, Beaufort River (depth 12 ft), Port Royal Sound, South Carolina Current	NOS	ACT7231_1	32.43	-80.67667	:America/New_York	USA	knots	257	73	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:17:00	\N	0.6	01:18:00	\N	0.7	00:55:00	01:08:00	Beaufort, Beaufort River	SC
101933	Beaufort Airport, Beaufort River (depth 15 ft), Port Royal Sound, South Carolina Current	NOS	ACT7236_1	32.45	-80.66333	:America/New_York	USA	knots	152	333	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	01:08:00	\N	0.5	01:39:00	\N	0.5	01:25:00	01:21:00	Beaufort Airport, Beaufort River	SC
101934	Brickyard Creek (depth 10 ft), Port Royal Sound, South Carolina Current	NOS	ACT7241_1	32.47333	-80.69167	:America/New_York	USA	knots	171	351	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	02:58:00	\N	0.4	00:30:00	\N	0.5	01:48:00	02:50:00	Brickyard Creek	SC
101935	Skull Creek, north entrance, Port Royal Sound, South Carolina Current	NOS	ACT7246_1	32.26333	-80.74167	:America/New_York	USA	knots	35	222	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-02:14:00	\N	0.6	-01:20:00	\N	0.4	-01:50:00	-01:58:00	Skull Creek, north entrance	SC
101936	Daws Island, SE of, Broad River (depth 15 ft), Port Royal Sound, South Carolina Current	NOS	ACT7251_1	32.30167	-80.725	:America/New_York	USA	knots	150	330	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:31:00	\N	0.8	00:05:00	\N	0.8	00:46:00	00:39:00	Daws Island, SE of, Broad River	SC
101937	Parris Island Lookout Tower, Broad River (depth 15 ft), South Carolina Current	NOS	ACT7256_1	32.31167	-80.70667	:America/New_York	USA	knots	152	339	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:16:00	\N	0.7	-00:07:00	\N	0.7	00:39:00	00:29:00	Parris Island Lookout Tower, Broad River	SC
101938	Daws Island, south of, Chechessee River (depth 15 ft), South Carolina Current	NOS	ACT7261_1	32.28667	-80.74333	:America/New_York	USA	knots	142	317	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:31:00	\N	0.7	-00:22:00	\N	0.6	00:31:00	00:34:00	Daws Island, south of, Chechessee River	SC
101939	Lemon Island South, Chechessee River (depth 10 ft), South Carolina Current	NOS	ACT7266_1	32.35	-80.80667	:America/New_York	USA	knots	175	359	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	-00:02:00	\N	0.7	01:19:00	\N	0.6	00:33:00	00:39:00	Lemon Island South, Chechessee River	SC
101940	Broad River Bridge, S of, Broad River (depth 15 ft), South Carolina Current	NOS	ACT7271_1	32.38167	-80.77667	:America/New_York	USA	knots	156	341	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:07:00	\N	0.8	-00:15:00	\N	0.6	00:52:00	00:49:00	Broad River Bridge, S of, Broad River	SC
101941	Boyd Creek entrance, SE of, Broad River (depth 12 ft), South Carolina Current	NOS	ACT7276_1	32.45669937133789	-80.81829833984375	:America/New_York	USA	knots	174	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:52:00	\N	0.5	00:51:00	\N	0.6	01:27:00	01:32:00	Boyd Creek Entrance, SE of, Broad River	SC
101942	Little Barnwell I., E of, Whale Branch River (depth 6 ft), South Carolina Current	NOS	ACT7281_1	32.50167	-80.78667	:America/New_York	USA	knots	175	354	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97991	00:40:00	\N	0.4	03:03:00	\N	0.6	01:41:00	01:54:00	Little Barnwell I., E of, Whale Branch River	SC
101943	Braddock Point, SW of, Calibogue Sound (depth 10 ft), South Carolina Current	NOS	ACT7286_1	32.105	-80.83667	:America/New_York	USA	knots	183	6	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:04:00	\N	1	00:16:00	\N	0.8	-00:15:00	-00:04:00	Braddock Point, SW of, Calibogue Sound	SC
101944	Haig Point Light, NW of, Cooper River (depth 10 ft), South Carolina Current	NOS	ACT7291_1	32.14833	-80.84167	:America/New_York	USA	knots	94	278	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:12:00	\N	0.7	-00:05:00	\N	0.4	-00:51:00	-00:40:00	Haig Point Light, NW of, Cooper River	SC
101945	Ramshorn Creek Light, E of, Cooper River (depth 6 ft), South Carolina Current	NOS	ACT7296_1	32.13	-80.88167	:America/New_York	USA	knots	98	280	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:17:00	\N	0.7	-00:53:00	\N	0.5	00:06:00	00:15:00	Ramshorn Creek Light, E of, Cooper River	SC
101946	Spanish Wells, Calibogue Sound (depth 30 ft), South Carolina Current	NOS	ACT7301_1	32.18667	-80.785	:America/New_York	USA	knots	204	28	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:10:00	\N	0.7	00:51:00	\N	0.7	-00:14:00	00:12:00	Spanish Wells, Calibogue Sound	SC
101947	Skull Creek, south entrance (depth 10 ft), Calibogue Sound, South Carolina Current	NOS	ACT7306_1	32.22333	-80.785	:America/New_York	USA	knots	231	53	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	00:55:00	\N	0.4	02:57:00	\N	0.4	00:38:00	01:23:00	Skull Creek, south entrance	SC
101948	MacKay Creek, south entrance (depth 10 ft), Calibogue Sound, South Carolina Current	NOS	ACT7311_1	32.22	-80.79	:America/New_York	USA	knots	212	33	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:26:00	\N	0.6	00:03:00	\N	0.3	00:06:00	00:12:00	MacKay Creek, south entrance	SC
101949	Bloody Pt., 0.5 mi north of, New River, South Carolina Current	NOS	ACT7316_1	32.08833	-80.88	:America/New_York	USA	knots	147	332	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-02:13:00	\N	0.6	00:00:00	\N	0.6	-01:03:00	-00:53:00	Bloody Pt., 0.5 mile north of, New River	SC
101950	Bloody Pt., 0.5 mi west of, New River, South Carolina Current	NOS	ACT7321_1	32.08167	-80.88333	:America/New_York	USA	knots	92	267	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:26:00	\N	0.9	-00:21:00	\N	0.9	-00:47:00	-00:36:00	Bloody Pt., 0.5 mile west of, New River	SC
101951	Wright R., 0.2 mi above Walls Cut, South Carolina Current	NOS	ACT7326_1	32.085	-80.92167	:America/New_York	USA	knots	142	332	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:16:00	\N	0.8	-00:16:00	\N	0.6	-00:38:00	-00:38:00	Wright R., 0.2 mile above Walls Cut	SC
101952	Walls Cut, Turtle Island (depth 6 ft), South Carolina Current	NOS	ACT7336_1	32.08167	-80.91667	:America/New_York	USA	knots	100	294	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-03:05:00	\N	0.5	-00:57:00	\N	0.5	-02:29:00	-01:12:00	Walls Cut, Turtle Island	SC
101953	Daufuskie Landing Light, south of (depth 10 ft), South Carolina Current	NOS	ACT7341_1	32.10167	-80.89833	:America/New_York	USA	knots	226	43	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:45:00	\N	0.8	01:04:00	\N	0.7	00:07:00	00:02:00	Daufuskie Landing Light, south of	SC
101954	Fort Pulaski, N of, Savannah River, South Carolina Current	NOS	ACT7356_1	32.03667	-80.90167	:America/New_York	USA	knots	98	283	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	00:09:00	\N	1.5	00:51:00	\N	0.9	00:42:00	00:15:00	Fort Pulaski	SC
101955	Fort Pulaski, 1.8 mi above, Savannah River, Georgia Current	NOS	ACT7361_1	32.045	-80.93167	:America/New_York	USA	knots	140	316	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	00:12:00	\N	1.4	00:18:00	\N	1.1	00:25:00	-00:01:00	Fort Pulaski, 1.8 miles above	GA
101956	Fort Pulaski, 4.8 mi above, Savannah River, Georgia Current	NOS	ACT7366_1	32.075	-80.97667	:America/New_York	USA	knots	116	296	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:16:00	\N	1.5	00:31:00	\N	1.1	00:36:00	00:06:00	Fort Pulaski, 4.8 miles above	GA
101957	McQueen Island Cut (depth 10 ft), Savannah River, Georgia Current	NOS	ACT7371_1	32.065	-80.98667	:America/New_York	USA	knots	69	251	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-02:44:00	\N	0.6	-02:45:00	\N	0.3	-02:39:00	-01:04:00	McQueen Island Cut	GA
101958	Elba Island Cut, NE of, Savannah River (depth 10 ft), South Carolina Current	NOS	ACT7376_1	32.07333	-80.965	:America/New_York	USA	knots	104	288	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:14:00	\N	1.3	00:15:00	\N	0.7	00:26:00	-00:37:00	Elba Island Cut, NE of, Savannah River	SC
101959	Elba Island, NE of, Savannah River (depth 10 ft), Georgia Current	NOS	ACT7381_1	32.09	-80.99333	:America/New_York	USA	knots	149	329	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:27:00	\N	1.2	00:40:00	\N	0.6	01:01:00	-00:35:00	Elba Island, NE of, Savannah River	GA
101960	Elba Island, west of, Savannah River (depth 10 ft), South Carolina Current	NOS	ACT7386_1	32.095	-81.02	:America/New_York	USA	knots	40	219	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:53:00	\N	0.8	00:52:00	\N	0.5	00:37:00	-00:30:00	Elba Island, west of, Savannah River	SC
101961	Fig Island, north of, Back River, Savannah River, Georgia Current	NOS	ACT7391_1	32.085	-81.05	:America/New_York	USA	knots	94	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:00:00	\N	0.7	01:06:00	\N	0.5	00:14:00	-00:25:00	Fig Island, north of, Back River	GA
101962	South Channel, western end, Savannah River, Georgia Current	NOS	ACT7396_1	32.08833	-81.01667	:America/New_York	USA	knots	122	300	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:35:00	\N	0.7	00:18:00	\N	0.5	00:42:00	-00:33:00	South Channel, western end	GA
101963	Wilmington R. ent., south channel, Savannah River, Georgia Current	NOS	ACT7401_1	32.07667	-81.00167	:America/New_York	USA	knots	206	32	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	01:25:00	\N	0.8	-00:36:00	\N	0.5	00:42:00	01:28:00	Wilmington R. ent., south channel	GA
101964	Savannah, southeast of highway bridge (depth 10 ft), Savannah River, Georgia Current	NOS	ACT7406_1	32.08667	-81.09667	:America/New_York	USA	knots	146	319	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	00:05:00	\N	1.3	00:41:00	\N	0.6	01:36:00	-00:24:00	Savannah, southeast of highway bridge	GA
101965	Savannah, Savannah River, Georgia Current	NOS	ACT7411_1	32.08333	-81.08333	:America/New_York	USA	knots	106	279	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	00:18:00	\N	1.1	00:45:00	\N	0.8	01:12:00	00:01:00	Savannah	GA
101966	Kings Island Channel, Savannah River (depth 10 ft), Georgia Current	NOS	ACT7416_1	32.12667	-81.13667	:America/New_York	USA	knots	152	339	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:21:00	\N	1	00:45:00	\N	0.8	01:21:00	00:06:00	Kings Island Channel, Savannah River	GA
101967	Seaboard Coast Line Railroad, Savannah River, Georgia Current	NOS	ACT7421_1	32.10333	-81.11833	:America/New_York	USA	knots	150	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	00:59:00	\N	1.7	00:45:00	\N	1.2	01:06:00	00:29:00	Seaboard Coast Line Railroad	GA
101968	King Island, west of, Savannah River, Georgia Current	NOS	ACT7426_1	32.12333	-81.135	:America/New_York	USA	knots	160	337	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	00:48:00	\N	1	00:54:00	\N	0.7	01:21:00	00:33:00	King Island, west of	GA
101969	Port Wentworth, 0.2 mi above, Savannah River, Georgia Current	NOS	ACT7431_1	32.14667	-81.14	:America/New_York	USA	knots	210	22	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	01:19:00	\N	0.7	01:36:00	\N	0.5	02:00:00	00:24:00	Port Wentworth, 0.2 mile above	GA
101970	Wassaw Island, N of E end, Wassaw Sound (depth 10 ft), Savannah River, Georgia Current	NOS	ACT7441_1	31.915	-80.93833	:America/New_York	USA	knots	108	292	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:33:00	\N	1	-00:50:00	\N	0.7	-00:48:00	-00:45:00	Wassaw Island, N of E end, Wassaw Sound	GA
101971	Entrance, off Beach Hammock, Wassaw Sound, Georgia Current	NOS	ACT7446_1	31.94167	-80.93167	:America/New_York	USA	knots	156	352	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:44:00	\N	1.1	-01:00:00	\N	0.9	-00:41:00	-00:54:00	Entrance, off Beach Hammock	GA
101972	Wilmington Island, SSE of, Bull River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7451_1	31.96667	-80.93	:America/New_York	USA	knots	218	35	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-02:00:00	\N	0.7	00:38:00	\N	0.4	-00:35:00	-00:40:00	Wilmington Island, SSE of, Bull River	GA
101973	Lazaretto Creek entrance, N of, Bull River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7456_1	32	-80.92833	:America/New_York	USA	knots	207	15	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-02:04:00	\N	0.7	00:00:00	\N	0.5	-00:37:00	-00:33:00	Lazaretto Creek Entrance, N of, Bull River	GA
101974	Bull River, 2 mi below hwy. bridge, Wassaw Sound, Georgia Current	NOS	ACT7461_1	32.01833	-80.94	:America/New_York	USA	knots	151	327	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:57:00	\N	0.8	-00:18:00	\N	0.6	-00:18:00	-00:25:00	Bull River, 2 miles below hwy. bridge	GA
101975	Entrance, off Wassaw Island, Wassaw Sound, Georgia Current	NOS	ACT7466_1	31.91667	-80.94667	:America/New_York	USA	knots	105	277	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:27:00	\N	0.9	-01:11:00	\N	0.7	-00:46:00	-00:42:00	Entrance, off Wassaw Island	GA
101976	Wilmington River ent. off Cabbage Island, Wassaw Sound, Georgia Current	NOS	ACT7471_1	31.93833	-80.97667	:America/New_York	USA	knots	138	323	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:51:00	\N	0.8	-00:36:00	\N	0.6	-00:44:00	-00:45:00	Wilmington River ent. off Cabbage Island	GA
101977	Joe's Cut, Wilmington River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7476_1	31.94333	-80.985	:America/New_York	USA	knots	123	315	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:44:00	\N	1	-00:48:00	\N	0.6	-00:54:00	-00:34:00	Joe's Cut, Wilmington River	GA
101978	Wilmington R., 0.5 mi S of Turners Creek, Wassaw Sound, Georgia Current	NOS	ACT7481_1	32.005	-81.00333	:America/New_York	USA	knots	154	344	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:51:00	\N	0.7	-00:10:00	\N	0.5	-00:31:00	-00:37:00	Wilmington R., 0.5 mi. S of Turners Creek	GA
101979	Thunderbolt, SE of, Wilmington River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7486_1	32.02333	-81.045	:America/New_York	USA	knots	121	298	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	00:25:00	\N	0.5	-01:04:00	\N	0.4	-00:20:00	00:12:00	Thunderbolt, SE of, Wilmington River	GA
101980	Oatland Island, north tip (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7491_1	32.07333	-81.01	:America/New_York	USA	knots	138	317	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-02:32:00	\N	0.5	-02:14:00	\N	0.3	-03:20:00	-00:43:00	Oatland Island, north tip	GA
101981	Skidaway River, north entrance, Wassaw Sound, Georgia Current	NOS	ACT7496_1	32.00833	-81.01667	:America/New_York	USA	knots	16	204	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-02:11:00	\N	0.7	-00:02:00	\N	0.6	-00:46:00	-00:49:00	Skidaway River, north entrance	GA
101982	Skidaway Island, N End, Wilmington River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7501_1	32.01	-81.00833	:America/New_York	USA	knots	119	307	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:49:00	\N	0.9	00:16:00	\N	0.6	-00:33:00	-00:23:00	Skidaway Island, N End, Wilmington River	GA
101983	Dutch Island, SE of, Skidaway River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7506_1	31.99167	-81.02	:America/New_York	USA	knots	61	245	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-02:02:00	\N	0.6	00:16:00	\N	0.5	-00:40:00	-00:33:00	Dutch Island, SE of, Skidaway River	GA
101984	Isle of Hope City, SE of, Skidaway River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7511_1	31.97667	-81.04667	:America/New_York	USA	knots	72	268	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:40:00	\N	0.3	-00:30:00	\N	0.2	-00:17:00	-00:32:00	Isle of Hope City, SE of, Skidaway River	GA
101985	Isle of Hope City, Skidaway River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7516_1	31.98	-81.055	:America/New_York	USA	knots	28	212	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:25:00	\N	0.3	00:00:00	\N	0.4	-00:34:00	-00:19:00	Isle of Hope City, Skidaway River	GA
101986	Burntpot Island, west of, Skidaway River (depth 6 ft), Wassaw Sound, Georgia Current	NOS	ACT7521_1	31.96833	-81.05333	:America/New_York	USA	knots	18	194	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:03:00	\N	0.5	-00:41:00	\N	0.5	-00:27:00	-00:13:00	Burntpot Island, west of, Skidaway River	GA
101987	Skidaway Narrows, Wassaw Sound, Georgia Current	NOS	ACT7526_1	31.95333	-81.065	:America/New_York	USA	knots	42	218	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:24:00	\N	0.5	-00:24:00	\N	0.5	00:03:00	00:26:00	Skidaway Narrows	GA
101988	Long Island, NNE of, Skidaway River (depth 6 ft), Wassaw Sound, Georgia Current	NOS	ACT7531_1	31.95667	-81.06	:America/New_York	USA	knots	47	226	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	00:17:00	\N	0.4	-01:09:00	\N	0.4	-00:13:00	01:02:00	Long Island, NNE of, Skidaway River	GA
101989	Long Island, south of, Skidaway River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7536_1	31.94333	-81.07333	:America/New_York	USA	knots	258	75	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-08:05:00	\N	0.3	-04:43:00	\N	0.2	-04:25:00	-06:07:00	Long Island, south of, Skidaway River	GA
101990	Pigeon Island, SSE of, Skidaway River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7541_1	31.93667	-81.07667	:America/New_York	USA	knots	150	331	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-02:16:00	\N	0.5	-02:43:00	\N	0.2	-02:37:00	-00:56:00	Pigeon Island, SSE of, Skidaway River	GA
101991	Burnside Island, SE of, Burnside River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7546_1	31.92167	-81.08	:America/New_York	USA	knots	295	114	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-02:05:00	\N	0.6	00:53:00	\N	0.4	-00:40:00	-00:20:00	Burnside Island, SE of, Burnside River	GA
101992	Little Don Island, east of, Vernon River (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7551_1	31.87	-81.07333	:America/New_York	USA	knots	153	316	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:38:00	\N	0.7	-01:16:00	\N	0.7	-00:17:00	-00:03:00	Little Don Island, east of, Vernon River	GA
101993	Little Ogeechee River entrance (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7556_1	31.88833	-81.09833	:America/New_York	USA	knots	71	259	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:06:00	\N	1	-00:59:00	\N	0.7	-00:15:00	-00:03:00	Little Ogeechee River Entrance	GA
101994	Little Ogeechee River entrance (depth 20 ft), Wassaw Sound, Georgia Current	NOS	ACT7556_2	31.88833	-81.09833	:America/New_York	USA	knots	73	244	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:57:00	\N	0.9	-00:50:00	\N	0.6	-00:30:00	00:05:00	Little Ogeechee River Entrance	GA
101995	Montgomery, Vernon River (depth 6 ft), Wassaw Sound, Georgia Current	NOS	ACT7561_1	31.935	-81.12833	:America/New_York	USA	knots	89	267	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:30:00	\N	0.6	00:00:00	\N	0.3	-00:32:00	-00:24:00	Montgomery, Vernon River	GA
101996	Odingsell River entrance (depth 10 ft), Wassaw Sound, Georgia Current	NOS	ACT7566_1	31.86833	-81	:America/New_York	USA	knots	212	32	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-02:14:00	\N	0.9	00:44:00	\N	0.7	-00:54:00	-00:48:00	Odingsell River Entrance	GA
101997	Odingsell River entrance (depth 20 ft), Wassaw Sound, Georgia Current	NOS	ACT7566_2	31.86833	-81	:America/New_York	USA	knots	210	30	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-02:12:00	\N	0.8	00:42:00	\N	0.6	-01:19:00	-00:42:00	Odingsell River Entrance	GA
101998	Wassaw Island, SSW of (depth 10 ft), Ossabaw Sound, Georgia Current	NOS	ACT7571_1	31.85667	-81.00833	:America/New_York	USA	knots	123	316	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:01:00	\N	1.1	-01:04:00	\N	0.8	-00:26:00	-00:27:00	Wassaw Island, SSW of	GA
101999	Wassaw Island, SSW of (depth 20 ft), Ossabaw Sound, Georgia Current	NOS	ACT7571_2	31.85667	-81.00833	:America/New_York	USA	knots	132	312	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:01:00	\N	0.9	-00:58:00	\N	0.7	-00:46:00	-00:33:00	Wassaw Island, SSW of	GA
102000	Bradley Point, NNE of (depth 10 ft), Ossabaw Sound, Georgia Current	NOS	ACT7576_1	31.83167	-81.03833	:America/New_York	USA	knots	125	302	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:12:00	\N	0.8	-00:58:00	\N	0.6	-00:48:00	-00:48:00	Bradley Point, NNE of	GA
102001	Raccoon Key (depth 10 ft), Ossabaw Sound, Georgia Current	NOS	ACT7581_1	31.86167	-81.055	:America/New_York	USA	knots	117	285	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:35:00	\N	0.9	-01:23:00	\N	0.8	-00:45:00	-00:36:00	Raccoon Key	GA
102002	Little Wassaw Island, SW of (depth 10 ft), Ossabaw Sound, Georgia Current	NOS	ACT7586_1	31.87	-81.05	:America/New_York	USA	knots	116	282	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:51:00	\N	0.7	-00:17:00	\N	0.9	-01:05:00	-00:21:00	Little Wassaw Island, SW of	GA
102003	Vernon R., 1.2 mi S of Possum Point, Ossabaw Sound, Georgia Current	NOS	ACT7591_1	31.89833	-81.09833	:America/New_York	USA	knots	166	324	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:33:00	\N	0.8	00:02:00	\N	0.6	-00:24:00	-00:12:00	Vernon R., 1.2 miles S of Possum Point	GA
102004	Little Ogeechee River entrance, north of (depth 6 ft), Ossabaw Sound, Georgia Current	NOS	ACT7596_1	31.89667	-81.095	:America/New_York	USA	knots	156	324	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-02:03:00	\N	0.8	00:29:00	\N	0.6	-00:41:00	-00:30:00	Little Ogeechee River Entrance, north of	GA
102005	Raccoon Key & Egg Island Shoal, between (depth 10 ft), Ossabaw Sound, Georgia Current	NOS	ACT7601_1	31.84283	-81.0675	:America/New_York	USA	knots	129	254	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:57:00	\N	1	00:17:00	\N	0.8	00:20:00	-00:23:00	Raccoon Key & Egg Island Shoal, between	GA
102006	Florida Passage, N of, Ogeechee River (depth 10 ft), Ossabaw Sound, Georgia Current	NOS	ACT7606_1	31.85667	-81.14333	:America/New_York	USA	knots	127	302	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:05:00	\N	1	00:01:00	\N	0.7	00:10:00	-00:01:00	Florida Passage, N of, Ogeechee River	GA
102007	Florida Passage (south) (depth 6 ft), Ossabaw Sound, Georgia Current	NOS	ACT7611_1	31.82967	-81.15783	:America/New_York	USA	knots	18	187	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:10:00	\N	0.7	-01:13:00	\N	0.5	-01:48:00	-00:23:00	Florida Passage (south)	GA
102008	610 Statute Mile Mark (depth 6 ft), Bear River, St. Catherines Sound, Georgia Current	NOS	ACT7616_1	31.8105	-81.17667	:America/New_York	USA	knots	175	357	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:39:00	\N	0.7	00:48:00	\N	0.5	00:20:00	-00:05:00	610 Statute Mile Mark	GA
102009	North of Big Tom Creek entrance (depth 10 ft), St. Catherines Sound, Georgia Current	NOS	ACT7621_1	31.78333	-81.16033	:America/New_York	USA	knots	179	11	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:25:00	\N	0.7	-00:13:00	\N	0.6	-00:24:00	-00:19:00	North of Big Tom Creek Entrance	GA
102010	South of Kilkenny Creek entrance, Bear River, St. Catherines Sound, Georgia Current	NOS	ACT7626_1	31.75833	-81.17333	:America/New_York	USA	knots	190	348	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:12:00	\N	1	01:25:00	\N	0.6	00:26:00	-00:02:00	South of Kilkenny Creek Entrance	GA
102011	Northwest of Newell Creek entrance (depth 10 ft), St. Catherines Sound, Georgia Current	NOS	ACT7631_1	31.74883	-81.1655	:America/New_York	USA	knots	149	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:12:00	\N	0.9	00:12:00	\N	0.6	-00:11:00	-00:16:00	Northwest of Newell Creek Entrance	GA
102012	Medway River at Marsh Island (depth 10 ft), St. Catherines Sound, Georgia Current	NOS	ACT7636_1	31.74333	-81.22	:America/New_York	USA	knots	117	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:56:00	\N	0.8	-00:18:00	\N	0.3	00:20:00	-00:15:00	Medway River at Marsh Island	GA
102013	St. Catherines Sound entrance (depth 10 ft), Georgia Current	NOS	ACT7641_1	31.715	-81.1405	:America/New_York	USA	knots	126	291	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:27:00	\N	0.8	-00:31:00	\N	0.9	-00:39:00	00:13:00	St. Catherines Sound Entrance	GA
102014	Medway River, northwest of Cedar Point (depth 10 ft), Georgia Current	NOS	ACT7646_1	31.7145	-81.19083	:America/New_York	USA	knots	146	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:21:00	\N	0.8	-00:43:00	\N	0.7	-00:40:00	-00:23:00	Medway River, northwest of Cedar Point	GA
102015	N. Newport River, NE of Vandyke Creek (depth 10 ft), Georgia Current	NOS	ACT7651_1	31.69117	-81.187	:America/New_York	USA	knots	45	233	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:21:00	\N	0.8	00:12:00	\N	0.7	-00:27:00	00:00:00	N. Newport River, NE of Vandyke Creek	GA
102016	N. Newport River, above Walburg Creek (depth 6 ft), St. Catherines Sound, Georgia Current	NOS	ACT7656_1	31.67383	-81.19533	:America/New_York	USA	knots	11	195	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:40:00	\N	0.8	00:30:00	\N	0.6	-00:34:00	-00:39:00	N. Newport River, above Walburg Creek	GA
102017	N. Newport River, NW of Johnson Creek (depth 10 ft), Georgia Current	NOS	ACT7661_1	31.663	-81.2105	:America/New_York	USA	knots	138	312	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:27:00	\N	0.9	-01:01:00	\N	0.5	00:20:00	-00:37:00	N. Newport River, NW of Johnson Creek	GA
102018	N. Newport River, ESE of S. Newport Cut (depth 6 ft), Georgia Current	NOS	ACT7666_1	31.66533	-81.2645	:America/New_York	USA	knots	147	319	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	00:15:00	\N	0.7	-00:13:00	\N	0.5	00:32:00	00:27:00	N. Newport River, ESE of S. Newport Cut	GA
102019	S. Newport River, below S. Newport Cut (depth 10 ft), Georgia Current	NOS	ACT7671_1	31.65033	-81.302	:America/New_York	USA	knots	134	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	02:15:00	\N	0.5	01:30:00	\N	0.5	01:20:00	02:41:00	S. Newport River, below S. Newport Cut	GA
102020	S. Newport River, above Swain River ent. (depth 10 ft), Georgia Current	NOS	ACT7676_1	31.6245	-81.21667	:America/New_York	USA	knots	156	335	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:43:00	\N	0.6	-01:13:00	\N	0.6	-00:22:00	00:00:00	S. Newport River, above Swain River Ent	GA
102021	Entrance (depth 19 ft), Sapelo Sound, Georgia Current	NOS	ACT7681_1	31.54	-81.18	:America/New_York	USA	knots	118	290	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:59:00	\N	1.1	00:28:00	\N	0.9	-00:30:00	-00:06:00	Entrance	GA
102022	Entrance (depth 29 ft), Sapelo Sound, Georgia Current	NOS	ACT7681_2	31.54	-81.18	:America/New_York	USA	knots	116	289	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:02:00	\N	0.9	-00:36:00	\N	0.7	-00:48:00	-00:17:00	Entrance	GA
102023	Johnson Creek, midway between ends, Sapelo Sound, Georgia Current	NOS	ACT7686_1	31.62667	-81.18833	:America/New_York	USA	knots	195	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:59:00	\N	0.4	-01:08:00	\N	0.4	-01:50:00	-00:35:00	Johnson Creek, midway between ends	GA
102024	Cedar Hammock, south of (depth 12 ft), Sapelo Sound, Georgia Current	NOS	ACT7691_1	31.545	-81.24667	:America/New_York	USA	knots	96	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:38:00	\N	0.6	-01:00:00	\N	0.7	-00:26:00	-00:12:00	Cedar Hammock, south of	GA
102025	Sapelo River entrance (depth 11 ft), Sapelo Sound, Georgia Current	NOS	ACT7696_1	31.535	-81.27167	:America/New_York	USA	knots	58	234	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:43:00	\N	0.6	-01:05:00	\N	0.6	-00:23:00	-00:13:00	Sapelo River Entrance	GA
102026	Sutherland Bluff, Sapelo River, Sapelo Sound, Georgia Current	NOS	ACT7701_1	31.54833	-81.33333	:America/New_York	USA	knots	104	281	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:16:00	\N	0.6	00:10:00	\N	0.5	-00:30:00	-00:12:00	Sutherland Bluff, Sapelo River	GA
102027	Front River (depth 13 ft), Sapelo Sound, Georgia Current	NOS	ACT7706_1	31.51333	-81.29833	:America/New_York	USA	knots	56	227	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-02:05:00	\N	0.5	01:16:00	\N	0.4	-00:33:00	-00:25:00	Front River	GA
102028	New Teakettle Cr., 0.8 mi N of, Mud River, Sapelo Sound, Georgia Current	NOS	ACT7711_1	31.49667	-81.29	:America/New_York	USA	knots	53	236	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-02:11:00	\N	0.5	-00:29:00	\N	0.4	-00:54:00	-01:08:00	New Teakettle Cr., 0.8 mi. N of	GA
102029	Crescent River (depth 11 ft), Sapelo Sound, Georgia Current	NOS	ACT7716_1	31.48667	-81.30667	:America/New_York	USA	knots	133	293	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:21:00	\N	0.5	01:07:00	\N	0.2	-01:27:00	-00:34:00	Crescent River	GA
102030	Old Teakettle Creek (north) (depth 13 ft), Sapelo Sound, Georgia Current	NOS	ACT7721_1	31.47833	-81.32833	:America/New_York	USA	knots	256	78	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:37:00	\N	0.6	00:01:00	\N	0.5	-00:35:00	00:14:00	Old Teakettle Creek (north)	GA
102031	Bar, Doboy Sound, Georgia Current	NOS	ACT7726_1	31.345	-81.235	:America/New_York	USA	knots	114	312	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:53:00	\N	0.7	-00:29:00	\N	0.7	-00:29:00	-00:09:00	Bar	GA
102032	Entrance (depth 14 ft), Doboy Sound, Georgia Current	NOS	ACT7731_1	31.34167	-81.26333	:America/New_York	USA	knots	106	289	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:49:00	\N	0.9	-00:10:00	\N	0.8	-00:32:00	-00:24:00	Entrance	GA
102033	Entrance (depth 22 ft), Doboy Sound, Georgia Current	NOS	ACT7731_2	31.34167	-81.26333	:America/New_York	USA	knots	99	276	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:26:00	\N	0.8	-00:05:00	\N	0.8	-00:56:00	-00:20:00	Entrance	GA
102034	Old Teakettle Creek entrance, south of (depth 15 ft), Doboy Sound, Georgia Current	NOS	ACT7736_1	31.42	-81.315	:America/New_York	USA	knots	159	335	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:27:00	\N	0.5	-00:59:00	\N	0.5	-00:45:00	00:00:00	Old Teakettle Creek Entrance, south of	GA
102035	Old Teakettle Creek (south) (depth 13 ft), Doboy Sound, Georgia Current	NOS	ACT7741_1	31.43667	-81.30833	:America/New_York	USA	knots	207	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-02:44:00	\N	0.4	-01:45:00	\N	0.5	-03:12:00	-02:16:00	Old Teakettle Creek (south)	GA
102036	Folly River and Cardigan River, between (depth 10 ft), Doboy Sound, Georgia Current	NOS	ACT7746_1	31.44167	-81.33667	:America/New_York	USA	knots	150	327	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:00:00	\N	0.3	-00:56:00	\N	0.3	-00:55:00	-00:16:00	Folly River and Cardigan River, between	GA
102037	South River (depth 13 ft), Doboy Sound, Georgia Current	NOS	ACT7751_1	31.36667	-81.31167	:America/New_York	USA	knots	95	282	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:24:00	\N	0.7	-00:25:00	\N	0.6	-00:22:00	-00:32:00	South River	GA
102038	South River (depth 21 ft), Doboy Sound, Georgia Current	NOS	ACT7751_2	31.36667	-81.31167	:America/New_York	USA	knots	95	286	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:24:00	\N	0.4	-00:33:00	\N	0.5	-00:41:00	-00:29:00	South River	GA
102039	North River at Darien River (depth 9 ft), Doboy Sound, Georgia Current	NOS	ACT7756_1	31.38333	-81.335	:America/New_York	USA	knots	29	247	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	00:22:00	\N	0.2	-00:33:00	\N	0.2	-00:10:00	00:08:00	North River at Darien River	GA
102040	Doboy Island (North River) (depth 12 ft), Doboy Sound, Georgia Current	NOS	ACT7761_1	31.40333	-81.32833	:America/New_York	USA	knots	37	224	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	00:13:00	\N	0.5	-00:06:00	\N	0.6	-00:14:00	00:47:00	Doboy Island (North River)	GA
102041	Doboy Island (North River) (depth 20 ft), Doboy Sound, Georgia Current	NOS	ACT7761_2	31.40333	-81.32833	:America/New_York	USA	knots	43	225	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	00:22:00	\N	0.3	00:36:00	\N	0.5	-00:20:00	00:46:00	Doboy Island (North River)	GA
102042	Buzzard Roost Creek (depth 13 ft), Doboy Sound, Georgia Current	NOS	ACT7766_1	31.415	-81.375	:America/New_York	USA	knots	2	177	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	00:28:00	\N	0.2	00:12:00	\N	0.3	00:22:00	00:56:00	Buzzard Roost Creek	GA
102043	Little Egg Island, northwest of (depth 12 ft), Altamaha Sound, Georgia Current	NOS	ACT7771_1	31.31833	-81.305	:America/New_York	USA	knots	110	296	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:10:00	\N	0.6	-00:53:00	\N	0.6	-00:33:00	-00:25:00	Little Egg Island, northwest of	GA
102044	Little Mud River Range (depth 9 ft), Altamaha Sound, Georgia Current	NOS	ACT7776_1	31.32667	-81.31833	:America/New_York	USA	knots	116	304	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:06:00	\N	0.5	-01:05:00	\N	0.3	-00:38:00	-00:23:00	Little Mud River Range	GA
102045	Little St. Simon Island (north) (depth 11 ft), Altamaha Sound, Georgia Current	NOS	ACT7781_1	31.31167	-81.35333	:America/New_York	USA	knots	89	267	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:29:00	\N	0.8	00:06:00	\N	0.6	00:10:00	-00:15:00	Little St. Simon Island (north)	GA
102046	Onemile Cut, 1 mi southeast of, Altamaha Sound, Georgia Current	NOS	ACT7786_1	31.31333	-81.35167	:America/New_York	USA	knots	92	272	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:32:00	\N	0.9	00:03:00	\N	0.5	00:46:00	-01:09:00	Onemile Cut, 1 mile southeast of	GA
102047	Broughton Island (south) (depth 9 ft), Buttermilk Sound, Altamaha Sound, Georgia Current	NOS	ACT7791_1	31.31	-81.41333	:America/New_York	USA	knots	30	222	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:51:00	\N	0.4	00:12:00	\N	0.4	-02:06:00	-00:01:00	Broughton Island (south)	GA
102048	Bar Channel (depth 12 ft), St. Simons Sound, Georgia Current	NOS	ACT7796_1	31.105	-81.33833	:America/New_York	USA	knots	119	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:02:00	\N	0.8	-00:44:00	\N	0.4	-00:13:00	00:09:00	Bar Channel	GA
102049	Entrance, north of channel (depth 13 ft), St. Simons Sound, Georgia Current	NOS	ACT7801_1	31.1335	-81.404	:America/New_York	USA	knots	107	290	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:11:00	\N	0.6	00:18:00	\N	0.9	-00:32:00	00:07:00	Entrance, north of channel	GA
102050	Entrance, south of channel (depth 11 ft), St. Simons Sound, Georgia Current	NOS	ACT7806_1	31.12667	-81.40333	:America/New_York	USA	knots	80	262	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:59:00	\N	1.1	-00:32:00	\N	0.8	-00:27:00	-00:21:00	Entrance, south of channel	GA
102051	Entrance, south of channel (depth 29 ft), St. Simons Sound, Georgia Current	NOS	ACT7806_2	31.12667	-81.40333	:America/New_York	USA	knots	92	257	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:21:00	\N	0.8	-00:03:00	\N	0.6	-00:18:00	00:06:00	Entrance, south of channel	GA
102052	Back River entrance (depth 10 ft), St. Simons Sound, Georgia Current	NOS	ACT7811_1	31.14833	-81.44167	:America/New_York	USA	knots	111	288	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:16:00	\N	0.5	01:34:00	\N	0.5	-00:37:00	00:06:00	Back River entrance	GA
102053	Back River entrance (depth 18 ft), St. Simons Sound, Georgia Current	NOS	ACT7811_2	31.14833	-81.44167	:America/New_York	USA	knots	109	280	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:15:00	\N	0.4	01:36:00	\N	0.5	-01:29:00	00:08:00	Back River entrance	GA
102054	Mackay R., 0.5 mi N of Troup Creek entrance, St. Simons Sound, Georgia Current	NOS	ACT7816_1	31.225	-81.43333	:America/New_York	USA	knots	166	348	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	00:24:00	\N	0.7	00:09:00	\N	0.5	00:56:00	00:35:00	Mackay R., 0.5 mi. N of Troup Creek entrance	GA
102055	Brunswick River, off Quarantine Dock, St. Simons Sound, Georgia Current	NOS	ACT7821_1	31.11167	-81.47333	:America/New_York	USA	knots	125	300	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:39:00	\N	1	-00:03:00	\N	0.7	00:10:00	00:11:00	Brunswick River, off Quarantine Dock	GA
102056	Brunswick River Bridge, southeast of (depth 13 ft), St. Simons Sound, Georgia Current	NOS	ACT7826_1	31.115	-81.47667	:America/New_York	USA	knots	132	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:09:00	\N	0.7	00:13:00	\N	0.5	-00:15:00	00:26:00	Brunswick River Bridge, southeast of	GA
102057	Brunswick River Bridge, southeast of (depth 21 ft), St. Simons Sound, Georgia Current	NOS	ACT7826_2	31.115	-81.47667	:America/New_York	USA	knots	129	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:02:00	\N	0.7	00:42:00	\N	0.5	00:19:00	00:56:00	Brunswick River Bridge, southeast of	GA
102058	Brunswick, off Prince Street Dock, St. Simons Sound, Georgia Current	NOS	ACT7831_1	31.13833	-81.49667	:America/New_York	USA	knots	166	342	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:08:00	\N	0.6	00:55:00	\N	0.5	-00:01:00	00:06:00	Brunswick, off Prince Street Dock	GA
102059	Turtle River, off Allied Chemical Corp, St. Simons Sound, Georgia Current	NOS	ACT7836_1	31.17667	-81.525	:America/New_York	USA	knots	165	348	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:33:00	\N	0.8	00:18:00	\N	0.7	00:16:00	00:36:00	Turtle River, off Allied Chemical Corp	GA
102060	Turtle River, off Andrews Island (depth 20 ft), St. Simons Sound, Georgia Current	NOS	ACT7841_1	31.14333	-81.52667	:America/New_York	USA	knots	153	339	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:23:00	\N	0.7	00:40:00	\N	0.5	-00:21:00	00:31:00	Turtle River, off Andrews Island	GA
102061	Entrance, St. Andrews Sound, Georgia Current	NOS	ACT7846_1	30.98667	-81.405	:America/New_York	USA	knots	103	268	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:00:00	\N	1.1	00:13:00	\N	1.1	-00:18:00	00:02:00	Entrance	GA
102062	Jekyll Creek, south entrance, St. Andrews Sound, Georgia Current	NOS	ACT7851_1	31.035	-81.43333	:America/New_York	USA	knots	232	60	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:20:00	\N	0.7	-00:21:00	\N	0.5	-00:21:00	-00:25:00	Jekyll Creek, south entrance	GA
102063	Cumberland River, north entrance, St. Andrews Sound, Georgia Current	NOS	ACT7856_1	30.95833	-81.43167	:America/New_York	USA	knots	18	191	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-01:18:00	\N	0.7	00:32:00	\N	0.7	-00:29:00	-00:17:00	Cumberland River, north entrance	GA
102064	Cabin Bluff, Cumberland River, St. Andrews Sound, Georgia Current	NOS	ACT7861_1	30.88167	-81.51333	:America/New_York	USA	knots	355	171	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97992	-00:45:00	\N	0.6	01:29:00	\N	0.7	00:21:00	00:51:00	Cabin Bluff, Cumberland River	GA
102065	Fort Clinch, 1.1 nmi NW of (depth 14 ft), Cumberland Sound, Florida Current	NOS	ACT7886_1	30.709	-81.47267	:America/New_York	USA	knots	133	309	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98511	00:18:00	\N	0.7	-00:01:00	\N	0.6	00:01:00	00:10:00	Fort Clinch, 1.1 n.mi. NW of	FL
102066	Fort Clinch, 1.1 nmi NW of (depth 29 ft), Cumberland Sound, Florida Current	NOS	ACT7886_2	30.709	-81.47267	:America/New_York	USA	knots	122	315	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98511	00:08:00	\N	0.5	00:02:00	\N	0.5	-00:13:00	00:02:00	Fort Clinch, 1.1 n.mi. NW of	FL
102067	Drum Point Island, Range D Channel (depth 12 ft), Cumberland Sound, Georgia Current	NOS	ACT7896_1	30.759	-81.48533	:America/New_York	USA	knots	170	350	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98511	-00:03:00	\N	0.6	-00:11:00	\N	0.5	-00:05:00	00:02:00	Drum Point Island, Range D Channel	GA
102068	Drum Point Island, Range D Channel (depth 22 ft), Cumberland Sound, Georgia Current	NOS	ACT7896_2	30.759	-81.48533	:America/New_York	USA	knots	170	351	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98511	-00:09:00	\N	0.5	-00:34:00	\N	0.4	-00:10:00	-00:08:00	Drum Point Island, Range D Channel	GA
102069	Stafford Island, west of, Cumberland Sound, Georgia Current	NOS	ACT7906_1	30.81	-81.49167	:America/New_York	USA	knots	180	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98511	-01:01:00	\N	0.5	-00:28:00	\N	0.6	-00:25:00	-00:27:00	Stafford Island, west of	GA
102070	Kingsley Creek, highway bridge, Cumberland Sound, Florida Current	NOS	ACT7921_1	30.62833	-81.485	:America/New_York	USA	knots	330	150	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98511	01:25:00	\N	0.6	01:17:00	\N	0.5	01:45:00	00:53:00	Kingsley Creek, highway bridge	FL
102071	Midsound, 1 mi N of Sawpit Creek entrance, Nassau Sound, Florida Current	NOS	ACT7926_1	30.52333	-81.45167	:America/New_York	USA	knots	135	312	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98922	-00:21:00	\N	0.7	-00:12:00	\N	0.8	00:02:00	-00:15:00	Midsound, 1 mi. N of Sawpit Creek entrance	FL
102072	South Amelia River, off Walker Creek, Nassau Sound, Florida Current	NOS	ACT7931_1	30.53667	-81.465	:America/New_York	USA	knots	162	341	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98922	-01:57:00	\N	0.6	-00:09:00	\N	0.6	-01:08:00	-00:40:00	South Amelia River, off Walker Creek	FL
102073	Nassau River, SW of Mesa Marsh, Nassau Sound, Florida Current	NOS	ACT7936_1	30.53333	-81.48	:America/New_York	USA	knots	129	294	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98922	-00:13:00	\N	0.7	-00:09:00	\N	0.7	00:09:00	-00:01:00	Nassau River, SW of Mesa Marsh	FL
102074	Ft. George River, Nassau Sound, Florida Current	NOS	ACT7941_1	30.45667	-81.45167	:America/New_York	USA	knots	162	334	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98922	-02:20:00	\N	0.4	-01:08:00	\N	0.1	-01:35:00	-01:26:00	Ft. George River	FL
102075	Mayport (depth 7 ft), St. Johns River, Florida Current	NOS	ACT7971_1	30.39333	-81.43333	:America/New_York	USA	knots	26	211	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	-00:04:00	\N	1.6	01:02:00	\N	1.1	00:06:00	00:15:00	Mayport	FL
102076	Mayport (depth 17 ft), St. Johns River, Florida Current	NOS	ACT7971_2	30.39333	-81.43333	:America/New_York	USA	knots	26	211	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	00:05:00	\N	1.3	00:38:00	\N	1.1	-00:03:00	00:12:00	Mayport	FL
102077	Mayport (depth 27 ft), St. Johns River, Florida Current	NOS	ACT7971_3	30.39333	-81.43333	:America/New_York	USA	knots	26	211	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	00:14:00	\N	0.9	00:26:00	\N	0.9	-00:27:00	00:15:00	Mayport	FL
102078	Pablo Creek bascule bridge (depth 3 ft), St. Johns River, Florida Current	NOS	ACT7986_1	30.32333	-81.43833	:America/New_York	USA	knots	0	180	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	00:59:00	\N	2.5	-00:18:00	\N	1.7	-00:14:00	00:49:00	Pablo Creek bascule bridge	FL
102079	Sisters Creek entrance (bridge) (depth 4 ft), St. Johns River, Florida Current	NOS	ACT7991_1	30.39	-81.46167	:America/New_York	USA	knots	180	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	-02:34:00	\N	0.8	-03:14:00	\N	0.8	-03:30:00	-02:13:00	Sisters Creek entrance (bridge)	FL
102080	Sisters Creek entrance (bridge) (depth 10 ft), St. Johns River, Florida Current	NOS	ACT7991_2	30.39	-81.46167	:America/New_York	USA	knots	180	0	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	-02:34:00	\N	0.6	-03:04:00	\N	0.6	-03:36:00	-02:07:00	Sisters Creek entrance (bridge)	FL
102081	Drummond Point, channel south of (depth 7 ft), St. Johns River, Florida Current	NOS	ACT8016_1	30.40917	-81.60283	:America/New_York	USA	knots	60	241	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	03:00:00	\N	0.8	02:32:00	\N	0.7	01:51:00	02:44:00	Drummond Point, channel south of	FL
102082	Drummond Point, channel south of (depth 17 ft), St. Johns River, Florida Current	NOS	ACT8016_2	30.40917	-81.60283	:America/New_York	USA	knots	61	222	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	03:01:00	\N	0.7	02:35:00	\N	0.7	01:34:00	02:51:00	Drummond Point, channel south of	FL
102083	Drummond Point, channel south of (depth 27 ft), St. Johns River, Florida Current	NOS	ACT8016_3	30.40917	-81.60283	:America/New_York	USA	knots	57	243	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	02:51:00	\N	0.5	02:20:00	\N	0.6	01:21:00	02:46:00	Drummond Point, channel south of	FL
102084	Terminal Channel (north end) (depth 7 ft), St. Johns River, Florida Current	NOS	ACT8031_1	30.357	-81.618	:America/New_York	USA	knots	1	225	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	03:38:00	\N	0.6	03:16:00	\N	0.5	02:39:00	03:02:00	Terminal Channel (north end)	FL
102085	Terminal Channel (north end) (depth 17 ft), St. Johns River, Florida Current	NOS	ACT8031_2	30.357	-81.618	:America/New_York	USA	knots	1	183	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	03:33:00	\N	0.5	03:06:00	\N	0.6	02:16:00	03:20:00	Terminal Channel (north end)	FL
102086	Terminal Channel (north end) (depth 27 ft), St. Johns River, Florida Current	NOS	ACT8031_3	30.357	-81.618	:America/New_York	USA	knots	1	185	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	03:23:00	\N	0.3	03:28:00	\N	0.5	01:51:00	03:16:00	Terminal Channel (north end)	FL
102087	Commodore Point, terminal channel (depth 7 ft), St. Johns River, Florida Current	NOS	ACT8036_1	30.3175	-81.62633	:America/New_York	USA	knots	72	197	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	03:37:00	\N	0.5	03:28:00	\N	0.5	02:39:00	03:10:00	Commodore Point, terminal channel	FL
102088	Commodore Point, terminal channel (depth 17 ft), St. Johns River, Florida Current	NOS	ACT8036_2	30.3175	-81.62633	:America/New_York	USA	knots	51	221	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	03:25:00	\N	0.4	03:13:00	\N	0.5	02:12:00	03:23:00	Commodore Point, terminal channel	FL
102089	Commodore Point, terminal channel (depth 27 ft), St. Johns River, Florida Current	NOS	ACT8036_3	30.3175	-81.62633	:America/New_York	USA	knots	35	221	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	03:08:00	\N	0.4	02:30:00	\N	0.6	01:43:00	03:38:00	Commodore Point, terminal channel	FL
102090	Jacksonville, off Washington St, St. Johns River, Florida Current	NOS	ACT8041_1	30.32167	-81.65333	:America/New_York	USA	knots	118	281	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	03:23:00	\N	0.9	03:10:00	\N	0.9	02:59:00	02:54:00	Jacksonville, off Washington St	FL
102091	Winter Point, St. Johns River, Florida Current	NOS	ACT8051_1	30.30833	-81.675	:America/New_York	USA	knots	15	200	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	03:59:00	\N	0.5	03:22:00	\N	0.6	02:59:00	04:04:00	Winter Point	FL
102092	Mandarin Point (depth 6 ft), St. Johns River, Florida Current	NOS	ACT8056_1	30.155	-81.685	:America/New_York	USA	knots	13	179	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	03:38:00	\N	0.4	03:39:00	\N	0.3	03:07:00	03:24:00	Mandarin Point	FL
102093	Mandarin Point (depth 15 ft), St. Johns River, Florida Current	NOS	ACT8056_2	30.155	-81.685	:America/New_York	USA	knots	13	179	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	03:38:00	\N	0.3	03:33:00	\N	0.3	03:13:00	03:24:00	Mandarin Point	FL
102094	Mandarin Point (depth 24 ft), St. Johns River, Florida Current	NOS	ACT8056_3	30.155	-81.685	:America/New_York	USA	knots	13	179	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	03:32:00	\N	0.3	03:33:00	\N	0.3	02:48:00	03:24:00	Mandarin Point	FL
102095	Red Bay Point, draw bridge (depth 4 ft), St. Johns River, Florida Current	NOS	ACT8061_1	29.985	-81.63	:America/New_York	USA	knots	300	115	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	04:02:00	\N	0.3	03:57:00	\N	0.5	02:48:00	05:24:00	Red Bay Point, draw bridge	FL
102096	Red Bay Point, draw bridge (depth 6 ft), St. Johns River, Florida Current	NOS	ACT8061_2	29.985	-81.63	:America/New_York	USA	knots	300	115	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	04:08:00	\N	0.3	03:57:00	\N	0.5	02:42:00	05:18:00	Red Bay Point, draw bridge	FL
102097	Red Bay Point, draw bridge (depth 14 ft), St. Johns River, Florida Current	NOS	ACT8061_3	29.985	-81.63	:America/New_York	USA	knots	300	115	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100489	04:08:00	\N	0.2	03:57:00	\N	0.4	02:48:00	05:30:00	Red Bay Point, draw bridge	FL
102098	Fort Lauderdale, New River, Port Everglades, Florida Current	NOS	ACT8126_1	26.11217	-80.11967	:America/New_York	USA	knots	130	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98922	00:52:00	\N	0.8	-00:01:00	\N	1.4	-00:14:00	00:28:00	Fort Lauderdale, New River	FL
102099	Bakers Haulover Cut, Miami Harbor, Florida Current	NOS	ACT8141_1	25.9	-80.12333	:America/New_York	USA	knots	90	270	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98922	-00:08:00	\N	1	00:19:00	\N	1.3	00:00:00	00:13:00	Bakers Haulover Cut	FL
102100	Caesar Creek, Biscayne Bay, Florida Current	NOS	ACT8216_1	25.38667	-80.22667	:America/New_York	USA	knots	123	316	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98525	-00:23:00	\N	1	00:03:00	\N	0.9	00:09:00	-00:21:00	Caesar Creek, Biscayne Bay	FL
102101	Long Key, drawbridge east of, Florida Current	NOS	ACT8221_1	24.84	-80.77	:America/New_York	USA	knots	202	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98525	01:15:00	\N	0.7	01:38:00	\N	0.8	01:00:00	02:14:00	Long Key, drawbridge east of	FL
102102	Long Key Viaduct, Florida Current	NOS	ACT8226_1	24.80167	-80.865	:America/New_York	USA	knots	170	349	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98525	01:39:00	\N	0.7	01:39:00	\N	0.7	01:36:00	01:55:00	Long Key Viaduct	FL
102103	No Name Key, northeast of, Florida Current	NOS	ACT8241_1	24.705	-81.31333	:America/New_York	USA	knots	142	312	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98525	00:35:00	\N	0.5	01:35:00	\N	0.5	00:57:00	01:13:00	No Name Key, northeast of	FL
102104	Ft. Taylor, 0.6 mi N of, Key West, Florida Current	NOS	ACT8261_1	24.55833	-81.81	:America/New_York	USA	knots	202	42	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98525	-00:05:00	\N	0.7	00:24:00	\N	0.4	00:22:00	-00:18:00	Ft. Taylor, 0.6 mile N of	FL
102105	Isaac Shoal, Florida Current	NOS	ACT8291_1	24.55833	-82.53667	:America/New_York	USA	knots	181	2	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98525	01:37:00	\N	0.5	01:05:00	\N	0.8	01:02:00	01:45:00	Isaac Shoal	FL
102106	Southeast Channel, Florida Current	NOS	ACT8296_1	24.627	-82.85117	:America/New_York	USA	knots	172	4	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98525	00:18:00	\N	0.4	00:05:00	\N	0.5	-00:25:00	00:30:00	Southeast Channel	FL
102107	Southwest Channel, Florida Current	NOS	ACT8301_1	24.61533	-82.91167	:America/New_York	USA	knots	209	1	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98525	01:46:00	\N	0.3	01:10:00	\N	0.3	00:47:00	01:18:00	Southwest Channel	FL
102108	Point Ybel, 0.4 mi northwest of, Florida Current	NOS	ACT8306_1	26.45667	-82.01867	:America/New_York	USA	knots	80	255	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	00:35:00	\N	0.7	-00:52:00	\N	0.8	-00:25:00	00:17:00	Point Ybel, 0.4 mile northwest of	FL
102109	Captiva Pass, Florida Current	NOS	ACT8311_1	26.60933	-82.22233	:America/New_York	USA	knots	251	67	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:23:00	\N	0.9	-01:29:00	\N	1.4	-00:53:00	-01:14:00	Captiva Pass	FL
102110	Boca Grande Pass, Charlotte Harbor, Florida Current	NOS	ACT8316_1	26.71433	-82.25667	:America/New_York	USA	knots	251	57	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	00:05:00	\N	1.3	-00:37:00	\N	1.7	-00:15:00	-00:15:00	Boca Grande Pass, Charlotte Harbor	FL
102111	Cape Haze, 2.3 mi S of, Charlotte Hbr, Florida Current	NOS	ACT8331_1	26.745	-82.15167	:America/New_York	USA	knots	268	80	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	01:18:00	\N	0.4	00:41:00	\N	0.4	00:30:00	-00:20:00	Cape Haze, 2.3 mi. S of, Charlotte Hbr	FL
102112	Gasparilla Pass, Florida Current	NOS	ACT8346_1	26.81233	-82.281	:America/New_York	USA	knots	236	66	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:41:00	\N	0.8	-01:13:00	\N	0.8	-01:15:00	-00:35:00	Gasparilla Pass	FL
102113	Venice Inlet, Florida Current	NOS	ACT8351_1	27.11333	-82.46667	:America/New_York	USA	knots	262	87	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-01:59:00	\N	0.7	-02:08:00	\N	0.8	-02:05:00	-01:57:00	Venice Inlet	FL
102114	Blackburn Bay, south end, bridge, Florida Current	NOS	ACT8356_1	27.12333	-82.47	:America/New_York	USA	knots	180	357	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:10:00	\N	0.5	-01:20:00	\N	0.7	-00:55:00	-01:28:00	Blackburn Bay, south end, bridge	FL
102115	Little Sarasota Bay, south end, bridge, Florida Current	NOS	ACT8361_1	27.18	-82.495	:America/New_York	USA	knots	357	167	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:06:00	\N	0.5	-00:56:00	\N	1.1	-01:19:00	-00:57:00	Little Sarasota Bay, south end, bridge	FL
102116	Big Sarasota Pass, Sarasota Bay, Florida Current	NOS	ACT8371_1	27.3	-82.56333	:America/New_York	USA	knots	183	6	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-02:03:00	\N	0.8	-01:49:00	\N	1.2	-01:54:00	-01:34:00	Big Sarasota Pass	FL
102117	Sarasota Bay, south end, bridge, Florida Current	NOS	ACT8376_1	27.30167	-82.54667	:America/New_York	USA	knots	13	196	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:32:00	\N	0.2	-01:39:00	\N	0.2	-01:25:00	-01:13:00	Sarasota Bay, south end, bridge	FL
102118	New Pass, Sarasota Bay, Florida Current	NOS	ACT8381_1	27.33167	-82.58167	:America/New_York	USA	knots	231	46	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-01:25:00	\N	0.8	-02:48:00	\N	1.2	-02:06:00	-01:18:00	New Pass	FL
102119	Golden Gate Point, off, Sarasota Bay, Florida Current	NOS	ACT8386_1	27.32833	-82.55667	:America/New_York	USA	knots	159	344	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-01:19:00	\N	0.2	-01:57:00	\N	0.3	-01:38:00	-01:25:00	Golden Gate Point, off	FL
102120	Longboat Pass, Sarasota Bay, Florida Current	NOS	ACT8391_1	27.44167	-82.69	:America/New_York	USA	knots	267	88	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-01:56:00	\N	1.2	-02:42:00	\N	1.4	-02:32:00	-01:51:00	Longboat Pass	FL
102121	Cortez, north of bridge, Sarasota Bay, Florida Current	NOS	ACT8396_1	27.47	-82.69333	:America/New_York	USA	knots	162	346	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-01:11:00	\N	0.1	-01:10:00	\N	0.5	-01:47:00	-00:25:00	Cortez, north of bridge	FL
102122	Egmont Channel, Marker 10 (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8401_1	27.6005	-82.86767	:America/New_York	USA	knots	259	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-01:31:00	\N	0.2	-03:17:00	\N	0.2	-02:04:00	-02:22:00	Egmont Channel, marker '10'	FL
102123	Egmont Channel (3 mi W of Egmont Key Lt.), Tampa Bay, Florida Current	NOS	ACT8406_1	27.60833	-82.81833	:America/New_York	USA	knots	260	65	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:29:00	\N	0.5	-00:28:00	\N	0.4	-00:30:00	-00:30:00	Egmont Channel (3 mi. W of Egmont Key Lt.)	FL
102124	Southwest Channel (S of Egmont Key) (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8416_1	27.56167	-82.76733	:America/New_York	USA	knots	269	87	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:30:00	\N	0.9	-00:53:00	\N	0.6	-00:46:00	-00:40:00	Southwest Channel (S of Egmont Key)	FL
102125	Mullet Key Channel entrance, Tampa Bay, Florida Current	NOS	ACT8421_1	27.6045	-82.72383	:America/New_York	USA	knots	255	55	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	00:08:00	\N	0.8	-00:01:00	\N	0.8	-00:03:00	-00:23:00	Mullet Key Channel entrance	FL
102126	Passage Key Inlet (off Bean Pt.) (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8426_1	27.53933	-82.74767	:America/New_York	USA	knots	247	81	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-01:08:00	\N	0.7	-01:50:00	\N	0.6	-01:29:00	-01:13:00	Passage Key Inlet (off Bean Pt.)	FL
102127	Rattlesnake Key, 3.1 mi west of, Tampa Bay, Florida Current	NOS	ACT8431_1	27.55333	-82.68833	:America/New_York	USA	knots	250	65	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	00:04:00	\N	0.4	-00:05:00	\N	0.3	00:20:00	-00:51:00	Rattlesnake Key, 3.1 miles west of	FL
102128	Rattlesnake Key, 1.1 mi northwest of, Tampa Bay, Florida Current	NOS	ACT8436_1	27.57083	-82.64383	:America/New_York	USA	knots	210	35	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:09:00	\N	0.1	-00:34:00	\N	0.2	-00:28:00	-00:34:00	Rattlesnake Key, 1.1 miles northwest of	FL
102129	Mullet Key Channel, Marker 24 (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8441_1	27.60833	-82.694	:America/New_York	USA	knots	255	73	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:06:00	\N	0.7	-00:07:00	\N	0.7	-00:14:00	-00:06:00	Mullet Key Channel, marker '24'	FL
102130	Bunces Pass (west of Bayway bridge), Tampa Bay, Florida Current	NOS	ACT8446_1	27.647	-82.7395	:America/New_York	USA	knots	315	125	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-01:02:00	\N	0.7	-00:46:00	\N	0.8	-00:47:00	-01:07:00	Bunces Pass (West of Bayway bridge)	FL
102131	Pine Key (Pinellas Bayway bridge), Tampa Bay, Florida Current	NOS	ACT8451_1	27.6925	-82.71717	:America/New_York	USA	knots	280	100	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-01:00:00	\N	0.6	-00:29:00	\N	0.3	-00:32:00	-01:07:00	Pine Key (Pinellas Bayway bridge)	FL
102132	Cats Point (bridge west of), Tampa Bay, Florida Current	NOS	ACT8456_1	27.70833	-82.72467	:America/New_York	USA	knots	150	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-01:23:00	\N	0.5	-02:41:00	\N	0.5	-01:27:00	-02:12:00	Cats Point (bridge west of)	FL
102133	Cut A & B, Channel Junction, Tampa Bay, Florida Current	NOS	ACT8466_1	27.63883	-82.6255	:America/New_York	USA	knots	225	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	00:46:00	\N	0.7	00:07:00	\N	0.8	00:25:00	00:23:00	Cut A & B, Channel Junction	FL
102134	Joe Island, 1.8 mi northwest of, Tampa Bay, Florida Current	NOS	ACT8471_1	27.6125	-82.625	:America/New_York	USA	knots	245	70	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:02:00	\N	0.7	-00:07:00	\N	0.5	00:03:00	-00:24:00	Joe Island, 1.8 miles northwest of	FL
102135	Harbor Key, 1.3 mi west of, Tampa Bay, Florida Current	NOS	ACT8476_1	27.61117	-82.5945	:America/New_York	USA	knots	160	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:38:00	\N	0.3	-00:56:00	\N	0.2	-00:50:00	-01:06:00	Harbor Key, 1.3 miles west of	FL
102136	Pinellas Point, 2.6 mi south of, Tampa Bay, Florida Current	NOS	ACT8486_1	27.660499572753906	-82.6417007446289	:America/New_York	USA	knots	210	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:34:00	\N	0.7	-00:23:00	\N	0.6	-00:46:00	-00:16:00	Pinellas Point, 2.6 miles south of	FL
102137	Pinellas Point, 0.5 mi southeast of, Tampa Bay, Florida Current	NOS	ACT8491_1	27.69700050354004	-82.63249969482422	:America/New_York	USA	knots	220	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:57:00	\N	0.2	-01:19:00	\N	0.2	-01:28:00	-01:53:00	Pinellas Point, 0.5 mile southeast of	FL
102138	Pinellas Point, 1.9 mi SE of, Tampa Bay, Florida Current	NOS	ACT8496_1	27.68470001220703	-82.60970306396484	:America/New_York	USA	knots	180	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	00:20:00	\N	0.6	-00:32:00	\N	0.5	00:29:00	-00:06:00	Pinellas Point, 1.9 miles SE of	FL
102139	Port Manatee Channel, Marker 4 (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8511_1	27.6535	-82.58983	:America/New_York	USA	knots	242	56	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	00:01:00	\N	0.3	-00:11:00	\N	0.2	-00:34:00	-00:22:00	Port Manatee Channel, marker '4'	FL
102140	Piney Point, 0.6 mi NNW of, Tampa Bay, Florida Current	NOS	ACT8516_1	27.65367	-82.56217	:America/New_York	USA	knots	215	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	00:01:00	\N	0.4	-00:29:00	\N	0.3	00:12:00	-00:45:00	Piney Point, 0.6 mile NNW of	FL
102141	Lewis Island, 0.9 mi east of, Tampa Bay, Florida Current	NOS	ACT8521_1	27.7245	-82.60967	:America/New_York	USA	knots	160	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100766	-00:06:00	\N	0.8	-00:09:00	\N	0.8	00:15:00	-00:52:00	Lewis Island, 0.9 mile east of	FL
102142	Camp Key, 1.9 mi northwest of, Tampa Bay, Florida Current	NOS	ACT8526_1	27.70783	-82.55	:America/New_York	USA	knots	220	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100766	-00:08:00	\N	0.7	00:09:00	\N	0.7	00:22:00	-00:30:00	Camp Key, 1.9 miles northwest of	FL
102143	Cut E Channel, Marker 2E (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8536_1	27.72533	-82.53567	:America/New_York	USA	knots	226	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100766	-00:09:00	\N	0.7	00:17:00	\N	0.7	-00:33:00	-00:13:00	Cut E Channel, marker '2E'	FL
102144	Snell Isle, 1.8 mi east of, Tampa Bay, Florida Current	NOS	ACT8546_1	27.79367	-82.57217	:America/New_York	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100766	00:13:00	\N	0.4	00:32:00	\N	0.3	00:49:00	-00:36:00	Snell Isle, 1.8 miles east of	FL
102145	Ross Island, 1 mi east of, Marker 4 (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8551_1	27.837	-82.57317	:America/New_York	USA	knots	175	347	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100766	-00:09:00	\N	0.5	00:29:00	\N	0.6	00:12:00	00:17:00	Ross Island, 1 mile east of, marker '4'	FL
102146	Weedon I. powerplant channel, Marker 10 (depth 23 ft), Tampa Bay, Florida Current	NOS	ACT8561_1	27.862	-82.58533	:America/New_York	USA	knots	204	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100766	-00:10:00	\N	0.4	00:47:00	\N	0.7	00:28:00	00:16:00	Weedon I. powerplant channel, marker '10'	FL
102147	Gandy Bridge, west channel, Tampa Bay, Florida Current	NOS	ACT8566_1	27.87917	-82.5805	:America/New_York	USA	knots	155	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100766	-00:20:00	\N	0.8	-00:16:00	\N	0.9	00:20:00	-00:42:00	Gandy Bridge, west channel	FL
102148	Gandy Bridge, east channel (depth 6 ft), Tampa Bay, Florida Current	NOS	ACT8571_1	27.88317	-82.55233	:America/New_York	USA	knots	179	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100766	00:20:00	\N	0.5	00:30:00	\N	0.6	00:21:00	00:22:00	Gandy Bridge, east channel	FL
102149	W Howard Frankland Bridge, Tampa Bay, Florida Current	NOS	ACT8576_1	27.92583	-82.58617	:America/New_York	USA	knots	140	285	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100766	00:29:00	\N	0.2	01:00:00	\N	0.3	00:30:00	00:01:00	W Howard Frankland Bridge	FL
102150	Courtney Campbell Parkway, Tampa Bay, Florida Current	NOS	ACT8581_1	27.968	-82.62417	:America/New_York	USA	knots	140	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100766	00:29:00	\N	0.6	00:36:00	\N	0.5	00:48:00	-00:22:00	Courtney Campbell Parkway	FL
102151	Cut A Channel, Marker 10, Hillsborough Bay (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8591_1	27.81183	-82.44733	:America/New_York	USA	knots	213	40	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100766	-00:40:00	\N	0.2	00:16:00	\N	0.3	-01:22:00	-00:41:00	Cut A Channel, marker '10', Hillsborough Bay	FL
102152	Cut C Channel, Marker 21, Hillsborough Bay (depth 15 ft), Tampa Bay, Florida Current	NOS	ACT8596_1	27.846	-82.44367	:America/New_York	USA	knots	183	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100766	-00:10:00	\N	0.2	00:41:00	\N	0.4	-01:03:00	-00:07:00	Cut C Channel, marker '21', Hillsborough Bay	FL
102153	Pass-a-Grille Channel, Florida Current	NOS	ACT8606_1	27.685	-82.735	:America/New_York	USA	knots	186	357	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:17:00	\N	1	-00:43:00	\N	0.9	-00:30:00	-00:30:00	Pass-a-Grille Channel	FL
102154	Bridge, 0.8 mi south of Maximo Pt., Florida Current	NOS	ACT8611_1	27.69333	-82.68	:America/New_York	USA	knots	255	78	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:50:00	\N	1	-01:22:00	\N	0.9	-01:05:00	-01:05:00	Bridge, 0.8 mi. south of Maximo Pt.	FL
102155	Blind Pass (north end), Florida Current	NOS	ACT8621_1	27.75667	-82.76167	:America/New_York	USA	knots	180	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-01:12:00	\N	0.3	-01:25:00	\N	0.5	-01:20:00	-01:20:00	Blind Pass (north end)	FL
102156	The Narrows (Indian Rocks Beach Bridge), Florida Current	NOS	ACT8651_1	27.876670837402344	-82.8499984741211	:America/New_York	USA	knots	0	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:54:00	\N	0.1	-00:25:00	\N	0.5	-00:23:00	-01:17:00	The Narrows (Indian Rocks Beach Bridge)	FL
102157	Clearwater Pass, 0.2 mi NE of Sand Key, Florida Current	NOS	ACT8656_1	27.95667	-82.82333	:America/New_York	USA	knots	348	179	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-01:50:00	\N	0.8	-02:49:00	\N	1	-02:24:00	-02:18:00	Clearwater Pass, 0.2 mi. NE of Sand Key	FL
102158	St. Marks River approach, Apalachee Bay, Florida Current	NOS	ACT8666_1	30.04667	-84.18	:America/New_York	USA	knots	170	339	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:08:00	\N	0.4	-00:46:00	\N	0.5	-00:57:00	-00:10:00	St. Marks River approach	FL
102159	Four Mile Point, St. Marks River, Apalachee Bay, Florida Current	NOS	ACT8671_1	30.11167	-84.20333	:America/New_York	USA	knots	187	358	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	-00:26:00	\N	0.3	-00:14:00	\N	0.3	-00:13:00	00:24:00	Four Mile Point, St. Marks River	FL
102160	St. Marks, St. Marks River, Apalachee Bay, Florida Current	NOS	ACT8676_1	30.155	-84.20167	:America/New_York	USA	knots	247	67	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97993	00:23:00	\N	0.3	01:10:00	\N	0.2	01:38:00	-00:23:00	St. Marks, St. Marks River	FL
102161	Pensacola Bay entrance, midchannel, Florida Current	NOS	ACT8716_1	30.335	-87.3	:America/Chicago	USA	knots	256	74	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98924	-00:49:00	\N	1.3	-01:01:00	\N	1.1	-01:13:00	00:06:00	Pensacola Bay entrance, midchannel	FL
102162	Channel, 6 mi N of Mobile Point, Mobile Bay, Alabama Current	NOS	ACT8731_1	30.33	-88.02833	:America/Chicago	USA	knots	208	32	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98924	01:09:00	\N	0.4	00:46:00	\N	0.4	-00:10:00	01:14:00	Channel, 6 miles N of Mobile Point	AL
102163	Mobile River entrance, Mobile Bay, Alabama Current	NOS	ACT8741_1	30.67	-88.03333	:America/Chicago	USA	knots	151	333	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98924	03:11:00	\N	0.5	04:24:00	\N	0.2	05:11:00	02:32:00	Mobile River entrance	AL
102164	Tensaw River entrance (bridge), Mobile Bay, Alabama Current	NOS	ACT8746_1	30.68167	-88.01167	:America/Chicago	USA	knots	222	29	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98924	00:05:00	\N	0.7	01:05:00	\N	0.3	01:39:00	-01:12:00	Tensaw River entrance (bridge)	AL
102165	Quatre Bayoux Pass, Barataria Bay, Louisiana Current	NOS	ACT8771_1	29.31	-89.85167	:America/Chicago	USA	knots	103	288	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98924	00:32:00	\N	0.9	00:34:00	\N	0.9	01:12:00	00:31:00	Quatre Bayoux Pass, Barataria Bay	LA
102166	Pass Abel, Barataria Bay, Louisiana Current	NOS	ACT8776_1	29.295	-89.90333	:America/Chicago	USA	knots	143	317	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98924	00:23:00	\N	1.1	00:30:00	\N	0.6	00:28:00	00:01:00	Pass Abel, Barataria Bay	LA
102167	Barataria Pass, Barataria Bay, Louisiana Current	NOS	ACT8781_1	29.27167	-89.94833	:America/Chicago	USA	knots	120	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98924	00:45:00	\N	0.9	00:53:00	\N	1.1	02:04:00	00:49:00	Barataria Pass, Barataria Bay	LA
102168	Barataria Bay, 1.1 mi NE of Manilla, Louisiana Current	NOS	ACT8786_1	29.43667	-89.96	:America/Chicago	USA	knots	160	356	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98924	04:38:00	\N	0.3	03:05:00	\N	0.3	04:16:00	02:58:00	Barataria Bay, 1.1 mi. NE of Manilla	LA
102169	Caminada Pass, Barataria Bay, Louisiana Current	NOS	ACT8791_1	29.19833	-90.04667	:America/Chicago	USA	knots	118	297	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98924	01:04:00	\N	1.1	01:57:00	\N	1.1	01:19:00	00:44:00	Caminada Pass, Barataria Bay	LA
102170	Cat Island Pass, Terrebonne Bay (depth 6 ft), Louisiana Current	NOS	ACT8801_1	29.08	-90.57333	:America/Chicago	USA	knots	195	13	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97994	-02:59:00	\N	1.2	-01:57:00	\N	0.8	-02:32:00	-01:05:00	Cat Island Pass, Terrebonne Bay	LA
102171	Wine Island Pass, Louisiana Current	NOS	ACT8806_1	29.07	-90.63333	:America/Chicago	USA	knots	160	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97994	-04:17:00	\N	1.5	-05:03:00	\N	1.2	-04:33:00	-03:38:00	Wine Island Pass	LA
102172	Caillou Boca, Caillou Bay (depth 4 ft), Louisiana Current	NOS	ACT8811_1	29.05833	-90.80833	:America/Chicago	USA	knots	264	95	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97994	-00:05:00	\N	0.6	-00:41:00	\N	0.9	-00:33:00	02:59:00	Caillou Boca, Caillou Bay	LA
102173	Galveston Bay ent. (between jetties) (depth 5 ft), Texas Current	NOS	ACT8851_1	29.34869956970215	-94.71420288085938	:America/Chicago	USA	knots	91	272	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97994	00:05:00	\N	1.1	00:15:00	\N	1	00:17:00	00:02:00	Galveston Bay Ent. (between jetties)	TX
102174	Galveston Bay ent. (between jetties) (depth 34 ft), Texas Current	NOS	ACT8851_3	29.34869956970215	-94.71420288085938	:America/Chicago	USA	knots	94	274	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97994	-00:13:00	\N	0.9	-00:01:00	\N	0.8	-00:18:00	-00:03:00	Galveston Bay Ent. (between jetties)	TX
102175	Bolivar Roads (depth 8 ft), Galveston Bay, Texas Current	NOS	ACT8856_1	29.343299865722656	-94.78130340576172	:America/Chicago	USA	knots	125	295	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97995	-00:01:00	\N	1.1	00:07:00	\N	1	00:09:00	-00:16:00	Bolivar Roads	TX
102176	Bolivar Roads (depth 31 ft), Galveston Bay, Texas Current	NOS	ACT8856_3	29.343299865722656	-94.78130340576172	:America/Chicago	USA	knots	115	306	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97995	-00:08:00	\N	0.6	-00:11:00	\N	0.8	-00:32:00	00:17:00	Bolivar Roads	TX
102177	Houston Channel, W of Port Bolivar (depth 3 ft), Galveston Bay, Texas Current	NOS	ACT8876_1	29.36467	-94.79667	:America/Chicago	USA	knots	135	313	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97995	-01:41:00	\N	1	-00:18:00	\N	1.1	-00:05:00	-02:14:00	Houston Channel, W of Port Bolivar	TX
102178	Houston Channel, W of Port Bolivar (depth 14 ft), Galveston Bay, Texas Current	NOS	ACT8876_2	29.36467	-94.79667	:America/Chicago	USA	knots	133	312	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97995	-01:55:00	\N	0.9	-00:11:00	\N	1	-00:03:00	-02:15:00	Houston Channel, W of Port Bolivar	TX
102179	Houston Channel, W of Port Bolivar (depth 26 ft), Galveston Bay, Texas Current	NOS	ACT8876_3	29.36467	-94.79667	:America/Chicago	USA	knots	133	312	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97995	-01:41:00	\N	0.8	-00:14:00	\N	0.9	-00:06:00	-02:12:00	Houston Channel, W of Port Bolivar	TX
102180	Houston Ship Channel (Red Fish Bar) (depth 7 ft), Galveston Bay, Texas Current	NOS	ACT8881_1	29.50733	-94.87467	:America/Chicago	USA	knots	154	341	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97995	00:50:00	\N	0.5	01:13:00	\N	0.5	00:41:00	01:13:00	Houston Ship Channel (Red Fish Bar)	TX
102181	Houston Ship Channel (Red Fish Bar) (depth 14 ft), Galveston Bay, Texas Current	NOS	ACT8881_2	29.50733	-94.87467	:America/Chicago	USA	knots	148	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97995	01:10:00	\N	0.7	01:28:00	\N	0.7	00:45:00	01:17:00	Houston Ship Channel (Red Fish Bar)	TX
102182	Houston Ship Channel (Red Fish Bar) (depth 24 ft), Galveston Bay, Texas Current	NOS	ACT8881_3	29.50733	-94.87467	:America/Chicago	USA	knots	144	323	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97995	01:42:00	\N	0.5	01:15:00	\N	0.5	00:48:00	01:20:00	Houston Ship Channel (Red Fish Bar)	TX
102183	Punta Ostiones, 1.5 mi west of, Puerto Rico Current	NOS	ACT8921_1	18.08667	-67.22667	:America/Puerto_Rico	USA	knots	1	187	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97996	-00:35:00	\N	1.3	-00:52:00	\N	1.7	-00:26:00	-00:04:00	Punta Ostiones, 1.5 miles west of	PR
102184	Vieques Sound, Puerto Rico Current	NOS	ACT8931_1	18.2645	-65.57	:America/Puerto_Rico	USA	knots	355	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97996	-01:05:00	\N	0.9	-01:16:00	\N	0.7	-00:44:00	-01:28:00	Vieques Sound	PR
102185	Largo Shoals, west of, Puerto Rico Current	NOS	ACT8936_1	18.31667	-65.58333	:America/Puerto_Rico	USA	knots	330	186	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97996	-01:08:00	\N	1	-01:28:00	\N	0.7	-00:52:00	-01:33:00	Largo Shoals, west of	PR
102186	Fajardo Harbor (channel), Puerto Rico Current	NOS	ACT8951_1	18.33333	-65.61667	:America/Puerto_Rico	USA	knots	339	162	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	97996	-01:45:00	\N	1.6	-01:52:00	\N	0.5	-01:13:00	-02:27:00	Fajardo Harbor (channel)	PR
102187	Port Mackenzie (depth 13 ft), Cook Inlet, Alaska Current	NOS	COI0211_7	61.26765	-149.91688	:America/Anchorage	USA	knots	193	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98284	-00:37:00	\N	0.3	-01:08:00	\N	0.2	-01:50:00	-00:44:00	Port Mackenzie	AK
102188	Corson's Inlet entrance (depth 15 ft), New Jersey Current	NOS	COR0301_5	39.20863	-74.6519	:America/New_York	USA	knots	129	308	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98412	-02:55:00	\N	1.1	-01:57:00	\N	0.9	-01:53:00	-02:04:00	Corson's Inlet Entrance	NJ
102189	Magdalena Bay entrance, California Current	NOS	PCT0016_1	24.53333	-112.03333	:America/Los_Angeles	USA	knots	\N	35	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100333	-04:27:00	\N	0.3	-04:46:00	\N	0.6	-05:45:00	-03:56:00	Magdalena Bay entrance	CA
102190	Point Loma Light, 0.8 nmi east of (depth 15 ft), San Diego Bay, California Current	NOS	PCT0026_1	32.66583	-117.22617	:America/Los_Angeles	USA	knots	174	328	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	00:45:00	\N	0.4	-00:43:00	\N	0.5	-00:18:00	-00:05:00	Point Loma Light, 0.8 nmi. east of	CA
102191	Point Loma Light, 0.8 nmi east of (depth 33 ft), San Diego Bay, California Current	NOS	PCT0026_2	32.66583	-117.22617	:America/Los_Angeles	USA	knots	166	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	-00:23:00	\N	0.2	-00:46:00	\N	0.4	-01:08:00	-00:08:00	Point Loma Light, 0.8 nmi. east of	CA
102192	Ballast Point, south of (depth 5 ft), San Diego Bay, California Current	NOS	PCT0036_1	32.6845	-117.23217	:America/Los_Angeles	USA	knots	238	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	-02:03:00	\N	0.2	-01:02:00	\N	0.4	-01:04:00	-01:01:00	Ballast Point, south of	CA
102193	Ballast Point, 100 yards north of, San Diego Bay, California Current	NOS	PCT0041_1	32.68333	-117.23333	:America/Los_Angeles	USA	knots	133	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	-00:02:00	\N	0.9	-00:24:00	\N	1	-00:27:00	-00:23:00	Ballast Point, 100 yards north of	CA
102194	Ballast Point, 0.55 nmi north of (depth 14 ft), San Diego Bay, California Current	NOS	PCT0046_1	32.69583	-117.2325	:America/Los_Angeles	USA	knots	193	354	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	00:24:00	\N	0.4	-00:39:00	\N	0.5	-00:05:00	-00:34:00	Ballast Point, 0.55 nmi. north of	CA
102195	Ballast Point, 0.55 nmi north of (depth 34 ft), San Diego Bay, California Current	NOS	PCT0046_2	32.69583	-117.2325	:America/Los_Angeles	USA	knots	147	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	-00:03:00	\N	0.2	00:10:00	\N	0.5	-00:44:00	00:03:00	Ballast Point, 0.55 nmi. north of	CA
102196	Quarantine Station, La Playa, San Diego Bay, California Current	NOS	PCT0051_1	32.7	-117.23333	:America/Los_Angeles	USA	knots	200	21	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	00:20:00	\N	0.8	00:15:00	\N	0.8	-00:03:00	00:10:00	Quarantine Station, La Playa	CA
102197	North Island (depth 14 ft), San Diego Bay, California Current	NOS	PCT0056_1	32.713	-117.21283	:America/Los_Angeles	USA	knots	245	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	-00:03:00	\N	0.4	-00:56:00	\N	0.5	-00:26:00	-00:54:00	North Island	CA
102198	North Island (depth 34 ft), San Diego Bay, California Current	NOS	PCT0056_2	32.713	-117.21283	:America/Los_Angeles	USA	knots	241	77	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	-00:33:00	\N	0.2	-01:05:00	\N	0.3	-00:43:00	-00:44:00	North Island	CA
102199	Harbor Island (east end), SSW of (depth 15 ft), San Diego Bay, California Current	NOS	PCT0061_1	32.71917	-117.19167	:America/Los_Angeles	USA	knots	293	97	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	00:23:00	\N	0.3	00:09:00	\N	0.3	00:29:00	-00:24:00	Harbor Island (east end), SSW of	CA
102200	San Diego, 0.5 mi west of, San Diego Bay, California Current	NOS	PCT0066_1	32.71667	-117.18333	:America/Los_Angeles	USA	knots	304	121	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	-00:12:00	\N	0.5	-00:08:00	\N	0.6	-00:16:00	-00:12:00	San Diego, 0.5 mile west of	CA
102201	G St. Pier (San Diego), 0.22 nmi SW of (depth 14 ft), San Diego Bay, California Current	NOS	PCT0081_1	32.70833	-117.1775	:America/Los_Angeles	USA	knots	304	139	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	00:41:00	\N	0.3	00:20:00	\N	0.3	00:10:00	-00:03:00	G St. Pier (San Diego), 0.22 nmi. SW of	CA
102202	G St. Pier (San Diego), 0.22 nmi SW of (depth 37 ft), San Diego Bay, California Current	NOS	PCT0081_2	32.70833	-117.1775	:America/Los_Angeles	USA	knots	301	125	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	00:58:00	\N	0.2	00:21:00	\N	0.3	-00:23:00	-00:18:00	G St. Pier (San Diego), 0.22 nmi. SW of	CA
102203	Coronado, off northeast end (depth 14 ft), San Diego Bay, California Current	NOS	PCT0091_1	32.698	-117.16383	:America/Los_Angeles	USA	knots	317	128	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	00:09:00	\N	0.5	-00:58:00	\N	0.7	-00:24:00	-00:51:00	Coronado, off northeast end	CA
102204	Coronado, off northeast end (depth 38 ft), San Diego Bay, California Current	NOS	PCT0091_2	32.698	-117.16383	:America/Los_Angeles	USA	knots	319	130	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	00:03:00	\N	0.4	-00:59:00	\N	0.5	-00:41:00	-01:01:00	Coronado, off northeast end	CA
102205	28th St. Pier (San Diego), 0.92 nmi SW (depth 7 ft), San Diego Bay, California Current	NOS	PCT0096_1	32.67467	-117.1495	:America/Los_Angeles	USA	knots	351	182	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	-00:05:00	\N	0.1	-01:17:00	\N	0.2	-00:44:00	-01:10:00	28th St. Pier (San Diego), 0.92 nmi. SW	CA
102206	28th St. Pier (San Diego), 0.35 nmi SW (depth 14 ft), San Diego Bay, California Current	NOS	PCT0101_1	32.68283	-117.14283	:America/Los_Angeles	USA	knots	317	133	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	00:13:00	\N	0.2	00:15:00	\N	0.3	-00:14:00	00:15:00	28th St. Pier (San Diego), 0.35 nmi. SW	CA
102207	28th St. Pier (San Diego), 0.35 nmi SW (depth 28 ft), San Diego Bay, California Current	NOS	PCT0101_2	32.68283	-117.14283	:America/Los_Angeles	USA	knots	328	148	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	00:35:00	\N	0.2	00:24:00	\N	0.2	00:01:00	00:15:00	28th St. Pier (San Diego), 0.35 nmi. SW	CA
102208	National City, San Diego Bay, California Current	NOS	PCT0106_1	32.65	-117.11667	:America/Los_Angeles	USA	knots	2	166	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	00:50:00	\N	0.4	00:00:00	\N	0.4	00:23:00	-00:02:00	National City	CA
102209	National City, WSW of Pier 12 (depth 32 ft), San Diego Bay, California Current	NOS	PCT0111_1	32.66217	-117.1255	:America/Los_Angeles	USA	knots	351	178	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	00:58:00	\N	0.2	00:34:00	\N	0.2	00:22:00	00:34:00	National City, WSW of Pier 12	CA
102210	Sweetwater Channel, southwest of (depth 14 ft), San Diego Bay, California Current	NOS	PCT0116_1	32.645	-117.12283	:America/Los_Angeles	USA	knots	348	203	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98998	00:46:00	\N	0.2	-00:33:00	\N	0.1	00:29:00	-00:05:00	Sweetwater Channel, southwest of	CA
102211	Point Bonita Lt., 5.27 nmi WSW of (depth 39 ft), California Current	NOS	PCT0181_1	37.8045	-122.63883	:America/Los_Angeles	USA	knots	266	95	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100333	-01:01:00	\N	0.2	-01:35:00	\N	0.2	-01:54:00	-00:51:00	Point Bonita Lt., 5.27 nmi. WSW of	CA
102212	Point Lobos, 3.73 nmi W of (depth 46 ft), California Current	NOS	PCT0191_1	37.7875	-122.58867	:America/Los_Angeles	USA	knots	241	92	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100333	-00:31:00	\N	0.2	-01:03:00	\N	0.3	-02:16:00	-00:20:00	Point Lobos, 3.73 nmi. W of	CA
102213	Point Lobos, 1.3 nmi SW of (depth 46 ft), California Current	NOS	PCT0201_1	37.77167	-122.5355	:America/Los_Angeles	USA	knots	182	8	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100333	-00:06:00	\N	0.4	-00:51:00	\N	0.5	-01:26:00	00:27:00	Point Lobos, 1.3 nmi. SW of	CA
102214	South Channel, California Current	NOS	PCT0206_1	37.75	-122.53333	:America/Los_Angeles	USA	knots	180	23	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100333	-00:52:00	\N	0.5	-01:21:00	\N	0.5	-01:31:00	-00:14:00	South Channel	CA
102215	Point Lobos, 5.47 nmi SW of (depth 39 ft), California Current	NOS	PCT0211_1	37.7205	-122.59783	:America/Los_Angeles	USA	knots	211	48	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100333	-01:10:00	\N	0.3	-02:02:00	\N	0.3	-02:01:00	-00:51:00	Point Lobos, 5.47 nmi. SW of	CA
102216	Point Bonita, 0.8 nmi NE of (depth 22 ft), California Current	NOS	PCT0231_1	37.82083	-122.51617	:America/Los_Angeles	USA	knots	267	64	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100333	-04:01:00	\N	0.3	-03:38:00	\N	0.4	-04:51:00	-04:21:00	Point Bonita, 0.8 nmi. NE of	CA
102217	Point Bonita, 0.8 nmi NE of (depth 41 ft), California Current	NOS	PCT0231_2	37.82083	-122.51617	:America/Los_Angeles	USA	knots	247	111	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100333	-04:01:00	\N	0.2	-04:23:00	\N	0.3	-05:12:00	-04:45:00	Point Bonita, 0.8 nmi. NE of	CA
102218	Point Bonita Lt., 0.4 nmi SSE of (depth 43 ft), California Current	NOS	PCT0236_1	37.812	-122.52117	:America/Los_Angeles	USA	knots	229	104	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100333	-01:25:00	\N	0.5	-01:04:00	\N	0.3	-01:08:00	-01:28:00	Point Bonita Lt., 0.4 nmi. SSE of	CA
102219	Mile Rock Lt., 0.2 nmi NW of (depth 15 ft), California Current	NOS	PCT0246_1	37.79533	-122.51133	:America/Los_Angeles	USA	knots	230	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100333	-00:33:00	\N	0.9	-00:25:00	\N	1.1	-00:35:00	00:18:00	Mile Rock Lt., 0.2 nmi. NW of	CA
102220	Mile Rock Lt., 0.2 nmi NW of (depth 35 ft), California Current	NOS	PCT0246_2	37.79533	-122.51133	:America/Los_Angeles	USA	knots	231	54	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100333	-00:34:00	\N	0.8	-00:28:00	\N	1.1	-00:48:00	00:23:00	Mile Rock Lt., 0.2 nmi. NW of	CA
102221	Point Diablo, 0.2 mi SE of, California Current	NOS	PCT0251_1	37.81783	-122.49667	:America/Los_Angeles	USA	knots	263	82	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100333	00:08:00	\N	1	-00:53:00	\N	0.8	-00:09:00	-00:47:00	Point Diablo, 0.2 mile SE of	CA
102222	Baker Beach (South Bay), 0.3 nmi NW of (depth 31 ft), California Current	NOS	PCT0256_1	37.79783	-122.4885	:America/Los_Angeles	USA	knots	208	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100333	-02:52:00	\N	0.3	-04:15:00	\N	0.6	-05:06:00	-01:59:00	Baker Beach (South Bay), 0.3 nmi. NW of	CA
102223	Baker Beach (South Bay), 0.3 nmi NW of (depth 50 ft), California Current	NOS	PCT0256_2	37.79783	-122.4885	:America/Los_Angeles	USA	knots	215	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100333	-02:54:00	\N	0.3	-04:14:00	\N	0.4	-05:11:00	-01:33:00	Baker Beach (South Bay), 0.3 nmi. NW of	CA
102224	Fort Point, 0.3 nmi west of (depth 75 ft), California Current	NOS	PCT0261_1	37.80917	-122.48283	:America/Los_Angeles	USA	knots	335	44	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100333	00:20:00	\N	0.2	-00:41:00	\N	0.6	-02:10:00	01:02:00	Fort Point, 0.3 nmi. west of	CA
102225	Golden Gate Bridge, 0.8 mi east of, California Current	NOS	PCT0281_1	37.82167	-122.46167	:America/Los_Angeles	USA	knots	256	70	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	00:43:00	\N	1.4	00:15:00	\N	0.9	00:42:00	00:27:00	Golden Gate Bridge, 0.8 mile east of	CA
102226	Fort Point, 0.5 nmi east of (depth 55 ft), California Current	NOS	PCT0286_1	37.81167	-122.46633	:America/Los_Angeles	USA	knots	287	99	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	-01:12:00	\N	0.8	-02:47:00	\N	0.2	-00:43:00	-00:30:00	Fort Point, 0.5 nmi. east of	CA
102227	Alcatraz Island, 0.2 mi west of, San Francisco Bay, California Current	NOS	PCT0291_1	37.82783	-122.43033	:America/Los_Angeles	USA	knots	266	70	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	00:20:00	\N	1.1	00:00:00	\N	0.8	00:15:00	00:24:00	Alcatraz Island, 0.2 mile west of	CA
102228	Alcatraz Island, south of, San Francisco Bay, California Current	NOS	PCT0301_1	37.81833	-122.422	:America/Los_Angeles	USA	knots	286	93	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	00:02:00	\N	1.2	-00:03:00	\N	0.5	00:15:00	00:07:00	Alcatraz Island, south of	CA
102229	Treasure Island, 0.8 mi west of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0321_1	37.82167	-122.39167	:America/Los_Angeles	USA	knots	334	148	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	-00:01:00	\N	1.5	-00:37:00	\N	0.4	-00:01:00	-00:39:00	Treasure Island, 0.8 mile west of	CA
102230	Treasure Island, 0.2 mi west of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0326_1	37.82167	-122.37833	:America/Los_Angeles	USA	knots	343	172	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	-00:30:00	\N	1.2	-00:50:00	\N	0.5	-00:54:00	-00:32:00	Treasure Island, 0.2 mile west of	CA
102231	Oakland, Yerba Buena Island (depth 29 ft), San Francisco Bay, California Current	NOS	PCT0336_2	37.80979919433594	-122.35070037841797	:America/Los_Angeles	USA	knots	355	163	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98999	-00:07:00	\N	0.6	-00:04:00	\N	0.7	-00:38:00	-00:01:00	Oakland, Yerba Buena Island	CA
102232	Treasure Island, 0.5 mi north of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0346_1	37.8405	-122.36833	:America/Los_Angeles	USA	knots	304	118	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98999	00:42:00	\N	0.9	00:02:00	\N	0.8	00:31:00	00:22:00	Treasure Island, 0.5 mile north of	CA
102233	Treasure Island, 0.85 nmi east of (depth 11 ft), San Francisco Bay, California Current	NOS	PCT0351_1	37.825	-122.34633	:America/Los_Angeles	USA	knots	340	161	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98999	-00:26:00	\N	0.5	00:16:00	\N	0.6	-00:13:00	00:24:00	Treasure Island, 0.85 nmi. east of	CA
102234	Treasure Island, 0.3 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0356_1	37.82667	-122.355	:America/Los_Angeles	USA	knots	327	140	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98999	01:02:00	\N	1.2	00:13:00	\N	1	01:12:00	00:00:00	Treasure Island, 0.3 mile east of	CA
102235	Yerba Buena Island, 0.3 nmi SE of (depth 23 ft), San Francisco Bay, California Current	NOS	PCT0361_1	37.80417	-122.35717	:America/Los_Angeles	USA	knots	316	159	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98999	00:21:00	\N	0.8	00:05:00	\N	0.5	00:31:00	00:07:00	Yerba Buena Island, 0.3 nmi. SE of	CA
102236	Oakland Inner Harbor entrance (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0371_1	37.80167	-122.34	:America/Los_Angeles	USA	knots	338	178	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98999	-00:09:00	\N	1.2	-00:12:00	\N	0.7	-00:11:00	-00:01:00	Oakland Inner Harbor entrance	CA
102237	Oakland Harbor, Webster Street, San Francisco Bay, California Current	NOS	PCT0386_1	37.79167	-122.2745	:America/Los_Angeles	USA	knots	300	120	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98999	-00:03:00	\N	0.8	-00:32:00	\N	0.6	00:08:00	-00:18:00	Oakland Harbor, Webster Street	CA
102238	Oakland 7th St. Marine, 0.6 nmi SSW of (depth 21 ft), California Current	NOS	PCT0396_1	37.7945	-122.34417	:America/Los_Angeles	USA	knots	342	154	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98999	00:03:00	\N	0.6	00:27:00	\N	0.8	-00:01:00	-00:02:00	Oakland 7th St. Marine, 0.6 nmi. SSW of	CA
102239	Rincon Point, midbay (depth 11 ft), San Francisco Bay, California Current	NOS	PCT0406_1	37.78333	-122.35383	:America/Los_Angeles	USA	knots	322	166	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	-00:24:00	\N	1.3	-00:33:00	\N	0.8	-00:22:00	-00:38:00	Rincon Point, midbay	CA
102240	Mission Rock, 0.6 mi east of, San Francisco Bay, California Current	NOS	PCT0411_1	37.77333	-122.36833	:America/Los_Angeles	USA	knots	320	160	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	00:06:00	\N	1.4	-00:21:00	\N	0.9	-00:09:00	-00:08:00	Mission Rock, 0.6 mile east of	CA
102241	Mission Rock, 1.3 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0416_1	37.775	-122.35333	:America/Los_Angeles	USA	knots	344	182	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	00:14:00	\N	1.2	-00:31:00	\N	0.8	00:01:00	-00:02:00	Mission Rock, 1.3 mile east of	CA
102242	Mission Rock, 2.0 mi east of, San Francisco Bay, California Current	NOS	PCT0421_1	37.77667	-122.33833	:America/Los_Angeles	USA	knots	330	142	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	-00:20:00	\N	1.4	-00:51:00	\N	0.6	-00:49:00	-00:18:00	Mission Rock, 2.0 miles east of	CA
102243	Potrero Point, 1.08 nmi east of (depth 20 ft), San Francisco Bay, California Current	NOS	PCT0426_1	37.7575	-122.35783	:America/Los_Angeles	USA	knots	342	169	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	-00:04:00	\N	1.1	-00:25:00	\N	0.6	-00:08:00	-00:06:00	Potrero Point, 1.08 nmi. east of	CA
102244	Potrero Point, 1.08 nmi east of (depth 49 ft), San Francisco Bay, California Current	NOS	PCT0426_2	37.7575	-122.35783	:America/Los_Angeles	USA	knots	327	139	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	00:13:00	\N	0.7	-00:32:00	\N	0.4	-00:15:00	-00:05:00	Potrero Point, 1.08 nmi. east of	CA
102245	Potrero Point, 2 mi east of, San Francisco Bay, California Current	NOS	PCT0431_1	37.75	-122.33333	:America/Los_Angeles	USA	knots	328	159	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	-00:02:00	\N	1	-00:44:00	\N	0.6	-00:08:00	00:03:00	Potrero Point, 2 miles  east of	CA
102246	Alameda Radar Tower, 0.9 nmi SSW of (depth 4 ft), San Francisco Bay, California Current	NOS	PCT0436_1	37.7455	-122.283	:America/Los_Angeles	USA	knots	309	132	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	-01:12:00	\N	0.4	-01:14:00	\N	0.2	-00:55:00	-01:18:00	Alameda Radar Tower, 0.9 nmi. SSW of	CA
102435	Ketchikan, Tongass Narrows, Alaska Current	NOS	PCT2786_1	55.33617	-131.64417	:America/Juneau	USA	knots	120	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:41:00	\N	0.1	00:08:00	\N	0.3	-00:50:00	00:04:00	Ketchikan	AK
102247	Point Avisadero, 0.3 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0441_1	37.73	-122.34833	:America/Los_Angeles	USA	knots	337	156	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:20:00	\N	1.3	-00:21:00	\N	1.2	-00:30:00	-00:13:00	Point Avisadero, 0.3 mile east of	CA
102248	Point Avisadero, 1 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0446_1	37.73	-122.33667	:America/Los_Angeles	USA	knots	352	154	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:07:00	\N	1	00:02:00	\N	1.2	-00:32:00	00:25:00	Point Avisadero, 1 mile east of	CA
102249	Point Avisadero, 2 mi east of (depth 6 ft), San Francisco Bay, California Current	NOS	PCT0451_1	37.73167	-122.31333	:America/Los_Angeles	USA	knots	335	148	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:24:00	\N	1.1	-00:06:00	\N	1.1	-00:32:00	-00:10:00	Point Avisadero, 2 miles east of	CA
102250	Point Avisadero, 0.6 nmi ESE of (depth 21 ft), San Francisco Bay, California Current	NOS	PCT0456_1	37.723	-122.32383	:America/Los_Angeles	USA	knots	335	140	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:39:00	\N	1	-00:25:00	\N	1	-00:32:00	-00:14:00	Point Avisadero, 0.6 nmi. ESE of	CA
102251	Point Avisadero, 0.6 nmi ESE of (depth 37 ft), San Francisco Bay, California Current	NOS	PCT0456_2	37.723	-122.32383	:America/Los_Angeles	USA	knots	327	132	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:43:00	\N	0.7	-00:23:00	\N	0.8	-00:37:00	-00:10:00	Point Avisadero, 0.6 nmi. ESE of	CA
102252	Point Avisadero, 1.25 nmi SSE of (depth 20 ft), San Francisco Bay, California Current	NOS	PCT0461_1	37.70783	-122.3495	:America/Los_Angeles	USA	knots	4	175	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:52:00	\N	0.8	-00:15:00	\N	0.9	-00:45:00	-00:29:00	Point Avisadero, 1.25 nmi. SSE of	CA
102253	Point Avisadero, 1.25 nmi SSE of (depth 32 ft), San Francisco Bay, California Current	NOS	PCT0461_2	37.70783	-122.3495	:America/Los_Angeles	USA	knots	8	186	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:48:00	\N	0.6	-00:06:00	\N	0.7	-00:43:00	-00:33:00	Point Avisadero, 1.25 nmi. SSE of	CA
102254	Oakland Airport, southwest of (depth 3 ft), San Francisco Bay, California Current	NOS	PCT0466_1	37.68217	-122.23083	:America/Los_Angeles	USA	knots	304	125	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-01:18:00	\N	0.5	-00:46:00	\N	0.5	-01:05:00	-00:39:00	Oakland Airport, southwest of	CA
102255	Sierra Point, 1.3 mi ENE of, San Francisco Bay, California Current	NOS	PCT0471_1	37.68467	-122.35667	:America/Los_Angeles	USA	knots	3	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:40:00	\N	0.7	-00:34:00	\N	0.8	-00:47:00	-00:25:00	Sierra Point, 1.3 miles ENE of	CA
102256	Sierra Point, 1.2 nmi east of (depth 18 ft), San Francisco Bay, California Current	NOS	PCT0476_1	37.678	-122.3175	:America/Los_Angeles	USA	knots	358	210	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:22:00	\N	0.5	-00:30:00	\N	0.6	-00:42:00	-00:26:00	Sierra Point, 1.2 nmi. east of	CA
102257	Oyster Point, 2.8 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0481_1	37.665	-122.32333	:America/Los_Angeles	USA	knots	345	172	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:16:00	\N	0.8	-00:20:00	\N	0.7	-00:29:00	-00:13:00	Oyster Point, 2.8 miles east of	CA
102258	Sierra Point, 4.4 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0486_1	37.67333	-122.295	:America/Los_Angeles	USA	knots	329	152	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:33:00	\N	0.6	-00:34:00	\N	0.7	-00:48:00	-00:09:00	Sierra Point, 4.4 miles east of	CA
102259	Point San Bruno, 0.51 nmi east of (depth 10 ft), San Francisco Bay, California Current	NOS	PCT0491_1	37.65417	-122.36383	:America/Los_Angeles	USA	knots	359	174	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-01:07:00	\N	0.3	-00:27:00	\N	0.5	-01:16:00	-00:21:00	Point San Bruno, 0.51 nmi. east  of	CA
102260	Little Coyote Pt., 3.4 nmi NNE of (depth 4 ft), San Francisco Bay, California Current	NOS	PCT0501_1	37.62383	-122.23133	:America/Los_Angeles	USA	knots	310	128	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-01:01:00	\N	0.4	-00:54:00	\N	0.4	-01:06:00	-00:50:00	Little Coyote Pt., 3.4 nmi. NNE of	CA
102261	Little Coyote Pt., 3.1 nmi ENE of (depth 4 ft), San Francisco Bay, California Current	NOS	PCT0506_1	37.598	-122.2055	:America/Los_Angeles	USA	knots	317	135	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-01:49:00	\N	0.4	-01:34:00	\N	0.4	-01:52:00	-00:58:00	Little Coyote Pt., 3.1 nmi. ENE of	CA
102262	Little Coyote Pt., 1.2 nmi NE of (depth 10 ft), San Francisco Bay, California Current	NOS	PCT0511_1	37.59033	-122.24867	:America/Los_Angeles	USA	knots	303	121	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:11:00	\N	1.1	-00:26:00	\N	1.1	-00:09:00	-00:11:00	Little Coyote Pt., 1.2 nmi. NE of	CA
102263	Little Coyote Pt., 1.2 nmi NE of (depth 20 ft), San Francisco Bay, California Current	NOS	PCT0511_2	37.59033	-122.24867	:America/Los_Angeles	USA	knots	307	122	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:13:00	\N	1	-00:27:00	\N	0.9	-00:17:00	-00:07:00	Little Coyote Pt., 1.2 nmi. NE of	CA
102264	Little Coyote Pt., 1.2 nmi NE of (depth 39 ft), San Francisco Bay, California Current	NOS	PCT0511_3	37.59033	-122.24867	:America/Los_Angeles	USA	knots	310	138	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:09:00	\N	0.8	-00:21:00	\N	0.7	-00:24:00	-00:12:00	Little Coyote Pt., 1.2 nmi. NE of	CA
102265	Redwood Pt., Blair I., 1.15 nmi NNE of (depth 19 ft), California Current	NOS	PCT0521_1	37.558	-122.19883	:America/Los_Angeles	USA	knots	310	120	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:06:00	\N	1.1	-00:21:00	\N	1	-00:02:00	-00:02:00	Redwood Pt., Blair I., 1.15 nmi. NNE of	CA
102266	Redwood Pt., Blair I., 1.15 nmi NNE of (depth 42 ft), California Current	NOS	PCT0521_2	37.558	-122.19883	:America/Los_Angeles	USA	knots	300	107	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:06:00	\N	0.7	-00:27:00	\N	0.8	-00:17:00	-00:10:00	Redwood Pt., Blair I., 1.15 nmi. NNE of	CA
102267	Dumbarton Hwy. Bridge, 0.28 nmi SE of (depth 25 ft), California Current	NOS	PCT0531_1	37.50133	-122.1155	:America/Los_Angeles	USA	knots	319	141	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:37:00	\N	1.2	00:06:00	\N	1	-00:21:00	00:02:00	Dumbarton Hwy. Bridge, 0.28 nmi. SE of	CA
102268	Dumbarton Hwy. Bridge, 0.28 nmi SE of (depth 42 ft), California Current	NOS	PCT0531_2	37.50133	-122.1155	:America/Los_Angeles	USA	knots	322	137	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:45:00	\N	0.7	00:10:00	\N	0.9	-00:36:00	00:01:00	Dumbarton Hwy. Bridge, 0.28 nmi. SE of	CA
102269	Dumbarton Point, 1.15 nmi SE of (depth 17 ft), San Francisco Bay, California Current	NOS	PCT0536_1	37.4875	-122.08133	:America/Los_Angeles	USA	knots	320	131	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	00:54:00	\N	0.6	-00:20:00	\N	0.8	-00:12:00	00:12:00	Dumbarton Point, 1.15 nmi. SE  of	CA
102270	Dumbarton Point, 2.25 mi SE of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0541_1	37.475	-122.07	:America/Los_Angeles	USA	knots	302	127	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	00:56:00	\N	0.8	-00:06:00	\N	0.9	00:08:00	00:00:00	Dumbarton Point, 2.25 miles SE of	CA
102271	Yellow Bluff, 0.8 nmi NE of (depth 19 ft), San Francisco Bay, California Current	NOS	PCT0546_1	37.8455	-122.45717	:America/Los_Angeles	USA	knots	211	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:59:00	\N	1.1	-00:28:00	\N	1.2	-00:27:00	-00:37:00	Yellow Bluff, 0.8 nmi. NE of	CA
102272	Yellow Bluff, 0.8 nmi NE of (depth 51 ft), San Francisco Bay, California Current	NOS	PCT0546_2	37.8455	-122.45717	:America/Los_Angeles	USA	knots	226	12	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100404	-00:33:00	\N	0.6	-00:31:00	\N	0.8	-00:42:00	-00:06:00	Yellow Bluff, 0.8 nmi. NE of	CA
102273	Yellow Bluff, 0.8 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0551_1	37.835	-122.455	:America/Los_Angeles	USA	knots	257	22	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	00:44:00	\N	1.4	00:16:00	\N	1	00:24:00	00:22:00	Yellow Bluff, 0.8 mile east of	CA
102274	Point Cavallo, 1.3 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0556_1	37.83167	-122.44333	:America/Los_Angeles	USA	knots	256	87	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	00:44:00	\N	1.6	00:26:00	\N	0.9	00:31:00	00:42:00	Point Cavallo, 1.3 miles east of	CA
102275	Point Blunt, Angel I., 0.5 nmi SW of (depth 21 ft), San Francisco Bay, California Current	NOS	PCT0561_1	37.8455	-122.423	:America/Los_Angeles	USA	knots	258	77	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	00:33:00	\N	1	00:09:00	\N	0.4	00:56:00	00:03:00	Point Blunt, Angel I., 0.5 nmi. SW of	CA
102276	Point Blunt, Angel I., 0.5 nmi SW of (depth 40 ft), San Francisco Bay, California Current	NOS	PCT0561_2	37.8455	-122.423	:America/Los_Angeles	USA	knots	258	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	00:33:00	\N	0.9	-00:12:00	\N	0.4	00:02:00	00:27:00	Point Blunt, Angel I., 0.5 nmi. SW of	CA
102277	Point Blunt, Angel I., 0.25 mi S of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0566_1	37.84667	-122.41667	:America/Los_Angeles	USA	knots	258	103	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	01:08:00	\N	1.3	00:11:00	\N	0.6	00:12:00	00:24:00	Point Blunt, Angel I., 0.25 mile S of	CA
102278	Pt. Blunt, Angel I., 0.8 mi SE of, San Francisco Bay, California Current	NOS	PCT0571_1	37.845	-122.405	:America/Los_Angeles	USA	knots	297	86	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	-00:12:00	\N	0.8	00:02:00	\N	0.4	-01:06:00	00:21:00	Pt. Blunt, Angel I., 0.8 mi. SE of	CA
102279	Pt. Blunt, Angel I., 0.25 nmi east of (depth 21 ft), California Current	NOS	PCT0576_1	37.85283	-122.41217	:America/Los_Angeles	USA	knots	185	49	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	02:23:00	\N	1	-00:06:00	\N	0.4	01:45:00	00:17:00	Pt. Blunt, Angel I., 0.25 nmi. east of	CA
102280	Pt. Blunt, Angel I., 0.25 nmi east of (depth 41 ft), California Current	NOS	PCT0576_2	37.85283	-122.41217	:America/Los_Angeles	USA	knots	194	37	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	02:02:00	\N	0.8	-00:32:00	\N	0.3	00:55:00	00:34:00	Pt. Blunt, Angel I., 0.25 nmi. east of	CA
102281	Angel Island, off Quarry Point, San Francisco Bay, California Current	NOS	PCT0581_1	37.86333	-122.41333	:America/Los_Angeles	USA	knots	130	27	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	01:47:00	\N	1.2	00:22:00	\N	0.2	02:11:00	01:10:00	Angel Island, off Quarry Point	CA
102282	Angel Island, 0.75 mi east of, San Francisco Bay, California Current	NOS	PCT0586_1	37.86333	-122.40167	:America/Los_Angeles	USA	knots	192	351	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	01:59:00	\N	0.6	01:10:00	\N	0.4	01:30:00	01:35:00	Angel Island, 0.75 mile east of	CA
102283	Point Simpson, Angel I., 1.05 nmi E of (depth 21 ft), California Current	NOS	PCT0591_1	37.87383	-122.40283	:America/Los_Angeles	USA	knots	177	332	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	00:33:00	\N	0.5	01:08:00	\N	0.5	00:53:00	01:03:00	Point Simpson, Angel I., 1.05 nmi. E of	CA
102284	Point Simpson, Angel I., 1.05 nmi E of (depth 42 ft), California Current	NOS	PCT0591_2	37.87383	-122.40283	:America/Los_Angeles	USA	knots	169	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	00:33:00	\N	0.3	01:19:00	\N	0.3	00:29:00	01:01:00	Point Simpson, Angel I., 1.05 nmi. E of	CA
102285	Fleming Point, 1.72 nmi SW of (depth 3 ft), San Francisco Bay, California Current	NOS	PCT0596_1	37.877	-122.35883	:America/Los_Angeles	USA	knots	259	82	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	-00:47:00	\N	0.3	-01:02:00	\N	0.2	-01:04:00	-00:24:00	Fleming Point, 1.72 nmi. SW of	CA
102286	Raccoon Strait, off Point Stuart (depth 15 ft), San Francisco Bay, California Current	NOS	PCT0606_1	37.86117	-122.452	:America/Los_Angeles	USA	knots	226	14	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	00:04:00	\N	1.2	00:08:00	\N	0.5	00:11:00	-00:02:00	Raccoon Strait, off Point Stuart	CA
102287	Bluff Point, 0.1 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0621_1	37.88333	-122.435	:America/Los_Angeles	USA	knots	147	9	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	00:50:00	\N	1.2	-00:26:00	\N	0.6	01:04:00	00:18:00	Bluff Point, 0.1 mile east of	CA
102288	Bluff Point, 1.15 nmi east of (depth 21 ft), San Francisco Bay, California Current	NOS	PCT0626_1	37.88717	-122.413	:America/Los_Angeles	USA	knots	167	336	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	00:33:00	\N	0.6	00:46:00	\N	0.4	00:55:00	00:58:00	Bluff Point, 1.15 nmi. east of	CA
102289	Southampton Shoal Light, 0.2 mi E of (depth 10 ft), San Francisco Bay, California Current	NOS	PCT0631_1	37.8825	-122.39583	:America/Los_Angeles	USA	knots	188	19	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100336	00:25:00	\N	0.7	00:55:00	\N	0.3	01:04:00	00:53:00	Southampton Shoal Light, 0.2 mile E of	CA
102290	Point Chauncey, 0.75 nmi NW of (depth 19 ft), San Francisco Bay, California Current	NOS	PCT0641_1	37.903	-122.45883	:America/Los_Angeles	USA	knots	131	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	-00:09:00	\N	0.6	-00:46:00	\N	0.7	00:08:00	00:10:00	Point Chauncey, 0.75 nmi. NW of	CA
102291	Point Richmond, 0.5 mi west of (depth 6 ft), San Francisco Bay, California Current	NOS	PCT0656_1	37.905	-122.4	:America/Los_Angeles	USA	knots	142	332	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	-00:12:00	\N	0.5	00:01:00	\N	0.5	-00:16:00	00:10:00	Point Richmond, 0.5 mile west of	CA
102292	Point Richmond, 0.8 nmi NNW of (depth 4 ft), San Francisco Bay, California Current	NOS	PCT0661_1	37.92083	-122.39667	:America/Los_Angeles	USA	knots	147	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	-02:02:00	\N	0.2	-01:55:00	\N	0.2	-00:48:00	-01:14:00	Point Richmond, 0.8 nmi. NNW of	CA
102293	Richmond (depth 7 ft), San Francisco Bay, California Current	NOS	PCT0666_1	37.929298400878906	-122.42500305175781	:America/Los_Angeles	USA	knots	150	324	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	00:04:00	\N	1.1	00:10:00	\N	1	00:16:00	-00:03:00	Richmond	CA
102294	Richmond (depth 31 ft), San Francisco Bay, California Current	NOS	PCT0666_3	37.929298400878906	-122.42500305175781	:America/Los_Angeles	USA	knots	145	333	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	-00:06:00	\N	0.8	-00:13:00	\N	1	-00:33:00	00:07:00	Richmond	CA
102295	Richmond (depth 43 ft), San Francisco Bay, California Current	NOS	PCT0666_4	37.929298400878906	-122.42500305175781	:America/Los_Angeles	USA	knots	149	330	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	-00:07:00	\N	0.7	-00:30:00	\N	0.8	-00:51:00	00:10:00	Richmond	CA
102296	Red Rock, east of (depth 11 ft), San Francisco Bay, California Current	NOS	PCT0671_1	37.9295	-122.42833	:America/Los_Angeles	USA	knots	175	318	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	00:07:00	\N	0.8	00:03:00	\N	0.8	00:06:00	00:28:00	Red Rock, east of	CA
102297	Red Rock, 0.60 nmi NNE of (depth 17 ft), San Francisco Bay, California Current	NOS	PCT0676_1	37.94	-122.42667	:America/Los_Angeles	USA	knots	155	337	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	-00:33:00	\N	0.9	-00:37:00	\N	1.1	-00:18:00	00:10:00	Red Rock, 0.60 nmi. NNE of	CA
102298	Red Rock, 0.60 nmi NNE of (depth 23 ft), San Francisco Bay, California Current	NOS	PCT0676_2	37.94	-122.42667	:America/Los_Angeles	USA	knots	145	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	-00:38:00	\N	0.8	-00:22:00	\N	1	-00:33:00	00:04:00	Red Rock, 0.60 nmi. NNE of	CA
102299	Red Rock, 0.60 nmi NNE of (depth 38 ft), San Francisco Bay, California Current	NOS	PCT0676_3	37.94	-122.42667	:America/Los_Angeles	USA	knots	145	335	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	-00:34:00	\N	0.6	-00:21:00	\N	0.9	-00:46:00	00:16:00	Red Rock, 0.60 nmi. NNE of	CA
102300	Point San Quentin, 0.82 nmi east of (depth 15 ft), San Francisco Bay, California Current	NOS	PCT0681_1	37.94117	-122.46167	:America/Los_Angeles	USA	knots	182	13	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	-00:46:00	\N	0.5	00:02:00	\N	0.4	-00:09:00	00:02:00	Point San Quentin, 0.82 nmi. east  of	CA
102301	Point San Quentin, 1.3 nmi east of (depth 23 ft), San Francisco Bay, California Current	NOS	PCT0686_1	37.94217	-122.45267	:America/Los_Angeles	USA	knots	181	5	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	00:23:00	\N	0.9	00:19:00	\N	0.8	00:20:00	00:35:00	Point San Quentin, 1.3 nmi. east of	CA
102302	Point San Quentin, 1.3 nmi east of (depth 38 ft), San Francisco Bay, California Current	NOS	PCT0686_2	37.94217	-122.45267	:America/Los_Angeles	USA	knots	186	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	00:11:00	\N	0.5	00:19:00	\N	0.6	-00:05:00	00:26:00	Point San Quentin, 1.3 nmi. east of	CA
102303	Point San Quentin, 1.9 mi east of (depth 8 ft), San Francisco Bay, California Current	NOS	PCT0691_1	37.95	-122.44	:America/Los_Angeles	USA	knots	168	14	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	00:37:00	\N	1.3	00:26:00	\N	0.9	00:52:00	00:28:00	Point San Quentin, 1.9 miles east of	CA
102304	Point San Pedro, 0.55 nmi SE of (depth 20 ft), San Pablo Bay, California Current	NOS	PCT0701_1	37.97967	-122.43667	:America/Los_Angeles	USA	knots	192	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	00:30:00	\N	1.5	00:23:00	\N	1.3	00:28:00	00:39:00	Point San Pedro, 0.55 nmi. SE of	CA
102305	Point San Pedro, 0.55 nmi SE of (depth 40 ft), San Pablo Bay, California Current	NOS	PCT0701_2	37.97967	-122.43667	:America/Los_Angeles	USA	knots	205	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	02:25:00	\N	1.2	-00:11:00	\N	1.1	00:12:00	00:37:00	Point San Pedro, 0.55 nmi. SE of	CA
102306	Point San Pedro, 0.55 nmi SE of (depth 63 ft), San Pablo Bay, California Current	NOS	PCT0701_3	37.97967	-122.43667	:America/Los_Angeles	USA	knots	236	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	00:20:00	\N	0.8	00:19:00	\N	0.7	-00:14:00	00:35:00	Point San Pedro, 0.55 nmi. SE of	CA
102470	The Narrows, Alaska Current	NOS	PCT3081_1	56.36783	-132.10267	:America/Juneau	USA	knots	45	225	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:44:00	\N	1.4	00:23:00	\N	0.9	00:31:00	00:13:00	The Narrows	AK
102307	Pinole Point, 1.18 nmi west of (depth 19 ft), San Pablo Bay, California Current	NOS	PCT0706_1	38.008	-122.38967	:America/Los_Angeles	USA	knots	218	43	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	00:06:00	\N	0.6	-00:25:00	\N	0.5	00:07:00	00:07:00	Pinole Point, 1.18 nmi. west of	CA
102308	Pinole Point, 3.0 nmi WNW of (depth 8 ft), San Pablo Bay, California Current	NOS	PCT0711_1	38.02667	-122.42467	:America/Los_Angeles	USA	knots	185	7	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	00:03:00	\N	0.5	-00:19:00	\N	0.5	00:01:00	00:05:00	Pinole Point, 3.0 nmi. WNW of	CA
102309	Pinole Point, 1.42 nmi NNW of (depth 21 ft), San Pablo Bay, California Current	NOS	PCT0721_1	38.03383	-122.37917	:America/Los_Angeles	USA	knots	233	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	01:11:00	\N	0.8	00:51:00	\N	0.7	01:09:00	00:52:00	Pinole Point, 1.42 nmi. NNW of	CA
102310	Petaluma River approach (depth 4 ft), San Pablo Bay, California Current	NOS	PCT0731_1	38.07	-122.42	:America/Los_Angeles	USA	knots	186	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	-00:06:00	\N	0.4	-00:24:00	\N	0.4	-00:01:00	-00:15:00	Petaluma River approach	CA
102311	Petaluma River entrance (depth 7 ft), San Pablo Bay, California Current	NOS	PCT0736_1	38.1105	-122.493	:America/Los_Angeles	USA	knots	95	277	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	-01:00:00	\N	0.6	00:05:00	\N	0.5	00:10:00	-00:19:00	Petaluma River entrance	CA
102312	Wilson Point, 1.55 nmi north of (depth 10 ft), San Pablo Bay, California Current	NOS	PCT0741_1	38.0375	-122.1505	:America/Los_Angeles	USA	knots	253	71	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	01:08:00	\N	0.5	00:57:00	\N	0.5	00:54:00	01:10:00	Wilson Point, 1.55 nmi. north of	CA
102313	Wilson Point, 3.90 nmi NNW of (depth 4 ft), San Pablo Bay, California Current	NOS	PCT0746_1	38.0745	-122.3425	:America/Los_Angeles	USA	knots	237	46	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99000	00:22:00	\N	0.3	-00:44:00	\N	0.3	-00:08:00	00:08:00	Wilson Point, 3.90 nmi. NNW of	CA
102314	Davis Point, midchannel (depth 8 ft), San Pablo Bay, California Current	NOS	PCT0756_1	38.06333	-122.25833	:America/Los_Angeles	USA	knots	249	91	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100442	-00:38:00	\N	0.9	-00:28:00	\N	0.7	-00:13:00	-00:17:00	Davis Point, (midchannel)	CA
102315	Mare Island Strait (Buoy 4) (depth 20 ft), Carquinez Strait, California Current	NOS	PCT0766_1	38.07417	-122.24283	:America/Los_Angeles	USA	knots	177	342	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100442	-03:07:00	\N	0.2	-01:05:00	\N	0.3	-02:25:00	-01:23:00	Mare Island Strait (Buoy "4")	CA
102316	Martinez Marina, 0.65 nmi NW of (depth 20 ft), Carquinez Strait, California Current	NOS	PCT0781_1	38.033	-122.14967	:America/Los_Angeles	USA	knots	272	91	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100442	-00:02:00	\N	0.6	-00:03:00	\N	0.7	-00:12:00	00:10:00	Martinez Marina, 0.65 nmi. NW of	CA
102317	Martinez Marina, 0.50 nmi west of (depth 30 ft), Carquinez Strait, California Current	NOS	PCT0786_1	38.02867	-122.14867	:America/Los_Angeles	USA	knots	271	89	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100442	00:11:00	\N	0.7	-00:43:00	\N	0.7	-00:37:00	00:27:00	Martinez Marina, 0.50 nmi. west of	CA
102318	Martinez Marina, 0.61 nmi NNW of (depth 23 ft), Carquinez Strait, California Current	NOS	PCT0791_1	38.03633	-122.14467	:America/Los_Angeles	USA	knots	266	85	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100442	-01:00:00	\N	0.6	-00:35:00	\N	0.5	-00:56:00	-00:13:00	Martinez Marina, 0.61 nmi. NNW of	CA
102319	Army Pt. Pier Lt. 0.2 nmi SE of (depth 21 ft), Carquinez Strait, California Current	NOS	PCT0796_1	38.03883	-122.13367	:America/Los_Angeles	USA	knots	238	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100442	00:08:00	\N	1	-00:13:00	\N	0.7	-00:07:00	-00:16:00	Army Pt. Pier Lt. 0.2 nmi. SE of	CA
102320	Army Pt. Pier Lt. 0.2 nmi SE of (depth 41 ft), Carquinez Strait, California Current	NOS	PCT0796_2	38.03883	-122.13367	:America/Los_Angeles	USA	knots	245	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100442	00:03:00	\N	0.5	00:02:00	\N	0.5	-00:37:00	-00:06:00	Army Pt. Pier Lt. 0.2 nmi. SE of	CA
102321	1 mi inside west entrance (depth 22 ft), Montezuma Slough, Suisun Bay, California Current	NOS	PCT0801_1	38.14717	-122.05633	:America/Los_Angeles	USA	knots	191	16	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	-01:41:00	\N	0.5	-00:50:00	\N	0.4	-00:25:00	-00:32:00	1 mile inside west entrance	CA
102322	West entrance (depth 6 ft), Montezuma Slough, Suisun Bay, California Current	NOS	PCT0806_1	38.132	-122.058	:America/Los_Angeles	USA	knots	315	135	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	-01:01:00	\N	1	-01:06:00	\N	0.7	-00:11:00	-00:09:00	West entrance	CA
102323	1 mi inside entrance (depth 15 ft), Suisun Slough, Suisun Bay, California Current	NOS	PCT0811_1	38.13783	-122.08133	:America/Los_Angeles	USA	knots	202	34	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	-01:41:00	\N	0.3	-01:03:00	\N	0.3	-00:55:00	-00:46:00	1 mile inside entrance	CA
102324	Entrance (depth 3 ft), Suisun Slough, Suisun Bay, California Current	NOS	PCT0816_1	38.12117	-122.0675	:America/Los_Angeles	USA	knots	110	290	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	-00:57:00	\N	0.9	-01:10:00	\N	0.6	-00:30:00	-00:39:00	Entrance	CA
102325	0.5 nmi east of entrance (depth 4 ft), Suisun Slough, Suisun Bay, California Current	NOS	PCT0821_1	38.11883	-122.05333	:America/Los_Angeles	USA	knots	156	358	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	00:08:00	\N	0.3	-01:18:00	\N	0.4	-00:22:00	-00:21:00	0.5 nmi. east of entrance	CA
102326	Avon Pier, 0.15 nmi north of (depth 30 ft), Suisun Bay, California Current	NOS	PCT0831_1	38.05167	-122.09033	:America/Los_Angeles	USA	knots	237	59	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	00:11:00	\N	0.7	00:21:00	\N	0.7	00:05:00	00:22:00	Avon Pier, 0.15 nmi. north of	CA
102327	Pt. Edith, 1.7 nmi NNW of (depth 24 ft), Suisun Bay, California Current	NOS	PCT0836_1	38.07867	-122.08383	:America/Los_Angeles	USA	knots	219	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	00:07:00	\N	0.5	00:03:00	\N	0.6	00:04:00	00:23:00	Pt. Edith, 1.7 nmi. NNW of	CA
102328	Seal Island, south of (depth 24 ft), Suisun Bay, California Current	NOS	PCT0841_1	38.05333	-122.0495	:America/Los_Angeles	USA	knots	271	69	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	00:38:00	\N	0.6	-00:03:00	\N	0.5	00:14:00	00:54:00	Seal Island, south of	CA
102329	Roe Island, Gilbert Pt., 0.15 nmi NW of (depth 16 ft), Suisun Bay, California Current	NOS	PCT0851_1	38.07367	-122.02167	:America/Los_Angeles	USA	knots	283	105	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	01:02:00	\N	0.8	00:43:00	\N	0.5	01:07:00	00:50:00	Roe Island, Gilbert Pt., 0.15 nmi. NW of	CA
102330	Suisun Cutoff (depth 24 ft), Suisun Bay, California Current	NOS	PCT0856_1	38.08883	-122.00717	:America/Los_Angeles	USA	knots	298	126	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	01:05:00	\N	0.5	01:42:00	\N	0.5	01:40:00	01:27:00	Suisun Cutoff	CA
102331	Middle Point Lt., 0.18 nmi NNW of (depth 20 ft), Suisun Bay, California Current	NOS	PCT0861_1	38.0575	-121.99283	:America/Los_Angeles	USA	knots	271	97	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	00:56:00	\N	0.8	00:11:00	\N	0.8	00:39:00	00:57:00	Middle Point Lt., 0.18 nmi. NNW of	CA
102332	Middle Point Lt., 0.18 nmi NNW of (depth 38 ft), Suisun Bay, California Current	NOS	PCT0861_2	38.0575	-121.99283	:America/Los_Angeles	USA	knots	307	130	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	01:00:00	\N	0.5	00:21:00	\N	0.7	00:29:00	00:57:00	Middle Point Lt., 0.18 nmi. NNW of	CA
102333	Stake Point, 0.9 nmi NNW of (depth 4 ft), Suisun Bay, California Current	NOS	PCT0866_1	38.06467	-121.9555	:America/Los_Angeles	USA	knots	283	77	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	00:29:00	\N	0.4	00:45:00	\N	0.4	00:13:00	00:33:00	Stake Point, 0.9 nmi. NNW of	CA
102334	Simmons Pt., Chipps Is., 0.6 nmi ESE of (depth 12 ft), Suisun Bay, California Current	NOS	PCT0871_1	38.0645	-121.92167	:America/Los_Angeles	USA	knots	279	101	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	01:02:00	\N	1.2	01:05:00	\N	0.9	01:16:00	00:56:00	Simmons Pt., Chipps Is., 0.6 nmi. ESE of	CA
102335	Simmons Pt., Chipps Is., 0.6 nmi ESE of (depth 34 ft), Suisun Bay, California Current	NOS	PCT0871_2	38.0645	-121.92167	:America/Los_Angeles	USA	knots	284	84	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	01:13:00	\N	1	01:05:00	\N	0.7	01:12:00	00:54:00	Simmons Pt., Chipps Is., 0.6 nmi. ESE of	CA
102336	Spoonbill Creek, near bridge (depth 3 ft), Suisun Bay, California Current	NOS	PCT0876_1	38.05883	-121.90467	:America/Los_Angeles	USA	knots	285	105	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	00:37:00	\N	0.9	00:16:00	\N	0.8	00:11:00	01:02:00	Spoonbill Creek, near bridge	CA
102385	Entrance, 0.6 mi WNW of Westport, Grays Harbor, Washington Current	NOS	PCT1286_1	46.91467	-124.125	:America/Los_Angeles	USA	knots	238	44	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	00:00:00	\N	0.7	00:00:00	\N	1.2	00:00:00	00:06:00	Entrance, 0.6 mile WNW of Westport	WA
102337	Montezuma Slough, east end, near bridge (depth 6 ft), Suisun Bay, California Current	NOS	PCT0881_1	38.07783	-121.88383	:America/Los_Angeles	USA	knots	315	135	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	02:23:00	\N	0.8	02:14:00	\N	0.5	02:29:00	02:08:00	Montezuma Slough, east end, near bridge	CA
102338	New York Slough, 0.6 mi E of Pt. Emmet (depth 7 ft), Suisun Bay, California Current	NOS	PCT0886_1	38.0325	-121.8695	:America/Los_Angeles	USA	knots	295	110	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	01:44:00	\N	0.9	01:15:00	\N	0.6	01:38:00	01:36:00	New York Slough, 0.6miles E of Pt. Emmet	CA
102339	New York Slough, Winter Island (depth 15 ft), Suisun Bay, California Current	NOS	PCT0891_1	38.02833	-121.84633	:America/Los_Angeles	USA	knots	302	122	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	01:11:00	\N	0.8	00:34:00	\N	0.6	01:01:00	00:45:00	New York Slough, Winter Island	CA
102340	Entrance, 0.7 mi SW of Chain Island (depth 7 ft), Suisun Bay, California Current	NOS	PCT0896_1	38.05833	-121.8705	:America/Los_Angeles	USA	knots	212	55	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	01:31:00	\N	0.9	01:22:00	\N	0.6	01:26:00	01:33:00	Entrance, 0.7 mile SW of Chain Island	CA
102341	Point Sacramento, 0.3 mi NE of (depth 7 ft), Sacramento River, California Current	NOS	PCT0901_1	38.06667	-121.83333	:America/Los_Angeles	USA	knots	286	98	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	01:07:00	\N	0.5	00:54:00	\N	0.6	01:14:00	01:22:00	Point Sacramento, 0.3 mile NE OF	CA
102342	Sherman Island East, 0.2 mi north of (depth 14 ft), Sacramento River, California Current	NOS	PCT0906_1	38.05867	-121.80417	:America/Los_Angeles	USA	knots	270	94	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	00:30:00	\N	0.8	01:01:00	\N	0.5	01:21:00	01:08:00	Sherman Island East, 0.2 mile north of	CA
102343	Sherman Island East, 0.2 mi north of (depth 25 ft), Sacramento River, California Current	NOS	PCT0906_2	38.05867	-121.80417	:America/Los_Angeles	USA	knots	274	79	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	00:56:00	\N	0.6	01:01:00	\N	0.4	02:10:00	01:08:00	Sherman Island East, 0.2 mile north of	CA
102344	Pt. San Joaquin, 0.45 nmi ENE of (depth 18 ft), San Joaquin River, California Current	NOS	PCT0911_1	38.06167	-121.85	:America/Los_Angeles	USA	knots	282	108	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	01:14:00	\N	0.8	01:26:00	\N	0.8	01:23:00	01:29:00	Pt. San Joaquin, 0.45 nmi. ENE of	CA
102345	Pt. San Joaquin, 0.45 nmi ENE of (depth 33 ft), San Joaquin River, California Current	NOS	PCT0911_2	38.06167	-121.85	:America/Los_Angeles	USA	knots	275	112	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	00:55:00	\N	0.5	01:36:00	\N	0.6	01:22:00	01:24:00	Pt. San Joaquin, 0.45 nmi. ENE of	CA
102346	Point Beenar, 0.7 nmi north of (depth 5 ft), San Joaquin River, California Current	NOS	PCT0916_1	38.04217	-121.838	:America/Los_Angeles	USA	knots	349	163	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	01:22:00	\N	0.4	01:58:00	\N	0.3	02:34:00	01:39:00	Point Beenar, 0.7 nmi. north of	CA
102347	Point Beenar, 100 yd NE of (depth 14 ft), San Joaquin River, California Current	NOS	PCT0921_1	38.0325	-121.8355	:America/Los_Angeles	USA	knots	314	137	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	02:25:00	\N	0.9	01:58:00	\N	0.5	02:34:00	02:27:00	Point Beenar, 100 yds., NE of	CA
102348	Point Beenar, 100 yd NE of (depth 22 ft), San Joaquin River, California Current	NOS	PCT0921_2	38.0325	-121.8355	:America/Los_Angeles	USA	knots	324	142	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	02:26:00	\N	0.8	01:58:00	\N	0.4	02:28:00	02:30:00	Point Beenar, 100 yds., NE of	CA
102349	Antioch Point, 0.3 mi east of, San Joaquin River, California Current	NOS	PCT0926_1	38.03333	-121.81667	:America/Los_Angeles	USA	knots	304	128	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	02:01:00	\N	1	02:22:00	\N	0.8	02:21:00	01:58:00	Antioch Point, 0.3 mile east of	CA
102350	West Island Lt., 0.5 mi SE of (depth 5 ft), San Joaquin River, California Current	NOS	PCT0931_1	38.02117	-121.762	:America/Los_Angeles	USA	knots	270	90	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	02:09:00	\N	0.5	02:13:00	\N	0.2	02:18:00	01:56:00	West Island Lt., 0.5 mile SE of	CA
102351	Vulcan Island, 0.5 mi east of (depth 17 ft), San Joaquin River, California Current	NOS	PCT0936_1	37.98533	-121.39083	:America/Los_Angeles	USA	knots	315	135	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100739	03:30:00	\N	0.3	03:23:00	\N	0.4	03:37:00	03:24:00	Vulcan Island, 0.5 mile east of	CA
102352	North Bay Channel at Fairhaven (depth 13 ft), Humboldt Bay, California Current	NOS	PCT1021_1	40.78733	-124.19433	:America/Los_Angeles	USA	knots	216	30	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98616	00:07:00	\N	1.2	00:05:00	\N	0.8	00:18:00	-00:11:00	North Bay Channel at Fairhaven	CA
102353	North Bay Channel at Samoa Channel (depth 15 ft), Humboldt Bay, California Current	NOS	PCT1026_1	40.79617	-124.18733	:America/Los_Angeles	USA	knots	196	15	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98616	00:05:00	\N	0.9	00:08:00	\N	0.8	00:14:00	00:00:00	North Bay Channel at Samoa Channel	CA
102354	Coquille River entrance, Oregon Current	NOS	PCT1056_1	43.121700286865234	-124.4197006225586	:America/Los_Angeles	USA	knots	290	91	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	-00:36:00	\N	0.43	-00:26:00	\N	0.74	-00:24:00	-00:23:00	Coquille River entrance	OR
102355	Coos Bay entrance, Oregon Current	NOS	PCT1061_1	43.35499954223633	-124.34120178222656	:America/Los_Angeles	USA	knots	280	100	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	00:20:00	\N	0.79	00:17:00	\N	0.95	00:12:00	00:22:00	Coos Bay entrance	OR
102356	Umpqua River entrance, Oregon Current	NOS	PCT1066_1	43.67829895019531	-124.19329833984375	:America/Los_Angeles	USA	knots	190	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	00:30:00	\N	0.36	00:27:00	\N	0.42	00:22:00	00:32:00	Umpqua River entrance	OR
102357	Heceta Head, Oregon Current	NOS	PCT1071_1	44.13330078125	-124.13330078125	:America/Los_Angeles	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	00:50:00	\N	0.5	00:47:00	\N	0.67	00:42:00	00:52:00	Heceta Head	OR
102358	Yaquina Bay entrance, Oregon Current	NOS	PCT1076_1	44.61669921875	-124.06670379638672	:America/Los_Angeles	USA	knots	235	50	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	-01:54:00	\N	0.8	-00:05:00	\N	1.3	-00:44:00	-00:13:00	Yaquina Bay entrance	OR
102359	Yaquina Bay, Highway Bridge, Oregon Current	NOS	PCT1081_1	44.62329864501953	-124.05699920654297	:America/Los_Angeles	USA	knots	222	44	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	-00:59:00	\N	0.8	-00:50:00	\N	1	-01:49:00	-00:40:00	Yaquina Bay, Highway Bridge	OR
102360	Yaquina, Yaquina River, Yaquina Bay, Oregon Current	NOS	PCT1086_1	44.60200119018555	-124.01129913330078	:America/Los_Angeles	USA	knots	2	184	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	-00:39:00	\N	0.4	-00:50:00	\N	0.5	-00:47:00	-00:33:00	Yaquina, Yaquina River	OR
102361	Yaquina River, 1 mi below Toledo, Yaquina Bay, Oregon Current	NOS	PCT1091_1	44.60049819946289	-123.94170379638672	:America/Los_Angeles	USA	knots	132	332	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	-00:08:00	\N	0.5	-00:13:00	\N	0.7	00:05:00	00:14:00	Yaquina River, 1 mile below Toledo	OR
102362	Tillamook Bay entrance, Oregon Current	NOS	PCT1096_1	45.562198638916016	-123.93830108642578	:America/Los_Angeles	USA	knots	305	141	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	-00:35:00	\N	0.9	00:12:00	\N	1.6	00:16:00	-00:01:00	Tillamook Bay entrance	OR
102363	Sand Island Tower, 1 nmi SE of (midchannel) (depth 15 ft), Oregon Current	NOS	PCT1106_1	46.25283	-123.99083	:America/Los_Angeles	USA	knots	275	107	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	00:07:00	\N	1.6	01:03:00	\N	1.6	01:12:00	00:38:00	Sand Island Tower, 1nm SE of (midchannel)	OR
102364	Sand Island Tower, 0.9 nmi SE of (north channel) (depth 15 ft), Oregon Current	NOS	PCT1111_1	46.25783	-123.9945	:America/Los_Angeles	USA	knots	262	92	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	-00:44:00	\N	0.7	00:33:00	\N	1.1	00:39:00	00:27:00	Sand Island Tower, 0.9nm SE of (north channel)	OR
102365	Baker Bay entrance, E of Sand Island Tower (depth 23 ft), Oregon Current	NOS	PCT1116_1	46.262	-123.998	:America/Los_Angeles	USA	knots	202	8	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	00:14:00	\N	0.3	00:08:00	\N	0.6	00:28:00	00:20:00	Baker Bay entrance, E of Sand Island Tower	OR
102366	Clatsop Spit, NNE of (depth 15 ft), Oregon Current	NOS	PCT1121_1	46.24617	-123.99417	:America/Los_Angeles	USA	knots	289	114	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	00:20:00	\N	1.1	00:56:00	\N	1.4	00:45:00	00:56:00	Clatsop Spit, NNE of	OR
102367	Sand Island, SSE of (depth 12 ft), Oregon Current	NOS	PCT1126_1	46.2555	-123.968	:America/Los_Angeles	USA	knots	265	97	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	-00:32:00	\N	0.4	-00:25:00	\N	0.3	00:18:00	-00:16:00	Sand Island, SSE of	OR
102368	Youngs Bay Bridge (depth 9 ft), Oregon Current	NOS	PCT1146_1	46.17783	-123.86833	:America/Los_Angeles	USA	knots	320	135	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	00:28:00	\N	0.3	-00:14:00	\N	0.4	00:10:00	00:50:00	Youngs Bay Bridge	OR
102369	Hammond, northeast of ship channel (depth 15 ft), Oregon Current	NOS	PCT1151_1	46.21117	-123.9345	:America/Los_Angeles	USA	knots	307	134	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	00:01:00	\N	0.6	00:24:00	\N	0.4	00:57:00	00:26:00	Hammond, northeast of ship channel	OR
102370	McGowan, SSW of (depth 14 ft), Washington Current	NOS	PCT1156_1	46.2395	-123.91533	:America/Los_Angeles	USA	knots	282	107	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	00:23:00	\N	1.6	01:14:00	\N	0.9	01:28:00	00:21:00	McGowan, SSW of	WA
102371	Point Ellice, east of (depth 17 ft), Washington Current	NOS	PCT1161_1	46.24167	-123.84833	:America/Los_Angeles	USA	knots	254	65	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	00:11:00	\N	0.9	00:25:00	\N	0.8	00:55:00	00:51:00	Point Ellice, east of	WA
102372	Point Adams, NNE of (depth 14 ft), Oregon Current	NOS	PCT1166_1	46.22783	-123.9675	:America/Los_Angeles	USA	knots	297	139	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	01:11:00	\N	0.9	00:13:00	\N	0.8	01:16:00	00:26:00	Point Adams, NNE OF	OR
102373	Chinook Point, WSW of (depth 14 ft), Oregon Current	NOS	PCT1171_1	46.24217	-123.96417	:America/Los_Angeles	USA	knots	287	117	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	-00:21:00	\N	0.9	00:25:00	\N	1.2	00:29:00	00:45:00	Chinook Point, WSW of	OR
102374	Tongue Point, northwest of (depth 15 ft), Oregon Current	NOS	PCT1176_1	46.21917	-123.76667	:America/Los_Angeles	USA	knots	249	77	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	00:46:00	\N	0.9	01:09:00	\N	0.4	02:31:00	00:24:00	Tongue Point, northwest of	OR
102375	Woody Island Channel (depth 15 ft), Washington Current	NOS	PCT1186_1	46.2395	-123.67333	:America/Los_Angeles	USA	knots	298	118	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	01:15:00	\N	0.3	01:09:00	\N	0.5	01:12:00	01:36:00	Woody Island Channel	WA
102376	Woody Island Channel (off Seal Island) (depth 12 ft), Oregon Current	NOS	PCT1191_1	46.2175	-123.62917	:America/Los_Angeles	USA	knots	247	81	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	02:53:00	\N	0.4	01:53:00	\N	0.3	02:38:00	01:25:00	Woody Island Channel (off Seal Island)	OR
102377	Quinn Island, Prairie Channel (depth 8 ft), Washington Current	NOS	PCT1201_1	46.23717	-123.50333	:America/Los_Angeles	USA	knots	281	97	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	01:53:00	\N	0.5	01:52:00	\N	0.3	03:19:00	00:55:00	Quinn Island, Prairie Channel	WA
102378	Clifton Channel (depth 10 ft), Washington Current	NOS	PCT1206_1	46.21783	-123.46533	:America/Los_Angeles	USA	knots	301	118	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	02:17:00	\N	0.4	02:27:00	\N	0.3	03:41:00	01:21:00	Clifton Channel	WA
102379	Hunting Island, south of (depth 20 ft), Washington Current	NOS	PCT1216_1	46.20717	-123.40417	:America/Los_Angeles	USA	knots	295	125	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	03:20:00	\N	0.4	02:56:00	\N	0.2	04:20:00	01:38:00	Hunting Island, south of	WA
102380	Cathlamet Channel, SE of Nassa Point (depth 19 ft), Washington Current	NOS	PCT1231_1	46.15617	-123.315	:America/Los_Angeles	USA	knots	278	103	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	05:38:00	\N	0.6	03:23:00	\N	0.1	05:16:00	01:39:00	Cathlamet Channel, SE of Nassa Point	WA
102381	Walker Island, south of (depth 12 ft), Washington Current	NOS	PCT1251_1	46.14117	-123.04583	:America/Los_Angeles	USA	knots	330	148	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	05:09:00	\N	0.4	04:15:00	\N	0.2	05:46:00	02:41:00	Walker Island, south of	WA
102382	South Bend, Willapa River, Washington Current	NOS	PCT1271_1	46.66467	-123.80133	:America/Los_Angeles	USA	knots	270	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	-00:06:00	\N	0.5	00:20:00	\N	0.6	00:19:00	00:24:00	South Bend, Willapa River	WA
102383	Entrance, 0.2 mi south of north jetty, Grays Harbor, Washington Current	NOS	PCT1276_1	46.92633	-124.16133	:America/Los_Angeles	USA	knots	243	70	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	-00:47:00	\N	0.6	00:16:00	\N	1.3	-00:28:00	00:10:00	Entrance, 0.2 mile south of north jetty	WA
102384	Entrance, Point Chehalis Range, Grays Harbor, Washington Current	NOS	PCT1281_1	46.90833	-124.1555	:America/Los_Angeles	USA	knots	268	92	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	-00:21:00	\N	1.1	-00:11:00	\N	0.9	00:08:00	-00:22:00	Entrance, Point Chehalis Range	WA
102386	Entrance, 1.1 mi NW of Westport, Grays Harbor, Washington Current	NOS	PCT1296_1	46.91667	-124.13333	:America/Los_Angeles	USA	knots	233	78	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	-00:23:00	\N	0.9	-00:06:00	\N	0.9	00:04:00	-00:05:00	Entrance, 1.1 miles NW of Westport	WA
102387	Channel, 1.5 mi north of Westport, Grays Harbor, Washington Current	NOS	PCT1301_1	46.93333	-124.1	:America/Los_Angeles	USA	knots	226	36	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	-00:25:00	\N	0.6	-00:04:00	\N	0.7	-00:22:00	-00:04:00	Channel, 1.5 miles north of Westport	WA
102388	Channel, 2.1 mi NNE of Westport, Grays Harbor, Washington Current	NOS	PCT1306_1	46.93333	-124.08333	:America/Los_Angeles	USA	knots	249	21	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	00:02:00	\N	0.5	00:00:00	\N	0.6	-00:02:00	-00:02:00	Channel, 2.1 miles NNE of Westport	WA
102389	Westport, channel 0.4 mi NE of, Grays Harbor, Washington Current	NOS	PCT1316_1	46.91417	-124.10833	:America/Los_Angeles	USA	knots	310	113	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99001	-00:36:00	\N	0.7	-00:04:00	\N	1	-00:41:00	-00:19:00	Westport, channel 0.4 mile NE of	WA
102390	Quillayute River entrance, Washington Current	NOS	PCT1321_1	47.91667	-124.63333	:America/Los_Angeles	USA	knots	345	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100333	00:00:00	\N	0.5	-00:12:00	\N	0.1	-00:12:00	00:24:00	Quillayute River entrance	WA
102391	New Dungeness Light, 6 mi NNE of (depth 15 ft), Washington Current	NOS	PCT1401_1	48.26667022705078	-123.05000305175781	:America/Los_Angeles	USA	knots	255	50	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99596	00:39:00	\N	0.57	00:46:00	\N	0.48	00:59:00	00:13:00	New Dungeness Light, 6 miles NNE of	WA
102392	Cattle Point, 2.8 mi SSW of, San Juan Channel, Washington Current	NOS	PCT1416_1	48.400001525878906	-123	:America/Los_Angeles	USA	knots	187	46	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99654	-00:08:00	\N	0.12	01:07:00	\N	0.21	-00:36:00	01:10:00	Cattle Point, 2.8 miles SSW of	WA
102393	Smith Island, 1.4 mi SSW of, Strait of Juan de Fuca, Washington Current	NOS	PCT1451_1	48.29999923706055	-122.8499984741211	:America/Los_Angeles	USA	knots	280	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99551	00:30:00	\N	0.28	00:14:00	\N	0.25	00:33:00	00:03:00	Smith Island, 1.4 miles SSW of	WA
102394	Point Partridge, 3.7 mi west of, Strait of Juan de Fuca, Washington Current	NOS	PCT1466_1	48.23332977294922	-122.86666870117188	:America/Los_Angeles	USA	knots	250	140	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99551	00:47:00	\N	0.59	00:28:00	\N	0.14	01:46:00	-00:50:00	Point Partridge, 3.7 miles west of	WA
102395	Point Wilson, 0.8 mi east of, Admiralty Inlet, Washington Current	NOS	PCT1496_1	48.150001525878906	-122.73332977294922	:America/Los_Angeles	USA	knots	280	165	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99551	-00:49:00	\N	0.74	-00:09:00	\N	0.87	-00:14:00	00:01:00	Point Wilson, 0.8 mile east of	WA
102396	Marrowstone Point, 1.1 mi northwest of, Admiralty Inlet, Washington Current	NOS	PCT1511_1	48.116668701171875	-122.69999694824219	:America/Los_Angeles	USA	knots	275	100	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99551	-01:37:00	\N	0.37	-02:09:00	\N	0.46	-02:52:00	-01:28:00	Marrowstone Point, 1.1 miles northwest of	WA
102397	Agate Passage, north end, Puget Sound, Washington Current	NOS	PCT1636_1	47.722	-122.555	:America/Los_Angeles	USA	knots	32	230	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99551	-00:54:00	\N	0.51	-00:49:00	\N	0.42	-00:49:00	-00:44:00	Agate Passage, north end	WA
102398	Off Pleasant Beach, Rich Passage, Puget Sound, Washington Current	NOS	PCT1701_1	47.58332824707031	-122.53333282470703	:America/Los_Angeles	USA	knots	132	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99551	00:48:00	\N	0.79	-00:04:00	\N	0.46	00:25:00	00:10:00	Off Pleasant Beach	WA
102399	Eld Inlet entrance (depth 15 ft), Puget Sound, Washington Current	NOS	PCT1861_1	47.146331787109375	-122.9333267211914	:America/Los_Angeles	USA	knots	28	224	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99421	-00:10:00	\N	0.31	00:10:00	\N	0.54	-00:13:00	-00:12:00	Eld Inlet entrance	WA
102400	Hammersley Inlet, west of Skookum Point (depth 15 ft), Puget Sound, Washington Current	NOS	PCT1896_1	47.207000732421875	-123.03949737548828	:America/Los_Angeles	USA	knots	101	287	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99421	01:04:00	\N	0.82	01:30:00	\N	1.01	01:05:00	01:21:00	Hammersley Inlet, west of Skookum Point	WA
102401	Iceberg Point, 2.1 mi SSW of, Rosario Strait, Washington Current	NOS	PCT1966_1	48.383331298828125	-122.91667175292969	:America/Los_Angeles	USA	knots	260	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99651	-00:37:00	\N	0.4	-00:41:00	\N	0.7	-00:44:00	00:52:00	Iceberg Point, 2.1 miles SSW of	WA
102402	Colville Island, 1 mi SSE of, Rosario Strait, Washington Current	NOS	PCT1971_1	48.400001525878906	-122.8166732788086	:America/Los_Angeles	USA	knots	235	55	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99651	-00:20:00	\N	1	-00:05:00	\N	0.7	00:09:00	00:17:00	Colville Island, 1 mile SSE of	WA
102403	Burrows Bay, 0.5 mi east of Allan I, Rosario Strait, Washington Current	NOS	PCT2006_1	48.46282958984375	-122.68283081054688	:America/Los_Angeles	USA	knots	209	22	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99651	-01:10:00	\N	0.2	-01:04:00	\N	0.6	-03:11:00	-00:07:00	Burrows Bay, 0.5 mile east of Allan I	WA
102404	Green Point, 0.8 mi northwest of, Rosario Strait, Washington Current	NOS	PCT2026_1	48.504669189453125	-122.70616912841797	:America/Los_Angeles	USA	knots	190	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99828	-01:30:00	\N	0.75	-01:11:00	\N	1.09	-00:43:00	-00:34:00	Green Point, 0.8 mile northwest of	WA
102405	Frost-Willow Island, between, Rosario Strait, Washington Current	NOS	PCT2046_1	48.53916931152344	-122.8308334350586	:America/Los_Angeles	USA	knots	126	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99651	00:02:00	\N	0.4	00:38:00	\N	0.4	00:36:00	-00:10:00	Frost-Willow Island, between	WA
102406	Barnes Island, 0.8 mi southwest of, Rosario Strait, Washington Current	NOS	PCT2071_1	48.685829162597656	-122.78883361816406	:America/Los_Angeles	USA	knots	140	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99651	-00:19:00	\N	0.4	00:44:00	\N	0.4	00:27:00	-00:36:00	Barnes Island, 0.8 mile southwest of	WA
102407	Raccoon Point, 0.6 mi NNE of, Rosario Strait, Washington Current	NOS	PCT2076_1	48.706329345703125	-122.82917022705078	:America/Los_Angeles	USA	knots	101	286	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99651	-00:47:00	\N	0.4	-01:21:00	\N	0.4	-00:46:00	-02:10:00	Raccoon Point, 0.6 mile NNE of	WA
102408	Matia Island, 0.8 mi west of, Rosario Strait, Washington Current	NOS	PCT2086_1	48.74882888793945	-122.86582946777344	:America/Los_Angeles	USA	knots	206	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99651	-00:13:00	\N	0.7	-00:10:00	\N	0.7	00:12:00	-00:55:00	Matia Island, 0.8 mile west of	WA
102409	Huckleberry Island, 0.5 mi north of, Rosario Strait, Washington Current	NOS	PCT2106_1	48.54583	-122.56633	:America/Los_Angeles	USA	knots	253	6	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99691	-01:57:00	\N	0.5	-00:47:00	\N	0.5	-03:28:00	-00:25:00	Huckleberry Island, 0.5 mile north of	WA
102410	Towhead Island, 0.4 mi east of, Rosario Strait, Washington Current	NOS	PCT2126_1	48.6121711730957	-122.7021713256836	:America/Los_Angeles	USA	knots	125	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99691	-00:46:00	\N	0.32	00:08:00	\N	0.5	-02:06:00	01:42:00	Towhead Island, 0.4 mile east of	WA
102411	Puffin Island Light, 4.8 mi north of, Rosario Strait, Washington Current	NOS	PCT2166_1	48.82217025756836	-122.8083267211914	:America/Los_Angeles	USA	knots	210	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99691	-00:36:00	\N	0.63	00:25:00	\N	0.31	00:07:00	-00:06:00	Puffin Island Light, 4.8 miles north of	WA
102412	Kings Point, Lopez Island, 1 mi NNW of (depth 15 ft), Washington Current	NOS	PCT2191_1	48.48332977294922	-122.9558334350586	:America/Los_Angeles	USA	knots	185	20	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99654	00:38:00	\N	0.37	-00:28:00	\N	0.53	00:50:00	00:47:00	Kings Point, Lopez Island, 1 mile NNW of	WA
102413	Johns Island, 0.8 mi north of, Washington Current	NOS	PCT2266_1	48.68333053588867	-123.1500015258789	:America/Los_Angeles	USA	knots	350	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99654	00:51:00	\N	0.17	-00:52:00	\N	0.21	-00:16:00	00:26:00	Johns Island, 0.8 mile north of	WA
102414	Skipjack Island, 1.5 mi northwest of (depth 15 ft), Washington Current	NOS	PCT2276_1	48.7495002746582	-123.06082916259766	:America/Los_Angeles	USA	knots	290	35	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99654	01:14:00	\N	0.39	00:58:00	\N	0.29	01:16:00	01:28:00	Skipjack Island, 1.5 miles northwest of	WA
102415	Point Hammond, 1.1 mi northwest of (depth 15 ft), Washington Current	NOS	PCT2281_1	48.731998443603516	-123.02532958984375	:America/Los_Angeles	USA	knots	255	55	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99654	01:15:00	\N	0.65	00:44:00	\N	0.22	01:10:00	00:47:00	Point Hammond, 1.1 miles northwest of	WA
102416	Alden Point, Patos Island, 2 mi S of, Rosario Strait, Washington Current	NOS	PCT2286_1	48.75783157348633	-122.98033142089844	:America/Los_Angeles	USA	knots	185	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99691	-01:40:00	\N	1.66	-01:31:00	\N	0.6	-00:02:00	-00:46:00	Alden Point, Patos Island, 2 miles S of	WA
102417	Drayton Harbor entrance, Georgia Strait, Washington Current	NOS	PCT2301_1	48.99082946777344	-122.76782989501953	:America/Los_Angeles	USA	knots	313	133	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99691	-01:08:00	\N	0.79	-01:29:00	\N	0.63	-01:01:00	-01:11:00	Drayton Harbor Entrance	WA
102418	Cape Muzon, 4 mi south from, Dixon Entrance, Alaska Current	NOS	PCT2621_1	54.6	-132.68333	:America/Juneau	USA	knots	225	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:26:00	\N	1.2	-00:47:00	\N	0.8	-00:39:00	-00:57:00	Cape Muzon, 4 miles south from	AK
102419	Point Marsh, 5 mi south from, Dixon Entrance, Alaska Current	NOS	PCT2626_1	54.63333	-132.3	:America/Juneau	USA	knots	215	35	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:26:00	\N	1.1	-00:47:00	\N	0.7	-00:39:00	-00:57:00	Point Marsh, 5 miles south from	AK
102420	West Devil Rock, 2 mi north of, Dixon Entrance, Alaska Current	NOS	PCT2636_1	54.7	-131.6	:America/Juneau	USA	knots	215	35	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:21:00	\N	1.2	-00:42:00	\N	0.8	-00:34:00	-00:52:00	West Devil Rock, 2 miles north of	AK
102421	Barren Island Light, 2 mi south from, Dixon Entrance, Alaska Current	NOS	PCT2641_1	54.7	-131.35	:America/Juneau	USA	knots	220	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:16:00	\N	1.1	-00:37:00	\N	0.7	-00:29:00	-00:47:00	Barren Island Light, 2 miles south from	AK
102422	East Devil Rock, 1 mi north of, Dixon Entrance, Alaska Current	NOS	PCT2646_1	54.7	-131.08333	:America/Juneau	USA	knots	265	85	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:44:00	\N	1.1	00:23:00	\N	0.7	00:31:00	00:13:00	East Devil Rock, 1 mile north of	AK
102423	Between Dundas Island and Cape Fox, Dixon Entrance, Alaska Current	NOS	PCT2651_1	54.7	-130.83333	:America/Juneau	USA	knots	270	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:39:00	\N	1.4	00:18:00	\N	0.6	00:14:00	00:20:00	Between Dundas Island and Cape Fox	AK
102424	Tongass Islands, east of, Nakat Bay, Dixon Entrance, Alaska Current	NOS	PCT2656_1	54.78233	-130.73717	:America/Juneau	USA	knots	157	326	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-01:31:00	\N	0.6	-02:40:00	\N	0.3	-01:31:00	-01:38:00	Tongass Islands, east of, Nakat Bay	AK
102425	Point Phipp, Pearse Canal, Alaska Current	NOS	PCT2676_1	54.78333	-130.63333	:America/Juneau	USA	knots	245	65	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:44:00	\N	1.3	00:23:00	\N	0.9	00:31:00	00:13:00	Point Phipp	AK
102426	Narrows, Pearse Canal, Alaska Current	NOS	PCT2681_1	54.83467	-130.4855	:America/Juneau	USA	knots	225	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:47:00	\N	1.3	00:26:00	\N	0.9	00:34:00	00:31:00	Narrows	AK
102427	Blaine Point, Pearse Canal, Alaska Current	NOS	PCT2686_1	55.03333	-130.21667	:America/Juneau	USA	knots	205	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	1	-00:27:00	\N	0.6	-00:19:00	-00:37:00	Blaine Point	AK
102428	Dickens Point, Portland Canal, Alaska Current	NOS	PCT2711_1	55.15	-130.15	:America/Juneau	USA	knots	200	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:54:00	\N	0.7	00:33:00	\N	0.5	00:41:00	00:23:00	Dickens Point	AK
102429	White Point, Portland Canal, Alaska Current	NOS	PCT2716_1	55.56667	-130.11667	:America/Juneau	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:59:00	\N	0.5	00:38:00	\N	0.3	00:46:00	00:28:00	White Point	AK
102430	Camp Point, Portland Canal, Alaska Current	NOS	PCT2721_1	55.28333	-129.98333	:America/Juneau	USA	knots	180	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:01:00	\N	0.6	-00:22:00	\N	0.4	-00:14:00	-00:32:00	Camp Point	AK
102431	Miners Point, Portland Canal, Alaska Current	NOS	PCT2726_1	55.71667	-130.15	:America/Juneau	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:04:00	\N	0.4	-00:17:00	\N	0.3	-00:09:00	-00:27:00	Miners Point	AK
102432	Lion Point, Portland Canal, Alaska Current	NOS	PCT2731_1	55.88333	-130.03333	:America/Juneau	USA	knots	205	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:04:00	\N	0.2	-00:17:00	\N	0.2	-00:09:00	-00:27:00	Lion Point	AK
102433	Race Point, 0.7 mi ENE of, Revillagigedo Channel, Alaska Current	NOS	PCT2761_1	55.28583	-131.546	:America/Juneau	USA	knots	300	145	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:18:00	\N	0.2	00:22:00	\N	0.2	00:49:00	00:10:00	Race Point, 0.7 mile ENE of	AK
102434	Saxman Spire, 0.2 mi south of, Tongass Narrows, Alaska Current	NOS	PCT2781_1	55.3155	-131.60267	:America/Juneau	USA	knots	110	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:12:00	\N	0.3	-02:00:00	\N	0.2	-00:32:00	-02:02:00	Saxman Spire, 0.2 mile south of	AK
102436	Hotspur Island, 0.5 mi southeast of, Felice Strait, Alaska Current	NOS	PCT2806_1	54.96667	-131.48333	:America/Juneau	USA	knots	220	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:56:00	\N	0.4	-01:29:00	\N	0.3	-00:53:00	-01:06:00	Hotspur Island, 0.5 mile southeast of	AK
102437	Point Davidson, 1 mi south of, Felice Strait, Alaska Current	NOS	PCT2811_1	54.98333	-131.6	:America/Juneau	USA	knots	240	60	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:16:00	\N	1	-00:37:00	\N	0.6	-00:29:00	-00:47:00	Point Davidson, 1 mile south of	AK
102438	Harris Island, Felice Strait, Alaska Current	NOS	PCT2816_1	55	-131.53333	:America/Juneau	USA	knots	235	55	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:16:00	\N	1.8	-00:37:00	\N	1.3	-00:29:00	-00:47:00	Harris Island	AK
102439	Ajax Reef, Felice Strait, Alaska Current	NOS	PCT2821_1	55	-131.46667	:America/Juneau	USA	knots	275	95	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:11:00	\N	1.4	-00:32:00	\N	0.9	-00:24:00	-00:42:00	Ajax Reef	AK
102440	Snipe Island, Felice Strait, Alaska Current	NOS	PCT2831_1	55	-131.38333	:America/Juneau	USA	knots	250	70	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	1.8	-00:27:00	\N	1.3	-00:19:00	-00:37:00	Snipe Island	AK
102441	Grass Rock, Tamgas Harbor entrance, Felice Strait, Alaska Current	NOS	PCT2836_1	55.02167	-131.52233	:America/Juneau	USA	knots	195	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:11:00	\N	1.2	-00:32:00	\N	0.8	-00:24:00	-00:42:00	Grass Rock, Tamgas Harbor entrance	AK
102442	Indian Reef, Felice Strait, Alaska Current	NOS	PCT2841_1	55.03333	-131.35	:America/Juneau	USA	knots	210	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	1.6	-00:27:00	\N	1.1	-00:19:00	-00:37:00	Indian Reef	AK
102443	Customhouse Cove, 1 mi west of, Felice Strait, Alaska Current	NOS	PCT2866_1	55.1	-131.26667	:America/Juneau	USA	knots	200	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	1	-00:27:00	\N	0.6	-00:19:00	-00:37:00	Customhouse Cove, 1 mile west of	AK
102444	Hid Reef, 2.7 mi south of, Nichols Passage, Alaska Current	NOS	PCT2871_1	55.03333	-131.66667	:America/Juneau	USA	knots	190	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:12:00	\N	0.2	-00:54:00	\N	0.2	-00:18:00	-00:40:00	Hid Reef, 2.7 miles south of	AK
102445	Point McCartey Light, Nichols Passage, Alaska Current	NOS	PCT2876_1	55.11667	-131.7	:America/Juneau	USA	knots	220	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:11:00	\N	1	-00:32:00	\N	0.6	-00:24:00	-00:42:00	Point McCartey Light	AK
102446	Wharburton Island, Nichols Passage, Alaska Current	NOS	PCT2891_1	55.1335	-131.62867	:America/Juneau	USA	knots	205	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:11:00	\N	1.1	-00:32:00	\N	0.7	-00:24:00	-00:42:00	Wharburton Island	AK
102447	Driest Point, Nichols Passage, Alaska Current	NOS	PCT2896_1	55.18333	-131.6	:America/Juneau	USA	knots	175	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	0.9	-00:27:00	\N	0.6	-00:19:00	-00:37:00	Driest Point	AK
102448	Blank Point, Nichols Passage, Alaska Current	NOS	PCT2911_1	55.24867	-131.66933	:America/Juneau	USA	knots	190	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:01:00	\N	1.1	-00:22:00	\N	0.7	-00:14:00	-00:32:00	Blank Point	AK
102449	Point Sykes, Behm Canal, Alaska Current	NOS	PCT2921_1	55.2	-131.11667	:America/Juneau	USA	knots	220	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Point Sykes	AK
102450	Behm Narrows, Behm Canal, Alaska Current	NOS	PCT2936_1	55.91367	-131.532	:America/Juneau	USA	knots	264	62	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-02:58:00	\N	0.6	-03:07:00	\N	0.1	-01:41:00	-03:41:00	Behm Narrows	AK
102451	Helm Point, Behm Canal, Alaska Current	NOS	PCT2941_1	55.6	-131.83333	:America/Juneau	USA	knots	210	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	0.6	-00:27:00	\N	0.4	-00:19:00	-00:37:00	Helm Point	AK
102452	Guard Islands, 2 mi northwest of, Behm Canal, Alaska Current	NOS	PCT2946_1	55.46667	-131.9	:America/Juneau	USA	knots	200	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	0.7	-00:27:00	\N	0.4	-00:19:00	-00:37:00	Guard Islands, 2 miles northwest of	AK
102471	Channel Island, north of, Alaska Current	NOS	PCT3086_1	56.37517	-132.16967	:America/Juneau	USA	knots	320	140	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:44:00	\N	1	00:23:00	\N	0.6	00:31:00	00:13:00	Channel Island, north of	AK
102453	Grass Rock, 1 mi south of, Clarence Strait, Alaska Current	NOS	PCT2961_1	55	-131.55	:America/Juneau	USA	knots	235	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:22:00	\N	0.6	-00:29:00	\N	0.2	-00:24:00	-00:02:00	Grass Rock, 1 mile south of	AK
102454	Moira Rock, 2 mi east of, Clarence Strait, Alaska Current	NOS	PCT2966_1	55.08333	-131.93333	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:11:00	\N	0.7	-00:32:00	\N	0.5	-00:24:00	-00:42:00	Moira Rock, 2 miles east of	AK
102455	Skin Island, 3 mi east from, Clarence Strait, Alaska Current	NOS	PCT2991_1	55.3	-131.98333	:America/Juneau	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	0.7	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Skin Island, 3 miles east from	AK
102456	Guard Island Lighthouse, 5.1 mi SW of, Clarence Strait, Alaska Current	NOS	PCT3011_1	55.4	-132	:America/Juneau	USA	knots	164	6	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:20:00	\N	0.3	-00:03:00	\N	0.2	00:06:00	-00:12:00	Guard Island Lighthouse, 5.1 miles SW of	AK
102457	Guard Islands, 2 mi west of, Clarence Strait, Alaska Current	NOS	PCT3016_1	55.45	-131.95	:America/Juneau	USA	knots	190	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	0.7	-00:27:00	\N	0.4	-00:19:00	-00:37:00	Guard Islands, 2 miles west of	AK
102458	Ship Island, Clarence Strait, Alaska Current	NOS	PCT3021_1	55.6	-132.25	:America/Juneau	USA	knots	155	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:01:00	\N	0.7	-00:22:00	\N	0.5	-00:14:00	-00:32:00	Ship Island	AK
102459	Narrow Point, Clarence Strait, Alaska Current	NOS	PCT3026_1	55.78333	-132.41667	:America/Juneau	USA	knots	150	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:04:00	\N	0.7	-00:17:00	\N	0.5	-00:09:00	-00:27:00	Narrow Point	AK
102460	Mabel Island, 3 mi west from, Clarence Strait, Alaska Current	NOS	PCT3031_1	55.91667	-132.5	:America/Juneau	USA	knots	150	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:14:00	\N	0.7	-00:07:00	\N	0.5	00:01:00	-00:17:00	Mabel Island, 3 miles west from	AK
102461	Lincoln Rock Light, 1 mi west from, Clarence Strait, Alaska Current	NOS	PCT3036_1	56.05	-132.71667	:America/Juneau	USA	knots	155	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:24:00	\N	0.7	00:03:00	\N	0.5	00:11:00	-00:07:00	Lincoln Rock Light, 1 mile west from	AK
102462	McHenry Ledge, 1 mi north of, Ernest Sound, Alaska Current	NOS	PCT3041_1	55.8	-132.3	:America/Juneau	USA	knots	225	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:04:00	\N	1	-00:17:00	\N	0.6	-00:09:00	-00:27:00	McHenry Ledge, 1 mile north of	AK
102463	Vixen Point, 3 mi west of, Ernest Sound, Alaska Current	NOS	PCT3046_1	55.85	-132.18333	:America/Juneau	USA	knots	245	65	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:09:00	\N	0.8	-00:12:00	\N	0.5	-00:04:00	-00:22:00	Vixen Point, 3 miles west of	AK
102464	Eaton Point, Ernest Sound, Alaska Current	NOS	PCT3051_1	55.95283	-132.09	:America/Juneau	USA	knots	195	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:14:00	\N	1	-00:07:00	\N	0.7	00:01:00	-00:17:00	Eaton Point	AK
102465	Niblack Islands, Ernest Sound, Alaska Current	NOS	PCT3056_1	56.03333	-132.08333	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	1	-00:02:00	\N	0.7	00:06:00	-00:12:00	Niblack Islands	AK
102466	Blanche Rock, Ernest Sound, Alaska Current	NOS	PCT3061_1	56.08333	-132.08333	:America/Juneau	USA	knots	215	35	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:24:00	\N	1	00:03:00	\N	0.6	00:11:00	-00:07:00	Blanche Rock	AK
102467	Point Warde, Ernest Sound, Alaska Current	NOS	PCT3066_1	56.18333	-131.96667	:America/Juneau	USA	knots	225	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:29:00	\N	1	00:08:00	\N	0.6	00:16:00	-00:02:00	Point Warde	AK
102468	Blake Island, Alaska Current	NOS	PCT3071_1	56.223	-131.90883	:America/Juneau	USA	knots	150	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:34:00	\N	1.2	00:13:00	\N	0.8	00:21:00	00:03:00	Blake Island	AK
102469	Berg Bay, Alaska Current	NOS	PCT3076_1	56.34367	-132.00767	:America/Juneau	USA	knots	155	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:39:00	\N	1.1	00:18:00	\N	0.7	00:26:00	00:08:00	Berg Bay	AK
102473	Point Highfield, Alaska Current	NOS	PCT3096_1	56.5	-132.38333	:America/Juneau	USA	knots	275	95	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	0.7	-00:02:00	\N	0.5	00:06:00	-00:12:00	Point Highfield	AK
102474	Found Island, 1 mi northwest of, Zimovia Strait, Alaska Current	NOS	PCT3101_1	56.11667	-132.1	:America/Juneau	USA	knots	140	320	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:24:00	\N	0.8	00:03:00	\N	0.5	00:11:00	-00:07:00	Found Island, 1 mile northwest of	AK
102475	No Name Island, near Thoms Place, Zimovia Strait, Alaska Current	NOS	PCT3106_1	56.15	-132.15	:America/Juneau	USA	knots	150	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:29:00	\N	0.8	00:08:00	\N	0.5	00:16:00	-00:02:00	No Name Island, near Thoms Place	AK
102476	Village Islands, Zimovia Strait, Alaska Current	NOS	PCT3111_1	56.21667	-132.31667	:America/Juneau	USA	knots	135	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:29:00	\N	0.7	00:08:00	\N	0.5	00:16:00	-00:02:00	Village Islands	AK
102477	Young Rock, 2 mi south of, Zimovia Strait, Alaska Current	NOS	PCT3116_1	56.33333	-132.38333	:America/Juneau	USA	knots	345	165	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:34:00	\N	0.8	00:13:00	\N	0.5	00:21:00	00:03:00	Young Rock, 2 miles south of	AK
102478	East Point, east of, Zimovia Strait, Alaska Current	NOS	PCT3121_1	56.38333	-132.4	:America/Juneau	USA	knots	190	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	0.8	-00:02:00	\N	0.5	00:06:00	-00:12:00	East Point, east of	AK
102479	Wrangell Harbor, 1.6 mi west of, Zimovia Strait, Alaska Current	NOS	PCT3131_1	56.46667	-132.45	:America/Juneau	USA	knots	235	50	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:33:00	\N	0.4	03:36:00	\N	0.3	02:28:00	02:16:00	Wrangell Harbor, 1.6 miles west of	AK
102480	Key Reef, Clarence Strait, Alaska Current	NOS	PCT3141_1	56.16667	-132.83333	:America/Juneau	USA	knots	190	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100056	02:33:00	\N	0.5	02:19:00	\N	0.6	01:58:00	02:08:00	Key Reef	AK
102481	Snow Passage, north entrance, Clarence Strait, Alaska Current	NOS	PCT3151_1	56.3	-133.03333	:America/Juneau	USA	knots	282	122	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100056	00:40:00	\N	1.1	-00:50:00	\N	0.6	00:08:00	00:08:00	Snow Passage, north entrance	AK
102482	Kashevarof Passage, north entrance, Clarence Strait, Alaska Current	NOS	PCT3161_1	56.25	-133.05	:America/Juneau	USA	knots	335	155	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100056	00:23:00	\N	0.7	-00:03:00	\N	0.6	00:10:00	00:35:00	Kashevarof Passage, north entrance	AK
102483	Steamer Point, 1 mi west of, Stikine Strait, Alaska Current	NOS	PCT3176_1	56.21667	-132.73333	:America/Juneau	USA	knots	220	40	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100056	02:33:00	\N	0.7	02:19:00	\N	0.8	01:58:00	02:08:00	Steamer Point, 1 mile west of	AK
102484	Round Point, Stikine Strait, Alaska Current	NOS	PCT3181_1	56.28333	-132.61667	:America/Juneau	USA	knots	195	15	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100056	02:33:00	\N	0.5	02:19:00	\N	0.6	01:58:00	02:08:00	Round Point	AK
102485	South Craig Point, Stikine Strait, Alaska Current	NOS	PCT3186_1	56.38333	-132.6	:America/Juneau	USA	knots	190	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100056	02:38:00	\N	0.7	02:24:00	\N	0.8	02:03:00	02:13:00	South Craig Point	AK
102486	Vank Island, off Neal Point, Stikine Strait, Alaska Current	NOS	PCT3191_1	56.4425	-132.59183	:America/Juneau	USA	knots	215	35	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100056	02:38:00	\N	0.7	02:24:00	\N	0.8	02:03:00	02:13:00	Vank Island, off Neal Point	AK
102487	Cape Muzon, 5 mi east of, Cordova Bay, Alaska Current	NOS	PCT3196_1	54.66667	-132.53333	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:26:00	\N	0.6	-00:47:00	\N	0.4	-00:39:00	-00:57:00	Cape Muzon, 5 miles east of	AK
102488	Dewey Rocks, 2 mi west of, Cordova Bay, Alaska Current	NOS	PCT3201_1	54.75	-132.53333	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:21:00	\N	0.5	-00:42:00	\N	0.3	-00:34:00	-00:52:00	Dewey Rocks, 2 miles west of	AK
102489	Boat Rocks, 2 mi west of, Cordova Bay, Alaska Current	NOS	PCT3211_1	54.81667	-132.56667	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:21:00	\N	0.5	-00:42:00	\N	0.3	-00:34:00	-00:52:00	Boat Rocks, 2 miles west of	AK
102490	Webster Point, 1 mi west of, Cordova Bay, Alaska Current	NOS	PCT3221_1	54.96667	-132.63333	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:16:00	\N	0.8	-00:37:00	\N	0.5	-00:29:00	-00:47:00	Webster Point, 1 mile west of	AK
102491	Mellen Rock, 1 mi east of, Cordova Bay, Alaska Current	NOS	PCT3226_1	55.03333	-132.65	:America/Juneau	USA	knots	190	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:11:00	\N	1	-00:32:00	\N	0.6	-00:24:00	-00:42:00	Mellen Rock, 1 mile east of	AK
102492	Shoe Rock, 1 mi north of, Tlevak Strait, Alaska Current	NOS	PCT3231_1	54.96667	-132.73333	:America/Juneau	USA	knots	105	285	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:16:00	\N	0.8	-00:37:00	\N	0.5	-00:29:00	-00:47:00	Shoe Rock, 1 mile north of	AK
102493	Grand Island, 2 mi north of, Tlevak Strait, Alaska Current	NOS	PCT3236_1	55	-132.86667	:America/Juneau	USA	knots	115	295	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:11:00	\N	0.7	-00:32:00	\N	0.5	-00:24:00	-00:42:00	Grand Island, 2 miles north of	AK
102494	High Point, 1 mi east of, Tlevak Strait, Alaska Current	NOS	PCT3241_1	55.01667	-132.93333	:America/Juneau	USA	knots	160	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:11:00	\N	0.9	-00:32:00	\N	0.6	-00:24:00	-00:42:00	High Point, 1 mile east of	AK
102495	McFarland Islands, Tlevak Strait, Alaska Current	NOS	PCT3246_1	55.06667	-132.95	:America/Juneau	USA	knots	160	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	0.8	-00:27:00	\N	0.5	-00:19:00	-00:37:00	McFarland Islands	AK
102496	Corlies Islands, Tlevak Strait, Alaska Current	NOS	PCT3251_1	55.13333	-132.96667	:America/Juneau	USA	knots	165	345	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	0.7	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Corlies Islands	AK
102497	Sukkwan Narrows, Tlevak Strait, Alaska Current	NOS	PCT3256_1	55.19833	-132.824	:America/Juneau	USA	knots	130	323	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:09:00	\N	0.6	-00:45:00	\N	0.4	-00:29:00	-00:20:00	Sukkwan Narrows	AK
102498	The Sentinels, 1 mi west of, Tlevak Strait, Alaska Current	NOS	PCT3261_1	55.18333	-133.01667	:America/Juneau	USA	knots	155	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	0.8	-00:27:00	\N	0.5	-00:19:00	-00:37:00	The Sentinels, 1 mile west of	AK
102499	Halibut Nose, Tlevak Strait, Alaska Current	NOS	PCT3266_1	55.21667	-133.06667	:America/Juneau	USA	knots	350	170	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100029	-00:05:00	\N	0.3	-00:06:00	\N	0.2	00:08:00	00:01:00	Halibut Nose	AK
102500	Lively Islands, west of, Tlevak Strait, Alaska Current	NOS	PCT3271_1	55.23317	-133.09233	:America/Juneau	USA	knots	355	175	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100029	-00:20:00	\N	0.7	-00:21:00	\N	0.5	-00:07:00	-00:14:00	Lively Islands, west of	AK
102501	Meares Island, south of, Meares Passage, Alaska Current	NOS	PCT3281_1	55.25783	-133.18283	:America/Juneau	USA	knots	270	90	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	1	-00:27:00	\N	0.7	-00:19:00	-00:37:00	Meares Island, south of	AK
102502	Millar Rocks, Meares Passage, Alaska Current	NOS	PCT3291_1	55.2	-133.25	:America/Juneau	USA	knots	210	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:16:00	\N	0.6	-00:37:00	\N	0.4	-00:29:00	-00:47:00	Millar Rocks	AK
102503	Diver Islands, Meares Passage, Alaska Current	NOS	PCT3296_1	55.18333	-133.28333	:America/Juneau	USA	knots	205	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:16:00	\N	0.5	-00:37:00	\N	0.3	-00:29:00	-00:47:00	Diver Islands	AK
102504	Cape Flores, Ulloa Channel, Alaska Current	NOS	PCT3301_1	55.35	-133.31667	:America/Juneau	USA	knots	330	150	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	1.1	-00:27:00	\N	0.7	-00:19:00	-00:37:00	Cape Flores	AK
102505	Waterfall Cannery, Ulloa Channel, Alaska Current	NOS	PCT3311_1	55.3	-133.25	:America/Juneau	USA	knots	335	155	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	1	-00:27:00	\N	0.6	-00:19:00	-00:37:00	Waterfall Cannery	AK
102506	Cape Bartolome, 2 mi east of, Alaska Current	NOS	PCT3316_1	55.23333	-133.55	:America/Juneau	USA	knots	200	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:16:00	\N	0.6	-00:37:00	\N	0.4	-00:29:00	-00:47:00	Cape Bartolome, 2 miles east of	AK
102507	Point Arboleda, 1 mi west of, Alaska Current	NOS	PCT3326_1	55.31667	-133.48333	:America/Juneau	USA	knots	200	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:11:00	\N	0.7	-00:32:00	\N	0.4	-00:24:00	-00:42:00	Point Arboleda, 1 mile west of	AK
102508	Cabras Islands, 1 mi west of, Alaska Current	NOS	PCT3331_1	55.35	-133.41667	:America/Juneau	USA	knots	225	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:11:00	\N	0.6	-00:32:00	\N	0.4	-00:24:00	-00:42:00	Cabras Islands, 1 mile west of	AK
102509	Cape Flores, 1 mi north of, Alaska Current	NOS	PCT3336_1	55.36667	-133.3	:America/Juneau	USA	knots	235	55	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	0.7	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Cape Flores, 1 mile north of	AK
102510	Toti Island, 1.1 mi west of, Alaska Current	NOS	PCT3346_1	55.41667	-133.15	:America/Juneau	USA	knots	250	70	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Toti Island, 1.1 miles west of	AK
102511	Coronados Islands, 2 mi west of, Alaska Current	NOS	PCT3351_1	55.43333	-133.16667	:America/Juneau	USA	knots	205	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:01:00	\N	0.5	-00:22:00	\N	0.3	-00:14:00	-00:32:00	Coronados Islands, 2 miles west of	AK
102512	Craig Cannery, Alaska Current	NOS	PCT3356_1	55.48333	-133.15	:America/Juneau	USA	knots	190	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:01:00	\N	0.5	-00:22:00	\N	0.3	-00:14:00	-00:32:00	Craig Cannery	AK
102513	Tuxekan Passage, 0.2 mi S of Tuxekan, Alaska Current	NOS	PCT3456_1	55.88267	-133.24233	:America/Juneau	USA	knots	137	323	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-03:05:00	\N	0.2	-03:32:00	\N	0.3	-03:34:00	-01:42:00	Tuxekan Passage, 0.2 mile S of Tuxekan	AK
102514	Skookumchuck Pass, El Capitan Passage, Alaska Current	NOS	PCT3476_1	55.91467	-133.31233	:America/Juneau	USA	knots	207	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:03:00	\N	1	-00:19:00	\N	0.7	-00:06:00	-00:11:00	Skookumchuck Pass	AK
102515	Brockman Island, east of, El Capitan Passage, Alaska Current	NOS	PCT3481_1	55.96683	-133.30483	:America/Juneau	USA	knots	182	351	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:31:00	\N	0.2	00:43:00	\N	0.1	00:28:00	-00:13:00	Brockman Island, east of	AK
102516	Tenass Island, 0.3 mi SSW of, El Capitan Passage, Alaska Current	NOS	PCT3491_1	55.98667	-133.30483	:America/Juneau	USA	knots	220	39	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:05:00	\N	0.3	-00:48:00	\N	0.2	00:06:00	-01:18:00	Tenass Island, 0.3 mile  SSW of	AK
102517	The Narrows, west of, Aneskett Point, El Capitan Passage, Alaska Current	NOS	PCT3506_1	56.16017	-133.338	:America/Juneau	USA	knots	248	65	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	05:37:00	\N	0.1	05:37:00	\N	0.2	04:57:00	05:54:00	The Narrows, west of	AK
102518	Cora Point, 2 mi east of, Sumner Strait, Alaska Current	NOS	PCT3521_1	55.91667	-134.05	:America/Juneau	USA	knots	200	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:21:00	\N	1	-00:42:00	\N	0.1	-00:34:00	-00:52:00	Cora Point, 2 miles east of	AK
102519	Point St. Albans, 3 mi SSE of, Sumner Strait, Alaska Current	NOS	PCT3551_1	56.03333	-133.95	:America/Juneau	USA	knots	232	78	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:28:00	\N	0.4	-01:14:00	\N	0.2	-00:05:00	-01:05:00	Point St. Albans, 3 miles SSE of	AK
102520	Point St. Albans, 4 mi east of, Sumner Strait, Alaska Current	NOS	PCT3556_1	56.08333	-133.85	:America/Juneau	USA	knots	205	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:16:00	\N	1	-00:37:00	\N	0.1	-00:29:00	-00:46:00	Point St. Albans, 4 miles east of	AK
102521	Ruins Point, 2 mi west of, Sumner Strait, Alaska Current	NOS	PCT3561_1	56.06667	-133.75	:America/Juneau	USA	knots	175	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:49:00	\N	0.3	00:38:00	\N	0.2	00:15:00	-00:48:00	Ruins Point, 2 miles west of	AK
102522	Shakan Light, 2.8 mi WNW of, Sumner Strait, Alaska Current	NOS	PCT3576_1	56.16667	-133.7	:America/Juneau	USA	knots	182	19	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:36:00	\N	0.3	-01:48:00	\N	0.2	-01:21:00	-01:34:00	Shakan Light, 2.8 miles WNW of	AK
102523	Beauclerc Island Light, 1 mi east of, Sumner Strait, Alaska Current	NOS	PCT3616_1	56.25	-133.81667	:America/Juneau	USA	knots	205	70	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-01:28:00	\N	0.4	-00:41:00	\N	0.1	00:09:00	-01:30:00	Beauclerc Island Light, 1 mile east of	AK
102524	Sumner Island, 1.8 mi south of, Sumner Strait, Alaska Current	NOS	PCT3636_1	56.36667	-133.81667	:America/Juneau	USA	knots	240	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-01:16:00	\N	0.3	-03:33:00	\N	0.3	-02:39:00	-00:54:00	Sumner Island, 1.8 miles south of	AK
102525	Blaquiere Point, 1 mi SSW of, Sumner Strait, Alaska Current	NOS	PCT3681_1	56.55	-132.56667	:America/Juneau	USA	knots	240	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:23:00	\N	0.5	00:23:00	\N	0.3	-00:08:00	-00:20:00	Blaquiere Point, 1 mile SSW of	AK
102526	Southern entrance to Keku Strait, Alaska Current	NOS	PCT3701_1	56.56667	-133.71667	:America/Juneau	USA	knots	184	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:32:00	\N	0.6	00:13:00	\N	0.3	00:57:00	-00:25:00	Southern entrance to Keku Strait	AK
102527	Eagle Island, 0.5 mi southeast of, Keku Strait, Alaska Current	NOS	PCT3706_1	56.60733	-133.68217	:America/Juneau	USA	knots	130	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:43:00	\N	1	-00:24:00	\N	0.5	-00:04:00	-00:49:00	Eagle Island, 0.5 mile southeast of	AK
102528	Devils Elbow, Keku Strait, Alaska Current	NOS	PCT3711_1	56.63617	-133.6895	:America/Juneau	USA	knots	90	285	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:13:00	\N	0.8	-00:09:00	\N	0.8	-00:18:00	-00:41:00	Devils Elbow	AK
102529	Summit Island, west of, Keku Strait, Alaska Current	NOS	PCT3716_1	56.6765	-133.7325	:America/Juneau	USA	knots	10	185	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	01:46:00	\N	1.2	01:43:00	\N	0.7	01:48:00	02:10:00	Summit Island, west of	AK
102530	High Island, 1.1 mi south of, Keku Strait, Alaska Current	NOS	PCT3721_1	56.70233	-133.733	:America/Juneau	USA	knots	10	150	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:30:00	\N	0.5	00:40:00	\N	0.3	00:40:00	00:28:00	High Island, 1.1 miles south of	AK
102531	High Island, northwest of, Keku Strait, Alaska Current	NOS	PCT3726_1	56.75	-133.73333	:America/Juneau	USA	knots	325	210	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:18:00	\N	0.4	00:49:00	\N	0.3	00:07:00	00:34:00	High Island, northwest of	AK
102532	Cucumber Reef, 0.2 mi northwest of, Keku Strait, Alaska Current	NOS	PCT3731_1	56.79	-133.767	:America/Juneau	USA	knots	325	110	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:11:00	\N	0.8	00:16:00	\N	0.4	00:11:00	00:04:00	Cucumber Reef, 0.2 mile northwest of	AK
102533	Point Alexander, Wrangell Narrows, Alaska Current	NOS	PCT3741_1	56.51033	-132.95833	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	0.5	-00:02:00	\N	0.3	00:06:00	-00:12:00	Point Alexander	AK
102534	Point Deception, Wrangell Narrows, Alaska Current	NOS	PCT3746_1	56.53333	-132.96667	:America/Juneau	USA	knots	180	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	0.5	-00:02:00	\N	0.3	00:06:00	-00:12:00	Point Deception	AK
102535	Point Lockwood, Wrangell Narrows, Alaska Current	NOS	PCT3751_1	56.55583	-132.96183	:America/Juneau	USA	knots	180	0	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	1.4	-00:02:00	\N	0.9	00:06:00	-00:12:00	Point Lockwood	AK
102536	Spike Rock, Wrangell Narrows, Alaska Current	NOS	PCT3756_1	56.601	-132.976	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	2.1	-00:02:00	\N	1.5	00:06:00	-00:12:00	Spike Rock	AK
102537	Anchor Point, Wrangell Narrows, Alaska Current	NOS	PCT3766_1	56.6395	-132.93117	:America/Juneau	USA	knots	225	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	1.6	-00:02:00	\N	1.1	00:06:00	-00:12:00	Anchor Point	AK
102538	Vexation Point, Woody Island, Wrangell Narrows, Alaska Current	NOS	PCT3771_1	56.65783	-132.927	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	1.2	-00:02:00	\N	0.8	00:06:00	-00:12:00	Vexation Point, Woody Island	AK
102539	Green Point, Wrangell Narrows, Alaska Current	NOS	PCT3781_1	56.7	-132.95	:America/Juneau	USA	knots	5	185	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:24:00	\N	0.5	00:03:00	\N	0.3	00:11:00	-00:07:00	Green Point	AK
102540	Mountain Point, Wrangell Narrows, Alaska Current	NOS	PCT3786_1	56.73333	-132.95	:America/Juneau	USA	knots	345	165	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:34:00	\N	1	00:13:00	\N	0.6	00:21:00	00:03:00	Mountain Point	AK
102541	Blunt Point, Wrangell Narrows, Alaska Current	NOS	PCT3791_1	56.77833	-132.97933	:America/Juneau	USA	knots	340	160	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:44:00	\N	1.6	00:23:00	\N	1.1	00:31:00	00:13:00	Blunt Point	AK
102542	Turn Point, Wrangell Narrows, Alaska Current	NOS	PCT3796_1	56.80783	-132.9835	:America/Juneau	USA	knots	40	220	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:44:00	\N	1.8	00:23:00	\N	1.4	00:31:00	00:13:00	Turn Point	AK
102543	Prolewy Rocks, Wrangell Narrows, Alaska Current	NOS	PCT3806_1	56.82233	-132.94833	:America/Juneau	USA	knots	60	240	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:44:00	\N	1.6	00:23:00	\N	1.1	00:31:00	00:13:00	Prolewy Rocks	AK
102544	Cosmos Point, 0.5 mi east of, Frederick Sound, Alaska Current	NOS	PCT3811_1	56.66667	-132.6	:America/Juneau	USA	knots	305	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:42:00	\N	0.2	01:15:00	\N	0.1	01:55:00	00:25:00	Cosmos Point, 0.5 mile east of	AK
102545	The Brothers, 2 mi east of, Stephens Passage, Alaska Current	NOS	PCT3826_1	57.3	-133.71667	:America/Juneau	USA	knots	205	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:24:00	\N	0.5	00:03:00	\N	0.3	00:11:00	-00:07:00	The Brothers, 2 miles east of	AK
102546	Point Gambier, 2 mi east of, Stephens Passage, Alaska Current	NOS	PCT3841_1	57.43333	-133.76667	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:29:00	\N	0.2	00:08:00	\N	0.2	00:16:00	-00:02:00	Point Gambier, 2 miles east of	AK
102547	Point Hugh, Stephens Passage, Alaska Current	NOS	PCT3846_1	57.61667	-133.76667	:America/Juneau	USA	knots	175	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:34:00	\N	0.5	00:13:00	\N	0.3	00:21:00	00:03:00	Point Hugh	AK
102548	Midway Island, Stephens Passage, Alaska Current	NOS	PCT3866_1	57.83333	-133.83333	:America/Juneau	USA	knots	155	335	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:34:00	\N	0.5	00:13:00	\N	0.3	00:21:00	00:03:00	Midway Island	AK
102549	Point Arden, Stephens Passage, Alaska Current	NOS	PCT3876_1	58.15	-134.13333	:America/Juneau	USA	knots	175	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:39:00	\N	0.5	00:18:00	\N	0.3	00:26:00	00:08:00	Point Arden	AK
102550	0.2 mi off Flat Point, Taku Inlet, Stephens Passage, Alaska Current	NOS	PCT3896_1	58.33333	-134.05	:America/Juneau	USA	knots	200	39	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:07:00	\N	0.5	00:11:00	\N	0.2	00:48:00	-00:12:00	0.2 mile off Flat Point	AK
102551	0.2 mi off Taku Point, Taku Inlet, Stephens Passage, Alaska Current	NOS	PCT3901_1	58.4	-134.01667	:America/Juneau	USA	knots	203	357	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:08:00	\N	0.4	00:34:00	\N	0.4	00:53:00	00:10:00	0.2 mile off Taku Point	AK
102552	Douglas, north of (depth 15 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3916_1	58.283	-134.39367	:America/Juneau	USA	knots	144	305	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	01:32:00	\N	0.2	00:44:00	\N	0.1	02:12:00	00:11:00	Douglas, north of	AK
102553	Douglas, north of (depth 25 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3916_2	58.283	-134.39367	:America/Juneau	USA	knots	136	302	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	01:08:00	\N	0.3	00:41:00	\N	0.1	01:33:00	00:27:00	Douglas, north of	AK
102554	Juneau Harbor, S of (depth 25 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3921_1	58.29117	-134.407	:America/Juneau	USA	knots	102	334	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	01:05:00	\N	0.3	02:03:00	\N	0.1	03:19:00	00:34:00	Juneau Harbor, S of	AK
102555	West Juneau, NE of (depth 25 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3936_1	58.29633	-134.4245	:America/Juneau	USA	knots	137	314	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	01:21:00	\N	0.2	00:49:00	\N	0.1	00:24:00	00:32:00	West Juneau, NE of	AK
102556	Aurora Basin, SW of (depth 15 ft), Gastineau Channel, Stephens Passage, Alaska Current	NOS	PCT3946_1	58.305	-134.44083	:America/Juneau	USA	knots	163	289	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:51:00	\N	0.4	00:34:00	\N	0.2	01:01:00	00:10:00	Aurora Basin, SW of	AK
102557	Point Sherman, WSW of, Lynn Canal, Alaska Current	NOS	PCT4011_1	58.84667	-135.197	:America/Juneau	USA	knots	175	341	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100319	-00:26:00	\N	0.1	-00:07:00	\N	0.3	-01:20:00	00:35:00	Point Sherman, WSW of	AK
102558	Hazy Islands, Chatham Strait, Alaska Current	NOS	PCT4056_1	55.88333	-134.6	:America/Juneau	USA	knots	205	25	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Hazy Islands	AK
102559	Cape Ommaney Light, 5 mi east of, Chatham Strait, Alaska Current	NOS	PCT4061_1	56.16667	-134.51667	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:01:00	\N	0.5	-00:22:00	\N	0.3	-00:14:00	-00:32:00	Cape Ommaney Light, 5 miles east of	AK
102560	Port Walter Light, 3 mi east of, Chatham Strait, Alaska Current	NOS	PCT4066_1	56.38333	-134.53333	:America/Juneau	USA	knots	185	5	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:04:00	\N	0.7	-00:17:00	\N	0.5	-00:09:00	-00:27:00	Port Walter Light, 3 miles east of	AK
102561	Point Ellis, 4 mi west of, Chatham Strait, Alaska Current	NOS	PCT4071_1	56.56667	-134.45	:America/Juneau	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:09:00	\N	0.7	-00:12:00	\N	0.5	-00:04:00	-00:22:00	Point Ellis, 4 miles west of	AK
102562	Kingsmill Point Light, 3 mi west of, Chatham Strait, Alaska Current	NOS	PCT4076_1	56.83333	-134.51667	:America/Juneau	USA	knots	175	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:14:00	\N	1	-00:07:00	\N	0.6	00:01:00	-00:17:00	Kingsmill Point Light, 3 miles west of	AK
102563	Point Gardner Light, 2 mi west of, Chatham Strait, Alaska Current	NOS	PCT4081_1	57.01667	-134.66667	:America/Juneau	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Point Gardner Light, 2 miles west of	AK
102564	Point Caution, 3 mi west of, Chatham Strait, Alaska Current	NOS	PCT4086_1	57.25	-134.73333	:America/Juneau	USA	knots	175	355	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:24:00	\N	1	00:03:00	\N	0.6	00:11:00	-00:07:00	Point Caution, 3 miles west of	AK
102565	Point Thatcher, 3 mi east of, Chatham Strait, Alaska Current	NOS	PCT4091_1	57.41667	-134.73333	:America/Juneau	USA	knots	160	340	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:24:00	\N	0.7	00:03:00	\N	0.5	00:11:00	-00:07:00	Point Thatcher, 3 miles east of	AK
102566	Danger Point Light, 3 mi west of, Chatham Strait, Alaska Current	NOS	PCT4101_1	57.51667	-134.7	:America/Juneau	USA	knots	170	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:29:00	\N	0.7	00:08:00	\N	0.5	00:16:00	-00:02:00	Danger Point Light, 3 miles west of	AK
102567	Turn Point, Kootznahoo Inlet, Chatham Strait, Alaska Current	NOS	PCT4106_1	57.5	-134.58333	:America/Juneau	USA	knots	285	105	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	01:09:00	\N	2.9	00:48:00	\N	2.2	00:56:00	00:38:00	Turn Point, Kootznahoo Inlet	AK
102568	South Passage Point, 3 mi east of, Chatham Strait, Alaska Current	NOS	PCT4111_1	57.76667	-134.83333	:America/Juneau	USA	knots	355	175	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:29:00	\N	0.7	00:08:00	\N	0.5	00:16:00	-00:02:00	South Passage Point, 3 miles east of	AK
102569	Point Augusta, ESE of (depth 70 ft), Chatham Strait, Alaska Current	NOS	PCT4116_1	58.025	-134.87333	:America/Juneau	USA	knots	164	344	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:54:00	\N	0.3	-00:04:00	\N	0.2	-00:02:00	00:01:00	Point Augusta, ESE of	AK
102570	Biorka Channel, Sitka Sound, Alaska Current	NOS	PCT4131_1	56.83333	-135.5	:America/Juneau	USA	knots	232	45	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:13:00	\N	0.2	00:20:00	\N	0.1	00:47:00	00:15:00	Biorka Channel	AK
102571	Sitka Harbor, channel off Harbor Island, Sitka Sound, Alaska Current	NOS	PCT4166_1	57.05	-135.33333	:America/Juneau	USA	knots	156	333	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-01:16:00	\N	0.2	-01:17:00	\N	0.1	-00:58:00	-02:02:00	Sitka Harbor, channel off Harbor Island	AK
102572	West Channel (narrows), Krestof Sound, Alaska Current	NOS	PCT4171_1	57.15	-135.58333	:America/Juneau	USA	knots	64	242	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:30:00	\N	0.5	-00:51:00	\N	0.4	-00:43:00	-01:01:00	West Channel (narrows)	AK
102573	East Channel (narrows), Krestof Sound, Alaska Current	NOS	PCT4176_1	57.16667	-135.55	:America/Juneau	USA	knots	229	51	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:23:00	\N	0.7	-00:32:00	\N	0.4	-00:30:00	-00:48:00	East Channel (narrows)	AK
102574	Allan Pt., 1.5 mi W of, Nakwasina Passage, Alaska Current	NOS	PCT4191_1	57.25	-135.43333	:America/Juneau	USA	knots	82	260	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:40:00	\N	0.8	-01:06:00	\N	0.6	-01:06:00	-00:59:00	Allan Pt., 1.5mile W of, Nakwasina Passage	AK
102575	Wyvill Reef, Neva Strait, Alaska Current	NOS	PCT4211_1	57.26667	-135.58333	:America/Juneau	USA	knots	323	150	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:13:00	\N	0.7	-00:30:00	\N	0.5	-00:27:00	-00:04:00	Wyvill Reef	AK
102576	Highwater Island, west of, Neva Strait, Alaska Current	NOS	PCT4216_1	57.28333	-135.6	:America/Juneau	USA	knots	330	144	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:34:00	\N	0.7	-00:29:00	\N	0.3	-00:15:00	-00:11:00	Highwater Island, west of	AK
102577	Sea Rock, 1 mi north of, Salisbury Sound, Alaska Current	NOS	PCT4236_1	57.35	-135.88333	:America/Juneau	USA	knots	245	65	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Sea Rock, 1 mile north of	AK
102578	Kalinin Point, 1 mi north of, Salisbury Sound, Alaska Current	NOS	PCT4241_1	57.35	-135.8	:America/Juneau	USA	knots	260	80	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	0.5	-00:27:00	\N	0.3	-00:19:00	-00:37:00	Kalinin Point, 1 mile north of	AK
102579	Sinitsin Island, Salisbury Sound, Alaska Current	NOS	PCT4246_1	57.35	-135.76667	:America/Juneau	USA	knots	275	95	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	-00:06:00	\N	0.7	-00:27:00	\N	0.5	-00:19:00	-00:37:00	Sinitsin Island	AK
102580	Point Siroi, Peril Strait, Alaska Current	NOS	PCT4266_1	57.41667	-135.58333	:America/Juneau	USA	knots	283	59	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100029	00:15:00	\N	0.4	00:11:00	\N	0.3	00:31:00	00:23:00	Point Siroi	AK
102581	Middle Point, Peril Strait, Alaska Current	NOS	PCT4271_1	57.43333	-135.58333	:America/Juneau	USA	knots	187	10	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100029	-00:06:00	\N	0.4	-00:37:00	\N	0.2	-00:09:00	-00:35:00	Middle Point	AK
102582	Otstoia Island Light, 1 mi north of, Peril Strait, Alaska Current	NOS	PCT4286_1	57.58333	-135.45	:America/Juneau	USA	knots	100	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Otstoia Island Light, 1 mile north of	AK
102583	Nismeni Point, 1 mi north of, Peril Strait, Alaska Current	NOS	PCT4291_1	57.58333	-135.41667	:America/Juneau	USA	knots	105	285	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Nismeni Point, 1 mile north of	AK
102584	Peschani Point, 1 mi east of, Peril Strait, Alaska Current	NOS	PCT4296_1	57.53333	-135.3	:America/Juneau	USA	knots	145	325	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Peschani Point, 1 mile east of	AK
102585	Point Elizabeth, 1 mi northeast of, Peril Strait, Alaska Current	NOS	PCT4301_1	57.51667	-135.26667	:America/Juneau	USA	knots	135	315	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Point Elizabeth, 1 mile northeast of	AK
102586	Point Benham, 1 mi east of, Peril Strait, Alaska Current	NOS	PCT4306_1	57.48333	-135.18333	:America/Juneau	USA	knots	130	310	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Point Benham, 1 mile east of	AK
102587	False Linderberg Head, 1 mi south of, Peril Strait, Alaska Current	NOS	PCT4311_1	57.45	-135.08333	:America/Juneau	USA	knots	125	305	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	False Linderberg Head, 1 mile south of	AK
102588	Lindenberg Head, Peril Strait, Alaska Current	NOS	PCT4316_1	57.45	-135.03333	:America/Juneau	USA	knots	100	280	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:19:00	\N	1	-00:02:00	\N	0.6	00:06:00	-00:12:00	Lindenberg Head	AK
102589	Eva Islands, Peril Strait, Alaska Current	NOS	PCT4321_1	57.45	-134.93333	:America/Juneau	USA	knots	95	275	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:24:00	\N	0.6	00:03:00	\N	0.4	00:11:00	-00:07:00	Eva Islands	AK
102590	Fairway Island, Peril Strait, Alaska Current	NOS	PCT4326_1	57.45	-134.88333	:America/Juneau	USA	knots	85	265	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:24:00	\N	1	00:03:00	\N	0.6	00:11:00	-00:07:00	Fairway Island	AK
102591	Morris Reef, south of, Peril Strait, Alaska Current	NOS	PCT4331_1	57.45	-134.81667	:America/Juneau	USA	knots	95	275	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:24:00	\N	0.7	00:03:00	\N	0.5	00:11:00	-00:07:00	Morris Reef, south of	AK
102592	North Inian Pass, middle, Cross Sound, Alaska Current	NOS	PCT4361_1	58.28329849243164	-136.38330078125	:America/Juneau	USA	knots	260	75	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100319	-00:51:00	\N	2.3	00:15:00	\N	2.9	-00:22:00	-00:37:00	North Inian Pass, middle	AK
102593	Claybluff Point Light, 3.5 nmi south of (depth 75 ft), Icy Bay, Alaska Current	NOS	PCT4406_1	59.91	-141.595	:America/Anchorage	USA	knots	209	104	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-03:20:00	\N	0.2	-02:09:00	\N	0.2	-03:02:00	-03:14:00	Claybluff Point Light, 3.5 nmi. south of	AK
102594	Claybluff Point Light, 2.3 nmi SE of (depth 206 ft), Icy Bay, Alaska Current	NOS	PCT4411_1	59.94667	-141.52	:America/Anchorage	USA	knots	215	30	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-03:14:00	\N	0.1	-02:44:00	\N	0.1	-03:10:00	-03:17:00	Claybluff Point Light, 2.3 nmi. SE of	AK
102595	Carson Creek entrance, 1.4 nmi ESE of (depth 15 ft), Icy Bay, Alaska Current	NOS	PCT4416_1	59.98333	-141.47	:America/Anchorage	USA	knots	164	71	IGNORE VELOCITIES	Velocities for this station should be disregarded--use times only.	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-02:09:00	\N	0.001	-00:36:00	\N	0.2	-04:48:00	-00:20:00	Carson Creek Entrance, 1.4 nmi. ESE of	AK
102596	Carson Creek entrance, 3.3 nmi SE of (depth 78 ft), Icy Bay, Alaska Current	NOS	PCT4421_1	59.97	-141.41333	:America/Anchorage	USA	knots	232	67	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-02:03:00	\N	0.2	-01:45:00	\N	0.3	-02:49:00	-01:03:00	Carson Creek Entrance, 3.3 nmi. SE of	AK
102597	Carson Creek entrance, 2.4 nmi ESE of (depth 50 ft), Icy Bay, Alaska Current	NOS	PCT4426_1	59.98667	-141.43667	:America/Anchorage	USA	knots	244	54	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-02:06:00	\N	0.3	-01:38:00	\N	0.2	-03:00:00	-02:24:00	Carson Creek Entrance, 2.4 nmi. ESE of	AK
102598	Wingham Island, off northeast corner, Controller Bay, Alaska Current	NOS	PCT4436_1	60.05	-144.38333	:America/Anchorage	USA	knots	288	68	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	01:06:00	\N	0.6	01:11:00	\N	0.5	00:42:00	00:46:00	Wingham Island, off northeast corner	AK
102599	Kanak Island, southeast of, Controller Bay, Alaska Current	NOS	PCT4441_1	60.08333	-144.3	:America/Anchorage	USA	knots	255	67	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100023	00:53:00	\N	1	00:37:00	\N	0.5	00:58:00	00:38:00	Kanak Island, southeast of	AK
102600	Cape Hinchinbrook, SW of, Hinchinbrook I (depth 20 ft), Alaska Current	NOS	PCT4466_1	60.18667	-146.74833	:America/Anchorage	USA	knots	180	317	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99942	00:33:00	\N	1.4	-01:12:00	\N	0.6	00:10:00	-00:58:00	Cape Hinchinbrook, SW of, Hinchinbrook I	AK
102601	Bear Cape and Zaikof Point, between (depth 70 ft), Prince William Sound, Alaska Current	NOS	PCT4471_1	60.31167	-146.81333	:America/Anchorage	USA	knots	162	352	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99942	-00:30:00	\N	1.8	00:39:00	\N	0.6	01:30:00	-01:01:00	Bear Cape and Zaikof Point, between	AK
102602	Montague Strait, NW of Pt. Woodcock (depth 70 ft), Prince William Sound, Alaska Current	NOS	PCT4506_1	59.94783	-147.86117	:America/Anchorage	USA	knots	223	38	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99942	00:35:00	\N	0.9	-00:17:00	\N	0.5	00:53:00	-00:40:00	Montague Strait, NW of Pt. Woodcock	AK
102603	Bainbridge Passage (mid-passage) (depth 21 ft), Prince William Sound, Alaska Current	NOS	PCT4546_1	60.12667	-148.20383	:America/Anchorage	USA	knots	208	52	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99942	-01:19:00	\N	2.7	-01:48:00	\N	2.4	-00:40:00	-02:10:00	Bainbridge Passage (mid-passage)	AK
102604	Johnston Point, 7 nmi northwest of (depth 71 ft), Prince William Sound, Alaska Current	NOS	PCT4596_1	60.55167	-146.78333	:America/Anchorage	USA	knots	204	14	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99942	-00:18:00	\N	0.7	-01:29:00	\N	0.2	00:54:00	-03:35:00	Johnston Point, 7 nmi. northwest of	AK
102605	Salmo Point, Hawkins I., 1.2 mi SE of, Orca Bay, Alaska Current	NOS	PCT4811_1	60.6	-145.75	:America/Anchorage	USA	knots	20	160	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99942	00:30:00	\N	0.5	00:55:00	\N	0.3	00:34:00	00:58:00	Salmo Point, Hawkins I., 1.2 miles SE of	AK
102606	Cape Douglas, northeast of (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4831_1	58.94083	-152.89	:America/Anchorage	USA	knots	167	312	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98300	00:21:00	\N	0.2	00:08:00	\N	0.2	00:36:00	00:09:00	Cape Douglas, northeast of	AK
102607	Ushagat Island, northwest of (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4841_1	59.00617	-152.56333	:America/Anchorage	USA	knots	117	283	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98300	00:20:00	\N	0.3	-00:02:00	\N	0.2	00:17:00	00:32:00	Ushagat Island, northwest of	AK
102608	Ushagat Island, north of (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4846_1	59.08333	-152.255	:America/Anchorage	USA	knots	121	292	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98300	00:26:00	\N	0.5	00:44:00	\N	0.9	-00:18:00	01:26:00	Ushagat Island, north of	AK
102609	Augustine Island, northwest of (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4886_1	59.40833	-153.62033	:America/Anchorage	USA	knots	229	60	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98300	03:42:00	\N	0.6	03:08:00	\N	0.3	03:13:00	02:40:00	Augustine Island, northwest of	AK
102610	Chinitna Point, southeast of (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4896_1	59.57167	-152.825	:America/Anchorage	USA	knots	209	21	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98300	01:54:00	\N	0.8	01:55:00	\N	0.7	01:51:00	02:11:00	Chinitna Point, southeast of	AK
102611	Iniskin Bay, Cook Inlet, Alaska Current	NOS	PCT4916_1	59.66667	-153.45	:America/Anchorage	USA	knots	179	358	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98300	-00:29:00	\N	0.7	-00:32:00	\N	0.5	-00:32:00	-00:21:00	Iniskin Bay	AK
102612	Kachemak Bay entrance (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4926_1	59.555	-151.79667	:America/Anchorage	USA	knots	210	35	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98300	00:00:00	\N	0.4	-00:11:00	\N	0.3	00:37:00	-00:22:00	Kachemak Bay Entrance	AK
102613	Kachemak Bay, west of (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4931_1	59.56667	-152.27167	:America/Anchorage	USA	knots	188	10	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98300	01:01:00	\N	1	00:46:00	\N	0.9	01:01:00	01:08:00	Kachemak Bay, west of	AK
102614	Anchor Point, 5 mi northwest of (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4941_1	59.85167	-152.00833	:America/Anchorage	USA	knots	198	22	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98315	-00:35:00	\N	0.5	-01:04:00	\N	0.6	-01:09:00	-00:50:00	Anchor Point, 5 miles northwest of	AK
102615	Anchor Point, WNW of (depth 22 ft), Cook Inlet, Alaska Current	NOS	PCT4946_1	59.85917	-152.205	:America/Anchorage	USA	knots	197	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98315	-00:04:00	\N	0.6	-00:49:00	\N	0.6	-00:39:00	-00:40:00	Anchor Point, WNW of	AK
102616	Cape Starichkof, northwest of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT4956_1	59.9675	-151.95083	:America/Anchorage	USA	knots	199	19	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98315	-00:36:00	\N	0.6	-01:22:00	\N	0.5	-00:47:00	-01:02:00	Cape Starichkof, northwest of	AK
102617	Chisik Island, 5 nmi east of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT4966_1	60.12667	-152.40167	:America/Anchorage	USA	knots	197	17	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98315	-00:11:00	\N	0.5	-01:01:00	\N	0.5	-00:50:00	-00:44:00	Chisik Island, 5 nmi. east of	AK
102618	Tuxedni Channel (south entrance) (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT4971_1	60.09667	-152.57417	:America/Anchorage	USA	knots	150	331	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98315	-01:41:00	\N	0.3	-01:30:00	\N	0.5	-01:35:00	-01:35:00	Tuxedni Channel (South Entrance)	AK
102619	Ninilchik Harbor, northwest of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT4976_1	60.13333	-151.93417	:America/Anchorage	USA	knots	212	29	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98315	-00:18:00	\N	0.8	-00:10:00	\N	0.6	-00:05:00	-00:19:00	Ninilchik Harbor, northwest of	AK
102620	Redoubt Point, southeast of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT4981_1	60.23167	-152.26417	:America/Anchorage	USA	knots	198	25	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98315	00:07:00	\N	0.6	-00:06:00	\N	0.5	-00:11:00	-00:10:00	Redoubt Point, southeast of	AK
102621	Cape Kasilof, 3 mi west of, Cook Inlet, Alaska Current	NOS	PCT5006_1	60.36667	-151.46667	:America/Anchorage	USA	knots	206	22	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98315	-00:41:00	\N	0.5	-01:47:00	\N	0.7	-01:27:00	-00:10:00	Cape Kasilof, 3 miles west of	AK
102622	Kenai, 6 mi southwest of, Cook Inlet, Alaska Current	NOS	PCT5011_1	60.48333	-151.43333	:America/Anchorage	USA	knots	193	21	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98315	-00:39:00	\N	0.6	-01:03:00	\N	0.6	-00:25:00	-00:23:00	Kenai, 6 miles southwest of	AK
102623	Kenai City Wharf, Cook Inlet, Alaska Current	NOS	PCT5016_1	60.55	-151.23333	:America/Anchorage	USA	knots	300	130	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98315	-00:56:00	\N	0.3	-01:45:00	\N	0.1	-01:18:00	-02:24:00	Kenai City Wharf	AK
102624	West Foreland, 1 nmi east of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5046_1	60.73917	-151.64167	:America/Anchorage	USA	knots	171	349	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98315	01:17:00	\N	1	-00:15:00	\N	0.9	00:54:00	00:07:00	West Foreland, 1 nmi. east of	AK
102625	East Foreland, 1.5 nmi west of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5056_1	60.72333	-151.46667	:America/Anchorage	USA	knots	195	6	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98315	00:20:00	\N	0.8	00:09:00	\N	0.7	00:24:00	00:19:00	East Foreland, 1.5 nmi. west of	AK
102626	Middle Ground Shoal, southeast of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5066_1	60.84583	-151.33667	:America/Anchorage	USA	knots	231	63	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98315	00:37:00	\N	1	-00:08:00	\N	0.8	00:45:00	00:05:00	Middle Ground Shoal, southeast of	AK
102627	North Foreland, southeast of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5071_1	61.00333	-151.07833	:America/Anchorage	USA	knots	221	62	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98284	-00:10:00	\N	0.7	-00:24:00	\N	0.7	-00:49:00	-00:41:00	North Foreland, southeast of	AK
102628	Moose Point, NNW of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5076_1	61.01583	-150.7	:America/Anchorage	USA	knots	237	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98284	-00:54:00	\N	0.5	-01:17:00	\N	0.6	-00:46:00	-00:46:00	Moose Point, NNW of	AK
102629	Moose Point, northwest of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5081_1	61.0775	-150.75	:America/Anchorage	USA	knots	255	86	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98284	-00:10:00	\N	0.5	-01:06:00	\N	0.6	-00:33:00	-00:35:00	Moose Point, northwest of	AK
102630	Point Possession, WNW of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5091_1	61.05	-150.46167	:America/Anchorage	USA	knots	246	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98284	-00:43:00	\N	0.6	-01:01:00	\N	0.7	-00:34:00	-00:27:00	Point Possession, WNW of	AK
102631	Point Possession, northwest of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5096_1	61.0875	-150.47167	:America/Anchorage	USA	knots	255	87	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98284	-00:57:00	\N	0.5	-00:31:00	\N	0.7	-00:22:00	-00:05:00	Point Possession, northwest of	AK
102632	Fire Island, west of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5111_1	61.1625	-150.5125	:America/Anchorage	USA	knots	258	93	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98284	00:14:00	\N	0.7	00:12:00	\N	0.8	00:05:00	00:21:00	Fire Island, west of	AK
102633	Point Woronzof, southwest of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5126_1	61.18717	-150.0625	:America/Anchorage	USA	knots	225	57	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98284	02:20:00	\N	0.3	-00:23:00	\N	0.6	00:15:00	00:31:00	Point Woronzof, southwest of	AK
102634	Point Woronzof, west of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5131_1	61.207	-150.06117	:America/Anchorage	USA	knots	225	61	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98284	-00:24:00	\N	0.6	-00:32:00	\N	0.6	00:11:00	00:26:00	Point Woronzof, west of	AK
102635	Anchorage, west of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5141_1	61.22783	-149.94833	:America/Anchorage	USA	knots	234	81	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98284	-00:20:00	\N	0.6	-00:09:00	\N	0.8	00:25:00	00:42:00	Anchorage, west of	AK
102636	Anchorage, 0.2 mi offshore (depth 15 ft), Cook Inlet, Alaska Current	NOS	PCT5146_1	61.225	-149.90633	:America/Anchorage	USA	knots	207	28	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98284	-01:22:00	\N	0.5	-00:55:00	\N	0.3	-02:59:00	-01:05:00	Anchorage, 0.2 mile offshore	AK
102637	Anchorage Shipdock, northwest of (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5151_1	61.24583	-149.90833	:America/Anchorage	USA	knots	195	28	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98284	-00:28:00	\N	0.8	00:16:00	\N	0.9	00:41:00	00:43:00	Anchorage Shipdock, northwest of	AK
102638	Cairn Point, northwest of (east side) (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5161_1	61.26717	-149.90083	:America/Anchorage	USA	knots	192	359	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98284	00:07:00	\N	0.8	00:35:00	\N	0.7	00:38:00	00:38:00	Cairn Point, northwest of (east side)	AK
102639	Cairn Point, northwest of (west side) (depth 20 ft), Cook Inlet, Alaska Current	NOS	PCT5166_1	61.26717	-149.89333	:America/Anchorage	USA	knots	198	18	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98284	-00:35:00	\N	0.7	00:24:00	\N	0.8	00:36:00	00:39:00	Cairn Point, northwest of (west side)	AK
102640	Knik Arm Mud Flats, south of (depth 10 ft), Cook Inlet, Alaska Current	NOS	PCT5186_1	61.33167	-149.79367	:America/Anchorage	USA	knots	241	74	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	98284	-00:26:00	\N	0.6	-00:18:00	\N	0.6	00:48:00	-00:02:00	Knik Arm Mud Flats, south of	AK
102641	Popof Strait, Shumagin Islands, Alaska Current	NOS	PCT5406_1	55.33333	-160.51667	:America/Anchorage	USA	knots	199	357	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-02:11:00	\N	0.2	-02:05:00	\N	0.1	-02:32:00	-01:28:00	Popof Strait	AK
102642	Unga Strait (1.4 mi N of Unga Spit), Shumagin Islands, Alaska Current	NOS	PCT5411_1	55.43333	-160.73333	:America/Anchorage	USA	knots	114	282	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	05:06:00	\N	0.1	05:42:00	\N	0.5	05:24:00	05:24:00	Unga Strait (1.4 miles N of Unga Spit)	AK
102643	Amak Island, 5 mi north of, Alaska Current	NOS	PCT5426_1	55.5	-163.1667022705078	:America/Nome	USA	knots	139	337	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100578	05:09:00	\N	0.23	05:30:00	\N	0.21	05:04:00	05:02:00	Amak Island, 5 miles north of	AK
102644	Amak Island, 5 mi southeast of, Alaska Current	NOS	PCT5431_1	55.349998474121094	-163.01669311523438	:America/Nome	USA	knots	200	350	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100578	04:35:00	\N	0.23	04:45:00	\N	0.21	04:36:00	04:22:00	Amak Island, 5 miles southeast of	AK
102645	Otter Point, off of, north side (depth 15 ft), Unimak Island, Alaska Current	NOS	PCT5441_1	55.06669998168945	-163.78329467773438	:America/Nome	USA	knots	258	89	\N	\N	Depth is as provided in the stations list.\nDepth is below surface.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100578	03:53:00	\N	0.27	03:36:00	\N	0.24	03:48:00	03:25:00	Otter Point, off of, north side	AK
102646	Bechevin Bay, off Rocky Point, Isanotski Strait, Alaska Current	NOS	PCT5451_1	54.983299255371094	-163.4333038330078	:America/Nome	USA	knots	139	331	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100578	00:02:00	\N	0.46	-00:26:00	\N	0.47	-00:53:00	00:04:00	Bechevin Bay, off Rocky Point	AK
102647	Unimak Pass, 2.4 mi N of Tanginak I, Aleutian Islands, Alaska Current	NOS	PCT5481_1	54.23333	-165.3	:America/Nome	USA	knots	144	298	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100517	-00:38:00	\N	0.6	-00:10:00	\N	0.5	00:27:00	-01:13:00	Unimak Pass, 2.4 miles N of Tanginak I	AK
102648	Ugamak Strait (north end), Aleutian Islands, Alaska Current	NOS	PCT5511_1	54.2	-164.91667	:America/Nome	USA	knots	122	322	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100517	00:22:00	\N	0.8	00:12:00	\N	1.3	00:39:00	00:45:00	Ugamak Strait (North end)	AK
102649	Umnak Pass, south approach, Aleutian Islands, Alaska Current	NOS	PCT5546_1	53.25	-167.91667	:America/Nome	USA	knots	181	341	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	00:54:00	\N	1.2	-00:15:00	\N	0.4	00:25:00	00:04:00	Umnak Pass, south approach	AK
102650	Umnak Pass, northwest of Ship Rock, Aleutian Islands, Alaska Current	NOS	PCT5561_1	53.38333	-167.85	:America/Nome	USA	knots	218	52	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	00:00:00	\N	1.3	-00:14:00	\N	0.7	01:04:00	-00:01:00	Umnak Pass, northwest of Ship Rock	AK
102651	Fenimore Rock, 1.2 mi southwest of, Aleutian Islands, Alaska Current	NOS	PCT5611_1	51.96667	-175.56667	:America/Adak	USA	knots	140	10	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	00:10:00	\N	1.2	-00:06:00	\N	0.6	00:47:00	-00:50:00	Fenimore Rock, 1.2 miles southwest of	AK
102652	Igitkin Pass, 0.8 mi N of Tanager Pt, Aleutian Islands, Alaska Current	NOS	PCT5616_1	51.95	-175.86667	:America/Adak	USA	knots	245	40	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	00:19:00	\N	0.8	00:35:00	\N	0.6	01:40:00	00:02:00	Igitkin Pass, 0.8 mile N of Tanager Pt	AK
102653	Chugul Pass, 0.8 mi SW of Tanager Pt, Aleutian Islands, Alaska Current	NOS	PCT5621_1	51.93333	-175.88333	:America/Adak	USA	knots	160	325	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	-00:09:00	\N	0.6	-00:08:00	\N	0.3	-00:42:00	00:39:00	Chugul Pass, 0.8 mile SW of Tanager Pt	AK
102654	Chugul Pass, 2 mi NE of Cape Ruin, Aleutian Islands, Alaska Current	NOS	PCT5626_1	51.93333	-175.93333	:America/Adak	USA	knots	150	335	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	00:59:00	\N	0.6	01:37:00	\N	0.3	02:33:00	00:33:00	Chugul Pass, 2 miles NE of Cape Ruin	AK
102655	Chugul Pass, 0.5 mi NE of Cape Ruin, Aleutian Islands, Alaska Current	NOS	PCT5631_1	51.91667	-175.96667	:America/Adak	USA	knots	120	305	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	01:12:00	\N	0.7	00:34:00	\N	0.2	00:51:00	01:09:00	Chugul Pass, 0.5 mile NE of Cape Ruin	AK
102656	Umak Pass, off Narrows Point, Aleutian Islands, Alaska Current	NOS	PCT5636_1	51.85	-176.06667	:America/Adak	USA	knots	130	305	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	00:17:00	\N	0.9	00:19:00	\N	0.6	00:44:00	00:29:00	Umak Pass, off Narrows Point	AK
102657	Little Tanaga Strait, off Tana Pt, Aleutian Islands, Alaska Current	NOS	PCT5641_1	51.81667	-176.23333	:America/Adak	USA	knots	130	320	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	00:20:00	\N	1.2	00:04:00	\N	0.5	00:21:00	00:15:00	Little Tanaga Strait, off Tana Pt	AK
102658	Kagalaska Strait, off Galas Point, Aleutian Islands, Alaska Current	NOS	PCT5646_1	51.8	-176.41667	:America/Adak	USA	knots	175	310	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	00:56:00	\N	1.1	-00:01:00	\N	0.8	-00:11:00	00:41:00	Kagalaska Strait, off Galas Point	AK
102659	Adak Strait, 4 mi ENE of Naga Point, Aleutian Islands, Alaska Current	NOS	PCT5656_1	51.78333	-177	:America/Adak	USA	knots	195	10	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	02:01:00	\N	0.7	01:16:00	\N	0.4	01:09:00	00:43:00	Adak Strait, 4 miles ENE of Naga Point	AK
102660	Adak Strait, off Argonne Point, Aleutian Islands, Alaska Current	NOS	PCT5661_1	51.8	-176.95	:America/Adak	USA	knots	200	10	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	-00:40:00	\N	0.6	01:02:00	\N	0.5	-01:49:00	-00:05:00	Adak Strait, off Argonne Point	AK
102661	Kanaga Pass, 0.3 mi NW of Annoy Rock, Aleutian Islands, Alaska Current	NOS	PCT5666_1	51.71667	-177.8	:America/Adak	USA	knots	195	0	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	01:11:00	\N	0.9	02:38:00	\N	0.5	02:30:00	00:42:00	Kanaga Pass, 0.3 mile NW of Annoy Rock	AK
102662	Kanaga Pass, 2.2 mi NE of Annoy Rock, Aleutian Islands, Alaska Current	NOS	PCT5671_1	51.75	-177.75	:America/Adak	USA	knots	225	20	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	00:32:00	\N	0.9	02:16:00	\N	0.5	02:07:00	00:19:00	Kanaga Pass, 2.2 miles NE of Annoy Rock	AK
102663	Ogliuga Island, pass east of, Delarof Is, Aleutian Islands, Alaska Current	NOS	PCT5681_1	51.61667	-178.6	:America/Adak	USA	knots	220	36	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	-00:10:00	\N	0.2	-00:26:00	\N	0.1	-00:16:00	-00:56:00	Ogliuga Island, pass East of, Delarof Is	AK
102664	Ulak Pass, Delarof Islands, Aleutian Islands, Alaska Current	NOS	PCT5691_1	51.31667	-179.03333	:America/Adak	USA	knots	125	326	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	01:30:00	\N	0.9	01:40:00	\N	0.5	02:03:00	01:25:00	Ulak Pass, Delarof Islands	AK
102665	Krysi Pass, Rat Islands, Aleutian Islands, Alaska Current	NOS	PCT5721_1	51.85	178.11667	:America/Adak	USA	knots	210	40	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	01:28:00	\N	0.9	01:38:00	\N	0.5	02:06:00	00:57:00	Krysi Pass, Rat Islands	AK
102666	Sea Lion Pass, Rat Islands, Aleutian Islands, Alaska Current	NOS	PCT5726_1	51.9	177.9	:America/Adak	USA	knots	195	12	\N	Reference is in time zone :America/Nome; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	100541	01:45:00	\N	0.9	01:45:00	\N	0.5	02:09:00	00:53:00	Sea Lion Pass, Rat Islands	AK
102667	Cape Lieskof, 3 mi west of, Aleutian Islands, Alaska Current	NOS	PCT5741_1	55.75	-162.2	:America/Nome	USA	knots	248	56	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-04:53:00	\N	0.3	-04:39:00	\N	0.3	-05:39:00	-04:38:00	Cape Lieskof, 3 miles west of	AK
102668	Entrance Point, 3 mi west of, Port Moller, Alaska Current	NOS	PCT5746_1	56	-160.65	:America/Anchorage	USA	knots	2	174	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-04:34:00	\N	0.8	-04:28:00	\N	0.7	-05:04:00	-04:06:00	Entrance Point, 3 miles west of	AK
102669	Entrance Point, Port Moller, Alaska Current	NOS	PCT5751_1	55.98333	-160.58333	:America/Anchorage	USA	knots	0	180	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-05:27:00	\N	0.6	-04:53:00	\N	0.5	-04:57:00	-05:06:00	Entrance Point	AK
102670	Harbor Point, Port Moller, Alaska Current	NOS	PCT5756_1	55.91667	-160.6	:America/Anchorage	USA	knots	335	158	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-04:26:00	\N	0.8	-04:03:00	\N	0.4	-04:28:00	-04:59:00	Harbor Point	AK
102671	Hague Channel, east of Doe Point, Alaska Current	NOS	PCT5761_1	55.9	-160.76667	:America/Anchorage	USA	knots	33	220	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-05:21:00	\N	0.6	-04:39:00	\N	0.9	-05:59:00	-04:23:00	Hague Channel, east of Doe Point	AK
102672	Johnston Channel, off Halftide Rock, Alaska Current	NOS	PCT5766_1	55.83333	-160.78333	:America/Anchorage	USA	knots	337	179	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-04:24:00	\N	0.5	-04:45:00	\N	0.5	-04:27:00	-05:15:00	Johnston Channel, off Halftide Rock	AK
102673	Port Heiden, Alaska Current	NOS	PCT5771_1	56.98333	-158.88333	:America/Anchorage	USA	knots	233	67	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-01:15:00	\N	0.4	-01:05:00	\N	0.4	-02:23:00	-01:14:00	Port Heiden	AK
102674	Morakas Point, Naknek River, Kvichak Bay, Alaska Current	NOS	PCT5781_1	58.73333	-156.93333	:America/Anchorage	USA	knots	294	111	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	01:15:00	\N	0.9	01:05:00	\N	0.5	02:01:00	00:04:00	Morakas Point, Naknek River	AK
102675	Cape Constantine, 4 mi southeast of, Alaska Current	NOS	PCT5791_1	58.33333	-158.76667	:America/Anchorage	USA	knots	238	59	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-01:52:00	\N	0.7	-01:38:00	\N	0.6	-02:08:00	-01:05:00	Cape Constantine, 4 miles Southeast of	AK
102676	Protection Point, 2.5 mi east of, Alaska Current	NOS	PCT5796_1	58.5	-158.61667	:America/Anchorage	USA	knots	180	13	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-01:04:00	\N	1	-01:25:00	\N	1	-00:44:00	-00:40:00	Protection Point, 2.5 miles east of	AK
102677	Nushagak Bay entrance, Alaska Current	NOS	PCT5801_1	58.56667	-158.41667	:America/Anchorage	USA	knots	180	343	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-00:23:00	\N	1	00:03:00	\N	1	-00:59:00	00:19:00	Nushagak Bay entrance	AK
102678	Etolin Point, 8.5 mi west of, Alaska Current	NOS	PCT5806_1	58.63333	-158.58333	:America/Anchorage	USA	knots	173	352	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	00:05:00	\N	1.2	00:13:00	\N	0.9	-00:19:00	00:08:00	Etolin Point, 8.5 miles west of	AK
102679	Clarks Point, 1 mi west of, Alaska Current	NOS	PCT5811_1	58.83333	-158.58333	:America/Anchorage	USA	knots	213	18	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-00:02:00	\N	1.4	00:34:00	\N	1.3	-00:07:00	00:41:00	Clarks Point, 1 mile west of	AK
102680	Goodnews Bay entrance, Kuskokwim Bay, Alaska Current	NOS	PCT5821_1	59.06667	-161.78333	:America/Anchorage	USA	knots	213	20	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-06:02:00	\N	0.9	-06:05:00	\N	0.9	-06:23:00	-05:26:00	Goodnews Bay entrance	AK
102681	Carter Bay, west of, Kuskokwim Bay, Alaska Current	NOS	PCT5826_1	59.28333	-162.36667	:America/Nome	USA	knots	212	21	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-04:21:00	\N	0.6	-04:29:00	\N	0.6	-05:10:00	-03:44:00	Carter Bay, west of	AK
102682	Warehouse Bluff, southwest of, Kuskokwim Bay, Alaska Current	NOS	PCT5831_1	59.78333	-162.23333	:America/Nome	USA	knots	188	7	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-03:45:00	\N	0.8	-03:21:00	\N	0.6	-03:43:00	-03:21:00	Warehouse Bluff, southwest of	AK
102683	Apokak Creek entrance, Kuskokwim Bay, Alaska Current	NOS	PCT5836_1	60.13333	-162.16667	:America/Nome	USA	knots	205	30	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-02:51:00	\N	1.1	-03:42:00	\N	1.1	-05:04:00	-02:04:00	Apokak Creek entrance	AK
102684	Walrus Island, 0.5 mi west of, Pribilof Islands, Alaska Current	NOS	PCT5841_1	57.18333	-169.95	:America/Nome	USA	knots	210	18	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-06:38:00	\N	0.5	-06:47:00	\N	0.4	-06:40:00	-06:40:00	Walrus Island, 0.5 mile west of	AK
102685	SW Point, St. Paul Island, 1 mi off, Pribilof Islands, Alaska Current	NOS	PCT5861_1	57.15	-170.45	:America/Nome	USA	knots	170	330	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-08:10:00	\N	0.3	-08:10:00	\N	0.8	-08:55:00	-08:55:00	SW Point, St. Paul Island, 1 mile off	AK
102686	Hooper Bay entrance (depth 15 ft), Yukon Delta, Alaska Current	NOS	PCT5866_1	61.5	-166.0500030517578	:America/Nome	USA	knots	223	46	\N	\N	Depth is as provided in the stations list.\nUnknown whether it is below surface or chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-01:22:00	\N	0.8	-01:09:00	\N	0.7	-02:17:00	-01:11:00	Hooper Bay entrance	AK
102687	St. Matthew Island, southwest coast, Bering Sea, Alaska Current	NOS	PCT5871_1	60.35	-172.71667	:America/Nome	USA	knots	119	292	\N	\N	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	03:07:00	\N	0.4	03:20:00	\N	0.5	02:24:00	03:29:00	St. Mathew I., southwest coast	AK
102688	Apavawook Cape, 1 mi south of, St. Lawrence Island, Alaska Current	NOS	PCT5881_1	63.11667	-168.93333	:America/Adak	USA	knots	272	75	\N	Reference is in time zone :America/Anchorage; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	-02:23:00	\N	0.4	-02:14:00	\N	0.2	-02:58:00	-02:39:00	Apavawook Cape, 1 mile south of	AK
102689	Off Northeast Cape, St. Lawrence Island, Alaska Current	NOS	PCT5886_1	63.33330154418945	-168.8332977294922	:America/Adak	USA	knots	258	95	\N	Reference is in time zone :America/Anchorage; adjusted offsets 1 hr\nto undo LST compensation.	No depth was provided in the stations list.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99002	00:10:00	\N	0.3	00:57:00	\N	0.3	-00:41:00	01:16:00	Off Northeast Cape	AK
102690	Waldron Island, 1.7 nmi west of (depth 27 ft), Washington Current	NOS	PUG1716_23	48.704219818115234	-123.10476684570312	:America/Los_Angeles	USA	knots	252	325	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99654	00:33:00	\N	0.25	-00:27:00	\N	0.48	-01:00:00	00:21:00	Waldron Island, 1.7 nm west of	WA
102691	Waldron Island, 1.7 nmi west of (depth 93 ft), Washington Current	NOS	PUG1716_13	48.704219818115234	-123.10476684570312	:America/Los_Angeles	USA	knots	227	31	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99654	-00:30:00	\N	0.2	-00:35:00	\N	0.55	-02:10:00	00:11:00	Waldron Island, 1.7 nm west of	WA
102692	Waldron Island, 1.7 nmi west of (depth 159 ft), Washington Current	NOS	PUG1716_3	48.704219818115234	-123.10476684570312	:America/Los_Angeles	USA	knots	232	28	\N	\N	Depth is as provided in the stations list.\nDepth is below chart datum.	CO-OPS Metadata API	Public domain	2023-12-31	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	\N	\N	\N	\N	\N	99654	-00:40:00	\N	0.22	-00:36:00	\N	0.53	-01:50:00	00:12:00	Waldron Island, 1.7 nm west of	WA
100749	Sabine Pass, USCG base (depth 267 ft), Texas Current	NOS	sn0201_20	29.7286	-93.87	:America/Chicago	USA	knots	\N	327.4	\N	\N	No depth was provided in the stations list.  Depth is as specified in the\nharcon record.  Unknown whether it is below surface or chart datum.\nNo mean flood direction provided.  Used azimuth from harcon record.	CO-OPS Metadata API	Public domain	2023-12-30	Credit:NOAA data processed by David Flater for XTide\n https://flaterco.com/xtide/	00:00:00	\N	0.049	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N	Sabine Pass, USCG Base	TX
\.



SELECT pg_catalog.setval('public.data_sets_index_seq', 110735, true);



ALTER TABLE ONLY public.aliases
    ADD CONSTRAINT aliases_pkey PRIMARY KEY (format, alias);



ALTER TABLE ONLY public.constants
    ADD CONSTRAINT constants_pkey PRIMARY KEY (index, name);



ALTER TABLE ONLY public.constituents
    ADD CONSTRAINT constituents_pkey PRIMARY KEY (name);



ALTER TABLE ONLY public.currents_geogroups
    ADD CONSTRAINT currents_geogroups_pkey PRIMARY KEY (sid);



ALTER TABLE ONLY public.data_sets
    ADD CONSTRAINT data_sets_pkey PRIMARY KEY (index);



ALTER TABLE ONLY public.aliases
    ADD CONSTRAINT aliases_name_fkey FOREIGN KEY (name) REFERENCES public.constituents(name);



ALTER TABLE ONLY public.constants
    ADD CONSTRAINT constants_index_fkey FOREIGN KEY (index) REFERENCES public.data_sets(index) ON DELETE CASCADE;



ALTER TABLE ONLY public.constants
    ADD CONSTRAINT constants_name_fkey FOREIGN KEY (name) REFERENCES public.constituents(name);



ALTER TABLE ONLY public.data_sets
    ADD CONSTRAINT data_sets_ref_index_fkey FOREIGN KEY (ref_index) REFERENCES public.data_sets(index);



